// Copyright (c) 2009 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// Created by postproc-shortwords 1.8 on 2009-03-22 11:11:34
// From input file /tmp/good_quad_input4567_sort.utf8
// See compact_lang_det.cc for usage
//
#include "encodings/compact_lang_det/cldutil.h"

// Suppressed:
//      ms-Latn gl-Latn mt-Latn af-Latn eu-Latn mk-Cyrl fa-Arab

// Remapped:
//      xxx-Latn=>ut-Latn sh-Latn=>hr-Latn sh-Cyrl=>sr-Cyrl

// ms/id probabilities leveled

static const int kQuadTableBuildDate = 20090322;    // yyyymmdd

COMPILE_ASSERT(MONTENEGRIN == 160, k_montenegrin_changed);
COMPILE_ASSERT(EXT_NUM_LANGUAGES == 209, k_ext_num_languages_changed);

// Nil-grams: 18 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE
//     SYRIAC ORIYA INUKTITUT

// Uni-grams: 6 languages
//     Japanese Korean Chinese VIETNAMESE ChineseT ZHUANG

// Words/Quads/Gibberish: 38 languages in range ENGLISH..NORWEGIAN_N:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     Ignore BULGARIAN CROATIAN SERBIAN TAGALOG TURKISH UKRAINIAN
//     HINDI INDONESIAN MALAY ARABIC CATALAN SLOVENIAN MARATHI
//     VIETNAMESE SLOVAK NORWEGIAN_N

//  ENGLISH 1836
//  DANISH 1263
//  DUTCH 1882
//  FINNISH 3458
//  FRENCH 2322
//  GERMAN 3061
//  HEBREW 16668
//  ITALIAN 1061
//  NORWEGIAN 1063
//  POLISH 5152
//  PORTUGUESE 1502
//  RUSSIAN 3933
//  SPANISH 1199
//  SWEDISH 1922
//  CZECH 3770
//  ICELANDIC 3554
//  LATVIAN 3970
//  LITHUANIAN 3229
//  ROMANIAN 2290
//  HUNGARIAN 4997
//  ESTONIAN 3612
//  Ignore 13                         [mapped to English]
//  BULGARIAN 4362
//  CROATIAN 2379
//  SERBIAN 4261
//  TAGALOG 1543
//  TURKISH 4038
//  UKRAINIAN 7551
//  HINDI 8958
//  INDONESIAN 2285
//  MALAY 51                      [Indonesian]
//  ARABIC 16053
//  CATALAN 1226
//  SLOVENIAN 1804
//  MARATHI 131                [Hindi]
//  VIETNAMESE 2870
//  SLOVAK 2464
//  NORWEGIAN_N 64          [Norwegian]


static const int kQuadTableSize = 32768;    // Bucket count
static const int kQuadTableKeyMask = 0xffff0000;    // Mask hash key

// 422572 possible entries:
// 130982 filled (30%), 815 merged (0%), 290775 dropped (68%)
static const cld::IndirectProbBucket4 kQuadTable[kQuadTableSize] = {
  // key[4], words[4] in UTF-8
  // value[4]
  { {0xcb670001,0x6db20002,0xb5da0003,0x99dd0004}},	// [000] шате_, cław, _لبدء_, stňu
  { {0x20070005,0x23bf0006,0xbddb0007,0xdce10002}},	//   _kuni_, täjä_, stèr, _zalą
  { {0x71730003,0x11d70003,0xddc40008,0x5d3b0009}},	//   تهلا, جولة_, _križ, _בתיא
  { {0xdfcf000a,0xf989000b,0xc2c60003,0x2007000c}},	//   ويل_, ור_, _نيجي, _muni_
  { {0x2007000d,0x3ea0000e,0xd3370009,0x97570009}},	//   _luni_, áit_, _דרכה_, שינו_
  { {0xef1f000f,0x6e360010,0xb4e00011,0x6c340012}},	//   tjük_, šybo, _तरफ़_, مفتا
  { {0x3ea00013,0xdc870014,0xbc670003,0x4c940015}},	//   šit_, исъл_, لمون_, сийс
  { {0xef1f000f,0x63bb0016,0xdb0d0017,0xa5bb0018}},	//   rjük_, giun, riaç, nsór
  { {0x36670019,0xe8d9001a,0x2fc6001b,0x7f3b0009}},	//   _като_, _đỡ_, mnog_, _שעמו
  { {0x2fc6001c,0x645e001d,0x98be001e,0x63a9001f}},	//   lnog_, _oppi, egtā_, ahen
  { {0x2b9c0020,0x7528001e,0xab660021,0xc19b0009}},	//   _tích_, _iedz, _ввел, דשיי
  { {0x63a90022,0x63bb000d,0x749b0009,0x4c9b0009}},	//   chen, ciun, _שיאפ, _שבאו
  { {0x69dc0023,0xa5070024,0x6fdd0025,0x333b0009}},	//   _okre, иявл, xécu, _יתאמ
  { {0x71730003,0x92b70009,0x99d30012,0xda7b0009}},	//   _وهنا, _דפדף_, _وتوا, _שנגר
  { {0x75280026,0x8937000b,0x66160002,0x6db20002}},	//   _medz, _כרגע_, _etyk, sław
  { {0x248d0027,0x6d470028,0x7afd0029,0x2fc60027}},	//   ćem_, sgja, ľstv, jnog_
  { {0x2fc6001c,0x6d5a002a,0xafb80003,0x6b8d002b}},	// [010] dnog_, _obta, _خطوط_, rjag
  { {0x63bb000d,0x6443002c,0x7ac4002d,0x6b8d002e}},	//   ziun, yuni, істе, sjag
  { {0x6b820027,0x6563002f,0x997d0030,0x6aad0031}},	//   _onog, venh, zňů_, szaf
  { {0x63bb000d,0xa8570009,0x6d5a0032,0x02d90012}},	//   xiun, שיאה_, _abta, _موجب_
  { {0xd6ab000a,0x63a90033,0x75280034,0x98780035}},	//   خدام_, vhen, _bedz, kšķa_
  { {0x27ed0036,0x69c6000e,0xb9950012,0xaaca0011}},	//   _when_, ékel, _الآب, ापनक
  { {0x27ed0036,0xa3ae0037,0x4c920001,0x2fc60027}},	//   _then_, _कतम_, зијс, bnog_
  { {0xc052000b,0xc17e0010,0xa3d70037,0x7e6d0038}},	//   _מזל_, šėte_, ाकि_, _osap
  { {0x67290039,0x2918003a,0x63a9003b,0x1306003c}},	//   _ieej, ıran_, rhen, щный_
  { {0xd9450001,0x2475001e,0xa9690001,0xdb090028}},	//   љени, _tām_, ћина_, _ánæg
  { {0xa3d70037,0xddc4003d,0x44310034,0x3c440012}},	//   ाका_, _priž, jsz_, _وَكِ
  { {0x38780028,0x4431000e,0x60080009,0xedb20011}},	//   ærra_, dsz_, יִשְ, ुच्छ
  { {0xeab3000a,0x6601003e,0x7e6d000f,0x4431003f}},	//   _بعض_, _kilk, _csap, esz_
  { {0x201a0006,0x2fc60027,0xb21b0040,0x7bdd0041}},	//   yppi_, znog_, _kræf, _aksu
  { {0x10150003,0x4431000e,0xe4da0012,0x28cf0011}},	//   _ابتد, gsz_, اوزت_, _सुचि
  { {0xee3f0042,0x69dc0043,0x28bd0011,0x260a0011}},	//   brý_, _skre, ्पनि, ादमी_
  { {0x2fc6001c,0xa3d70044,0x44310002,0x8f1b0009}},	// [020] vnog_, ाक़_, asz_, _גופת
  { {0x0ae90003,0xe2450012,0xa5bb0018,0x44250045}},	//   شرقي_, تخفي, ssór, _owl_
  { {0x75280039,0xef1a0046,0xc209000b,0x2fc60027}},	//   _redz, гме_, תה_, tnog_
  { {0x4386000a,0xbb860003,0xa3e70037,0x7e2a0024}},	//   _الحق, _الحي, _मील_, гіка_
  { {0x65940047,0x7e56002d,0x2fc60027,0x529a0048}},	//   жалу, стец, rnog_, _съня_
  { {0x291e0028,0xd5b3000b,0xdb160028,0x2fc60049}},	//   _ýta_, ּׁה_, ábær, snog_
  { {0x3cf40037,0x40960003,0xb8960003,0x2fc60027}},	//   ेखें_, _الزر, _الزع, pnog_
  { {0x53980014,0xe644003a,0x7646004a,0xdb0d0028}},	//   рвия_, şlığ, kuky, nnað
  { {0x539b000b,0xcb670001,0x5b330012,0x314a0009}},	//   טיקו, сање_, سعير, ְתֹּ
  { {0x44310002,0xdbde004b,0x7dc60012,0x316a004c}},	//   ysz_, nţân, _اترك, ушио_
  { {0x3bd6002d,0x89db0009,0xec130012,0x1d170009}},	//   _людс, רחיי, _فولد, _הקבר_
  { {0x96f9004d,0x65ab004e,0x7bc8004f,0x478b0050}},	//   иент_, _mühe, édul, усом_
  { {0x65ab0051,0x27fc0029,0x36d50024,0xa3020011}},	//   _lühe, ívny_, іогр, लखोज_
  { {0xe5c70015,0x4431000e,0x98b8003a,0xf2370009}},	//   ссмо, tsz_, _ları_, _פרוץ_
  { {0x7995003e,0xe8d90020,0x71bb000b,0xdb0d0028}},	//   _rozw, _đủ_, _תצוג, fnað
  { {0x69c80052,0x44310053,0xb4e90011,0x67d40048}},	//   lnde, rsz_, _बरी_, _нощу
  { {0x7995003e,0x91b90014,0x4431000e,0x7e6d002c}},	// [030] _pozw, агат_, ssz_, _usap
  { {0x672f003e,0x67290051,0x64410054,0x5a340055}},	//   lacj, _seej, àlis, янут
  { {0xe719000a,0x64410056,0xe5880009,0x515b0009}},	//   ليات_, álid, _הָרָ, רכבו
  { {0xe00b0037,0x672f0002,0xcfab0012,0x22400057}},	//   _संसद_, nacj, دائم_, brik_
  { {0xdce8001e,0xed4e0001,0xfe450024,0x68080030}},	//   _radā, мо_, інко, _dědi
  { {0xd658000b,0xdb1b003a,0xb21b0058,0x63ad0059}},	//   ציות_, onuç, _præf, lhan
  { {0x672f003e,0x69da005a,0xbca50012,0x6601005b}},	//   kacj, dote, تمثي, _vilk
  { {0xdb000051,0xeb99005c,0xe3b10003,0x69c8005d}},	//   himõ, рии_, برت_, ende
  { {0xbfa80014,0x69da0051,0x672f0002,0x6609005e}},	//   _утре_, fote, dacj, _uuek
  { {0xb21b0058,0x4999004d,0x63ad002e,0x11d60012}},	//   _træf, ртия_, hhan, يوية_
  { {0xa3e90044,0x77ca0001,0x98b8003a,0x6ca70024}},	//   यता_, илог_, _yarı_, _ураж
  { {0x8b67000a,0x672f003e,0x99860002,0x22590015}},	//   _دائم, gacj, _ktoś_, _виды_
  { {0x6db20002,0x75e0000e,0xa3d80037,0xcf560009}},	//   płat, közt, िवस_, חברת_
  { {0x98a5005f,0x67c40031,0x22400060,0x867a0009}},	//   _миле, dője, vrik_, ברשו
  { {0x8fe6000a,0xdb0d0028,0xe885002d,0x98a5001e}},	//   _وأعم, tnað, _єгип, balā_
  { {0x42260014,0x7bc90061,0x63ad0062,0xc0520009}},	//   ждав, nneu, ghan, _חזה_
  { {0xa3bb0044,0xf11a0003,0x764b0052,0xda660003}},	// [040] _अगर_, لغات_, _ägyp, غاري
  { {0x65ab0051,0x42550063,0x98b80060,0x99920064}},	//   _pühe, ятст, _sarı_, kryť_
  { {0x106a0015,0xd70a003c,0x60260024,0x32270030}},	//   рией_, анее_, ідда, _čtyř_
  { {0x68e30065,0xddcd0066,0x225d0030,0x5ea60012}},	//   _mynd, _vrať, ízký_, يمال
  { {0xa3d70037,0x69c6000e,0x20070028,0xc7b30009}},	//   ाकर_, ékek, ínir_, ובא_
  { {0x672f003e,0xa2d30037,0x64410067,0x45b70024}},	//   zacj, _भुट्, šlie, огію_
  { {0x6d4a0068,0xfbaa0024,0x07a60069,0xb21b0040}},	//   rgfa, итий_, _давн, _præg
  { {0xd326002d,0x7bc90061,0x6e460003,0x63a4006a}},	//   цьки, gneu, _ونأم, nkin
  { {0xdcfe0039,0xaa66002d,0x63a4006b,0x69da006c}},	//   _kopē, ітик, ikin, tote
  { {0xb2bb000b,0x27e0006d,0x672f0002,0x69da006e}},	//   ימפר, _akin_, wacj, uote
  { {0xdb06000f,0x672f0002,0x69c80052,0x2610001a}},	//   _elké, tacj, rnde, _hào_
  { {0x2907006f,0x63a40070,0x28bd0011,0xc2760012}},	//   _egna_, jkin, ्पति, _وُضع
  { {0x672f003e,0xd250000a,0x5f940014,0x20180071}},	//   racj, _أنت_, фият, ūri_
  { {0x1dbc0011,0x63a40072,0x3e5e0035,0x98be0073}},	//   ्चित, ekin, mātā_, egtą_
  { {0x7bc00051,0x2610001a,0x2ca50074,0xe4e40024}},	//   oimu, _lào_, áld_, дітн
  { {0x52150075,0xb8e00037,0x20040076,0x7b88004c}},	//   здат, ूप_, _nimi_, ољуб_
  { {0x26100020,0xd6280001,0x3e5e001e,0xdc3c0035}},	// [050] _nào_, _доње_, nātā_, kšķe
  { {0xddc2003e,0x63a40077,0x63ad0078,0x27e60025}},	//   rtoś, akin, shan, elon_
  { {0x35f8000a,0xddc20002,0x7bc00079,0x2eed0034}},	//   _بريد_, stoś, kimu, _szef_
  { {0x7bc0007a,0xdc88000b,0x201e0010,0x2610001a}},	//   jimu, _וְשָ, ipti_, _bào_
  { {0xab5d003e,0x79a70001,0x7bc0007b,0x6b7a0009}},	//   niże, _дрве, dimu, _פרשנ
  { {0x5a34007c,0x98a5007d,0x8afa007e,0xbafa000b}},	//   _інст, nală_, _להרי, _להרש
  { {0xdd8e0003,0x96bb0011,0xf9920009,0xfd360012}},	//   اوى_, _शेरॉ, _ארם_, سكيب_
  { {0xb21b0058,0xf7730012,0xdb4e0012,0xe1ff0034}},	//   _træd, _غاز_, هَى_, _psów_
  { {0x82350012,0xa2c10011,0x76420025,0x7bc9007f}},	//   أربا, लपट्, croy, rneu
  { {0x14190003,0x314b0009,0x9c870012,0x27e00080}},	//   _هيئة_, ׁתִּ, _وشاه, _skin_
  { {0x3cdb0011,0xf6490009,0xe8e00081,0xb33b0060}},	//   _खुले_, _תצ_, riệu_, _elçi
  { {0xf7720003,0x94040003,0x3e5e001e,0xe3b30012}},	//   راج_, _قوله, bātā_, _غرض_
  { {0xd5c8001a,0xddc90082,0xa3c10037,0xdb0d005e}},	//   iền_, _mrež, ्चन_, nnaõ
  { {0x98ab0037,0x427a000b,0x98a5000d,0xdb000018}},	//   चनाए, _לאנג, gală_, rimô
  { {0x07a60001,0xc0e2002d,0xa0a50083,0x2a6d0084}},	//   _накн, _пошк, _хайд, lweb_
  { {0x883a000b,0x69c10085,0xccf20009,0xd7760012}},	//   _התקו, lile, תכל_, _رابع
  { {0xc64a0003,0xeb970086,0xfe720012,0x98a5004b}},	// [060] _اجعل_, чит_, _أدب_, bală_
  { {0x98a5000d,0xb6bb000b,0xfa490003,0xab5d0002}},	//   cală_, _לצפי, تشفى_, roży
  { {0x859b000b,0xa0670014,0x69c6000e,0x759b0009}},	//   _השיו, заха_, ékei, _הייח
  { {0x2d9a0087,0xb21b0040,0xab5d0034,0x7bc00088}},	//   _hope_, _dræb, poży, ximu
  { {0x67220039,0x7bc0007a,0x69c10089,0xc7b3000b}},	//   rboj, vimu, kile, עבד_
  { {0x2610008a,0x6d5c008b,0x63ab0051,0x865b000b}},	//   _vào_, nfra, _algn, מדני
  { {0x69c1008c,0x7bc0008d,0x661b008e,0x2918008f}},	//   dile, timu, _etuk, _ifra_
  { {0xdb000006,0xa857000b,0x3057000b,0x34370003}},	//   yhmä, _מילה_, _משלך_, أسود_
  { {0xadc3008a,0xb21b0040,0x7bc00090,0x69c1005b}},	//   _quản, _træe, rimu, file
  { {0x69c10091,0x7bc00092,0x361b0009,0x9aeb0009}},	//   gile, simu, _לומד, מַיִ
  { {0xf9930093,0x30a30014,0x660d0010,0xc057002d}},	//   תרת_, еряв, _suak, пія_
  { {0x65b0004a,0x201e0010,0xeb970094,0xd36f0012}},	//   _lähd, rpti_, _них_, _مهم_
  { {0x98a5000d,0x8ae3002d,0x69c10095,0x82330012}},	//   tală_, _пішл, bile, _كروا
  { {0x65b00006,0xceb3000b,0xaa3b000b,0x29d30012}},	//   _nähd, גיש_, _פתוח, _كينس
  { {0xd5c80020,0x515b000b,0x98a5000d,0x415b0009}},	//   yền_, _הכוו, rală_, _הדוג
  { {0x6d4e002c,0x443f0096,0x6d5c0097,0xc1780073}},	//   agba, ču_, afra, ldė_
  { {0xc73c000b,0x98a5000d,0xe2f8002d,0x6d5c0052}},	// [070] _התחת, pală_, зеті_, bfra
  { {0x5c070098,0x67d2001e,0xc1780073,0x7ae60099}},	//   _няма, māja, ndė_, _dykt
  { {0x3ea6001e,0x8014002d,0x661b009a,0x8f990012}},	//   _ļoti_, ефіц, _stuk, ينئذ_
  { {0x6443009b,0x69c1009c,0xa7140024,0x60f80024}},	//   vrni, zile, емці, їнця_
  { {0xee38002d,0x69c1003a,0x4b7a0009,0x6ee70012}},	//   зні_, yile, _וארו, أسال
  { {0xe6780009,0x8d540048,0x7bdf009d,0xddd6009e}},	//   פתוח_, етъч, loqu, _kryš
  { {0x6458009f,0x644300a0,0x05740012,0x24f70009}},	//   gtvi, urni, عاهد, הֶ֗ם_
  { {0x98a50010,0x67d2001e,0xe3b10012,0xa2c20011}},	//   nalą_, kāja, ضرب_, _रेड्
  { {0x64580071,0x75e0000e,0xd24e0012,0x28bd0011}},	//   atvi, közp, لني_, ्पवि
  { {0x67d2001e,0x81f60003,0xd0590024,0xeeeb0081}},	//   dāja, وفير_, ормі_, ýờng_
  { {0x69c100a1,0xe3c200a2,0xc948000b,0x4b550014}},	//   rile, lmış_, הֲרֹ, _жълт
  { {0x69c100a3,0x907a0009,0xcb690012,0x207a0009}},	//   sile, קטרי, _ذمته_, קארא
  { {0xe3c200a2,0x65b000a4,0x2d9a00a5,0xb9b50048}},	//   nmış_, _lähe, _pope_, _оскъ
  { {0x65ab0051,0x9c7c009b,0x90c500a6,0x8afa0009}},	//   _püha, _izčr, _обле, _והני
  { {0x6d5c00a7,0x66030015,0xed570014,0x65b000a8}},	//   rfra, тпра, ьор_, _nähe
  { {0x25b40010,0x6c070003,0x67d2001e,0x5ea60012}},	//   _šalį_, ِيِّ_, bāja, _يمثل
  { {0x69de00a9,0x8f8b0009,0xd5b20012,0x550d0011}},	// [080] tope, _וְיֵ, _لفظ_, िखाए_
  { {0x31a4000e,0x65ab0032,0x7bcd00aa,0xb14300ab}},	//   _közi_, _hühn, anau, кнул
  { {0xb21b0058,0x8b26004c,0x65ab0032,0x98a50073}},	//   _præc, _одне, _kühn, balą_
  { {0xdfd20003,0x201c001e,0x46ea00ac,0xa3e90011}},	//   خيص_, īvi_, оден_, यतः_
  { {0x65b0004a,0xaff70012,0x42d60024,0xfe6f0012}},	//   _tähd, ذفها_, _ціну, لدو_
  { {0x645800ad,0x644a0032,0xaac500ae,0xd6e900af}},	//   ttvi, tufi, _ستُن, הַצָ
  { {0x91030015,0x84380003,0x70560012,0x645800b0}},	//   _апре, أكبر_, _تنزا, utvi
  { {0xda080020,0x8aa6002d,0x69cf0061,0xc2740001}},	//   _hỏi_, дрод, écen, елиј
  { {0x026a0024,0xd7570012,0x200e00b1,0x870b0009}},	//   іший_, _تلقت_, _sufi_, _וּבֶ
  { {0xb5aa0003,0x67d2001e,0x5e9b000b,0x6e9b0009}},	//   _بارك_, vāja, _ובמק, _ובמח
  { {0xc1780010,0x76400028,0x65ab0032,0xda080081}},	//   rdė_, ámyn, _bühn, _mỏi_
  { {0x67d2001e,0xdce50029,0xd5c80081,0x73360012}},	//   tāja, _pohľ, iềm_, _آرائ
  { {0x69cb000e,0x7bdf00b2,0xc3fb0009,0xabfb0009}},	//   égek, voqu, _ולאש, _והאר
  { {0x2907007a,0x58d400b3,0x6c1b0012,0xdcfa0035}},	//   žnai_, _полт, قترح_, _notī
  { {0x7bcd0010,0x7c380070,0xab5d0034,0xe3c20060}},	//   tnau, nsvr, liża, zmış_
  { {0x628200b4,0xcc770009,0x62090012,0x466b00b5}},	//   _kroo, וגלת_, كْرِ_, _дром_
  { {0x2aab002d,0xdee70003,0xa3d60011,0x62340024}},	// [090] цтво_, _تأثي, _सदन_, кету
  { {0xd1310003,0xf9930003,0x51f8003c,0x30eb0048}},	//   اما_, خبر_, дную_, офен_
  { {0x200900b6,0x1dd80012,0x7bdf00b7,0x753500b8}},	//   _kiai_, _تبيع_, poqu, mazz
  { {0x65b000b9,0xa295002d,0xa635002d,0x753500ba}},	//   _vähe, _замі, енді, lazz
  { {0x59de0044,0x799c002a,0xdf360012,0xcfb80009}},	//   नकार, _forw, ركوت_, ולאי_
  { {0x65b00005,0xba430010,0xc58b0015,0x6234004c}},	//   _tähe, žįst, ющее_, _јеру
  { {0x645c0051,0xc01c001a,0x98140012,0x753500b8}},	//   _äril, rước_, _لبقا, iazz
  { {0x6aca0037,0x58050003,0xe3c2003a,0xf3f10012}},	//   ापूर, _أورك, pmış_, دأت_
  { {0xeab10003,0xc9550015,0x99580030,0xc6740012}},	//   طعة_, нтны, láři_, _لطلب
  { {0xf991000a,0x69c50065,0x7c3a0010,0xe5c400bb}},	//   ابة_, nihe, štri, _исхо
  { {0xfc30000a,0xa3c10044,0xdb510003,0xf992000b}},	//   _نحن_, ्चा_, _مَا_, ארי_
  { {0xd7760003,0xbb840012,0x43840012,0x24860064}},	//   راجع, _للمي, _للمق, _čom_
  { {0xee3700bc,0x23ae0065,0x628200bd,0xa68300be}},	//   ння_, _nýja_, _groo, гляд
  { {0xceb200bf,0xf9c700c0,0x753500c1,0x68020035}},	//   נים_, _ющен, gazz, _jēdz
  { {0x61d6000b,0xdb0b0061,0xab62005e,0x99580030}},	//   _אוסף_, _algé, üügi, jáři_
  { {0xebe3002d,0x2009001a,0xddcd0010,0x61e1008e}},	//   госп, _giai_, _graž, loll
  { {0xe8df0020,0x661c009b,0x65ab0052,0x86c60012}},	// [0a0] _khỏi_, _črko, _kühl, _سيدن
  { {0x61e100c2,0x63a900c3,0x99e900af,0x000000c4}},	//   noll, hken, פַּ֥,
  { {0x7c960003,0x799c0052,0x25a5004a,0x6dc50012}},	//   _أشخا, _vorw, ölle_, _جزيل
  { {0x1bba0003,0x38780028,0x644e001e,0xf4f3002d}},	//   _راجع_, ærri_, mubi, _якiй_
  { {0x63a900c5,0x539b000b,0xdfcf0003,0x92b60012}},	//   dken, _זיכו, حين_, _أحجا
  { {0x6b8b00c6,0xb21b0058,0x63a900c7,0x645c004b}},	//   _angg, _kræn, eken, otri
  { {0x61e1004a,0x186700ac,0x443a000e,0xb1980081}},	//   doll, _пари_, ép_, _nhưỡ
  { {0x628200c8,0x645c00c9,0x67d20035,0xf4130009}},	//   _proo, _ärim, dājo, נפח_
  { {0x645c00ca,0x81c60048,0xa3ae0011,0x1af40048}},	//   htri, ещне, _कतई_, ъпия
  { {0x7abb000b,0x6b8b00b6,0xf6090012,0xd2570009}},	//   פציו, _engg, _قتله_, עשיה_
  { {0xd8f8007c,0xf1b30093,0xdd8f0003,0x69cb000e}},	//   ьної_, רסת_, _دول_, égei
  { {0xd4690003,0xd379002d,0x628200cb,0xb4be0011}},	//   _تحكم_, _очі_, _troo, ीपी_
  { {0x65ab0052,0x21ef0052,0x69c60031,0x657a00cc}},	//   _fühl, fühl_, ékes, _kath
  { {0xb8940003,0x645c0052,0x40940003,0x67d200cd}},	//   _للتع, ftri, _للتر, bājo
  { {0xddcd001c,0xa4d4002d,0x94d40001,0xf9930009}},	//   _traž, горі, горц, _תרצ_
  { {0x657a002c,0x2d9e00ce,0x61fe00cf,0x995800d0}},	//   _lath, _lote_, empl, váři_
  { {0x3df50098,0x71790046,0x2d8c00d1,0xef640014}},	// [0b0] _изис, мбар_, _onde_, _също
  { {0xc4b00011,0xd944004c,0x77a60018,0x3eb30060}},	//   जनाओ, леђи, _róxi, ıntı_
  { {0xb21b00d2,0x764f0034,0x71d70009,0x03f9004c}},	//   _græn, lucy, עובד_, _оној_
  { {0x07a40024,0xc43a0009,0x2eab0009,0x2d8c00d3}},	//   лаєн, _קתרי, ּשַּ, _ande_
  { {0x8b9a000b,0xf6530003,0x99580066,0x64c90037}},	//   _חברת, ائص_, sáři_, िप्श
  { {0x6594002d,0x7bc200d4,0xdd9b0048,0x657a00d5}},	//   лачу, _amou, яше_, _cath
  { {0xabd50046,0x69cf0061,0x10480015,0xa7150024}},	//   кциј, écem, _пяти_, _амбі
  { {0xc1780010,0x68e30052,0x2d8c00d6,0xe4c80012}},	//   klės_, ündu, _ende_, عبون_
  { {0x657a0036,0x853c0010,0x7d08000e,0x7e2b002d}},	//   _fath, _plėt, _kérü, _хіба_
  { {0x92640003,0x36040003,0x657a00d7,0x63a900d8}},	//   اديم, _موقف, _gath, sken
  { {0xb6040066,0x65b0005e,0x644100d9,0xddcd0034}},	//   ntář, _näha, álil, _draż
  { {0x61e1004a,0x2ca70028,0x6b8b00b6,0xdce80030}},	//   soll, mynd_, _ungg, _ladě
  { {0x31a4000e,0xd5b7001a,0xab5d0002,0x442100da}},	//   _közt_, ắng_, liżo, _ath_
  { {0x614500db,0x88c50012,0xd9450048,0xdce80030}},	//   _река, _لتعل, _реки, _nadě
  { {0xb0240020,0xc5f8001e,0xfce600dc,0x84ac0009}},	//   _trườ, ķē_, тово, ִימִ
  { {0x2c7c0066,0xc6d60012,0x645c00dd,0x1e86003c}},	//   ládá_, _لتخت, rtri, _алим
  { {0xc3320093,0x3ce80037,0x7f77000b,0x715a00de}},	// [0c0] יון_, _चुने_, _יעקב_, дрес_
  { {0x7aeb007a,0x3f8d0054,0xa96a0003,0xadfa0012}},	//   _mygt, _aneu_, ظمام_, _تربط_
  { {0x20330003,0xdd05000d,0x2d9e00df,0x657a00e0}},	//   لفلس, ăsăt, _rote_, _rath
  { {0xdce80026,0x6d41003a,0xe3b8003a,0x62840010}},	//   _podľ, _adla, _atın_, _šiom
  { {0x6eb60012,0x66730012,0xdee3004c,0xfecd0009}},	//   خصائ, لدور, аоци, ּמוּ
  { {0x2fc6007a,0x7c3a0029,0xd1320003,0x645c0051}},	//   siog_, štru, _خمس_, _ärik
  { {0x6da30046,0xd4670001,0x6aca0037,0x2ca70058}},	//   рија, вије_, ाप्र, gynd_
  { {0x07a30046,0x50db000b,0xc4d3000b,0xe76a0003}},	//   _касн, _חקלא, יגו_, _تحسن_
  { {0xa6650003,0xcb670001,0x2d9e00e1,0x7fd50024}},	//   _مطلو, тање_, _tote_, _сірі
  { {0x2d8c007d,0x601e0039,0xd5fb0081,0xf426008e}},	//   _unde_, _līme, _trú, öäsi_
  { {0x3137000b,0x9f35002d,0x89370009,0x5c56004c}},	//   כנים_, лені, כריע_, _штаф
  { {0x69c300e2,0xddcd0002,0x6c570009,0x07e40024}},	//   _emne, _wraż, _ייבא_, ицям
  { {0xf773000b,0xcb67004c,0x7c220064,0xaab70012}},	//   בקר_, _јаче_, _čora, _لدور_
  { {0xdcf5001e,0xa382005e,0xc2370009,0xdbd10097}},	//   edzā, öõnn, _ירדו_, lýðs
  { {0xd5b800e3,0xb4ad0037,0x98a30001,0xdce80066}},	//   тся_, कने_, _вије, _radě
  { {0x9cd7000b,0x6bd40012,0x88bc0030,0x21ef005e}},	//   דולה_, لتقر, yběj, rühm_
  { {0x6284007a,0x69c8004a,0x27e900b6,0xdd910012}},	// [0d0] _šioj, oide, _ikan_, _هوة_
  { {0x4a5b000b,0x645a0054,0x69c800e4,0x61150024}},	//   ודמו, àtic, nide, уджу
  { {0x98140003,0xc1e80015,0x290700e5,0x69c800e6}},	//   لبنا, тьте_, äna_, iide
  { {0x69c800e7,0x224900e8,0xa8ab0009,0xb5fb00e9}},	//   hide, prak_, וֹדִ, stád
  { {0x69c800ea,0x3f810066,0xb3ba0009,0xf7740009}},	//   kide, ěhu_, _נמשכ, יקף_
  { {0x27310020,0x601e001e,0x8e08002d,0x6d550070}},	//   ạn_, _zīme, внів_, ngza
  { {0x25a10066,0xe8940015,0x61e50042,0xf1b20009}},	//   _mohl_, _карь, mohl, _פסל_
  { {0x99840010,0xdb090017,0xdddb00eb,0xb8f70011}},	//   ksmų_, nheç, _druš, ाप_
  { {0x443e0058,0xdce1001e,0x38780002,0x11e50048}},	//   _evt_, _palē, _zsrr_, лжим
  { {0x27e900ec,0x63ad00ed,0x6d410040,0x67f80064}},	//   _akan_, hkan, _udla, ríje
  { {0x65ab0051,0x07a600b3,0x63ad00ee,0x8fa600ef}},	//   _tühj, ганн, kkan, гане
  { {0xa5bb0002,0x63ad00f0,0xebd90048,0xa8a80009}},	//   spól, jkan, _ядеш_, דֹשִ
  { {0x200d00c1,0xdddb00f1,0xe1ee0015,0xe7f60011}},	//   _miei_, _zruš, _гг_, ेषता_
  { {0x23a70051,0xcc120037,0x26190081,0x6abb0032}},	//   _mõju_, _ढूँढ_, _mèo_, mzuf
  { {0x225f000e,0x74160012,0x98ac004b,0x443e00f2}},	//   ltuk_, اورا, radă_, ét_
  { {0xa6960046,0xc0520093,0x7bc900f3,0xd1380010}},	//   _број, _הזה_, nieu, _žą_
  { {0x225f00c6,0x6abb0052,0xdd04003a,0x98ac004b}},	// [0e0] ntuk_, nzuf, ırıs, padă_
  { {0x6e24003a,0x11da0003,0x5ebb0009,0x65b00032}},	//   _itib, روضة_, _נזיק, _zähn
  { {0x601e0039,0x11d70003,0x9c7c0010,0x64a600f4}},	//   _tīme, دولة_, _tyči, _сана
  { {0xaf360003,0xe29a0014,0xcf260012,0xd00f0012}},	//   ارات, _зам_, ارضي, سله_
  { {0x657e000e,0x4733002d,0xe5c600f5,0x97570009}},	//   _kaph, сніс, лско, רינו_
  { {0x225f000f,0x8b080066,0x69cb0031,0x3eb20035}},	//   dtuk_, apří, éget, _čatā_
  { {0xbcaa0003,0x8078000b,0xf8780009,0x90780009}},	//   عدتك_, _בְּה, _בְּל, _בְּפ
  { {0xafe60015,0xbc670003,0x7bc900f6,0x69c800f7}},	//   _собл, امين_, gieu, wide
  { {0x0d560003,0x69c800f8,0x85560012,0xb5fb00f9}},	//   _مخاد, tide, _مخاط, ntác
  { {0x104a00fa,0x63ad009b,0x27e600fb,0xd6cf0012}},	//   нями_, zkan, loon_, _عقل_
  { {0xbca60003,0x2a600051,0xa2cb0011,0x0c2600fc}},	//   _حماي, htib_, _सेन्, _смен
  { {0x64410039,0x8c1b000b,0x7bc90061,0x27e600fd}},	//   šlik, _נודי, cieu, noon_
  { {0x78ba000f,0x88bc0066,0xb8eb0011,0x69c800fe}},	//   sztv, zběh, _रे_, pide
  { {0x63a20051,0x99840010,0x3eb90060,0x98a70073}},	//   _hoon, rsmų_, _üste_, _seną_
  { {0x24190015,0x27e6004a,0x63a200ff,0x89370009}},	//   тобы_, koon_, _koon, _גרוע_
  { {0x63a20051,0x25a10052,0x68f50100,0x67f60029}},	//   _joon, _wohl_, üzde, pája
  { {0x65ab0051,0x1a5b0012,0xa2940024,0xc9870086}},	// [0f0] _lühi, عشرة_, баті, лужи
  { {0x7e6d0101,0x2bc60037,0x60d3001e,0xb5fb000e}},	//   _ipap, रोबा, ņemš, stáb
  { {0x27e60070,0x61e50066,0x225f0102,0x3f150103}},	//   foon_, rohl, ztuk_, адес
  { {0xa857000b,0xbddb0061,0xd5b60001,0xd5c8001a}},	//   ריאה_, ssèd, cикл, iều_
  { {0x69cb000e,0xbb3a007e,0x433a0009,0xef180024}},	//   éges, _בערי, _בערב, умі_
  { {0xdcfa00a2,0xdca50104,0xce380009,0x75ed0031}},	//   _altı, иали, נאות_, húzv
  { {0x9f420042,0xbd180024,0x6b9b0032,0x63a20105}},	//   soké_, уції_, tjug, _boon
  { {0x225f000e,0x8a950003,0x747c0009,0xdb040031}},	//   ttuk_, لشخص, תנהג, lkiá
  { {0x7bc90106,0x6d450107,0xdfd80048,0xc7b20009}},	//   rieu, _odha, _сър_, _ובן_
  { {0x7bc90108,0x79c5002d,0xd9450001,0x89a9004d}},	//   sieu, рйоз, јени, тков_
  { {0x229a007a,0x40490014,0xe8f60109,0x7e6d010a}},	//   ešką_, ъпно_, иль_, _apap
  { {0x6d45000e,0x225f000e,0x6283001e,0xe73a0015}},	//   _adha, ptuk_, ānoj, ъем_
  { {0x2bb8000a,0x67d2001e,0x8f9a0009,0x69c7001b}},	//   _حالة_, nāji, דירי, _omje
  { {0xc9870001,0xb2ba0009,0x057a0012,0x69dd0031}},	//   _људи, _שמסר, خمسة_, ésed
  { {0x80880012,0x80e90011,0x2d840030,0x99610035}},	//   _مضيف_, _ऑडिओ_, ěme_, tīņu_
  { {0x65b00052,0x67d2001e,0xb21b0040,0xd8da0009}},	//   _zähl, kāji, _græk, _בקצר
  { {0x9a25000a,0xfd120003,0x42230014,0xd2a7010b}},	// [100] معلن, _وجد_, ждув, акте_
  { {0x1e3b0093,0x64410066,0x27e60070,0xc0460003}},	//   _שגיא, _ovli, woon_, لخصو
  { {0x7e7b007d,0xa3e50037,0xe73a010c,0x27e6010d}},	//   _asup, पका_, вее_, toon_
  { {0x78a30006,0xd823002d,0x753c0002,0x60230024}},	//   änva, ідчи, larz, ідча
  { {0x27e6010e,0xee770003,0x7e7b000e,0x6d410028}},	//   roon_, لصوت_, _csup, ðlag
  { {0x224d005e,0x753c010f,0x644e0110,0xef1f0060}},	//   drek_, narz, orbi, zcü_
  { {0xb7960001,0x9423004c,0x9b440012,0x27e60111}},	//   _краћ, омје, منغو, poon_
  { {0xafe3007c,0x67d2001e,0x5a340048,0xfba7003c}},	//   _досл, bāji, бнит, итый_
  { {0xfbb7000b,0xe57a0001,0x753c0112,0xf6690012}},	//   יפקת_, _иза_, karz, _محله_
  { {0x20180113,0x65ab0051,0x2bc60037,0x63a20070}},	//   _kuri_, _tühi, रोता, _woon
  { {0x753c003e,0x63a20114,0x09f70009,0xd1170009}},	//   darz, _toon, שמים_, יקיה_
  { {0x65b0008b,0xdddb0002,0x22400115,0x3f800017}},	//   _wähl, _opuś, ksik_, _caiu_
  { {0x95cb0014,0x539b000b,0x644e0116,0x3bbb0009}},	//   вува_, _שידו, erbi, _במאד
  { {0x95cb0001,0x2735001a,0x67030037,0x0dcb0001}},	//   тума_, ấn_, रेषक_, туми_
  { {0xab950046,0x51fb000b,0xb21b0058,0xd1380002}},	//   бављ, _שהוצ, _træk, ając_
  { {0x69c7001c,0xbf350014,0xc2c50012,0x7e620117}},	//   _smje, _унищ, ميزي, ktop
  { {0x2bc60011,0x33770009,0xb062008e,0xa7fd0060}},	// [110] रोधा, סתמך_, äänl, atıc
  { {0xdce1007a,0xa6db0028,0xdcb1001a,0x673d0118}},	//   _galė, taðf, ở_, lasj
  { {0xcd76000b,0x4dda000b,0xa34c0010,0x4ddc0009}},	//   _העתק_, _תחתו, dėžė_, _בחזו
  { {0x9f05000a,0x67d20039,0x673d0119,0x33950003}},	//   موضو, tāji, nasj, _الحز
  { {0x2d810051,0x7bcd0010,0x6455011a,0xe7580024}},	//   _kahe_, miau, luzi, ричі_
  { {0x85e8002d,0x69c70027,0x7bcd0010,0xbddb0061}},	//   адів_, _umje, liau, crèt
  { {0x23b1000f,0xb5b8000b,0x673d011b,0x2db80009}},	//   _fájl_, שלוח_, kasj, שלון_
  { {0xdd3a000d,0x2d810051,0x7bcd011c,0x9cd80009}},	//   păşi, _lahe_, niau, יווה_
  { {0x6575000e,0xcbc40012,0x27ed0060,0x46150012}},	//   kezh, تزوي, _iken_, _طوار
  { {0x2d810052,0xd9f90037,0x3f800017,0xb5fd0010}},	//   _nahe_, ्गित_, _saiu_, _apšv
  { {0xe73a0104,0x7bcd0010,0x600a011d,0x65750031}},	//   лен_, kiau, лном_, dezh
  { {0x673d011e,0x753c0112,0x22400052,0xa4f60009}},	//   gasj, warz, ysik_, _הצעד_
  { {0x73c40003,0xa969011f,0x2169011f,0x753c0120}},	//   _بينم, _била_, _били_, tarz
  { {0x64a6002d,0x41260014,0xf77f0017,0x6575000e}},	//   бага, _лошо_, boço_, gezh
  { {0xa34a0014,0x645c0051,0x27ed0121,0x01360009}},	//   лзва_, _ärit, _oken_, _הרצת_
  { {0xd4670001,0x7bcd0010,0x7395002d,0x753c0002}},	//   љите_, giau, ошує, sarz
  { {0x1757000b,0x20180122,0x11da0012,0x63bb0032}},	// [120] _הספר_, _suri_, هورة_, ihun
  { {0x645500c1,0x25a5006f,0x2c610123,0xbdfa0012}},	//   buzi, _noll_, kód_, _حربا_
  { {0x6c86000a,0x645500c1,0xddd60010,0x7bcd0010}},	//   _الجم, cuzi, _kryž, biau
  { {0xb73a0003,0xe7e9002d,0xa3bc0037,0xb5fb0124}},	//   اثاء_, афік_, _अति_, ntán
  { {0x66e6002d,0x444400ff,0x67630003,0xd7ef0012}},	//   щода, _hv_, سُول, ركه_
  { {0x2018007a,0x62830002,0x63bb0052,0x6b840125}},	//   _turi_, łnoc, ehun, ldig
  { {0x29cf001e,0x7e620126,0x628b0127,0x5c740024}},	//   aļas_, stop, _argo, ілит
  { {0xdce30066,0x2bba0012,0xe44f0012,0xb8cc0011}},	//   leně, طاعة_, رضى_, गह_
  { {0xd130000a,0x67d20039,0x2a9a0012,0x6b840128}},	//   ومة_, nāju, ائعة_, idig
  { {0x361b000b,0x7c2a0033,0x1543010c,0x7bde0025}},	//   _עובד, ppfr, _неум, épub
  { {0x673d0119,0xc19b000b,0x9f990129,0x1f7500de}},	//   tasj, אשיי, авну_, олня
  { {0xf8b30093,0x753a0070,0x63bb012a,0x61e8012b}},	//   פשר_, _hetz, chun, sodl
  { {0x4444012c,0x673d012d,0xcaf60012,0x67d20035}},	//   _av_, rasj, _اساب, jāju
  { {0xb21b00c5,0x753a0052,0x645c0051,0x67d2001e}},	//   _kræv, _jetz, _äris, dāju
  { {0xb062004a,0x2d81005e,0xe0d3004c,0x65750031}},	//   ääll, _vahe_, _ношњ, rezh
  { {0xddc4012e,0x753a008b,0x645500c1,0xccab0009}},	//   _vpiš, _letz, ruzi, אֱמֹ
  { {0x7bcd012f,0x67d2001e,0xc2090012,0x2d81005e}},	// [130] riau, tājv, لقرن_, _tahe_
  { {0x753a008b,0x26360002,0x79c80003,0x7bcd0010}},	//   _netz, dło_, موقف_, siau
  { {0xddc40027,0x90d5001a,0x72040012,0x26360034}},	//   _upiš, hàn, أولم, eło_
  { {0x25a5008b,0x6fd4002d,0x18770009,0xd6d10012}},	//   _soll_, пціє, מעבר_, وقا_
  { {0x9599007c,0xb5fd001c,0x67d2001e,0x2c610002}},	//   итку_, _opšt, cāju, wód_
  { {0x5e58000b,0x2bb10037,0x98ac0002,0x7afd0130}},	//   מידע_, जस्थ, sadę_, _izst
  { {0x65b00006,0x4c920001,0x79950052,0x25a50052}},	//   _sähk, дијс, _inzw, _voll_
  { {0x5bc50003,0x2c610002,0x27ed0033,0xa0240052}},	//   تقبل, ród_, _uken_, stöß
  { {0x6025007a,0x25a50131,0x49990024,0xb21b0040}},	//   _dėme, _toll_, атня_, _usæd
  { {0xfc330003,0xc5fb0012,0xdb1d0097,0x65ab0032}},	//   _فحص_, _إعرض_, _umsæ, _mühs
  { {0xc9520093,0xf7720012,0x6faa0012,0x32050132}},	//   ומי_, واح_, لهدف_, rmly_
  { {0xe3b3000a,0x661b0006,0x628b0133,0x22950012}},	//   _عرض_, _kuuk, _trgo, _ولاس
  { {0x6443006f,0x645c0051,0x333f0061,0x69cf0061}},	//   lsni, _ärir, maux_, éces
  { {0x67d20039,0x98ac0030,0xb5fb0134,0x75d60012}},	//   vāju, nadě_, stán, زيزا
  { {0x70520003,0xb97a000b,0xb4b40037,0x833a010c}},	//   _قنوا, _כנסי, झने_, ичат_
  { {0x67d20039,0x0457000a,0x333f0061,0x6b840070}},	//   tāju, تلفة_, naux_, udig
  { {0x9f5f001a,0x49ca0001,0xba290003,0x65b00038}},	// [140] _thuê_, алан_, مسلم_, _lähi
  { {0xa7fd003a,0xb5fb0135,0x3ce00060,0xe0d20012}},	//   ntın, ntál, şivi_, وزا_
  { {0xdce10039,0x67d2001e,0x3e64004a,0xef1a0136}},	//   _dalī, sāju, löt_, аме_
  { {0xf1bf000f,0x753a0052,0x69c6000e,0xb4fb0009}},	//   _után_, _setz, ékez, _כפיי
  { {0x64410026,0x60250010,0x96b70001,0x3e640137}},	//   šlit, _rėme, жују_, nöt_
  { {0x27380020,0xd639002d,0xc7b9000e,0x64430058}},	//   ẩn_, сяці_, _elő_, fsni
  { {0x2636003e,0xe73a0138,0x64430139,0x2918013a}},	//   sło_, _веб_, gsni, _igra_
  { {0x6fb60003,0x79830070,0x8c1b000b,0xdee6013b}},	//   _بمرا, _aanw, סופי, _доби
  { {0xd6250003,0x6443013c,0xf1aa0012,0xdfcf0012}},	//   _فعلي, asni, لاده_, _شيك_
  { {0x36fe0037,0x6d480058,0x65b00052,0x62840010}},	//   रेज़ी_, _udda, _fähi, _šios
  { {0xdfd10003,0x69dd0061,0x3f84013d,0x7c28013e}},	//   فيد_, ésea, _kamu_, _utdr
  { {0xc7c7002d,0x442e0052,0xd7f9000d,0x333f0061}},	//   існи, mpf_, ptăm_, caux_
  { {0x22940014,0x8d770012,0xb9c60012,0x9f4e0031}},	//   _хиля, ياسا, _وتته, ónál_
  { {0x69ca00a7,0x64580066,0x6d5c013f,0xa6db0097}},	//   _umfe, ouvi, ggra, taðb
  { {0x6021001e,0x2ba70001,0x93970012,0x43950024}},	//   _tēma, ојав, يجرا, павс
  { {0xcfe90003,0xdce1001e,0x3f85001e,0xc053000b}},	//   _دفعه_, _salī, ēlus_, _חזק_
  { {0xdce10039,0x23ae0065,0x1ddb0037,0x201c0051}},	// [150] _palī, _nýju_, _बदलत, _huvi_
  { {0x644300e2,0x69da0140,0x6458004a,0xdce70034}},	//   ysni, nnte, kuvi, zeję
  { {0x6e29007a,0x65ab008b,0x7d7a000b,0xe7190003}},	//   _steb, _führ, _הנתו, ميات_
  { {0x69da0052,0x6443013f,0x547a0009,0xa3af0011}},	//   hnte, vsni, _פטרו, _कवि_
  { {0x7afd0039,0x333f0061,0x539a000b,0xcb9a000b}},	//   _uzst, vaux_, _הירו, _הסרט
  { {0xd658000b,0xae7c000b,0x3d190037,0x0dc8002d}},	//   קיות_, שְׁת, _दलों_, олій_
  { {0x9f35002d,0xe3b10003,0x333f0061,0x8cd10037}},	//   _неві, فرة_, taux_, _डेमो
  { {0x65b00006,0x6e380028,0x69da0141,0xeb99004d}},	//   _vähi, ðabú, ente, сии_
  { {0x333f0061,0x64430142,0x98ac0066,0x798300b6}},	//   raux_, ssni, padě_, _panw
  { {0x6443007a,0x65b00051,0x7abc000b,0x5ce50012}},	//   psni, _tähi, יצחו, _فكذل
  { {0xb5fb000e,0x645c0051,0xa7fd003a,0x79830070}},	//   rtál, _ärip, rtın, _vanw
  { {0xb4fa000b,0x2d850143,0x34fa0009,0x3e64008e}},	//   _הפעי, _hale_, _ההעד, töt_
  { {0x19950014,0xa2cb0011,0x65ab0032,0xa7fd0060}},	//   _надя, _सेल्, _rühr, ptın
  { {0xa7fd003a,0x67d2001e,0x2d870144,0xd1840024}},	//   ltıl, tājs, ndne_, _олій
  { {0x9f920145,0x3e64004a,0x64a60146,0x291c0029}},	//   lší_, söt_, чава, ázať_
  { {0xa7fd00a2,0x22520058,0xa5bb0028,0x42260104}},	//   ntıl, tryk_, fpós, здав
  { {0x6e46000a,0x27e000b6,0xab5d0002,0x9f9200d9}},	// [160] _عندم, _ijin_, liżs, nší_
  { {0xb4660147,0x67f80064,0x9f920030,0x48e60148}},	//   _екол, ríjm, iší_, позв
  { {0xe1ff0149,0xab5d003e,0x41dd0011,0x7d7b0009}},	//   _após_, niżs, _मदरस, _פנטו
  { {0x3f860066,0xa6db0028,0x78720028,0x20550055}},	//   udou_, laða, _aðvö, ьтур
  { {0x9f92014a,0x9b170009,0x69da014b,0x3f86014c}},	//   jší_, _מחכה_, ynte, rdou_
  { {0xa6db014d,0x63b60065,0x8afb000b,0x2d85000d}},	//   naða, lkyn, _להכי, _cale_
  { {0x69ce002c,0x3f8400b6,0x8c960024,0x986c0035}},	//   _imbe, _tamu_, ярді, rķēt_
  { {0x69dd0108,0x7d07014e,0xb21b014f,0x50db0009}},	//   ésen, léré, _græs, _הקלא
  { {0xc9860046,0x539b007e,0xa6db0097,0x201c0150}},	//   пуни, מיקו, kaða, _suvi_
  { {0xdebb000b,0x7d070061,0xa7fd003a,0x2d850151}},	//   _הממל, néré, atıl, _gale_
  { {0xf993000b,0x9f920066,0x601e001e,0x69da0152}},	//   גרת_, aší_, _zīmj, rnte
  { {0x60280066,0xc0530009,0x09b90011,0x3cfb0009}},	//   _něme, עזר_, _इत्य, _פלאנ
  { {0xa6db0028,0xc7b30009,0x63b60030,0x69ce0153}},	//   faða, גבר_, dkyn, _ombe
  { {0x7afd0154,0xca970009,0xa6db0097,0xc27b0009}},	//   üste, _מדדי_, gaða, _לרדי
  { {0x7d070061,0x9f420042,0xe1ff0034,0x14180012}},	//   déré, soká_, _opór_, كيّة_
  { {0xa3bc0044,0x69ce0155,0xf8db0009,0xd8db0009}},	//   _अतः_, _ambe, _לחומ, _לקור
  { {0xdcf2001e,0x7d070156,0xda780024,0x52150024}},	// [170] īgāk, féré, зях_, ддат
  { {0xa5bb0028,0xdebc0009,0x76bc0009,0xbef80012}},	//   rpós, _למחל, _למחפ, _عريض_
  { {0x7bdb0002,0xb21b0058,0xdcee000d,0xd91b0009}},	//   ynuu, _præs, rebă, צואל
  { {0x256f003a,0x69ce0157,0x2d850158,0xa8570009}},	//   zılı_, _embe, _sale_, ליבה_
  { {0xeafa0037,0x442c0066,0x256f0060,0x64480159}},	//   ्धृत_, _atd_, yılı_, _avdi
  { {0xcb12015a,0x93b50020,0x9f920004,0x929a0009}},	//   _שלך_, _cũn, vší_, _וישת
  { {0x6da20014,0xc1720009,0x201c0030,0x6592004c}},	//   тища, _שחל_, ívit_, тају
  { {0x395e001e,0xd498000b,0xdcfe001e,0x9f92015b}},	//   egts_, לכות_, _japā, tší_
  { {0x2d85015c,0xa3be0011,0xa3cc0011,0xa7fd0060}},	//   _tale_, ीफ़_, रफ़_, rtıl
  { {0xdcfe0039,0xb5fb000f,0x3ce80037,0xab5b0052}},	//   _lapā, stáj, _चुके_, _flüg
  { {0xd371000a,0x41050047,0x256f003a,0x3cf0015d}},	//   _لها_, ьзов, rılı_, čové_
  { {0x256f003a,0x65b0015e,0x2252003a,0x9f920042}},	//   sılı_, _läht, ünkü_, pší_
  { {0xb8f4015f,0x8f9a000b,0xa6db0028,0xa294002d}},	//   _से_, קישי, taða, _паці
  { {0x273c0020,0x7987003e,0x3615002d,0x6d430160}},	//   ận_, _najw, еєст, nana
  { {0xdddb0027,0x2c870066,0x7646006f,0x80240012}},	//   _oruž, vídá_, ssky, _كريم
  { {0x6d430161,0x63a40010,0x6b890162,0x76460064}},	//   hana, ujin, ndeg, psky
  { {0x63a60163,0xdb0b0164,0x7d07000e,0x59e10037}},	// [180] ökni, _algú, téré, _पदार
  { {0x50d60012,0x23bc0031,0x61470031,0x50ba0012}},	//   وزار, _díja_, vélí, يداد_
  { {0x7bc7007a,0x628b006f,0x859b0009,0xa0670048}},	//   _įjun, ågor, _ושיו, даха_
  { {0x62830035,0x645c0165,0x7d070025,0x657c0166}},	//   ānor, muri, séré, lerh
  { {0x4733002d,0x7d070061,0xdfcf0003,0x4e7a0003}},	//   тніс, péré, جين_, تحاد_
  { {0x657c008b,0x6d430167,0xf2d30009,0x60c90030}},	//   nerh, gana, _יער_, _řeme
  { {0x67f6000e,0x7bc00168,0xd75a0012,0xd8230048}},	//   láju, thmu, _ولست_, _адси
  { {0x69c10169,0x8c1b0009,0x657c016a,0xb5fb0031}},	//   ehle, חוקי, herh, tták
  { {0x53c60037,0x0aea0003,0x657c016b,0x6ac70011}},	//   रोएश, غربي_, kerh, _रेफ़र
  { {0x60280030,0x645c016c,0x442c016d,0xb5fb0097}},	//   _němc, kuri, _ttd_, rták
  { {0x3957000b,0x1957000b,0x63ab000e,0xb5fb000e}},	//   ושים_, וביל_, _fogn, sták
  { {0x33930003,0x9b930003,0x63060012,0xe29a003c}},	//   _للمز, _للمت, _قوال, _мае_
  { {0xdce8007a,0xc3330009,0xe664016e,0x81a60012}},	//   _padė, _סוס_, ктро, _يحتل
  { {0x12fb000b,0xceb3000b,0x645c016f,0x8afb0009}},	//   _והדב, דיש_, furi, _והדי
  { {0xdb06000f,0x67d50170,0xb4b80012,0xa7fd0060}},	//   _elkü, _поку, وافذ_, ntık
  { {0x9fe70003,0x6d430171,0xcf270012,0x62830034}},	//   _تسته, zana, _غربي, łnom
  { {0x9e07002d,0x6e200172,0x65950173,0x657c0174}},	// [190] _очол, _numb, _запу, berh
  { {0x15e90037,0x89340012,0xa7fd0060,0x6f000060}},	//   _फ़ीचर_, نعما, ktık, ümce
  { {0x2a690005,0x917b0020,0xdddb001c,0x1048002d}},	//   stab_, _hệ_, _pruž, дячи_
  { {0x6d430175,0xf0930009,0xaad00011,0x69c10030}},	//   wana, כנע_, _सेवक, zhle
  { {0xcb360093,0xee38007c,0x65b00176,0x69c10066}},	//   _ראשי_, дні_, _täht, yhle
  { {0x65940177,0x6e920003,0x0d840024,0xa2bf0011}},	//   качу, الوا, клін, लैण्
  { {0x917b0020,0x6d3c000b,0x6d430178,0x577b0012}},	//   _lệ_, חתונ, rana, _وصرح_
  { {0x6d430179,0x65b00052,0xb5fb017a,0xe3b10012}},	//   sana, _jähr, stáh, طرب_
  { {0xd24e0003,0x6e20017b,0x645c017c,0x6d43017d}},	//   مني_, _gumb, zuri, pana
  { {0xa2f8000b,0xa6db0028,0xd1c6003c,0xd6180012}},	//   ומחה_, taðn, елье_, _قتلا_
  { {0xab950001,0x657c017e,0x67f60031,0x6724017f}},	//   _пажљ, verh, záju, žije
  { {0x9056000b,0x6d410180,0xa8560009,0xf0920009}},	//   עברו_, _hela, עירה_, אנט_
  { {0x6d4100c6,0xe3c2003a,0x3e690029,0x657c0181}},	//   _kela, nlış_, nút_, terh
  { {0x92c100a2,0x6d4100c6,0x9aa40003,0xdb09004a}},	//   ığın, _jela, _جمهو, rkeä
  { {0x6d4100ec,0xddcd000d,0x61e6000e,0xeb9a00b3}},	//   _mela, _spaţ, ékle, пив_
  { {0x6d410182,0x58f60009,0x645c0183,0xb8760009}},	//   _lela, _אמצע_, ruri, _נתפס_
  { {0xc332000b,0x6e930003,0x2249002c,0x39450184}},	// [1a0] טון_, _مليا, gsak_, oals_
  { {0x39450185,0xe889001a,0x645c0186,0x4c860187}},	//   nals_, _kẻ_, puri, _злов
  { {0x6e2000c6,0xc172000b,0xe53b000b,0x21f40052}},	//   _sumb, רחב_, _מתיר, fähr_
  { {0xfaa60188,0xa2cb0011,0xdeba0009,0x999f0035}},	//   _замо, _सेक्, ּמַל, āršo_
  { {0xe889001a,0xc7d70009,0xaff70012,0x3c3e0030}},	//   _lẻ_, עוני_, رفها_, lův_
  { {0xa4d4002d,0xdce1003a,0xa7fd003a,0xb5fb0031}},	//   колі, _anlı, ttık, ttái
  { {0xc5f3000b,0xe44f0012,0xa3cc0011,0x91e30189}},	//   אדג_, مضي_, रफल_, _соре
  { {0x6d410005,0x3e69018a,0x6e20018b,0x7669008e}},	//   _eela, bút_, _tumb, ösyö
  { {0xdac20024,0xb5fb0031,0x1a5a0012,0x6d41018c}},	//   кцiя_, stái, أشعة_, _fela
  { {0xbe13000a,0x64a60098,0xa7fd003a,0xb5fb000e}},	//   _موقع, _паза, ptık, ltáv
  { {0xc7b10012,0x22490060,0xc1730009,0xdb120097}},	//   لّد_, zsak_, אחת_, _ágæt
  { {0xfa88008a,0x765d004a,0x83360003,0x765a0002}},	//   _từ_, tusy, _أراض, ątyn
  { {0xb5fb0018,0x3945018d,0x996c0035,0xddcd0073}},	//   itáv, bals_, vēņu_, _apaš
  { {0x9f4b0013,0x917b001a,0x9a870003,0xc8f40014}},	//   mocí_, _vệ_, _أَوْ_, _излъ
  { {0x661a004a,0xdcfc0034,0xef1f0060,0x644a018e}},	//   _mitk, odrę, ndük_, nsfi
  { {0xd138007a,0x917b001a,0x7bdf018f,0xc2c50012}},	//   lbą_, _tệ_, unqu, نيزي
  { {0x66d3000f,0x4fd8000b,0x95c50012,0x3ced0011}},	// [1b0] _műkö, _רוחב_, _ليظه, _आँके_
  { {0x65b0008b,0x44210190,0x22490191,0x644a0192}},	//   _währ, _tuh_, rsak_, ksfi
  { {0x2009001a,0x6d470193,0xdce30034,0xe8890081}},	//   _khai_, maja, ofną, _xẻ_
  { {0x6d410194,0x3e690029,0x6d470195,0x18980012}},	//   _sela, tút_, laja, عضلة_
  { {0x69dd000f,0x6b9d0052,0x46a4002d,0x6d410196}},	//   ések, _insg, лаїв, _pela
  { {0xdce80039,0xab5b0052,0x6b8d0197,0xddab0048}},	//   _gadī, _flüc, ldag, ятел_
  { {0xab5b0052,0xe58c0009,0xd49b0198,0x3e690031}},	//   _glüc, לָהָ, ярд_, sút_
  { {0x1adc0037,0xe65d003a,0xe889001a,0x6d470199}},	//   मपंथ, ştığ, _rẻ_, haja
  { {0x6d4100c6,0xe889001a,0x6458019a,0xd7e40024}},	//   _tela, _sẻ_, arvi, _сіро
  { {0x46150003,0x93bc004b,0x6d47019b,0x6995019c}},	//   _شوار, _stăt, jaja, трих
  { {0x6d47019d,0xf992000b,0xb902002d,0x3945019e}},	//   daja, ברי_, изьк, rals_
  { {0xe889001a,0xcb350048,0xdcfa0034,0x63af0034}},	//   _vẻ_, _редъ, _natę, _nocn
  { {0x93b60093,0x63a9001c,0x3945019f,0xb9950012}},	//   _שלנו_, mjen, pals_, _للإب
  { {0xceb20093,0xeab00003,0x865a000b,0xd256000b}},	//   סים_, _دعم_, ודשי, _ישנה_
  { {0xddc20039,0x22510002,0xdce8001e,0xc5f2000b}},	//   ntoš, ązku_, _radī, ידך_
  { {0x6b8d0101,0xa00a0003,0x69d701a0,0x63a901a1}},	//   gdag, _تقبل_, eixe, njen
  { {0x6b8b01a2,0x4b23007c,0x61e20061,0x63a90027}},	// [1c0] _magg, рмув, éolo, ijen
  { {0xfe1e0037,0x00da0003,0x63a901a3,0x63bb01a4}},	//   _यूएस_, وبات_, hjen, hkun
  { {0x8c43003a,0xdce8001e,0x661a000e,0x63bb01a5}},	//   üşte, _vadī, _ritk, kkun
  { {0x93c7007d,0xdfcf0003,0x6b8b01a6,0x69d701a0}},	//   _plăţ, ييل_, _nagg, aixe
  { {0x661a004a,0xddc2001e,0x443e00b6,0x63a901a7}},	//   _pitk, etoš, _swt_, djen
  { {0x8d630046,0xe626001a,0x69c50168,0xb5fb01a8}},	//   авље, _đôla_, chhe, stáv
  { {0xd5b10020,0x98be001e,0x3ea0000d,0x6b8b01a9}},	//   _tín_, katā_, ţit_, _bagg
  { {0xfe1e0037,0x64a30001,0x63a901aa,0xe3b20012}},	//   _यूऍस_, раћа, gjen, شرع_
  { {0xd00f000a,0xfbd30093,0x661a000e,0x97570009}},	//   _ذلك_, יתה_, _titk, _שימו_
  { {0xa3f50013,0x6feb0002,0x661a0070,0x6b8d000e}},	//   ější_, ięce, _uitk, zdag
  { {0x2d9e01ab,0xd1380010,0x115b000b,0x6d4701ac}},	//   _inte_, rbą_, ודיע, vaja
  { {0x2d8c01ad,0x63bb0052,0x317e0052,0x63a901ae}},	//   _hade_, ckun, setz_, cjen
  { {0xc9aa0046,0x42540003,0xf77f003a,0x6d4701af}},	//   _овде_, _إنتر, reç_, taja
  { {0xea77000b,0xa4d5002d,0x7bc20030,0x20d60012}},	//   _סגור_, гогі, _hlou, _لتعج
  { {0x2d8c0036,0x29230029,0xb97b01b0,0xf5e40024}},	//   _made_, árať_, _חנוי, ріям
  { {0x6b800058,0x49170009,0x88f70009,0xd407003c}},	//   nemg, _בקול_, _שזהו_, тяги
  { {0xf8eb0011,0x6b8d01b1,0xf8e20011,0x7bc20030}},	// [1d0] _जुड़ा_, rdag, _पशुप, _mlou
  { {0x79c80012,0x49540012,0x2d8c01b2,0xc69200af}},	//   نوقف_, لخمس, _nade_, _פאי_
  { {0x442701b3,0x69dd000f,0x6b8d01b4,0xc9530009}},	//   _în_, ései, pdag, שמע_
  { {0xb4c10037,0x2d9e01b5,0x82370012,0xfecb0009}},	//   ्छी_, _ante_, _لرسا, ֽמַּ
  { {0x6b8b01a2,0x4ea70098,0xe78401b6,0x6d4501b7}},	//   _ragg, ържа, рухо, _keha
  { {0xf2d20093,0xe618002d,0x66d2003a,0x1d0901b8}},	//   _פעם_, вді_, _sıkç, нели_
  { {0x6b8b0101,0xb5fb000f,0x6c350003,0x63bb00da}},	//   _pagg, ltás, دفعا, tkun
  { {0x93bc000d,0xddc201b9,0x9f420064,0x7bc201ba}},	//   _stăr, rtoš, sokú_, _clou
  { {0xb5fb000f,0xee840015,0x7bc20066,0x63a901bb}},	//   ntás, _выхо, _dlou, rjen
  { {0xdcbb0098,0x6d45009b,0xa8550009,0xc50b0012}},	//   _още_, _neha, ְיָה_, _قتال_
  { {0x2dd8000a,0xf1c30010,0x361a000b,0x1c1f0037}},	//   _شبكة_, _ryšį_, _נועד, _मंगल_
  { {0xf772000a,0xdb0601bc,0xc43a0009,0xdb0f0018}},	//   حاد_, _loká, _נתני, _você
  { {0xa6db0028,0xb5fb000e,0x69d50070,0x4e270048}},	//   naðh, jtás, _omze, лоян_
  { {0x88c50003,0x4ed5002d,0x7bc20027,0xbbbc0011}},	//   _متعل, рюют, _zlou, ईस्क
  { {0xa3ea0014,0xe0550003,0xf8a80003,0x43760055}},	//   едва_, _إختب, _لديه_, луат
  { {0x7afd0013,0x44250051,0xd497001a,0xdcf5001e}},	//   _byst, _mul_, ừng_, edzē
  { {0xa95a0003,0xdcfc01bd,0xe2450012,0x7e970012}},	// [1e0] فجار_, merč, لخلي, _منير_
  { {0xd5b10020,0x3f820051,0x10a6002d,0x6d4501be}},	//   _nó_, leku_, лизн, ðhal
  { {0xdce3007a,0x98be000d,0x2d8c01bf,0xdb060042}},	//   menė, mată_, _rade_, _doká
  { {0x224d00a2,0xd5ed0020,0x3f820051,0xf1bf0066}},	//   ksek_, _trạ, neku_, _stát_
  { {0x98be004b,0xdcf80035,0xb5fb0031,0xb4c10011}},	//   oată_, devā, mtár, ्ज़ी_
  { {0xd5b1008a,0x7bc20013,0x98be000d,0x4425003a}},	//   _có_, _slou, nată_, _bul_
  { {0xd4670001,0x98be000d,0x6da3004c,0x2d8c01c0}},	//   гије_, iată_, сија, _vade_
  { {0x5398005c,0xba540001,0x3f820027,0x1faa002d}},	//   твия_, авиј, jeku_, _якби_
  { {0xdb06000e,0x316a0048,0x7dc60097,0xae890012}},	//   _elkö, ншно_, _aðse, _لخلق_
  { {0xc05a002d,0x644e0058,0x6021001e,0x5eeb000b}},	//   нім_, ksbi, _lēmu, _אַבְ
  { {0x98be007d,0x09f7000b,0xd9170015,0xdfd10003}},	//   dată_, רמים_, лью_, قيد_
  { {0x6d4500c6,0xdcf5001e,0x69c3000e,0xa6db0028}},	//   _seha, zdzē, _elne, laði
  { {0x86740024,0xe667003c,0x98be004b,0x798101c1}},	//   бляє, ытно, fată_, belw
  { {0xbb1b0061,0x98be000d,0xb5fb01c2,0xe5c70015}},	//   _maît, gată_, etár, усмо
  { {0xb4c10037,0x69da01c3,0x6c540024,0xcc780009}},	//   ्छे_, mite, йкру, כְּר
  { {0x7afd0006,0xa3cf0037,0xa09b000b,0x9cd70009}},	//   _pyst, वों_, _טיוט, אולה_
  { {0x79d5002d,0x6d450051,0x98be000d,0x69c8004a}},	// [1f0] ажає, _teha, bată_, ohde
  { {0x98be007d,0xb5fb01c4,0x645a01c5,0xdcf50035}},	//   cată_, rtás, átic, udzē
  { {0x7afd003e,0x69da00e6,0x69c8008e,0xf20401c6}},	//   _wyst, iite, ihde, сято
  { {0xe7190003,0xdcfe0002,0x31e101c7,0xf43a0009}},	//   نيات_, _napę, _पद्ध, _שגרמ
  { {0x98aa001e,0xa6db0028,0x442501c8,0x97580009}},	//   ējām_, faði, _sul_, רידו_
  { {0x93bc000d,0xa159003c,0x63ad01c9,0xa6db0097}},	//   _stăp, _шагу_, ljan, gaði
  { {0xe3b1000a,0xa7fd00a2,0x63ad0010,0x10890009}},	//   قرة_, ntıs, ojan, _בָּֽ
  { {0x98be007d,0xe3b10003,0x69da0052,0xdb1d0028}},	//   zată_, ترت_, eite, _umsó
  { {0xdcfc0010,0x69c30064,0x69da01ca,0x798101cb}},	//   verč, _plne, fite, telw
  { {0x27e9004a,0xb5fb000e,0x98be000d,0x224d01cc}},	//   _ajan_, ztár, xată_, rsek_
  { {0x3f820027,0x98be000d,0x63ad0028,0x66ca000e}},	//   teku_, vată_, kjan, _töké
  { {0xe0d60014,0xc6000037,0xfe670012,0x69c8008e}},	//   рвю_, ोग्य_, يد_, ahde
  { {0x98be007d,0xab5b0032,0xc6330012,0x9e630048}},	//   tată_, _plün, يفَة, овяд
  { {0x7bc90061,0x69c80052,0x63ad01cd,0x3f8201ce}},	//   lheu, chde, ejan, seku_
  { {0x98be007d,0xdd0e003a,0xfc270012,0xe5880009}},	//   rată_, _dışa, تح_, נָשָ
  { {0xc052000b,0x7bc90061,0x98be000d,0x63ad01cf}},	//   _וזה_, nheu, sată_, gjan
  { {0x57fb000b,0x7bc9004a,0x661e017b,0xd7fb01b0}},	// [200] _בלקו, iheu, _tipk, _בהקל
  { {0xb5fb000e,0xc8960001,0x2896004c,0x7d090030}},	//   stár, ирењ, ијес, řesa
  { {0xb5fb000e,0xcf8f0001,0xa3af0037,0x394701d0}},	//   ptár, ој_, _कवच_, _mens_
  { {0x69da01d1,0x9e660012,0xd7ef0012,0x63ad0034}},	//   zite, لاتن, وكل_, cjan
  { {0xe8e20037,0xa6db0028,0xeda60021,0xb8fd0011}},	//   _पश्च, taði, ишко, _ते_
  { {0x7c960012,0x394701a0,0xd5e30024,0x8e970009}},	//   لشعا, _nens_, ожчи, ידנו_
  { {0xa6db0028,0x29270029,0x26c001d2,0x2bda0011}},	//   raði, ávať_, šio_, _बगदा
  { {0xa6db0065,0xa037000b,0x6b8401d3,0x69da0034}},	//   saði, _כאלה_, neig, wite
  { {0xc1a60001,0xa3c70011,0xab5d0034,0xf1ba0011}},	//   ајни, _उतर_, niży, _इवान
  { {0xda160037,0x497301d4,0x9d530012,0x78ba008e}},	//   थगित_, ольс, _ونقت, tytv
  { {0xc953000b,0x58d8002d,0xa9c3002d,0xe9cf0003}},	//   חמת_, удня_, іськ, بغي_
  { {0x39470070,0x27e601d5,0x04db0009,0xa8570009}},	//   _eens_, nnon_, _בקבל, סיכה_
  { {0x5f940098,0xf773000b,0x22580015,0x2005001e}},	//   цият, חקר_, _силы_, ēli_
  { {0x6d48001c,0x7bc60006,0xb2bb000b,0x39470007}},	//   _jeda, _alku, _במדר, _gens_
  { {0x63ad01d6,0xf77f01d7,0xb9370009,0xd7f9004b}},	//   tjan, ança_, _דרוג_, luăm_
  { {0xe0fb000b,0x394c0058,0xa7fd003a,0x63ad0010}},	//   _שלהל, lads_, atır, ujan
  { {0xc2990015,0x24180015,0xadf60011,0x926b0048}},	// [210] ыках_, роты_, इवान_, ърва_
  { {0x6f09003e,0x6d4801d8,0x99d40012,0x780f0011}},	//   _rzec, _neda, يتلا, िष्क_
  { {0x6b840039,0x6d410097,0x04950012,0x6f0901d9}},	//   beig, ðlau, _الجح, _szec
  { {0x20140054,0x27e601da,0x7d08005e,0xfe710012}},	//   _èxit_, gnon_, üdse, كدت_
  { {0x23da0037,0x9e640024,0x6d4801db,0xc7d80009}},	//   _बग़द, жвід, _beda, סודי_
  { {0xce380093,0x63a201dc,0x7ad00011,0xdcfe0030}},	//   סאות_, _anon, _सेटअ, _napě
  { {0x97a70014,0xa6db0028,0xd64d002d,0xd7950014}},	//   _крал, maðu, _гiпе, _ливъ
  { {0xc245002d,0x1bb90012,0x394701dd,0xa6db0097}},	//   бник, طابع_, _sens_, laðu
  { {0x65870015,0xe1f901de,0x248c016d,0x7bc901df}},	//   _выез, лги_, _esdm_, rheu
  { {0x6b84008b,0xa6db0065,0x7db40003,0x6d4801e0}},	//   zeig, naðu, _وصلا, _geda
  { {0xa3e801e1,0x7dc20029,0xdce3001e,0xeae40011}},	//   _बदल_, _dôsl, ienī, _गश्त_
  { {0x7dc20029,0x5fc70037,0x907a0009,0x487a0009}},	//   _pôso, लसिल, נטרי, נטרס
  { {0xa7fd00a2,0xa6db0028,0xbc1a0009,0x394701e2}},	//   ttır, kaðu, _עונש, _tens_
  { {0x6e2100b6,0xab18002d,0x8e070024,0x6e2901e3}},	//   _jilb, _тієї_, йняв_, _mueb
  { {0x7d090066,0xa7fd003a,0x8c950024,0x18350012}},	//   řesn, rtır, орті, _ارتح
  { {0xf1bf001a,0xa7fd003a,0xbbe90012,0x00560009}},	//   _quán_, stır, لرقم_, _השקת_
  { {0xa7fd003a,0xda650012,0x69c10159,0xa6db0097}},	// [220] ptır, قالي, okle, faðu
  { {0x01d7000a,0x5d860003,0xd1960001,0x49960001}},	//   موقع_, _الدل, љшањ, љшат
  { {0x444401e4,0x6d4e0101,0x94760003,0x0219002d}},	//   _uw_, maba, _ادخا, ріть_
  { {0x6d4e01e5,0x68fc0052,0xb0990024,0x6d4801e6}},	//   laba, ürdi, штує_, _seda
  { {0x319f001e,0xc3330009,0xd6770012,0x6d4801e7}},	//   _bāzē_, _מור_, محوا_, _peda
  { {0x6d4e0101,0x3f580081,0xa91c0064,0x225f01e8}},	//   naba, ứu_, deľn, druk_
  { {0x2bbf0037,0xef1f003a,0xb5fb01e9,0x394c0035}},	//   _एकमा, ndür_, duál, vads_
  { {0xa3d20037,0x6f000002,0xa857000b,0x8c430001}},	//   हों_, _tymc, _לילה_, чеће
  { {0x4fbb000b,0x7dcb003a,0x4422000e,0x6d4e01ea}},	//   _עצמא, _hüse, _mik_, kaba
  { {0xce37000b,0xd9fa0037,0x6d4e01eb,0x018a01ec}},	//   _לאמת_, ्तित_, jaba, ущий_
  { {0x6d4e01eb,0x672d00eb,0x9f4201e9,0xa98b0009}},	//   daba, žaje, soký_, אָכִ
  { {0x2902001e,0x69dd0061,0x69de01ed,0x57190024}},	//   āka_, éser, hipe, ижня_
  { {0x2bbf0037,0x69de01ee,0x645a0097,0x95cb0048}},	//   _एकबा, kipe, átin, гува_
  { {0xbd450003,0x30a601ef,0xf1bf0164,0xea010081}},	//   تنسي, _грив, _cuál_, _đắp_
  { {0x2a600051,0x89db000b,0x69de01f0,0xb9db0009}},	//   erib_, _תחוי, dipe, _תחוש
  { {0x69c7001c,0x44220039,0xeb480024,0x6e460097}},	//   _slje, _cik_, йчук_, ðubú
  { {0x6d4e0101,0x539b000b,0xa6db0028,0xa9270012}},	// [230] baba, נימו, taðu, معاه
  { {0x24890002,0xe4e7002d,0x99d70012,0x35be0011}},	//   łami_, _гімн, حترا, ्सफ़
  { {0x44220058,0xa91c0029,0x1dac0011,0x20100034}},	//   _fik_, ieľo, चानत, łnił_
  { {0x6e290164,0x4422014f,0x6e2101f1,0x20180012}},	//   _pueb, _gik_, _silb, متنع_
  { {0x7bdf01f2,0x7d070031,0xda660012,0x6e2901f3}},	//   miqu, _újsz, _تُ_, _queb
  { {0xb5fb0042,0x7bdf01f4,0x69de01f5,0xa6db0097}},	//   xuál, liqu, cipe, laðs
  { {0xddcc007a,0x0dc80001,0x7c2201f6,0xf9920009}},	//   _žiūr, ључи_, _bior, _קרל_
  { {0xa91c0026,0x7bdf01f7,0x7bcd01f8,0x23c90011}},	//   teľn, niqu, nhau, रसिद
  { {0x3e72007d,0x66030029,0x49c9002d,0xd24e0012}},	//   cât_, plnk, илин_, نني_
  { {0x09f60003,0x7bdf0061,0x42060024,0x225f00b0}},	//   يفية_, hiqu, жньо_, rruk_
  { {0xd7ea0047,0x0fda0003,0xbddb0054,0x6d4e01f9}},	//   имое_, لبحث_, ipèd, vaba
  { {0x7c2201a2,0xdd0e00a2,0x61fa0051,0x6d4e00b6}},	//   _gior, lışm, aotl, waba
  { {0x6008000b,0x61fa003a,0x7bdf01fa,0xd8080009}},	//   מִשְ, botl, diqu, מִשָ
  { {0x2d8701fb,0x992b0015,0xdd0e003a,0x112b002d}},	//   nene_, _сюда_, nışm, _сюди_
  { {0x2d8701fc,0x628f01fd,0xdcfc004b,0x6c360012}},	//   iene_, _asco, deră, تفزا
  { {0xb5fb000f,0x7bdf01f2,0x6d410028,0x27ed013a}},	//   trác, giqu, ðlar, _njen_
  { {0x2d87011b,0xe9da013b,0x6d4e01fe,0xed5a0198}},	// [240] kene_, ака_, paba, _коп_
  { {0x93c7008a,0xdcf5003a,0xdcfc000d,0x2d870082}},	//   _hoặ, _çağr, geră, jene_
  { {0x442201ff,0x30860003,0x2d870200,0x628f0201}},	//   _tik_, تلاف, dene_, _esco
  { {0x394a0054,0x443a0002,0xb5fb0042,0xc2090009}},	//   _webs_, _itp_, prác, דה_
  { {0x2e470014,0x2d870202,0xfe6f0012,0xb21b0040}},	//   оящо_, fene_, ندو_, _psæt
  { {0x3e720203,0xfc4b0030,0x443a016d,0x2d870204}},	//   rât_, říž_, _ktp_, gene_
  { {0x60280066,0xdfd20012,0xa7860012,0xab5b0032}},	//   _těmi, _قيس_, _وشرو, _blüh
  { {0x4422006f,0x7bc40010,0xd3770015,0xa3ba0012}},	//   ök_, nkiu, очь_, شاعر_
  { {0xa91c0026,0xf413000b,0xa3cf0037,0x6d5a0003}},	//   teľo, ופה_, वोट_, _نجاح_
  { {0x2fc90205,0xc27b0009,0x61e80206,0xa6db0097}},	//   _slag_, סריי, undl, kaðr
  { {0x09b7000a,0x6f0d0002,0x28f8002d,0xeb070037}},	//   تطيع_, _szac, сень_, _शर्त_
  { {0x32050036,0x7bdf0061,0xea010081,0xab5b0032}},	//   ally_, xiqu, _đập_, _glüh
  { {0x69dc009b,0x2fc90070,0x501b0009,0x87070012}},	//   _omre, _vlag_, יוטו, تبدل
  { {0x99d30003,0xf5aa0009,0x3834004c,0x7e620035}},	//   _يتوا, ׁבָּ, _енкр, irop
  { {0x7bdf0207,0x4c94002d,0xa6db0208,0xc4940024}},	//   tiqu, мирс, taðs, мирщ
  { {0x79880002,0x5a350209,0x08570009,0x442c0132}},	//   ledw, знат, _ובהם_, _mud_
  { {0x7bdf020a,0x6d41003a,0xa6db0028,0x2d930203}},	// [250] riqu, ılab, raðs, _taxe_
  { {0x442c0070,0x7bcd020b,0x7bdf020c,0x7bc4020d}},	//   _oud_, shau, siqu, akiu
  { {0x96180003,0xf8ca0037,0x7bdf0007,0xf7710012}},	//   _بغير_, ानिय, piqu, ّات_
  { {0xf8b3000b,0xb4fa0009,0xacfa0009,0x6d5a0031}},	//   ושע_, _לפתי, _להתכ, _adta
  { {0xd6db0046,0x2d870119,0xdd0e003a,0xf7700003}},	//   јте_, tene_, tışm, ضان_
  { {0x3aba000b,0xb2ba000b,0xa2ba000b,0x2aba0009}},	//   _המשנ, _המשר, _המשט, _המשא
  { {0x3ea9000d,0x9f51000e,0xc1720009,0x7d7c0009}},	//   ţat_, óból_, _רחל_, ינגו
  { {0x7e62009b,0x5ba9020e,0x398a0034,0xc245020f}},	//   brop, ским_, rósł_, пник
  { {0x2362000f,0xe9d90210,0xdce70060,0xe6880012}},	//   ókja_, йки_, ğlıl, _ونفى_
  { {0xdb060029,0x6ca70211,0x6455000e,0xa7fd003a}},	//   _pokú, _мреж, kszi, yrıc
  { {0x7bc40010,0xdcfa001e,0xfaf9001e,0x38150009}},	//   ykiu, _datē, egūt_, ּקָם_
  { {0xe29f0065,0x547a000b,0x27fd002a,0x69ca0212}},	//   _orð_, _לטעו, nown_, _elfe
  { {0xb902015f,0x6298001e,0xadf80037,0x7bcb0213}},	//   _ने_, āvok, ंकलन_, _ilgu
  { {0xceb20214,0x7995003e,0x69c500bd,0x7c3a006f}},	//   עים_, _nazw, jkhe, _yttr
  { {0x2cc90009,0x61e10215,0x64a30216,0xa50a0217}},	//   זֶּ֑, mill, нара, сева_
  { {0x61e10218,0xe8d6000b,0x60d6000b,0x3ce50031}},	//   lill, _מוצר_, _מוצא_, úlva_
  { {0x2737001a,0x61e1004a,0x5e570003,0x6f790009}},	// [260] _ủng_, oill, _فليس_, _וְתו
  { {0x6d41003a,0xa96a0003,0x61e10219,0x7e62021a}},	//   ılac, إمام_, nill, vrop
  { {0x55bb000b,0x6e3b002c,0x5dbb000b,0x79950032}},	//   _המיו, _atub, _הזיה, _dazw
  { {0x63a6021b,0x79880034,0x2d98021c,0x6d430032}},	//   _unkn, zedw, ldre_, ebna
  { {0xdfcf000a,0x96b70001,0x539b000b,0xd5ba0015}},	//   دين_, зују_, _היכו, йск_
  { {0x61e1021d,0x4639002d,0xb5fb00d9,0x8e570009}},	//   jill, іччя_, hrán, לינג_
  { {0xb5fb0065,0x4c940014,0xa91c0029,0xa0240052}},	//   krán, фийс, teľm, größ
  { {0x9f590061,0x79950002,0x33730048,0x7dcb0060}},	//   posé_, _zazw, егър, _müsa
  { {0x6033000d,0xdcfa001e,0xe3af0012,0x6d430031}},	//   _răma, _patē, ارى_, bbna
  { {0xe1d8002d,0x442c000e,0xdcf5001e,0xa63b000b}},	//   ідні_, _tud_, udzī, _לגמר
  { {0x6d3b000b,0xdcf5001e,0x442c00b6,0x7c3a021e}},	//   _התבנ, rdzī, _uud_, _uttr
  { {0xdc8b0009,0xec130012,0x3ea0021f,0x61fe0220}},	//   _לְדָ, _كولد, _brit_, hopl
  { {0x539b0009,0x2ba90011,0x61e10221,0xe3bf01e3}},	//   _ליאו, कारा, bill, _niña_
  { {0xba180003,0x64550222,0xba170012,0x99760223}},	//   _بيتا_, tszi, _فينا_, _худш
  { {0x717b000b,0xe97b000b,0x317b000b,0xa97b000b}},	//   _הנוס, _הנוש, _הרומ, _האוכ
  { {0xcf270003,0x61fe002a,0xd6d10012,0x3ea00224}},	//   _عربي, eopl, _لقب_, _frit_
  { {0x61eb000f,0xb7dc000b,0x6455000e,0x91b90014}},	// [270] _állí, _לקהי, sszi, огат_
  { {0x2d8a0017,0x9aa40012,0x64550031,0x454b0048}},	//   cebe_, عملو, pszi, _учим_
  { {0x721b000b,0x7c260225,0x27fd0226,0x7d7a0009}},	//   מומח, _fikr, town_, _ונתו
  { {0xe29f0065,0x629b0010,0xa0370009,0xe7580024}},	//   _eyða_, yvuo, פאדה_, зиці_
  { {0x6ff5003e,0x0f58000b,0x27fd002a,0x98be0066}},	//   jące, ליאם_, rown_, tatě_
  { {0xd126000a,0xdb070025,0x6ff50034,0x6b890227}},	//   _لم_, _éléc, dące, weeg
  { {0x4426001c,0x6b890051,0x61e10228,0x8d5c0009}},	//   _bio_, teeg, vill, זכוי
  { {0xc4780009,0x5f940229,0x2fc6001b,0xfaf10012}},	//   פתחו_, _пист, ckog_, َثة_
  { {0xc3340093,0x60180015,0x8d87022a,0x61e1022b}},	//   עוץ_, _хотя_, _нужд, till
  { {0x26c2007a,0x61e1022c,0x20c50024,0x629b0073}},	//   vyko_, uill, дйом, rvuo
  { {0x7dd00006,0xb5fb022d,0x63b9002a,0x31360009}},	//   _jäse, trán, _town, ונתם_
  { {0xdee6022e,0x3ea00061,0xb4fa007e,0x61e1022f}},	//   доми, _prit_, _ולער, sill
  { {0x7dd0006f,0xcf56000b,0xd7f9000d,0xb5fb0164}},	//   _läse, וברת_, crăm_, rrán
  { {0x7c260230,0xb21b0231,0xa3d90011,0x442600b8}},	//   _sikr, _spæn, डोर_, _zio_
  { {0x3e760058,0xc1050012,0x113a0009,0xc1040012}},	//   sæt_, _توثي, _ותצל, _كوهي
  { {0x6ff60003,0xf8b20009,0xf7720012,0xf7f60012}},	//   _تستط, _ישו_, _شاب_, _تستد
  { {0x3b070098,0x42260232,0x27f70012,0x764b0040}},	// [280] дето_, ддав, _تفيد_, _ægyp
  { {0xc9860003,0x2fcd000d,0x60280066,0xdb240031}},	//   بشري, _aleg_, _těmt, éséi
  { {0x8cb50044,0x7c26007a,0xf2c9000b,0x19b900fa}},	//   _उपयो, _tikr, סע_, чуть_
  { {0x61fe00c5,0x672d0027,0x4f0a022a,0xb5fb0066}},	//   sopl, žajn, онен_, hrál
  { {0x44260233,0xa91c0064,0xdcf80030,0x501b00af}},	//   _rio_, teľk, bevě, קונו
  { {0x7d780003,0x2fc60027,0xddc20066,0xdd900012}},	//   سمبر_, skog_, stož, اوث_
  { {0xd497003c,0xe5a3004c,0x6da3004c,0x52b80011}},	//   дры_, тији, тија, ेन्स
  { {0xcfaa0003,0x5e460012,0x29180034,0xeb97004c}},	//   _باسم_, _يَأْ, ągać_, дић_
  { {0x8cb50037,0xd1660014,0x44260164,0xdb0d0097}},	//   _उपभो, мъни, _vio_, nkað
  { {0xe29f0065,0x27e00175,0x7c3e0027,0xb5fb0234}},	//   æða_, _amin_, _otpr, stáz
  { {0xf993000b,0x44260235,0x48aa0024,0xf1bf0081}},	//   דרת_, _tio_, ітом_, _quái_
  { {0xdb0d0065,0x443e0236,0x5ba5002d,0x72c60237}},	//   kkað, _itt_, _пріз, _обез
  { {0xc7b3000b,0xff040048,0xa7fd0060,0x753d0031}},	//   דבר_, вярн, brın, _őszi
  { {0x27e000a2,0x7ae90238,0x3f8b017b,0x41770012}},	//   _emin_, _žeto, secu_, _يمنح_
  { {0xe4e4002d,0x6286001e,0xc1780010,0xc173000b}},	//   вітн, _apko, snės_, _יחס_
  { {0x5f950014,0xd0110012,0xe7870024,0xddc90030}},	//   _чиит, _حلب_, _цуко, _dveř
  { {0x6feb003e,0xda150001,0xbbbf0011,0x52150239}},	// [290] jęci, едањ, _एकीक, едат
  { {0x6277000b,0x91e40001,0x443e023a,0xdddb023b}},	//   וגמא_, вође, _ott_, _opuš
  { {0x35f8000a,0x6d55022d,0xab5b0052,0x29070097}},	//   _تريد_, maza, _blüt, æna_
  { {0x251a0093,0x6d55023c,0xad1a000b,0x2ef50001}},	//   _מותא, laza, _מותר, нзер
  { {0x443e023d,0xbb3a000b,0xde58002d,0x433a000b}},	//   _att_, _מערי, дачі_, _מערב
  { {0x3e320003,0xdcee0010,0x6b82023e,0x6d55023f}},	//   دفور, gebė, _abog, naza
  { {0x26c90027,0x63bd0240,0xd1380002,0x67d5003c}},	//   šao_, _kosn, dcą_, _зову
  { {0xa3d90037,0xd9b90011,0x6ab50048,0x03790012}},	//   डों_, ेस्ट, есох, سحبت_
  { {0x443e0241,0xb5fb0242,0x60160042,0x6d550243}},	//   _ett_, trál, náme, kaza
  { {0xf1b10003,0x9c870003,0x66e4004c,0x2a620031}},	//   اءة_, _يشاه, _рођа, ákba_
  { {0x67240013,0xe3bf0164,0xf1b20009,0x9f420030}},	//   žijt, _niño_, אסי_, liké_
  { {0x649a000b,0x78bc006f,0x0b780012,0x4c9a0009}},	//   _מסעד, ärva, _يصنع_, _מבעו
  { {0xa7fd00a2,0xe1ee0014,0x6d41003a,0x3f9e0066}},	//   ntıy, _бг_, ılan, ětu_
  { {0x7bcf01a2,0x99840012,0x7bc90244,0x69c80245}},	//   _alcu, _للهو, lkeu, ckde
  { {0xb0420020,0xc5f2000b,0x6feb0034,0x63bd0246}},	//   _trưở, אדם_, zęci, _bosn
  { {0x42d6002d,0x97c60012,0x7bc9008e,0x8b26004c}},	//   нізу, _ستعم, nkeu, едбе
  { {0x7bc90006,0x443e001e,0xada60247,0x21a6003c}},	// [2a0] ikeu, ūt_, _запл, ниам
  { {0xdb0d0065,0x2002004a,0x42070001,0x0b170012}},	//   rkað, loki_, енуо_, رقلة_
  { {0x7bc9004a,0x7dcb003a,0x7c3e00ad,0x71730012}},	//   kkeu, _müsl, _utpr, اهما
  { {0x2ca50058,0x6e280248,0x60160249,0xdc3b00af}},	//   ælde_, _sidb, lámb, _מעטר
  { {0x9757000b,0x7bc90070,0xdcee0010,0x6289001e}},	//   תינו_, dkeu, tebė, _ģeog
  { {0xab5b0052,0x245a001e,0xa2d90011,0x61e50060}},	//   _flüs, tīm_, _नेट्, cihl
  { {0xc9770009,0x25f10011,0x7d090030,0x6458008e}},	//   _רגלי_, ँचती_, řesv, usvi
  { {0xd1380002,0xe8df0081,0x2d9a0073,0x6b9b020d}},	//   wcą_, _chửi_, _lape_, gdug
  { {0x60e0007a,0x9f42008e,0x249c0073,0x7b140048}},	//   žymė, inkä_, _žymė_, ъдих
  { {0x91e30001,0xaa770009,0x9aeb0009,0xddcc0060}},	//   лоње, עתיד_, לַיִ, _ğişt
  { {0xc057002d,0x443e001e,0xc32a0003,0x6d55024a}},	//   нія_, _utt_, _فكان_, vaza
  { {0x2d9c000e,0xd65e0024,0x4bda0012,0xc7e60009}},	//   ldve_, _вiдд, _عباد_, תוֹ֙_
  { {0x0e340015,0x63bd024b,0xdb060064,0xb7db0009}},	//   лняю, _rosn, _poký, לקטי
  { {0xbbc90037,0x7d03024c,0x5b13002d,0xdb06003a}},	//   रस्क, _ønsk, _сміт, _dokü
  { {0x5ff50014,0x3137000b,0x63bd009b,0xc953000b}},	//   _изку, _ארוך_, _posn, _עמק_
  { {0xfc30000a,0x6d5a0028,0x40eb0009,0x4394003c}},	//   صحف_, ótar, _מַחֲ, ласс
  { {0xe1670001,0x8c1b000b,0x0e150001,0x4975024d}},	// [2b0] еђен, לולי, _имиџ, клас
  { {0x8cb10044,0x60160164,0x932400ae,0x000000c4}},	//   _अपलो, ráme, ارِن,
  { {0x4ddc000b,0x6fc60018,0xa7fd0060,0x2d8e0060}},	//   _מחזו, _sóci, yrıl, defe_
  { {0xe8170037,0x60c5004a,0xbcb6000b,0xfecb0009}},	//   _धीमा_, ryhm, _ספרו_, ּמַּ
  { {0xee38007c,0xa3b40044,0x6016000e,0xd3560009}},	//   ені_, ञान_, lámc, _שישי_
  { {0x31350001,0x7bc90070,0x8d620015,0x85780014}},	//   _јевр, wkeu, авше, есът_
  { {0xcd98000b,0x645a024e,0x02c90011,0x27e6024f}},	//   גדות_, štiv, िन्न, bion_
  { {0xddc20010,0x47340003,0x64430250,0xdc8c0009}},	//   ruoš, _مركز, rpni, לְחָ
  { {0x442b000d,0x7bc90251,0x7dd0006f,0x62720012}},	//   _mic_, rkeu, _läsa, لهيئ
  { {0x3f8f0028,0x3cfa0011,0x10a5004c,0xdd940012}},	//   legu_, _ऊँचे_, вион, _مجمع
  { {0x9991000f,0xa3c30037,0xc212000b,0x55ba0009}},	//   öző_, ्सा_, שהי_, _קמעו
  { {0xf7720003,0x442b0252,0x34b6000b,0xe4580024}},	//   جاد_, _nic_, _בפעם_, _їжі_
  { {0x44330108,0x2f5a000b,0x2d9a0253,0x6603005e}},	//   _aux_, ודרנ, _pape_, oonk
  { {0x7d0400a2,0x67eb004a,0xd6560009,0x80e50012}},	//   şise, töjä, כישת_, _لأعل
  { {0xdce1003a,0x8ca40037,0xd6270254,0x80c00011}},	//   _kalı, कियो, торе_, _एथें
  { {0x27e60255,0x2d9c0031,0x66030256,0xe3630257}},	//   xion_, zdve_, honk, икси
  { {0x2ebd0037,0x44330061,0x27e60258,0xa206004d}},	// [2c0] ्नोत, _eux_, vion_, впад
  { {0xdcfc001e,0x0657000b,0x602c003a,0x24920002}},	//   ndrī, _שייך_, _aşma, łymi_
  { {0xe0d20003,0xdcfc001e,0xd12f0003,0xdb060034}},	//   جزء_, idrī, زمن_, _pokó
  { {0x2d850036,0xddce0002,0xbe8a0001,0xf8b20009}},	//   _able_, żdża, дске_, ישב_
  { {0xa3ab0044,0x64410259,0x4420025a,0x7d090030}},	//   खाई_, _atli, mmi_, řest
  { {0x3f8f0051,0xf1bf001a,0xdb060002,0x4420025b}},	//   aegu_, _quát_, _wokó, lmi_
  { {0x3183000e,0xdce1003a,0x319b0009,0x61eb0025}},	//   észő_, _balı, _קבלנ, ègle
  { {0xb4fb000b,0xb8f60037,0xdcfc001e,0xd9ca0037}},	//   ופצי, िन_, edrī, िस्ट
  { {0x313400b3,0xdf370012,0xdce10060,0x64410032}},	//   лепр, _شكلت_, _dalı, _etli
  { {0x79a6025c,0x2e260012,0x29d40012,0x4420025d}},	//   трие, _شفاف, ايدس, hmi_
  { {0xc157000b,0xc60e0037,0xb5fb000e,0xbb860012}},	//   כשיו_, ितीय_, lság, _للاي
  { {0x6d41003a,0x4420025e,0x9f4b01e3,0xa91c0064}},	//   ılam, jmi_, vocó_, deľt
  { {0xb5fb000f,0x29020002,0xb9960012,0xe6670048}},	//   nság, łka_, _للشب, ътно
  { {0x4420025f,0x7dcf0260,0x6d580261,0x3f8f0034}},	//   emi_, _løsn, nava, zegu_
  { {0x2ca50028,0x645c006f,0x61e80262,0xe7f30011}},	//   íld_, gsri, midl, _अदला_
  { {0xef670098,0xa3ab0037,0xc334000b,0xa7750001}},	//   _ръко, खाए_, רוּ_, _слич
  { {0x799c0263,0xd2340048,0x5b150264,0x6d580265}},	// [2d0] _barw, интъ, умат, kava
  { {0xc27b000b,0xb5fb0074,0x51f80015,0x44200266}},	//   ורמי, dság, вную_, ami_
  { {0x3c38000f,0xc1040012,0x3f8f005e,0x44200064}},	//   _név_, لوكي, tegu_, bmi_
  { {0xe4a4002d,0x1b4b0003,0x2d91000d,0xb5fb0018}},	//   _трьо, _تؤدي_, leze_, cuár
  { {0x645a0267,0x35a80037,0xb5fb000e,0x8e850268}},	//   štit, _छोड़, gság, الته
  { {0x3e7b0061,0x2d91000d,0xed580029,0xa3c30011}},	//   rêt_, neze_, _poľa_, ्सव_
  { {0x60160028,0xdb0b0061,0xc172000b,0xb4bf0011}},	//   háma, _ingé, _לחם_, ुने_
  { {0xe2b90001,0x6603000e,0x6d580269,0xbcd80012}},	//   ећој_, sonk, aava, خذها_
  { {0xd1790024,0x6603026a,0x2fc0026b,0x8d770012}},	//   нсні_, ponk, _roig_, _لاضا
  { {0xe5730003,0x987e003a,0x46150012,0x3c380025}},	//   _خطر_, _açıp_, _صوار, _fév_
  { {0x7bcd004a,0x4420026c,0x35c60011,0x43750012}},	//   kkau, ymi_, रॉफ़, _مهار
  { {0xbb1b0025,0xeb9f0040,0x61e8005e,0x366a026d}},	//   _abîm, _skøn_, aidl, намо_
  { {0x200f003a,0xd5a70024,0xd6cf0024,0xee370048}},	//   ilgi_, _пiдп, йтi_, лня_
  { {0x6da6004c,0x63bb026e,0x61e8026f,0x7bcd0270}},	//   ћива, ljun, cidl, ekau
  { {0x2a7f0051,0xdca1002d,0xb5fb0271,0x69fa0009}},	//   ltub_, остi_, zság, _אלסק
  { {0x6d580272,0x44200273,0x8cb50037,0xdb0f0018}},	//   zava, umi_, _उपरो, _incê
  { {0xc3320093,0xa3b40037,0xdcfa001e,0x7fd70009}},	// [2e0] מון_, ञात_, _patī, _תופס_
  { {0xfd4a002d,0xb5fb0017,0xddd40029,0x7644002c}},	//   _язок_, suár, _ťažk, _itiy
  { {0xe4e30037,0xd12f0003,0x2a7f0051,0x63bb0028}},	//   _केलि_, أمم_, htub_, kjun
  { {0x44440274,0xb5fb000e,0xb4c20037,0x6033004b}},	//   _it_, tság, ्नी_, _cămi
  { {0xa3c30037,0x6d580275,0xf5360009,0xb7d70012}},	//   ्सर_, tava, ְנֵי_, دونا_
  { {0x2703001a,0xb5fb0031,0xd49a0276,0x44440277}},	//   ổng_, rság, ери_, _kt_
  { {0xb5fb000f,0x61e80107,0x39570009,0xbc670012}},	//   sság, vidl, _תשלם_, همون_
  { {0x7dc60065,0xf77f0017,0x2d910278,0x6f090034}},	//   _aðst, viço_, zeze_, żeci
  { {0xd130000a,0x0aea0003,0x9fb801bd,0xfd760012}},	//   يمة_, عربي_, nčí_, _مداخ
  { {0x2d91000d,0xfe370009,0x82330012,0xf62a0012}},	//   xeze_, _ערבי_, حريا, _أسرى_
  { {0x28f800fa,0x44440279,0x33860048,0x2d9e0018}},	//   тень_, _nt_, _булв, _iate_
  { {0xb4fb000b,0x3cfb0009,0xcb0a0012,0x2d9e0132}},	//   _אלבר, _אלבנ, _كيان_, _hate_
  { {0xa91c0026,0x4444027a,0x61e8027b,0x2d91027c}},	//   teľs, _at_, pidl, teze_
  { {0x7dcb0005,0xb5fb0042,0x5a9b0009,0xaa9b0009}},	//   _küsi, hráv, _נשוא, _נבוכ
  { {0xa157000b,0xa4d4002d,0xd13f0002,0x1957000b}},	//   _גבוה_, борі, łącz_, _גבול_
  { {0x2d9e0087,0x2d91027d,0x9ee90012,0x7bcd008e}},	//   _late_, seze_, _لفعل_, ukau
  { {0x7bcd027e,0xfc3f01e9,0x1155027f,0xb9550048}},	// [2f0] rkau, _čím_, икаю, иващ
  { {0x11540024,0x44440280,0x54550281,0x7bcd0282}},	//   йкую, _ft_, _квот, skau
  { {0xa0a7003c,0xdcf80035,0x44440283,0x893700af}},	//   ышал, ievē, _gt_, ארבע_
  { {0xb4d10037,0xd6d10003,0xf7730003,0x900b0012}},	//   वनी_, يقا_, صاص_, رزاق_
  { {0x2d9e0284,0x8db50024,0x7fb60012,0x44440031}},	//   _bate_, искі, شهور_, _zt_
  { {0xd658007e,0x4ade0044,0xb5fd0066,0x60180066}},	//   ניות_, _नेटव, _ovše, tímc
  { {0xdcf80039,0xeb9900be,0xabd50001,0xdb06000e}},	//   devē, вий_, ициј, _inká
  { {0xea01001a,0xd2650148,0x68e30097,0xdb4e0012}},	//   _đẹp_, акий, úndu, وَى_
  { {0x2d9e0285,0x59a60011,0xd7f8004c,0x63bb0286}},	//   _fate_, _कोहर, _сур_, rjun
  { {0x2d9e0287,0x6ff20035,0x7dcb005e,0xe8850288}},	//   _gate_, māci, _füsi, агоп
  { {0x7c950003,0x6ce4002d,0xf992000b,0x2a7f0051}},	//   _خلاص, _ліце, חרי_, stub_
  { {0x44440289,0x2249002c,0xe29f0097,0x645a0025}},	//   _rt_, kpak_, _eyði_, âtim
  { {0xa3b90044,0x6ff2001e,0x4444028a,0xe9ce028b}},	//   चान_, nāci, _st_, _дк_
  { {0x9fb80066,0x4444028c,0x69c30060,0x98a500b5}},	//   včí_, _pt_, önel, _вике
  { {0xb4c20044,0x2d9e0026,0xa3cc0037,0x442f0058}},	//   ्ने_, ľte_, _रकम_, _kig_
  { {0x6ff20039,0x44440051,0x2d9e00f1,0xd3720012}},	//   kāci, _vt_, žte_, تهر_
  { {0x6016000e,0x60180042,0xe61a00db,0x3e7f004b}},	// [300] lámo, jíma, _иди_, cît_
  { {0x673b0029,0xbbd20037,0xe9d7028d,0x5bd20011}},	//   ľuje, _तत्क, аку_, _तत्व
  { {0x4444028e,0x6d4e000e,0x2d9e028f,0x290e0097}},	//   _ut_, mbba, _rate_, æfa_
  { {0xddc20039,0x6d410290,0xc334000b,0x03a60188}},	//   droš, _afla, _לוֹ_, _тимо
  { {0xeb970014,0x6ff2001e,0x7dcb005e,0xd707004c}},	//   _тия_, gāci, _süsi, анце_
  { {0x7dcb0051,0xdb0b0123,0x04660291,0x6d5c0292}},	//   _püsi, _logó, атим, nara
  { {0x601d0061,0xb5fb014a,0x442f0293,0x8f760024}},	//   léme, práv, _big_, _вузі
  { {0x0b8a011f,0x938a0294,0x309b0009,0x6d5c0295}},	//   тски_, тска_, _בשלמ, hara
  { {0x442f0296,0x601d0061,0x6d5c0297,0x600b0009}},	//   _dig_, néme, kara, _יִמְ
  { {0x4e7b0093,0x6d5c00c6,0x867b0009,0xb5fb0031}},	//   _באמצ, jara, _ברמו, zsáb
  { {0x31370093,0xdfd1000a,0x54730003,0x2918006f}},	//   ינים_, كيد_, _وهكذ, åra_
  { {0x961f0037,0x6d4e006f,0xe6950015,0x3ea90298}},	//   पष्ट_, ebba, бимы, _prat_
  { {0x6d5c0163,0x8674002d,0xaaba0012,0x75d50012}},	//   fara, оляє, _جدار_, ميحا
  { {0x3f55001a,0x6d5c0299,0xf2db0009,0xb6070024}},	//   ấu_, gara, _שַׁל, рямк
  { {0x6ff20039,0x61ef0061,0x19bb0009,0x621b0009}},	//   zāci, ècle, _במגב, _שווק
  { {0x3ea90052,0x83350048,0x60290034,0xb5fb0031}},	//   _trat_, снах, _ośmi, usáb
  { {0xba550003,0x69da004a,0xd7fc000b,0x27e9029a}},	// [310] صناع, ohte, _שהחל, _iman_
  { {0xe29f0065,0xc1780010,0xf5950012,0x6d99003c}},	//   æði_, ngė_, _الدج, _своё_
  { {0xd138029b,0xf7730012,0x69da029c,0xda080012}},	//   рху_, قاش_, ihte, جيله_
  { {0x60180028,0x6ff2001e,0xb5fb029d,0xd0f70009}},	//   tíma, tāci, arát, סמאת_
  { {0x6d410052,0x6016000e,0xb6a5002d,0x27f2000e}},	//   _pfla, zámo, силл, ézni_
  { {0x6ff20039,0x8e08002d,0xddc2013a,0xe5780024}},	//   rāci, анів_, troš, изі_
  { {0xe3b10003,0x27e9004a,0x6ff20035,0x98be0073}},	//   كرة_, _oman_, sāci, matė_
  { {0x351c000b,0x1bf90037,0x69da0051,0x7c940012}},	//   כוונ, ्किल_, ehte, تشها
  { {0x36d4002d,0x93b8000b,0xfbb8000b,0xeb920009}},	//   _дотр, שלחו_, שפחת_, פָה_
  { {0x69da029e,0xdef80015,0x27e9029a,0x7c24029f}},	//   ghte, _тыс_, _aman_, zmir
  { {0x07a6002d,0x69c30052,0x1bf90011,0x39410032}},	//   банн, _vone, ्काल_, ichs_
  { {0xcdc90093,0x6d5c02a0,0x69da02a1,0x69c302a2}},	//   _אך_, wara, ahte, _wone
  { {0xdb24003a,0x32450012,0x539a0009,0x69c302a3}},	//   üsün, _انتف, _תינו, _tone
  { {0x32b8000a,0x69da02a4,0x7dd0004a,0xe6170015}},	//   _خدمة_, chte, _täsm, йдя_
  { {0x04460001,0x64a60014,0x91ba0009,0x4e160009}},	//   себн, щава, _תמצי, מחשב_
  { {0xa3ca0037,0x6bb5002d,0x9f820028,0x7dd00269}},	//   रॉप_, осує, _góð_, _käsk
  { {0x09360003,0xb7db000b,0x01360003,0x395802a5}},	// [320] مراج, _תקפי, معاد, _pers_
  { {0x6016000f,0x8d560001,0x601d0061,0x24890034}},	//   záml, _утич, réme, łamy_
  { {0x88860047,0xfbd20003,0x601d0061,0x395802a6}},	//   слеж, _فتح_, séme, _vers_
  { {0x25a10052,0xca290009,0x9e660012,0x87260024}},	//   _zahl_, גם_, ماتن, бмеж
  { {0x69da004a,0xe5c60063,0x82360012,0xdfa50012}},	//   yhte, йско, _درجا, تحلي
  { {0xa3ca0037,0x63a402a7,0x3ea6008e,0x443a02a8}},	//   रॉन_, ldin, rvot_, _kup_
  { {0xf41f004a,0xe9d700fa,0x628402a9,0x515b0009}},	//   _yhä_, _укр_, ltio, _תכלו
  { {0x00f7000b,0xb33b0060,0x443a02aa,0xd00a02ab}},	//   _המלך_, _kaça, _mup_, _себе_
  { {0x7ae90065,0x7dcb0052,0x60290002,0x32ba0012}},	//   _þett, _küst, _uśmi, ادعة_
  { {0xf77f00a2,0x984a0014,0xba9b000b,0xdcfc001e}},	//   miçi_, ляма_, נסיי, nerē
  { {0xa7b90001,0x6d5a001e,0xdb4f02ac,0xbda50012}},	//   алну_, _ieta, _ню_, _بحقو
  { {0x6016000e,0x0c2602ad,0xaba50012,0x63a402ae}},	//   lámj, _умен, _وإنه, jdin
  { {0xdb1d0013,0x6d5a0190,0x93a90012,0x7e6202af}},	//   _posí, _keta, _خالف_, nsop
  { {0x27070020,0xd6d8007c,0xc27b000b,0x6d5a0025}},	//   ống_, стю_, _תרגי, _jeta
  { {0x7a29007a,0xb1e50003,0xa4d4002d,0xdce8003a}},	//   _užti, _بأنه, порі, _kadı
  { {0x25a10052,0xd0f70009,0x7c150024,0x395e02b0}},	//   _wahl_, _למות_, ідає, lats_
  { {0x82f80003,0x39410061,0x7a570012,0x2418003c}},	// [330] مركز_, tchs_, إضرا, соты_
  { {0x7c3a02b1,0xb5fb02b2,0x6f1b0002,0x395e02b3}},	//   _outr, rrás, _rzuc, nats_
  { {0xb5fb0028,0x7c3a02b4,0x8d5a0009,0x50950012}},	//   srás, _nutr, _דכתי, تلاء
  { {0x61c50044,0xc885003a,0xdef10003,0x907b0009}},	//   _लक्ष, vaşı_, وًا_, רטאי
  { {0x7c3a02b5,0x9e64002d,0x628402b6,0xb5fd01bd}},	//   _autr, звід, ctio, _avša
  { {0x9628000a,0xdcfc001e,0x6d5a02b7,0x3135004d}},	//   مكنك_, cerē, _ceta, _февр
  { {0x9f5f000e,0xdb060248,0x7c3a02b8,0x59a60011}},	//   óról_, _enkä, _cutr, _कोइर
  { {0x04560003,0x77d70012,0x7dcb02b9,0xc24502ba}},	//   آلية_, _اغسط, _küss, оник
  { {0x7e62000f,0x69c7001c,0x85b900ac,0xe9d902bb}},	//   csop, _koje, _клас_, ики_
  { {0x7dcb008b,0x63a4007a,0x91e5002d,0x395e02bc}},	//   _müss, zdin, іоне, gats_
  { {0x7e640028,0xc172000b,0xcea90009,0x7649008e}},	//   _svip, וחי_, _שי_, _htey
  { {0x200b0054,0x907a000b,0xa3a90037,0x2465001e}},	//   goci_, סטרי, _गोल_, mēm_
  { {0xa294007c,0x2465001e,0x8f9a0009,0x68e1005e}},	//   _наці, lēm_, בירי, _üldf
  { {0x7dd002bd,0xca36000b,0xe29f0028,0x395e02be}},	//   _käsi, _ונסה_, æðu_, cats_
  { {0x7bc602bf,0x60160042,0x8c430294,0x7dcb0032}},	//   _poku, námk, десе, _rüst
  { {0x7dcb0005,0xa3e40011,0x628402c0,0x63a402c1}},	//   _süst, भों_, ttio, udin
  { {0x98a5003a,0x9a6a0003,0xda650003,0xe2460003}},	// [340] malı_, شمال_, كالي, تخزي
  { {0xfd120003,0x63a40010,0xba170012,0x7bc60034}},	//   _يجد_, sdin, قيقا_, _woku
  { {0xdbd1003a,0x291c0248,0x7649020d,0xa3ca0011}},	//   _güçl, åva_, _atey, रॉड_
  { {0x98a5003a,0x2465001e,0x6d5a02c2,0xddcd0002}},	//   nalı_, dēm_, _seta, _gwał
  { {0xd5ba0047,0x4e960003,0x63a20054,0xde960003}},	//   иск_, تشار, _raon, تجاب
  { {0xe452000a,0x3ead0054,0x7c3a00b6,0x3f580081}},	//   وضع_, _dret_, _putr, ẩu_
  { {0x98a500a2,0x26090037,0x395e0054,0xd64b0024}},	//   kalı_, ाक़ी_, vats_, _дiял
  { {0x98ba007a,0x9faf0066,0x2d9802c3,0x326602c4}},	//   lapį_, tří_, here_, отов
  { {0x6d5a00c6,0x98f50020,0x395e02c5,0x2d9802c6}},	//   _teta, uản, tats_, kere_
  { {0xddc20002,0x395e0054,0x601d0061,0x670e0037}},	//   społ, uats_, déma, _सड़क_
  { {0xeb9a0098,0x63a20101,0x395e02c7,0x24650035}},	//   _вие_, _taon, rats_, cēm_
  { {0x56950001,0x8c430060,0x395e02c8,0x69c102c9}},	//   памт, üşme, sats_, ajle
  { {0x370702ca,0x3949000d,0x395e02cb,0x57fb0009}},	//   ючов, _şase_, pats_, שלכו
  { {0xddcf000d,0x2d9802cc,0x68e1005e,0x6ff50034}},	//   ducţ, gere_, _üldg, rąci
  { {0xa177000b,0xfbd30003,0xa802003a,0xfd100012}},	//   _ועוד_, وتر_, şıya, نجف_
  { {0xedb70037,0xa0080012,0xa7740048,0xb5fb0031}},	//   _इच्छ, _وقول_, _жлъч, csán
  { {0x539b000b,0xe1f30003,0x2465001e,0x69c702cd}},	// [350] סימו, وسط_, zēm_, _poje
  { {0x44220005,0x91b80015,0x7a380024,0x2d9802ce}},	//   _ehk_, огут_, цпфр_, cere_
  { {0xdb1d0066,0xb8810066,0x69c70042,0x91a80012}},	//   _dosá, žíve, _voje, تهلك_
  { {0x69c70002,0x4c9a000b,0x3ead02cf,0x320c02d0}},	//   _woje, _פברו, _pret_, hody_
  { {0xb3ba000b,0x9bba000b,0x320c0034,0x501c0009}},	//   _המרכ, _הצרפ, kody_, בואו
  { {0x53a3015f,0x270a0020,0x7c2202d1,0x85e8002d}},	//   _खोजश, ờng_, _ahor, одів_
  { {0xc212000b,0x98a5003a,0x85580009,0xd5ae0012}},	//   _נהל_, yalı_, חשוב_, طفي_
  { {0x442900a2,0xe4fc000b,0x34fc000b,0x3ead0054}},	//   nma_, יפוש, יהוד, _tret_
  { {0xa263001a,0x2465001e,0x6d5a0028,0xf414000b}},	//   _giố, sēm_, ðtak, ופק_
  { {0x6aa902d2,0xe9d902d3,0x442902d4,0x320c0034}},	//   rvef, ско_, hma_, gody_
  { {0x98a5003a,0x224d00b6,0xc7a60024,0x601601e3}},	//   talı_, spek_, пинк, lámi
  { {0x224d000e,0xd8d6000b,0x25a502d5,0x53a40012}},	//   ppek_, פורט_, _hall_, _يملك
  { {0x98ab00a2,0x44290051,0xbb3a000b,0x98a5003a}},	//   ılık_, dma_, _העני, ralı_
  { {0x7bcb0028,0xd1bb0012,0x44d70081,0x7c2902d6}},	//   ögun, _خاصا_, õ_, lmer
  { {0xb5fb0066,0x98a5003a,0x81bc001e,0x25a502d7}},	//   psán, palı_, kmēj, _mall_
  { {0x6376003a,0x9e660001,0x2d9802d8,0x442902d9}},	//   münü, _евид, sere_, gma_
  { {0x6d4100a2,0xb77b0093,0x6376003a,0x877b0009}},	// [360] ılar, _האפש, lünü, _האפי
  { {0xa7fd00a2,0xb33b02da,0xddcf000d,0x7c290052}},	//   nsın, _faço, rucţ, hmer
  { {0x6d5e0039,0x7c290033,0x80a60003,0xb53b000b}},	//   _iepa, kmer, ثمان, _לגיש
  { {0xc2090009,0xa8560009,0x1cbb0009,0xf1ba0081}},	//   אה_, פינה_, _המטע, _nhơn_
  { {0x6d5e00c6,0xa7fd00a2,0xa3b90037,0x44d7001a}},	//   _kepa, ksın, चार_, ẽ_
  { {0x7c220036,0x6d5e00b6,0x1ea90003,0x7c2902db}},	//   _shor, _jepa, غاني_, emer
  { {0x25a501a2,0x7c2902dc,0x320c0042,0x395c02dd}},	//   _dall_, fmer, vody_, _revs_
  { {0x6c470003,0xdcf8001e,0x320c0002,0x6d5e02de}},	//   أليف_, levī, wody_, _lepa
  { {0x44d70020,0x63a602df,0x320c02e0,0x25a502e1}},	//   ã_, _makn, tody_, _fall_
  { {0x6720001c,0x2003001c,0xd8f8002d,0xdca602e2}},	//   _izmj, čkim_, жної_, _нази
  { {0xa3190037,0x6376003a,0x9f9902e3,0x7c2202e4}},	//   _दर्ज_, günü, овну_, _thor
  { {0xd0f7000b,0xc43b000b,0x63a6013a,0x4c3b0009}},	//   למית_, _התאי, _nakn, _התאב
  { {0xb80d0044,0x6d5e00bd,0xe80d0037,0x7c3e0061}},	//   िकतम_, _bepa, िकता_, _aupr
  { {0x6d5e00b6,0x7ae40029,0x224b0029,0xe29b000b}},	//   _cepa, dzit, ícke_, _לשדר
  { {0x7c3e000d,0x3f990051,0xdcf8001e,0x6d5e02e5}},	//   _cupr, pesu_, devī, _depa
  { {0xec34002d,0x69dc02e6,0xd0110012,0x8afd0030}},	//   енсь, _alre, _جلب_, saře
  { {0x25ed0037,0x5a350232,0xa2940024,0x9f4b0030}},	// [370] _अगली_, днат, наті, nicí_
  { {0x7c2902e7,0x443e02e8,0x799a00c7,0x05790012}},	//   zmer, _out_, netw, _بمدة_
  { {0x4429003a,0xb4670003,0x66280066,0x7c670012}},	//   pma_, _عدده, řské, _عادل
  { {0xc104000a,0xa7fd003a,0x69dc000e,0x98170012}},	//   روني, zsın, _elre, أبطا
  { {0xf7700003,0x81bc001e,0x999f000e,0x63760060}},	//   طان_, rmēj, őről_, zünü
  { {0xf650000a,0x443e02e9,0x6d470002,0x601602ea}},	//   ائن_, _but_, ncja, rámi
  { {0x63a600c6,0x98170003,0xdca20014,0x64a20014}},	//   _yakn, _فبرا, ващи, ваща
  { {0x49060037,0x7dd002eb,0x25a502ec,0x8d180012}},	//   _सँजो_, _häst, _wall_, أزهر_
  { {0x443e0061,0x25a502ed,0x6d470002,0xb33b0060}},	//   _eut_, _tall_, kcja, _raçl
  { {0x39e9007c,0x443e02ee,0x6376003a,0xc5fb0003}},	//   ідно_, _fut_, tünü, _اعرض_
  { {0x443e02ef,0xa7fd003a,0x7c2902f0,0x7bdd003a}},	//   _gut_, rsın, pmer, _olsu
  { {0x637600a2,0x7bcb0065,0x7dd002f1,0x7e690073}},	//   rünü, ögul, _läst, _kvep
  { {0x63a60028,0xceb2000b,0x2e240032,0x63760060}},	//   _rakn, ֣ים_, höfe_, sünü
  { {0x7dd00163,0x63a6006f,0xf2d20009,0x69b70011}},	//   _näst, _sakn, _בעד_, _ऍचटी
  { {0x7bcb0005,0x31780034,0x764d0060,0x63a902f2}},	//   _kogu, órze_, _etay, oden
  { {0x305a0009,0x42d60024,0x237a0012,0xab7a0012}},	//   _ודקד, мізу, تمرد_, تمرا_
  { {0x7bcb02f3,0x7dd0006f,0x6d5e00b6,0xde1a0003}},	// [380] _mogu, _bäst, _tepa, _وقعت_
  { {0x6b9b0070,0x63a9004a,0x70f60003,0x00da0012}},	//   heug, hden, وسائ, يبات_
  { {0xd7ef0001,0x55bb0009,0x9f4b0030,0xb8650012}},	//   ву_, _ומיו, zicí_, فانو
  { {0x799a0002,0xef1a02f4,0xf9890009,0x63a902f5}},	//   zetw, оме_, יר_, jden
  { {0x27f9000e,0x7dd0006f,0x539b000b,0x96b7004c}},	//   érni_, _fäst, _ויכו, дују_
  { {0x443e02f6,0x69c302f7,0x63a90204,0x7dd002f8}},	//   _put_, önet, eden, _gäst
  { {0xa4d8002d,0x6feb0002,0x2075003c,0x78450073}},	//   ядку_, ręcz, _путё, _tėva
  { {0x7a290010,0x69ca02f9,0x60080060,0xd4990024}},	//   _užtr, _sofe, nımd, ярі_
  { {0xa80200a2,0x5a340014,0x443e0032,0x65630018}},	//   ğıda, ннит, _wut_, banh
  { {0x7abb000b,0x05760012,0x63a902fa,0xdb1b0097}},	//   קציו, _زائد, aden, rkuð
  { {0x7dd00052,0xc057002d,0x764d002a,0x443e02fb}},	//   _läss, мія_, _stay, _uut_
  { {0x601d0025,0x2fc60031,0x2d9c02fc,0xb5fb0031}},	//   rémo, njog_, leve_, csáj
  { {0x03d7000b,0xc6e70024,0xcf570009,0x60080060}},	//   _קודם_, фінп, ובכת_, dımd
  { {0x7dd40054,0x9f4f0025,0xdb040032,0xd3370009}},	//   _bàsi, rigé_, weiß, _חרדה_
  { {0x2bbb0003,0xab950001,0x2d87003a,0x16340021}},	//   يارة_, нављ, _önem_, теря
  { {0x8b5b0012,0xe4510009,0xaad20011,0x2d9c02fd}},	//   تجسس_, רֶם_, _तथाक, heve_
  { {0x160e0037,0xd2510012,0xa7fd0060,0x9f4f00b0}},	// [390] ाकार_, انئ_, nsım, nngå_
  { {0xdbd60005,0x6b9b008b,0x2d9c0027,0xdeb6000b}},	//   _hääl, zeug, jeve_, _נפתח_
  { {0xdb0b006f,0x9961001e,0x7dd002fe,0x63a902ff}},	//   _ingå, nūšu_, _väst, yden
  { {0x7e6d001e,0x9cd60009,0xe7580024,0x44260081}},	//   šapm, _נורה_, диці_, _nho_
  { {0x7dd00006,0x2003001c,0x65630017,0x501c000b}},	//   _täst, čkih_, tanh, קודו
  { {0x44390274,0x0ea8007c,0x2918006f,0xd1260003}},	//   _his_, ькій_, _fyra_, _مم_
  { {0xfc460026,0x7bcb0300,0x4439000e,0x683a0066}},	//   žíva_, _pogu, _kis_, _vůdc
  { {0x4426008a,0x4439007a,0x62890301,0xa3ca0011}},	//   _cho_, _jis_, tteo, रॉल_
  { {0x66f30302,0x65630017,0x44390303,0xeab10003}},	//   _अधिक_, panh, _mis_, اعب_
  { {0x3f9d0002,0x7e7d0304,0x2d9c00b8,0xd2560009}},	//   lewu_, dusp, ceve_, עשתה_
  { {0x05c30037,0x7c2d0305,0x94a80306,0x60160031}},	//   शानब, kmar, _отца_, zámu
  { {0xf772000a,0xe73a0015,0x2919001e,0x6441000d}},	//   داد_, яем_, āsa_, _iuli
  { {0x96ba0046,0x64410101,0x201e001e,0xa3b90037}},	//   чуну_, _huli, ēti_, चाई_
  { {0x270e001a,0x64410307,0x64480018,0xdca6004c}},	//   ộng_, _kuli, ídio, наги
  { {0x4439008b,0x65610149,0xfce60308,0x8dfa0009}},	//   _bis_, _melh, хово, להשת
  { {0x7c2d0309,0x04570003,0xf0620014,0x442d030a}},	//   gmar, علقة_, _скъп, nme_
  { {0x160f0044,0x291e001c,0x6008003a,0x4439030b}},	// [3a0] िवार_, _šta_, rımd, _dis_
  { {0x442d008b,0xdb060013,0x7c2d030c,0x6f160034}},	//   hme_, _jaké, amar, życk
  { {0x6441007b,0xb5fb0031,0x7c2d030d,0x442d030e}},	//   _nuli, zsák, bmar, kme_
  { {0x7dd00006,0x3f8200b6,0x69c3030f,0x8afd0030}},	//   _täss, ngku_, öner, zařa
  { {0x245e0013,0xceb3000b,0xeb3b0009,0x433b0009}},	//   lům_, ָיו_, _מעכש, _מעכב
  { {0x4439000d,0x7a8b0009,0x867b0009,0x442d0310}},	//   _zis_, _מָלַ, פרצו, eme_
  { {0xdcfc0039,0xb7960046,0xd4970047,0x245e0066}},	//   derī, _праћ, еры_, nům_
  { {0x442d0311,0x251b0009,0x68e1005e,0x6561005e}},	//   gme_, הוצא, _ülda, _eelh
  { {0x65610272,0x539b0009,0x245e0030,0x2327004c}},	//   _felh, ליקו, hům_, ноћи_
  { {0x44260036,0x245e0066,0x2ca90002,0x27e00312}},	//   _who_, kům_, łada_, _alin_
  { {0x33d6007c,0x29180065,0xdfd10003,0xdbd6004a}},	//   _підт, æra_, ليد_, _pääl
  { {0x04db000b,0x245e0066,0x7e7d0038,0x1ae60313}},	//   _מקבל, dům_, tusp, _поем
  { {0x9f4b0054,0xa3d50011,0x0cc90011,0x7c2d0248}},	//   ricà_, _सकत_, रह्म, vmar
  { {0x2d85003a,0x69ce0314,0xb8660003,0xddc20030}},	//   üle_, _nobe, _كابو, hrož
  { {0xd5b80015,0xdbd6004a,0xe4e4002d,0x98a30001}},	//   хся_, _tääl, гітн, _бије
  { {0xb5fb0066,0x7c2d0315,0x9cbb0009,0xe3b30012}},	//   zsáh, umar, הצלח, درس_
  { {0x98ac00a2,0x44390316,0x9f4b005e,0x69da016d}},	// [3b0] madı_, _vis_, öjõu_, okte
  { {0x98ac003a,0x4efc0009,0x91e4004c,0x601d0030}},	//   ladı_, _מהחו, гође, kémk
  { {0xe3c300a2,0x99840003,0x69c80070,0xfe360009}},	//   ngıç_, المو, ijde, _שרתי_
  { {0xa857000b,0x65610066,0x83190012,0x64410132}},	//   גיאה_, _selh, _يقدر_, _ruli
  { {0x2fcd0070,0xe72e0001,0x6441010a,0xe7e20011}},	//   _voeg_, ре_, _suli, _खतरा_
  { {0x69ce0317,0x0c950048,0x7b07004b,0xc6940009}},	//   _gobe, вшия, ăptă, ראס_
  { {0x301b0003,0xd6180003,0x65610318,0xdb060031}},	//   _فترة_, رتها_, _velh, _raké
  { {0x7bcf000d,0xeb9900de,0x403401ec,0xae0f0011}},	//   _jocu, фии_, _бесс, िवहन_
  { {0x69d8000f,0x1309007c,0x8b250014,0x628d0319}},	//   öveg, ьний_, ъдие, ntao
  { {0x7bcf031a,0x6441031b,0x63ad031c,0xb5fb0031}},	//   _locu, _tuli, hdan, aráz
  { {0x9b950003,0xf8e10037,0xac740012,0x80cb0011}},	//   _للات, पनिय, _مانش, ाहें
  { {0x6008003a,0x245e0066,0xaa890012,0xa3b00011}},	//   dımc, vům_, _ينضم_, _टों_
  { {0x3f8c0002,0x21e40052,0x69c40037,0xdb060029}},	//   ędu_, _höhe_, रामी, _také
  { {0x7ae9000f,0x63ab0028,0x245e0066,0x69da031d}},	//   mzet, _hagn, tům_, ckte
  { {0xa8060098,0xa3d50037,0xa0a5002d,0xe5880009}},	//   _изкл, _सका_, _райд, עָשָ
  { {0xd00f0003,0x6f160002,0x245e0066,0x7bdb004a}},	//   _ولو_, życi, rům_, nkuu
  { {0x61460046,0xd5b1001a,0xe7f70037,0xd9460001}},	// [3c0] веза, ốc_, ूचना_, вези
  { {0x7ae9000e,0xdb0d0028,0xbd460012,0x7e60004b}},	//   izet, rjað, _جندي, âmpu
  { {0x7bdb0006,0xa0670014,0x1d0a00f5,0xa50a031e}},	//   kkuu, ваха_, _цени_, _цена_
  { {0x9985000e,0x69ce031f,0x9e660012,0xd7ef0012}},	//   illő_, _wobe, ناتن, يكل_
  { {0x69da0033,0xc7b3000b,0x6e940003,0xe737022a}},	//   ykte, יבא_, التا, вец_
  { {0x6146004c,0x69d80031,0xa6130024,0x44440320}},	//   _јева, öved, аміч, _ku_
  { {0x44a30003,0x9cb40003,0x8cc40012,0xd1970009}},	//   لموق, امبت, اقعه, _שכלי_
  { {0x3d160321,0xc4d30009,0x60160031,0x601d0030}},	//   _पुणे_, שגה_, zámr, rémk
  { {0x8c1b000b,0x7ae90322,0x81bc0035,0xb5fb0031}},	//   ווקי, gzet, kmēt, msáv
  { {0x44440323,0xbda50003,0x6008003a,0x6e3a0070}},	//   _ou_, _محمو, yımc, _uitb
  { {0xb97b0093,0xddc2003e,0x417b000b,0x44440324}},	//   וניי, zpoś, וניב, _nu_
  { {0xb5fb0017,0x63ab0325,0xd0060003,0x9cd70009}},	//   nsáv, _gagn, صل_, _שואה_
  { {0x44440326,0xd2500003,0x2f5b000b,0x77640327}},	//   _au_, _انت_, ודכנ, _deix
  { {0x444400a1,0xceb3000b,0x63ab0328,0xee310009}},	//   _bu_, ביש_, _zagn, ֶֽם_
  { {0x444401b3,0x499b000b,0x7dcb000e,0xa99b0009}},	//   _cu_, _חשוב, _küsz, _חבור
  { {0x3137000b,0x60080060,0x3ed50012,0x7b770012}},	//   _ברוך_, rımc, _مقبر, ضطرا
  { {0x44440329,0xfc300012,0x63a00034,0x7c34004c}},	// [3d0] _eu_, زحف_, iemn, ретх
  { {0x444401a2,0xa294002d,0xddc20002,0x6b84002c}},	//   _fu_, рафі, groż, agig
  { {0xf775002d,0x82340003,0xf1ba001a,0x94d5002d}},	//   гулю, شركا, _chơi_, _сонц
  { {0x2e240028,0x6280032a,0xf7700012,0x7ae90031}},	//   nöfn_, kumo, قاه_, yzet
  { {0x4444032b,0x6280001e,0x6008003a,0xdb7a0009}},	//   _zu_, jumo, nıma, _אנרכ
  { {0xee38007c,0x7ae9012e,0x8d540014,0xbef30037}},	//   вні_, vzet, атъч, _अधीन_
  { {0x64450005,0x4444001a,0xc1050003,0xcd98000b}},	//   _juhi, _xu_, _صوري, דדות_
  { {0xac96000a,0x3d3c000b,0x3ea9004a,0x672c000e}},	//   انيا_, וגוס, _osat_, öljü
  { {0x7ae90027,0x62800010,0x7c3d032c,0xd945005f}},	//   uzet, gumo, _misr, лепи
  { {0xb0ae0037,0xf2d2000b,0x60180028,0x2d830058}},	//   टिंग, צעי_, símt, _øje_
  { {0x228b0119,0x7ae9000e,0x545502d3,0x88f60009}},	//   søk_, szet, _свет, ָ֖יו_
  { {0x92b50012,0xdb0d005e,0x2cae0031,0x6280032d}},	//   _محتا, ljaõ, üldő_, bumo
  { {0x64450051,0xe73700b3,0x7f190024,0xaa890012}},	//   _auhi, лею_, віру_, _أنتم_
  { {0x4444032e,0xc3320009,0xd24e00ae,0xdb1d032f}},	//   _pu_, _הוד_, _عنى_, _insè
  { {0x444402b5,0x3ea90039,0x9999007a,0xdce3007a}},	//   _qu_, _esat_, ūsų_, kanč
  { {0xdce3007a,0x44440330,0x81bc0035,0xdd030073}},	//   janč, _vu_, smēt, ūrėm
  { {0x6d410331,0xac070015,0xdce30010,0x6b840051}},	// [3e0] _ogla, унта_, danč, rgig
  { {0x69c40037,0x44440332,0x7a220064,0x2f1d0031}},	//   राधी, _tu_, rôto, ságú_
  { {0x81bc0333,0x7fd6002d,0xcf9a0001,0x44440334}},	//   slēg, ліді, ејл_, _uu_
  { {0xd3da0003,0x4b550014,0x6d410335,0x7f860012}},	//   _أبدا_, _върт, _agla, الإن
  { {0xddc4009b,0x6d5c00f1,0x2d8a003a,0x44200336}},	//   _zviš, obra, _öbek_, mli_
  { {0xc693000b,0x7d1e008e,0xdb0000b0,0x0caa0337}},	//   צאו_, _kyps, ndmå, етии_
  { {0x601d0025,0x44200338,0xaf9a0024,0x2a070198}},	//   sémi, oli_, _птах_, _серп_
  { {0x442000a2,0xc2740001,0x3a740294,0xb2740339}},	//   nli_, алиј, алир, алиш
  { {0xdd250010,0x4420033a,0xfbd30009,0x8e0a0024}},	//   rūši, ili_, מתה_, _знав_
  { {0x2a97000a,0x81bc001e,0x44200107,0x79a60148}},	//   ائية_, emēr, hli_, урие
  { {0x02170093,0x683e007a,0xbb860003,0x4ddb0009}},	//   רחים_, _būda, _ملاي, _רחבו
  { {0x75280039,0x273a003a,0x3137000b,0x01370009}},	//   _izdz, _günü_, טנים_, טרית_
  { {0xdb190002,0xeab20003,0xa3b80011,0x1bfb0009}},	//   _dowó, _دعا_, चयन_, _אלאב
  { {0x44320002,0xdb000052,0x045b0012,0xf1a30048}},	//   emy_, rdmä, فجرت_, _грън
  { {0x721b000b,0x4420033b,0xdb1d0061,0x55bb0009}},	//   _רווח, fli_, _insé, עמלו
  { {0x81bc001e,0x4420033c,0xa7750048,0xb355033d}},	//   slēd, gli_, _тлич, ркаш
  { {0x6d5c033e,0xd2510012,0x644a0025,0x9f490060}},	// [3f0] bbra, زنا_, _éfin, _amaç_
  { {0x6d5c0017,0x61fa033f,0xdcfc001e,0x44f50063}},	//   cbra, nitl, sgrā, _впос
  { {0xdce30340,0xa3d50011,0x8f550012,0x8b030030}},	//   tanč, _सकल_, لناش, ěřil
  { {0xa802003a,0x8e550024,0x4fc80012,0xb4c30011}},	//   şına, аткі, ُولُ_, ्ही_
  { {0xea00001a,0x8d650341,0xa6350024,0xc0c60097}},	//   _giầy_, авле, анді, _óánæ
  { {0x3f750020,0xc27a000b,0xaaa80014,0xb5fb000e}},	//   ều_, _ברשי, _съюз_, csát
  { {0xfbd10003,0x228f0342,0xadd80009,0x7a2b0032}},	//   قتة_, lük_, רווח_, güte
  { {0x7c640003,0x2a6d0051,0x0b450014,0x6d5c0343}},	//   حاول, tseb_, шнин, zbra
  { {0x4a450001,0x11e5022a,0x7aed0344,0x83b60009}},	//   јнов, ижим, nzat, בִיא_
  { {0x84670098,0x063b0003,0x7bcd004a,0x6d4100eb}},	//   _бъде, _أسرع_, hjau, _ugla
  { {0xf1b20093,0x23c50037,0x44320002,0x55ba000b}},	//   קסט_, वादद, ymy_, _שמעו
  { {0xd5b10020,0x5b150345,0x2295022a,0x39580060}},	//   ốn_, _кмет, _видя, ırsa_
  { {0x228f000f,0x25a30058,0x81bc001e,0x1e830048}},	//   jük_, fejl_, rmēr, олям
  { {0x44200034,0x7aed0064,0x61fa0346,0xdb040018}},	//   wli_, dzat, citl, ldiç
  { {0x64a6011f,0x8f76002d,0x6d5c0347,0xdb000348}},	//   шава, _купі, rbra, rdmå
  { {0x35c70044,0xdb040149,0x7d1e0066,0xef1f0052}},	//   लाड़, ndiç, _vyps, rfür_

  { {0x89660046,0x4b550014,0x68e10051,0x5166002d}},	// [400] икаж, съст, _üldj, иваб
  { {0x48b60014,0xa1c3026d,0x70560012,0x68e40030}},	//   ищет, обуд, لنطا, _řidi
  { {0x3205002a,0x161f0037,0x6d7b0009,0x757b0009}},	//   inly_, _मीटर_, _באיח, _בטיפ
  { {0x99870010,0x1e0e0037,0x2cac0028,0x2d870349}},	//   _kinų_, ाक्ष_, æddu_, egne_
  { {0xe5c6034a,0x63a4034b,0x228f0060,0xb5fb0031}},	//   иско, mein, cük_, csás
  { {0xd49a034c,0xdd900012,0xde030024,0x8d63004c}},	//   ври_, سوب_, опчи, овље
  { {0x53e60104,0xcbe6022a,0x83f8034d,0x9c57004c}},	//   ициа, иции, лекс_, ашњу_
  { {0xa7fd003a,0xaf490012,0xfc2f0012,0xe3b20012}},	//   nsıt, _مشكل_, وحي_, زرع_
  { {0x75e20029,0x9f7b000b,0xe7b30012,0x6fb30012}},	//   _rôzn, _שנמח, _بمقد, _بمقا
  { {0x63a4008b,0xe61f0061,0x2a790031,0x9f590025}},	//   hein, ntôt_, ásba_, misé_
  { {0x7aed034e,0x9f590108,0x228f034f,0x59d30012}},	//   zzat, lisé_, zük_, تغير
  { {0x228f00a2,0x61d30044,0xf8b3000b,0xdce80029}},	//   yük_, _दक्ष, קשר_, _obdĺ
  { {0x42540012,0x9f590025,0xe1ff0064,0x63a40350}},	//   _انتر, nisé_, _kvót_, dein
  { {0x752d0066,0xadf80037,0x6008003a,0x63a40032}},	//   řaze, ्चिन_, lıml, eein
  { {0x3157000b,0xd4370003,0x7b670015,0x7bcd001e}},	//   _דיון_, لعرب, итае, tjau
  { {0x600800a2,0x7aed0054,0x228f000e,0x7ff40003}},	//   nıml, tzat, tük_, _وسيا
  { {0x6e950351,0x5e95000a,0x7bcd0006,0xe695000a}},	// [410] _الخا, _الخط, rjau, _الخد
  { {0x68e10051,0xa802003a,0xc05b002d,0x20190352}},	//   _üldk, şıla, від_, losi_
  { {0xea00001a,0x7aed000e,0x36340003,0xdce3001e}},	//   _giấy_, szat, _بريس, kanā
  { {0x5f740003,0x4f580012,0xa2360035,0x20190353}},	//   قاهر, لجهد_, āršā_, nosi_
  { {0xf1a70001,0xef1f003a,0x6008003a,0x539a0009}},	//   _крвн, zgün_, dıml, _גירו
  { {0xe618002d,0xbb3a000b,0xa1840015,0xd658000b}},	//   аді_, _תעשי, _мысл, סיות_
  { {0xddc9007d,0x55780009,0x33f50024,0xac960012}},	//   _aveţ, בעון_, йчис, منوا_
  { {0xd7740003,0xf3f2000b,0x58050012,0x5ff5004c}},	//   _واقع, ּ֣ה_, _اورك, _узбу
  { {0x68f70073,0x65680031,0x75eb0031,0x9f59008e}},	//   žadė, _fedh, _küzd, insä_
  { {0x7bc20354,0xdb060066,0xdb040018,0x86c40012}},	//   _enou, _jaká, sdiç, _بيكن
  { {0x27330020,0xcea9000b,0x34b30037,0x69d50355}},	//   _ảnh_, _רי_, ुमोद, _moze
  { {0x6d45002c,0xdb060356,0x03940024,0xeb900012}},	//   _agha, _inkö, _мрія, _يظن_
  { {0xe9ce00ac,0xc2cb0012,0x1dc30011,0x07a30357}},	//   _ек_, _جبال_, शांत, чаян
  { {0x9f59004a,0x63a40032,0x6448016d,0xd3360009}},	//   ensä_, wein, _yudi, _פרסה_
  { {0xe0550003,0xb4260003,0x8afd0066,0x40920003}},	//   _اختب, معرو, daři, _فلور
  { {0x680b0002,0x2d8c0002,0x6b890358,0x661801bd}},	//   lędn, żde_, ngeg, zovk
  { {0xb5fb0017,0x6b890359,0x63a4035a,0x06970012}},	// [420] rsár, igeg, rein, _هنية_
  { {0xb5fb0149,0x05aa035b,0x9f590061,0x4586035c}},	//   ssár, _свой_, visé_, _угов
  { {0xb8650003,0x6008003a,0xa802003a,0x7c960003}},	//   قانو, yıml, şıma, _اشخا
  { {0xd0190024,0xa067004c,0x2d870060,0x263d0064}},	//   афі_, саца_, _öner_, _dňom_
  { {0x8408000e,0x501b0009,0xa6fa0012,0x92b60012}},	//   _előá, נונו, دعاء_, _احجا
  { {0x2d9100a2,0x244e0026,0x9f590061,0xd5b1001a}},	//   _özel_, _kým_, risé_, _cá_
  { {0xd4670046,0xa3cc0037,0x65680058,0x27040011}},	//   бије_, लाप_, _vedh, रपुर_
  { {0x9473000a,0xba540001,0x69c3035d,0xdb0601bd}},	//   أدوا, овиј, _anne, _zaká
  { {0x6ff5003e,0x75eb00a2,0xdd3a000d,0x6008003a}},	//   jący, _yüzd, făţi, rıml
  { {0xee370046,0x31c60015,0xa074035e,0x1e570009}},	//   _гну_, ссив, огоч, _לשמר_
  { {0x6448035f,0x621b000b,0x20190360,0xc19b0009}},	//   _uudi, רויק, tosi_, נשטי
  { {0x61fe003a,0xa3cc0037,0x69dc0361,0x493b0009}},	//   hipl, लाफ_, öreb, טגיו
  { {0xa3cc0044,0xdce1001e,0x2d980362,0xfc170009}},	//   लान_, _ielā, ffre_, _פקדי_
  { {0x15eb002d,0xddcd0002,0xa158002d,0x93250003}},	//   уємо_, _stał, _таку_, _برمن
  { {0x3c78000b,0xe478000b,0x41dc0011,0x6ff50034}},	//   יָּב, יָּש, _मक़स, rącz
  { {0x68e10005,0xdfd10012,0xb8de0011,0xdb0f01e3}},	//   _üldi, _آية_, ीम_, _hacé
  { {0xdd910003,0x7769000d,0x27e90363,0xb7940012}},	// [430] _قوة_, _reex, _ilan_, _رؤيت
  { {0x645c0364,0x9e150024,0x49580009,0x49750024}},	//   bpri, _єдні, שֻּׁ, ілес
  { {0x7afb0029,0x1bd50048,0xdb0f0025,0xa3d50365}},	//   _ľutu, _доня, _macé, _донч
  { {0x75eb00a2,0x680b0002,0xd5bf001e,0x7a2f00b0}},	//   _düze, zędn, žādi_, møte
  { {0xf41f008e,0xdc0f0030,0xdb060366,0x62350367}},	//   _ikä_, něčn, _taká, _мему
  { {0x27180020,0x4efc000b,0x49cb003c,0x75eb0368}},	//   ọng_, נהגו, _сумм_, _füze
  { {0x27e900a2,0x6812001e,0x75eb003a,0x6ff50002}},	//   _olan_, lāde, _güze, zący
  { {0x5f940046,0x8c4202ad,0x3a990024,0xd7940048}},	//   _нист, меще, атою_, _нисъ
  { {0xdd3a007d,0x6b890369,0xdb0b0052,0x22430227}},	//   tăţi, rgeg, _ungü, _kijk_
  { {0x6b89036a,0xef1f003a,0x27e9036b,0xf9890012}},	//   sgeg, rgül_, _alan_, جندي_
  { {0xa0690046,0x6b890070,0xe5c4003c,0xdd3a004b}},	//   јама_, pgeg, _эсто, răţi
  { {0xd9a60037,0xcdc9000b,0xb8d10011,0x644200b8}},	//   _ऑस्ट, _בך_, _ऑन_, _gioi
  { {0x8db6002d,0x11d5002d,0x501a000b,0x51f50012}},	//   осві, _мікр, שורו, _وستر
  { {0xcb36000b,0x11440012,0x0446004c,0x69c3036c}},	//   _ואני_, _فَهُ, жевн, _unne
  { {0x2ea60037,0x25a5005e,0x7a300248,0x23600227}},	//   _गन्त, õlla_, näte, tbij_
  { {0xf0920009,0xa6ca0012,0xfe080081,0x200d0073}},	//   _חנה_, _نوبل_, iữa_, _njei_
  { {0x236000bd,0x3ea00027,0x6812001e,0xd6cf0012}},	// [440] rbij_, _upit_, gāde, _لقي_
  { {0x645c0108,0x244e022d,0xc9860003,0xf77f036d}},	//   ppri, _tým_, تشري, rkçe_
  { {0x80a60003,0x321a02e0,0xf0aa0048,0x224302ae}},	//   تمان, ropy_, ркел_, _dijk_
  { {0x7a30004a,0xca290009,0x7ee60012,0x44240081}},	//   däte, דם_, يكان, _óm_
  { {0xdce7001e,0x661c0070,0xf1a90011,0x680b0034}},	//   majā, oork, क़ान, zędo
  { {0xddc90013,0x78af0006,0xdce7001e,0x1cba0012}},	//   _kteř, äivä, lajā, لاعب_
  { {0x37e6002d,0xdfa60012,0x63b60073,0x75eb0060}},	//   _довг, _وحري, odyn, _yüzb
  { {0x2d80000d,0xdce7001e,0x63b60112,0x9ad40048}},	//   şie_, najā, ndyn, зжич
  { {0xcb670046,0xc1a60001,0x6442008e,0x7bdb0009}},	//   цање_, ојни, _vioi, שקפו
  { {0x68e90066,0x1a9b000b,0x81bc0035,0x929b0009}},	//   _ředi, סייע, alēn, סיית
  { {0xf2df0020,0xc953000b,0xa054002d,0xdce7001e}},	//   _ngân_, ומת_, явні, kajā
  { {0xad1b0009,0x429a0012,0x6ac60012,0x8ae60024}},	//   _דובר, _ننصح_, _وقام, _мілл
  { {0xf773000b,0xd6d80015,0x68e1005e,0x661c036e}},	//   וקר_, отр_, _üldv, fork
  { {0xdcfa003a,0x69d8000e,0x63b60002,0x25570030}},	//   _hatı, övel, edyn, dělí_
  { {0xdcfa00a2,0x2007000e,0x22430070,0xdb6b036f}},	//   _katı, énik_, _rijk_, ирал_
  { {0xda670003,0x3eb0004a,0x69d80370,0xaa550048}},	//   قائي, ältä_, _hove, зваш
  { {0x2aab0046,0x161a0037,0x8bd7000b,0xd2290003}},	// [450] штво_, धवार_, קומו_, مكره_
  { {0x68120039,0x645a01a2,0x7c3a0010,0xd1640048}},	//   rāde, _otti, įtra, дъци
  { {0x6d550002,0x69d80371,0x55bc0009,0xb4b5003c}},	//   mcza, _move, _כמזו, _эйнш
  { {0x99980010,0x2bb60037,0x27e9000e,0x6d48002c}},	//   _virš_, _अफगा, óan_, _agda
  { {0x9e64002d,0xf1bc0011,0x645a0372,0xed590373}},	//   двід, ्ञान, _atti, бол_
  { {0xbb3a000b,0x7a300052,0x8f1c0009,0xbdc7003c}},	//   _לערי, täte, בודת, ющей
  { {0x05760003,0xdcfa003a,0x6da200fa,0xd57c0009}},	//   سمية_, _batı, хища, שָׂר
  { {0x6e950015,0x2bb90003,0x7a300374,0xf7730012}},	//   _нибу, صابة_, räte, _زار_
  { {0x645a00a2,0x69d800bd,0xc7b2000b,0x201d0002}},	//   _etti, _bove, _אבן_, mowi_
  { {0x200b0002,0x69d80375,0x201d0002,0x99150024}},	//   enci_, _cove, lowi_, зьмі
  { {0x6d55003e,0xc6170037,0xc6890009,0x6c490012}},	//   dcza, दकीय_, _תא_, _الصف_
  { {0x201d0002,0xf74600de,0x34b60009,0x6d550034}},	//   nowi_, яемо, _מפעם_, ecza
  { {0xdce80066,0x33f40003,0x2477000d,0xdce70035}},	//   _oddě, _تسلس, lăm_, vajā
  { {0x725a000b,0x2ca90002,0x52d6000b,0xdef60009}},	//   _הכספ, ładu_, _מונע_, למרט_
  { {0xdce70039,0xdcfa003a,0x201d0002,0x99d40003}},	//   tajā, _yatı, kowi_, _تتنا
  { {0x487a0093,0x78ba000e,0x6b8d0376,0x69d80377}},	//   _הטקס, _átvi, ggag, _zove
  { {0x63b60002,0x661c0378,0x2477001a,0x201d0034}},	// [460] rdyn, pork, hăm_, dowi_
  { {0x4efb000b,0x6b8d002c,0x63a9006e,0x20020379}},	//   _להפו, agag, heen, liki_
  { {0x4ddb0093,0x2451037a,0x2477000d,0x6296002c}},	//   _החיו, _nám_, jăm_, styo
  { {0x2002037b,0x63a90227,0xf9890009,0xa1130012}},	//   niki_, jeen, טר_, رونت
  { {0xa3cf0037,0xdb06006f,0x3ebf0025,0x8bd70009}},	//   शान_, _bakå, _crut_, _זוכו_
  { {0xdcfa00a2,0xf1d0001a,0x9f590042,0x746a0024}},	//   _satı, _mạch_, visí_, брив_
  { {0x247701b3,0xd5b10020,0x64580061,0x44220051}},	//   găm_, ối_, _évid, _kkk_
  { {0x69d801d5,0x6d550002,0x75eb003a,0xd4670001}},	//   _sove, zcza, _müza, чиће_
  { {0x64460065,0x6d550002,0x69d8037c,0x5a3402ad}},	//   _miki, ycza, _pove, мнит
  { {0x68e100c5,0xe9f8002d,0x6831037d,0x51f80024}},	//   fyld, інні_, råde, інню_
  { {0xf1af0003,0x2477000d,0x68e1037e,0x2002037f}},	//   اءً_, căm_, _üldt, fiki_
  { {0x6d550002,0xa263001a,0xf1d0001a,0x27e60380}},	//   wcza, _khố, _bạch_, nkon_
  { {0x3bbb0009,0xf1940223,0x9f4d0248,0xb3bb0009}},	//   _למאד, _жиль, _umeå_, _למאכ
  { {0xc27b000b,0x7a2b003a,0xbb3b0009,0x4a7b0009}},	//   _פרוי, gütl, _העדי, _פרוב
  { {0xc9b7000b,0x6d550002,0x2c55001e,0xec09001a}},	//   _זהות_, rcza, _kāda_, iến_
  { {0x683f0039,0x1bd40109,0xfbd30012,0x671e0011}},	//   _līdz, нося, رتز_, _युवक_
  { {0xe8020037,0x2477000d,0xe2930003,0x877c0009}},	// [470] _लगता_, zăm_, عذر_, _האחי
  { {0x96b30037,0x64460010,0xceb4000b,0xda0c0011}},	//   _इनबॉ, _eiki, _טיפ_, िचित_
  { {0x628402d1,0x4ddc000b,0xdb0b000e,0xb5fb000e}},	//   ario, _לחזו, _magá, ppáb
  { {0xdb0f0164,0xa857000b,0xd9a90037,0x2477000d}},	//   _hací, פידה_, _कस्ट, văm_
  { {0xa2630020,0x6812001e,0x201d0002,0x24510042}},	//   _chố, nāda, rowi_, _sám_
  { {0x6da20014,0x2477000d,0x20020343,0x201d0002}},	//   виша, tăm_, ziki_, sowi_
  { {0x58840015,0x63a90381,0xe5700012,0x201d0034}},	//   _пыта, teen, اطه_, powi_
  { {0x24510382,0xf8b2000b,0x24770383,0x4429003a}},	//   _vám_, _בשל_, răm_, nla_
  { {0x2477000d,0x63a90384,0x5ac90024,0x3ebf0385}},	//   săm_, reen, ілом_, _urut_
  { {0x13060047,0x81bc0039,0x68e10386,0x2451001a}},	//   ьный_, blēm, _ülds, _tám_
  { {0xc172000b,0x2002009b,0xf1d0001a,0x66030387}},	//   כחי_, tiki_, _sạch_, mink
  { {0x3f8f00c6,0x9f4b0164,0x48e20024,0x66030388}},	//   nggu_, dicó_, тоюв, link
  { {0x7c2900a2,0x69d8000e,0x44290389,0x8f9a0009}},	//   mler, övek, dla_, חירי
  { {0xc3320093,0x9f4b0164,0x64a6038a,0x6603038b}},	//   _סוג_, ficó_, мага, nink
  { {0x81bc0039,0x644600c6,0x8cc00037,0x27ed00b9}},	//   klēj, _piki, वियो, _olen_
  { {0x7c2900a2,0x2d84003a,0xc8f90011,0x7a2b005e}},	//   nler, şme_, ्पैम_, sütl
  { {0xec090020,0x877b000b,0xb77b000b,0x41c90037}},	// [480] yến_, _ואפי, _ואפש, रांस
  { {0x6603007b,0xea00001a,0x7c29038c,0x644601ee}},	//   jink, _phẩy_, hler, _wiki
  { {0x7c29038d,0x11d70003,0x64460010,0x16c60037}},	//   kler, بولة_, _tiki, लम्ब
  { {0xa263001a,0xdb0f0066,0xc209000b,0xd0120012}},	//   _phố, _zací, בה_, خلص_
  { {0x27e6004a,0x2c55001e,0xfbdf001a,0x7c29038e}},	//   rkon_, _rāda_, _kiên_, dler
  { {0xa3cc0044,0x7bdd0052,0x4420008e,0x68360031}},	//   लाव_, ösun, loi_, ládd
  { {0x7c2900a2,0x64a30001,0x81bc001e,0x7ae4004a}},	//   fler, ваја, blēj, lyit
  { {0xfbdf008a,0xdfa6000a,0xa2630020,0xbc370003}},	//   _liên_, _تحسي, _thố, وسيا_
  { {0x23270001,0xe3af0003,0x518601b6,0xc986038f}},	//   моћи_, شري_, муна, муни
  { {0x442900a1,0xfbdf001a,0x66030002,0xdce70002}},	//   zla_, _niên_, cink, lają
  { {0x69dc0390,0x44290391,0x5ce60003,0xca48001a}},	//   _more, yla_, _تكال, _mời_
  { {0xca480020,0xd0110003,0x4429006f,0xdce70002}},	//   _lời_, الح_, xla_, nają
  { {0xe81f0044,0x6bd70003,0xfbdf001a,0x683f0066}},	//   यकता_, _تونس_, _biên_, jádř
  { {0xbf9b0392,0xf1aa0003,0x7c200393,0x2a69003a}},	//   ciên, _ذاته_, lomr, _çaba_
  { {0xdb0f02d1,0xdce70002,0x26c20030,0xd498004c}},	//   _vací, kają, _škol_, мрт_
  { {0x1bb80003,0xdb0d0017,0xdce70002,0x66030394}},	//   واقع_, ndaç, jają, zink
  { {0xdce7003e,0x5a350146,0x6d5a0395,0xc3340009}},	// [490] dają, енат, _ofta, תוּ_
  { {0x7c29003a,0x68ed0066,0x41c90037,0x69dc0396}},	//   zler, _řadi, राइस, _core
  { {0x96180003,0x69dc0397,0x7c290398,0x65750031}},	//   _تغير_, _dore, yler, mazh
  { {0xdd0d0002,0xdce70002,0x6d5a0399,0xca48001a}},	//   półp, gają, _afta, _dời_
  { {0x6603007a,0xcff80093,0x7af6003e,0x7c29039a}},	//   tink, וצאה_, czyt, vler
  { {0x04b50014,0x6603004a,0x69dc039b,0xed590055}},	//   есия, uink, örel, чок_
  { {0x6603039c,0xdcfe00a2,0x7c29039d,0x24e90024}},	//   rink, _yapı, tler, ямки_
  { {0x7c3b001e,0xdce70002,0xdb060029,0x6603039e}},	//   umur, cają, _rakú, sink
  { {0x7c2900a2,0x52a60015,0xc24501d4,0x41c90011}},	//   rler, евым_, нник, राऊस
  { {0xe1ff003e,0x7bdd0002,0x7c29039f,0x9ce70014}},	//   _swój_, _losu, sler, _оцел
  { {0x7c2003a0,0xbc68000a,0xbf9b0017,0xdc12003a}},	//   bomr, _يمكن_, riên, aşın
  { {0x34bd0037,0x35c70037,0xcc560009,0x8cae0011}},	//   ्मीद, लाक़, _טבעי_, ूटरो
  { {0x6264002d,0x6d47000e,0xaae70012,0x442003a1}},	//   _авіа, _újab, _تساو, voi_
  { {0x63bb008b,0xdce70002,0xec09001a,0xf1d0001a}},	//   ldun, zają, iếm_, _hạnh_
  { {0xfbdf0020,0x32050036,0xe1ff003e,0x07a6002d}},	//   _viên_, mily_, _twój_, _зайн
  { {0xca48001a,0x683f0010,0x442003a2,0x63bb03a3}},	//   _rời_, _būdu, uoi_, ndun
  { {0xfbdf0020,0xf1d00020,0x69dc03a4,0x63bb0052}},	// [4a0] _tiên_, _mạnh_, _pore, idun
  { {0x171b000b,0xdce70002,0xd5b1001a,0x4420004a}},	//   _מופע, wają, ốt_, soi_
  { {0x69dc00c5,0x4420007d,0xdce70002,0x629b0051}},	//   _vore, poi_, tają, htuo
  { {0x14d7000b,0xc209000b,0x629b0010,0x63ad03a5}},	//   _נוכל_, זה_, ktuo, cean
  { {0x2bd30044,0xdce7003e,0x3f9a0002,0xd6d00012}},	//   थाना, rają, ępu_, ؤقت_
  { {0xd5b30009,0x200f03a6,0x02460012,0x32050030}},	//   ָׁה_, angi_, _سَأَ, jily_
  { {0x7e7c001e,0x68e10051,0x987e0066,0x3f6a0103}},	//   _ārpu, _üldp, _péče_, _ниво_
  { {0xf1d00020,0xd3700003,0xa2c40037,0x7e7b001e}},	//   _cạnh_, جهة_, रिप्, šupi
  { {0x63b90002,0xeb9f0033,0x75280002,0xc43b0009}},	//   _dawn, _kjør_, _wydz, התקי
  { {0x4e7b000b,0x75280002,0xf65f0028,0x7dc50003}},	//   _מאמצ, _tydz, lvæg_, _لتمك
  { {0x68150002,0x2bb80037,0xa7fd003a,0x09f70009}},	//   ląda, _आसपा, msız, גמים_
  { {0xc02e0020,0x9cd7000b,0x7c650003,0x20d50010}},	//   _điều_, _רואה_, _شامل, džią_
  { {0x91e60046,0x95cb0014,0x2d8501c5,0x320503a7}},	//   _поде, пува_, óleo_, bily_
  { {0xa2c40044,0x92f2003a,0x2d91003a,0xa7fd003a}},	//   रिन्, ığım, _özet_, nsız
  { {0x19bb0009,0x7c840048,0x03c703a8,0xa25b0018}},	//   _ממגב, луте, нсам, _crôn
  { {0xdb000058,0x7a2b0032,0x68380097,0xa0970009}},	//   remæ, müti, nídd, _נדחק_
  { {0x59b70037,0xa7fd003a,0xe9870001,0x75eb003a}},	// [4b0] _असमर, ksız, ећен, _yüzl
  { {0xdb00005e,0x99990073,0xe9810024,0x63ad03a9}},	//   memä, _rusų_, ражi_, sean
  { {0x4426001c,0xef20003e,0xdb00004a,0x78ba0029}},	//   _oko_, ążek_, lemä, _štvr
  { {0x660701e4,0x200f00c1,0xe9380012,0xdb1d0248}},	//   lijk, ungi_, رسلت_, _anså
  { {0x212b008a,0x7c2d00a1,0xed4e0001,0x2369000d}},	//   ́ch_, mlar, ио_, mbaj_
  { {0xeb9f0119,0xd658000b,0xdcee001e,0x85e8002d}},	//   _gjør_, עיות_, labā, ндів_
  { {0x34bd0037,0xdb000051,0x66e7001e,0x320503aa}},	//   ्मेद, hemä, _sīkā, vily_
  { {0x7c2d00a1,0xdb00004a,0xdb4e0012,0x3035003c}},	//   nlar, kemä, يَى_, _ребё
  { {0x660700bd,0x75240066,0x13c80009,0x52a90024}},	//   kijk, řizp, תּוֹ_, євом_
  { {0x3d1a0044,0x629b03ab,0x7c2d030f,0xcaa40012}},	//   _मुझे_, rtuo, hlar, اصيي
  { {0x23e7007c,0x9be7002d,0xc952000b,0x3205002a}},	//   _підв, _підк, ימי_, rily_
  { {0x7c2d003a,0x6812001e,0x3205027b,0x2fdf0025}},	//   jlar, rādo, sily_, _joug_
  { {0x26c40013,0x443f03ac,0x7c2d03ad,0xb5fb0066}},	//   ímo_, mmu_, dlar, rpán
  { {0x644b0101,0x7c2d0051,0x600b004a,0x91e2003c}},	//   _higi, elar, tömä, _воше
  { {0x7b96007c,0x7c2d00a2,0xeb9a002d,0xc0d20012}},	//   краї, flar, мив_, _نيوب
  { {0x442d00a2,0x6f1e0002,0xd1160009,0xccf20009}},	//   nle_, ępcz, _בקצה_, בכל_
  { {0x3b070014,0x2006004a,0xbf9b0009,0xae210011}},	// [4c0] вето_, vioi_, _חיפש, यवान_
  { {0xc64a0003,0x644b03ae,0xa25b03af,0xf1aa0012}},	//   _تجعل_, _ligi, _trôn, باره_
  { {0xdce30066,0x7d7b0009,0x48b60048,0x7a30008e}},	//   raně, _קנטו, ъщат, säto
  { {0x7aeb000f,0x27e0002a,0x5fb20011,0x186703b0}},	//   ölté, _join_, ज़िल, таци_
  { {0x442d0013,0x96960098,0xa7fd003a,0x7c2403b1}},	//   dle_, треш, tsız, moir
  { {0xceb3000b,0x27e00061,0x6d480010,0x60860003}},	//   ייד_, _loin_, ždau, _لشرك
  { {0xa37b0005,0x2006004a,0xeb9f0033,0xa7fd003a}},	//   _klõp, pioi_, _kjøp_, rsız
  { {0xe4e3007c,0xeb970046,0x6ce3002d,0x27e0004a}},	//   рішн, вић_, ріше, _noin_
  { {0xea00001a,0x644b03b2,0x37140009,0x2d9603b3}},	//   _nhảy_, _digi, _עַֽל_, _арес
  { {0x644b0065,0x6804000e,0x7c2d003a,0xa697000b}},	//   _eigi, sődl, zlar, _בכמה_
  { {0xf993000b,0x44260027,0x7c2d03b4,0xdfd10012}},	//   ברת_, _tko_, ylar, ميد_
  { {0x6838015b,0x27e003b5,0x442d03b6,0xb4fb0009}},	//   bíde, _coin_, cle_, _קלאר
  { {0xa3cc0044,0x69ce0070,0xea00001a,0x4ab60011}},	//   लाई_, _onbe, _chảy_, _अनिव
  { {0x4b370093,0x2458001a,0xe9180024,0x20c60024}},	//   _סרגל_, _kém_, _полі_, _асиг
  { {0x7c2d00a2,0x660700bd,0x48e30001,0x2d5800b3}},	//   tlar, rijk, _војв, тись_
  { {0xe414007c,0x0a6b0046,0x24580066,0xfbdf001a}},	//   адсь, држи_, _mém_, _tiêm_
  { {0x7c2d00a2,0x6d5c00c5,0x6440004a,0xba740012}},	// [4d0] rlar, bcra, immi, لالت
  { {0x442d00a2,0x7c2d003a,0x75d50003,0x35b502ad}},	//   zle_, slar, _إيدا, _сбор
  { {0x21a4007c,0x7c2d00a2,0xd141003e,0x3947006f}},	//   риєм, plar, cząć_, äns_
  { {0x3b640014,0x442403b7,0x6f950012,0x20570009}},	//   _върв, jom_, الإض, דיאל_
  { {0xde580024,0xa2c40011,0x68e30248,0x5ea50012}},	//   вачі_, रिण्, ändb, امتل
  { {0x69d8000f,0xdb060066,0x68e8006f,0xf624002d}},	//   övet, _jaký, kydd, адіо
  { {0xe3b10003,0x18b80015,0x63bd0082,0xa3cf0011}},	//   مرة_, _игры_, _kasn, शाल_
  { {0xf42a004a,0x5f450003,0x442403b8,0xa3cc0011}},	//   _isää_, _منزل, gom_, लाए_
  { {0x11d90003,0xeb920009,0x68150034,0xda650012}},	//   فوظة_, צָה_, lądo, داعي
  { {0x644003b9,0x27e00061,0xd70d0011,0x628901e3}},	//   ammi, _soin_, सपैठ_, rreo
  { {0x644b002c,0x91050015,0x27e000b6,0x442d03ba}},	//   _tigi, упне, _poin_, ple_
  { {0xcbc70012,0xd00f0012,0x8cc00011,0x442403bb}},	//   _جزئي, كلٍ_, विरो, com_
  { {0x27e0004a,0x7c2403bc,0x9bb60009,0xfe710012}},	//   _voin_, voir, _תהנה_, ْدِ_
  { {0x7a7a0009,0x8e750024,0xdb040018,0x7bdb005e}},	//   _טרנס, шуюч, leiç, ljuu
  { {0x7c240108,0x6d5c002a,0x621a0009,0x6c550024}},	//   toir, rcra, _אוסק, иттє
  { {0xf092000b,0x42d6002d,0x7bdd03bd,0xc1780073}},	//   _הנה_, лізу, ösuh, _žė_
  { {0x070a0012,0x7afb0032,0x230a0012,0x7ae903be}},	// [4e0] _سيدي_, nzut, رتري_, nyet
  { {0x7bcf02d1,0x764b0061,0x7a2b0051,0xbb430024}},	//   _encu, _égyp, kütu, сеук
  { {0x98a60027,0x5d9b0009,0x659b0009,0xf9360024}},	//   čiće_, _אביה, _אייק, ухаю
  { {0x27e00065,0x61e003bf,0x788000f1,0xdb040017}},	//   ðin_, _पक्ष, _návš, jeiç
  { {0x7e2a002d,0x4a750015,0x98090003,0x69d8000e}},	//   ніка_, _выст, ختلف_, öves
  { {0xdcba0014,0x69ce03c0,0xe8560012,0xa3cc0011}},	//   ещи_, _unbe, _منسد, लाक_
  { {0xa1160003,0x54a60003,0x98be003a,0x6da30012}},	//   _صورت, احتف, yatı_, صميم
  { {0x0c730012,0xccf30009,0x63a403c1,0x7afb0032}},	//   حدود, מכו_, nfin, fzut
  { {0x81bc0039,0x63a403c2,0x41e60024,0x99630064}},	//   klēt, ifin, гіна, líši_
  { {0xa7fd003a,0x68380066,0xdd1f0029,0xd2b70009}},	//   apıl, bídc, _líši, נלית_
  { {0xf9930093,0xea000020,0xd1300003,0xc057002d}},	//   זרת_, _chạy_, تمد_, лія_
  { {0x1e1d0037,0xd36f0003,0x3c0c0030,0xad1b0009}},	//   पक्ष_, _فهم_, těvu_, _אובר
  { {0xe9800024,0x6b7b0009,0x75f00064,0x0f540012}},	//   _далi_, _טראנ, _väzn, صَّح
  { {0xdb07000f,0x63bd0039,0x52830003,0xdb06000e}},	//   ámít, _sasn, _الوك, _lakó
  { {0xa0c30012,0x683603a7,0x63bd03c3,0x7e7d0032}},	//   _هيوو, mádn, _pasn, sssp
  { {0xf1d20037,0x7bc00051,0x75eb003a,0x7a2b0052}},	//   तावन, ndmu, _müzi, hütt
  { {0x2ba60037,0xdb060029,0x497501d4,0x92950063}},	// [4f0] क्या, _taký, илас, разц
  { {0xd91b0015,0x2c510034,0x7d200031,0x200b03c4}},	//   нье_, _sądu_, ézsé, lici_
  { {0xd7e7002d,0xffe7002d,0xfaf90010,0xb0f90003}},	//   лідо, людн, lbūt_, خفاض_
  { {0xf3f10020,0xdef10003,0xa295002d,0x200b03c5}},	//   _mục_, يًا_, _камі, nici_
  { {0xb5fd007a,0x7c3a0061,0x4b7a0009,0xe37a0009}},	//   _atša, ître, _בארו, _שרשר
  { {0x7bc70039,0x48770003,0x644f0164,0xdb1f0051}},	//   ējum, _مدرس, _hici, övõi
  { {0xdb1d00c5,0x2c550039,0xc212000b,0x200b003a}},	//   _ansø, _kādi_, _והם_, kici_
  { {0x6a850014,0x62d50012,0x69c90011,0x7afb0032}},	//   алиа, لآخر, _होती, tzut
  { {0xde59002d,0x91d5002d,0x200b03c6,0xa7fd0060}},	//   _разі_, ацні, dici_, rpıl
  { {0x7a30004a,0xb9550001,0x7bdb0051,0x644f03c7}},	//   vätk, штић, sjuu, _lici
  { {0xf1b20009,0xf4840024,0x7cd90012,0x2d850132}},	//   חסי_, _гучн, _جواز_, _idle_
  { {0x644f03c8,0x200b03c9,0x92b50012,0xf3f10081}},	//   _nici, gici_, _نحتا, _dục_
  { {0x9a880003,0xd7360024,0xaa670254,0x68120035}},	//   _مَنْ_, рхнь, _стек, nādi
  { {0x644f001e,0xa2c40037,0x7ae6006f,0x7e6403ca}},	//   _aici, रिस्, äkte, _vtip
  { {0xda480009,0xab5d0034,0x399a0009,0x200b03cb}},	//   _עֲנָ, adże, _ייסד, bici_
  { {0x69c10065,0x61e3000e,0x3ead0027,0x9f1a0012}},	//   ldle, _honl, _opet_, _لآخر_
  { {0xda650003,0xfbd20009,0x7e64001b,0xb956004c}},	// [500] مالي, חתן_, _utip, атећ
  { {0x8e7b000b,0x867b0009,0xe1f703cc,0xba170012}},	//   _שניה, _שריו, агу_, ليقا_
  { {0xf3f10020,0xd8260148,0x6f660012,0x03a603cd}},	//   ệc_, аджи, لهام, _кино
  { {0x68e30163,0xb8ce0037,0x46ea0014,0x657c03ce}},	//   ända, _कह_, кден_, larh
  { {0x2fc00054,0xa6b60014,0x6812001e,0xddd60042}},	//   _maig_, рсещ, gādi, _zvyš
  { {0x443203cf,0xc6f7002d,0x6444004a,0x200b03d0}},	//   lly_, шніх_, lmii, zici_
  { {0xeb0e0044,0xed570046,0x200b003a,0x7a30004a}},	//   ाप्त_, шој_, yici_, jäti
  { {0x44320036,0xd7f20003,0x25a00066,0xe8d7000b}},	//   nly_, _بكر_, řil_, _דולר_
  { {0x69c10070,0xda660003,0x1ea90003,0x44320042}},	//   fdle, جابي, _مالي_, ily_
  { {0x6444004a,0x7e9b0009,0xfe9b0009,0x657c001b}},	//   hmii, _בסמו, _ביממ, jarh
  { {0x3a370093,0x3957000b,0x2360009b,0xf957000b}},	//   שרים_, ישים_, kcij_, יסית_
  { {0xcb6a0001,0xb5fb03d1,0x82a603d2,0xa34603d2}},	//   _раде_, ppák, _вадж, _кэлл
  { {0x67010037,0xe1fa0001,0xab5d0002,0x61e3003a}},	//   _लेखक_, _игд_, udże, _fonl
  { {0xf3f10020,0xfaf903d3,0xf6e40024,0xdb04005e}},	//   _tục_, rbūt_, іцян, ndiõ
  { {0x6ab60044,0x52b60044,0x245c000f,0x6804000e}},	//   _अनुर, _अनुस, _cím_, ződi
  { {0xd0f7000b,0x26c9001a,0x62820051,0x2d980033}},	//   _כמות_, _trao_, _kvoo, agre_
  { {0xa3a80044,0xe8e0001a,0xd2510012,0xa2c40011}},	// [510] ख्य_, ưới_, سنا_, रिष्
  { {0x68380013,0xf9930003,0x2ba60037,0x996703d4}},	//   vída, تبر_, क्ता, ртал
  { {0x44320036,0xb9c40003,0x3ead009b,0x2c550035}},	//   bly_, تقلي, _spet_, _tādi_
  { {0x1ab60037,0x4432002a,0xd7880012,0x4035003c}},	//   _अनूठ, cly_, لنمو_, щеес
  { {0x683d0108,0xec09001a,0x7a3d0061,0xe1ff0034}},	//   céde, iết_, lète, _dwór_
  { {0x68120039,0x442903d5,0xec090081,0x8de40012}},	//   rādi, loa_, hết_, يكنه
  { {0xfc3f001a,0x22590260,0x7a3d0025,0xd7590012}},	//   _khí_, _husk_, nète, _ملأت_
  { {0x3ea90054,0x61e3003a,0xd7940014,0x04560003}},	//   çats_, _sonl, _мисъ, حلية_
  { {0x7aed03d6,0xeab10003,0x645c000e,0xdb1d0061}},	//   nyat, سعة_, _érin, _basé
  { {0x61fa002a,0x7a3003d7,0x7aed0060,0xcef40012}},	//   ghtl, täti, iyat, _بأفغ
  { {0x4429004a,0x443203d8,0xb8750024,0x6444008e}},	//   koa_, yly_, алiз, ymii
  { {0x6be40003,0x7aed00b6,0xc5e90009,0x25f50011}},	//   _وكلم, kyat, _אד_, ऍसवी_
  { {0x7a300006,0x0cd00037,0x290b0002,0xfaf90010}},	//   säti, हम्म, ńca_, rbūs_
  { {0x4432002a,0x6da60001,0x69dc006f,0x61fa0358}},	//   wly_, љива, öret, chtl
  { {0x40950351,0x443203d9,0x9c59004c,0x74160012}},	//   _العر, tly_, ишту_, موسا
  { {0xfc3f0020,0x44f3001a,0x3ce5006f,0x7a30006f}},	//   _chí_, ị_, älva_, nätv
  { {0x44320036,0x77f7000b,0x68e302f1,0x6444008e}},	// [520] rly_, _למקד_, ändn, rmii
  { {0xc332000b,0x245c014a,0x200e0002,0x443203da}},	//   לון_, _tím_, ślić_, sly_
  { {0xef6500a2,0x2c550039,0xe1650003,0xe93a0001}},	//   ğını_, _kādu_, تدقي, учај_
  { {0x8b9600fa,0xef65003a,0xc0a90012,0xea000081}},	//   _уроч, şını_, شامل_, _thầy_
  { {0x68380013,0x8f9b0009,0x479b0009,0xe7f90011}},	//   bídn, ריני, רינס, ्फ़ा_
  { {0x63b60028,0x99d60003,0x6296003a,0x6dc30048}},	//   leyn, _اتحا, muyo, зсъж
  { {0xec090020,0x7589002d,0x6296003a,0xbcaa0012}},	//   yết_, рсів_, luyo, ادتك_
  { {0x62860010,0xcfaa0003,0xc7a30103,0x8fa303db}},	//   škom, _حاسم_, _ниск, _насе
  { {0x6296003a,0xfd9a0003,0x03d70009,0xd9f8003c}},	//   nuyo, _مئات_, מוקם_, иниц_
  { {0xf2d3000b,0x660e00b6,0x7abb0009,0x7de50012}},	//   פעת_, jibk, נציו, _وسلم
  { {0x20190017,0x64c60012,0x68360031,0x60110064}},	//   ério_, _ديال, mádj, sťme
  { {0x3137000b,0x6812001e,0x6836000e,0x5bc50012}},	//   מנים_, kādu, ládj, _وتنف
  { {0x41c80037,0x83360012,0x442903dc,0xf7490012}},	//   रयास, _اراض, voa_, شلسي_
  { {0x329b0093,0x9e150024,0xa2b70011,0x2327004c}},	//   _עבוד, ідві, ्टर्, _уочи_
  { {0xfc3f0020,0x44290006,0xb97b0009,0x657a03dd}},	//   _phí_, toa_, _גרוז, _meth
  { {0x317e03de,0x7a3d0025,0x9ee90012,0x99940030}},	//   latz_, rète, _نفعل_, _češi_
  { {0x1a5b0003,0x6296002c,0xd00c000b,0x442903df}},	// [530] اشرة_, guyo, _תּוֹ, roa_
  { {0x645a0108,0x9f4b0066,0xf77f0054,0x442903df}},	//   _outi, nkcí_, laç_, soa_
  { {0xe8e0008a,0x7a300006,0x3178003e,0xfc3f001a}},	//   ười_, jätu, órzy_, _thí_
  { {0x389b000b,0xa09b0009,0x7ce80009,0x825b0012}},	//   ריאנ, ריאט, _הַשֶ, _مؤسس_
  { {0x7c2900bd,0x539a000b,0x62860010,0x20190061}},	//   voer, _דירו, škoj, insi_
  { {0xdc3c001e,0xa87b0012,0x2ba60011,0x6d470031}},	//   kšēj, _محرر_, क्सा, _újak
  { {0x8ccc0037,0x69d500f1,0x44f3001a,0x4429001a}},	//   हियो, _inze, ụ_, _ưa_
  { {0xfbdf008a,0x69c5000e,0xd0100012,0x645a03e0}},	//   _tiêu_, ldhe, _كلّ_, _duti
  { {0x0ae60015,0x200f009b,0xe7dd0011,0xe1f903e1}},	//   ждый_, migi_, यानप, иги_
  { {0x78a90001,0x8a05002d,0x200f01ea,0x888503e2}},	//   аког_, ізне, ligi_, олож
  { {0xf9920093,0x32f40020,0x7a30004a,0xdc3c001e}},	//   ורי_, ày_, mätt, gšēj
  { {0x6296003a,0x69dc006f,0x81bc001e,0x44290028}},	//   yuyo, örer, slēp, _ða_
  { {0xddc2001e,0x200f0051,0xe9d90083,0x69d503e3}},	//   lpoš, iigi_, _вкл_, _onze
  { {0xf3f1008a,0xdce80066,0x3a240024,0x6b9b005e}},	//   ện_, _nedě, _еміг, lgug
  { {0x2c55001e,0x5cac0009,0x2ba60011,0x69c3008e}},	//   _tādu_, ְׁמַ, क्वा, _iane
  { {0x69d503e4,0x6b9b0051,0x6aa400c1,0xf77f03e5}},	//   _anze, ngug, ttif, caç_
  { {0x2c55001e,0x63b60028,0x6aa4002a,0x261a0037}},	// [540] _kāds_, reyn, utif, _बदली_
  { {0xea000020,0x69c303e6,0x6296003a,0x238c0010}},	//   _thấy_, _jane, ruyo, mėjų_
  { {0x20dc0029,0x69c303e7,0x02b60011,0x9b760012}},	//   pšiť_, _mane, _अन्न, _واحص
  { {0xe29a03e8,0xc66a004c,0x99850030,0xe7dd0011}},	//   _кам_, ашке_, kolů_, यायप
  { {0x645a03e9,0x777b0061,0x26cd0164,0x13b70009}},	//   _suti, _deux, _creo_, _והכל_
  { {0x62860010,0x8c66002d,0x7c360028,0x7aeb0032}},	//   škok, отид, llyr, ägte
  { {0xf77f003a,0x63a903ea,0x4ddb0009,0x8cb70012}},	//   yaç_, ffen, יחסו, قديس_
  { {0x7a3403eb,0x628403ec,0x26c0008e,0x238c0073}},	//   màti, osio, _osio_, kėjų_
  { {0x32f4001a,0x442f000e,0x7a3002fe,0x9e650012}},	//   ùy_, _dkg_, bätt, _فالن
  { {0xc3330093,0x094a0146,0x3ebb000b,0x51f8002d}},	//   ווח_, ични_, _דצמב, сною_
  { {0xf8160020,0x645a0006,0x69b7000b,0x61e30052}},	//   ước_, _uuti, חליף_, önli
  { {0x317e0052,0x69c5000e,0x2fc6002c,0x628403ed}},	//   satz_, zdhe, ndog_, ksio
  { {0x7a2f024c,0x0aba0003,0x69c303ee,0xf77f03ef}},	//   tøtt, _خطاب_, _fane, raç_
  { {0x3ea6001e,0xfba60037,0x81f80003,0x683f001e}},	//   itot_, क्रम, _دفتر_, _jūdz
  { {0x271c0020,0x1bd50014,0x80270003,0x71260012}},	//   ỉnh_, повя, _وربم, _برشل
  { {0x683f0333,0xdfd1000a,0x60240001,0xe0fb0009}},	//   _lūdz, _أية_, _одја, _כלול
  { {0xec09001a,0x27e9000d,0xe4510009,0xaabc0011}},	// [550] iếp_, _ioan_, תֶם_, ्टिक
  { {0x78a50028,0x27e9001a,0xdb0003f0,0xef650060}},	//   tthv, _hoan_, lemó, ğımı_
  { {0x9f400065,0xd7590003,0x55ba000b,0x3ea6001e}},	//   _hlið_, ملات_, _המתו, etot_
  { {0x27e903f1,0xd91b0009,0x9ed9003c,0x200f005e}},	//   _joan_, סואל, ймет_, uigi_
  { {0x7bda000b,0xf65f0028,0x15ff0037,0x200f00c1}},	//   _הקרו, kvæm_, _उतार_, rigi_
  { {0x7c2d007d,0x8e08002d,0xdd910003,0x27e903f2}},	//   loar, онів_, روع_, _loan_
  { {0x7a3003f3,0x3fb70003,0x69c50097,0x69c303f4}},	//   rätt, _وإرس, _óhei, _rane
  { {0xc2c5000a,0x7a3003f5,0xcfb40014,0x644203f6}},	//   كيبي, sätt, _обсъ, _choi
  { {0x44240003,0x69c10028,0x63a903f7,0xd5bb03e1}},	//   بروف, _óles, rfen, _все_
  { {0x238c0010,0xfad60009,0xbef80012,0x1306003c}},	//   vėjų_, פותך_, _برفض_, яный_
  { {0x69c30005,0xf865002d,0x26040012,0x63a90032}},	//   _vane, явно, _تولّ, pfen
  { {0xb4d70037,0x60160010,0xe53a0009,0x6d3a0009}},	//   ामी_, kšme, _התער, _התענ
  { {0x4dd60024,0x69c303f8,0x644903f9,0x7c2d03fa}},	//   півф, _tane, mmei, doar
  { {0x7c2d000d,0x2c55001e,0x82370012,0xa1c40024}},	//   eoar, _tāds_, _برصا, _обід
  { {0xf1b20093,0x8cce0037,0xdb0b0002,0x79810052}},	//   _נסה_, थियो, _tagó, malw
  { {0x628403fb,0x7c2d000d,0x683d0066,0x74160012}},	//   tsio, goar, lédn, أورا
  { {0x57fb000b,0xd7fb000b,0x62840010,0x6ffb0009}},	// [560] _ללקו, _להקל, usio, _להקפ
  { {0x3f8200c6,0x7d270031,0x60c90035,0x7a3401a0}},	//   laku_, érsé, _ņema, tàti
  { {0x23bd0044,0xd6250003,0x64490051,0x5577000b}},	//   ्याद, _تعيي, kmei, _מעין_
  { {0xca29000b,0xdb1d0066,0x7a300052,0x7882000e}},	//   אם_, _zasí, täts, _hívá
  { {0x7882000f,0x64490051,0xf3f1001a,0xcf260012}},	//   _kívá, dmei, _cụm_, أرضي
  { {0x7bc603fc,0xeb3b000b,0x2bd10037,0x6f020070}},	//   _haku, _לעכש, _दोबा, rzoc
  { {0x3ea60006,0x3243002d,0x7bc6002c,0xa2c40037}},	//   stot_, _черг, _kaku, रिक्
  { {0xbc670003,0x3f8202a1,0xa2c80011,0x22ae0035}},	//   أمين_, jaku_, ़िल्, pēkā_
  { {0x7bc60101,0x6b800065,0xf1e00011,0x9bb70009}},	//   _maku, ramg, नापन, להקה_
  { {0xeaaf0003,0x7bc600b6,0x6e2e000e,0x4efb0009}},	//   اعي_, _laku, jobb, _ההמו
  { {0xdfd10012,0x6568016d,0xd7950048,0x6e2e03fd}},	//   نيد_, _ifdh, минъ, dobb
  { {0x04db0093,0x1ae60014,0x3f8203fe,0xec4a003c}},	//   _לקבל, _ноем, gaku_, _узел_
  { {0xf3f10020,0xa3c00044,0xe66702ad,0xeb970048}},	//   ệm_, ंजन_, ятно, _хич_
  { {0x61140046,0x91e303ff,0x52d70009,0x53da0011}},	//   _одлу, _поче, _מודע_, भावश
  { {0x7c2d007d,0x680b0002,0x657e00b6,0xa4d40024}},	//   toar, iędz, _deph, норі
  { {0x03c40014,0x5454010b,0x80a30012,0x6c540400}},	//   нсум, евст, _أمين, ексу
  { {0x7c2d0401,0x92a40034,0xdd0c0034,0xba55004c}},	// [570] roar, ółpr, góła, двај
  { {0x5a340046,0x68380013,0x7c2d000d,0x7e6d0402}},	//   енут, bídk, soar, _itap
  { {0x7c2d007d,0xad3a002d,0xdb0b0028,0xf8b90012}},	//   poar, _квiт, _lagð, تهاب_
  { {0x27e9014d,0x2d9c0163,0xb5fb0028,0x68360017}},	//   ðan_, _över_, ppás, tádi
  { {0x6fa50037,0x7e69000d,0x9e640024,0x62490403}},	//   _कानू, _împă, евід, _džor
  { {0x7bc60404,0xfe700012,0x2d830405,0xddc4004b}},	//   _zaku, ادن_, naje_, _itiţ
  { {0x64580061,0x64490051,0x25de0011,0xfdf80009}},	//   _évit, tmei, खाती_, הצגת_
  { {0x69d800c5,0xeb990406,0x9cd80009,0xf7730012}},	//   _anve, ции_, לווה_, _سار_
  { {0xdcfc009b,0x644901f8,0x680b0034,0x3f820407}},	//   varč, rmei, będz, vaku_
  { {0xe2a60028,0xa9e40003,0x42090024,0x08890306}},	//   æðin_, ّثَن, інно_, обой_
  { {0x39450094,0x02ba0037,0x22a3001e,0x7c3a0097}},	//   ьног, _उन्न, lūkā_, ðbrö
  { {0x6d410408,0x7bc7001e,0x645e0409,0x69d8040a}},	//   _izla, ējus, _rupi, _enve
  { {0xf8c6000e,0xa2e40024,0xfbda0011,0x63bb040b}},	//   óért_, _поїд, भारम, meun
  { {0x2bbd0044,0x8d760012,0xdd920012,0x7bc6040c}},	//   ्यवा, باحا, ضور_, _saku
  { {0xb80a0003,0x7bc6040d,0x63ad040e,0x7e6d040f}},	//   _ويتم_, _paku, ffan, _etap
  { {0x680b0002,0x645a0054,0x487a0009,0x89360009}},	//   zędz, ítiq, _וטקס, _קרקע_
  { {0xf412000b,0x62860410,0xc1ea027f,0x11da0012}},	// [580] דפן_, škov, одаж_, يورة_
  { {0xfe46002d,0x68380411,0x7c290412,0x2aa60064}},	//   _інно, mídi, čera, rôb_
  { {0xafe6002d,0x106a0015,0x76400066,0x7bc60413}},	//   можл, цией_, ůmys, _taku
  { {0x63bb0414,0x680b0034,0xd6d90034,0xdfd00012}},	//   jeun, wędz, _szła_, طيت_
  { {0xa3e10037,0x7de60024,0xf5e60024,0x63bb0415}},	//   दान_, дійд, дійм, deun
  { {0x63a200c1,0x7bc90052,0xf1b80009,0xaa460024}},	//   _scon, edeu, _מֶֽל, _цегл
  { {0xdb0b0028,0xbc670012,0xf79a0012,0xacf80198}},	//   _sagð, ومون_, _ونسب_, янку_
  { {0x69c70416,0x828a00de,0x6143004c,0x683d0417}},	//   _zaje, особ_, _реса, gédl
  { {0x752d003a,0x680b0002,0xf6970012,0x22580418}},	//   ğaza, pędz, _ينفع_, _kirk_
  { {0x6b840051,0x24f60063,0x27e60419,0x64b60012}},	//   haig, _очер, ljon_, _يحار
  { {0x63ad00a2,0x72330003,0x7e6d041a,0xd4c60012}},	//   yfan, خريط, _stap, _تغذي
  { {0xb8e60044,0x628b000e,0x68e3041b,0x7e60041c}},	//   _उन_, ágok, ändi, _kump
  { {0x2905003a,0x41e60012,0x2bbd0011,0xd839001b}},	//   azla_, _يستف, ्यरा, juče_
  { {0xc1c80037,0xbb3b000b,0x69d8041d,0x828b0009}},	//   रयोग, _ועדי, _unve, _וְהֶ
  { {0x63ad0065,0x7e60041e,0xebc70001,0xe534003c}},	//   tfan, _lump, мљан, верь
  { {0xeac80020,0x2d83041f,0xa0080003,0x44220002}},	//   _kỹ_, saje_, _يقول_, _cjk_
  { {0x26c50039,0x27e6000e,0x877c0009,0x68380420}},	// [590] ālos_, djon_, _ואחי, cídi
  { {0xeac80020,0x63ad0421,0xa2c40011,0xa2940024}},	//   _mỹ_, sfan, रिज्, тафі
  { {0x6b84007a,0x61e7006f,0x63ad0422,0xf1a40048}},	//   baig, öjli, pfan, ъртн
  { {0xf7700003,0xfe710012,0x749a0009,0x7e600423}},	//   لاه_, هدت_, _צירפ, _bump
  { {0xdb1d0424,0x644d0108,0x6d410002,0x7e600425}},	//   _ansö, mmai, _szla, _cump
  { {0xc27a000b,0x7a2b0052,0xa5940014,0x2fc90070}},	//   _מרשי, hütz, връщ, _laag_
  { {0x63bb00bd,0xdce3001e,0x271b0011,0xc57c0009}},	//   teun, manī, नपुर_, חרות
  { {0x2d810051,0xee3f0029,0xdd580009,0xdb1d0030}},	//   _lehe_, dtým_, ובוט_, _zasá
  { {0xb065004a,0x17f80012,0x9dab0048,0xc6a40426}},	//   kyää, _غرفة_, _мъжа_, _архи
  { {0xc5fb0003,0x6b84000e,0xdb040017,0x89a9010c}},	//   _بعرض_, zaig, nfiá, чков_
  { {0x07a6007c,0x6d410039,0x83fc0027,0x86080012}},	//   нанн, _uzla, _suđe, _تقلق_
  { {0x60da000e,0xc4760009,0x73c50012,0xcc760009}},	//   _átme, _נתנו_, _سيتم, _נענה_
  { {0xbbbd0044,0xdce10010,0x8f9a0009,0xbf9a0009}},	//   ्यीक, _pelė, הירי, הירש
  { {0xd839001b,0x6b840032,0x27ed005e,0xceb20009}},	//   vuče_, waig, _loen_, איך_
  { {0x27ff00a2,0x62860427,0x6b840010,0xc5f20009}},	//   _olun_, škot, taig, נדל_
  { {0x27ed0119,0xfc1a0012,0x7c3b020d,0xd4910081}},	//   _noen_, أقرب_, nlur, ờn_
  { {0x7c3b000d,0x69960109,0x62890428,0x6b840429}},	// [5a0] ilur, ерех, nseo, raig
  { {0xe7ac0044,0x1677000b,0x41c60012,0xa2d30012}},	//   ट्रप, _רגיל_, عقاق, ديكت
  { {0x22580028,0x7d7b000b,0xdfda0048,0xdb1d0031}},	//   _virk_, _מניו, зъл_, _vasá
  { {0xf9890009,0xe1080009,0x08090012,0xc6a6042a}},	//   מר_, וּנָ, وزني_, ерки
  { {0x27ed00bd,0x27e6000e,0x4420042b,0xf7770009}},	//   _doen_, rjon_, mni_, געני_
  { {0x44320101,0x27e6042c,0xfcc60001,0x7c3b0190}},	//   loy_, sjon_, ељим, elur
  { {0xc5f3000b,0xeac8001a,0x7c3b0028,0x4420042d}},	//   רדו_, _sỹ_, flur, oni_
  { {0x2bba0003,0x4420042e,0xcb0a0014,0x7c3b0028}},	//   ساعة_, nni_, зход_, glur
  { {0x61ee0119,0xb4bd0011,0x6ec50012,0xe3af0012}},	//   _kobl, _इन्_, _لتلق, صري_
  { {0x22580065,0x44ce003e,0xd8f8002d,0x84e60015}},	//   örk_, _tę_, дної_, _позж
  { {0x7a2b008b,0x5a17000b,0x4432002c,0x0217000b}},	//   tütz, תקין_, koy_, תחים_
  { {0x6d5e002c,0x7c3b042f,0x80f5000b,0x889b000b}},	//   _agpa, clur, דֶשׁ_, הבטי
  { {0xd6d801d4,0x69dc0227,0x8c430430,0xee3f03a7}},	//   нтр_, _onre, _сеце, stým_
  { {0x63a60431,0x94770012,0x30a60024,0xaacd0011}},	//   _ackn, فدرا, _зрив, ़िरक
  { {0x44200065,0x11e90003,0xdce30035,0x9c470223}},	//   fni_, _تعني_, vanī, ехал
  { {0x493b000b,0x69dc0052,0x69ca0432,0x3c0c0030}},	//   _מגוו, _anre, _hafe, těvy_
  { {0x5a350014,0x600c000b,0xa2940024,0x2369004b}},	// [5b0] внат, _מִזְ, латі, rcaj_
  { {0xf2040024,0x20fc0081,0x44200433,0xa91c0064}},	//   ляхо, ỏi_, ani_, naľo
  { {0xdcfc001e,0x718b0009,0x82340012,0xec680048}},	//   parā, לְאַ, ارقا, _пряк_
  { {0xe7190003,0x69dc0207,0x6d45009b,0x87e40434}},	//   ويات_, _enre, _izha, люче
  { {0x539a0093,0xf7700012,0xcee80012,0x02bc0011}},	//   _קישו, صان_, فرون_, ्टोन
  { {0x27e00039,0x44d1007a,0xdce80039,0xceb4000b}},	//   ķina_, _ką_, _nedē, ריס_
  { {0x27ed0070,0x7c3b000d,0xdb040028,0xdce1001e}},	//   _toen_, tlur, leið, _ielī
  { {0x7bcd0065,0xa158002d,0x19580015,0x04dc0009}},	//   ndau, _часу_, _часы_, לקול
  { {0x2fc00051,0x24800027,0x7c3a0061,0x1ef80012}},	//   õige_, ćima_, îtri, _كعكة_
  { {0x929d0002,0x7c3b0028,0x44200435,0x69ca0436}},	//   szło, slur, zni_, _cafe
  { {0xa3e10037,0x7ff60012,0x62890437,0x44200438}},	//   दाद_, نسحا, sseo, yni_
  { {0x339b000a,0x2d870439,0xdb040028,0x5b15004d}},	//   _رخصة_, lane_, keið, _имет
  { {0x76480006,0x20fc001a,0x4420043a,0x2d87004b}},	//   _yhdy, ải_, vni_, oane_
  { {0x7bcb03eb,0x44200002,0xa6e30028,0xca96000b}},	//   _hagu, wni_, æðas, _ידני_
  { {0x2aab00c5,0x7bcb0167,0x15f40037,0x4432043b}},	//   løb_, _kagu, _अवसर_, toy_
  { {0x4420043c,0x3e66043d,0x69ca0060,0x2d87043e}},	//   uni_, _tôt_, _zafe, hane_
  { {0x6b840005,0x09fa0003,0x66060015,0x4432043f}},	// [5c0] _õige, وفرة_, _аппа, roy_
  { {0xfe9b0093,0x9f440054,0x60d50002,0x7bdd0440}},	//   _קיימ, _romà_, _brzm, _ensu
  { {0x7af6004a,0x18a60015,0x7e64004a,0xd5fb0009}},	//   syyt, таем, _huip, _חפיר
  { {0xef1a0047,0x66010051,0xdb040028,0x937a0012}},	//   мме_, _allk, beið, _تصدر_
  { {0x5f060014,0xf62a002d,0xc1780010,0x7e2a002d}},	//   ъзда, міки_, ybė_, міка_
  { {0x998c0066,0x68380017,0x2aab0058,0x69dc0441}},	//   vodů_, vídu, døb_, _unre
  { {0x6abc0044,0x7bcb0160,0x69ca0442,0xa91c0064}},	//   ्ट्र, _bagu, _rafe, vaľo
  { {0x6e960003,0xfc2f0003,0xab5d0002,0xccf30009}},	//   _للرا, يحي_, jeżd, שכה_
  { {0xf413000b,0x5a340406,0x7bcb0443,0xe737003c}},	//   יפה_, лнит, _dagu, _ает_
  { {0x32050444,0x683d0445,0x998c0030,0x7dc50012}},	//   ghly_, médi, rodů_, _متمك
  { {0x09f7000b,0xbb1b000d,0x319b000b,0xc19b0009}},	//   דמים_, _neîn, ובינ, ושיי
  { {0xdfd10003,0x63a40227,0x3f840446,0x1d1700af}},	//   حيح_, jgin, _jemu_, _בקבר_
  { {0x44d1003e,0x99ea0012,0x8a0600fc,0x683d0025}},	//   _są_, _يعتق_, _изде, nédi
  { {0x7bc00005,0x2731001a,0x0e340367,0x99160012}},	//   lemu, ỡng_, иняю, _لبعض
  { {0xab950447,0xde88001a,0x6d5c0029,0xde58002d}},	//   ливі, hị_, _úrad, тарі_
  { {0x7bc000b6,0x3957000b,0x260d001e,0x63a40448}},	//   nemu, _בשום_, ežot_, ggin
  { {0x36d50449,0x2019044a,0xdcee0035,0x1ec40012}},	// [5d0] _сопр, misi_, fabē, _نقيّ
  { {0xdb040065,0xe718000b,0x6618044b,0x44d1044c}},	//   reið, _שחזר_, jivk, _tą_
  { {0x7bc00179,0xab5d0034,0x2bab0011,0xa1150012}},	//   kemu, leże, _छापा, دوات
  { {0x2d87003e,0xba77000a,0xe894002d,0x4426009b}},	//   wane_, _لاست, раць, _njo_
  { {0xf3f10020,0x539a0093,0x4b7a0093,0xb2840015}},	//   ệu_, _אירו, _ראשו, _выск
  { {0xa2b80044,0xd1260003,0x68e3006f,0x2019004a}},	//   ्बन्, _هم_, änds, hisi_
  { {0x64b50003,0x2d87044d,0xdd8e0012,0x2019044e}},	//   احتر, rane_, سوي_, kisi_
  { {0x7bc0044f,0x2019003a,0x2d870450,0x5ac90451}},	//   gemu, jisi_, sane_, елим_
  { {0x2d870452,0x645d0453,0xe3b6003c,0x20190454}},	//   pane_, _misi, убы_, disi_
  { {0x1ddb000a,0xf9910012,0xe4d70012,0x3f9e0073}},	//   _تبرع_, حبة_, _لتصب, ėtum_
  { {0xa2ca0037,0x63a40455,0x5f060011,0xafdb0040}},	//   _सैन्, ygin, सैन्_, dløb
  { {0xbb1b000d,0x2d850456,0x889a0009,0x8ba40024}},	//   _reîn, _hele_, עברי, _виїж
  { {0xa3e70037,0x443f0457,0xc7d60009,0xfc300012}},	//   पान_, mlu_, אורי_, _بحل_
  { {0x22920003,0xaa920003,0x64a60458,0x20190459}},	//   _الوس, _الوث, лага, érir_
  { {0x69c100a1,0x645d0101,0x2d85007d,0x2fe60012}},	//   mele, _bisi, _mele_, _مكثف
  { {0x3ec9004a,0x2019045a,0x443f045b,0xb4250012}},	//   ättä_, cisi_, nlu_, لعقو
  { {0xc68f0003,0x8c430014,0xd36f0003,0x645d045c}},	// [5e0] _فِي_, сете, سهل_, _disi
  { {0x4439045d,0xdb0a0061,0x2d850284,0x7a300032}},	//   _eks_, énér, _nele_, lätz
  { {0xd5fb000b,0x69c1045e,0x34aa0288,0x3ea2045f}},	//   _נפטר, iele, _явно_, lukt_
  { {0xf3f10020,0xdc9b000b,0xc169000b,0x69c10460}},	//   ệt_, _איטל, לח_, hele
  { {0x68e3006f,0x69c10461,0xce360009,0xa3d70011}},	//   ändr, kele, ְאֶת_, ायन_
  { {0x69c1000f,0x2d850462,0x7a300052,0x629b0010}},	//   jele, _cele_, hätz, druo
  { {0x29550098,0x7bc002b7,0x443f0463,0x2a3b0009}},	//   _вътр, temu, flu_, _נעלמ
  { {0xab5d0002,0x68e30464,0x443f0465,0xa3ab0011}},	//   zeże, ånde, glu_, गभग_
  { {0x69c1000f,0xcff7000b,0xb21b0058,0x2d850031}},	//   fele, _עצמה_, _ivær, _fele_
  { {0x60c90039,0x32b70003,0xdcfa000d,0x2d850070}},	//   _ņemi, ادية_, _cetă, _gele_
  { {0x3a37000b,0xca370009,0xe0200011,0x629b0073}},	//   ררים_, רניה_, मचंद_, aruo
  { {0x3157000b,0x7c240027,0xa835004c,0x6d480466}},	//   טיין_, jnir, ремљ, _izda
  { {0xcaf6000a,0xa3e10037,0xddc9000d,0x20190467}},	//   _حساب, दार_, _uteţ, risi_
  { {0x201900c6,0x6828003a,0xd2500003,0x75eb003a}},	//   sisi_, rıda, _بنت_, _yüzy
  { {0xe4e4007c,0x0217000b,0x344b0001,0x443900b6}},	//   бітн, _תחום_, ечан_, _pks_
  { {0xfbdf008a,0xe7870001,0x17fb0003,0xc6e70024}},	//   _thêm_, _суко, _سرعة_, _біоп
  { {0x7a30004a,0x7c280061,0xdcf80010,0x9bc80012}},	// [5f0] läty, édra, ravę, دوقك_
  { {0x91e40001,0xd9990012,0x98a80011,0x69ce0468}},	//   бође, ئنات_, _कमाए, _cabe
  { {0x69ce008b,0x628d004a,0xa3d70011,0xa9080012}},	//   _dabe, ssao, ायम_, هيكل_
  { {0xe8d7000b,0xf093000b,0x628b000e,0xedc50011}},	//   טובר_, מנע_, ágos, _लघुछ
  { {0x66f70037,0x69c1045b,0x66e5025c,0x22590012}},	//   ुनिक_, yele, рола, _للحد_
  { {0x2bda0037,0xb88200d9,0x7c950469,0x44a50012}},	//   _मोबा, _číns, ариц, لمتق
  { {0xfdf8000b,0x69c1046a,0xf3e5002d,0x443f046b}},	//   רצות_, vele, ижко, tlu_
  { {0xdcfa007d,0x06f70011,0xc2c50012,0x7a30008e}},	//   _setă, ुनाव_, ليبي, däty
  { {0x443f046c,0xbda70003,0x0205046d,0x800402ad}},	//   rlu_, _محاو, изин, _учре
  { {0xd24e0003,0xcef40001,0x6b890051,0x7c87034a}},	//   وني_, _упућ, saeg, _буде
  { {0xd00a035c,0xd59a0009,0xd945046e,0xd12e0012}},	//   вене_, _יֹאכ, рени, ِمٍ_
  { {0xdcfe0039,0x2d8a002c,0x31360009,0xb9360009}},	//   _nepā, wabe_, ירתך_, ינתו_
  { {0x629d000e,0x79950002,0x09e500de,0xa0360009}},	//   ásod, _odzw, _волн, שארה_
  { {0x44d50333,0x7a30008b,0xd1670014,0x3ea2046f}},	//   _kā_, sätz, _съди, rukt_
  { {0x6b660098,0x2d8a0470,0x44d5001e,0xa2cd0011}},	//   иква, rabe_, _jā_, तिक्
  { {0x3ced015f,0x7afb0060,0x27e0020d,0x69ce0201}},	//   _अपने_, oyut, _unin_, _sabe
  { {0x883b007e,0xcb000037,0x69ce0471,0xd1860472}},	// [600] _בתקו, लैंड_, _pabe, илай
  { {0x9359002d,0xe1ff0028,0xb21b0262,0x41b30012}},	//   урсу_, _stór_, _svær, يمقر
  { {0x6f660001,0x661c0473,0x759b0009,0x859b0009}},	//   авез, mirk, _בייח, _בשיו
  { {0x661c045b,0xb5fd001b,0xb955004c,0x61fe0474}},	//   lirk, _bušo, стућ, skpl
  { {0xdfcf0003,0x683d0061,0x3ed40012,0xfe6f0012}},	//   بين_, cédu, إقتر, ودو_
  { {0xa613007c,0x2735001a,0x661c0475,0x94aa0012}},	//   оміч, ụng_, nirk, نطبق_
  { {0x6da30046,0xb21b0058,0xfce80012,0xb4e00011}},	//   ција, _tvær, افعي_, दमे_
  { {0x661c00b6,0xcfaa0012,0x4c9b0009,0x07a30476}},	//   hirk, _جاسم_, דבקו, _масн
  { {0x15f80044,0x52140047,0xbf9b000b,0xa3200011}},	//   ुसार_, йдит, _שימש, मपेज_
  { {0x44c7000e,0x7cdc000d,0x7178003c,0x9966004c}},	//   _fő_, _pără, ыбор_, штил
  { {0xd4910020,0xf9930093,0x661c00b6,0x69fb0009}},	//   ời_, חרת_, dirk, דליק
  { {0xa2b80037,0xdb1d000e,0x34fb0009,0xa3e10011}},	//   ्बद्, _vasú, _שהאד, दाः_
  { {0xc7b3000b,0x69a70011,0x7a30008e,0x661c0477}},	//   חבר_, _चाली, säty, firk
  { {0x18660046,0x2723001a,0x2abb0009,0x82330012}},	//   _књиг, ằng_, _סמוא, _وروا
  { {0x40940351,0xedf40044,0xe654007c,0xb8940003}},	//   _البر, _अवैध_, івсь, _البع
  { {0x5398002d,0x515b000b,0xab5d0002,0x415b000b}},	//   ився_, _בכוו, leża, _בדוג
  { {0x99670406,0x24580015,0xe1670001,0x1a5b0003}},	// [610] ател, рать_, ађен, نشطة_
  { {0xc73c000b,0x2b85001a,0xe2c80012,0xea770009}},	//   _בתחת, ặc_, ؤولو_, יגמר_
  { {0x6d5a0010,0xa3e70011,0xf2040024,0x27230064}},	//   žtar, पाद_, цято, kčnú_
  { {0x4e950003,0x80140024,0x7bc4004b,0x3f69004c}},	//   مشتر, офіц, ceiu, ћило_
  { {0x1de20044,0xa3ea0044,0xd6d9003e,0x201c0054}},	//   पांत, मान_, _była_, èvia_
  { {0xee38007c,0x6e920003,0x85780048,0x92a90034}},	//   ані_, ألوا, асът_, agłó
  { {0x69c50051,0xcd98000b,0xd6180012,0xbca80012}},	//   mehe, בדות_, جتنا_, لديك_
  { {0x69c50005,0x661c0052,0xf8b20009,0xf4120009}},	//   lehe, zirk, _משל_, ּ֤ה_
  { {0x6032001e,0xe7eb0011,0xe299004c,0x60060478}},	//   lāmg, टाना_, ћао_, _nóma
  { {0x44d50039,0xa2050479,0xcb120009,0x1a05047a}},	//   _tā_, спод, פלי_, спом
  { {0xa3d70037,0x3f89042f,0x629d01e9,0x3860005e}},	//   ायद_, _beau_, ásob, _piir_
  { {0x661c0052,0x69c50052,0x34b60009,0xd7ef0012}},	//   wirk, hehe, _לפעם_, ّكَ_
  { {0x7e61004a,0x661c047b,0x63a9047c,0xaac60011}},	//   _kilp, tirk, mgen, _रैंक
  { {0x99850003,0x3f9e003a,0x77430012,0xa2db0011}},	//   _الثو, ştu_, سَّم, निन्
  { {0x661c003a,0x61e3047d,0xddcd000d,0x61fc047e}},	//   rirk, _innl, _staţ, örle
  { {0xf3f10020,0x78fa000b,0x60dc03ee,0x644f047f}},	//   ệp_, _תפקו, ærme, _chci
  { {0xfe72000a,0x38b10029,0x63a90347,0xd4550024}},	// [620] _عدة_, lár_, igen, ітсь
  { {0x2002004a,0x6d41003a,0x69c501e0,0xcaa50012}},	//   lkki_, _oyla, gehe, تصفي
  { {0xa3d70044,0x04b60014,0xdcfe000d,0x395c006f}},	//   ाया_, _успя, _depă, ävs_
  { {0xa6e90020,0x20020006,0x4f0a0063,0xe7eb0011}},	//   _trự, nkki_, лнен_, टाया_
  { {0xadec015f,0x248d0039,0x6d41003a,0x60c9001e}},	//   ञापन_, ņemt_, _ayla, _ņemt
  { {0x44d80066,0x4733002d,0x6d410010,0x6032001e}},	//   _kč_, чніс, _byla, lāmd
  { {0xdd99002d,0x63a90480,0xf8780009,0xa0a30198}},	//   рші_, fgen, _כְּל, _нард
  { {0x3a3a0163,0x68150002,0xb2740447,0xc274004c}},	//   lopp_, ządz, олиш, олиј
  { {0xfbd3000b,0x93fb000b,0x644400fd,0x42540012}},	//   לתה_, טלקי, ilii, ينبر
  { {0x60060074,0x3eb90248,0x63a90481,0xbe1300ae}},	//   _róma, _ästa_, agen, _فوقع
  { {0xabaa0003,0x4ddb000b,0xeb9a0048,0x3f890025}},	//   _مهام_, _תחבו, _бие_, _peau_
  { {0x3942001e,0x82a600de,0xc4d30009,0x61e300b0}},	//   āks_, _гадж, _מגע_, _ennl
  { {0xab5d003e,0x60dc0058,0xa3e70037,0x501b0009}},	//   leżn, ærmb, पास_, רוכו
  { {0xddcd0002,0x862701d4,0xcd740048,0x38b10482}},	//   _uważ, сьме, згръ, bár_
  { {0x4c98000b,0x55590048,0x9f4401a0,0x69c50483}},	//   יֹּא, равя_, _comú_, vehe
  { {0xcc77000b,0x321e0484,0x00770009,0x68150034}},	//   מעלה_, lity_, _פתחי_, sądz
  { {0x7a3d0108,0xe3b00003,0xeab00003,0x6b8d0070}},	// [630] mètr, عرف_, فعل_, raag
  { {0x32070485,0x99670209,0xddab0103,0x7e7d0486}},	//   óny_, стал, _стил_, mpsp
  { {0x094b010c,0x753a0032,0x321e008e,0x237f0034}},	//   учаи_, ützt, iity_, ybuj_
  { {0x69c5008b,0xad1a000b,0x248d001e,0x69da0028}},	//   sehe, _כותר, ņems_, _óten
  { {0x8e55002d,0x38b1000e,0x8f9c0009,0x8d650487}},	//   откі, zár_, רידי, овле
  { {0x56b80009,0x999e0073,0x171c0009,0xdc990488}},	//   צפון_, imtų_, נוגע, атиш_
  { {0xfbda0037,0x20020028,0x63a901e0,0xcc8602ad}},	//   _मोहम, ykki_, tgen, обще_
  { {0x6b840051,0x9f350024,0x58050012,0xdb0d01e3}},	//   _õigl, _дебі, _بورك, leañ
  { {0x7e61038e,0x23290129,0xab290489,0x4209004c}},	//   _tilp, ропи_, ропа_, инио_
  { {0x38b1000f,0x31250015,0xb5fd0027,0xb2360012}},	//   tár_, ждог, _mušk, يكيا_
  { {0x2903048a,0xd7ea0177,0x621a0009,0x63a90227}},	//   ája_, амне_, שותק, pgen
  { {0xa3ea0044,0x290b0002,0x38b10028,0x3ea0048b}},	//   माण_, ąca_, rár_, šite_
  { {0xd4910020,0x20020006,0x34c20044,0x2903009b}},	//   ần_, rkki_, शब्द, šja_
  { {0x27380020,0x27e0001e,0x2ca7002a,0x321e03e0}},	//   ứng_, ķini_, ound_, city_
  { {0xdbc70065,0x44290065,0xed5a048c,0x3e6f005e}},	//   töðu, fna_, ров_, _eüt_
  { {0xc4d20093,0x1c46002d,0x68360029,0x2407002d}},	//   וגל_, інам, hádz, онси_
  { {0xdbc70028,0xa3c90011,0xdb110025,0x7c29048d}},	// [640] röðu, ऊज़_, éfèr, iner
  { {0x7c290052,0x644401a3,0x6b8b048e,0x27e50035}},	//   hner, slii, _legg, ēlne_
  { {0x63af0006,0xd6d9003e,0x6444048f,0x55bb0009}},	//   ännö, _było_, plii, _דמיו
  { {0x7c3b0108,0x1eaa0012,0x44290490,0x7c290491}},	//   jour, لاتي_, cna_, jner
  { {0xa3e70044,0x62860066,0x6e3c0070,0xa8570009}},	//   पार_, škoz, oorb, קינה_
  { {0xa6e30065,0x2ba80037,0x3ecb000b,0x44200492}},	//   æðis, गलवा, שֶׁ֣, lii_
  { {0x25a000a2,0x2ca70065,0x1db20037,0x2d8e0052}},	//   ğil_, gund_, _जानत, rafe_
  { {0x44200493,0x321e0002,0x25a0003a,0x7c3b0061}},	//   nii_, wity_, şil_, gour
  { {0x6ab6003e,0x2489001b,0xe7f90011,0x9c870064}},	//   ntyf, ćama_, ूसरा_, _počú
  { {0x44200494,0xa2bb0009,0x44290495,0x2ca70496}},	//   hii_, סמיט, zna_, bund_
  { {0x104b0047,0x3cf60037,0xc173000b,0x321e0497}},	//   иями_, ीनों_, וחת_, rity_
  { {0x321e002a,0x4429006f,0x7c3b0440,0x1ae6003c}},	//   sity_, xna_, cour, _моем
  { {0x77640098,0x6e3c0260,0xcf930009,0xa3d70011}},	//   държ, forb, וטר_, ायर_
  { {0x44290002,0x2d8c0052,0x6b8b0070,0x40940012}},	//   wna_, _jede_, _zegg, _فلتر
  { {0xa3e70044,0x317b000b,0x2d8c0498,0xa4d40024}},	//   पाल_, _דרומ, _mede_, морі
  { {0x2d8c0262,0x80c70011,0x6ff40012,0x78a80040}},	//   _lede_, ़बरे, _يسيط, mudv
  { {0x416b0001,0x44290499,0xd839017b,0x69c80227}},	// [650] ајем_, rna_, juči_, oede
  { {0xa2b20037,0xdb110061,0x2d8c0260,0xd5b20011}},	//   _आमन्, éfér, _nede_, _जायज
  { {0x81bc0039,0x68360029,0x6024000e,0x18a4002d}},	//   tnēj, vádz, sőme, даєм
  { {0x2d910027,0x98b30027,0x69c8049a,0x4420049b}},	//   laze_, žeći_, hede, cii_
  { {0x63ad038e,0xb7dc000b,0x76c70003,0xf2070014}},	//   mgan, יקאי, تغال, _дяво
  { {0x63ad049c,0x69c8049d,0xe618002d,0xe7300012}},	//   lgan, jede, оді_, خصم_
  { {0x7c3b049e,0x68360064,0x7e6d016d,0xe3c50012}},	//   tour, rádz, _luap, كْثَ
  { {0x2ca7049f,0x63ad04a0,0xb8ff0011,0x73fb0009}},	//   rund_, ngan, ति_, יּ֖ו
  { {0x29ff0002,0x2d8c04a1,0x2ca704a2,0xa2d20012}},	//   ałań_, _fede_, sund_, فييت
  { {0x11d5000a,0x6b8b04a3,0x7c3b04a4,0xddc4001b}},	//   ستخد, _wegg, sour, _stiž
  { {0x38b503ee,0xcea90009,0x394504a5,0x61fc0248}},	//   når_, _תי_, яног, örla
  { {0x6e3c0052,0x69d504a6,0xdcfa0030,0x9c820030}},	//   worb, _laze, _letě, áčen
  { {0x63ad00c5,0x93270012,0x63bb04a7,0xa2e50264}},	//   dgan, _بران, mfun, _холд
  { {0x9c8204a8,0x2d8c0017,0xa2f6000b,0x69c804a9}},	//   ščen, úde_, _ממנה_, cede
  { {0x61420001,0x1d0701ef,0x40920012,0x442004aa}},	//   _пеша, пери_, _كلور, tii_
  { {0xb89a000b,0x68fc006f,0x25e20011,0x78fa0009}},	//   _הבקש, ärde, _टोनी_, _לפצו
  { {0x2fc00101,0x442004ab,0x06970012,0xd38704ac}},	// [660] _ibig_, rii_, _فنية_, яйте_
  { {0xa3e20037,0x6ab60002,0x4a4304ad,0x25db0011}},	//   _फोन_, rtyf, енув, _गोली_
  { {0x2d8c04ae,0xd5fb000b,0x5dfb000b,0xb5fb000b}},	//   _rede_, _הפיר, _הפינ, _הליכ
  { {0xde6d001a,0x46ea00de,0x69c80123,0xd0190024}},	//   _hươn, йден_, zede, офі_
  { {0x073a000a,0x69d50149,0xf8a80037,0x6d40003a}},	//   حساب_, _faze, _कम्प, şmad
  { {0x69d504af,0x6b840032,0xd839001b,0x02460012}},	//   _gaze, lbig, ruči_, _رَأَ
  { {0xdb0f0108,0x629d000e,0x2d85000e,0x63bb0052}},	//   _accè, áson, űleg_, ffun
  { {0x8cbd0037,0xde6d001a,0x69c804b0,0x929d0034}},	//   _शहरो, _lươn, wede, zyłe
  { {0x6b84002c,0x69c804b1,0x6296002c,0x61f8017b}},	//   ibig, tede, nsyo, _povl
  { {0x27e00039,0x320a0002,0x6faa0037,0x69c804b2}},	//   ķinu_, óby_, _काउं, uede
  { {0xb4c80037,0x6aa40358,0xdd7b000b,0x2ee000b6}},	//   ोटो_, hrif, _הטבל, _arif_
  { {0x62960101,0xe45a04b3,0x4420003a,0xc4c50012}},	//   ksyo, _уже_, _öi_, _تتكو
  { {0xf2060098,0x56940048,0x78a80040,0x2d910064}},	//   _няко, наят, sudv, taze_
  { {0x9c8304b4,0xd29b000b,0xa2db0037,0x3205002a}},	//   účov, _פשוט, निस्, ckly_
  { {0x49bb000b,0xc1bb000b,0x19bb007e,0xde6d001a}},	//   _המוס, _המוש, _המוב, _dươn
  { {0x6b840101,0xdfd10012,0x929d0034,0x69d50030}},	//   gbig, _شيخ_, syłe, _saze
  { {0x6aa4008b,0x8f9c000b,0xc6190015,0x979c000b}},	// [670] grif, _היחי, _моих_, _השחק
  { {0x20c80044,0x6f0f003a,0x63ad04b5,0xde6d0081}},	//   रबंध, ıncı, sgan, _gươn
  { {0x60320039,0x7fd5002d,0xe3c70010,0x55ba0009}},	//   lāma, ділі, ščių_, _ומתו
  { {0x290f0002,0x7af20030,0xdc880009,0x2c7104b6}},	//   ąga_, _šetř, _מְשָ, _rád_
  { {0xdcf8001e,0x16a9002d,0x2907013a,0x9ea90024}},	//   kavē, івки_, šna_, івка_
  { {0xc604002d,0x45d20001,0x68e1000e,0xb9c50012}},	//   нзій, вољс, _áldo, _تقسي
  { {0x24890027,0xd2500012,0x8cd30011,0x63bb04b7}},	//   ćamo_, _إنّ_, डिटो, tfun
  { {0xdfd40015,0xdb0f04b8,0x13090055,0x3a990198}},	//   _посы, _accé, жний_, отою_
  { {0x2d9e0028,0x35b500b5,0x05dd0011,0x17f80012}},	//   ótek_, _обар, मयाब, _عرفة_
  { {0x22560003,0x86c40012,0xe8100011,0x3eab04b9}},	//   وليد_, _سيمن, ासभा_, duct_
  { {0xc6090037,0x07a604ba,0x7c2d03ce,0x8fa600ac}},	//   वसीय_, манн, knar, мане
  { {0x7c940012,0xbb550012,0xde6d0081,0xa03a0012}},	//   _أشلا, _قناب, _sươn, تأخر_
  { {0xc9f50003,0xa3ea0037,0x7c2d009b,0xac06002d}},	//   _يستع, मार_, dnar, _інша_
  { {0x200d0054,0x09e40024,0xf1ac0011,0x3f820034}},	//   _llei_, _поін, _चाइन, dłuż_
  { {0x9e630046,0xe1f00003,0x3eb90070,0x442d04bb}},	//   тврд, _حسن_, atst_, one_
  { {0x443f04bc,0x9c7c01bd,0x442d04bd,0xdbf20030}},	//   nou_, _urče, nne_, přís
  { {0xde6d0020,0xc053000b,0x6aa40051,0x7c2901bd}},	// [680] _tươn, _בזה_, urif, čerp
  { {0x443f0013,0x2b8c001a,0x6296002c,0x64490052}},	//   hou_, ếc_, rsyo, hlei
  { {0x443f014a,0x851c0011,0x2006008e,0x200d04be}},	//   kou_, _भेंट_, tkoi_, _blei_
  { {0xa2db0044,0x6296002c,0x787a0073,0x442d04bf}},	//   निश्, psyo, _nįve, jne_
  { {0x629d000e,0x443f04c0,0x644904c1,0x200704c2}},	//   ásol, dou_, dlei, ênia_
  { {0x44ce0066,0xa2db0037,0x644904c3,0x01660012}},	//   _př_, निर्, elei, _يُحَ
  { {0xd5ed008a,0xa3ea0037,0x94aa002d,0x0caa002d}},	//   _quả, माल_, ітка_, ітки_
  { {0x443f0017,0x27e0001e,0x68e30058,0xaa7b0029}},	//   gou_, ķins_, ænde, _urýc
  { {0x61fc012b,0x6e23002c,0x3e7b004b,0xfbcf0012}},	//   _korl, binb, _câtă_, شتي_
  { {0x4efb0009,0xcb57000b,0x442d04c4,0xc3330009}},	//   _והמו, וספה_, ane_, כוח_
  { {0x25eb0037,0x644904c5,0xdfd10012,0x9e650012}},	//   चारी_, blei, هيد_, _ساكن
  { {0x443f04c6,0x60320035,0x60240031,0x0bd40012}},	//   cou_, tāma, tőma, _سيتح
  { {0x442404c7,0x61fc0070,0x64400010,0xdb24004a}},	//   mim_, _oorl, momi, äräy
  { {0x8a030014,0x6032001e,0x3eab04c8,0x929d0034}},	//   _изче, rāma, ruct_, syłc
  { {0x443f0020,0x64400051,0x718b0009,0x6ed50011}},	//   _ưu_, oomi, _וְחַ, _मैनु
  { {0xfc300012,0x889b0009,0xb89b0009,0x69da04c9}},	//   لحق_, _ובהי, _ובהש, ldte
  { {0xa3b60037,0xcd040066,0xba550001,0x7c2d04ca}},	// [690] _जान_, vněž_, евај, rnar
  { {0x443f04cb,0x45d5004c,0x442d04cc,0xd2b70009}},	//   zou_, _џонс, zne_, ולמת_
  { {0x39470058,0x8e380012,0xdb040031,0x644004cd}},	//   æns_, _تسير_, rgiá, komi
  { {0x64400010,0x443f0017,0x155a000b,0xa2a70037}},	//   jomi, xou_, _מכתב, _चिप्
  { {0x9f400065,0x3d170037,0x937a000b,0x38b8000e}},	//   ðið_, _भेजे_, _מטרת, hér_
  { {0x7bc20036,0x442d003e,0xc3320093,0x9f59006f}},	//   _abou, wne_, _תוך_, ckså_
  { {0xe3b1000a,0xfdf8000b,0x443f04ce,0x6aad0097}},	//   هرة_, וצגת_, tou_, luaf
  { {0x442d007d,0x61fc003a,0x6e23006f,0x644004cf}},	//   une_, _zorl, sinb, gomi
  { {0x78ba0033,0x442d04d0,0x8a0504ad,0x645b04d1}},	//   ettv, rne_, езпе, rmui
  { {0xe1f1000a,0x5d840003,0xa2a70037,0x9c8204d2}},	//   اسة_, _للكل, _चिन्, ščan
  { {0x69d800a2,0x6594007c,0x2d87009b,0x38b80058}},	//   _dave, _раху, mbne_, gér_
  { {0x68fc006f,0xf649000b,0x2be50011,0xa3b60011}},	//   ärda, _הצ_, काओं_, _जाय_
  { {0x7ae204d3,0xef120009,0x69d804d4,0x2ac30035}},	//   _grot, ָּר_, _fave, nībā_
  { {0xa3d70037,0xdd920003,0x2d9e0061,0x8afa0009}},	//   ायक_, طور_, ûte_, _מהני
  { {0xd00a0046,0xa3b60011,0xddc90412,0x7bd9016d}},	//   _неке_, _जाम_, _otež, _kawu
  { {0xb6020013,0xe73a0015,0xd91a000b,0xccf20009}},	//   _žádo, _ней_, _מוצל, נכן_
  { {0x1f66002d,0x52aa02ac,0xfaa304d5,0x437504d6}},	// [6a0] _яким, явам_, лато, туст
  { {0xa3b10037,0x7c24004a,0x442404d7,0xe9d704d8}},	//   फ़्त_, siir, zim_, нку_
  { {0xa3ea0098,0x4424003a,0x1bea0014,0x61fc04d9}},	//   _една_, yim_, _едни_, _vorl
  { {0xa3ba0037,0x442404da,0x61fc04db,0xfbae0011}},	//   _आउट_, xim_, _worl, _टाइम
  { {0x442404dc,0x3f860004,0x2f970009,0x600601e3}},	//   vim_, rbou_, תכנן_, _cómi
  { {0x999a0034,0x29050073,0xf2d30009,0xfe790030}},	//   żyły_, kyla_, _געש_, _trůn_
  { {0x81bc001e,0x442404dd,0x8c1a0009,0xdc030030}},	//   inēt, tim_, ּוִי, ačís
  { {0x961d0044,0xd4670046,0xccf3000b,0x6440004a}},	//   _नष्ट_, није_, רכה_, uomi
  { {0x6d48003e,0x69d8007a,0x07b7000a,0x2ac3001e}},	//   _wyda, _pave, _سهلة_, cībā_
  { {0x442404de,0xe9f80024,0x644004df,0x38b804e0}},	//   sim_, єнні_, somi, tér_
  { {0x0b8a00e3,0x290a000f,0x9f440164,0x7ae204e1}},	//   _если_, ába_, _tomó_, _wrot
  { {0x929d003e,0x2897000b,0x69d8002a,0x2c7504e2}},	//   syła, עדכן_, _wave, _råd_
  { {0x93fb000b,0x7bcd04e3,0x69d804e4,0xabfb0009}},	//   _מלאי, veau, _tave, _מהאר
  { {0x8cd70037,0x29050066,0x5eeb0009,0xb8f40012}},	//   _मनमो, byla_, הַלְ, _لكتب
  { {0x248d0027,0x8c250012,0x58d40048,0xda650012}},	//   ćemo_, نفسه, _ройт, _شاهي
  { {0x21030029,0x59c60011,0x8cc20011,0x442204e5}},	//   nčiť_, _रॉबर, _लहरो, _cmk_
  { {0x6b840005,0xc3340009,0x7b740012,0x49cb003c}},	// [6b0] _õigu, דוּ_, اطفا, зуем_
  { {0x7bcd04e6,0x6d4104e7,0x78a804e8,0x21030064}},	//   seau, ülas, ordv, hčiť_
  { {0x5f950014,0x48ab0014,0xc078002d,0x6250004a}},	//   виет, ятам_, есії_, päon
  { {0xfbab0047,0x629d000f,0x200b0066,0xf4070012}},	//   _этой_, ások, nkci_, _أبدً
  { {0x6283001c,0x79a70001,0xc66b003c,0x21030064}},	//   ćnos, _прве, чшее_, dčiť_
  { {0x171c000b,0x62500051,0x2ac3001e,0x644d04e9}},	//   הודע, näol, rībā_, llai
  { {0xdce10002,0x6cd20003,0x25d8000b,0x69c10037}},	//   _oglą, لقوا, גוון_, र्णी
  { {0x7c84004c,0x644d04ea,0x8ca20011,0x5f740012}},	//   ћује, nlai, _गिरो, _ماكر
  { {0x3ced0011,0x68fc0248,0x961d0035,0x02bd0011}},	//   _अपके_, ärdn, _atņe, ्बेन
  { {0x2fcf04eb,0xf9910012,0x201c0035,0x85b8004c}},	//   legg_, جبة_, īvie_, _плус_
  { {0x6abb04ec,0xc1720009,0x93b5004c,0xd6560009}},	//   stuf, יחי_, _абец, _סיעת_
  { {0x7d070002,0xa0880009,0x764304ed,0x27ed0032}},	//   dyjs, עְתִ, lony, _jnen_
  { {0x93940003,0x441a000b,0x78a80070,0x9aa40003}},	//   _إجما, _קונס, ardv, _ممنو
  { {0xceb20009,0x6f060034,0xc5d50024,0x6b8904ee}},	//   ביך_, rykc, лісь, lbeg
  { {0xdcfc0039,0xdde4000e,0x201a0012,0xb1160012}},	//   varē, ésőb, _يتبع_, _لقوا_
  { {0x644d0061,0xd1640048,0x27ff0132,0x6b8904ef}},	//   glai, _съчи, _noun_, nbeg
  { {0xee3a04f0,0xab660014,0xab270103,0x62660012}},	// [6c0] _они_, твал, вота_, ناطق
  { {0x1757000b,0x6b890032,0x48e6004c,0x7d010032}},	//   _בספר_, hbeg, козв, älsc
  { {0x2d9804f1,0xdfda0048,0x7d070034,0x35c40011}},	//   mare_, дъл_, cyjs, ल्फ़
  { {0x6aa90119,0x661d007a,0x78fa007e,0x644d04f2}},	//   kref, _įska, ופעו, clai
  { {0x443204f3,0x5ed30012,0x7ed30012,0xc6d30012}},	//   mny_, لتوز, لزوا, لتوت
  { {0xa2a701e1,0x443204f4,0x8f1b000b,0x2d9804f5}},	//   _चित्, lny_, וונת, nare_
  { {0x44320002,0xd5e9001a,0x7f860003,0x61ee04f6}},	//   ony_, _qué, _للأن, _inbl
  { {0x6459003e,0x2cf20037,0x2000000d,0x69dc04f7}},	//   _chwi, _अपील_, _noii_, _hare
  { {0x69dc00ec,0x20d3007d,0x2d980163,0xd6cf0003}},	//   _kare, _aţi_, kare_, _وقف_
  { {0xd8f8002d,0x69dc0070,0x2a6a000e,0x76430002}},	//   еної_, _jare, öbb_, cony
  { {0x2d9804f8,0x47d50012,0x98c5001b,0x6aa904f9}},	//   dare_, هيدر, čuće_, aref
  { {0x27ff0065,0x443204fa,0x032604fb,0x3ea904fc}},	//   ðun_, jny_, _иден, šate_
  { {0xdcf50039,0x4ea70014,0x63a200c1,0x96f80014}},	//   pazī, ърна, _idon, веят_
  { {0x69dc0133,0xc0aa0003,0x2d9804fd,0x08fa0012}},	//   _nare, _قابل_, gare_, _يرغب_
  { {0x20d30003,0x6b840051,0x6d4004fe,0xdfd10012}},	//   _نتيج, _õigs, şman, _هيث_
  { {0xec3401b6,0x7d070002,0x764304ff,0xd0f70009}},	//   ансь, ryjs, zony, _ימות_
  { {0x7d070002,0xfe790066,0x36050003,0x5a3500a6}},	// [6d0] syjs, _prům_, _موظف, гнат
  { {0x2d980500,0x44320501,0x69dc0502,0x52140198}},	//   care_, any_, _care, адут
  { {0x26080044,0x5f770003,0x644d0503,0x44320504}},	//   _सकती_, ناشر, plai, bny_
  { {0xac19002d,0x44320002,0xd491001a,0xe10b0009}},	//   _чому_, cny_, ầu_, וּדָ
  { {0x7c3a000f,0x501c0009,0xf7700012,0xa3d60011}},	//   étre, וואו, زان_, ाजन_
  { {0x62720002,0x63a20505,0x3eaf0506,0x7bdd016d}},	//   _młod, _adon, rugt_, _hasu
  { {0x3f990066,0x7bdd0507,0x25a9003a,0xfbd10003}},	//   kasu_, _kasu, ğal_, متة_
  { {0x2d98007d,0x44290508,0x6aa90509,0x249e0064}},	//   zare_, nia_, tref, átmi_
  { {0x7bdd050a,0x36d40447,0x4429005e,0x04560012}},	//   _masu, _котр, iia_, دلية_
  { {0x44320002,0x2d98000d,0x386d050b,0x4ea40048}},	//   zny_, xare_, _hier_, _ърса
  { {0x4432050c,0x4429050d,0xabb50003,0x2d98050e}},	//   yny_, kia_, _مماث, vare_
  { {0x4429004a,0x999e0030,0xafdb0040,0x7bdd050f}},	//   jia_, botů_, dløs, _nasu
  { {0x539a000b,0x2d980510,0x765a004a,0x7e600070}},	//   _ניסו, tare_, _yhty, ïmpo
  { {0x06560003,0x44320002,0xb7c2001e,0x98e50003}},	//   انسح, wny_, ēģin, _مكتو
  { {0xd5b8001e,0x03a60511,0x44320512,0x7bdd0513}},	//   ļā_, ливо, tny_, _basu
  { {0x44e300a2,0x59c60037,0x69dc0514,0x2d980515}},	//   _mı_, र्नर, _sare, sare_
  { {0xc0170009,0x6250008e,0x62720034,0x44e30060}},	// [6e0] _תקפו_, säom, _głod, _lı_
  { {0x81a50003,0x44320516,0x36f70009,0xeef70009}},	//   لحمل, sny_, _עצים_, _עמיר_
  { {0x44e3003a,0xd00a0014,0x7c290517,0x3ea000b0}},	//   _nı_, неже_, kier, _hvit_
  { {0xe73a0047,0xb8dc0037,0x69dc0518,0xaaac0037}},	//   нее_, _आम_, _ware, _चिपक
  { {0x539b000b,0xc7a30014,0xdfcf0003,0xadf00037}},	//   _איכו, сичк, ثين_, चालन_
  { {0xceb3000b,0x386d0519,0x12eb0009,0x3f990034}},	//   מיד_, _eier_, _אַלּ, zasu_
  { {0x7c29051a,0x30d8000b,0x7ae4051b,0x6282051c}},	//   fier, _בַּע, lvit, _stoo
  { {0x79950002,0x28030066,0x7c29051d,0x8f970012}},	//   _zezw, ěrná_, gier, _منفذ_
  { {0xf5b60003,0xaae60003,0xd4030015,0x7bdb000b}},	//   _مصاد, اسبو, сящи, תקפו
  { {0xf2d3000b,0x7dc50003,0xddcd0066,0x660100b6}},	//   צעת_, _نتمك, _staž, _golk
  { {0x7c29051e,0xddcd000d,0x9c7c0029,0x09f7000b}},	//   bier, _luaţ, _krčm, אמים_
  { {0xaae6000a,0xb606001e,0x62720034,0x998c0073}},	//   _مستو, _lašā, _płod, todų_
  { {0xcf270003,0x6d40003a,0x7bdd051f,0xa2940024}},	//   ارجي, şmal, _rasu, _талі
  { {0xd2b70093,0x27310020,0x4429003e,0x44e3003a}},	//   _עלות_, ạng_, wia_, _yı_
  { {0xa2a70044,0xe97b000b,0x44290520,0x75140009}},	//   _चिह्, _אנוש, tia_, בַּע_
  { {0x60060097,0x44290521,0x8d5b00af,0x60c50522}},	//   _dóms, uia_, תכלי, _ähma
  { {0xd2bb0012,0x7ed70012,0x59c60011,0x290d0064}},	// [6f0] عارض_, _إزعا, र्भर, čkať_
  { {0x386d0033,0xdb160028,0x44290523,0x7c290524}},	//   _sier_, reyð, sia_, zier
  { {0x7bdd0005,0x6013003a,0xdcfc0010,0x7d7a000b}},	//   _tasu, _açma, darė, _בנתו
  { {0xb4fa000b,0x7c290052,0xe84b0003,0x79950002}},	//   _ספרי, xier, رجان_, _wezw
  { {0x6b8d00c6,0x6ec40003,0x539a0009,0x2d940029}},	//   mbag, متوق, _בירו, ždeň_
  { {0x7c29003e,0x6b8d0525,0x68e30526,0xbe640012}},	//   wier, lbag, ånds, مهني
  { {0x7c290527,0xd6180012,0x80790009,0x386d0528}},	//   tier, دتنا_, _יְ֭ה, _tier_
  { {0xa0c40012,0x7c2901e3,0x66010529,0x4b860048}},	//   _ديفو, uier, _wolk, айън_
  { {0x21f5007c,0x929d0034,0xe29f0097,0x6601052a}},	//   аїнс, myłk, éð_, _tolk
  { {0x7c29052b,0x20c5002d,0xcad80009,0xa3cc0011}},	//   sier, айом, רוזת_, _शॉन_
  { {0xbe640012,0xd3b90024,0x60320035,0x5bb9052c}},	//   _اهلي, _алеї_, lāmi, _алея_
  { {0xfc670014,0x7ae4004a,0xb4fa0009,0xf8b60009}},	//   _съзн, yvit, _בפעי, ספרי_
  { {0x636b00a2,0xc7d6000b,0x6032001e,0x7d01006f}},	//   _dönü, בורי_, nāmi, älsn
  { {0x91fc0333,0x6b8d00b6,0x6b9b052d,0x6289052e}},	//   rmāc, ebag, laug, mpeo
  { {0x3b960046,0xc3960001,0xf50300b3,0xd5ed0081}},	//   ијат, ијањ, озро, _quá
  { {0xe8e0001a,0x6b8d002c,0x3ea000eb,0x69c5052f}},	//   _hiệp_, gbag, šiti_, efhe
  { {0xf3f70020,0x27e000b6,0xd4670530,0x60320035}},	// [700] ợng_, _iain_, рите_, jāmi
  { {0x5e9b000b,0x7ae40531,0x0e9b0009,0x26060018}},	//   _שביק, rvit, _ששיל, _vôos_
  { {0xa3b60044,0x636b003a,0x27e000ed,0x6b9b0532}},	//   _जाल_, _yönü, _kain_, kaug
  { {0x4375002d,0xdb20000e,0xbc7b000b,0x929d0002}},	//   _гурт, ítóg, _שנכת, szły
  { {0x2fdf007a,0x27e00533,0x6aad0534,0xdcfc0073}},	//   _daug_, _main_, craf, tarė
  { {0x27e00535,0x4426048b,0x39420002,0xeca60001}},	//   _lain_, _smo_, ększ_, ајин
  { {0xadf70003,0x44260051,0xd4970015,0x4c940015}},	//   شروط_, _pmo_, ары_, щийс
  { {0xa3c90044,0xeca70037,0xef190034,0x99850030}},	//   ल्प_, _गिरफ, _leży_, filů_
  { {0xf1c60037,0xf1c20035,0xb8810018,0x76d30012}},	//   र्थन, pašā_, üíne, _ويفض
  { {0xdb0d0028,0xdb09003a,0xdebb0009,0x82330012}},	//   ngaá, zgeç, _בממל, ْرَا
  { {0xa3e6015f,0x9f910028,0xe3ba0014,0x80270012}},	//   पया_, _búðu_, _абе_, لرحم
  { {0xf1c60037,0x6d5a0536,0x6250008e,0x2ee9004b}},	//   र्तन, _izta, säoh, _praf_
  { {0x2bba0011,0x8c1b0009,0x787e0035,0xabfb0009}},	//   इलना, _בואי, _dīva, _שהדר
  { {0x99840012,0x59af0011,0x88c70030,0x6f1d0537}},	//   _الغو, _फ़ायर, _sněž, rzsc
  { {0xf5e4002d,0x26c2004a,0xac190538,0xda5b0009}},	//   ціям, atko_, гову_, _שכול
  { {0x200400c1,0xd3750001,0x2d9c0539,0x27e00503}},	//   _nomi_, слаћ, have_, _gain_
  { {0x6b8d00c6,0xf9930003,0xda780021,0x91870012}},	// [710] rbag, قبض_, аях_, لجام
  { {0x98da0044,0xd999000a,0xf8da0044,0x41b50003}},	//   _बनाए, انات_, _बनाय, إمار
  { {0x6aad003a,0x2907000d,0xe4e40024,0xa3d60011}},	//   sraf, âna_, _діян, ाजा_
  { {0x6aad053a,0x0ee20011,0xa25b0025,0xd7590012}},	//   praf, पिंड, _apôt, هلات_
  { {0x7c2d053b,0xa8580009,0x217b0012,0xa2670048}},	//   miar, ביאה_, _لحزب_, _въвл
  { {0x9c7c0027,0x929d0002,0x4d880012,0x7e240024}},	//   _grčk, syłk, لَهُ_, одіж
  { {0x4c920001,0x6b9b0068,0x60320035,0x20d400ae}},	//   пијс, taug, sāmi, _وتفج
  { {0x2d82000f,0xf538007e,0xa954002d,0xf77f003a}},	//   _őket_, ינוי_, _єкті, _üç_
  { {0xa3c90044,0xa3d60037,0xa7150001,0x3f150015}},	//   ल्य_, ाज़_, _удаљ, _удас
  { {0x6b9b053c,0x75280002,0xe1f90103,0xe6130012}},	//   saug, ździ, уго_, _بشر_
  { {0x62720034,0xafdb00b0,0x27e0053d,0x62890132}},	//   _płoc, tløp, _pain_, speo
  { {0x9f06000a,0x7d560093,0x6d40003a,0xa3c90037}},	//   موجو, _היעד_, şmak, ल्म_
  { {0x27e00006,0xdce300a2,0x201e007a,0x5285000a}},	//   _vain_, manı, ėti_, _التك
  { {0xe29f0065,0xdce300a2,0x62720002,0x64490227}},	//   áðu_, lanı, _włoc, loei
  { {0x7c2d0058,0x26c20002,0x0c790015,0x291e0002}},	//   fiar, stko_, исты_, czta_
  { {0x2d9c012e,0xdce3003a,0x442d053e,0x05550024}},	//   zave_, nanı, nie_, ітря
  { {0x38a3003a,0x26de001e,0x63a60028,0xf9920012}},	// [720] lır_, ātos_, ókni, كبا_
  { {0x9c82012e,0x2176002d,0xd24f0012,0xf1a90012}},	//   ščin, суар, ّنك_, لامه_
  { {0x38a300a2,0xcb09000b,0xdce3003a,0xf8aa0001}},	//   nır_, על_, kanı, увек_
  { {0x442d001e,0x68fc0248,0x2d9c053f,0xd0590024}},	//   jie_, ärdi, wave_, арчі_
  { {0x9f490065,0xdcfc0039,0xf62a002d,0xf7460015}},	//   ðað_, karī, ліки_, щедо
  { {0x442d0005,0x6b8200c1,0x97570009,0x38a30060}},	//   eie_, _sfog, זינו_, kır_
  { {0xdcfc0039,0xdce3003a,0xc19b0009,0x54e60012}},	//   darī, fanı, _תשלי, إستق
  { {0x5b140047,0x38a300a2,0x6d5a0066,0x2d9c009b}},	//   жмит, dır_, _vzta, save_
  { {0x3866006f,0x0aea0012,0x41e60024,0x60320035}},	//   mmor_, اربي_, біна, nāmu
  { {0xff17000b,0x7c2d00c1,0x38a3003a,0x867b0009}},	//   _הקמת_, ziar, fır_, _ערבו
  { {0x2bca007c,0x66050005,0xf8140020,0x19580047}},	//   _було_, _rohk, ược_, раны_
  { {0x39570093,0x3c77000b,0x3157000b,0xa157000b}},	//   משים_, _התאם_, מיין_, מביה_
  { {0x291e0540,0xf1d80011,0x7c2d0541,0x000000c4}},	//   szta_, ड़ान, viar,
  { {0xe84c0066,0x7f2b0009,0x09e3003c,0xdb0d0018}},	//   ětší, אֵלֶ, _ночн, lgaç
  { {0xe654007c,0xa99b0009,0x6c850012,0xee2e0024}},	//   ївсь, _גבור, تلزم, ьнi_
  { {0x3881007a,0x54550024,0x29370009,0x89370009}},	//   _nėra_, іват, _לאון_, _לרוע_
  { {0x24580015,0xda670012,0xdb0d0018,0x99990542}},	// [730] сать_, مائي, igaç, икат_
  { {0xdce3003a,0xff18000b,0xdd910003,0x442d0543}},	//   zanı, _לקחת_, _تود_, zie_
  { {0xa25b0026,0xdce3003a,0x7c2d0544,0x6d8c0009}},	//   _spôs, yanı, piar, _עָזְ
  { {0xc1c40037,0x9c7c0159,0x69d80064,0x9f550545}},	//   वभुग, _grči, ôver, овеч
  { {0x38a3003a,0x9f34002d,0xb9e70024,0x41e70024}},	//   zır_, пеці, _ліви, _ліва
  { {0x2d83003e,0xd9fd0037,0x442d0546,0x38a3003a}},	//   ncje_, _उचित_, wie_, yır_
  { {0xdce3003a,0x442d0547,0xed5900b3,0xeb910012}},	//   tanı, tie_, шок_, وظة_
  { {0xd2a90015,0x24090015,0x1d180009,0x6c350012}},	//   акие_, рнии_, מקור_, تفعا
  { {0xdce300a2,0x2d830002,0x13060015,0x0325002d}},	//   ranı, kcje_, жный_, юдин
  { {0x38a300a2,0xdce3003a,0x88c900de,0x442d0548}},	//   tır_, sanı, алов_, sie_
  { {0xf1b2000b,0x999e0066,0x5e440012,0xdce30060}},	//   וסי_, nitř_, _عَمْ, panı
  { {0xb9010044,0x7e7b0005,0xa3b60044,0x4c570003}},	//   _नई_, _kuup, _जाए_, _اضطر
  { {0xb7da000b,0x38a3003a,0xf7720012,0x6d580030}},	//   בקרי, sır_, باد_, _úvaz
  { {0x644f0549,0xf267004c,0xdcf50034,0x75e90031}},	//   _akci, _уђем, zczą, böző
  { {0xd24e000a,0xc5f2000b,0xdcf50002,0xd4f50015}},	//   _جنو_, ודם_, yczą, пяты
  { {0x69c50037,0x6ab60028,0x6e2e0031,0x69de054a}},	//   ़्री, tuyf, sibb, _óper
  { {0xfbd2000b,0x7ae9004a,0xa206024d,0xa3ab0011}},	// [740] ותן_, nvet, опад, कृय_
  { {0xe2460003,0x915f001a,0x63bb00b6,0x42560024}},	//   آخري, _sắp_, hgun, ітат
  { {0x69d90037,0x60260472,0x30a50024,0xe0da054b}},	//   नज़ी, оджа, зрів, рве_
  { {0xb8f20044,0x46ea0014,0x9c7c0107,0x8bb60012}},	//   _वह_, иден_, _urči, _بإدا
  { {0x4e0e0037,0xaad80037,0x8703003c,0x64410025}},	//   _हवाई_, _बैंक, дяще, élie
  { {0x6ce50044,0x11d60003,0xf1c60037,0xb4fe0037}},	//   किंग_, _بتحد, र्शन, _उपाय_
  { {0x9f450066,0x6fb60012,0x62720034,0x08c3004c}},	//   ělé_, _ومسا, _błon, _обрн
  { {0x61e30070,0x63bb054c,0xa6aa0012,0xbc670012}},	//   _aanl, ggun, _ناطق_, يمون_
  { {0x7ae9000e,0x75d60012,0x2d830034,0x62720034}},	//   gvet, _ويرا, ycje_, _dłon
  { {0x82f70093,0x3218003e,0x61e3003a,0x91ba0009}},	//   קציב_, óry_, _canl, ׁמִי
  { {0xb97b000b,0xb21b0028,0x717b0009,0x91bb0009}},	//   יניי, _stæk, יניס, סמטי
  { {0x68e30058,0x69ca0037,0x27e6054d,0xdce50064}},	//   ændi, स्ती, ndon_, _pehľ
  { {0xee3f0066,0x62500051,0xeb910009,0xc2c40012}},	//   krýt_, näos, _נָא_, _ريغي
  { {0x2e4b00a6,0x27e6008e,0x799c0034,0xdcfa0035}},	//   рямо_, hdon_, _nerw, _netī
  { {0x80c90037,0x7afd054e,0x2d830034,0xdb1f054f}},	//   _रहें, ästv, rcje_, seqü
  { {0x27e4023d,0x27e60550,0xdc8b0009,0x61e30060}},	//   _namn_, jdon_, יְמָ, _zanl
  { {0xa3cc0037,0x9b6b0014,0x61e3003a,0x799c00b6}},	// [750] श्य_, ршва_, _yanl, _berw
  { {0xd2510003,0x3eb90051,0x51f80024,0x20d60011}},	//   رنا_, must_, оную_, ठबंध
  { {0x21270020,0x3eb90005,0x7ae90551,0x4dda0009}},	//   ành_, lust_, zvet, _החתו
  { {0x69ce0552,0x69ca0037,0xc1570009,0x63a0001b}},	//   _ebbe, त्ती, חשבו_, jamn
  { {0xf770000a,0x3eb90051,0xfd4c001a,0xdbc60051}},	//   ناه_, nust_, _triề, tööd
  { {0xc27a000b,0x7ae9003a,0x62720002,0xd5b10012}},	//   _לרשי, vvet, _słon, رفع_
  { {0x1c0f0037,0xcd98000b,0x3eb9005e,0x62720034}},	//   _सवाल_, חדות_, hust_, _płon
  { {0x3eb900b4,0x6d3c000b,0x63bb0052,0xeb910009}},	//   kust_, יתונ, ugun, ךָ֙_
  { {0xeab10003,0x61e3002c,0x63bb0553,0x93fc0009}},	//   رعة_, _panl, rgun, שלחי
  { {0x3eb90554,0x321e0555,0x35b40024,0x7ae90556}},	//   dust_, ghty_, _обур, rvet
  { {0x61e3028e,0xa3bb0003,0x43750012,0x9a240012}},	//   _vanl, _ناشر_, _فهار, بعين
  { {0xd3b8002d,0x7ae9000e,0xe4d40012,0xe8f60557}},	//   _душі_, pvet, _تتكب, їля_
  { {0xdbd90065,0xf7720003,0x23760003,0xa3e60037}},	//   væðu, عاج_, _عمود_, _योग_
  { {0xa3c90037,0x7afd005e,0x32130081,0x59c20011}},	//   ल्स_, ästu, _ôxy_, _शायर
  { {0xdbd90028,0xed5a035b,0xf9fa0009,0x3c890009}},	//   tæðu, сов_, _להסמ, מָּ֑
  { {0x799c003e,0x6c360003,0x6aa40558,0x1c460024}},	//   _serw, أفرا, tsif, їнам
  { {0x3cdd0044,0x799c00c6,0xc8650003,0xdbd90028}},	// [760] _कैसे_, _perw, _تطوي, ræðu
  { {0xa3ab0044,0x6aa40559,0x7c3b0032,0x2cb80032}},	//   कृत_, rsif, hnur, purd_
  { {0x799c055a,0xc329000b,0x3d150037,0xc5eb000b}},	//   _verw, נו_, तनों_, _הַכֹ
  { {0xdcf50002,0x1eaa0003,0xd3da0012,0xe7160009}},	//   jczę, ماتي_, _ابدا_, ּחַר_
  { {0x799c055b,0x03770009,0x6f7b0009,0x17790024}},	//   _terw, _מתכת_, צְאו, ісць_
  { {0xf536000b,0x26c6004a,0xd49a00f5,0x7c3b055c}},	//   ּנֵי_, rtoo_, бри_, enur
  { {0x721b0009,0x80da0011,0x4420005e,0x621b0009}},	//   _פולח, _बनें, ohi_, _פולק
  { {0xb6030039,0x4420002c,0x6bd60003,0xa08b000b}},	//   īšan, nhi_, ستعر, _לְמִ
  { {0xade70037,0x27f70145,0x18670024,0xb6030035}},	//   _टोकन_, šení_, _хати_, ūšan
  { {0x3eb90005,0x39140001,0x63a0055d,0x2bac0081}},	//   vust_, дмор, samn, ớc_
  { {0x764e055e,0x69bd0011,0x3eb902a2,0x3ea60035}},	//   doby, _शारी, wust_, lsot_
  { {0x3eb90005,0x8fa40001,0x9f35002d,0xe759002d}},	//   tust_, наџе, демі, жимі_
  { {0xe6670014,0x6b9d055f,0x38850035,0x3f860018}},	//   зтво, _resg, _pērc_, icou_
  { {0xacf90560,0x3eb90561,0x68fc0248,0xa8a60488}},	//   онгу_, rust_, ärds, _ерик
  { {0x3eb90051,0x61f80070,0xb2290012,0xd6570009}},	//   sust_, _invl, _بأنك_, פילת_
  { {0x5c740098,0xb157000b,0x3957000b,0x3157000b}},	//   елст, _מסוג_, _משום_, _מיון_
  { {0x69da0562,0x8e840012,0xc7fa0009,0x5c370009}},	// [770] oete, _كليه, _וִיר, פרמן_
  { {0xdce7003a,0xdcf50002,0x644d0017,0x69da0563}},	//   sajı, zczę, soai, nete
  { {0xdb0d0028,0x320a00d9,0x91fc0035,0x20190073}},	//   ngaú, _doby_, emāk, ūriu_
  { {0x7985008b,0x69c8003a,0x44200564,0x98c5001b}},	//   schw, _öden, chi_, žući_
  { {0xa2a70037,0xcee80012,0x69bd0011,0xf7730012}},	//   _चिट्, كرون_, _शाली, راص_
  { {0x8afa000b,0xee38002d,0x02fa0009,0x12fa0009}},	//   _והשי, пні_, _ולשמ, _והשב
  { {0xd0d40098,0x3cdd0037,0x1d060014,0xa5060048}},	//   _поръ, _कैशे_, дещи_, деща_
  { {0x3ea90006,0x61e7000e,0xea890217,0x2b150024}},	//   _ovat_, _hajl, обил_, дьор
  { {0x69ca0037,0x37c40012,0x7aed0565,0x66120031}},	//   स्वी, _سيلف, nvat, ükkö
  { {0xb33b00a2,0x7aed000e,0xf8a90055,0x02fc0009}},	//   _geçe, ivat, овок_, מלחמ
  { {0x7aed0566,0x34940014,0xa3c80011,0x44200024}},	//   hvat, _захр, _लॉक_, _зi_
  { {0x7ad80011,0x5b15004c,0x7aed0567,0x99910034}},	//   _बैकअ, _омет, kvat, ózł_
  { {0x6d49000d,0x5f760012,0xddc10073,0xf7720012}},	//   şeal, بادر, _milž, ضاح_
  { {0x7a20000f,0x61e70568,0x7aed0558,0x32450012}},	//   _köte, _najl, dvat, _تنتف
  { {0x25fe0011,0x3ea90227,0x7aed0569,0x4420056a}},	//   लाती_, _evat_, evat, thi_
  { {0xb09a000b,0xc952000b,0xa09a000b,0x7a20006f}},	//   _ויקר, _שמה_, _ויקט, _möte
  { {0x0b170003,0x2eff0052,0xfaa3034a,0x7aed056b}},	// [780] وقفة_, äuft_, като, gvat
  { {0xe9d7007c,0xc1d80011,0x9f9d0097,0x4420056c}},	//   мку_, ड़ेग, læði_, shi_
  { {0x2d9e01a2,0x4999002d,0xd7e6002d,0x25e70037}},	//   _rete_, яття_, діло, _छोटी_
  { {0xb33b00a2,0x6d40003a,0x69da056d,0x2d9e056e}},	//   _seçe, şmas, zete, _sete_
  { {0xc7a30046,0x63b90002,0x61e70027,0x07a30001}},	//   тичк, ówne, _fajl, тачн
  { {0xdce80029,0xdd8f0012,0xdc8a003c,0x3f9f01e3}},	//   _vedľ, لوه_, осил_, _eeuu_
  { {0xdb190002,0xa1160012,0xa5c40011,0x68e30040}},	//   _obwó, _غورت, _राठौ, ændt
  { {0xd4670001,0x690b000b,0xe10b0009,0x44c80032}},	//   мије_, _וּמְ, _וּמָ, iß_
  { {0xe457000b,0xc274004c,0xd403056f,0xee3a0050}},	//   ויקט_, нлиј, тящи, _дна_
  { {0xf8d20044,0x6ffe000d,0x7ae2009b,0x63a40258}},	//   _सहाय, _făcâ, _vsot, hain
  { {0xd130000a,0x29180570,0xe8df001a,0x9f450066}},	//   امج_, ára_, _buộc_, ělí_
  { {0xe8df0020,0x63a40571,0x7aed0042,0xc1730009}},	//   _cuộc_, jain, yvat, כחת_
  { {0xd6d9003e,0x44c80052,0x6b960572,0xa3bf0011}},	//   _były_, eß_, dbyg, ूऍस_
  { {0x7bc00058,0xe731000b,0xaa570003,0x3e64008e}},	//   lgmu, אֵל_, _قلنا_, yöte_
  { {0x1bd50014,0x18970003,0x645c001e,0x49bb0009}},	//   новя, _قضية_, _īrij, _ומוס
  { {0x69ca0037,0xec68002d,0x3ea9013a,0xc4540012}},	//   त्री, друк_, šati_, نَّب
  { {0x44c80052,0xc0540009,0xeaf80012,0xcb340048}},	// [790] aß_, _בזק_, وركت_, ветъ
  { {0xdb000108,0xc2c4000a,0xe9d30003,0x42550012}},	//   ramè, ئيلي, ضغط_, رنار
  { {0xd131000a,0x31c40014,0x7aed01a3,0xe7c60011}},	//   دما_, ъств, svat, _वामप
  { {0x9516000b,0x63a40573,0x201900b6,0x27e90574}},	//   _נקרא_, cain, nksi_, _jaan_
  { {0x2019004a,0x27e90575,0xfbb60009,0x22840060}},	//   iksi_, _maan_, _אפרת_, _gök_
  { {0x6442004a,0xff18000b,0x56920001,0x8e080024}},	//   _ajoi, וקדת_, ћајт, мнів_
  { {0x64480025,0xf41f0248,0x25a10032,0x57b700ae}},	//   édig, _klä_, _mehl_, _يحرز
  { {0x5ba90001,0x3eb20010,0xc4f80003,0x1309002d}},	//   чким_, šyta_, بعها_, зний_
  { {0x9f9d0065,0xeb92000b,0xef540014,0x7c3a0576}},	//   væði_, נָה_, _акть, étri
  { {0x2019004a,0xbef80003,0x7a200052,0xf41f004a}},	//   eksi_, _ترفض_, _töte, _llä_
  { {0xf65f0058,0x79a80009,0x20890048,0x27e90227}},	//   rtæl_, וֹרַ, яйни_, _baan_
  { {0xcdc9015a,0xc1720009,0x59cf0011,0x80a00011}},	//   _לך_, טחי_, स्तर, _खबरे
  { {0xef170047,0x9f9d0065,0x27e9002c,0x6836001e}},	//   емя_, ræði_, _daan_, gšda
  { {0x20190577,0xfce60578,0xc6920009,0x443f0579}},	//   aksi_, ного, ראם_, lnu_
  { {0x22840163,0xa3cc0044,0xd46a0001,0x621a000b}},	//   _sök_, श्व_, зиве_, _מוסק
  { {0x27e900bd,0x6b89057a,0x7dd3003a,0x3c3a001e}},	//   _gaan_, nceg, lısı, tīvi_
  { {0x41b6057b,0xdd2f0066,0x443f057c,0x883b0009}},	// [7a0] есет, _měře, inu_, _מתקו
  { {0x2b9e001a,0x8e97000b,0x7dd30060,0x6aa90035}},	//   ắc_, _רדיו_, nısı, isef
  { {0x69c800a1,0xf1c60037,0x659b000b,0xdb00057d}},	//   _ödem, र्गन, _מייק, ramé
  { {0xad37000b,0x40560003,0xa2b20037,0xc1bd0037}},	//   _טניס_, رئاس, ेंद्, ्भुग
  { {0x68e30058,0xddc3000e,0x5b7b0009,0x201f004b}},	//   ændr, elnő, _מרכא, _dlui_
  { {0xd49a057e,0xc73b0009,0x7c24057f,0x41c70011}},	//   при_, התנת, lhir, _लायस
  { {0x443f0028,0x69c10027,0xf41f008e,0x2019008e}},	//   fnu_, dgle, _ylä_, yksi_
  { {0x66e6002d,0x2c610029,0x443f0580,0x59c20011}},	//   _поба, tóda_, gnu_, _शाहर
  { {0xdcea00a2,0xe7d5003a,0x99a40030,0xe3af0012}},	//   rafı, lığı, átům_, حرى_
  { {0x27e90581,0xf3ff001a,0xd5e90003,0x69c10582}},	//   _saan_, _nhãn_, _يعلن_, ggle
  { {0x3a370093,0x0dc90003,0x9f400028,0x39580058}},	//   תרים_, _تبقى_, _snið_, ærs_
  { {0x645b0583,0xb8d80037,0x443f0584,0x69c10585}},	//   clui, _चि_, cnu_, agle
  { {0x27e9004a,0x6e350032,0x6a660097,0x69c10032}},	//   _vaan_, tizb, eðfe, bgle
  { {0x7dd3003a,0xdb020018,0x6d5a0030,0xa3cc0011}},	//   cısı, _adoç, _kyta, श्र_
  { {0x64410108,0xf65f0028,0x69b90037,0xa4d40024}},	//   élio, ltæk_, _एफ़टी, лорі
  { {0xe7d500a2,0x515b000b,0xb6f50001,0x3c3a0035}},	//   dığı, _מכוו, _азиј, būve_
  { {0xc87f003a,0x61ea0097,0x6a660097,0x57b4003c}},	// [7b0] ışma_, _kafl, aðfe, _сбыт
  { {0x69de0586,0x28c40011,0xc73c0009,0xe9190024}},	//   gepe, लंपि, _מתחת, мозі_
  { {0x399b0009,0x999e0031,0x4c95004c,0x443f0587}},	//   פיאד, nitő_, _шинс, ynu_
  { {0x80d20011,0x7dd30060,0x69c10412,0x6e950588}},	//   _ठहरे, zısı, zgle, виду
  { {0x7dd300a2,0x9178001a,0x7ac700fa,0x443f0589}},	//   yısı, hời_, _ясне, vnu_
  { {0x3eb9002a,0x69de000d,0xc1780010,0xe618002d}},	//   irst_, cepe, ndės_, нді_
  { {0x443f058a,0xdb0d0028,0xd7950012,0x6d5a0034}},	//   tnu_, ngaþ, _للأخ, _cyta
  { {0x201f007d,0xcec10002,0x2ef50136,0x443f058b}},	//   _ului_, _pięć_, _избр, unu_
  { {0x04560003,0x69c10032,0x7dd30060,0xe2910012}},	//   خلية_, tgle, tısı, جذب_
  { {0x443f001c,0xd24e0003,0x645b0070,0x5f440012}},	//   snu_, يني_, slui, _إنكل
  { {0x69c1008b,0x7dd3003a,0x69a20037,0x6e21006f}},	//   rgle, rısı, _ग़री, _illb
  { {0x69c10052,0x69de0123,0xf6490009,0xe73a03cd}},	//   sgle, zepe, _וצ_, дем_
  { {0x69c70027,0x7dd3003a,0xdb060004,0x7bdf058c}},	//   _ocje, pısı, _odká, dequ
  { {0xc332000b,0xdd920012,0xf2050011,0x69c60031}},	//   _דוד_, شور_, राफ़_, őker
  { {0x6da30046,0x2731001a,0xed5702d3,0xa00a0012}},	//   риса, ạnh_, вор_, _يقتل_
  { {0xe8d6000b,0x60d6000b,0x88ba0009,0xc1780073}},	//   _יוצר_, _יוצא_, _חזקי, adės_
  { {0xf9920003,0x7799000b,0xaf4a0012,0xb33b0018}},	// [7c0] لبا_, _אֹתו, _تشغل_, _peça
  { {0xceb90066,0xe7d5003a,0xb21b058d,0x7c24058e}},	//   áře_, tığı, _stær, shir
  { {0x7bdf0017,0x291c022d,0x69de058f,0x91e3004c}},	//   bequ, áva_, repe, рохе
  { {0xdfcf0003,0x6d5a0073,0x6fb30012,0x69de0590}},	//   قيم_, _ryta, لمما, sepe
  { {0x442200a2,0xdfcf000a,0x3ed40003,0xa6fa0003}},	//   _ilk_, تين_, اقتر, بعاء_
  { {0x6d5a003e,0xceb3000b,0x4a750015,0x63a20051}},	//   _pyta, שיג_, _быст, _seon
  { {0xa3c90044,0x10a3002d,0x04c70003,0x3ead003a}},	//   ल्क_, _висн, نووي_, _evet_
  { {0x94230001,0x21670024,0xa7850012,0x61ea0060}},	//   имје, _риси_, _مشكو, _safl
  { {0x7c23007d,0x59cf0037,0x6ac30012,0x68260031}},	//   _înre, स्वर, لقيم, _módd
  { {0xd5af0012,0x6cd60012,0x7e7a0227,0x66250034}},	//   _وفق_, _لقطا, _uitp, ątkó
  { {0x859b015a,0x91bb000b,0x23e20037,0x2cb8000e}},	//   _חשבו, ומיי, _पसंद, _írd_
  { {0xc9530093,0x92a90002,0x28c40037,0x3c3a001e}},	//   ימת_, nałó, लंबि, tīvu_
  { {0x8c1b0009,0x8f9b0009,0x64410025,0x61ea0591}},	//   _קודי, ויכי, élim, _tafl
  { {0xf773000b,0x6e940015,0xb8f40003,0x82d7000b}},	//   יקר_, риру, _مكتب, _סווג_
  { {0x6272003e,0x4a7b000b,0x1dd20037,0xc1030003}},	//   _słow, _קרוב, द्धत, _نووي
  { {0xd10f0044,0x7bc401a2,0xa177000b,0x5fa70037}},	//   ाहरण_, ggiu, _בעוד_, _ख़िल
  { {0x24580047,0xc334000b,0xda670012,0x7bdf0592}},	// [7d0] тать_, אוּ_, نائي, requ
  { {0x442200bd,0x4d99002d,0x9f440054,0xd5350003}},	//   _elk_, _якою_, _camí_, _مفخخ
  { {0xe01e0011,0x5fa70011,0x2419003c,0x6d410064}},	//   पसंद_, _ख़ाल, _зоны_, úlad
  { {0x787a0013,0x251a0009,0x50640223,0xd7890012}},	//   _důvo, _נורא, атча, رنتو_
  { {0x539a000b,0x03d6000b,0xdb0d0051,0x17540024}},	//   _רישו, _גורם_, ngaü, авця
  { {0x7c220108,0x26360002,0x5187035c,0x0dc8004c}},	//   _alor, słon_, _шума, вући_
  { {0x6aad00b6,0x6da20593,0xadd80009,0x64e80012}},	//   lsaf, щища, דווח_, َّهِ_
  { {0x32cb0119,0xd46600a6,0xc57c0009,0x20f3001b}},	//   tøy_, лище_, ורות, _ići_
  { {0x65950594,0x27ff008e,0xdb040031,0x92390595}},	//   _базу, _inun_, taié, ечну_
  { {0x2d810020,0xc5fb0003,0xf9d4002d,0xb33b0025}},	//   _nghe_, _تعرض_, ацюю, _leço
  { {0x07a600c0,0x8cc40012,0x69c50132,0x64c40012}},	//   ланн, _نقله, ighe, _نيلل
  { {0xf3f00003,0xc5e90009,0xcaf50012,0x25a50596}},	//   _وأن_, _מד_, _مستب, _hell_
  { {0x25a50597,0x9f8a0051,0x38b90028,0xdcee003a}},	//   _kell_, _tööd_, _býrð_, vabı
  { {0x2aba0093,0x7c22009b,0x63a90598,0x02450012}},	//   _נמצא, _zlor, laen, _حَتَ
  { {0x91fc0039,0xdcee003a,0x27ff003a,0x61e10599}},	//   rmāt, tabı, _onun_, mell
  { {0x61e10006,0x74160012,0x80cd0011,0x40920012}},	//   lell, دورا, _सहजे, _الير
  { {0xab66059a,0x04570012,0x23270430,0xcaa50012}},	// [7e0] увал, القة_, готи_, لصلي
  { {0xdcee00a1,0x55e60047,0x25a501a2,0x787a0013}},	//   sabı, _сооб, _nell_, _půvo
  { {0x60c1059b,0xa9880009,0x63a9059c,0x61e1059d}},	//   nulm, דָנִ, kaen, iell
  { {0xe29a007c,0x7643059e,0x61e1059f,0x6a660097}},	//   _пам_, enny, hell, iðfa
  { {0x66ad000b,0x61e105a0,0xf6d30012,0x8f9b0009}},	//   ֵיהֶ, kell, مزود, גיני
  { {0xf38f0020,0x69d30037,0x25a505a1,0x60c105a2}},	//   uảng_, _बॉली, _cell_, kulm
  { {0x25a505a3,0x83fd000e,0xbca40003,0xda5b000b}},	//   _dell_, klőd, جمعي, _נכלל
  { {0xe4f70044,0x4422000f,0x61ee0164,0x61e1004a}},	//   ुमति_, ók_, _habl, eell
  { {0xbc67000a,0xa3c90037,0xe3af0003,0x25a502c3}},	//   دمين_, ल्ट_, سري_, _fell_
  { {0xd8f8007c,0xf1c60066,0x3c3a001e,0x2000000d}},	//   вної_, _část_, tīvs_, _anii_
  { {0x5bc6000a,0x6444004a,0x3257000b,0x73c60012}},	//   _مقال, knii, רסים_, _ميام
  { {0x0eeb0015,0x64560132,0xd2590035,0x82a60365}},	//   ньги_, joyi, ruņa_, _бадж
  { {0x62860010,0xb33b0061,0x6fc60037,0x33170012}},	//   _nuko, _reço, _वारं, _مزود_
  { {0x6ecc0011,0x6d5e05a4,0xc0aa0012,0x27ed05a5}},	//   _समनु, _bypa, _كابل_, žen_
  { {0xf993000b,0x55590014,0x63a60227,0x63b90034}},	//   _פרק_, тавя_, _bekn, ówno
  { {0xf8b30009,0x60df0031,0x628605a6,0x9b95042a}},	//   _השק_, őzmé, _buko, риац
  { {0x7655003e,0x3ce40037,0x64480061,0x53470001}},	// [7f0] pozy, झौते_, édia, ухва
  { {0x321e0002,0xa5350024,0xbc840081,0xc7b90031}},	//   nkty_, _вноч, _ướn, _elől_
  { {0xc5f8001e,0x69c505a7,0xd2620035,0x69dd0031}},	//   ķēt_, rghe, diņā_, őseg
  { {0x627205a8,0x765a05a9,0x25a505aa,0x4c9a0009}},	//   _złot, _akty, _sell_, _שברו
  { {0xddc8007a,0x69d80470,0x65640066,0x8f9c0009}},	//   _didž, _obve, řihl, תידי
  { {0x44290149,0xf770000a,0x60c1003a,0xb2ba0009}},	//   lha_, سان_, yulm, _במשר
  { {0x999e0066,0x63a90262,0x3e320012,0x20f3001b}},	//   entů_, taen, تفور, _ući_
  { {0x442905ab,0x25a5029e,0xbae50012,0xdb510012}},	//   nha_, _well_, لكبي, يَغ_
  { {0x7412000a,0xcda9000a,0x25a5002a,0xb2250001}},	//   تويا, _لهذه_, _tell_, имил
  { {0xd262001e,0x60c1003a,0xe8f9002d,0x6abb05ac}},	//   ciņā_, tulm, вло_, rruf
  { {0x5d84000a,0x44290101,0x83fd000e,0x69ca0011}},	//   _المل, kha_, tlőd, स्टी
  { {0x60c100a2,0x43750146,0xc1560009,0x16030011}},	//   rulm, _култ, ישתו_, लावर_
  { {0x46e7007c,0x8c1a0093,0x26020037,0x83fd000e}},	//   адян_, _שוני, शाली_, rlőd
  { {0x43720003,0x7c2905ad,0x442905ae,0x628605af}},	//   _ظهور, lher, eha_, _ruko
  { {0xed5a035b,0x845a046d,0x628605b0,0x9268004c}},	//   тов_, врат_, íkov, _срца_
  { {0xb8db0044,0x6d5e05b1,0x61ee05b2,0x200005b3}},	//   ें_, _vypa, _sabl, _unii_

  { {0x62720002,0x6d5e0002,0xdcfc001e,0x935a0001}},	// [800] _głos, _wypa, obrī, трву_
  { {0xb33b00a2,0xc693000b,0x1daa0037,0x3c3f004a}},	//   _geçm, _ואז_, _क़ित, tävä_
  { {0x55bb000b,0xdfa6004c,0x61ee0159,0xd5bb0009}},	//   _במיו, ајло, _vabl, _בזיל
  { {0x1eaa0003,0xfa88001a,0x442905b4,0x386d05b5}},	//   ناتي_, _lừa_, cha_, _cher_
  { {0x539b000b,0xd9e50037,0xd262001e,0x66f40055}},	//   _ביכו, क़ात_, tiņā_, сплу
  { {0x386d0052,0x4096011f,0xdb000097,0xc896004c}},	//   _eher_, _врат, jamá, _врањ
  { {0x7589002d,0x95080012,0x29070248,0xdb000097}},	//   усів_, اقعك_, änat_, damá
  { {0x6a6b0052,0x0163002d,0x1d070001,0x6e3c05b6}},	//   rüfe, _єкто, рећи_, hirb
  { {0x5a340014,0x8ff90003,0xf5ea0014,0x9294004c}},	//   йнит, _حرّر_, _имал_, љаоц
  { {0x5cd6002d,0xf2d30009,0xc2110009,0xcb67004c}},	//   _відх, קעת_, ִ֔י_, шање_
  { {0xdcb1001a,0x621b000b,0xa3e60037,0x442005b7}},	//   ởi_, דויק, फ़ा_, kki_
  { {0xb33b00a2,0x7c2905b8,0x6d3b000b,0xcfab0012}},	//   _seçm, cher, _בתבנ, خادم_
  { {0x3294000a,0x229405b9,0xaa940003,0xfe730003}},	//   _التأ, _التس, _التث, قدس_
  { {0x8afb000b,0xbafb0009,0x442005ba,0xaadb0009}},	//   _שהגי, _שהגש, eki_, _סחור
  { {0x2ba70046,0x62720002,0xda050037,0x44260577}},	//   ијав, _włos, रासत_, _klo_
  { {0x717b0093,0xe97b0093,0x417b000b,0x5bb80015}},	//   _בנוס, _בנוש, _בנוב, ился_
  { {0xb0660051,0xe9870001,0xaed50001,0x442905bb}},	// [810] svää, аћен, _уопш, rha_
  { {0x9178001a,0x82340012,0x7ac401c6,0xd1b80012}},	//   _sớm_, يرلا, юссе, لاما_
  { {0xda78004d,0x442005bc,0x4ddc0009,0xa3d60011}},	//   рят_, bki_, _יחזו, िभा_
  { {0xa3ce0044,0xe8df0020,0x442005bd,0xfd560009}},	//   _राय_, _quốc_, cki_, _לשתי_
  { {0xd9f80037,0x161b0321,0x7ff40012,0x20e805be}},	//   ्ञात_, _नकार_, تسلا, _eşi_
  { {0x7c29002a,0xcb120009,0x63ad05bf,0x2d910034}},	//   wher, _צלם_, laan, ncze_
  { {0xa3ce0037,0x7c2905c0,0xdd8e0012,0x29070248}},	//   _राम_, ther, روي_, ånad_
  { {0x40350014,0x44390051,0x61e50066,0xd4e4002d}},	//   _уебс, _jms_, lehl, юючи
  { {0x32d0001a,0x7c2905c1,0x7c3b05c2,0xdcfc0035}},	//   gày_, rher, riur, tbrī
  { {0xc332000b,0x69c805c3,0x6ecc0011,0x442005c4}},	//   פוי_, ggde, _समतु, zki_
  { {0x44200002,0xfa88001a,0x6d40003a,0x6c850012}},	//   yki_, _vừa_, şmaz, _الصم
  { {0x33f40012,0x6e3c0032,0xa0880009,0x2d910034}},	//   _وسنس, wirb, יְשִ, ecze_
  { {0x2bcb0037,0x44200133,0xfc300012,0xf4120009}},	//   िलना, vki_, _تحل_, _מפא_
  { {0x4420003e,0x23740029,0x51950003,0x69dd000e}},	//   wki_, ňajú_, _الغذ, őseb
  { {0x1d19007c,0x8234000a,0x50db0037,0x442005c5}},	//   ають_, _برنا, _बहिष, tki_
  { {0x3eb2007a,0x3f80007a,0x711a000b,0xb38605c6}},	//   šyti_, žiui_, _תוקפ, слал
  { {0x61e50052,0xc053000b,0x3b070014,0x629b004a}},	// [820] fehl, _מזה_, бето_, npuo
  { {0x7dea0015,0x7afd008e,0xdb0d0097,0x99850073}},	//   _смог_, ästy, rgað, milų_
  { {0xf77f0017,0x7cd60012,0x443905c7,0xa06a05c8}},	//   meça_, _اتخذ, _fms_, гажа_
  { {0xa2aa0037,0xdb06000e,0xa9670014,0xddc80034}},	//   _फ़िल्, _leké, щиха_, _widż
  { {0x92f6002d,0x20d1001a,0x29070248,0x61e50064}},	//   _учні, hái_, änar_, behl
  { {0xf77f0018,0x20d10031,0xe0860012,0x442605c9}},	//   neça_, kái_, _هجري, _slo_
  { {0x645d0006,0x6f1d0002,0xd5b90024,0x88980009}},	//   _yksi, zysc, рсі_, _כֹּה
  { {0x94180015,0x2d910002,0x786a015b,0xcce50012}},	//   ржит_, zcze_, býva, تسهي
  { {0x59cf0037,0x6a700248,0xdfcf0012,0xdb060031}},	//   स्कर, räff, _سيل_, _beké
  { {0x98a700a2,0x6d4000a2,0xef170001,0x23ad0010}},	//   _aynı_, şmay, _уму_, mųjų_
  { {0xc0aa0003,0x20f7004b,0xd5af0012,0x09f70009}},	//   داخل_, _căi_, _سفن_, זמים_
  { {0xbb860003,0x43860003,0x4420001a,0x2d910002}},	//   _الإي, _الإق, _ôi_, wcze_
  { {0x29180051,0xf1a80037,0x23ad0073,0x316b0034}},	//   ärab_, गरान, nųjų_, ęcza_
  { {0x41c70037,0xf1c70011,0x65940048,0x443905ca}},	//   _लाइस, _लाइन, зару, _sms_
  { {0x63ad05cb,0x786a01bd,0x80a40012,0xb4250034}},	//   taan, zýva, _بمعن, łżeń
  { {0x25bf000d,0x53990015,0xdc8b0009,0xd0110012}},	//   şul_, рвая_, טְמָ, _آلة_
  { {0x7b6705cc,0xf77f0017,0x443905cd,0x91870012}},	// [830] стве, beça_, _vms_, مجام
  { {0xd2500012,0xd3010024,0x63ad05ce,0x23ad0073}},	//   ّنْ_, кiвс, saan, dųjų_
  { {0x63ad05cf,0x61e50029,0xd1b80012,0x89db0009}},	//   paan, rehl, صالا_, רחבי
  { {0x7c670003,0x7aee004a,0xdc880009,0xfde10011}},	//   _داخل, äntä, _לְשָ, फ़्फ
  { {0xa3ce0037,0xa3e60011,0x95850189,0xcebb004c}},	//   _रात_, फ़र_, олле, уље_
  { {0xae030044,0x2c4c0066,0x7c95046d,0x291e0010}},	//   लाइन_, věda_, ориц, kyta_
  { {0x44f80020,0x7c840001,0x41090009,0xafdb0040}},	//   _cĩ_, пуње, _דִּ֣, rnøj
  { {0xa4b80093,0xfc310003,0x291e0010,0x7c2d05d0}},	//   צלחה_, بحت_, dyta_, nhar
  { {0xc7b9000e,0x20f7000d,0x7bc905d1,0x7bfa0009}},	//   _idő_, _săi_, rgeu, בִיה
  { {0x39450055,0xdcf5003a,0xd1790024,0xaa560012}},	//   жног, hazı, исні_, يليا_
  { {0x7bcf05d2,0x629b05d3,0xa96905d4,0x7afc0035}},	//   _occu, spuo, рина_, ārta
  { {0xe8df0020,0x629b008e,0x7d560009,0x20d105d5}},	//   hiệm_, ppuo, _ויעד_, rái_
  { {0xdcb1001a,0x65690066,0xc7d6000b,0xd5b1001a}},	//   ẩn_, řehl, חורי_, _góc_
  { {0xb33b00a2,0x443f05d6,0x442d0017,0x7c2d00b6}},	//   _geçi, liu_, lhe_, ehar
  { {0xf77f03eb,0x7afd05d7,0x442d01a4,0xa06a05d8}},	//   reça_, _arst, ohe_, _кака_
  { {0xccf20093,0xdb000051,0xb466002d,0xd8760003}},	//   וכל_, bamä, ікал, _باتب
  { {0x63ab05d9,0xda050037,0x89aa01ef,0xcfb70009}},	// [840] _megn, रांत_, икав_, _ולפי_
  { {0x62830066,0x644905da,0x4ce60048,0x682605db}},	//   _jino, hnei, _джоб, _kódo
  { {0x443f0010,0x045a0003,0x7afd0204,0xbfaa00b5}},	//   kiu_, _نجحت_, _erst, атле_
  { {0x6826000f,0xd5b10020,0x30760015,0x62990002}},	//   _módo, ức_, цузс, _otwo
  { {0x44f80020,0x98ab001e,0xf4130009,0x27e60132}},	//   _sĩ_, āmās_, _חפר_, reon_
  { {0x7c240005,0xdcba0098,0x35e10011,0x4efb0009}},	//   lkir, ащи_, फ़ग़, יהנו
  { {0x7a200052,0x291c0051,0x443f0029,0x1cba0009}},	//   _nöti, ävad_, fiu_, ׁמַע
  { {0xb33b00a2,0x2900007a,0x62830006,0x44f8001a}},	//   _seçi, _čia_, _aino, _vĩ_
  { {0x63b90002,0x63ab00b8,0xafdb00b0,0x7c2405dc}},	//   ówni, _degn, snøk, ikir
  { {0x291e0010,0xee370001,0x628b05dd,0x442d05de}},	//   tyta_, _дну_, _dugo, ahe_
  { {0x7233000a,0xf9930093,0x69fb000b,0xfa330003}},	//   بريط, ורת_, בליק, بريد
  { {0xb084002d,0x63ab05df,0x443f05e0,0x291e05e1}},	//   овiд, _gegn, ciu_, ryta_
  { {0xd5b10020,0xc7b3000b,0x3866000d,0xa87b000b}},	//   _hóa_, ובר_, ilor_, יאטר
  { {0x765c05e2,0x22570012,0x644005e3,0x7ae205e4}},	//   gory, _وجوب_, limi, _ipot
  { {0x644000e6,0xa99b0009,0x45d40048,0xe6540024}},	//   oimi, _דבור, ьорс, євсь
  { {0x59dd0037,0xdb000029,0x04c80012,0x28380012}},	//   न्नर, pamä, توفي_, _وأية_
  { {0xdceb00a2,0x83350014,0xf77f0017,0x7c2d05e5}},	// [850] ınız, чнах, meço_, rhar
  { {0xf1c30020,0x7c240006,0x7afd0133,0xe1670001}},	//   _giờ_, akir, _vrst, ођен
  { {0xab95002d,0x7c380028,0x6449004a,0x58d40048}},	//   _нині, ðará, ynei, дохт
  { {0xdce50020,0x443f0054,0x8d5a0009,0xb8e30011}},	//   _nghĩ, xiu_, _לכתי, _एट_
  { {0x06fb0037,0x6605034c,0xe8e0001a,0x69d80011}},	//   एटिव_, зпла, _khớp_, न्ही
  { {0x63ab01a2,0x61e8001c,0xee38002d,0x65650051}},	//   _segn, jedl, оні_, ühho
  { {0x62990002,0x85780014,0x2bb20037,0x443f05e6}},	//   _stwo, осът_, _ज़मा, tiu_
  { {0xc1040003,0x644005e7,0x09b50011,0xe50c0011}},	//   _توفي, gimi, ूल्य, हमति_
  { {0x63ab05e8,0x442d05e9,0x0b4500b3,0x1306003c}},	//   _vegn, rhe_, янин, зный_
  { {0xd6280001,0x02160009,0x61e80132,0x7ae00032}},	//   _дође_, ִ֗ים_, gedl, _ämte
  { {0x91fc001e,0x644f0002,0x644005ea,0x0ef40011}},	//   plān, _ojci, bimi, इट्स_
  { {0x644005eb,0x628b002c,0x16030037,0x66e601b6}},	//   cimi, _tugo, लाकर_, пома
  { {0x6299003e,0x765c05ec,0x661a0522,0x7c2405ed}},	//   _utwo, tory, ötko, vkir
  { {0x8afa000b,0x915e001a,0x9b160009,0xa3ce0011}},	//   _להני, hắm_, _מחנה_, _राह_
  { {0xd5b10020,0xdd8f0003,0x32070002,0xd46a0012}},	//   _xóa_, اوف_, _inny_, محرم_
  { {0xc952000b,0xc4830345,0x58ba000b,0xdddc01bd}},	//   _רמה_, елск, _המקצ, zorň
  { {0x0ae90003,0x32180002,0x7c2405ee,0x6fa20011}},	// [860] يركي_, _pory_, rkir, _क्यू
  { {0x17570093,0xd5b1001a,0x7c2405ef,0xa3ce0011}},	//   _מספר_, ứa_, skir, _राव_
  { {0x6440003a,0x361b000b,0xd12f0012,0x7c240073}},	//   yimi, _הויד, همك_, pkir
  { {0x1fd60011,0x44240081,0x92050011,0xc7f70009}},	//   ठभेड, _ôm_, राउज_, ּ֖את_
  { {0x61f500a1,0x33fb000b,0x38660168,0xabfb0009}},	//   _fazl, _ההכנ, rlor_, _ההכר
  { {0xc3330009,0x7c2b0097,0x61f50060,0xcf250012}},	//   _טור_, _algr, _gazl, برمي
  { {0x80c00037,0x8fa605f0,0xe6a90011,0xc5f30009}},	//   _विधे, _наве, _कब्ज, גדו_
  { {0xb7da0003,0xdc9b000b,0xd92b0009,0x60c80248}},	//   _دورا_, זיקל, _הֵמָ, vudm
  { {0x7afc001e,0xe7c60037,0x298a002d,0x644005f1}},	//   ārto, _वाजप, йсно_, rimi
  { {0x80c00044,0xd337000b,0x4b37000b,0x3f800010}},	//   _विदे, פריה_, פריל_, žius_
  { {0xdca3007c,0x859b000b,0x66080058,0xd59b0009}},	//   _захи, _השבו, _indk, _הבבל
  { {0xdcb10020,0x7aed003e,0xa3e30037,0x35d20011}},	//   ẩm_, ywat, _पॉप_, _साड़
  { {0xf77f0149,0x7ae205f2,0x6826000e,0xabfb0009}},	//   reço_, _upot, _kódj, _להאר
  { {0x661a0006,0x4b7b000b,0x8b450012,0xb4b605f3}},	//   _jotk, _האדו, _تضمن, _जिफ़_
  { {0x61db0093,0x7a2d0164,0x61f5048b,0x6826000e}},	//   _הקוד, _fútb, _razl, _módj
  { {0xfc49001a,0xc49b0009,0x7e60004b,0xe4140024}},	//   hận_, משלת, împr, ндсь
  { {0xa3de0037,0x67bc000b,0x35d20011,0xda090012}},	// [870] द्य_, _המחק, _साढ़, ييره_
  { {0x91fc0333,0x2bcb0044,0x661a0065,0xdb0b0040}},	//   klām, िलहा, _notk, _udgå
  { {0x21270020,0xb33b0061,0x4094002d,0x16380009}},	//   ánh_, _reçu, еріт, _מנזר_
  { {0x66080051,0xa2bd0011,0x6fbf0011,0xa4b60009}},	//   _andk, _शिल्, ्लिं, _קלרה_
  { {0xd6db05f4,0x1ec9002d,0x907c0009,0xa6c90024}},	//   сте_, ілки_, צטדי, ілка_
  { {0x9e340024,0x8ee80024,0xfe730012,0x2f230035}},	//   нечч, ямів_, ردش_, _rīgā_
  { {0x3cf90037,0xcd980009,0xac960012,0x644d05f5}},	//   ्में_, הדות_, ونوا_, onai
  { {0x62870164,0x644d05f6,0xf2050011,0x3e640031}},	//   _hijo, nnai, राक़_, lött_
  { {0xb33b003a,0x661a05b1,0xbe980012,0x15f50011}},	//   _geçt, _fotk, _فضلا_, _इसपर_
  { {0x80d9002d,0x7afb0051,0x02390003,0xaa56004c}},	//   оєму_, rvut, تثبت_, мињу_
  { {0xdb0b000e,0xb7bd000d,0x63a40010,0x7643055c}},	//   _megé, _alţi, ybin, miny
  { {0xa3ae0044,0x59dd0044,0x7d1e005e,0x3f6a05f7}},	//   करण_, न्तर, äpse, жимо_
  { {0x9f5f0028,0xcfb6000b,0xe9ce05f8,0xb7da0009}},	//   ðuð_, ולרי_, _ик_, חקרי
  { {0xfce6002d,0x3e64000e,0x764300b6,0x59d40011}},	//   мого, jött_, niny, _दायर
  { {0x33f6002d,0x91fc001e,0x3e64000e,0x26d9004a}},	//   мчас, klāj, dött_, atso_
  { {0x644d05f9,0x68260031,0x69c301e3,0x628f05fa}},	//   gnai, _módk, ónen, _buco
  { {0xd6aa0003,0x09ba0003,0xae9a0003,0xcb6705fb}},	// [880] _بدعم_, قطاع_, _بضبط_, дате_
  { {0x3e640031,0xda050011,0x644d05fc,0x764305fd}},	//   gött_, रागत_, anai, jiny
  { {0xb33b00a2,0x3cf90037,0x7643055c,0x02190024}},	//   _seçt, ्मों_, diny, чіть_
  { {0xfbb20044,0x28c50011,0x0fee0011,0x23b20011}},	//   _ज़िम, _विनि, ज़िश_, _ज़िद
  { {0xe7320012,0xc68f0012,0x7643016d,0x628705fe}},	//   خصا_, لِن_, finy, _fijo
  { {0xd10d0037,0xceb90066,0xd49a05ff,0x59dd0011}},	//   िमाण_, áři_, ори_, न्दर
  { {0xf983024d,0xfce3004c,0xfc490081,0x9e650012}},	//   _агро, војо, rận_, راهن
  { {0xa8030014,0xa9570009,0xa1570009,0x493b00af}},	//   _изсл, _חילק_, _חבלה_, _וגלו
  { {0xa01b0065,0x98460039,0x539b000b,0x6e930003}},	//   lmög, _dēļ_, חיפו, _للقا
  { {0x7a200600,0x03770009,0xc5760012,0xc114004c}},	//   _gött, ותפת_, _قطاع, емој
  { {0x644b0028,0xa3c00011,0x2bbd0011,0xa01b0032}},	//   ðmið, ीला_, ोलशा, nmög
  { {0x3e64000f,0xf5370009,0x3ea9004b,0x78520035}},	//   zött_, _קטאר_, ţate_, tāva
  { {0xe667002d,0x77640014,0x80c00037,0xa77403e1}},	//   дтво, върж, _विवे, ключ
  { {0xe2460003,0xfc3f0030,0x68fc0601,0x7d000035}},	//   _تخصي, _smí_, årds, āmsn
  { {0xa4d40024,0xdcb10012,0x0cd40024,0x7a200602}},	//   корі, طىء_, корю, _löts
  { {0x62870603,0xdb0b000e,0xe0d10009,0xbb4b0024}},	//   _sijo, _segé, _עֲו_, оїзд_
  { {0x8c1b000b,0x3e64000e,0xd3700012,0xeb9101b0}},	// [890] קומי, tött_, لهِ_, אָב_
  { {0x416b0001,0x61f80604,0x99870030,0x21f50012}},	//   ојем_, _javl, ónů_, عكاس
  { {0xc5f20009,0xa3ae0011,0x18a40024,0xe9d00012}},	//   _גדי_, करा_, ваєм, شغل_
  { {0x2c27007c,0x38c40028,0xfc3f0030,0xd6b50048}},	//   _цьог, _sérð_, _umí_, ейдъ
  { {0x28c50044,0x76430605,0x6b9a0009,0x539a0009}},	//   _विभि, tiny, _משרד, _מירו
  { {0xf7700003,0x999e0030,0xad250012,0xd0d50048}},	//   جام_, ditů_, فرعو, _погъ
  { {0xbdf80003,0x29180051,0x44290606,0x76430607}},	//   برنا_, äral_, oka_, riny
  { {0x764300c6,0xf3f2000b,0xa3d70011,0x2101001b}},	//   siny, ָ֣ה_, _साफ_, rčić_
  { {0xa3de0044,0x6ee70012,0xa3d70011,0xd5b10081}},	//   द्ध_, _تسأل, _सान_, _hóm_
  { {0x80c00302,0xedd50003,0xe9d90281,0xa2c20011}},	//   _विशे, _سيؤد, чко_, _लिस्
  { {0x186a029b,0xf4d40003,0x68460063,0x44290608}},	//   зани_, _لتنظ, енна, kka_
  { {0x44f1039c,0xb4fa000b,0xc952000b,0xdb060029}},	//   _iš_, _מפעי, רמט_, _leká
  { {0xc2c80003,0x69d50002,0x93270012,0x78760018}},	//   _قبول_, _ocze, _تران, jáve
  { {0xf6520003,0x7c290609,0x69c301e3,0x7f3a0009}},	//   ائح_, lker, ónel, לערו
  { {0xdb0402d1,0xa9660048,0x1d07060a,0x68e20034}},	//   mbié, _пиша_, нери_, łodz
  { {0x4429060b,0x3c2e0064,0x1ddf0011,0x98160012}},	//   gka_, _býva_, प्तत, _سببا
  { {0x7c29060c,0x28c50037,0x78760018,0xa9a60148}},	// [8a0] iker, _विडि, gáve, еизд
  { {0xe1f7026d,0x2bb20011,0xa01b0032,0x4432060d}},	//   нгу_, _ज़वा, tmög, shy_
  { {0x44320036,0x4c860345,0xf2050011,0x35c90011}},	//   phy_, _плов, राज़_, _राज़
  { {0x442901ab,0x768b003e,0x7c290070,0xbe8a0001}},	//   cka_, _użyc, jker, пске_
  { {0x44f1007a,0x6826060e,0x78760017,0xc8ec0321}},	//   _aš_, _códi, cáve, _जन्म_
  { {0xdcfc00a1,0xceb3007e,0xf7470012,0xdd8f0012}},	//   ları, ניו_, علوي_, موه_
  { {0x3da5007c,0xc43a0009,0xb5a50024,0x64c300ae}},	//   тріб, ּתִי, трій, هيول
  { {0x6f04007d,0x7c29060f,0xd491001a,0xd5770009}},	//   _oric, gker, _dù_, עתקה_
  { {0x3254004c,0x78520035,0xee3a047a,0x59d40610}},	//   квир, tāvn, _ена_, _दादर
  { {0x2d8c0029,0x6da60003,0x7c290611,0x010a0009}},	//   ždej_, _أمام, aker, ִלָּ
  { {0xdcfc00a2,0x3a37000b,0x6d49000d,0x44290612}},	//   karı, גרים_, şeaz, yka_
  { {0xac970003,0x6d0b0009,0x7d570009,0x7c290613}},	//   _أننا_, _מִדַ, _איבד_, cker
  { {0xdcfc003a,0x6f040614,0x6d4801e3,0xd6040024}},	//   darı, _cric, údan, _пiдв
  { {0xbe880015,0x44290002,0x78760017,0xef0e002d}},	//   ессе_, wka_, váve, рмi_
  { {0xf1b3000b,0xd491001a,0x2d850615,0xa407004c}},	//   _עסק_, ề_, äle_, нџак
  { {0x2c090037,0x78760017,0xd6db0345,0x8d77000b}},	//   वाएं_, táve, _ето_, תגלו_
  { {0xf9c7035b,0x17f80012,0x07f80012,0xa3d70011}},	// [8b0] ещен, _سرية_, _سريع_, _साठ_
  { {0x51f80015,0x1ed80012,0x78760616,0x69da0031}},	//   нную_, _أبيب_, ráve, _ötel
  { {0x7fd5002d,0xbc79002d,0xdcfc0060,0x69d80011}},	//   вілі, _обох_, barı, _मानी
  { {0x69d50002,0x64480617,0x9f98004c,0x612b0031}},	//   _wcze, édit, евцу_, lölö
  { {0xe8df001a,0xdb0b0058,0x141a0009,0x8c1a0009}},	//   _thỏa_, _udgø, _חורב, _חורי
  { {0xb5c2002d,0x69d50002,0xd5b1001a,0xf7740009}},	//   айшл, _ucze, _tóm_, נקס_
  { {0xf402000d,0x28c50037,0x2245009b,0xe8df0081}},	//   _faţă_, _विधि, vilk_, _muịc_
  { {0xd1380002,0xb8e70037,0x130900b3,0x78ba0618}},	//   dzą_, ों_, дний_, dstv
  { {0x56950014,0x628a006f,0x28c90011,0x3ed90012}},	//   _разт, _bifo, ांकि, _زواج_
  { {0xdcfc003a,0xaae40012,0xef640048,0x76410097}},	//   zarı, اسيو, _съсо, _umly
  { {0xdcfc00a2,0xf992000b,0xa2bd0037,0x07a600fa}},	//   yarı, ירי_, _शिक्, канн
  { {0x5046004c,0x6f040619,0x7d1a0248,0xd4960009}},	//   темб, _pric, ätsm, _סכנת_
  { {0x539a000b,0x7c26006f,0xdcfc003a,0xfc4600d9}},	//   _חינו, ökre, varı, ších_
  { {0xceb20093,0x2c4c0066,0x6fa20037,0x89350012}},	//   שים_, vědi_, _क्रू, _لعبا
  { {0x61d6000b,0xdcfc003a,0xd1380002,0xdb0b000e}},	//   _יוסף_, tarı, czą_, _megí
  { {0x5184007c,0x2ae50037,0xe8d6000b,0xf0920009}},	//   _суча, _कहाँ_, _סופר_, _דנה_
  { {0x78780149,0xdcfc003a,0x63a900df,0xa3c40011}},	// [8c0] níve, rarı, iben, ौलत_
  { {0xa3d70044,0x4253000a,0xdcfc003a,0x5ee9000b}},	//   _साथ_, لنقر, sarı, _נַפְ
  { {0xdcfc003a,0x6abe0011,0x7afc0035,0x3e69061a}},	//   parı, _एट्र, ārti, nútu_
  { {0xc952000b,0xc7c30015,0x65570009,0x63a9001b}},	//   סמא_, асши, _יביא_, jben
  { {0xa3d70037,0x52860003,0x935a004c,0xfaa6004c}},	//   _सात_, _للحك, _црну_, _јаго
  { {0x78780066,0xd5e30024,0x9f42008e,0x63a9061b}},	//   díve, ижчи, mekä_, eben
  { {0x628a00c1,0xdb0f0018,0xe4d30012,0x3253003c}},	//   _rifo, _recé, لتيب, _твёр
  { {0xa5070001,0xdfd20003,0x31bc0030,0x6826061c}},	//   ђења_, _خير_, bází_, _kódu
  { {0x26dd0002,0x78780017,0x96e50012,0xcec10034}},	//   ctwo_, gíve, _مثلم, _chęć_
  { {0x6206002d,0x78ba061d,0x637b0009,0x3ea6061e}},	//   тчиз, tstv, ונפד, mpot_
  { {0x26c4000e,0x497301d4,0xc4c50012,0x1be20011}},	//   ámon_, ильс, _متنو, खभाल_
  { {0xd1380002,0x14d70009,0x78780018,0x78ba061f}},	//   rzą_, _יובל_, bíve, rstv
  { {0xd138003e,0xe29f0028,0xfbd30009,0x628a0620}},	//   szą_, _orða_, _כתף_, _tifo
  { {0xa3de0044,0xa4d5007c,0x78ba0580,0x3e690064}},	//   द्र_, логі, pstv, bútu_
  { {0xfa77000b,0x69c8003a,0xa3ce0011,0xea7700af}},	//   _שעות_, _ödey, _राख_, _שגור_
  { {0xdfd1000a,0x787600f1,0xe8e0001a,0xb4fb0009}},	//   _اية_, rávc, ýời_, ופלי
  { {0xa8580093,0x2d9e0621,0x337505fb,0x7e63020d}},	// [8d0] _שיחה_, _ofte_, угар, yonp
  { {0x63a90622,0x41b50012,0x5b340012,0x5a340560}},	//   zben, امار, جعفر, анут
  { {0x9848003a,0xdb0b0164,0x27ef0623,0x89780009}},	//   _ağı_, _regí, tegn_, תָּה
  { {0xdb0b000f,0x61fc0036,0xdcb10020,0x6fd40024}},	//   _segí, _earl, ẩu_, иціє
  { {0x787601e9,0x645a0025,0x78780018,0x61fc0624}},	//   náva, étie, xíve, _farl
  { {0xd7740003,0x0e640024,0x6da40012,0x7bc20025}},	//   جامع, акін, لمهم, _adou
  { {0xeb990625,0x26dd0002,0x245a001e,0xd469011d}},	//   ний_, stwo_, zīme_, нике_
  { {0x200d007d,0x1bb90003,0x63a90626,0x7c2d0627}},	//   _unei_, رابع_, uben, nkar
  { {0x7876000e,0xc7b2000b,0x76450058,0x61fc0060}},	//   jáva, _לבן_, _omhy, _yarl
  { {0x78760628,0x38690629,0x96f80003,0x3c310064}},	//   dáva, _akar_, _جعفر_, _dáva_
  { {0x78780017,0x9f4e0066,0xd5b1001a,0x2ba40011}},	//   síve, čním_, _nói_, _ग्वा
  { {0x2c090037,0xb8eb0037,0xc172000b,0xddd50066}},	//   वाओं_, _लि_, מחי_, mozř
  { {0x44f50066,0x09e500f5,0x28c50321,0x91e503e2}},	//   _ať_, _болн, _विवि, _боле
  { {0xdd92000a,0x2edc0011,0x64490097,0x2bbd0011}},	//   صور_, मझौत, liei, ोलका
  { {0x8c7a0014,0x6e210027,0x8cd40011,0xc984004c}},	//   ещат_, _molb, बंधो, _кући
  { {0x7c2d0101,0xc9520009,0x442d062a,0x6449004b}},	//   gkar, _למו_, nke_, niei
  { {0x9b93000a,0x442d062b,0x69da0060,0xb69b0018}},	// [8e0] إلكت, ike_, _ötek, lvân
  { {0x3e760028,0x3b83062c,0x442d0154,0xe9d701d4}},	//   bæta_, слуг, hke_, лку_
  { {0x11d70003,0x3ebf000d,0xd5b1001a,0x442d062d}},	//   اومة_, _avut_, _gói_, kke_
  { {0x442d062e,0xca29000b,0xdbd70052,0x68fc0058}},	//   jke_, הם_, mäßi, ærdi
  { {0xc7d70093,0x7852001e,0x442d062f,0xf4130009}},	//   רוני_, tāvj, dke_, _הפר_
  { {0xccfa0046,0x442d0630,0x6cd40012,0xa6e30097}},	//   ећи_, eke_, لقتا, óðir
  { {0xf8c50044,0x54e60003,0xcce60003,0x44220631}},	//   _विषय, استق, استي, _kok_
  { {0x25f00037,0xd4670001,0x6826000e,0x78a30097}},	//   _इसकी_, лије_, _móds, ínve
  { {0x628e000e,0x2bd50011,0x91fc0035,0x29020035}},	//   _kibo, _धारा, klāt, ākam_
  { {0x2ba40044,0xa3e40044,0xd6cf000a,0x28c50044}},	//   _ग्रा, प्त_, _رقم_, _विशि
  { {0xf593000a,0x8d93000a,0x442200bd,0x7d93000a}},	//   _المج, _المش, _ook_, _المؤ
  { {0xe29a0014,0x442d0632,0x628e0633,0x44220634}},	//   _зад_, cke_, _libo, _nok_
  { {0x80c00037,0xa3ce0011,0x6e950635,0x91aa0011}},	//   _विके, _राज_, ригу, टरफ़े
  { {0x7c220070,0x6e94003c,0x78760636,0x38660227}},	//   _hoor, сиру, ráva, hoor_
  { {0x16d10044,0x7c2d0039,0x7876000f,0x7a36007d}},	//   _सम्ब, tkar, sáva, _câte
  { {0x26de000d,0x7c2d003a,0x44220060,0xa3e70011}},	//   ător_, ukar, _cok_, म्प_
  { {0x4422001c,0xc334000b,0xda670012,0xead50024}},	// [8f0] _dok_, בוּ_, هائي, розь
  { {0x442d0637,0x7c2d0638,0x628e0639,0x7d08063a}},	//   zke_, skar, _cibo, _ords
  { {0xdb0b000e,0x442d004a,0x2907063b,0x628e00b6}},	//   _megá, yke_, ína_, _dibo
  { {0x7c22063c,0xe8d7000b,0x2ba40011,0x44220227}},	//   _noor, רואר_, _ग्ला, _gok_
  { {0x76ab0046,0x63ad063d,0xb3ba000b,0x44c10010}},	//   хтев_, mban, _במרכ, lė_
  { {0xa3e70037,0x1994002d,0x1be20037,0x28c50011}},	//   म्न_, _гаря, क्सल_, _विलि
  { {0x44c1007a,0x442200a2,0x3d080044,0x6e210066}},	//   nė_, _yok_, हिये_, _volb
  { {0x6a6b0052,0xdd1d0029,0x91fc001e,0x63ad063e}},	//   rüfu, ráňt, klās, nban
  { {0x7c22063f,0x02d60003,0xf20a0011,0x7c84004c}},	//   _door, لويب_, _होड़_, љује
  { {0x27ff0006,0x44c10010,0xcb120009,0x442d0640}},	//   _haun_, kė_, קלי_, ske_
  { {0x7c220005,0x63ad0101,0xb69b000d,0x8e840003}},	//   _foor, kban, uvân, _الله
  { {0x44c10010,0x7bc70010,0xdb0f0018,0x63ad0641}},	//   dė_, ėjus, _mecâ, jban
  { {0x92b70003,0x98aa001e,0x93940003,0x501a000b}},	//   _إحصا, ējāt_, _اجما, דורו
  { {0xed5a0046,0x44220642,0xbb3a000b,0xd3560009}},	//   вог_, _sok_, _בעני, _דיני_
  { {0x89da000b,0x44c10010,0xdb0f0164,0x628e04cf}},	//   _יחסי, gė_, _decí, _ribo
  { {0xbb760014,0x141a0012,0x7c3a0035,0x7aa60012}},	//   аузъ, خيرة_, ītro, لإطل
  { {0x386600bd,0xa3d70037,0x6aa4003a,0xc246046d}},	// [900] voor_, _सार_, _çift, анак
  { {0xb77b0093,0x15460001,0x78780066,0xb6bb000b}},	//   _באפש, _веом, díva, _שציי
  { {0xeaf20037,0xf1dd0037,0x26190037,0x91fc001e}},	//   _अन्त_, _मानन, पानी_, olār
  { {0x63bb0039,0xdb0f007d,0xdc9b000b,0xa9670048}},	//   jaun, _decâ, _שיכל, шиха_
  { {0x8f9b000b,0x6f090164,0x27ff00b6,0x46f60014}},	//   דיני, _crec, _daun_, рчет
  { {0x6f0903eb,0x7d00000f,0x7c220643,0x7cec000e}},	//   _drec, járá, _soor, _görö
  { {0xa3e70044,0x787d000e,0x7c220644,0xdd990024}},	//   म्भ_, léve, _poor, уші_
  { {0x6456000e,0x63bb0645,0x8ba90009,0x6c830012}},	//   nnyi, gaun, ְׁתִ, يلوم
  { {0x7c2201e4,0xadba0003,0x44c10010,0xd6cf0012}},	//   _voor, _لهذا_, zė_, _يقف_
  { {0x7c2200bd,0x5a340646,0xc50a0012,0xa3e70011}},	//   _woor, снот, _لتصل_, म्ब_
  { {0xa3d70044,0xd1300003,0x787600f1,0x7c220647}},	//   _साल_, سمح_, rávn, _toor
  { {0x9202001e,0x04db000b,0x78a1000e,0x3e7b0025}},	//   _šāda, _יקבל, _élve, rête_
  { {0x20050066,0xa857000b,0x787d000e,0x83fd0031}},	//   ěli_, שיכה_, jéve, rlőt
  { {0x2005003e,0x44c1007a,0xa3e40037,0x7a320058}},	//   śli_, tė_, प्स_, _sætn
  { {0x8a7b000b,0xcd04003c,0xc5340009,0x4a7b0009}},	//   _שאות, очти, זָּה_, _שרוב
  { {0xec34002d,0xc334000b,0x44c10010,0x8f4700dc}},	//   онсь, ֖וּ_, rė_, _вход
  { {0x290a039c,0x98ab0002,0x787d000e,0x5a350014}},	// [910] _arba_, ącą_, géve, бнат
  { {0x44c1007a,0xe7e80037,0xe9190024,0xf426005e}},	//   pė_, ट्ठा_, лозі_, äära_
  { {0x26140037,0x5f950003,0x7cec000e,0x32640024}},	//   दारी_, ملائ, _vörö, ітув
  { {0x7d00000e,0x7852001e,0x7878029d,0xb8ef0011}},	//   zárá, tāvi, tíva, _शि_
  { {0x7cec000f,0x8c1a000b,0x8416000b,0x3c350248}},	//   _törö, _עושי, _הקרב_, _gåva_
  { {0xfc49001a,0x3cf30011,0xf7700012,0x63a204f9}},	//   hật_, ंबले_, ذان_, _afon
  { {0xe8020037,0x44f8001a,0x7d00000e,0xce38000b}},	//   _रोका_, _cũ_, várá, שאות_
  { {0xed58000b,0x8558000b,0x80c00037,0x644d0010}},	//   יבור_, ישוב_, _विजे, niai
  { {0x7d00000e,0xdb060648,0x1ddb0012,0x6f09004b}},	//   tárá, _sekú, _لبضع_, _urec
  { {0xe4e7007c,0x7876000f,0x6ce7002d,0x629b0061}},	//   _відн, távo, _віде, rquo
  { {0x999e007a,0xa3d70037,0x644d0010,0xe4e4002d}},	//   entų_, सला_, kiai, _міцн
  { {0xaac70037,0x9b950003,0xc952000b,0x7afc001e}},	//   _लिंक, _الإت, למי_, ārtr
  { {0xbb85000a,0x7c3b003a,0x3897000d,0x7b140003}},	//   _الشي, mhur, _mări_, _وبهذ
  { {0x6da3029b,0x6601004a,0xceb20009,0x3c380031}},	//   зира, _jalk, היך_, _véve_
  { {0x2ba60066,0x44e10649,0xf9920009,0x80ce0011}},	//   síců_, nó_, _צרה_, _थिये
  { {0x2c610029,0x8856000b,0x69dc064a,0xdb0a0030}},	//   tódy_, _לֹ֥א_, _scre, šníh
  { {0x290a0027,0xd3b90024,0x44e10081,0x624b0034}},	// [920] _srba_, русі_, hó_, rżon
  { {0xbf9b0149,0x26c2064b,0x228d0073,0x42290009}},	//   ndên, msko_, _užkl_, נֵּ֣
  { {0x787d000f,0x26c2064c,0x3076064d,0x1bf90011}},	//   séve, lsko_, будс, ्याल_
  { {0xe73a0047,0x07b70003,0xf3f9000d,0x644d064e}},	//   лее_, مهمة_, boţi_, ciai
  { {0x2f18064f,0x26c20650,0x44320042,0xd62a0198}},	//   роль_, nsko_, mky_, лоде_
  { {0x50960046,0x63a200c1,0x44320145,0xceb3000b}},	//   _грађ, _sfon, lky_, ליד_
  { {0x91bb000b,0x96c40037,0x71760003,0x44200651}},	//   _תמלי, _रिकॉ, _طهرا, oji_
  { {0x44320652,0x44f8001a,0x3957000b,0x93c5001a}},	//   nky_, _vũ_, _השלם_, _ngắ
  { {0x8c1b000b,0x32660014,0xd3700003,0x26c20653}},	//   רופי, йтов, بهة_, jsko_
  { {0x11d8000a,0xd6250003,0x3e7f0061,0xcb130009}},	//   جودة_, _وعلي, oîte_, פלת_
  { {0x0496000a,0x7174000a,0xdfd10003,0x44e10164}},	//   _الصح, تهدا, ويد_, có_
  { {0xdb0b0163,0x6e25003a,0x26c202a1,0x6fd80011}},	//   _begä, _sohb, fsko_, डलिं
  { {0x7c650003,0x44320107,0xa3760012,0x78780031}},	//   _بالل, dky_, _اداؤ, hívo
  { {0x63b90002,0x39dd0037,0x44200010,0x912a0012}},	//   _zewn, न्फ़ि, eji_, _مسبق_
  { {0x90a60003,0x644d004a,0x94770012,0x7c260654}},	//   _احتم, tiai, مدرا, _bokr
  { {0xb4e90037,0x98c5001e,0x915f001a,0x7d03000e}},	//   _यही_, ūtīt_, _lặp_, eírá
  { {0x78780026,0x44e1000f,0x91b90014,0x2fc90655}},	// [930] tívn, zó_, игат_, _idag_
  { {0x44260051,0x98b8003a,0x44e10164,0xe3bf0164}},	//   _loo_, _ayrı_, yó_, _doña_
  { {0xdce80066,0x443201bd,0x35d20011,0xa0c40012}},	//   _vzdě, bky_, _साज़, كيلو
  { {0x44200656,0x6f0d0070,0x44e10164,0x44320657}},	//   cji_, _krac, vó_, cky_
  { {0x44390108,0xfaff001e,0x7d030658,0xba770012}},	//   _ils_, šību_, bírá, _هاست
  { {0xd126000a,0x44e10659,0x3cf90012,0xaa5d0024}},	//   _قم_, tó_, لعبد_, _регi
  { {0xe3b1000a,0x63b9003e,0x6601065a,0xac39002d}},	//   ورة_, _pewn, _valk, ичих_
  { {0x386d0033,0x69da000e,0x3ea9004a,0x44e1065b}},	//   _uker_, egte, _otat_, ró_
  { {0xb4d60037,0x63b90002,0xe299004c,0x44e1065c}},	//   _सम्_, ówny, јао_, só_
  { {0x5ce50003,0x63b90002,0x915f001a,0x44200002}},	//   _وكذل, _wewn, _gặp_, zji_
  { {0x6f0d00a2,0x35d30037,0xfbdf0017,0xf6520009}},	//   _arac, _ताज़, _ocê_, _קצב_
  { {0x78760029,0x44c5001e,0x186a065d,0x93150012}},	//   mávk, mē_, рами_, _وواش
  { {0x28c5015f,0x44c5001e,0x443200f1,0x96ba004c}},	//   _विकि, lē_, vky_, јуму_
  { {0x4426051c,0x4439065e,0xdb000097,0x26c2065f}},	//   _zoo_, _als_, tamö, rsko_
  { {0x4432022d,0x27ed0052,0x44c5001e,0x7d030030}},	//   tky_, _oben_, nē_, vírá
  { {0xeb970015,0x6a700052,0xd5dc0037,0x17fa0003}},	//   жит_, häft, _बावज, _ضربة_
  { {0x3b070014,0x44200660,0x6f0d0661,0x3a260662}},	// [940] оето_, rji_, _grac, омаг
  { {0x44390663,0x4420003e,0x3205002a,0x78780664}},	//   _els_, sji_, ndly_, tívo
  { {0x10a6022a,0x27ed0031,0xc6170009,0x03b60012}},	//   циен, _bben_, _וחיי_, _وإحد
  { {0xa2a20037,0x24610010,0xe3b20003,0x44c5001e}},	//   _कंप्, tėme_, _ترد_, dē_
  { {0xa25b0029,0x9e660012,0x7680008e,0x63a40060}},	//   _kvôl, ياتن, pöyd, mcin
  { {0x24610010,0x27ed0052,0xa3e70037,0xeca60001}},	//   rėme_, _eben_, म्स_, ојин
  { {0x672f003e,0xd4970015,0x16b70037,0xbfd60012}},	//   zycj, оры_, _अब्ब, _ويسع
  { {0x3e7b0025,0xe4660060,0x711b0009,0x63a40665}},	//   rêta_, _önüş, _דולפ, ncin
  { {0x63a4001e,0x83fd000e,0x69da003a,0x6df60012}},	//   icin, rlőp, _ötes, _وكرا
  { {0xc5160012,0x89da0009,0x7bdb020d,0x26c00073}},	//   _وبات, ׁחִי, aguu, šios_
  { {0xfbca0044,0xc19b000b,0x44260666,0x64950066}},	//   िणाम, ישיי, _too_, _všic
  { {0x4034003c,0x32050132,0x69da020d,0x8b6a0667}},	//   деюс, adly_, sgte, _киев_
  { {0x61ee00c1,0xe67b001a,0x7c650003,0xdb20008e}},	//   _obbl, _hưở, _عامل, ätäl
  { {0x63a40039,0xddda0031,0x6f0d0668,0x7bc00669}},	//   ecin, _kitű, _vrac, lamu
  { {0x6ce4007c,0x6594002d,0xe4e4002d,0x6f0d0120}},	//   міте, дару, мітн, _wrac
  { {0x320d003a,0x26110011,0xc3990024,0x2004066a}},	//   _şey_, _धोनी_, скає_, _nami_
  { {0x44c5001e,0x97ea003a,0x93fb0009,0xe9ab0012}},	// [950] zē_, ışlı, סלמי, لدان_
  { {0xfc49001a,0x78a3000e,0xeab00012,0xceb20009}},	//   hập_, ínvo, ضعك_, _ריי_
  { {0xdfd10003,0x31c4064f,0x15fa0009,0xd5fa0009}},	//   فيا_, ьств, _ההתע, _הפתר
  { {0xa295002d,0x9cd6000b,0x44c5001e,0x7bc0066b}},	//   _намі, _צורה_, vē_, jamu
  { {0xdefb0047,0x63bd0039,0x8c1a000b,0x2004002c}},	//   рые_, _iesn, _הורי, _dami_
  { {0xa6fc000b,0x9e34002d,0xafdb0033,0x2efc0009}},	//   שִׁי, мечч, rnøy, שִׁב
  { {0xfc31000a,0xdfdb0014,0x6605066c,0x6a70066d}},	//   فحة_, _въз_, _mahk, räft
  { {0x6605066e,0xf992000b,0x98170003,0x8d5c000b}},	//   _lahk, _טרם_, _ببسا, יכוי
  { {0xf749000a,0x768b003e,0x3da70014,0x6e280058}},	//   _الذي_, _używ, _дреб, _fodb
  { {0xeb92000b,0x44c5001e,0xc2420055,0x2ddb0012}},	//   עָה_, pē_, еньк, _خبرة_
  { {0x3205002a,0x21690538,0xa969066f,0x9b950012}},	//   rdly_, сини_, сина_, _فلات
  { {0x711a0009,0x7d7a0009,0x3ea40030,0xdb0b0031}},	//   צורפ, _הנעו, ímto_, _megú
  { {0x660500c6,0x20040026,0xdb0b000e,0x539a0009}},	//   _bahk, ľmi_, _legú, _הסנא
  { {0x8b05003e,0x7d790009,0x6d430670,0x80cc0011}},	//   _częś, ֶנּו, ozna, _हिले
  { {0xc6920093,0x91ba000b,0xca36000b,0x19ba000b}},	//   תאם_, _המצי, _מנסה_, _המצב
  { {0xc0a80003,0x26d9002c,0x01340012,0xaac70011}},	//   _باول_, buso_, _تعهد, _लिखक
  { {0x883b000b,0x62950550,0xe29f0028,0xf0930009}},	// [960] _לתקו, _bizo, _yrði_, _אנה_
  { {0xb4bb0011,0xda650012,0x499a003c,0x63bd005e}},	//   _अबू_, والي, стая_, _eesn
  { {0x759b0009,0x859b0009,0x9e650012,0x6ab80011}},	//   _לייח, _לשיו, _تاين, _इब्र
  { {0xfc32000a,0xdb040070,0xd0590024,0x6a7401a0}},	//   _أحد_, ncië, орчі_, ràfi
  { {0xfbd30093,0x80250003,0x7bc00051,0x2004025e}},	//   _אתר_, برلم, vamu, _vami_
  { {0xe8df0020,0x4b7b000b,0xdb0f0017,0x97570009}},	//   _giữa_, _לאכו, _secç, הינו_
  { {0x5ede0011,0xd00a004c,0x69ce0031,0x6026033d}},	//   कंड्_, _леве_, óbem, _едва
  { {0xf8c50321,0x515b0009,0xb3c60011,0xdbcf0030}},	//   _विजय, _הכלו, रृंख, ožád
  { {0xdb06000e,0x69c10671,0x75960012,0x8c1b0009}},	//   _nekü, fale, _فجاء, מוקי
  { {0x7f3b000b,0x7a320028,0xe67b001a,0xfaef0003}},	//   _העמו, _bæti, _tưở, اثي_
  { {0x26190037,0xf1dd0011,0x24890034,0xa01b008e}},	//   पारी_, _मारन, ymam_, lmöi
  { {0xc4860047,0x4c9b0093,0xdb06000e,0xb97b000b}},	//   _элек, _הבאו, _bekü, מניי
  { {0x9b930003,0x63bd009b,0x8b660003,0xee87003c}},	//   _كلمت, _resn, _عاصم, зыво
  { {0x1317000b,0xf1c3001a,0x38a10672,0x12fb0009}},	//   _מחדל_, _chờ_, _fór_, _להדב
  { {0x7a320065,0xc27b000b,0xab5d0002,0x2902001e}},	//   _gæti, _הרגי, raże, ākas_
  { {0x415b0093,0x31c60066,0x2d58002d,0x515b000b}},	//   _לדוג, bízí_, чись_, _לכוו
  { {0xdb0b02d1,0x8f9c000b,0x26c4000e,0xdb040061}},	// [970] _segú, _פיזי, ámot_, nciè
  { {0x61fa0673,0x1758000b,0xdb09000e,0x66bc0009}},	//   netl, _מסחר_, nbeá, _המזה
  { {0x60da003a,0x24890029,0x14d50009,0xa3e50011}},	//   nutm, ňami_, _קוֹל_, _नाप_
  { {0xe0d00003,0xf7750024,0x69c10674,0x61fa0675}},	//   ازل_, мулю, zale, hetl
  { {0x61fa00a2,0xe80e0037,0x660501b6,0xf8680012}},	//   ketl, ियता_, дпла, أمني_
  { {0xf770000a,0x61fa0027,0x238a0029,0xf3f9004b}},	//   دام_, jetl, ňujú_, inţe_
  { {0xc2120093,0x61fa0676,0x91b30081,0x69c10677}},	//   _בהם_, detl, _đèn_, vale
  { {0xc952000b,0x2ef5002d,0x69c10002,0x52a90339}},	//   _סמן_, _озбр, wale, овим_
  { {0x13060015,0xa3df0037,0xe8210037,0xf3f9004b}},	//   дный_, तलब_, याना_, reţ_
  { {0x442b007d,0x88c90015,0x6440003a,0x68e1006f}},	//   _loc_, олов_, ahmi, _älds
  { {0xa3cd0011,0x69c10678,0xdcf60035,0x8c3c0060}},	//   रणा_, rale, ācīb, _buğd
  { {0xcdc90093,0xbca40003,0x64400679,0x78a90159}},	//   _כך_, _أمني, chmi, _čevl
  { {0xdb040070,0x4374010b,0x61fa067a,0x77830198}},	//   rcië, _пушт, betl, клюз
  { {0xcb120009,0xa2940024,0xc1050012,0x329a0009}},	//   _שלג_, _зачі, _يوشي, _ובסד
  { {0x6a7d03eb,0xe2900012,0xd4f5003c,0xe29f0097}},	//   lèfo, _إذن_, няты, _auð_
  { {0x9983007a,0x26c4000e,0xe8d60009,0x6e210097}},	//   ųjų_, ámos_, _חוקר_, ölbr
  { {0xf7460015,0x29030051,0x7ae9067b,0xfaff001e}},	// [980] _цепо, _asja_, ntet, šīnu_
  { {0x7ae9067c,0x7c360010,0x7c2b067d,0xf9920012}},	//   itet, skyr, _logr, نبا_
  { {0x32070036,0xac86002d,0x361b000b,0x7ae9067e}},	//   _many_, _огол, _וויד, htet
  { {0xdfcf000a,0xc9850012,0x7ae9067f,0x68e301a0}},	//   ليم_, رشلي, ktet, ànda
  { {0x7ae9000e,0x33fb000b,0x96fa0003,0x61fa02f7}},	//   jtet, _והכנ, تعار_, yetl
  { {0x768b003e,0x2d9a0033,0x11d60003,0x28db0011}},	//   _użyt, øpe_, _تتحد, मूहि
  { {0xa3e50044,0xddde000e,0xf6570009,0xdd900012}},	//   _नाम_, övőb, וססי_, دوث_
  { {0x47d30003,0x7ae90680,0x442b01a0,0xe29f0097}},	//   _ليفر, ftet, _xoc_, _erðu_
  { {0xae1e0037,0x1ea90003,0x3ea00061,0x68e1006f}},	//   पादन_, _فالي_, _nuit_, _äldr
  { {0xdb040025,0x1e830681,0xe8140011,0xddc30682}},	//   rciè, _алум, _तोबा_, ponš
  { {0x60da0051,0x61fa0683,0x32070684,0xa0550024}},	//   uutm, retl, _dany_, евні
  { {0xf993000b,0x68e1006f,0x3ea00685,0x5cc50012}},	//   כרת_, _ålde, _buit_, _أغلق
  { {0xc7b3000b,0x5b360012,0x3cf10011,0x74130012}},	//   כבר_, _تعار, ँढ़ने_, _جونا
  { {0x6b82009b,0x3ea000b6,0x7f2b0009,0xee84003c}},	//   _izog, _duit_, חֵלֶ, высо
  { {0xd3080020,0x442b0054,0x6e940686,0xfa970009}},	//   _hệ_, _poc_, тиру, _קדוש_
  { {0x7a3f0061,0x443d0002,0xb7e60011,0x1bbb0012}},	//   _vête, ów_, _कायम_, تاسع_
  { {0x6298000e,0x7a320028,0xae0c0011,0x67bc0009}},	// [990] _kivo, _lætu, िएशन_, _ומחק
  { {0x7a3f0061,0xa295002d,0x3e690029,0x62750012}},	//   _tête, хазі, búty_, رهائ
  { {0xd3080020,0x7ae9000e,0xc6920009,0xdb1d0031}},	//   _lệ_, ztet, _תאי_, _mesé
  { {0x7ae90006,0xa2cf0037,0x64480054,0xa9570009}},	//   ytet, _दिल्, èdit, ויבק_
  { {0xd7580012,0xe7240012,0xaac70012,0x8bd60009}},	//   وجها_, َّمَ, _تتجن, _אורו_
  { {0xdb1d0029,0x6298013a,0x99d40012,0x75d50012}},	//   _odsú, _nivo, _لتفا, ريعا
  { {0xba3d0013,0xdfd50015,0x67d50001,0x7c2b0687}},	//   způs, _повы, _пову, _pogr
  { {0xcd980093,0xdcb1001a,0x69c50688,0x83fd000e}},	//   ודות_, ẩy_, lahe, llőz
  { {0xa3e40037,0x7ae9004a,0xed580029,0xba3d0030}},	//   प्ट_, utet, _veľa_, dpůr
  { {0x64950010,0xdb0e000e,0x21990009,0xe29f0097}},	//   _išim, ájáh, ּבֹא, _urðu_
  { {0x61e10065,0x3ea00689,0x245a001e,0x7a320028}},	//   _öllu, _suit_, zīmi_, _gætu
  { {0x7a320065,0xc5e9000b,0x787801bd,0xf9920009}},	//   _hætt, _לד_, tívi, טרי_
  { {0x64850017,0x6d64000d,0x3ea00132,0x2fc001a0}},	//   róid, ătaţ, _quit_, _veig_
  { {0xceb2015a,0xe29f0065,0xd356000b,0x3ea001a0}},	//   רים_, íðu_, _איני_, _vuit_
  { {0x75f3003a,0xa806003a,0x7a32068a,0xe29f0097}},	//   mızı, _alış, _mætt, _orðs_
  { {0x25e40037,0x98a70066,0x52aa0014,0x35dc0011}},	//   ञ्जी_, šně_, звам_, _बाक़
  { {0xa6960046,0xfd650020,0x3d010037,0x69dc0002}},	// [9a0] _прој, _chuẩ, _वैसे_, óreg
  { {0x75f300a2,0x72060003,0xdb090018,0x69c5068b}},	//   nızı, عوام, abeç, gahe
  { {0x261d0037,0x78ab000d,0xba3b01a0,0xec7a05d8}},	//   मारी_, _învă, _suïc, _нпо_
  { {0xe786002d,0xa0670345,0x248d03ca,0x59e20011}},	//   нуло, наха_, jmem_, _पावर
  { {0x2ba80037,0x7a320097,0x11d6002d,0xa857000b}},	//   _ज़्या, _bætt, _півр, עינה_
  { {0x69ce0058,0xad260003,0xbf650012,0x64560060}},	//   _udbe, فربو, خدمو, liyi
  { {0x629800c1,0x7876068c,0x61fe068d,0x6b82068e}},	//   _rivo, návs, mepl, _szog
  { {0xcd030015,0xab5d0002,0x47d60003,0xc4d30009}},	//   учши, waża, _سيطر, אגה_
  { {0xa01b0065,0xcb070003,0xfd9a0003,0xdb080061}},	//   llög, فيين_, _فئات_, élèv
  { {0xd3080020,0x5a340014,0x2486002a,0xc333000b}},	//   _vệ_, тнот, _whom_, טוח_
  { {0xab5d0002,0x7655003a,0x6e2b0009,0x45b70009}},	//   raża, vizy, _מֵאַ, _נפאל_
  { {0x9cd7000b,0x44cc0066,0xd308001a,0x5fb90037}},	//   _טובה_, mě_, _tệ_, आरएल
  { {0x61fe00b0,0x7c260248,0x261d0011,0xe667068f}},	//   kepl, ökru, माली_, етво
  { {0x2c4c0066,0x7b06001e,0x68eb000e,0x61460061}},	//   vědy_, ērtī, éldá, _célé
  { {0x44cc0013,0x69c50005,0xe8210037,0x61fe0690}},	//   ně_, vahe, यादा_, depl
  { {0x897b000b,0x8aa70015,0xb97b0009,0xa97b0009}},	//   _מרוצ, ержд, _מנוי, _מאוכ
  { {0xe2f8002d,0xc29900b3,0x2be10011,0xa3e80011}},	// [9b0] неті_, дках_, फलता, _बान_
  { {0x7a360061,0x25b90012,0xbb840012,0xf3f9004b}},	//   _bâti, _تهدد_, الكي, inţa_
  { {0x65950046,0xe61f001a,0x18a40024,0x78780031}},	//   _јану, _đô_, гаєм, hívu
  { {0x44cc0013,0x7a320058,0xd7590003,0x69c50691}},	//   dě_, _sætt, ولات_, sahe
  { {0x61fe003a,0x22950003,0x245a0035,0xe7f40011}},	//   bepl, _للحس, nīmu_, ेजता_
  { {0xee38007c,0x20090692,0x649501bd,0x44290693}},	//   нні_, žai_, _všim, lja_
  { {0x25e90037,0x16000011,0xf3f9004b,0x85780048}},	//   _जानी_, ऊज़र_, enţa_, нсът_
  { {0x351c000b,0x44290694,0xeb990695,0xf8b20009}},	//   לוונ, nja_, мий_, _כשל_
  { {0xe7db0037,0x48640014,0xb4360009,0x50640696}},	//   _भाजप, _сърб, דָיו_, _стра
  { {0xc334000b,0x44cc0066,0x25ac0697,0x44290269}},	//   רוץ_, bě_, _gfdl_, hja_
  { {0x44290309,0x186a00f5,0x63a90698,0xf3f9004b}},	//   kja_, дани_, pcen, anţa_
  { {0x2c170037,0x2d850060,0x321c0132,0x44290699}},	//   थाओं_, _izle_, _envy_, jja_
  { {0x7c29001c,0x4429069a,0xf0920009,0x3b09004c}},	//   mjer, dja_, ינט_, _цело_
  { {0x0dba0003,0x7aed01aa,0x7d030132,0x2d9e00b0}},	//   باحث_, dtat, owns, øte_
  { {0x3aeb0033,0x44290028,0x1fb6069b,0xd9420014}},	//   løp_, fja_, _испр, _вещи
  { {0x442f069c,0x4429069d,0xb063008e,0xc4d20009}},	//   _jog_, gja_, äätt, יגל_
  { {0x61460108,0x7aed0101,0x442f0027,0x64440051}},	// [9c0] _télé, gtat, _mog_, rhii
  { {0x4a43002d,0x8f370009,0xd5e00011,0x69c3069e}},	//   анув, _סניף_, _नाइज, _jene
  { {0xd5be001e,0x442f0070,0xc879003a,0x7c3b069f}},	//   šāka_, _oog_, luğa_, kkur
  { {0x4429003e,0x44cc0013,0x442f06a0,0xbb860012}},	//   cja_, vě_, _nog_, _للجي
  { {0xab5d003e,0x7aed06a1,0x3aeb00b0,0xb6060048}},	//   ważn, ctat, jøp_, вяйк
  { {0x7673002d,0x44cc0066,0x98a7000d,0xdb06000e}},	//   аліф, tě_, ână_, _bekö
  { {0xc5f30009,0xdff40011,0x0466004c,0x442f06a2}},	//   ידג_, ेजाद_, ктим, _bog_
  { {0xdb0b0017,0x1d070001,0x7c290033,0x2465001e}},	//   _negó, тећи_, gjer, tēma_
  { {0x4e060046,0xbea60098,0x442f06a3,0xa01b0028}},	//   _изаб, _разк, _dog_, kmör
  { {0x8f75002d,0x442906a4,0x3cfa0012,0x44cc0030}},	//   _сусі, zja_, _يعاد_, pě_
  { {0x7aed0272,0x7c3b0039,0x442f000f,0x35dc0037}},	//   ztat, bkur, _fog_, _बाज़
  { {0xc173000b,0x320a00f1,0x7aed000e,0xfd570009}},	//   יחת_, žby_, ytat, _בשבי_
  { {0xada20028,0x7ad40012,0x7641008e,0x2d8c0030}},	//   _þúsu, _إقتص, _ylly, ýden_
  { {0x442f0052,0x12a90003,0x539b0009,0x6f160248}},	//   _zog_, _أدنى_, _חידו, _dryc
  { {0x64480039,0xe29b000b,0xbca50003,0x69fb000b}},	//   īdin, _קשור, امري, _חלוק
  { {0xbf670003,0xe8d7000b,0x69c3000e,0x0ed20011}},	//   _لدخو, _סוחר_, _zene, _सिंड
  { {0x4c9406a5,0x7aed06a6,0x69c306a7,0x629c06a8}},	// [9d0] ритс, utat, _yene, _biro
  { {0xe1f00003,0x201e001e,0x442906a9,0x7aed06aa}},	//   قسم_, ētie_, sja_, rtat
  { {0xdb0b03eb,0x4429000f,0xdce80066,0x645a0054}},	//   _segü, pja_, _vydě, ètic
  { {0x92b70003,0x629c001e,0xdd3a000b,0x645a0061}},	//   _لحسا, _eiro, _נערכ, étit
  { {0x7c29001c,0x16350014,0xd7ee0003,0x442f000d}},	//   vjer, ледя, سكو_, _rog_
  { {0x64420006,0x6d580010,0x7f3c000b,0x442f0052}},	//   _aloi, _žvai, ועדו, _sog_
  { {0x78780026,0x56920001,0x69c806ab,0xe4c80012}},	//   tívt, љајт, dade, نبين_
  { {0x130904b3,0x63ad06ac,0x7c3b0010,0x84580015}},	//   ений_, ncan, ukur, крыт_
  { {0xc0520093,0x69c300c6,0x97ea00a2,0xab5d0034}},	//   _הזן_, _pene, ıştı, rażo
  { {0xc332000b,0x7c290033,0x69c806ad,0xee87003c}},	//   צוי_, sjer, gade, _рыбо
  { {0xe4e4002d,0xa2cf0011,0x6ec60011,0x442f06ae}},	//   _вічн, _दिक्, ़ीनु, _tog_
  { {0x64420061,0x1cba0009,0x69c8005e,0x69c306af}},	//   _gloi, _נמנע, aade, _wene
  { {0xa3e80044,0x63bb06b0,0x93270012,0x85430073}},	//   _बात_, mbun, _جران, šėli
  { {0xa2d80044,0xb0630051,0x63bb06b1,0x2ca506b2}},	//   _मित्, äärt, lbun, _kuld_
  { {0xa01b0028,0xdb1d06b3,0x5d860012,0x33f60223}},	//   rmör, _desí, الأل, лчас
  { {0x6f16006f,0x6e3c04d2,0x60da006f,0xb97a0009}},	//   _tryc, skrb, _åtmi, _אנצי
  { {0x63bb0052,0xc053000b,0x6f160066,0xcaa60012}},	// [9e0] ibun, _לזה_, _uryc, اصري
  { {0xbf9b0009,0x479b0009,0x63ad06b4,0x079b00af}},	//   _איפש, _איפס, acan, _אספל
  { {0x25e90044,0x68e1003a,0x7ae0001e,0x645a0025}},	//   _जाती_, nuld, zumt, étis
  { {0x63ad06b5,0x69c806b6,0x3d170011,0xdb1d0030}},	//   ccan, zade, पटने_, _zesí
  { {0x200d016d,0x601b008e,0xa2cf0011,0x68e106b7}},	//   _daei_, _hämä, _दिग्, huld
  { {0x99850010,0xb5aa0003,0xa5f805c6,0x3cb40024}},	//   nklų_, راتك_, теку_, айкр
  { {0xa3e80044,0x7bc600c6,0x6f0900c1,0x614600b3}},	//   _बाद_, _keku, _esec, _сева
  { {0x7ae006b8,0xb4fb0009,0x711b0009,0x76580073}},	//   tumt, תפקי, _אולפ, sivy
  { {0x38550098,0x200200a2,0x9f4a004a,0x38a80061}},	//   _търс, deki_, ämän_, _sûr_
  { {0x64a6002d,0x2ca50058,0x68e10058,0x787d0031}},	//   _бажа, _fuld_, fuld, névv
  { {0x6e93000a,0x68e1001e,0x5e930012,0xb8210011}},	//   _اللا, guld, _اللط, यालम_
  { {0x6485000e,0x7bc606b9,0xa3bb0610,0x27e606ba}},	//   lóin, _neku, _अभय_, ngon_
  { {0xa8570093,0xac970003,0x20570009,0x69c806bb}},	//   ריכה_, _إننا_, ריכל_, pade
  { {0xdd2006bc,0x539b0009,0xdb9b0009,0xa19406bd}},	//   _může, _ניגו, _נסגר, _калч
  { {0xe7a40037,0x68e10017,0xdb0b0028,0xf1b30009}},	//   _ओलंप, culd, _hegð, _פסק_
  { {0x200200a2,0xa98b0009,0x7bc6016d,0x2480001b}},	//   ceki_, _אָחִ, _ceku, glim_
  { {0xba550001,0x291806be,0xaa550048,0x92b40012}},	// [9f0] авај, _arra_, аваш, محلا
  { {0x5d550024,0x6fc70011,0x249206bf,0x63bb06c0}},	//   _вкот, ारभू, amym_, zbun
  { {0xdfd10003,0x3eb9001e,0x6e9a0009,0x7e9a0009}},	//   قيا_, lpst_, _שבתח, _שסתו
  { {0x64b10039,0x98be0002,0x2ca50097,0x27e9005e}},	//   _jāie, cztą_, íldu_, üan_
  { {0xd00c000b,0xfe710003,0x7c2b005e,0x61f80159}},	//   גּוֹ, يدت_, ögru, _obvl
  { {0xbada000b,0x7c2d06c1,0x68e10060,0x20020034}},	//   _בקשת, ljar, yuld, zeki_
  { {0xce380093,0x91f5001a,0x7dd0000e,0x9d450021}},	//   ראות_, híc, lósí, рейд
  { {0x201f007d,0x68e10070,0x7c2d06c2,0x63bb0415}},	//   _unui_, vuld, njar, ubun
  { {0xe4320012,0x787a0009,0x3aef0060,0x63bb06c3}},	//   تفيد, _יָמו, nüp_, rbun
  { {0x63bb06c4,0x68e10060,0x5f440012,0x994a0060}},	//   sbun, tuld, _انكل, nışa_
  { {0x10210037,0xafdb0058,0x80660024,0x8bd50012}},	//   यांश_, dkøb, ивож, _نقاش
  { {0x68e100a2,0xdd2f0066,0x7afd06c5,0x84640048}},	//   ruld, _běže, _opst, _лъче
  { {0x387e0108,0x7c3a000b,0xb8870028,0x644900da}},	//   _être_, _שתנס, _smíð, mhei
  { {0xbb840003,0x69c706c6,0xff160009,0x9f960009}},	//   _الهي, _neje, בקשת_, ידרה_
  { {0x7afd0039,0xdd920012,0xe47a004c,0x660306c7}},	//   _apst, زور_, вљај_, ienk
  { {0xef1a0014,0x6206001e,0x44f1001a,0x442d06c8}},	//   _ами_, ārlū, _mơ_, nje_
  { {0x69c7000f,0x645a0061,0x442d0027,0x487b000b}},	// [a00] _beje, étiq, ije_, _בטקס
  { {0x601b0006,0x171b000b,0x6f09003a,0xa2d80037}},	//   _tämä, _יופע, çece, _मिस्
  { {0x443f0005,0x4ddb000b,0x442d06c9,0x7bc606ca}},	//   kku_, _בחיו, kje_, _teku
  { {0x1ae60047,0xf992000b,0x351b000b,0xca29000b}},	//   _комм, קרא_, _סוכנ, ום_
  { {0x69c7000e,0x2d810052,0x6485000e,0xa3df0011}},	//   _feje, ühen_, tóin, _ताज_
  { {0xaa460014,0x442d0002,0x443f001e,0x91a70037}},	//   _тегл, eje_, eku_, _फ़्लै
  { {0x44f10020,0xdb0b0028,0x7ae406cb,0x9c46002d}},	//   _cơ_, _segð, luit, ихил
  { {0x644906cc,0x628106cd,0x645b004b,0x64850031}},	//   ghei, ello, giui, sóin
  { {0x23380047,0xab380015,0x55e6003c,0xb8e90011}},	//   уппы_, уппу_, _возб, ली_
  { {0x11d80003,0x442d06ce,0x443f06cf,0x75d30012}},	//   دودة_, aje_, aku_, _ويقا
  { {0x442d009b,0x02170009,0x82330012,0x644606d0}},	//   bje_, בחים_, تريا, _olki
  { {0x442d003e,0xdb190052,0xdb0901a0,0x68e301a0}},	//   cje_, _bewä, cceï, àndi
  { {0x95cb0048,0xe7870560,0x29020030,0x7e770012}},	//   кува_, руно, ňka_, لاسئ
  { {0x7ae40108,0x6e9500f5,0xbb3b0009,0x7aef01a0}},	//   duit, сигу, _בעדי, àcte
  { {0x7c970012,0x6c970012,0x0ed30011,0x69c706d1}},	//   لشرا, لشرط, _तिकड, _reje
  { {0xe5170044,0x386900c6,0x34480001,0x69c706d2}},	//   थिति_, _ujar_, ачун_, _seje
  { {0xd6d1000a,0x7ae406d3,0xdb190052,0x228b0033}},	// [a10] _عقد_, guit, _gewä, søke_
  { {0xc2c40003,0xe4e7002d,0xd2b70009,0x3aef0060}},	//   تيكي, _кімн, ילמת_, rüp_
  { {0x442d06d4,0x7c2206d5,0x64410227,0x929d0034}},	//   yje_, _onor, ëlis, zwło
  { {0x3ea900b6,0x7d15000e,0x7ae406d6,0xc86406d7}},	//   _kuat_, _ázsi, buit, отчи
  { {0x44f10020,0x3b640014,0xe7080003,0x7ae4000d}},	//   _sơ_, _дърв, لتون_, cuit
  { {0x9f56000e,0xc332000b,0xcb360009,0x85e80024}},	//   ágát_, _צום_, _הנשק_, идів_
  { {0xd5ae0003,0x3ea9000d,0x442d06d8,0xfdf80009}},	//   رفي_, _luat_, tje_, יצגת_
  { {0x442d0010,0xa2d80037,0x44f10081,0xdb0b0031}},	//   uje_, _मिश्, _vơ_, _megö
  { {0xa3e80044,0xdb0b000e,0x9b450003,0x442d06d9}},	//   _बार_, _legö, صندو, rje_
  { {0x3e7b0061,0x2b4d0002,0x4a4506da,0xa2d80011}},	//   rêts_, rzec_, снов, _मिर्
  { {0x84670098,0x49990015,0x65150012,0x867a0009}},	//   _къде, ытия_, _دوائ, _ערעו
  { {0x3ea906db,0xa3bb0037,0xd0790024,0x66fa0035}},	//   _buat_, _अभि_, исяч_, bākā
  { {0xac740003,0x14740003,0x44d305bd,0x94740003}},	//   _بالش, _بالج, eć_, _بدلا
  { {0x28d80037,0x6d4e0052,0x877a0009,0x7f760009}},	//   _डिलि, tzba, ראשי, מערב_
  { {0x25e90044,0xc212000b,0x3205002a,0x6efd006f}},	//   _जारी_, _זהו_, mely_, _påbö
  { {0xa01b004a,0x320506dc,0xb60306dd,0x7ae406de}},	//   llön, lely_, _hráč, tuit
  { {0x232706df,0x44d30002,0x32110002,0xab2706e0}},	// [a20] боти_, ać_, _bazy_, бота_
  { {0x239b0010,0x1757000b,0x88c60012,0x7ae406e1}},	//   mąjį_, _לספר_, متصل, ruit
  { {0xa3e80037,0xdfda0014,0x7ae406e2,0x21a30048}},	//   _बाल_, гъл_, suit, чихм
  { {0xa9880009,0x2bba0012,0x6446008e,0x6fe90024}},	//   בָנִ, _حادة_, _ulki, ифів_
  { {0x3205002a,0xd00f0003,0xa2a20037,0xd7f9002d}},	//   kely_, عله_, _कंट्, рує_
  { {0x2bd00037,0x6f1b0052,0x91fc001e,0xcf250012}},	//   तःका, _druc, gnāl, ترمي
  { {0xd1320003,0x2a6f000e,0x186a046d,0x320506e3}},	//   _عمر_, égbe_, _бави_, dely_
  { {0x91fc001e,0x66fa001e,0xe8e0001a,0xf06306e4}},	//   anāl, tākā, _chụp_, _експ
  { {0x64400028,0x6611004a,0x6bd30012,0xffb70012}},	//   rkmi, ökkä, ستير, _طُلب_
  { {0x64400005,0xd6cf0003,0xd8f8002d,0x44d30002}},	//   skmi, _أقل_, аної_, yć_
  { {0x5d86000a,0x28f8002d,0x201200b6,0x2db70009}},	//   _الال, шень_, _bayi_, _הלבן_
  { {0x3ea10051,0x0eeb0024,0x1799003c,0x9f9902e3}},	//   _siht_, льги_, ивны_, ивну_
  { {0x21270020,0x1dac0037,0x9b960012,0xab960012}},	//   ̣nh_, _चलात, _الشت, _الشغ
  { {0xef11000b,0x6d140011,0xb3850012,0x25fb0011}},	//   וּל_, डिंग_, _بجمه, ल्पी_
  { {0x725b000b,0xf65f0058,0x32110002,0x7bcd0028}},	//   _תכופ, dsæt_, _razy_, taau
  { {0x0ca80662,0xc3340009,0x94a806e5,0x44d30034}},	//   стри_, ֗וּ_, стра_, rć_
  { {0x6a350046,0xc3340009,0x8c1b0009,0x60080009}},	// [a30] онађ, חוּ_, נומי, _הִתְ
  { {0x91f5001a,0xdd210010,0xa3e50011,0x69ca01e3}},	//   hín, _rįžt, _नाक_, _jefe
  { {0x82340003,0xcdf60009,0xa3e80011,0x30150560}},	//   أرقا, _ומתי_, बला_, ждер
  { {0xac1906e6,0x06ed0037,0xb9010037,0x753a0052}},	//   _тому_, _जमाव_, _दि_, ätze
  { {0xf5ab000b,0xb066004a,0xcff80009,0x69ca0227}},	//   ְבֵּ, ltää, מצאה_, _oefe
  { {0xf770000a,0x66150002,0x6f1b06e7,0x3e6b003c}},	//   ران_, ndzk, _vruc, ышен_
  { {0xb0660006,0x32050036,0xc212000b,0x91fc001e}},	//   ntää, vely_, _קהל_, rnāl
  { {0x69d806e8,0x4c920001,0x6f1b06e9,0xb066008e}},	//   _adve, мијс, _truc, itää
  { {0x6f1b0002,0x52a60015,0x69ca06ea,0xe7330003}},	//   _uruc, овым_, _befe, _عصر_
  { {0xe4e7002d,0x4f880009,0x239b0073,0xe8f906eb}},	//   _гідн, _הָעֲ, vąjį_, ало_
  { {0x386d012e,0x24610010,0x32050444,0x53fb0003}},	//   _kjer_, nėms_, rely_, _مرشح_
  { {0xc85a002d,0xdb1d004a,0x60dc06ec,0x76430623}},	//   ршої_, _kesä, árma, lkny
  { {0x7bcb001e,0xc7f60009,0x02450012,0x2d8506ed}},	//   _iegu, חזרת_, _وَصَ, ülen_
  { {0x64a60294,0x8afa0009,0x8f9a0009,0xceb20009}},	//   жава, _כהני, יירי, ויך_
  { {0xf3f9007d,0x26090037,0x7bcb00b6,0x6da30294}},	//   enţi_, ाज़ी_, _kegu, дира
  { {0xc486002d,0x628506ee,0xf9920009,0xac860024}},	//   ілак, elho, _קרה_, ігал
  { {0xe7ff0037,0xf65f0058,0x49ca0001,0x764b0010}},	// [a40] ोजना_, tsæt_, илан_, _įgyv
  { {0x5e570003,0x7bcb06ef,0xceb90030,0x69c10032}},	//   _وليس_, _legu, íře_, nble
  { {0xf65f0058,0xf3f9004b,0xad590048,0xe7aa05c8}},	//   rsæt_, anţi_, _грях_, авел_
  { {0x6edb0037,0x225e009b,0x644d01da,0xfe7f01a0}},	//   _निशु, zitk_, chai, nuïn_
  { {0x63b40002,0xb1e60012,0x57fb0009,0x6fcc0011}},	//   ągną, _وأسه, שלנו, ारबं
  { {0x7bcb0051,0x386d0058,0xc4da0001,0x6b8b000e}},	//   _aegu, _ejer_, ађи_, ügge
  { {0xe0d70014,0x344a01d4,0x69dc0034,0xdb070097}},	//   _мвр_, ичин_, órem, élög
  { {0x9cd7000b,0x69ca003a,0x6444004a,0x78a40051}},	//   קופה_, _sefe, nkii, _niiv
  { {0xe3af0003,0x16660014,0x93b7000b,0xcb070003}},	//   خرى_, _двам, חלפו_, قيين_
  { {0x7af6007a,0xa9540046,0xb066004a,0x291c013a}},	//   ityt, звољ, ytää, _prva_
  { {0x6444004a,0xf21f0037,0x7bcb0097,0x69ca0097}},	//   kkii, बाज़_, _fegu, _vefe
  { {0x69ba0037,0xcce50003,0x6aa306f0,0x7bcb0010}},	//   _श्री, _رسمي, _einf, _gegu
  { {0x64b1001e,0xb09b0009,0x889b0009,0x24610073}},	//   _jāin, ייטר, יבטי, zėms_
  { {0x3f850039,0xb066004a,0x69d80040,0x29180248}},	//   ālu_, ttää, _udve, åras_
  { {0x34950046,0x91bb000b,0xa9670001,0x660706f1}},	//   завр, _דמוי, _миља_, rejk
  { {0x1bbb0003,0xa8340012,0x2bbb0012,0x24610073}},	//   شارع_, _يعيش, شارة_, vėms_
  { {0x644d004a,0xe8df001a,0xb066004a,0xdce7003a}},	// [a50] rhai, _thừa_, stää, ğlıd
  { {0x7c26012e,0x539b000b,0x65950294,0x644d01a4}},	//   _enkr, שימו, _напу, shai
  { {0x68e800b6,0x3a380070,0x7af60010,0xc5f20009}},	//   nudd, _dorp_, atyt, _אדי_
  { {0xa6c90003,0x7d7a0009,0x38580024,0x80a80024}},	//   موصل_, _לנתו, орію_, івів_
  { {0x9bb60009,0x54540048,0xd247003c,0x7680008e}},	//   _מהרה_, _цвят, _дэви, pöyt
  { {0xd1260003,0x68e80033,0x24610010,0xbb3a000b}},	//   _كم_, kudd, pėms_, _העשי
  { {0x6aa300b8,0x91fc0035,0x443906f2,0xc5080012}},	//   _rinf, anāk, _kos_, قتيل_
  { {0x443906f3,0xfbd10012,0x44f30018,0xdfd10012}},	//   _jos_, رتب_, rã_, _سيئ_
  { {0xcf27000a,0x9f4f0164,0xec460048,0x78a4005e}},	//   _برأي, regó_, язъл_, _riiv
  { {0x443906f4,0x4426012e,0x7e550003,0x68e800b6}},	//   _los_, _eno_, _عناص, fudd
  { {0x7bcb06f5,0x69c106f6,0x7e7c06f7,0xfe7f01a0}},	//   _tegu, rble, vorp, tuïn_
  { {0x44d7007d,0xe8df0020,0xa06a0001,0xb4fa000b}},	//   mă_, _chứa_, сама_, _לפעי
  { {0x44d7007d,0x644b06f8,0x7d1e02f3,0x78a401a3}},	//   lă_, _ilgi, _srps, _viiv
  { {0x44390149,0x629d0013,0x2fcd06f9,0x539a0009}},	//   _aos_, ůsob, _leeg_, _פיסו
  { {0x44d7007d,0x7ae90006,0x78a4019a,0x88c40012}},	//   nă_, luet, _tiiv, _قتيل
  { {0x44260164,0x443906fa,0x7c950024,0x5baa05c8}},	//   ño_, _cos_, друц, скам_
  { {0x78bb0027,0x443906fb,0x9aa60012,0x29030031}},	// [a60] _čuva, _dos_, سماو, _apja_
  { {0x3af40248,0xd196004c,0x69960048,0x9196004c}},	//   räp_, пшењ, прех, пјеш
  { {0xc006007c,0x18a60015,0xe63b000b,0x44d7000d}},	//   зпек, чаем, _התיכ, jă_
  { {0x44d7000d,0xa3ea0037,0xafdb0623,0xa4b70009}},	//   dă_, _टाइप_, lhør, _מלטה_
  { {0x8c1b0009,0xc7d70009,0xdfcf0012,0x91fc0035}},	//   _הוכי, פוסי_, ايه_, unāk
  { {0xb1460001,0x7bc40010,0x76a9002d,0xceb30009}},	//   _енгл, lbiu, ітів_, עיו_
  { {0x44d7000d,0x69dc06fc,0x4439016d,0xf8e005f3}},	//   gă_, _idre, _yos_, _पटिय
  { {0xb6030333,0xad1b000b,0xbab806fd,0x68e306fe}},	//   ēšan, מוצר, огих_, ánde
  { {0x69ce00c6,0xdee305f7,0x7ae406ff,0x22860700}},	//   _kebe, _поти, nrit, зунг
  { {0x64aa0013,0x44d7000d,0x78ad0027,0xb6bb000b}},	//   _přid, bă_, _čavr, _לצמי
  { {0x44d7007d,0x6e2800c5,0x7ae4008b,0x55bb000b}},	//   că_, _indb, hrit, _המבו
  { {0x69ce008b,0x44260701,0xa2dd0011,0x68e80702}},	//   _lebe, _uno_, _पिल्, rudd
  { {0x69dc001c,0xa857000b,0x8c1b000b,0x96f80048}},	//   _odre, ליטה_, _לואי, пеят_
  { {0x76890065,0x6595002d,0x539b000b,0xdb9b000b}},	//   mþyk, дагу, _הידו, _הסדר
  { {0x7ae40703,0x51fb000b,0x01fb000b,0xd217000b}},	//   erit, _ההוצ, _הפול, _זקוק_
  { {0x3cf60011,0x7ae40704,0x83fd0031,0x69dc0705}},	//   ँढ़ें_, frit, gnőh, _adre
  { {0x44d701b3,0x69ce00c6,0x44390706,0xe3b00003}},	// [a70] ză_, _bebe, _vos_, ارف_
  { {0xe603004a,0x52d8003c,0x69ce0707,0xc87f0032}},	//   ätää, ямую_, _cebe, loß_
  { {0x44390708,0x15fa0009,0x45fa0009,0x629a0073}},	//   _tos_, _והתע, _והתג, imto
  { {0xf990000a,0x44d7000d,0x9cd6000b,0xaadd0037}},	//   ابك_, vă_, _קורה_, _मिलक
  { {0x3ea50051,0x200b0002,0x8c1a0009,0x765e008e}},	//   _pilt_, ieci_, _וורי, _ympy
  { {0x44d701b3,0xcb12000b,0x69ce0358,0xff180009}},	//   tă_, _שלם_, _gebe, פקות_
  { {0x3ea50065,0x7c390002,0xc879003a,0xdb1d0029}},	//   _vilt_, _powr, luğu_, _nesú
  { {0x3ea500bd,0x44d7007d,0x44390028,0x200b0027}},	//   _wilt_, ră_, ðs_, jeci_
  { {0xd5b1008a,0x44d7007d,0x04560003,0xadf50014}},	//   _các_, să_, بلية_, _опаш
  { {0x8f680003,0x44d7000d,0x2d850002,0x39450069}},	//   _عملك_, pă_, _tyle_, дног
  { {0x7ae40026,0x24890709,0xd00a0048,0xb22b0024}},	//   zrit, klam_, оене_, раiн
  { {0x7ae4004a,0x7bcf000d,0xe3b30003,0xd05a0024}},	//   yrit, _necu, _أرض_, ірні_
  { {0xba550014,0xfa350012,0x44f70060,0x63050012}},	//   _откъ, _يرتد, eç_, _آوتل
  { {0xc87900a2,0xf2d20093,0x91fc001e,0x01650001}},	//   duğu_, _יעד_, riāc, _окло
  { {0x7ae4070a,0x91ba0009,0xd12e0012,0x6d43070b}},	//   writ, _ומצי, _نمو_, nyna
  { {0x78b30333,0x69ce070c,0x7bcf000d,0x69c5000e}},	//   ēgvā, _sebe, _cecu, ebhe
  { {0xd5b10020,0xf093000b,0x7bcf070d,0x7bc4070e}},	// [a80] _xác_, _בנה_, _decu, rbiu
  { {0xff5f0108,0x6aa70070,0xe8df001a,0x24890160}},	//   raît_, _cijf, _chữa_, alam_
  { {0xa90a0003,0x7e63004a,0xfbc6070f,0x50ba0012}},	//   تيال_, dinp, _обно, زداد_
  { {0xc879003a,0xa3c30011,0xad1b0009,0x7d1c0097}},	//   buğu_, ्रफ_, _ווטר, _ársi
  { {0x3946001e,0x69ce0710,0xc8790060,0xa09b0009}},	//   ņos_, _tebe, cuğu_, קינט
  { {0xd5b1001a,0x64670002,0x7e630698,0xdcba022a}},	//   _rác_, ąpił, ginp, ощи_
  { {0xaaa70011,0x69350030,0xc6930009,0xe4d30012}},	//   _कूटक, _přeš, דאג_, نتيب
  { {0x64aa0066,0xd7060001,0xdb1d01e3,0x515b0009}},	//   _přib, _озби, _resú, _וכלו
  { {0x41e6002d,0xb9e6002d,0x6d43003a,0x27f70711}},	//   міна, міни, ayna, _تفقد_
  { {0xd626000a,0xd2500003,0x51f8002d,0x2fc6002c}},	//   _تعري, اند_, чною_, lbog_
  { {0xa01b004a,0xbfa3001a,0x45460003,0x248903ef}},	//   llöi, hiề, _تناق, ylam_
  { {0xc32a000a,0xd5b10020,0xb9060011,0x7b6605c8}},	//   _وكان_, _tác_, _पि_, _отле
  { {0xd78b000a,0x20190005,0x200b0712,0x44da0004}},	//   تخدم_, rdsi_, reci_, eď_
  { {0x3eb90164,0x200b0604,0x1cbb0012,0x44cc0034}},	//   _éste_, seci_, قارب_, oś_
  { {0x320c0087,0x7588003c,0xb8860030,0x1df8003c}},	//   medy_, дств_, _smíš, ьеры_
  { {0x28d80011,0xc2c50012,0xc1730009,0x320c0030}},	//   _डिजि, فيري, _שחק_, ledy_
  { {0x6d430002,0x7b670001,0xa3b30011,0x64930060}},	// [a90] zyna, фтве, जुट_, eçic
  { {0x248900b6,0x22f70009,0x66bc0009,0x82150012}},	//   slam_, וזמן_, _ומזה, عواص
  { {0xa3c30044,0x248900a2,0x6aa70070,0xc6780012}},	//   ्रम_, plam_, _vijf, _تحيط_
  { {0xf8b10009,0x26d90713,0x5ed5042a,0x61fe0227}},	//   אשׁ_, osso_, ежду, afpl
  { {0xdb020020,0x320c0029,0xb3ba0009,0x6c560009}},	//   _ngoà, kedy_, _ממרכ, _נישא_
  { {0xee38002d,0x645a001e,0x245100d9,0x88c70012}},	//   мні_, ītie, _máme_, _يتأل
  { {0x645a001e,0x7aed0714,0x61ea0097,0x7e630715}},	//   ūtie, luat, ófle, rinp
  { {0xdb1d024c,0xa1940015,0xf4120009,0x6d430716}},	//   _besø, _расч, ָ֤ה_, ryna
  { {0x2ef40014,0x64aa0066,0x1306003c,0x99f50024}},	//   _изтр, _přic, еный_, няні
  { {0xcb12000b,0x291e0010,0x05b80012,0x320c0132}},	//   נלי_, _štai_, _قدمت_, gedy_
  { {0xa3c10011,0xf1b20011,0xb8990009,0xa5f80024}},	//   ुरा_, _जलसन, ּבָש, _цеху_
  { {0x7aed00b6,0xc6890009,0xad1a0009,0x9d1a0009}},	//   kuat, _הא_, _מוער, _מועט
  { {0x64490052,0x64aa0066,0x201e0066,0x7f190024}},	//   mkei, _třic, ěti_, міру_
  { {0x443d0036,0x8b3a000b,0xbb3a000b,0x24800002}},	//   _how_, _מתנצ, _מעני, woim_
  { {0xf2020037,0x6449004a,0xe8f50012,0x52380012}},	//   र्फ़_, okei, _أستخ, _تسنح_
  { {0x301a0012,0x6da3004c,0x78a90717,0xd0190034}},	//   _رتبة_, уиса, _niev, _nań_
  { {0x3b070098,0x2c010037,0x6449004a,0x7aed0718}},	// [aa0] нето_, व्यू_, ikei, guat
  { {0x9b93000a,0xb77b0093,0x877b000b,0x98d30037}},	//   الكت, _מאפש, _מאפי, _दबाए
  { {0x64490006,0x7afb0051,0xef18001e,0x321803d9}},	//   kkei, htut, āļu_, _vary_
  { {0x443d0036,0x672400bd,0xdfcf0003,0x7aed00b6}},	//   _now_, _krij, ميم_, buat
  { {0xc7d7000b,0x0c230014,0x91fc0035,0x78a90719}},	//   תוני_, _смян, onāt, _diev
  { {0x25fb0037,0x2fc60058,0x2907071a,0xdb02001a}},	//   ल्ली_, sbog_, _opna_, _ngoá
  { {0xa3e40044,0xb8660012,0xc8660012,0xf5170012}},	//   _नया_, _كارو, _كطري, فتيش_
  { {0x6449008b,0xd6d20003,0x85030012,0x6724071b}},	//   gkei, _مقر_, اوين, _orij
  { {0xa3b70003,0x88bc0066,0xdb190052,0x7afb002c}},	//   راير_, zvěd, _gewü, gtut
  { {0x6449007a,0x24510064,0x629e020d,0xdb070025}},	//   akei, _ráme_, nmpo, élég
  { {0x753a0052,0xc5f30009,0x75d30012,0xbd290012}},	//   ätzl, _תדע_, _إيما, _يأمل_
  { {0xa3c30037,0xc173000b,0xbb860012,0x3866071c}},	//   ्रण_, טחת_, _كلاي, nior_
  { {0xc43b0093,0xe29a0014,0x4c3b0009,0x2d8c06ed}},	//   _מתאי, _еад_, _מתאב, üden_
  { {0x27e000a2,0x661a0006,0x23690012,0x6724071d}},	//   _edin_, _jatk, _تحمي_, _drij
  { {0xdcb10020,0x25a5006f,0xdcfa001e,0x7c3d0470}},	//   ể_, äll_, _iztē, _posr
  { {0x68e70029,0xdddc0030,0x661a071e,0x6d58071f}},	//   ájde, borů, _latk, izva
  { {0x88bc0066,0xeab30012,0xde790048,0x2458003c}},	// [ab0] svěd, اعر_, _обич_, хать_
  { {0x83fd000e,0xda7800b3,0xd9f00011,0x78a90720}},	//   lnőt, нях_, चलित_, _siev
  { {0x78a90039,0xa2dd0037,0xd5b1001a,0x7aed00b6}},	//   _piev, _पिक्, _bán_, suat
  { {0xe536000b,0xe8d7000b,0xd3710012,0x33950012}},	//   _סטרט_, תואר_, _نهج_, _للجز
  { {0xdb07004a,0xd5b1001a,0xab5b0070,0x42990003}},	//   ämäs, _dán_, _geüp, _ينجح_
  { {0x8e850721,0xceb40009,0x60da0722,0xa0c50012}},	//   خلته, איס_, kstm, _ليسو
  { {0x92a60002,0x93c6000d,0xd6180003,0xa3d50037}},	//   _dołą, sfăş, عتها_, _सजा_
  { {0xcf7b0003,0x7afb00c1,0x62810002,0xd5b1001a}},	//   _فإذا_, ttut, wolo, _gán_
  { {0xf7730003,0x64490723,0xa3b90011,0x8c1c0009}},	//   _صار_, rkei, _चलन_, לוהי
  { {0x6449065a,0x4a450083,0x200f0724,0x6aaa0040}},	//   skei, тнов, legi_, _ciff
  { {0xf1b2000b,0x7afb0725,0x6aaa0726,0x6724001b}},	//   יסי_, stut, _diff, _srij
  { {0xa3d20044,0xf7670003,0x200400f1,0x91fc001e}},	//   वरण_, لا_, ými_, liāl
  { {0x60c4009b,0xb7da0009,0xe7370048,0x249f0097}},	//   _čime, וקרי, вея_, mmum_
  { {0x63bd00c5,0x9f61000f,0x67240727,0x3f8c001e}},	//   _afsn, ását_, _vrij, ādu_
  { {0x7ae9038e,0x7bd6002c,0xc5f20009,0x9c860012}},	//   lret, tayu, ידם_, نشره
  { {0xc9520093,0x15ee0037,0x3f89001e,0x3ce5000e}},	//   _כמו_, _जाकर_, ļauj_, álva_
  { {0xfbd2000b,0x248d0066,0x7af6004a,0xcb670146}},	// [ac0] יתן_, ilem_, _äytt, вате_
  { {0xd6aa0003,0xae9a0012,0x6fa70011,0x3cea0011}},	//   _تدعم_, _تضبط_, _गणतं, _छिपे_
  { {0x69ce0065,0xfe37000b,0xe5720003,0xa3c30037}},	//   ðbei, _סרטי_, _خطة_, ्रा_
  { {0xd5b10020,0x14d7000b,0x60dc000e,0xb90a0037}},	//   _báo_, _בוטל_, ármi, _मि_
  { {0xd5b1008a,0x69ca0065,0x92a6003e,0x2ca00051}},	//   _cáo_, ðfes, _połą, mmid_
  { {0xe7370001,0x975b0009,0x2ca0005e,0x7bc90227}},	//   тељ_, ודנט, lmid_, ebeu
  { {0x3866006f,0x8d63004c,0x621b0009,0x6fb60012}},	//   pior_, ивље, _קולק, _لمزا
  { {0x6aaa0728,0x248d0729,0x7467003c,0x2918016d}},	//   _siff, glem_, крыв_, _isra_
  { {0x6d47003e,0xa0670001,0x2d810052,0xdb0d0017}},	//   zyja, _рата_, üher_, rcaç
  { {0x91fc0039,0x3eb902d1,0x5ea60003,0xdb1b0028}},	//   ciāl, _ésta_, _شمال, rauð
  { {0x6722072a,0x3eab0064,0xdb1b0097,0xd6570009}},	//   lvoj, žitú_, sauð, _שיבת_
  { {0xdb0402d1,0x01370009,0x4bda0012,0x64930060}},	//   nció, דרטת_, _آباد_, eçin
  { {0x73360003,0xf09f0054,0xb3e90012,0xa2d30012}},	//   _جرائ, rmà_, _أعمل_, _نينت
  { {0x2ca00051,0x52d7000b,0x25bf0011,0xcf930009}},	//   emid_, _יודע_, ्रेण, שטש_
  { {0x984f0002,0xc7c70001,0xdb04000e,0x2a790031}},	//   jęć_, _испи, kció, ésbe_
  { {0x31cb0037,0x3eac0058,0x5c740048,0x2c7a0035}},	//   िर्ध, _lidt_, алст, bīde_
  { {0x6e450003,0xb275072b,0x2d8c0040,0x0bb40024}},	// [ad0] _منظم, глаш, _lyde_, рбую
  { {0x2ca00005,0x7aef0054,0x68e30649,0xa6e30028}},	//   amid_, àcti, ándo, íðus
  { {0xb8b40003,0x7ae9072c,0xa3d20011,0xc7b10012}},	//   لإنت, zret, वरा_, مّا_
  { {0x69ca0028,0x25ff0011,0xae000011,0x7ce80009}},	//   ðfer, श्री_, ल्सन_, _בַשֶ
  { {0x64aa0066,0xa01b004a,0x9f050012,0x98a70073}},	//   _přin, llös, اوتو, šnį_
  { {0xe29a008a,0x644d0006,0xdb0402d1,0xf3f9007d}},	//   _như_, lkai, ació, miţi_
  { {0x91fc0039,0xf3f9000d,0x58d40021,0x644d004a}},	//   riāl, liţi_, _вост, okai
  { {0xdb0402d1,0xc1720093,0xd9bd0037,0x8d740012}},	//   cció, _החל_, ोर्ट, جاها
  { {0x69d5000f,0xac960003,0xf3f9000d,0x644d0606}},	//   _keze, دنيا_, niţi_, ikai
  { {0xa3c30037,0x248d072d,0x25ed0011,0xfdbf0011}},	//   ्रह_, slem_, _घाटी_, ्रोफ
  { {0x644d004a,0x69d5072e,0x2ba40011,0x10a6038f}},	//   kkai, _meze, खेबा, лион
  { {0xf992000b,0x69d50070,0x7ae9072f,0x76410730}},	//   מרי_, _leze, pret, _holy
  { {0xe28e0731,0xa2e50109,0xfc160009,0x64930060}},	//   _га_, _солд, _תקני_, tçin
  { {0xa01b0052,0x75d60003,0xd5b20003,0x7c2f0025}},	//   flös, طيرا, صفر_, _ancr
  { {0x2919001e,0x2d8c0058,0xdb0b0058,0x1d070313}},	//   āsas_, æde_, _afgø, лери_
  { {0xfe7f03eb,0x644d002c,0x2ca0005e,0x63b80030}},	//   duïu_, gkai, umid_, ěvno
  { {0x69d50732,0x2ca00051,0x28d70011,0x33d50024}},	// [ae0] _beze, rmid_, _भौति, ріст
  { {0x7e1d0037,0xe8050037,0x62330001,0xa75b0009}},	//   पयोग_, ष्ठा_, беђу, _נדיר
  { {0x2d85000e,0xbd460012,0xd5b10081,0x00e6016e}},	//   ület_, _إنجي, _cám_, ужен
  { {0x984f0002,0xf3f9004b,0x7d160034,0x97c50012}},	//   ręć_, biţi_, łysk, لتهم
  { {0x442000a2,0x9f34002d,0xb7db000b,0xbe8a0001}},	//   mdi_, релі, תקני, нске_
  { {0x442f0733,0xdd25001e,0x9f970009,0xb9c50012}},	//   _ang_, līša, נדסה_, _نتفه
  { {0x20d1012e,0xdb040734,0xdcfe001e,0x41180009}},	//   jši_, pció, _izpē, _בֵּא
  { {0xdd25001e,0x661e0735,0x44200736,0x3ed60012}},	//   nīša, _lapk, ndi_, _مقرر
  { {0x15f60003,0x78ad00c1,0x7641000e,0xcfb70009}},	//   _مساح, _riav, _foly, _תלמי_
  { {0x8f990014,0x6493003a,0xcb130009,0xda140011}},	//   _ръст_, eçil, צלת_, ड़ित_
  { {0x2d8c003e,0xdfd10003,0x3a37000b,0xd48f00ac}},	//   żdej_, ييد_, ארים_, _гр_
  { {0x4d7b000b,0x228f0051,0x44200737,0xd0e50011}},	//   _ארבע, tükk_, jdi_, _किरण_
  { {0xead40047,0xe29a0020,0xdd250039,0xa2b00037}},	//   _толь, _thư_, dīša, _अंग्
  { {0x442001a2,0x98bc0066,0x33930012,0xf3f9004b}},	//   edi_, ávě_, _الهز, viţi_
  { {0xa4d5007c,0xa9bb0093,0x644d0006,0xfe7f03eb}},	//   робі, _אזור, tkai, duït_
  { {0xf3f9007d,0x859b000b,0x78a20027,0x644d004a}},	//   tiţi_, תשלו, jmov, ukai
  { {0x644d0738,0x4c940015,0xa01b031d,0x90980012}},	// [af0] rkai, ситс, slös, _حضور_
  { {0xf3f9007d,0x644d0739,0x4b7b000b,0x51f80015}},	//   riţi_, skai, תאמו, лную_
  { {0x2127008a,0xf3f9007d,0x9851003e,0xc27b000b}},	//   ính_, siţi_, nąć_, ערבי
  { {0x64420070,0xa3d60037,0xf3f9000d,0x69d50070}},	//   _nooi, हरण_, piţi_, _weze
  { {0x7bda007e,0xcee80003,0x2d9c0064,0xfe7f01a0}},	//   _בקרו, هرون_, _úver_, buït_
  { {0xb5c2002d,0x6493003a,0x20d70012,0xc8d70012}},	//   ойшл, içim, _مترج, _مزرع
  { {0xe3b1000a,0xa3b90037,0x2dd80003,0x7a410066}},	//   يرة_, _चला_, ابهة_, _vítě
  { {0x1309007c,0x20d10604,0x1c4500fa,0x629c01e9}},	//   вний_, vši_, рним, _zhro
  { {0x6d4a00a2,0x76410010,0x44230030,0x387c0031}},	//   ayfa, _toly, ěj_, évre_
  { {0x2480001c,0xf41f006f,0x7aed073a,0xc3320009}},	//   čima_, _skäl_, irat, קוי_
  { {0x6493003a,0x27e00028,0x4420003a,0x7aed073b}},	//   tçil, ðing_, ydi_, hrat
  { {0x186a00be,0xa06a0001,0xe53a0009,0xc60e0011}},	//   тами_, тама_, _בתער, ाज्य_
  { {0x6c840003,0x2bc80365,0x91d80011,0x29180097}},	//   _النم, _сухо_, यरमै, ærar_
  { {0x7aed073c,0x69da073d,0x8cb10011,0xf2d00012}},	//   drat, cate, _आंखो, _رآه_
  { {0xdd250039,0xabd60001,0xada6073e,0x7bcd0032}},	//   tīša, ицај, равл, fbau
  { {0x2b090037,0x417a000b,0x629c073f,0x44200740}},	//   _वहाँ_, _שנקב, _shro, udi_
  { {0xfe7f0054,0x2d85004e,0xe3b70177,0x929d0034}},	// [b00] tuït_, üler_, рбу_, atłe
  { {0xdd25001e,0x09e601d4,0x6edb0009,0x7bdb0032}},	//   sīša, рожн, _שחיפ, hauu
  { {0xaa7b0013,0xdb190052,0x6fb60012,0x67290741}},	//   _svýc, _gewö, لمضا, _arej
  { {0xafdb0058,0x64aa0030,0x2bba0012,0x4d7b0009}},	//   lkør, _přim, _جادة_, _יריע
  { {0x629c0742,0x2bd30037,0x60c9009b,0x78a20042}},	//   _thro, तररा, _čeme, rmov
  { {0x67290040,0x9ce6004c,0x9df8020f,0x78a20743}},	//   _drej, ацил, ункт_, smov
  { {0x98a6002d,0x69da0744,0xde570024,0xd5b90024}},	//   _виве, vate, ращі_, усі_
  { {0x9168001a,0x3205002a,0x9418003c,0x44a30012}},	//   _lực_, efly_, ужит_, يموق
  { {0xe457000b,0x69da0745,0xa2b3003c,0xa08b0009}},	//   ייקט_, tate, обыч, _יְמִ
  { {0x166300de,0x228f005e,0x1efb0009,0xd5d80009}},	//   _двум, tüki_, _בלמע, _תַּש
  { {0x91a9008a,0xa3d60037,0xe1660012,0x6f0d0746}},	//   _đã_, हरा_, شددي, _spac
  { {0x69da0747,0x90e70012,0x50670451,0x228f0522}},	//   sate, جَّل_, ртоа, rüki_
  { {0x98be0010,0x69da0748,0xd2520012,0xfe7f01a0}},	//   dytą_, pate, _ونص_, duïr_
  { {0x69d80065,0x9f400052,0x2d84003a,0x9998000e}},	//   ðvel, _weiß_, ğmen_, űrő_
  { {0x929b000b,0x6a9b0009,0xa3bd0011,0x7ea00032}},	//   _שיות, _ששונ, _आलम_, köpf
  { {0x228b0033,0x6f020749,0x31570009,0x91ad0081}},	//   søkt_, ktoc, _כיון_, _đè_
  { {0x7bcd0039,0x64aa0013,0xdb99002d,0x69d8000e}},	// [b10] rbau, _přij, увач_, _keve
  { {0xab840046,0x78b8003a,0x11d90012,0xa2cd0011}},	//   цуск, _kuvv, اواة_, दीग्
  { {0xdfd1000a,0x69d80054,0x7aed074a,0x24550012}},	//   كيا_, _meve, srat, _هندس
  { {0x6729074b,0x5fe70024,0x8c190009,0x7aed074c}},	//   _prej, ріжж, _גוֹי, prat
  { {0xdd280039,0x4fe8002d,0xdefb0015,0xf7700012}},	//   mēša, рмін_, тые_, واه_
  { {0x9e64007c,0xdd280039,0xddc3000d,0xb60700be}},	//   овід, lēša, dinţ, рядк
  { {0xc212000b,0xd658000b,0x7ae2001e,0xd46905c6}},	//   _מהם_, שיות_, _avot, лике_
  { {0x9cd8000b,0xdd28001e,0x55780009,0xeb990695}},	//   בוהה_, nēša, יעון_, лий_
  { {0x6729012e,0x9f44003a,0x69d8074d,0xc5ff0035}},	//   _urej, ümü_, _beve, ļēji_
  { {0x8b58000b,0xe7300003,0xf6530012,0x6288074e}},	//   ייחס_, _تصف_, _بئر_, godo
  { {0x8d95000a,0xf5950003,0x6442004a,0xc7a90009}},	//   _الاش, _الاج, öoik, _נב_
  { {0xa8560046,0x3d01003e,0x6e21074f,0xcd960009}},	//   стој, mów_, _halb, _הדעת_
  { {0x6e21007a,0x8b68007c,0x3d010002,0x443f001e}},	//   _kalb, _київ_, lów_, mju_
  { {0x69d800bd,0x65c3010c,0xddc3004c,0x8f9a0009}},	//   _geve, збра, збри, טירי
  { {0x3d01003e,0x9168001a,0x98be0010,0xdd920012}},	//   nów_, _vực_, tytą_, سور_
  { {0x443f0750,0xab5d0002,0x69d80070,0x78a30070}},	//   nju_, waży, _zeve, ïnvl
  { {0x4e7a0003,0x8c430014,0x7bd900b6,0x04430751}},	// [b20] _محدد_, чете, _mewu, четн
  { {0x3d01003e,0x443f0051,0xd9f90011,0xe9d70173}},	//   ków_, hju_, ्भित_, йку_
  { {0x3d010002,0x02190024,0xcdb70009,0x09060752}},	//   jów_, шіть_, _לפיה_, спен
  { {0x3d01003e,0xdd28001e,0x6ee60003,0xb69b0753}},	//   dów_, cēša, مستل, ntân
  { {0x443f013a,0xdb060097,0x645b0227,0x6d4e0754}},	//   dju_, _afkö, dhui, lyba
  { {0x7c2400a2,0x44220755,0xddc3000d,0x8f9b000b}},	//   ldir, _hak_, vinţ, ניסי
  { {0x6446007a,0x3d010002,0x89db000b,0x7ae20027}},	//   _koki, gów_, _תחלי, _svot
  { {0x44220756,0x62880002,0xa3cb0037,0x64460757}},	//   _jak_, wodo, रुप_, _joki
  { {0x23600758,0x10a30001,0x64460759,0x35fa0012}},	//   nzij_, _хитн, _moki, _مراد_
  { {0xc3330093,0xddc3007d,0x6e96000a,0x3d010002}},	//   פות_, rinţ, _الطا, bów_
  { {0x443f009b,0x3d010002,0x7c24003a,0x6288075a}},	//   bju_, ców_, kdir, rodo
  { {0x6288012e,0x4422075b,0x7648004a,0xb4250003}},	//   sodo, _nak_, ödyn, _وعنو
  { {0xdd28001e,0x69d8075c,0x76450042,0x69de075d}},	//   vēša, _teve, _pohy, kape
  { {0xdce50029,0x7aef01e3,0xa5f9004c,0x44220227}},	//   _vzhľ, ácte, јеву_, _aak_
  { {0x64aa0013,0xe5730003,0xfa97000b,0xdd28001e}},	//   _přih, سطس_, _הדגש_, tēša
  { {0xb69b075e,0xa1770009,0x92b70012,0x60c7075f}},	//   ctân, _לעוד_, محطا, íjme
  { {0xdd280039,0x3d010002,0x32bb0003,0xe2f90024}},	// [b30] rēša, zów_, ادرة_, резі_
  { {0x7b740003,0x443f009b,0xdd28001e,0x7f3c0009}},	//   أطفا, zju_, sēša, _תעזו
  { {0xd1310003,0xf652000b,0x104b0232,0x672d05b1}},	//   بما_, _חצי_, ляди_, _hraj
  { {0x19a804b3,0x442200b6,0x7c220027,0x64bc001b}},	//   ступ_, _gak_, _naor, _očij
  { {0x3d010002,0xcf240012,0x5f770012,0x29d50012}},	//   wów_, كروي, حاضر, _ويحس
  { {0x3d01003e,0xdb1d0163,0xd0d50014,0xd6290760}},	//   tów_, _besö, _могъ, роке_
  { {0x443f0761,0xed590762,0x660a0060,0x2eb50011}},	//   tju_, рой_, _öfke, ंदुत
  { {0x3d01003e,0x94790001,0x9cd80009,0x27e90060}},	//   rów_, јску_, זוהה_, _ndan_
  { {0x3d01003e,0xa5f90046,0xf414000b,0x645b0070}},	//   sów_, _везу_, לפק_, rhui
  { {0xda65007c,0x3d010002,0x7bdf0763,0x645b0227}},	//   івни, pów_, haqu, shui
  { {0xf9910012,0x443f0764,0xf4870048,0xd9450765}},	//   ببة_, pju_, _лудн, цени
  { {0x7aee003a,0x1faa035c,0x78fa0009,0xa7aa0048}},	//   üntü, икни_, ספרו, икна_
  { {0x92b70003,0x09e50014,0xb69b0284,0x501a0009}},	//   _احصا, _долн, rtân, בורו
  { {0x8aa70766,0xdd1c0066,0xb69b0753,0xa3c30011}},	//   _уред, ráže, stân, ्रक_
  { {0x64460767,0x94aa0012,0xb69b004b,0x44220768}},	//   _poki, لطرق_, ptân, _pak_
  { {0x23600070,0xe8d60009,0x69de0227,0xdb1d0769}},	//   tzij_, _ווקר_, wape, _lesõ
  { {0xf4120093,0x44220070,0x64460010,0x7c24076a}},	// [b40] ופן_, _vak_, _voki, rdir
  { {0x2360009b,0xd1960001,0xb69b004b,0x499600b5}},	//   rzij_, ошењ, ntâl, ошет
  { {0x6446007a,0xdd0f003a,0x2f040028,0x6bd60003}},	//   _toki, mışt, lög_, _وتحر
  { {0xdd0f00a2,0xc172000b,0x3947006f,0xd00a076b}},	//   lışt, וחב_, änsa_, реде_
  { {0x245c000f,0xc6f70024,0x187b0009,0xd7f90024}},	//   _címe_, жніх_, סטנב, сує_
  { {0xf4ea0015,0x6481001e,0xe2970063,0x8f9b0009}},	//   афий_, rķie, _мая_, ביני
  { {0x998c0002,0x9103076c,0xf9870012,0x6ce60024}},	//   zedł_, _опре, _آب_, ціле
  { {0xa4b70009,0x87060012,0xdb1d005e,0x7ae4076d}},	//   חלקה_, _وبذل, _eesõ, osit
  { {0x69dc0272,0x29050002,0xdd0f003a,0x6fd00011}},	//   _kere, etla_, kışt, _ड्यू
  { {0x7648004a,0xd8f8002d,0x7bdf0017,0xc50a0012}},	//   ödyl, бної_, zaqu, _نتصل_
  { {0x69dc00ec,0x91bb000b,0x929b0009,0x2247076e}},	//   _mere, ימיי, שיית, _donk_
  { {0xc867002d,0x66180304,0x9ca50012,0xdfd80048}},	//   ітни, levk, _فإنن, жър_
  { {0x20050002,0x94a90012,0xa92706dd,0x7bdf076f}},	//   ęli_, _اطلق_, _poží, vaqu
  { {0x24890029,0x8f9b0009,0x98be0034,0xaa580012}},	//   čame_, ייכי, zytę_, _دلتا_
  { {0x76480002,0xe599002d,0x16d70011,0x60870012}},	//   _mody, скві_, _डब्ब, _وشبك
  { {0xd6db0015,0x415b000b,0x69dc00c1,0xa0680001}},	//   _кто_, _כדוג, _aere, _маја_
  { {0xc334000b,0x7645004a,0xb6060029,0x8c1b000b}},	// [b50] הוּ_, öhyk, _kráľ, סומי
  { {0x69dc0770,0xc7b40009,0xbebd0073,0xeaf80012}},	//   _cere, _קבץ_, _krūv, ترفت_
  { {0xc0150047,0x7d0d0002,0xe2a60028,0x34950001}},	//   змещ, łasz, íðan_, _наор
  { {0x9d1a0093,0x351a000b,0xa98b0009,0x765a0060}},	//   _פורט, _פורנ, בָדִ, _alty
  { {0x27e00065,0xf43a007e,0xce950014,0x69dc0771}},	//   ðina_, _הגרמ, падъ, _fere
  { {0x2ca90051,0x69dc0772,0x290501bd,0x82d60009}},	//   lmad_, _gere, ytla_, _מושג_
  { {0xdfd50047,0x67d50015,0x7bdd00b6,0x20190773}},	//   _новы, _нову, _kesu, kesi_
  { {0x69c5008b,0xc57c0093,0x4d7c000b,0x20190774}},	//   lche, ירות, ירוע, jesi_
  { {0x69dc00a2,0x76d50003,0xfaf10003,0x7bdd0207}},	//   _yere, _رياض, رثة_, _mesu
  { {0xddce001e,0x2ca901b7,0x8f880009,0xba750012}},	//   ribū, hmad_, _וְעֵ, ثابت
  { {0x69c5008b,0xdcef0010,0x2019013d,0x26180011}},	//   iche, _įdėt, fesi_, फ़री_
  { {0x7bdd007a,0xd59a000b,0x859a000b,0x2d84003a}},	//   _nesu, _הבעל, _השעו, şmek_
  { {0x64aa0066,0xd5b8001e,0x69cc0037,0x24510066}},	//   _přiv, žām_, _द्वी, _námi_
  { {0xfe790013,0xe2980024,0x7aba0009,0x35c7004c}},	//   _svůj_, _даі_, _פצצו, згро_
  { {0x61e103fc,0x6da30046,0xceb20093,0x7bdd008b}},	//   mall, еира, תים_, _besu
  { {0x2ca90027,0x69c50775,0xd467004c,0x98a30306}},	//   gmad_, eche, писе_, _пище
  { {0xdd0f003a,0x7bdd0058,0x7bc40776,0x2d9e01bd}},	// [b60] pışt, _desu, rciu, ťte_
  { {0xada60046,0x7bc400c1,0x4223002d,0x63790024}},	//   _напл, sciu, ндув, істр_
  { {0x7648007a,0xda020037,0x5dbb0009,0xfe790030}},	//   _rody, र्गत_, _לזיה, _tvůj_
  { {0xc8650003,0x69dc0777,0xa06a0001,0x7bdd0778}},	//   وطني, _were, љада_, _gesu
  { {0x61e10006,0xddcf0066,0x387f006f,0xdc8b0009}},	//   kall, _řeše, _djur_, _לְךָ
  { {0x69c500c1,0x78bc00b9,0x61e10779,0x8f9b0009}},	//   cche, _turv, jall, זיני
  { {0x20c10020,0x2019003a,0x7c26009b,0x7bdd00b6}},	//   _nói_, yesi_, _kakr, _yesu
  { {0xd007002d,0x321a0002,0x244e015b,0x6d41008e}},	//   _несе_, lepy_, _týmu_, älai
  { {0xaae60003,0xcb070003,0x66180029,0x67200027}},	//   أسبو, كيين_, pevk, _usmj
  { {0x201900b6,0x3f85003a,0x20c10081,0x61e1077a}},	//   wesi_, şluk_, _bói_, gall
  { {0x69c3009b,0x3ec20010,0x92570012,0x929d0034}},	//   žneg, ųstą_, ثشير_, atło
  { {0x853b0009,0x6d3b0009,0x2bb80011,0x653b0009}},	//   _לגבי, _לתבנ, _अलगा, _לעבד
  { {0x2bd20044,0xaa7b0066,0x2019077b,0x61e1077c}},	//   _ध्या, _svým, resi_, ball
  { {0x61e10036,0x7bdd00c6,0x20190218,0xa1580476}},	//   call, _sesu, sesi_, _малу_
  { {0x4426077d,0x4c95077e,0x89eb0009,0x20c10081}},	//   _kao_, дивс, _הַחֵ, _gói_
  { {0x9584003e,0xe97b000b,0x3f9a0002,0x7c2600b6}},	//   _łącz, _לנוש, ępuj_, _cakr
  { {0xa2b5007c,0x76430002,0x2ca902eb,0x69c5077f}},	// [b70] дбач, yjny, rmad_, tche
  { {0x27e00065,0x24510066,0xe3b00003,0x44260780}},	//   ðinn_, _vámi_, طرق_, _lao_
  { {0xa1670001,0xa01b0028,0x69c50781,0x29190012}},	//   чњак, rnöf, rche, تقاد_
  { {0x69c50782,0xd7590003,0x44260783,0x68e70064}},	//   sche, يلات_, _nao_, ájdi
  { {0xba770003,0x8ee8002d,0x79950002,0x44290784}},	//   _فاست, змів_, _wyzw, mda_
  { {0x999e0010,0xef18002d,0x44290785,0x7c260786}},	//   nktų_, ямі_, lda_, _zakr
  { {0x44260020,0xc1050003,0x7de40003,0x61e10787}},	//   _bao_, _توزي, رسوم, vall
  { {0x44260020,0xcac90015,0xbd18002d,0x4518002d}},	//   _cao_, огие_, яції_, яція_
  { {0xe73f0017,0xdb09003a,0x59e10011,0xb6060030}},	//   _çõ_, _önüm, _फ़ार, _sráž
  { {0x4429004a,0x25a00066,0x99d40024,0x1dc60011}},	//   hda_, řila_, нююч, रुआत
  { {0x443900bd,0x44290101,0x64aa0066,0xd5b8001e}},	//   _ons_, kda_, _přit, žāk_
  { {0xc5e90093,0xfb150003,0x81bc0035,0x61e10788}},	//   _כד_, _يواج, ndēj, sall
  { {0x81bc001e,0x61fe006f,0x44290789,0x61e1078a}},	//   idēj, ygpl, dda_, pall
  { {0x3ebf0006,0x4429078b,0x4439078c,0xda0e001a}},	//   _muut_, eda_, _ans_, _hỏng_
  { {0x90460003,0xba280003,0xe969048c,0x7c26078d}},	//   _ينته, _رسوم_, _файл_, _pakr
  { {0x4429078e,0xf9920009,0x27ed078f,0xf4950198}},	//   gda_, _שרה_, _nden_, ерую
  { {0x7afb0006,0xae1d0037,0x3b070048,0xeb970790}},	// [b80] nuut, फ़ान_, мето_, дит_
  { {0x443903eb,0x2480009b,0x44260791,0x39ea0024}},	//   _ens_, čimi_, žo_, ідео_
  { {0xa5d40044,0x27e0008b,0x7c26009b,0x8e570009}},	//   _ब्यौ, _kein_, _takr, _חייג_
  { {0x7c2900bd,0x7afb0006,0xc209000b,0xd7ef0012}},	//   jder, kuut, יה_, لكم_
  { {0x27e00052,0x47360003,0x7afb008e,0xda660012}},	//   _mein_, براز, juut, _قاسي
  { {0x44260020,0x27ed0792,0xdd1d0042,0xa2e3004c}},	//   _sao_, _eden_, lášt, _јорд
  { {0xac940024,0xda0e0081,0x44260793,0x3494076b}},	//   накш, _bỏng_, _pao_, накр
  { {0xe9a30794,0x32c4003a,0x7af60002,0x27e00795}},	//   _расп, _köy_, oryt, _nein_
  { {0x1dcf0796,0x661c0033,0xd7030014,0x84ea0011}},	//   _स्वत, kerk, _изти, _टिकट_
  { {0xdb22003e,0x64aa0066,0xf626002d,0x44290797}},	//   _źród, _přis, _ідео, zda_
  { {0x44260101,0x09f70093,0xeaaf0003,0x55bb0009}},	//   _tao_, ומים_, جعي_, _ומבו
  { {0x286b002d,0xdbd60269,0xf1b30009,0x7afb0798}},	//   ірно_, _jääd, כסת_, buut
  { {0x27e00052,0xfe730012,0xe8200011,0xa2be0011}},	//   _dein_, ندس_, _बसरा_, _वूल्
  { {0x7ea0004a,0x44290002,0x661c0799,0x539b0009}},	//   töpa, wda_, gerk, _וידו
  { {0xa3b10037,0x443900b6,0xceb80002,0x245c0028}},	//   टेन_, _pns_, _mię_, _síma_
  { {0xd5b80625,0x6493003a,0xaa7b015b,0x4429079a}},	//   ься_, eçir, _zvýh, uda_
  { {0xda67000a,0xf094000b,0x5a350014,0x6e3a0070}},	// [b90] وائي, _בנק_, ннат, _ontb
  { {0x64930060,0x6d45079b,0x91e4004c,0x3ebf005e}},	//   tçis, ähak, кође, _ruut_
  { {0x25d6000b,0xeab10009,0x7c29079c,0x3ff50012}},	//   _אותן_, רֹן_, yder, فكار
  { {0x245c0065,0x603e000d,0xc19b000b,0x7af6079d}},	//   _tíma_, _rămâ, חשבי, bryt
  { {0x6d55000e,0x2294006f,0xa3c20037,0x26000011}},	//   lyza, täkt_, ंशन_, _राशी_
  { {0xceb8003e,0x7afb004a,0x603e000d,0xdce80060}},	//   _cię_, vuut, _pămâ, _azdı
  { {0x63a2000f,0xdc3a003a,0x7c29001e,0x98c3001e}},	//   _azon, _açıs, tder, ēvēt_
  { {0x27ed00c5,0x661c000f,0x64a20014,0x2294006f}},	//   _uden_, zerk, лаща, säkt_
  { {0x8ed80003,0x200c000e,0x64aa0066,0x6628004a}},	//   _يذكر_, ődik_, _přir, öskä
  { {0x7afb0006,0x64b10039,0x27e00022,0xfeb80003}},	//   ruut, _jāiz, _sein_, _قالت_
  { {0x2d80007d,0x661c079e,0x7afb0282,0xc2360009}},	//   şier_, verk, suut, גרתו_
  { {0x661c036a,0x88f60009,0x74280012,0x7afb079f}},	//   werk, עזרו_, _يكلف_, puut
  { {0xa8560009,0x83640012,0x61e50097,0xe81f0011}},	//   גירה_, _لدول, kahl, यज़ा_
  { {0x443e000e,0x7ae907a0,0x42550012,0x27e00032}},	//   _őt_, mset, _سنعر, _wein_
  { {0xdd920003,0x409607a1,0xf6520009,0x7ae907a2}},	//   اوز_, _прит, נצל_, lset
  { {0x46ea0098,0xfc3f0020,0x7bc907a3,0xa2d60012}},	//   _един_, _phía_, nceu, فيرت
  { {0xd9f30037,0xa87b000b,0x2cad021b,0xd38700de}},	// [ba0] _आयात_, _מרקח, imed_, ейте_
  { {0x9985000f,0xdbd6004a,0xcfb7000b,0x9f4200d9}},	//   lelő_, _sääd, _אלפי_, jaké_
  { {0x2cad0051,0x50ba0003,0x7ae907a4,0xf77f0018}},	//   kmed_, سداد_, hset, maça_
  { {0xceb80656,0x27e00028,0xe3a70012,0x375a0009}},	//   _się_, úin_, _مر_, ּכַד
  { {0x2cad0005,0xc7d70009,0x248007a5,0x645a0035}},	//   dmed_, גוני_, mnim_, ūtis
  { {0x2480013a,0x2ca607a6,0x8b0b0009,0x38600097}},	//   lnim_, _shod_, _מִלֵ, _llir_
  { {0xcd930001,0x88c50012,0xf6530009,0x63a20031}},	//   лашћ, _لتقل, רצו_, _szon
  { {0x7ea00006,0x25a00066,0x7ae90028,0xccf30009}},	//   köpo, řilo_, fset, אכה_
  { {0x7ae90065,0xf20601b6,0x1e860024,0xd3700012}},	//   gset, няно, _злам, شهد_
  { {0x2cad0132,0x629a06c0,0x4a5407a7,0x7e290012}},	//   amed_, ulto, ткос, _يسلف_
  { {0x386007a8,0x67d5002d,0x88bc0066,0x7ae907a9}},	//   _blir_, кону, jvět, aset
  { {0x61e50052,0xa3b10037,0x248000eb,0x25a10032}},	//   zahl, टेड_, jnim_, ühle_
  { {0x41e10037,0xdc8b000b,0x8cd90011,0x24800353}},	//   _फ़लस, _צְבָ, _फौजो, dnim_
  { {0xbb3b000b,0x6d550002,0xfc3f001a,0x9bb70009}},	//   _מעדי, tyza, _chín_, _נהגה_
  { {0x89330003,0x75880223,0x6ca70048,0x321e07aa}},	//   _معيا, еств_, ераж, mety_
  { {0x299b000b,0xc19b000b,0x6d550002,0x999b000b}},	//   _מסומ, _משוי, ryza, _מבוט
  { {0xdc8b0009,0x30840012,0x61e50032,0xcf270012}},	// [bb0] לְמָ, _حليف, tahl, _أربي
  { {0x7afd0054,0x3f7c0009,0x2cad0159,0x67220034}},	//   àsti, _מאחס, zmed_, dwoj
  { {0xdfd1000a,0xa3c20037,0x61e502dc,0x248000eb}},	//   ليا_, ्डा_, rahl, bnim_
  { {0x9cd6000b,0x80a70011,0x24800412,0x8f750024}},	//   _שורה_, _टीमे, cnim_, кулі
  { {0xe758002d,0xd9ad0037,0x442b0029,0x4f58002d}},	//   ниці_, _घण्ट, _iac_, ницю_
  { {0x7c2d0065,0x0376000b,0x644f0029,0x9985000e}},	//   ldar, _יתרת_, _hoci, zelő_
  { {0x64aa0013,0xfc31000a,0x2cad0051,0xbe980003}},	//   _přip, لحة_, tmed_, رضها_
  { {0x24890470,0x63a20002,0xd9e10011,0x7ae907ab}},	//   čamo_, żone, _फ़ुट, tset
  { {0x13060015,0xa6ab0003,0x321e07ac,0x1c42003c}},	//   вный_, _فائق_, fety_, рным
  { {0x2480013a,0x442b07ad,0xcb120009,0xa77407ae}},	//   znim_, _lac_, סלי_, _случ
  { {0x320b0002,0x99850031,0x3eba020d,0x7bc30030}},	//   ęcy_, telő_, _ript_, ěnuj
  { {0x7c2d0039,0x7ae907af,0x070a0012,0xc6890009}},	//   jdar, pset, ويجي_, _וא_
  { {0x2480013a,0x442d07b0,0x8c280009,0x7c2d07b1}},	//   vnim_, mde_, _רֵעֵ, ddar
  { {0x7c2b0065,0xf1b10037,0x23690002,0x645b004a}},	//   _hagr, जधान, dzaj_, lkui
  { {0x67220002,0x0c96003c,0x442d07b2,0x7c2d0227}},	//   zwoj, вшая, ode_, fdar
  { {0x644f0164,0xc48305fb,0x644907b3,0xccf20009}},	//   _coci, алск, njei, יכל_
  { {0xc053000b,0x88bc0066,0x2480013a,0xe9d20012}},	// [bc0] _כזה_, svět, rnim_, لغا_
  { {0x442d0006,0x0f57000b,0x6449019a,0xda79002d}},	//   hde_, _סיים_, hjei, няє_
  { {0x27e60101,0x442b000d,0x248000eb,0x7c2d07b4}},	//   taon_, _fac_, pnim_, bdar
  { {0x7e610005,0xd0100003,0x78a907b5,0x30a50024}},	//   _allp, صلت_, _chev, грів
  { {0x442007b6,0xf11e0037,0xbe8a0001,0x23690002}},	//   mei_, _बन्द_, мске_, czaj_
  { {0xdce1003a,0x97570009,0xd627004c,0xa3b90011}},	//   _aylı, כינו_, воље_, _ग़लत_
  { {0x442d0070,0xc5f3000b,0x60c30032,0xc0e60024}},	//   fde_, בדו_, _nunm, _шовк
  { {0x91bf0020,0xd6d20003,0x442d07b7,0x64810035}},	//   _đủ_, _نقر_, gde_, eķij
  { {0x68e10058,0xaf06002d,0x84630048,0x442007b8}},	//   _ældr, _шпал, ръще, iei_
  { {0x38660149,0xdb11000e,0x2c7a0035,0xe61707b9}},	//   lhor_, ágán, vīdu_, _иду_
  { {0xdd1f0029,0xa257000b,0xa5d80037,0x01fb0009}},	//   píšt, דביק_, _न्यौ, ופיל
  { {0xf9930093,0x38660017,0x68e307ba,0x442007bb}},	//   ירת_, nhor_, ândi, jei_
  { {0x6d5803ec,0x2d9e07bc,0x24580031,0x69ce0097}},	//   lyva, üten_, _némi_, _ofbe
  { {0xdce504b4,0xd357000b,0x42560001,0xc7b30009}},	//   _vyhľ, _בידי_, _штет, יבר_
  { {0xc1e00037,0x25a5006f,0xac19028d,0x5db40012}},	//   _पड़ेग, åll_, нову_, لإفر
  { {0x69ce00bd,0xdd25001e,0x442007bd,0x6abc0132}},	//   _afbe, gūša, gei_, _airf
  { {0xfaf30003,0x6d580073,0x52150367,0x644f07be}},	// [bd0] ؤثر_, hyva, лдат, _voci
  { {0x442d00a2,0xa2c30037,0xf09f0054,0x91f40012}},	//   zde_, रदत्, llà_, لأما
  { {0x21270020,0x442007bf,0x50f50001,0xf6520009}},	//   ình_, bei_, узет, _הצי_
  { {0x32070002,0x442007c0,0x61e807c1,0x3cf80011}},	//   żny_, cei_, hadl, ैंने_
  { {0xd9e30037,0xdbd10051,0xe7080003,0xe72e004d}},	//   _ग़लत_, _müüd, نتون_, ще_
  { {0x442d0070,0x6a600028,0x99d40012,0xa0c50012}},	//   wde_, _höfn, _نتفا, _ميسو
  { {0x7c2b007a,0xceb40009,0x64490031,0x9f4001a0}},	//   _pagr, ביס_, tjei, _veié_
  { {0x2901002c,0x6c350003,0xdbd10051,0x6a600097}},	//   muha_, افظا, _nüüd, _jöfn
  { {0x3e660061,0x60c3003a,0x78660164,0x644900e6}},	//   _hôte_, _sunm, _jóve, rjei
  { {0xd9e10037,0x442d060e,0x78660017,0xb7bd000d}},	//   _फ़ोट, sde_, _móve, _naţi
  { {0x61e300c5,0x41b5003c,0x628107c2,0xc1050012}},	//   _venl, ысит, rnlo, دوجي
  { {0x44e1039c,0xf7670003,0x5b250003,0xe43c0066}},	//   mų_, ما_, _مفصل, _příč
  { {0xa3c20037,0x44e10010,0xf092000b,0x78660097}},	//   ्डर_, lų_, מנט_, _nóve
  { {0x29010101,0x3f9e0039,0x249f07c3,0x44200052}},	//   kuha_, ātu_, llum_, wei_
  { {0x44e1007a,0xd7ce0037,0xe8f50012,0x05550024}},	//   nų_, हुँच, _إستخ, аття
  { {0xa3e60037,0xb9560009,0x8c960024,0x786601e3}},	//   _बड़ा_, _תיקח_, ургі, _bóve
  { {0xfc3f022d,0xa25b001a,0xf1fa0012,0x7fe90012}},	// [be0] _dní_, _vuôn, فعات_, _شريف_
  { {0x3205002a,0x44e10010,0xfeba0003,0x81bc001e}},	//   ngly_, kų_, _ثابت_, rdēv
  { {0x44e1007a,0x3e66043d,0x7d160002,0x249f07c4}},	//   jų_, _côte_, łysz, klum_
  { {0x44e10010,0xd5b8001e,0xd46a0001,0x7afb07c5}},	//   dų_, žās_, _чиме_, krut
  { {0xd7f9002d,0xdd1d0029,0x81bc001e,0x46f60345}},	//   тує_, ráťt, ldēt, учет
  { {0x11da0003,0x6d580010,0x2ca007c6,0xfc3f0030}},	//   _سورة_, tyva, llid_, _zní_
  { {0x44e10010,0x2cc90029,0x81bc001e,0xdd900003}},	//   gų_, _ľudí_, ndēt, غوب_
  { {0x54540014,0x249f0028,0x95530012,0x26090011}},	//   рвит, glum_, إخوا, _साथी_
  { {0xa0670001,0x18670001,0x41e6002d,0x30750294}},	//   _сата_, _сати_, ліна, _турс
  { {0xdbd10051,0x7bdb002c,0x44e10010,0x6d580010}},	//   _süüd, abuu, bų_, pyva
  { {0x2ca00051,0xdbd10051,0x94060012,0xb7bd004b}},	//   klid_, _püüd, _مواه, _raţi
  { {0xfc3f001a,0x7afb07c7,0xc0ab0012,0xc1730009}},	//   _phím_, brut, عادل_, מחת_
  { {0x7c93000a,0x04930003,0xc339000e,0xfebb0012}},	//   _النص, _النح, őírá, فاست_
  { {0xcf93000b,0x6a600028,0xb6040024,0x929d0034}},	//   מטר_, _söfn, йяск, tułe
  { {0xf77f0017,0x4a5b0009,0x3ebe07c8,0x09f70009}},	//   paço_, _אדגו, _mitt_, _עמהם_
  { {0x7ae2003e,0x2ca00051,0x3ebe07c9,0x248d02a1}},	//   _kwot, glid_, _litt_, čemo_
  { {0x0ca80015,0xc7d80009,0x44e10073,0x94a8004c}},	// [bf0] утри_, _עוזי_, zų_, утра_
  { {0x2bb80003,0x2bdb0037,0x7aef07ca,0x6b7b0009}},	//   طاقة_, _ग्नू_, ácti, גרמנ
  { {0x7aed07cb,0x47d50012,0xc984005f,0x76ba0009}},	//   ssat, ليار, буци, _שמתפ
  { {0x2c27007c,0xab95002d,0x44e10010,0x961d0037}},	//   _сьог, _вимі, vų_, फ़्ट_
  { {0xd5e5002d,0xb8170037,0xd6db010c,0x2009001e}},	//   ажли, ध्यम_, хте_, ļai_
  { {0x44e1007a,0xacf50001,0x644d07cc,0x628307cd}},	//   tų_, ачиј, ljai, čnos
  { {0xd6580093,0x3ebe07ce,0x249f0028,0xa63c0009}},	//   ריות_, _ditt_, tlum_, תגור
  { {0x9984000a,0xeb990094,0x3ebe071a,0x44e10010}},	//   _الفو, кий_, _eitt_, rų_
  { {0x644d004a,0x44e10010,0xc86401ef,0x8c1c0009}},	//   ijai, sų_, _утри, תוחי
  { {0x62850033,0x3ebe0033,0xba160003,0x7cd1001e}},	//   nnho, _gitt_, ليًا_, _pārd
  { {0x9a76000b,0x4a42002d,0x68460015,0x186a0146}},	//   שתתף_, інюв, анна, вани_
  { {0x78ad0149,0x7cd10039,0xb4c10037,0xcea9000b}},	//   _chav, _vārd, ंदी_, _חי_
  { {0xe73a0001,0x7bda0009,0x644d07cf,0x83fd0031}},	//   њег_, _סקסו, djai, nhőm
  { {0x3ebe000f,0x61e70066,0xa2d20012,0x5f080011}},	//   ött_, _nejl, _بيوت, _समस्_
  { {0xbda50003,0x81bc001e,0xa966002d,0x7d0307d0}},	//   محفو, udēt, _вища_, nuns
  { {0x442f0163,0xdd010066,0xbc6307d1,0xa01b008e}},	//   _jag_, _štěs, овск, nnöl

  { {0x91fc0039,0x442f07d2,0xb89b000b,0x6b850003}},	// [c00] bkād, _mag_, _בבקש, مشكل
  { {0xda66000a,0x4a43002d,0x25a00066,0x27e90028}},	//   جاري, онув, řili_, ðann_
  { {0x2cba0003,0xd5fb000b,0x6aa1006f,0x5dfb0009}},	//   _لاحظ_, _בפיר, illf, _בפינ
  { {0x442f0101,0x3ebe07d3,0x97c50012,0x644b005e}},	//   _nag_, _sitt_, متهم, ögit
  { {0x7c240149,0x61e707d4,0x28130003,0x6e2307d5}},	//   meir, _fejl, تونس, fenb
  { {0xb4c10037,0x7c2407d6,0x6e2307d7,0x8cf40012}},	//   ंदू_, leir, genb, مكتش
  { {0x721b000b,0x3947006f,0xc5f3000b,0xddc80002}},	//   _שולח, änst_, קדה_, _podł
  { {0x7c240149,0xe7f20037,0xcdb70009,0x7c930012}},	//   neir, _आएगा_, ספקה_, يشيا
  { {0xd5b10020,0xcb070003,0x15e60037,0x27e00028}},	//   _máy_, ليين_, करार_, ðinu_
  { {0x7d1e0119,0x80ca0302,0xf1aa0037,0x443207d8}},	//   _opps, _संदे, _करान, hdy_
  { {0x3a370093,0xba37000b,0xd575002d,0xca37000b}},	//   ברים_, בטיח_, _луць, בניה_
  { {0xdd7b000b,0x320a0002,0x69c30260,0xd0f70009}},	//   _בטבל, żby_, _egne, סמכת_
  { {0x7ad4000a,0x236d0002,0xe2f8002d,0x7c2407d9}},	//   _اقتص, czej_, _селі_, deir
  { {0xa2c30044,0x442f0070,0x831b0009,0xbe880223}},	//   रदर्, _zag_, _סווז, ассе_
  { {0xa4d5002d,0x58870015,0xd0870015,0xb7f80011}},	//   собі, _выпа, _выпи, ुलाम_
  { {0x44320002,0x60c00052,0x6130000e,0x24580029}},	//   gdy_, _nimm, zólá, _tému_
  { {0xa3b10044,0x644d004a,0x6a600028,0xdee4004c}},	// [c10] टें_, rjai, _töfl, _доњи
  { {0x78a202a1,0x442407da,0xfe050011,0xeb910009}},	//   elov, hem_, _राइस_, הָב_
  { {0x7fd5002d,0x61130066,0x61e70058,0x644d000e}},	//   білі, dělá, _vejl, pjai
  { {0x78a2012e,0x27e90689,0x9ef50003,0x28f80024}},	//   glov, _jean_, مستش, рець_
  { {0xde59002d,0x53340015,0x8c1a000b,0x238a0029}},	//   ладі_, _деят, _גורי, čujú_
  { {0x8e08002d,0x929d0034,0x98a80030,0x628607db}},	//   инів_, kuła, _brně_, ékol
  { {0x442f01e5,0x40350014,0xbd6b0014,0x60c00028}},	//   _pag_, _левс, ърде_, _fimm
  { {0x7cd10039,0x442407dc,0x30850003,0x64b30037}},	//   _pārb, gem_, _الرف, ुदेश
  { {0x20100029,0x83fd0031,0x7d0307dd,0x98bf0073}},	//   íliž_, lhők, suns, lytė_
  { {0x442f002c,0x6aa10033,0x9f4205b1,0xaae40012}},	//   _wag_, ullf, jaká_, آسيو
  { {0x236d003e,0x25570066,0x443207de,0xa4d40024}},	//   szej_, _dělá_, ydy_, _дохі
  { {0x245c0028,0x7c240017,0x9f440025,0x442407df}},	//   _tími_, xeir, _semé_, cem_
  { {0x4374004c,0x6d5c0034,0x69c30064,0x6d410248}},	//   _мушт, wyra, ľnej, ålan
  { {0xa3bd0037,0xda030037,0x1d0a0232,0x539a0009}},	//   ेखन_, _लागत_, леги_, _גינו
  { {0xba740003,0x11440012,0x33f60024,0x7c2407e0}},	//   _بانت, _وَهُ, йчас, teir
  { {0x29050175,0x3fe60538,0x7876001e,0x232a0472}},	//   mula_, _ужив, kšvi, лоби_
  { {0x64aa0013,0x7c2407e1,0xcad50009,0xc2e90012}},	// [c20] _přiz, reir, מוּת_, لعلم_
  { {0xd9f90037,0x0f37000b,0x200d004b,0x7c2407e2}},	//   ूलित_, _פריט_, _acei_, seir
  { {0x97c60003,0x1e57000b,0x7d1e07e3,0xd657000b}},	//   مقاو, _השיר_, _upps, _היית_
  { {0x18a60063,0xcf460048,0x673b01e3,0x629c0034}},	//   щаем, йней, _bruj, _wkro
  { {0xa6fa0009,0x11d60024,0x442407e4,0x1867004c}},	//   רִ֣י, _гібр, vem_, љачи_
  { {0x412a007c,0x4424003e,0x3a250033,0x5be00037}},	//   _його_, wem_, jelp_, नर्व
  { {0x60c00163,0x26090037,0x78a20580,0x27e00097}},	//   _timm, _सारी_, plov, ðins_
  { {0xbf4d0066,0xb8de0037,0x9cd7000b,0x00f70009}},	//   _šířk, ुआ_, זוקה_, _למלך_
  { {0xc1ea002d,0xe7370015,0xafdb0033,0x6f66002d}},	//   льне_, _лет_, kjør, _уваз
  { {0x3d190044,0x27e907e5,0xdb1d0031,0x7ead0064}},	//   _पहले_, _sean_, özép, túpe
  { {0x3a37000b,0x6e930003,0x27e90051,0xca370009}},	//   זרים_, _علما, _pean_, זניה_
  { {0xc953000b,0x48670014,0x9f4b0061,0xc86707e6}},	//   למת_, съоб, lacé_, стои
  { {0xac970003,0x80ca0037,0x27e901e3,0xa01b0031}},	//   _اننا_, _संवे, _vean_, lnök
  { {0x63a201e5,0xafdb0033,0xee2e0024,0x539b0009}},	//   _iyon, gjør, днi_, _עיגו
  { {0x7cf8000b,0x27e90051,0xdd3a000d,0xba170009}},	//   יִּק, _tean_, văţa, _החוץ_
  { {0x985d003e,0x69d8000e,0x7cd10035,0x9cd70009}},	//   _błąd_, űvel, _jāra, מולה_
  { {0x5ea50003,0xba550001,0xd1380010,0x6d480248}},	// [c30] _ومعل, овај, lvą_, ädar
  { {0x75480031,0x629a07e7,0x1ed800ae,0xe9ab00ae}},	//   ószí, noto, _ابيب_, هدان_
  { {0xc05b0024,0x99d40012,0xdd3a004b,0x9cb50012}},	//   лід_, ستلا, răţa, _ومخت
  { {0x27e901e3,0x3e6b00b0,0x26160011,0x37fc0009}},	//   úan_, _møte_, प्सी_, ָּׁב
  { {0xddc5007c,0x63a201ea,0xa6fb0009,0x9f4b0025}},	//   обли, _nyon, אִ֔י, facé_
  { {0xddc50066,0x34b30011,0x6e940024,0xc2c40012}},	//   _pohř, ुद्द, пичу, _ريفي
  { {0x69c70119,0xe80a0044,0xb7fb0037,0xde940003}},	//   _igje, _वाला_, ्लाम_, أجنب
  { {0xc57c0009,0x64930060,0xe45907e8,0xdd1d0064}},	//   טרות, tçiy, ржи_, kážt
  { {0x60ca0052,0xf8c9001a,0x27ef0097,0x61ea0032}},	//   _aufm, _cẩn_, magn_, _befl
  { {0x629a07e9,0x386907ea,0xba750012,0xc87f0032}},	//   goto, _alar_, تابت, eiß_
  { {0xdddc0010,0xc27a0009,0x602607eb,0xc9a90430}},	//   sirū, שרתי, одна, рвне_
  { {0xe45f0051,0x50460001,0x316b0002,0xf649000b}},	//   ööd_, цемб, ącz_, _בצ_
  { {0x290507ec,0x8e5a004c,0x66260012,0xe1ee07ed}},	//   sula_, ајву_, يرسك, _ог_
  { {0x9bb6000b,0x24890692,0x245c0097,0x61ea016a}},	//   _והנה_, enam_, _límt_, _gefl
  { {0x8c7a0014,0x2c67005e,0xdd920012,0xa8a60012}},	//   ащат_, _sõda_, ذور_, _وصعو
  { {0x9f4f0028,0x69d50227,0x0443004c,0x8c430373}},	//   yggð_, _afze, месн, месе
  { {0xc889000a,0xd467029b,0x1dc90011,0xda660012}},	// [c40] _دخول_, ците_, िखात, ياطي
  { {0xae0e0011,0x25ad0030,0x248907ee,0x7d1507ef}},	//   _साधन_, řela_, anam_, éfsá
  { {0xc92a0014,0x41260012,0x361b0009,0xc7c60635}},	//   роеж_, تفاق, _דויד, осли
  { {0xdfd00003,0x69da0037,0xa3ee0011,0x91da0011}},	//   ريت_, _प्री, _ज़िप_, _प्रै
  { {0x41c90037,0xf1c90037,0x501b0009,0x160e0011}},	//   रशास, रशान, שונו, _सादर_
  { {0x4733007c,0x72c30015,0xccfa0001,0xd1380010}},	//   ьніс, _обяз, аћи_, yvą_
  { {0xf653000b,0xbbb40011,0x68ed0034,0xc43a0009}},	//   וצג_, ुश्क, _ładn, ֹתִי
  { {0x245c0029,0xa01b000e,0x6ab20011,0x60c4005e}},	//   _tímu_, rnök, ँग्र, _niim
  { {0x3ce90027,0x629a07f0,0x69cf0030,0x3e6b00b0}},	//   ćava_, toto, ěcen, _søte_
  { {0xfb1b000b,0x9e660003,0xd25a05fb,0x5d1a0024}},	//   סוימ, _بارن, рци_, _відс_
  { {0x61ea0028,0x7c660012,0x6446008e,0x22570012}},	//   _vefl, _واصل, _onki, تجيب_
  { {0x0b460104,0x7ea0006f,0x7afd001e,0x629a07f1}},	//   _мнен, köps, šsta, soto
  { {0xdfa70003,0x60c400b6,0xa01b008e,0x628f0025}},	//   تحدي, _diim, nnöi, écoc
  { {0x64460002,0x95c80048,0x7aa60012,0xb2370012}},	//   _anki, жута_, _بإصل, _وكنا_
  { {0xe9170024,0xeda40024,0x14d80009,0x6cd80009}},	//   _дощі_, дшто, מַּמ, מַּצ
  { {0x6f020002,0x88f70009,0x3e540060,0x3869016d}},	//   kroc, _וזהו_, _aştı_, _ular_
  { {0x27ef0248,0x248907f2,0x225807f3,0x000000c4}},	// [c50] vagn_, rnam_, _bork_,
  { {0x0b88002d,0x9388002d,0x3cfe013a,0xf7720009}},	//   істи_, іста_, štva_, _נקי_
  { {0xfeb80003,0x0a680001,0xd9990012,0x320c0034}},	//   _بايت_, црти_, حنات_, igdy_
  { {0x88c8002d,0xc0780024,0x859a0009,0x48780024}},	//   ілів_, осії_, _לשתו, осія_
  { {0x4429007d,0x87270003,0xdf780024,0x8bd60009}},	//   mea_, تعام, обці_, _מורו_
  { {0xb3ba000b,0x9bba0009,0x8d550048,0x442907f4}},	//   _למרכ, _לצרפ, зтич, lea_
  { {0x38b20029,0x61140024,0x30850012,0xed59003c}},	//   láre_, _одру, _فلسف, сой_
  { {0x9f440066,0xb066004a,0x68ed0002,0x17f80003}},	//   _zemí_, isää, _łado, _ورقة_
  { {0x4ea70046,0x66f40001,0xa3b50037,0xc6a7004c}},	//   _држа, _опту, छें_, _држи
  { {0x20e7000f,0xcb12000b,0x28cf0037,0xe6640015}},	//   tői_, עלי_, _संदि, _отхо
  { {0x44290006,0x60c40051,0xd9450434,0x614507f5}},	//   kea_, _piim, чени, чена
  { {0xc4d2000b,0xa3bd0037,0xda1c0037,0x6fcb0011}},	//   _נגד_, ेखा_, ब्बत_, िशिं
  { {0xeb8e007c,0x32110002,0x60c407f6,0x7c2907f7}},	//   _чи_, _oczy_, _viim, meer
  { {0xc4c60351,0xbb3a000b,0xd356000b,0x7c290643}},	//   كترو, _לעני, _מיני_, leer
  { {0xc1aa0044,0xceb20093,0x60c40006,0x0446002d}},	//   _करेग, גים_, _tiim, певн
  { {0xa5070046,0x628107f8,0x6f0207f9,0x7c2907fa}},	//   џета_, lilo, yroc, neer
  { {0x77830048,0xb066005e,0x2d850025,0x225807fb}},	// [c60] _плъз, asää, ûler_, _pork_
  { {0x7c2900bd,0x6281007d,0x69de0005,0xb77b000b}},	//   heer, nilo, _õpet, _לאפש
  { {0x27ed0036,0x2366001c,0x7c2907fc,0x2f160058}},	//   _been_, šoj_, keer, læg_
  { {0x22580036,0xdfcf0003,0xa8000066,0x69c30037}},	//   _work_, هيم_, příč_, _रणनी
  { {0x62810065,0xbea6007c,0x26c50082,0x163402ad}},	//   kilo, падк, _bilo_, деля
  { {0x6b89014d,0x98ac003a,0xdef70009,0xde880081}},	//   _þega, ılır_, למנט_, aịn_
  { {0x6281009b,0x15170003,0xf9870012,0x645907fd}},	//   dilo, كزية_, _أب_, _bowi
  { {0x27ed01e4,0x3f6a0047,0x7c29063c,0x2c7a001e}},	//   _geen_, _либо_, geer, līdz_
  { {0x6459003e,0xa6ca0003,0x628107fe,0xda660012}},	//   _dowi, _طوال_, filo, كادي
  { {0x0377000b,0x3377000b,0x271e001e,0x7af60010}},	//   פתית_, פעים_, rānā_, isyt
  { {0x7c290070,0x76480002,0x5bc60003,0x4ddb0009}},	//   beer, _indy, _فقال, _החבו
  { {0xa3e60044,0x7c2900bd,0x7af60006,0xdfd80048}},	//   _बजट_, ceer, ksyt, зър_
  { {0x6a600065,0xb8d30037,0x53340014,0xf1bf0029}},	//   _höfu, _जी_, _целт, čšie_
  { {0xcad70093,0x64470039,0x6281000d,0x3bbb0009}},	//   _צוות_, ējie, cilo, _המדד
  { {0x442901b3,0x3866000e,0x746b0109,0x765a07ff}},	//   tea_, kkor_, брав_, _moty
  { {0xea00001a,0x9f4b0066,0x89330012,0xd5b8003c}},	//   _đạn_, lací_, _أعوا, яся_
  { {0x442901b3,0xe7e3015f,0x24580800,0x20f80027}},	// [c70] rea_, _क्या_, чать_, eči_
  { {0x44290801,0xa01b000e,0x9f4b0066,0x27ed0802}},	//   sea_, gnöv, nací_, _seen_
  { {0x30150803,0x51f40003,0xd1640048,0x32d20081}},	//   ддер, عسكر, нъци, _lây_
  { {0x7c290070,0x91bb0009,0xf1b00012,0x7ea00097}},	//   xeer, זמבי, اءك_, löpp
  { {0xcc56000b,0xef0e0014,0x9f4b0066,0x7c290804}},	//   _חברי_, ъм_, kací_, veer
  { {0x6459008b,0x7c290070,0xc332000b,0xdd1c0066}},	//   _sowi, weer, _שום_, láše
  { {0x6459003e,0x765a04fa,0x9f4b05b1,0x7c290805}},	//   _powi, _doty, dací_, teer
  { {0x32d20020,0xccf80066,0x3866006f,0xdd1c0066}},	//   _bây_, _dvě_, ckor_, náše
  { {0xa0c40003,0x7c290804,0x32d2001a,0x69ca0060}},	//   _سيكو, reer, _cây_, şleş
  { {0x83640003,0x32d2001a,0x7c290806,0xe8f90247}},	//   عديل, _dây_, seer, оло_
  { {0x6281007d,0x382a005c,0xac19002d,0xb69b000d}},	//   rilo, ожно_, _можу_, trân
  { {0x200f0807,0xf7670003,0xd59a000b,0x7af6004a}},	//   nggi_, نا_, _ובעל, ysyt
  { {0x32d20020,0x28cf0037,0x2ca90058,0x62810808}},	//   _gây_, _संवि, dlad_, pilo
  { {0x7cd5007a,0x753c0013,0x248d009b,0x9f4f0025}},	//   _sąra, tvrz, lnem_, gagé_
  { {0x6da3011f,0x3f9e0034,0x64430035,0x67f80031}},	//   вира, łtu_, ēnin, gújí
  { {0x248d0809,0x3cfe080a,0x161f0011,0xd8770012}},	//   nnem_, štvo_, म्बर_, _يموت_
  { {0x32d20020,0x248d0052,0xa5a40037,0xf1fa0012}},	// [c80] _xây_, inem_, _चुनौ, قعات_
  { {0x7cd10039,0x77f80037,0x7af60002,0x2bde0037}},	//   _pārl, ुल्क_, rsyt, _फ्रा
  { {0x81460003,0x2ca90698,0xd7ef0024,0x386d001b}},	//   بنان, blad_, ку_, _bler_
  { {0x629e000f,0x9f4b0066,0x20d3001a,0xe7aa0593}},	//   sopo, zací_, _mãi_, овел_
  { {0x629e080b,0x20d30081,0x3866080c,0x248d080d}},	//   popo, _lãi_, rkor_, dnem_
  { {0xa3c10044,0x8f9b0009,0x200f00b8,0x6df40012}},	//   ंधन_, חיני, aggi_, ركبا
  { {0x386d0163,0x9f4b014a,0xa06a0014,0x99850030}},	//   _fler_, vací_, _дава_, delů_
  { {0x7d0a0052,0x83340048,0x628f0025,0x2ca0080e}},	//   rufs, ених, écon, noid_
  { {0x6d410052,0x41c90037,0xd6260003,0xf2060148}},	//   _erla, रशंस, _يعطي, мяно
  { {0x5a340014,0x5186027f,0x4154027f,0x20d30081}},	//   хнот, дума, евос, _bãi_
  { {0x9f4b0066,0x20d3001a,0x3888000e,0x248d080f}},	//   rací_, _cãi_, zőre_, bnem_
  { {0x32d20020,0x246c0002,0xbb4a0012,0xc1780073}},	//   _tây_, yśmy_, _ولان_, lbėk_
  { {0x80ca0037,0x93140012,0x627903a7,0x6d5a0810}},	//   _संके, _أوتش, vňov, ätan
  { {0x2005003a,0xf1940198,0x7a370024,0xa01b0032}},	//   şli_, _пиль, _опір_, enöt
  { {0xda650003,0x200f0028,0x44fa001e,0x45d4003c}},	//   _ثاني, yggi_, nī_, тосс
  { {0x78fb000b,0xbae50003,0xf993000b,0xac740012}},	//   _ולהפ, فكري, _שרק_, ناقش
  { {0x7b180047,0x290c0051,0xddc80002,0xa2b50538}},	// [c90] мотр_, luda_, _podś, ебач
  { {0xe3b0000a,0x38b2000e,0x248d0811,0x627903a7}},	//   شرق_, mára_, znem_, sňov
  { {0x7cd1001e,0x69dc0028,0x290c0812,0x38b20813}},	//   _pārm, ðrey, nuda_, lára_
  { {0x41df0044,0x5f950098,0x59df0011,0x38880031}},	//   _प्रस, ниет, _प्रर, pőre_
  { {0xcc76000b,0x290c0814,0x248d009b,0x7bda0009}},	//   _נעשה_, _ådan_, vnem_, _מקרו
  { {0x8cb90044,0xb0cf0037,0x99850066,0x44390815}},	//   ्दको, _संलग, xelů_, _has_
  { {0x6da2002d,0xe5a2002d,0x248d0816,0x44390817}},	//   лиша, лиши, tnem_, _kas_
  { {0x387f00b6,0x290c0818,0x44390819,0x38b2029d}},	//   _umur_, duda_, _jas_, kára_
  { {0x99850013,0x4439081a,0x38b2081b,0x539a0009}},	//   telů_, _mas_, jára_, ּיתו
  { {0x443906f4,0xc3320093,0xae1b0037,0x60c9004a}},	//   _las_, נוי_, प्शन_, _hiem
  { {0x60c9000f,0x00860345,0x7cd1001e,0x290c081c}},	//   _kiem, елно, _mārk, guda_
  { {0x60c90010,0x6a6d0029,0xe1080009,0x6d3a0009}},	//   _jiem, _dúfa, וּשָ, _מתענ
  { {0x60c9081d,0x38b2000e,0x644b081e,0xb69b0018}},	//   _miem, gára_, _ingi, arâm
  { {0x442d0006,0x786602d1,0x78bd081f,0xcb120009}},	//   lee_, _móvi, amsv, _עלו_
  { {0x44390820,0x22580012,0x6fa00011,0xfcb6003c}},	//   _bas_, _تجنب_, _गुरू, ещаю
  { {0x44390706,0x60c90821,0xdca600f5,0x141a0012}},	//   _cas_, _niem, хаби, ثيرة_
  { {0x44390822,0x645d0026,0x33d5002d,0x2ca00823}},	// [ca0] _das_, _dosi, тіст, roid_
  { {0xa79b000b,0xae0e0037,0x60c9004a,0x44390051}},	//   _משפח, _साइन_, _aiem, _eas_
  { {0x442d0824,0xdfda0048,0x49ba0012,0x645d0825}},	//   kee_, пъл_, سائد_, _fosi
  { {0x61e3003a,0x7c2d000d,0x6e2e000e,0x60c90826}},	//   ınla, cear, lebb, _ciem
  { {0x3a38007a,0x9f34002d,0x765e0827,0xb65a0009}},	//   _tarp_, телі, _kopy, ּדֶש
  { {0xe45f004a,0xc333000b,0x290c0164,0x644b0828}},	//   öön_, _גוש_, yuda_, _angi
  { {0x89340009,0xa5660012,0xad660012,0x61430048}},	//   _בָּא_, عدتن, عاته, _йера
  { {0x44fa0039,0x8fa60829,0x94170048,0x2b010011}},	//   rī_, _забе, ежът_, _शिशु_
  { {0x7ae4004a,0x44fa0035,0xd3d70012,0x136a0472}},	//   npit, sī_, ربيا_, яшки_
  { {0x4efb000b,0x75d60003,0xda100037,0xe6c60003}},	//   _מהמו, _أيضا, ालित_, _أتري
  { {0xd48f029b,0x018a01ec,0x6df30012,0x79940048}},	//   _бр_, ящий_, _إكما, тинф
  { {0xfd57000b,0xf993000b,0x38b2029d,0x7f440025}},	//   _רשאי_, טרת_, tára_, _briq
  { {0x69dc02d1,0xc6f8002d,0x26d20164,0xab290012}},	//   _ofre, ннях_, _cuyo_, _يسهل_
  { {0x6e2e000e,0x645d082a,0xdd860012,0x7c390034}},	//   gebb, _sosi, لو_, _zawr
  { {0x38b2082b,0x4439082c,0xa8a7082d,0x25e00011}},	//   sára_, _pas_, _прик, कड़ी_
  { {0x7f850012,0x45b70009,0x69a40011,0x6aa90011}},	//   _للعن, תפלל_, _कड़ी, कत्र
  { {0xe4ed0037,0xf8bf0061,0x44390082,0x7cd1001e}},	// [cb0] _जबकि_, mmé_, _vas_, _pārk
  { {0x4439082e,0x60c9082f,0x69da0830,0x99d40012}},	//   _was_, _siem, ncte, هتما
  { {0x60c90039,0x7c2d0036,0x44390831,0x645d019a}},	//   _piem, pear, _tas_, _tosi
  { {0xdddc0010,0x7afd0066,0xb4fa0009,0x39a40024}},	//   mirš, ástk, _קפרי, ушув
  { {0x6f1d0832,0x60c90833,0xe72e0024,0x6a600097}},	//   ntsc, _viem, ше_, _vöfr
  { {0xad8b0009,0x158b0009,0x60c90034,0x442d0834}},	//   ּנֵ֥, ּנֵֽ, _wiem, wee_
  { {0x60c90835,0xdd03001e,0x9181001a,0xc1050012}},	//   _tiem, ērķa, iệc_, _جوزي
  { {0xdd8e000a,0x20d7003a,0x1c450594,0x69da0203}},	//   توى_, _içi_, тним, ecte
  { {0x36d5007c,0xaed5007c,0x2ba70037,0x442d0836}},	//   _розр, _розш, _कुमा, ree_
  { {0x394500be,0xb145002d,0x27f20052,0x6f0f0837}},	//   вног, внол, _seyn_, ducc
  { {0xd00a0838,0x44200839,0x8ccd0011,0x35550012}},	//   мене_, yfi_, _दंगो, _جناز
  { {0x7d56000b,0x59c30037,0xcc140012,0x8bb70012}},	//   _ביעד_, वेयर, _مذهب, _كإشا
  { {0x547a000b,0xa8560009,0x2cbf005e,0x765e0034}},	//   _קטנו, דירה_, mmud_, _popy
  { {0x2cad0036,0x3376000b,0x5bd10011,0xdee3083a}},	//   lled_, _בתנך_, _हलुव, рори
  { {0x6e2e01a2,0xada60800,0x6f1d0070,0x48b6003c}},	//   rebb, тавл, atsc, _ищит
  { {0x64be0044,0x6e2e000e,0x2c7500ad,0x6acd0011}},	//   ्देश, sebb, _nådd_, ़दूर
  { {0x6d45008b,0x44200309,0x7d1c009b,0x2cad083b}},	// [cc0] _erha, rfi_, strs, iled_
  { {0x2cad0013,0x5db60003,0x91e60015,0xeef70009}},	//   hled_, _لإجر, тоже, _שמיר_
  { {0xc0aa0003,0xa3ea027f,0xbca60012,0x161b0011}},	//   واصل_, _одна_, _لمدي, _पॉटर_
  { {0x7afb083c,0x895a000b,0xa0670014,0x21a30048}},	//   ksut, ודעת, каха_, шихм
  { {0x44fe0010,0x2f8d000b,0x78a20051,0xa78d0009}},	//   lį_, ּרוּ, roov, ּאוֹ
  { {0x577b000b,0xa9060003,0x2492083d,0x20ee0066}},	//   וטנצ, _لبرن, lnym_, yři_
  { {0x44fe007a,0x91fc001e,0x6e23059b,0x35ba0011}},	//   nį_, skāk, _önbe, _इरफ़
  { {0x39470058,0x2cad048b,0x3860083e,0x2492083f}},	//   ænse_, gled_, _noir_, nnym_
  { {0x38b9000e,0x501b000b,0xd4330003,0x9c0b000b}},	//   nére_, _קומו, شعيب, וִיִ
  { {0x44fe0010,0xf8ca001a,0x2cad07fb,0x63ab080c}},	//   kį_, _mẩu_, aled_, _dygn
  { {0x7afb0005,0x987e00a2,0x09f7000b,0xe5050012}},	//   asut, _açın_, כמים_, _مبني
  { {0x24920002,0x30a40014,0xdddc0010,0x38b9000e}},	//   jnym_, иряв, virš, kére_
  { {0xd36f0003,0xf8bf0061,0x6f1d0052,0x38b9000e}},	//   _وهم_, rmé_, utsc, jére_
  { {0xb7e30044,0x6f1d03e4,0x2c750058,0x6f0f0840}},	//   _क्रम_, rtsc, _måde_, rucc
  { {0x7cd1001e,0x6f0f053f,0x38720841,0x75880842}},	//   _pāri, succ, _flyr_, вств_
  { {0x853b0009,0x48150373,0x62880843,0x20050073}},	//   וגלי, _смис, lido, ėlis_
  { {0x09bd0037,0x1da90037,0x36d50024,0xcaf40012}},	// [cd0] ्ख्य, _चुनत, _щопр, لسلب
  { {0x62880844,0x7a570003,0x291e0845,0x160e0011}},	//   nido, خضرا, otta_, _सागर_
  { {0xdfd10003,0x49a40001,0x2c71000e,0x249204f3}},	//   ميا_, ајца, _láda_, bnym_
  { {0xd5e8001a,0x24580029,0xb3eb0003,0x2c750846}},	//   _đón, _témy_, _تعدل_, _både_
  { {0xef1f003a,0xf7700012,0xb8fa0011,0x97250012}},	//   ntü_, ياه_, _डू_, افتو
  { {0x98b3003a,0x9f4200d9,0xee380024,0xc66b003c}},	//   ıdır_, jaký_, кні_, ьшее_
  { {0xc212000b,0x63ab0002,0x6288052e,0x2cad0847}},	//   _להם_, _sygn, dido, tled_
  { {0x6288001e,0x39490848,0x24890849,0x7afb084a}},	//   eido, _čas_, niam_, tsut
  { {0x7c3d003a,0x89f50024,0x99830073,0x6a720097}},	//   _masr, лянц, _tajų_, _hæfa
  { {0x38600061,0x2492084b,0x7ead0064,0x5ee80009}},	//   _soir_, znym_, kúpi, _יַעְ
  { {0xe73c00a2,0x64150003,0xd9190009,0x2cad0132}},	//   _küçü, _مواط, עוֹל, pled_
  { {0x7c840264,0x511a0009,0x05a70011,0x47aa0012}},	//   _куче, עֵינ, _गड़ब, ّاسٍ_
  { {0x38600108,0x443f0028,0x6288084c,0x41c30011}},	//   _voir_, mdu_, bido, वेतस
  { {0x24920002,0x44fe0010,0x38b9000e,0x644f084d}},	//   wnym_, tį_, vére_, _anci
  { {0xe8140037,0x2492047f,0x60cd00b8,0xc5f20009}},	//   _डाला_, tnym_, _fiam, מדם_
  { {0x44fe0010,0x3896001e,0x38b9000e,0xe3b20012}},	//   rį_, māro_, tére_, مرء_
  { {0x4bd90625,0x44fe0010,0x8c430014,0x3b070345}},	// [ce0] ться_, sį_, щете, лето_
  { {0xe74705ab,0x44fe007a,0x443d084e,0x249204f3}},	//   ções_, pį_, _law_, snym_
  { {0x38b9000f,0x2bc50037,0xb05b004a,0x600a0760}},	//   sére_, लेबा, lmäa, енем_
  { {0x38600065,0x26cc084f,0xfc320003,0x78bb0017}},	//   ðir_, _sido_, _احد_, _chuv
  { {0x4bfb000b,0x443f0028,0xaff70012,0x57f30024}},	//   _אלכס, ddu_, افها_, спіт
  { {0x0f370093,0x7e610850,0x291e0851,0x5694004c}},	//   טרנט_, _colp, ytta_, јакт
  { {0xf1c30037,0xad260012,0x7e610852,0x60d50853}},	//   वेदन, ارتو, _dolp, _guzm
  { {0xdd04007a,0xccf30009,0xd12f0012,0x44320854}},	//   ūrėt, זכה_, _عمق_, ney_
  { {0xe457000b,0x9a8a0014,0xeb970001,0x2e160012}},	//   ריפט_, ещна_, лић_, _مباح
  { {0xc3330093,0x27e00108,0x60cd00c1,0x44320802}},	//   צות_, _afin_, _siam, hey_
  { {0x291e0006,0xa055002d,0xc27b0009,0x34260012}},	//   utta_, авні, גריי, _مرشّ
  { {0x7cd10039,0xf537000b,0xdfd10003,0x291e0855}},	//   _pārv, _תנאי_, تيح_, rtta_
  { {0x24890856,0xfbd30009,0xb6070024,0x36d506e5}},	//   viam_, _התנ_, лявк, рогр
  { {0x64400028,0xd5a60012,0x60c20032,0x24890034}},	//   ldmi, قف_, hmom, wiam_
  { {0xdcbb0014,0x61fa004e,0x64400857,0xbca50012}},	//   еща_, matl, odmi, لمسي
  { {0x64400051,0x61fa034f,0x67650012,0x44320858}},	//   ndmi, latl, _نُعل, gey_
  { {0x6d4a0065,0x6e95002d,0x50b80003,0x3b550001}},	// [cf0] _áfan, _випу, _حدود_, шкар
  { {0xbbd10037,0x7cd1001e,0xdb24000e,0x290c0859}},	//   _हल्क, _kārt, ásán, orda_
  { {0x39470028,0xd7d50001,0x6d5e004a,0xd1310012}},	//   íns_, ажењ, äpal, تما_
  { {0x9f050003,0xd0ab0012,0x61fa085a,0xfafe0035}},	//   لوصو, رطان_, hatl, _ķīna_
  { {0x07a50046,0xe739085b,0x8e55002d,0x443f0584}},	//   јалн, тел_, иткі, vdu_
  { {0xb95b0003,0x443d085c,0x8d65085d,0xcdd50009}},	//   _كجزء_, _saw_, ивле, ׁךְ_
  { {0xbdf80003,0x3e740051,0xed5900de,0xfbd10012}},	//   ارها_, _jäta_, той_, يتة_
  { {0x443f0006,0x1305076b,0x9cd80009,0xb05b008e}},	//   udu_, азим, נוחה_, ymäa
  { {0xa3a80037,0x290c0164,0x443f085e,0x43750021}},	//   _खुद_, erda_, rdu_, руйт
  { {0xc6a70046,0x4432003a,0xfb1c0009,0x38960035}},	//   _срби, zey_, תוזמ, tāro_
  { {0x7c240065,0xf9910003,0x85040003,0x6e3e00b6}},	//   yfir, تبة_, _هولن, _rapb
  { {0x18a60047,0x92a60002,0xf7460063,0x98a6085f}},	//   рамм, _załą, аемо, риме
  { {0xa3d90037,0x4a750015,0xbca40012,0x290c0860}},	//   ाशन_, _выйт, _امني, arda_
  { {0x91e50001,0xddc1001e,0x4b7a0009,0xe737004c}},	//   _токе, _nolū, _שאסו, јер_
  { {0x44f3007d,0xa3dc0037,0xc4c60012,0xabf605c8}},	//   nţ_, तुक_, لترو, ичащ
  { {0xb05b0861,0x3e7b0066,0x7ae9004a,0xab2a004c}},	//   lmän, eště_, opet, коба_
  { {0xfc3f0018,0xb05b0248,0x3ea70862,0x0b43028b}},	// [d00] _daí_, omän, kont_, онтн
  { {0xf2df001a,0x232704ad,0x4efb0009,0xab270264}},	//   _trân_, рофи_, _שהיו, рофа_
  { {0x69dc0073,0x2fe60012,0x7f4901e3,0x25f905f3}},	//   žreg, لكاف, _areq, _ईज़ी_
  { {0x03a6007c,0x628b0061,0x07ba0012,0x8c460863}},	//   _вимо, égor, نهضة_, _теме
  { {0xbb43002d,0x9168001a,0x61fa003a,0x27e90164}},	//   _деяк, _mức_, yatl, ñana_
  { {0xa01b004a,0x3cfe00eb,0x29d30012,0x7ea0008e}},	//   riöi, štvu_, _ويُس, töpy
  { {0xcd330012,0xd49a00ef,0xc5f30009,0xd6570009}},	//   قريب, кри_, חדו_, ייסת_
  { {0x98a3024d,0x493b0009,0x9c38003c,0xa0670365}},	//   _дисе, _בגלו, упит_, _каса_
  { {0xd2500003,0xc1780010,0x61fa000e,0xda660012}},	//   كنة_, ybės_, tatl, لادي
  { {0x7cd10039,0xe3af0012,0xeb910009,0x15f80009}},	//   _pārt, برى_, לָי_, _תִּמ
  { {0x672d0864,0x67220606,0x02b70009,0x867b0009}},	//   _spaj, ltoj, שהים_, _שרבו
  { {0x61fa0865,0x67220079,0x251b0009,0xdd8f0012}},	//   satl, otoj, _יובא, _توم_
  { {0xab830046,0x62800010,0x73360003,0x67220866}},	//   _мушк, _įmon, _خرائ, ntoj
  { {0xb882014d,0xea000020,0x6722007a,0x237b000b}},	//   _þína, _đến_, itoj, _שָׁמ
  { {0x2abb000b,0xb2bb000b,0x6722004a,0x28d00037}},	//   _שמוא, _שמור, htoj, _संचि
  { {0x115b000b,0x2c75006f,0x57f50001,0x5c740867}},	//   _ידוע, _båda_, _упит, олст
  { {0xa9e70003,0x2bc90037,0xb89c0009,0x88bc0009}},	// [d10] لثان, ाइया, _שבחש, _בזהי
  { {0xd1380002,0x4a540868,0x8e8400ae,0x09f900ae}},	//   ową_, окус, _وليه, افاة_
  { {0xc5f20093,0x67220869,0xb7d50003,0xdd910012}},	//   _מדי_, etoj, مقاب, _روح_
  { {0x201900c6,0xa3c80011,0x8cba0011,0x286b0048}},	//   ngsi_, ोखा_, ्षणो, ързо_
  { {0x28c80011,0x6d5a008e,0x3ea7086a,0xb05b008e}},	//   रगति, ätav, tont_, ymän
  { {0x78a200f1,0xa684002d,0x6ec40012,0xade80012}},	//   čova, олід, يتوق, لفهم_
  { {0x3ea70108,0x28f801d4,0x19940048,0x1d060048}},	//   ront_, _весь_, _даря, бещи_
  { {0xcd98000b,0x0d98000b,0xae1c0037,0xaadb0011}},	//   ידות_, יכום_, _नाथन_, _बढाक
  { {0x7cd10333,0x3ea7086b,0xf7850012,0xd2a9003c}},	//   _pārs, pont_, _الذَ, лкие_
  { {0x9168001a,0xfc3f00d9,0xcb360009,0xfe730012}},	//   _sức_, ží_, צאתי_, _بدر_
  { {0x61f8003a,0x7ae9086c,0x38b20064,0x186a0147}},	//   _devl, spet, lári_, гани_
  { {0x45b6000b,0xf992000b,0x307a0003,0x385a002d}},	//   _הפעל_, לרי_, احدة_, урою_
  { {0x248d0039,0x76890010,0xb05b008e,0x889a0009}},	//   miem_, ažym, mmäl, רברי
  { {0xd5b10020,0x248d001e,0xb05b004a,0x61f80227}},	//   _ký_, liem_, lmäl, _gevl
  { {0xceb2000b,0x9168001a,0xd5b20003,0x628f0025}},	//   פיל_, _tức_, سفر_, écou
  { {0x6722007a,0x28d001e1,0x475a0014,0x248d086d}},	//   ytoj, _सूचि, _броя_, niem_
  { {0xd5b10020,0xf1bf0066,0x04570012,0x59d60012}},	// [d20] _lý_, řád_, حلقة_, مغار
  { {0xb05b086e,0x6f04086f,0x2f5b0009,0x76410870}},	//   hmäl, _ivic, _עדינ, _naly
  { {0xfe370093,0x248d0871,0x64ac0052,0x25d70009}},	//   _פרטי_, kiem_, ußis, _לוין_
  { {0x248d0039,0x91fc0039,0x17fa0003,0x67220872}},	//   jiem_, nkār, اراة_, ttoj
  { {0x248d0039,0xb4c40044,0x501b000b,0x14b50037}},	//   diem_, एगी_, רונו, ंतरण
  { {0x7c2b0052,0x5ee90009,0x66c00248,0x6fb30012}},	//   _abgr, בַקְ, sökf, أمها
  { {0x7641007a,0x67220873,0x91fc0035,0x21670048}},	//   _daly, stoj, kkār, _лири_
  { {0xfd0f0003,0xd197000b,0xb176001a,0x76430002}},	//   رجى_, _הכלי_, _ngượ, adny
  { {0x7cd1001e,0xcb070003,0x988b0009,0xa3a80011}},	//   _pārr, ميين_, _עָלֵ, _खुश_
  { {0x9e65000a,0xc3330093,0xd1380034,0x7c360097}},	//   _والن, לוח_, twą_, heyr
  { {0xd0110003,0x142a0024,0x7afd0874,0x7c36008e}},	//   ولد_, _біло_, ástr, keyr
  { {0xb4b70011,0xd1380034,0x248d0875,0xbec30035}},	//   _छठे_, rwą_, ciem_, ķīmi
  { {0x3e970003,0x5f940014,0x94bb0009,0x61fe0876}},	//   مؤسس, зият, _עמדת, kapl
  { {0x539b000b,0x7d150035,0x91fc0035,0xeb0700ae}},	//   _גידו, tuzs, akār, _اقوى_
  { {0x90e60003,0xb05b004a,0xe5c40014,0x5d780009}},	//   _استن, lmäm, зсто, בָּנ
  { {0x38b90108,0x4917000b,0xb4b30011,0x6444020d}},	//   méro_, _הקהל_, टते_, gdii
  { {0x2ca9002a,0x228f0002,0xfbd00012,0xd9f9004c}},	// [d30] road_, eżka_, فتك_, инац_
  { {0xacf80002,0xf9c70063,0x7f4d0877,0x51f8003c}},	//   _żółt, бщен, _iraq, йную_
  { {0xb05b004a,0xb9250003,0xc1040012,0xe10b0009}},	//   ymäl, تفضي, كولي, ָּבָ
  { {0x6d400039,0xdd000013,0xd825002d,0xdb0f0061}},	//   āmat, štěn, ідли, _lycé
  { {0xbc1a000b,0x76410010,0x248d0878,0x7ce70060}},	//   _דורש, _paly, viem_, _kırg
  { {0x999e000f,0xf1c80044,0x248d0002,0x91fc001e}},	//   hető_, रधान, wiem_, zkār
  { {0x248d0039,0x9f400065,0x38b20029,0xf5560012}},	//   tiem_, _leið_, sári_, قلوب_
  { {0x7b080065,0xa3d90037,0x1309064f,0x26d30018}},	//   _ástæ, ाशि_, аний_, _lixo_
  { {0x290a000f,0xb7bd007d,0x248d0879,0x999e000e}},	//   ában_, _obţi, riem_, dető_
  { {0x248d0039,0x0905007c,0x2f100028,0xb05b0872}},	//   siem_, опон, _lögð_, smäl
  { {0xdd9b064f,0x3896001e,0x91fc001e,0xc212000b}},	//   _сша_, lāri_, tkār, והי_
  { {0xc5e90093,0x9fca0014,0x61fe01e9,0x43750294}},	//   _יד_, игна_, zapl, _мулт
  { {0x27ff0065,0x98c50010,0xdd1e0029,0xe28e0083}},	//   ðuna_, štės_, _víťa, _жа_
  { {0x44290028,0x6e960012,0xc2c40012,0x91fc0035}},	//   efa_, زلزا, _فيني, skār
  { {0xa3c10037,0x61fe003a,0x2911000e,0x261b0037}},	//   ंधक_, vapl, ázad_, _बारी_
  { {0x6f00000f,0x74160003,0x26d30018,0x7f4d0018}},	//   ámcs, تورا, _eixo_, _fraq
  { {0x61fe00a2,0x7aed0101,0x4dd60024,0xc2e90012}},	// [d40] tapl, gpat, _мінф, معلم_
  { {0xf9920003,0x6d5a004a,0x4429087a,0xf2210011}},	//   وبا_, ätas, afa_, _माफ़_
  { {0x27e50002,0x2724087b,0x64970035,0xed5a0373}},	//   ślne_, lön_, rģij, _тон_
  { {0x61fe00a2,0x7c290070,0x6286000e,0xf992000b}},	//   sapl, jfer, ékoz, ורב_
  { {0x27240006,0xaf360003,0xf1ab0011,0x6d430097}},	//   nön_, ترات, _घुसन, _ánar
  { {0xf773000b,0x999e000e,0xf1bb0011,0x25ad004b}},	//   וקד_, zető_, ैधान, şele_
  { {0xafe6002d,0x7c29087c,0x385a0055,0xdd900012}},	//   _мовл, ffer, _краю_, عوب_
  { {0xe8140037,0xa3e50011,0x8c43004c,0x99980035}},	//   _डाटा_, बुल_, деће, _garš_
  { {0x999e000e,0x2724012b,0xbc670012,0x261b0011}},	//   vető_, jön_, تمين_, _बाली_
  { {0x026a002d,0x60dc003a,0x76890010,0x3f82087d}},	//   рший_, _kurm, ržyk, dzku_
  { {0x3a370093,0x4429087e,0x7aed0002,0xc2370009}},	//   חרים_, yfa_, zpat, חריו_
  { {0xf8b00003,0xb05b004a,0xadb70012,0x6d3b0009}},	//   َةَ_, mmäk, _بهما_, _כתבנ
  { {0xe29a0046,0xaa4606a5,0xab770012,0xd2520012}},	//   _кад_, _медл, _ومما_, _ينص_
  { {0x2907000f,0xee2e0024,0xa2c10011,0x628a0032}},	//   ának_, енi_, _रीप्, _umfo
  { {0x12a90003,0xdb06008e,0x05740012,0x0467087f}},	//   _ادنى_, _lykä, وافد, отам
  { {0x69d80010,0x9b890003,0x317b0009,0xd5b801c6}},	//   žvel, منزل_, _כרומ, юся_
  { {0x44290028,0x61fc0880,0xb2750867,0xddde0034}},	// [d50] rfa_, _berl, плаш, _dopł
  { {0x66c00006,0x442900b8,0x656e0031,0xe2170012}},	//   töke, sfa_, ínhá, تبرع
  { {0x2fd90003,0xdc2f001e,0x629a004a,0x7bdc0030}},	//   مواد_, ažād, into, ěruj
  { {0x7c590012,0xf8070024,0x79ab0009,0x7aed0881}},	//   _الحر_, ічен, בֹדַ, ppat
  { {0x8cba0037,0x61fc0028,0x66c0006f,0x9f400028}},	//   ्षरो, _ferl, söke, úið_
  { {0x1af60009,0xc3320009,0xfe420024,0x60dc0882}},	//   _ממשל_, _רום_, еншо, _furm
  { {0x7c290883,0xe5f8000b,0xf3ff0017,0x2d830034}},	//   tfer, חזור_, _joão_, nzje_
  { {0xd59c0009,0x629a0884,0x61fc0032,0x2724008e}},	//   יבול, ento, _zerl, yön_
  { {0x7c29014d,0x5f94007c,0x61fc00a2,0x3834002d}},	//   rfer, _житт, _yerl, _інфр
  { {0x62800010,0xaabd0011,0x7c290885,0xc6d40012}},	//   _įmok, ्गिक, sfer, _قتلت
  { {0x91fc001e,0xe45f0051,0xf2d4000b,0x7c290886}},	//   rkāp, öös_, ועץ_, pfer
  { {0x55ba000b,0x2724004a,0x6d410887,0x38b2000e}},	//   _המעו, tön_, _isla, járt_
  { {0x3869007d,0x31b80037,0xe73a004c,0xaabd0011}},	//   _doar_, _अर्ध, љег_, ्गाक
  { {0xe7370001,0xab64002d,0xbb4205fb,0x2cad0227}},	//   џер_, _ювіл, _чешк, loed_
  { {0x7c2f000d,0x27240137,0xdeba0009,0xdd920012}},	//   _bbcr, sön_, ממשל, رور_
  { {0x07a6002d,0x8fa60024,0xd3f40024,0x61fc0888}},	//   _найн, _найе, вiст, _serl
  { {0x61fc0889,0x8e56002d,0xa87b0009,0x487b0009}},	// [d60] _perl, _етні, _לאקר, _לטקס
  { {0x7c2f0058,0x2002088a,0x1eaa0012,0xdb060034}},	//   _ebcr, laki_, _داعي_, _szkó
  { {0xb5f7000b,0x4ddb000b,0x85f7000b,0x61fc088b}},	//   _מציג_, _לחיו, _מציע_, _verl
  { {0xb4d80037,0x764505b1,0x18a30048,0x60dc0060}},	//   ादी_, _zahy, нахм, _vurm
  { {0x61fc00c6,0x29130054,0x764500b6,0xf4130009}},	//   _terl, arxa_, _yahy, _אפר_
  { {0xd6d9002d,0x929d0002,0x2905088c,0x6446088d}},	//   іті_, ysła, ksla_, _haki
  { {0x3896001e,0xdb07014a,0xe9a30055,0x6446088e}},	//   lāru_, _člán, _зарп, _kaki
  { {0x6446003e,0xc19b0093,0x499b000b,0x399b000b}},	//   _jaki, _השלי, _השלב, _הילד
  { {0x200200a2,0x6b840052,0x8b230001,0x6446088f}},	//   daki_, nzig, едње, _maki
  { {0xb05b0006,0x877b000b,0x38b2000e,0x15460024}},	//   mmäi, _האמי, zárt_, _незм
  { {0xa6e90020,0x2bb90037,0x05760003,0xdb23000e}},	//   _chươ, _आर्थ, _عائد, _öröm
  { {0x63a20002,0x64460890,0xb7d90012,0x41bb0009}},	//   żony, _naki, توحا_, מציע
  { {0x6b8401e4,0x99690029,0x38b2000e,0x61e505b1}},	//   jzig, hŕňa_, várt_, ychl
  { {0x2c710066,0xd357000b,0x539b0009,0x5eeb0009}},	//   _rádi_, _מידי_, _פיגו, מַלְ
  { {0xeda4002d,0x64460891,0xa2c00011,0xb2bb0009}},	//   ешто, _baki, वतन्, _המגר
  { {0x764500b6,0x45240012,0xc9b70009,0x628e0892}},	//   _wahy, عرِّ, _מהות_, _ambo
  { {0x3f9e00a2,0x64460893,0x32010066,0xcb340048}},	// [d70] ştur_, _daki, tahy_, нетъ
  { {0x99d70003,0xf7720009,0x3f7c0009,0x877c0009}},	//   ستطا, _סקי_, _לאחס, _לאחי
  { {0x7c220894,0x29070066,0x61e50895,0x6d410060}},	//   _ocor, éna_, rchl, çlad
  { {0x61e5008b,0x38690065,0xdfd1000a,0x6a73003a}},	//   schl, ðar_, نيا_, _sıfı
  { {0x6497000d,0x600c0009,0x2cad0227,0x7c2d0896}},	//   nţie, מִגְ, voed_, mfar
  { {0x171c0093,0x6d410897,0x20020898,0x442f016d}},	//   מודע, _psla, zaki_, _sbg_
  { {0xa934007c,0x27e90065,0xdca50014,0x6f090066}},	//   _перш, _ofan_, маки, šech
  { {0xe81f0044,0x14bf0037,0x9872001e,0x6d7c0009}},	//   _भाषा_, ्षिण, kšā_, מאוח
  { {0x1c420015,0x200d0899,0x2bdc0011,0x2002089a}},	//   тным, _idei_, मख़ा, vaki_
  { {0xa6e90020,0x9f040012,0xdcf70012,0xddc1004b}},	//   _phươ, _أولو, _فأصب, _colţ
  { {0x3896001e,0x10a601ef,0x19c50109,0x98a60063}},	//   kārt_, динн, ьбом, дине
  { {0x16200044,0x29050028,0x6603089b,0x7d1c0260}},	//   _बाहर_, rsla_, lank, _årsa
  { {0x7c3b0061,0xb9040037,0x9872001e,0xac1801d4}},	//   meur, _भू_, gšā_, _хочу_
  { {0xa6e90020,0x442d089c,0xe2c90003,0x38b2000e}},	//   _thươ, lfe_, _بوتو_, társ_
  { {0xceb20093,0x6446089d,0x5fdd0011,0xb4d80011}},	//   דים_, _paki, यशाल, ादे_
  { {0x6449089e,0x27ff0032,0x6b840032,0x88bd0030}},	//   ndei, _neun_, tzig, htěj
  { {0x6497000d,0x3e740051,0x64460774,0x442d02c3}},	// [d80] cţie, _läti_, _vaki, ife_
  { {0x644600b6,0xfbd10012,0x6b840032,0x1996004c}},	//   _waki, اتِ_, rzig, мјер
  { {0x7c3b00bd,0xb80a0003,0x6603036a,0xcb09000b}},	//   keur, قيام_, dank, של_
  { {0xca29000b,0xccf3000b,0x7c3b089f,0x6bd60012}},	//   ים_, _שכר_, jeur, _يتحر
  { {0xc6f7002d,0x073a0003,0x3896001e,0x7d1c030f}},	//   дніх_, تساب_, lārs_, lurs
  { {0xcb8b000b,0x66030070,0x6e3c00ed,0x442008a0}},	//   _וְלֹ, gank, nerb, lgi_
  { {0x69dc0017,0xa2ab0037,0x442d0204,0x6143003c}},	//   _igre, जकर्, ffe_, _иера
  { {0x3ae4006f,0x4422000e,0xb05b004a,0x6603004a}},	//   _köp_, ük_, lmäv, aank
  { {0x442008a1,0x224708a2,0xbcb70009,0xfee90012}},	//   igi_, _bank_, ופקו_, _فعلى_
  { {0x66c0004a,0xb2380012,0x07a30367,0xf2df004b}},	//   yöka, أكدا_, _раун, _grâu_
  { {0x0217000b,0x018a0015,0x7c3b0070,0x22470832}},	//   וחים_, ющий_, beur, _dank_
  { {0x7d1c0065,0x73c60003,0x1c1d0037,0x3eb90035}},	//   durs, _قيام, _फाइल_, _īsti_
  { {0xdfd80014,0x6a720097,0x42560012,0x6266004c}},	//   дър_, _hæfu, _ينصر, _овда
  { {0x64830005,0xddda0013,0x5333002d,0x69dc01e3}},	//   _kõig, _potř, _решт, _ngre
  { {0xec6b0001,0x08f70012,0xd8bb0012,0xc3480081}},	//   орак_, _قريب_, _ودعا_, _hổ_
  { {0x442008a3,0x261b0037,0x6497004b,0x69dc08a4}},	//   ggi_, _बाकी_, pţie, _agre
  { {0x7c2d0065,0x66c00163,0x64830051,0x43940001}},	// [d90] rfar, söka, _lõig, ватс
  { {0x442008a5,0xa3ce0011,0xaceb0012,0xc3480081}},	//   agi_, षेध_, _ورجل_, _mổ_
  { {0x7d1c08a6,0xc0150306,0xb015004c,0x7c3b08a7}},	//   curs, емещ, емељ, yeur
  { {0x8c3d000d,0xb8090012,0xb8e70011,0x929d0034}},	//   noşt, سيتم_, _उठ_, ysło
  { {0x76480101,0xb4bd0044,0xc348001a,0xa6e7001a}},	//   _bady, ेगी_, _nổ_, _giữ
  { {0x8afa000b,0xc2c50012,0x8f9c0009,0x6f1d00b8}},	//   _מהשי, _سيزي, חידי, iusc
  { {0x7ce700a2,0x7c3b08a8,0x660308a9,0x64490097}},	//   _bıra, teur, rank, tdei
  { {0xc3480020,0x934505cc,0x88bd0066,0x765a08aa}},	//   _bổ_, ение, stěj, _enty
  { {0xc348001a,0x224708ab,0x7c3b020c,0x6f1d08ac}},	//   _cổ_, _pank_, reur, jusc
  { {0xe1f10003,0x27290164,0x7d28006f,0xda0f0037}},	//   دسة_, mún_, örsö, ाणित_
  { {0x9c7c001c,0xa3b60044,0x2d9a0029,0x49990063}},	//   _suče, _चुन_, ĺpec_, ятия_
  { {0xf7670003,0x6e3c0168,0xc1dc0011,0x38a40060}},	//   ها_, werb, _बल्ग, fıra_
  { {0x2418002d,0xd5b8001e,0x224708ad,0x7f76004c}},	//   _цією_, ļām_, _tank_, хунц
  { {0xdce70002,0x6e3c0032,0x387f01a0,0x7bdd020d}},	//   zyją, uerb, _llur_, _agsu
  { {0x387f003a,0x6da300f5,0x11450012,0xd5b208ae}},	//   _olur_, гира, _أَبُ, افز_
  { {0x249f0028,0x69c30027,0x10690003,0x6601000e}},	//   nnum_, _izne, _يحيى_, _lelk
  { {0xb89b000b,0xc4d2000b,0xb09b000b,0x1fb6002d}},	// [da0] _מבקש, רגן_, _מיקר, _яскр
  { {0x7fd7000b,0x6379002d,0x66290029,0xc7d70009}},	//   _אופס_, єстр_, ľský, _אופי_
  { {0x66c00006,0x44200033,0x249f087a,0x8dfb0009}},	//   löko, pgi_, knum_, _מהית
  { {0x44fe0066,0xc209000b,0x7648002c,0x9f7a0009}},	//   mů_, מה_, _sady, ּנַח
  { {0x6136000f,0x272902d1,0xddc80002,0x44fe0066}},	//   _külö, gún_, łoże, lů_
  { {0x7ce700a2,0x66010107,0xe7690030,0xc3480081}},	//   _sıra, _celk, nářů, _rổ_
  { {0x249f0065,0x44fe0066,0xc5f3000b,0xc348001a}},	//   fnum_, nů_, נדה_, _sổ_
  { {0x249f0065,0x66010051,0x5454005c,0x26da009b}},	//   gnum_, _eelk, твит, _lipo_
  { {0xb05b006f,0x6497001e,0x9cd7000b,0x44fe0066}},	//   lläg, eģis, עופה_, hů_
  { {0xdee30098,0x44fe0013,0x179b0009,0xeb330012}},	//   _софи, ků_, _זימב, اريخ
  { {0x2d87003e,0x44fe0013,0xd6cf0003,0x2b910029}},	//   czne_, jů_, _اقل_, môcť_
  { {0xc3480020,0x44fe0013,0x33f60003,0x38a4003a}},	//   _tổ_, dů_, _أساس, tıra_
  { {0xb05b0052,0x6cd30012,0xdb1d0060,0xf09f01a0}},	//   hläg, _إقنا, üyük, rnà_
  { {0x66c0006f,0x877b0009,0x44fe0030,0xa01b016a}},	//   sökn, לאכי, fů_, chön
  { {0x44fe0066,0xac950109,0x4c950024,0x3d340009}},	//   gů_, вавш, вивс, כָּל_
  { {0xdcb80098,0xf969002d,0x7ae200b6,0x91bb0009}},	//   ещу_, _юрій_, _kuot, _ממוי
  { {0x6497007d,0xfaf00003,0x7cd1001e,0x48140015}},	// [db0] nţia, مثل_, _pārz, _смыс
  { {0x7ae20006,0x979c000b,0x64830051,0x44fe0066}},	//   _muot, _משחק, _sõid, bů_
  { {0x7ae20006,0xf1a703e2,0x82a4004c,0x249f0097}},	//   _luot, хран, уште, ynum_
  { {0xc078002d,0x6601004a,0xb066004a,0xb05b08af}},	//   нсії_, _selk, mpää, mmäs
  { {0x7ae2007a,0x386d00bd,0xd6db08b0,0x64830051}},	//   _nuot, _voer_, чте_, _võid
  { {0x88bd0030,0x44e7005e,0x64970073,0x291e08b1}},	//   stěh, _kõ_, dţia, kuta_
  { {0xd658000b,0xa3d90037,0x32050066,0x99d70003}},	//   תיות_, ाशक_, valy_, _ستسا
  { {0x660100bd,0x2d8708b2,0x291e08b3,0x644d08b4}},	//   _welk, rzne_, duta_, ndai
  { {0xb05b004a,0x228f0002,0x249f032c,0x5ba90055}},	//   hmäs, eżki_, rnum_, ьким_
  { {0xc332000b,0x7ed70003,0x7ae20010,0x5edc0011}},	//   סוי_, _أزرا, _duot, _गूग्_
  { {0x249f0028,0x99d4002d,0xb05b08b5,0xfe700012}},	//   pnum_, лююч, ymät, _ادق_
  { {0x3e74006f,0x44fe0066,0xdee60063,0xcea90009}},	//   _lätt_, vů_, коми, _וי_
  { {0xab5b000e,0x10a301b6,0x443f08b6,0xcf43003c}},	//   _szün, риян, meu_, аняй
  { {0x443f03eb,0x63a4007a,0x09e20014,0x44fe0066}},	//   leu_, _žing, _кошн, tů_
  { {0xceb2000b,0x2907004b,0x27ed0032,0x69c30220}},	//   ייך_, ânal_, _ofen_, _uzne
  { {0x44fe0066,0x443f08b7,0x7f860012,0x2ca0005e}},	//   rů_, neu_, _للبن, unid_
  { {0x44fe0066,0x644b08b8,0x443f08b9,0xb0b70009}},	// [dc0] sů_, _magi, ieu_, _בפקס_
  { {0x645d08ba,0xaa7b0028,0x44fe0066,0xaab30011}},	//   _ensi, _stýr, pů_, ुतिक
  { {0x44e7001a,0xc6170009,0xa9260063,0x48060024}},	//   _gõ_, _בחיי_, тдел, впев
  { {0x644b08bb,0xb05b08bc,0x63a40097,0xd6e20034}},	//   _nagi, rläg, _þing, ykłą_
  { {0x443f03eb,0xb606009b,0xb05b006f,0xd00706bd}},	//   deu_, pušč, släg, тече_
  { {0x7bc6009b,0x60c90052,0xb05b08bd,0xddde0066}},	//   _izku, _ehem, pläg, _popř
  { {0x644b00c6,0x443f0054,0x60260014,0x60db00c1}},	//   _bagi, feu_, _идва, _fium
  { {0x443f0054,0x7ce7003a,0x69b50011,0x644b00b8}},	//   geu_, _tırn, _उड़ी, _cagi
  { {0xcb070003,0xb05b006f,0x38b9000e,0x03c30109}},	//   نيين_, kmär, iért_, исьм
  { {0xd8f8002d,0xb05b004a,0x6497000d,0x7ae208be}},	//   нної_, ymäs, rţia, _vuot
  { {0x38b9000f,0x621b000b,0x443f08bf,0xc98603ff}},	//   kért_, וויק, beu_, тупи
  { {0x04460046,0x7ae20006,0x44e70020,0xf1b3000b}},	//   _једн, _tuot, _rõ_, יסת_
  { {0x6b89003e,0x291e08c0,0x6440003a,0xda340015}},	//   czeg, suta_, memi, _белы
  { {0x6497007d,0xd9540003,0x38b90029,0x644b0034}},	//   nţin, _منتخ, véru_, _zagi
  { {0x3e74006f,0xf708001a,0x85b80012,0x443208c1}},	//   _rätt_, hủ_, نافس_, ffy_
  { {0xed100020,0x3e740163,0x644008c2,0x44e708c3}},	//   _đổi_, _sätt_, nemi, _võ_
  { {0x5a350098,0xfbd00003,0x644d08c4,0x40bc0009}},	// [dd0] лнат, قتك_, rdai, _קזחס
  { {0xdce70002,0xf8bf08c5,0x443f08c6,0x644008c7}},	//   zyję, llé_, zeu_, hemi
  { {0x64400006,0x74be0037,0x83fd000e,0x7af60002}},	//   kemi, _वीकृ, rkőz, apyt
  { {0x443f0054,0xc19b000b,0x6497000d,0xcfe90012}},	//   xeu_, ושבי, eţin, رفته_
  { {0x443f08c8,0x8c1a000b,0x200408c9,0x6ca80009}},	//   veu_, _אורי, _demi_, _יֹשְ
  { {0x76240024,0xf8bf08ca,0x7ce70060,0xde580024}},	//   иміз, hlé_, _fırl, качі_
  { {0x443f08cb,0xcd350003,0xf8bf0066,0x6d320012}},	//   teu_, ارتب, klé_, مفوض
  { {0x64400005,0x69c702a1,0xcf270012,0x66050030}},	//   gemi, _izje, _لرئي, _lehk
  { {0x443f03eb,0x09e50001,0x6497000d,0xd2990024}},	//   reu_, лопн, bţin, етні_
  { {0x443f08cc,0x200408cd,0x6b8908ce,0x38b9000e}},	//   seu_, _zemi_, rzeg, zért_
  { {0xe4e7007c,0x44f50014,0x7ce7003a,0xab5b000e}},	//   _різн, _спес, _kırm, _szül
  { {0xa3550003,0x9b450012,0x2c200011,0xa3ea0011}},	//   _مختص, _منصو, _याएं_, _मलय_
  { {0x6d41003a,0x68e30052,0x99750002,0x9cd6000b}},	//   çlan, _wund, nęła_, _עונה_
  { {0x68e3044f,0x539a0009,0xdee3019c,0x2cbf005e}},	//   _tund, _אינו, сори, llud_
  { {0x6497000d,0xa3e70011,0xf8bf08cf,0x66c00097}},	//   nţio, पशप_, blé_, lökk
  { {0xb05b0005,0xdd8f0003,0x91ba0009,0xa97600af}},	//   smär, سوق_, _אמצי, _תתקנ_
  { {0xb05b006f,0x99750034,0x66c00031,0x5b260012}},	// [de0] pmär, jęła_, nökk, طفال
  { {0x38b9000e,0xca4a0012,0x7f290009,0x44320132}},	//   sért_, علاه_, _סֵפֶ, sfy_
  { {0xdce8001e,0x64400060,0x290e08d0,0xba170012}},	//   ēlēt, yemi, éfa_, طينا_
  { {0xd59b0009,0x64400018,0xad1b0009,0xdee604d5}},	//   _טביל, xemi, _אוטר, годи
  { {0x2bba0012,0xb8eb0011,0x5376004c,0xa3ba0012}},	//   _ساحة_, _री_, _сунђ, _ساحر_
  { {0x78a2013a,0x91e30229,0x9cf40024,0x09e308d1}},	//   snov, _горе, азкі, _горн
  { {0x11d5002d,0x6497000d,0xafdb0262,0x644008d2}},	//   _вітр, rţin, ndør, temi
  { {0x5b140014,0x6497000d,0x7b140048,0x5c7406bd}},	//   амит, sţin, адих, рлит
  { {0xf20604ad,0x87250012,0x6497004b,0x3ae90081}},	//   ляно, _نعلم, aţio, _cúp_
  { {0x67220010,0x86c60003,0xd9f60037,0x6497000d}},	//   muoj, _صيان, ेरित_, lţil
  { {0xd6570093,0x6497000d,0x3cf80029,0x644008d3}},	//   _תיבת_, cţio, jprv_, pemi
  { {0xf993000b,0x2cbf000d,0x6497000d,0xe58b000b}},	//   מרת_, clud_, nţil, _אָדָ
  { {0x26de0010,0x67220010,0xf8bf0061,0xa2b90011}},	//   _kito_, nuoj, rlé_, ्तम्
  { {0xb05b008b,0xc7b30093,0x0cbf0011,0xa3d80011}},	//   fläc, מבר_, ्ष्म, ाधन_
  { {0x6d580028,0x6ca7022a,0x765e004a,0x6e350060}},	//   _ával, граж, öpyy, _özbe
  { {0x67220010,0x7ae600b6,0x1f7502ad,0x44ea0081}},	//   kuoj, _bukt, _влия, _mù_
  { {0xd5b10044,0x26de0017,0x66050051,0x67220010}},	// [df0] _आँकड़, _oito_, _tehk, juoj
  { {0x44ea0108,0x26de0101,0x19590015,0x200b0066}},	//   _où_, _nito_, казы_, laci_
  { {0x32b80003,0x629a08d4,0x3ff50012,0xf1ab0012}},	//   ادقة_, iito, لكار, رائه_
  { {0x8934000a,0x6cfa000b,0x90990014,0x9be40024}},	//   إعلا, _שפרס, ъвет_, _гірк
  { {0xe758002d,0x67220010,0x4f580024,0x48040024}},	//   лиці_, guoj, лицю_, спів
  { {0x644f02d1,0x99d70003,0x6286001e,0x870401ec}},	//   _haci, _متزا, ūkoj, сяце
  { {0x200b0013,0x26de08d5,0x6f1d0052,0x365c000b}},	//   kaci_, _dito_, hrsc, תכונ
  { {0x62880006,0x44ea001a,0x24890539,0x200b05dd}},	//   ehdo, _dù_, nham_, jaci_
  { {0xd627000a,0xc482007c,0xe3b10003,0x66270003}},	//   _معاي, ільк, غرب_, _مراك
  { {0x7f840003,0xa7740015,0x644f0054,0x6497000d}},	//   _الكن, _улуч, _laci, pţio
  { {0x66c0000e,0x6497000d,0xf86608d6,0x443908d7}},	//   sökk, lţim, авно, _obs_
  { {0x6288004a,0x200b0729,0x9c8201e9,0xb4fa0009}},	//   ahdo, gaci_, účto, _יפעי
  { {0x23290063,0xa0880009,0xe3b30012,0x661a0034}},	//   _роли_, רְתִ, _ارض_, ótko
  { {0x443903c0,0x41e70024,0xc7d60009,0x6288036c}},	//   _abs_, _сіда, יורי_, chdo
  { {0x9cb60003,0x67220010,0x200b0027,0xa5070014}},	//   لمست, zuoj, baci_, иера_
  { {0x3d080044,0x386008d8,0xc48305fb,0x200b08d9}},	//   _सबसे_, _unir_, олск, caci_
  { {0xb6a6002d,0xa2060731,0x4e1a0015,0x58bb0009}},	// [e00] _випл, ипад, _июня_, _במקצ
  { {0x88bd0013,0xda79002d,0xef1f000e,0x442b00c1}},	//   stět, ляє_, zzük_, _ecc_
  { {0x2bb80037,0x26de08da,0x361b0009,0x600a0198}},	//   _आडवा, _rito_, _בויד, внем_
  { {0x26de01a2,0x09c60044,0xd0100003,0x67220010}},	//   _sito_, _वरीय, سلت_, tuoj
  { {0x6497007d,0x87030075,0x09e6002d,0xe6660594}},	//   rţil, ояще, _вогн, итко
  { {0x200b0013,0x644f08db,0x67220010,0x9757000b}},	//   zaci_, _zaci, ruoj, יינו_
  { {0x6722004a,0x32180002,0x629a08dc,0x3f8008dd}},	//   suoj, órym_, vito, šiu_
  { {0x660a0058,0x3eb808de,0x3c760009,0xbf6b0030}},	//   safk, hort_, יתֶם_, _šíři
  { {0x200b08df,0xc3270012,0x9e660239,0x8aa608e0}},	//   vaci_, لكين_, _квад, ирод
  { {0xc3330093,0xab5b000f,0x44ea001a,0xba180003}},	//   קות_, _szük, _tù_, ديدا_
  { {0xfc660014,0xa446022a,0x25eb0011,0xf27b0009}},	//   _вълн, _внед, _चलती_, דריש
  { {0x859b000b,0x6d41003a,0x80a40012,0x38bc0030}},	//   _בשבו, çlam, ْمَن, píru_
  { {0x2bd20037,0x200b08e1,0xdbe50012,0xd6b70012}},	//   देशा, raci_, _اسمً, لإسب
  { {0x6f1d0052,0xda660003,0x4b7b0009,0x92b30012}},	//   rrsc, _خاصي, _באדו, _وحوا
  { {0xbc0704ad,0xddcf0010,0xfce90012,0xacf70012}},	//   ичай, ūdži, افري_, ؤسست
  { {0x320c01bd,0xe58b0009,0x7e200011,0x7d1a0097}},	//   lady_, דָמָ, बलॉग_, átsa
  { {0x22840163,0x6a15003c,0xc2c50012,0x3b540024}},	// [e10] _söka_, ймау, ميري, октр
  { {0x6d5a00a2,0x78a90027,0x929d0002,0x60c208e2}},	//   _orta, _sjev, bsłu, elom
  { {0x7ed40003,0x78a90027,0x2967004c,0xa167004c}},	//   _بزيا, _pjev, шњав, шњак
  { {0x2547000e,0x24800404,0x291e0028,0x320c0042}},	//   _ről_, ckim_, irta_, hady_
  { {0xfd4c001a,0x26c3009b,0xa01b0052,0xd00e0012}},	//   _thiể, oljo_, rhöh, رلو_
  { {0x52850003,0x7bda000b,0xc0b90066,0x2ee90060}},	//   _السك, _תקשו, _žádá, _muaf_
  { {0xbe3c000b,0x6d5a001b,0x62060031,0xf2d20009}},	//   דעות, _crta, örlő, _זעם_
  { {0xfc310003,0x764308e3,0x8c490198,0x63a40073}},	//   سحب_, seny, упив_, _žina
  { {0x6d5c0065,0x291e08e4,0x752300b8,0x66c00248}},	//   _áran, erta_, sunz, söki
  { {0xf6740003,0x2547000e,0x16380003,0x8e740003}},	//   _والخ, _től_, _نسمة_, _والض
  { {0xd945005c,0x3eb80028,0x05790012,0xd00a08e5}},	//   щени, vort_, _حماة_, лене_
  { {0xb7bd007d,0x3eb80052,0x44290034,0x3cd5003c}},	//   _acţi, wort_, jga_, _ужес
  { {0x42d5002d,0x442904f6,0x3eb808e6,0x291e08e7}},	//   _ліку, dga_, tort_, arta_
  { {0x201e08e8,0x442908e9,0xdb4e0012,0x7bcb08ea}},	//   şti_, ega_, _أَو_, _izgu
  { {0xe8f5000a,0x70f50003,0x80f50003,0x3eb80422}},	//   _استخ, _استئ, _استض, rort_
  { {0x442908eb,0xdb230028,0x6f04002a,0x27e002a1}},	//   gga_, _þróu, _twic, žini_
  { {0xf8b3000b,0x7c360028,0x7c290347,0xc4d20009}},	// [e20] _משה_, rfyr, iger, לגל_
  { {0xa96a010c,0xb05b08ec,0x7c360097,0x216a0337}},	//   лиза_, nlän, sfyr, лизи_
  { {0xd6db000b,0xc693000b,0x6608009b,0xd5b8001e}},	//   _תחיל, _מאז_, _redk, ļās_
  { {0x7c290227,0x3ea70032,0x2cbd010f,0x53a608ed}},	//   jger, ennt_, _nkwd_, _гамб
  { {0x4cbb000b,0xe7f90011,0x60c208ee,0x68fb08ef}},	//   _תזכו, ंडता_, rlom, _čude
  { {0x44ee0020,0xfd65001a,0x010a0012,0x4f650012}},	//   _ký_, _nguồ, _مترو_, تامف
  { {0x9986000a,0x7c2903de,0x27e900eb,0x50f80009}},	//   _الأو, fger, žana_, _כִּד
  { {0xbca40012,0x7ead0064,0x7c2908f0,0x629e08f1}},	//   تمعي, tĺpc, gger, lipo
  { {0x44ee0020,0xf3ef0003,0x77860001,0xa3d80037}},	//   _lý_, رأي_, _улаз, ाधि_
  { {0x3377000b,0x2732000d,0x326a0012,0x326608e0}},	//   צעים_, mân_, احةً_, стив
  { {0x44ee0065,0x85f7000b,0xfdf70009,0x3abb0009}},	//   _ný_, _הצבע_, _הצבת_, רמינ
  { {0xc173000b,0x629d0025,0x320c08f2,0xa3d80011}},	//   לחת_, ésor, sady_, ाधा_
  { {0xeb970015,0x937a0012,0xff040048,0xa4b70009}},	//   _лиц_, _حصار_, зясн, _פלדה_
  { {0x8bd7000b,0x44ee0028,0xcf930009,0xa2d30012}},	//   _הודו_, _bý_, לטר_, _فينت
  { {0x40350406,0x2732001a,0xf5180009,0x54450012}},	//   _дейс, hân_, יֵּל, ينسك
  { {0xcd02003e,0x18a40001,0x98a40001,0xa01b006f}},	//   mość_, _најм, _није, ehöv
  { {0x660e00c6,0x24580015,0x41e70003,0x442908f3}},	// [e30] babk, щать_, مساف, rga_
  { {0xf09f0054,0x4429002c,0x9e0700a6,0x629e0818}},	//   lià_, sga_, _учил, gipo
  { {0xcd02003e,0x442900b0,0x7ce70060,0x94d50012}},	//   ność_, pga_, _hırv, _ويخش
  { {0x17fb0003,0xf8c90037,0x50c90011,0xf09f01a0}},	//   ارضة_, रतिय, रतिष, nià_
  { {0xf1050044,0xd5e5002d,0x2732001a,0x6c560009}},	//   _शब्द_, ожли, gân_, _וירא_
  { {0xcd02003e,0x451905cc,0xee38002d,0x629e0018}},	//   kość_, ация_, йні_, cipo
  { {0x64830051,0xf6960012,0x2ca908f4,0x7c2908f5}},	//   _lõim, تنوع_, onad_, tger
  { {0x2ca90005,0xa2b90037,0xf1c30066,0x7afb08f6}},	//   nnad_, ्तव्, _liší_, tput
  { {0x6497004b,0xf09f01a0,0xb05b0245,0x68ea0032}},	//   nţii, dià_, tlän, _aufd
  { {0x78ad0051,0xe2990001,0x8fa40003,0x7c2908f7}},	//   _ajav, рао_, _عمله, sger
  { {0x63a4014d,0x9f460065,0xb9c50003,0xddab0015}},	//   _þinn, lboð_, تقدي, _стал_
  { {0xfd10000a,0x200f0051,0x61fc003a,0xc156000b}},	//   _أجل_, nagi_, ırla, קשרו_
  { {0xc1c601e1,0x61c601e1,0xe73a0001,0x3b09020e}},	//   _वर्ग, _वर्ष, јег_, _тело_
  { {0x200f0101,0xb7da000b,0x66c0004a,0x3f8c0002}},	//   hagi_, יקרי, yöku, ądu_
  { {0x200f0051,0x3f840029,0x7aeb0028,0x1d0a0538}},	//   kagi_, šmu_, _hugt, реби_
  { {0x07a6002d,0x08c30014,0x90c305cc,0x2ca9006f}},	//   _майн, _общн, _обще, gnad_
  { {0x200f0005,0xc6d60012,0xf1fa0012,0x2002005e}},	// [e40] dagi_, _وتخت, لعات_, mbki_
  { {0x66c00028,0xa01b0032,0x78ad04e5,0xb6a6003c}},	//   töku, nkön, _zjav, _фиол
  { {0x68e40051,0x4fea01de,0x57ea06bd,0x6497004b}},	//   _kiid, амен_, адем_, aţii
  { {0xd7f00003,0x7f860003,0x7ae308f8,0x10a30048}},	//   ركت_, يلان, _lint, михн
  { {0x6497000d,0x2732001a,0xcd020002,0x6d4108f9}},	//   cţii, uân_, zość_, _apla
  { {0x68e40005,0x63a4007a,0x05760003,0xddc1009b}},	//   _liid, _žino, قاعد, _dolž
  { {0xa2b90037,0x200f00b6,0x41180009,0x6e030012}},	//   ्तर्, bagi_, _לֵּא, ذِين
  { {0x69ce012e,0x68e40006,0xd1970009,0x9c7c001b}},	//   _izbe, _niid, _וכלי_, _kuči
  { {0xcd02003e,0xc4d3000b,0xd7ef0003,0x0a6a0294}},	//   wość_, וגה_, _شكل_, арни_
  { {0x5a340014,0xa5f70001,0xcd020002,0xc217002d}},	//   чнот, _међу_, tość_, оєю_
  { {0x7ae3007d,0x15fb0011,0x21660024,0xec4a0048}},	//   _dint, ्रसर_, ітог, _взел_
  { {0x57f40098,0x7ae308fa,0xcd020034,0x320a0034}},	//   мпют, _eint, rość_, źby_
  { {0xb4c80037,0x98b30027,0x5f940014,0x987400b3}},	//   ोगी_, žeća_, дият, фляц
  { {0x648303fb,0x199400ac,0xaa570012,0xcd370012}},	//   _võim, _наля, _ولنا_, يرزب
  { {0x80da0037,0x66cd0029,0x2d850107,0xb05b08fb}},	//   बगाइ, núka, ále_, lläm
  { {0xbca5000a,0xd7fb0098,0xe5710009,0x672208fc}},	//   أمري, _тук_, עַם_, kroj
  { {0x50d40003,0x53340014,0xcb340014,0x787a0009}},	// [e50] _تزور, метт, метъ, _הָיו
  { {0xd251000a,0x64830005,0x200f0034,0x6497004b}},	//   عنا_, _kõik, wagi_, rţii
  { {0x61550012,0xb05b008e,0xdcef0035,0xdcf80035}},	//   ثنائ, yläl, ēdēt, izvē
  { {0x78bd004a,0x66c0006f,0x63ad0028,0xa2cb0011}},	//   nosv, sökt, _þang, _तीर्
  { {0x64830005,0xae1f0037,0x6d5c000e,0xaf040024}},	//   _lõik, _बयान_, _áraj, дпіл
  { {0x7bda000b,0x5b7a000b,0xe7e30037,0x442f08fd}},	//   _לקרו, _הרשא, _गणना_, _scg_
  { {0x20020002,0x661a0002,0xbf0b0037,0xe9180024}},	//   ybki_, ótki, _सौरभ_, _морі_
  { {0xddc70029,0x69c30002,0x6d41009b,0x7c2d08fe}},	//   rejň, _ryne, _vpla, ngar
  { {0xec79001a,0x2d8a0032,0x86c50012,0xbf670012}},	//   _độc_, _üben_, _فيرن, _بدأو
  { {0xc879003a,0x8c3d003a,0xee780003,0x64ac003a}},	//   _hoş_, dişe, _وصلت_, eğil
  { {0x6d4108ff,0x6b890034,0xb05b008e,0x2d980097}},	//   _upla, _żegl, lmäy, _þrep_
  { {0x628a000f,0x2eb60037,0x7cd90015,0x2eb40011}},	//   _elfo, ृत्त, _умер_, ंक्त
  { {0x44f10900,0x442d003a,0x68e40269,0x1eaa0012}},	//   _há_, mge_, _viid, ماسي_
  { {0x8afa000b,0xaa41004a,0x12fa000b,0x24f60024}},	//   _הפסק, ärää_, _ההסב, зчар
  { {0x44f10901,0x62860035,0x27ed0902,0x20d20031}},	//   _já_, īkot, žena_, táid_
  { {0x768f0033,0x66c0004a,0x201e0010,0xb97a0009}},	//   _høyd, töks, ėtis_, _לנצי
  { {0xbae60003,0xcb67046d,0x2ca0005e,0x44f10903}},	// [e60] سكاي, пате_, riid_, _lá_
  { {0x78ab0073,0x6d5e03a7,0x66c00031,0xa01b008e}},	//   engv, _trpa, röks, hköl
  { {0x44f10065,0xf67b000b,0xc879003a,0xc4cb0037}},	//   _ná_, _האימ, _boş_, ाताओ
  { {0xc879000d,0x6aa10052,0xa01b0245,0x67220904}},	//   _coş_, hilf, lhör, troj
  { {0x27e00006,0xd00f0003,0x442d0905,0xd7e30024}},	//   äin_, اله_, dge_, нішо
  { {0x62850906,0xab5b0031,0x6d5c0907,0x29180031}},	//   ckho, _ezüs, _árak, árak_
  { {0x6d5c00bd,0x44f10908,0xd9430909,0x9c83090a}},	//   nvra, _cá_, _пери, ščev
  { {0xd00f000a,0x26c7017b,0x442d090b,0x64490032}},	//   _ملف_, alno_, gge_, geei
  { {0x7690004a,0x3d080011,0xa08b0009,0x7ce70060}},	//   _käyd, _सबके_, _פְלִ, _sırt
  { {0x44f10065,0xaabe0037,0x46a30129,0x442d090c}},	//   _fá_, ्तिक, _заув, age_
  { {0x6f090052,0xe8e0001a,0xf2370009,0x3a370009}},	//   _zwec, _ngồi_, הריץ_, הרים_
  { {0xab2a0047,0x64830005,0x66cd0029,0xdce30073}},	//   _года_, _võik, núkn, dynė
  { {0x4abe0044,0xac970003,0xaabe0037,0x2bdb0037}},	//   ्ताव, _عنها_, ्ताक, मेदा
  { {0x7bdb000b,0x6720000e,0x2ee50052,0xee2e0024}},	//   _הקדו, ámja, ölf_, внi_
  { {0x2a3b000b,0xd23b000b,0x9a3b000b,0xdb1d0066}},	//   _העומ, _הגול, _התוק, _vysí
  { {0x718b0009,0xacfb0009,0x98620034,0x79850012}},	//   _לְחַ, מהלכ, _róć_, _تؤهل
  { {0x6497000d,0x768f0119,0x9cd70009,0x389c0009}},	// [e70] cţiu, _høye, לולה_, _ליהנ
  { {0xedf80044,0x6ce7002d,0xd1380073,0x47340012}},	//   ुरोध_, _німе, otą_, _أريز
  { {0xd138007a,0xc5fb0037,0x7bc60028,0xc0cb0560}},	//   ntą_, ्रीय_, _eyku, буде_
  { {0xd138007a,0x44f10074,0xe9d00012,0x99d40012}},	//   itą_, _rá_, اغك_, رتلا
  { {0x2d83007a,0xb8f40037,0x44f1090d,0xef180024}},	//   lyje_, _सी_, _sá_, змі_
  { {0xd1380010,0xf62b0024,0x17580009,0x7e2b0024}},	//   ktą_, сіди_, פסור_, сіда_
  { {0x442d0663,0x2d830010,0x2d8a0032,0xb05b008e}},	//   tge_, nyje_, _übel_, smäy
  { {0xdbf10013,0x44f1090e,0x78a201bd,0x05760012}},	//   přík, _vá_, ciov, ظمية_
  { {0x2bb90012,0x64490132,0xdfd10012,0xa01b090f}},	//   غابة_, reei, _شيئ_, rköl
  { {0x38690054,0x27360028,0xe299002d,0x6d450910}},	//   _anar_, væn_, іан_, _opha
  { {0x672b0028,0x442d006f,0x91f60009,0xd1380073}},	//   lugj, pge_, ומתו_, gtą_
  { {0xe73a0015,0xa06a0001,0x7afd0051,0x186a01ec}},	//   оем_, цама_, _otst, цами_
  { {0xd1380911,0x2cad0912,0x6d450913,0x883a00af}},	//   atą_, mned_, _apha, חתרו
  { {0xdce30010,0xcb120009,0x6497004b,0xdbc70097}},	//   tynė, _ילד_, rţiu, _röði
  { {0x2cad002a,0x6d4e0070,0x2d830010,0x7afd0259}},	//   oned_, uwba, gyje_, _atst
  { {0x6d5c006f,0x69da0017,0x6497000d,0x6c550024}},	//   rvra, _útei, pţiu, нтує
  { {0xa01b006f,0x2cad021b,0xab5b000e,0xae0d0011}},	// [e80] phör, ined_, _szür, हरान_
  { {0x2cbf00bd,0x0caa0011,0xdddc0159,0x2cad0030}},	//   houd_, _छद्म, akrš, hned_
  { {0x63a90065,0x994a0003,0x74f60012,0x7bc60034}},	//   _þenn, تلال_, _تأخذ, _wyku
  { {0xd12f0012,0x5ca60198,0x7df80011,0x6abe0032}},	//   ؤمن_, _цимб, ुर्ग_, sopf
  { {0x7e7a001c,0x7690004a,0x9b030048,0xd1380034}},	//   _potp, _täyd, _изяд, ztą_
  { {0xccfa0001,0xd1380914,0x2f970009,0x67260097}},	//   оћи_, ytą_, וכנן_, irkj
  { {0xdd900003,0x98a60237,0x68fc0159,0x2a5700af}},	//   طوة_, _живе, _utrd, _קבלן_
  { {0x2cad0036,0xc19b0009,0x399b0009,0xb19b0009}},	//   gned_, _ושלי, _וילד, _וילכ
  { {0xb05b0248,0x8c43004c,0xdd310034,0xe61a052c}},	//   släk, тење, węże, _мда_
  { {0x3254002d,0x6f020164,0x60c40010,0x69cf0034}},	//   хвор, mpoc, _akim, ęcen
  { {0x60f8002d,0xd1380073,0xa3ba0011,0x67260097}},	//   яння_, utą_, _आँक_, erkj
  { {0xd1380915,0x6483005e,0x2d830073,0x3b8604a5}},	//   rtą_, _hõiv, vyje_, _олег
  { {0xd1380916,0xa7740024,0x6497004b,0x27ed05a5}},	//   stą_, вляч, rţit, ženo_
  { {0x2d830010,0x3b53002d,0x61560012,0xd1380073}},	//   tyje_, _шкір, _ينشئ, ptą_
  { {0x7aef0026,0x72330012,0xfa330012,0x7ce70060}},	//   íctv, _شروط, _شرود, _kırp
  { {0xbf35002d,0x2d830010,0x20c7005e,0x6483005e}},	//   _знищ, ryje_, lõiv_, _lõiv
  { {0xa01b008e,0x9f630248,0x22580917,0xac180024}},	// [e90] hkök, åväl_, _bark_, ьоту_
  { {0x2d83007a,0xd3370009,0xdcee0030,0xfc3f0030}},	//   pyje_, ורמה_, íděn, _ajít_
  { {0x22580918,0x49d40009,0xb05b008e,0x38b90919}},	//   _dark_, תֵּן_, eläi, wéry_
  { {0xc87900a2,0x3cfe000f,0x38690164,0xdfd10012}},	//   _kişi_, ítve_, ñar_, هيا_
  { {0xfc3f000f,0x2258003a,0x69c70002,0x7afd07c7}},	//   _amíg_, _fark_, _wyje, _utst
  { {0xaa45004a,0x2cad002a,0x66cd0029,0x05550048}},	//   ävää_, wned_, rúko, етия
  { {0xc2c40003,0x3f890010,0x20e80060,0xafdb00b0}},	//   _شيفي, šau_, _işin_, rdøy
  { {0x44f5091a,0x8c3d000d,0xa3ba0011,0xa2b90011}},	//   _må_, fişa, _आँख_, ्तक्
  { {0x2cad0036,0xff280003,0x27ed091b,0x66150064}},	//   rned_, _يكفي_, _igen_, kazk
  { {0x17fa0037,0x8fa4004c,0x4105091c,0x60c4091d}},	//   ूर्व_, _рађе, нзов, _skim
  { {0x68e9003e,0x44f5091e,0xd8d90009,0xa9690281}},	//   _kied, _nå_, ּקָר, чина_
  { {0xf1b20009,0x62880132,0x2d51001b,0xddc80030}},	//   רסט_, akdo, _iše_, _nadř
  { {0xeb8e091f,0xb3870003,0x8c3d000d,0x6497004b}},	//   _си_, _تجاه, cişa, bţir
  { {0x2006000d,0x24890920,0x443f0921,0x02440012}},	//   zboi_, ekam_, lfu_, _لَهَ
  { {0xceb2000b,0x6f02003e,0x7bcb0052,0x27ed0070}},	//   אים_, zpoc, ügun, _ogen_
  { {0x44f50163,0x63a40010,0x68e90546,0x644d0061}},	//   _då_, _žini, _nied, geai
  { {0x6d4100a2,0x67560003,0xd80b0009,0x2a390009}},	// [ea0] çlar, _أخبر, _מִיָ, ּעֲמ
  { {0x27ed0922,0x44f50923,0x6b960034,0x64590924}},	//   _agen_, _få_, rzyg, _lawi
  { {0x68e90925,0x6483005e,0x905a0009,0x44f50926}},	//   _bied, _rõiv, ּכְת, _gå_
  { {0x6459003e,0x7e7e0927,0xacfb0009,0x805b00af}},	//   _nawi, _hopp, _מהטכ, ּ֣או
  { {0x7e7e0928,0x17540015,0xde58002d,0xc0170009}},	//   _kopp, твля, далі_, תקנו_
  { {0x764e0033,0x27ed0846,0x6f630012,0x753c0929}},	//   neby, _egen_, اهوم, otrz
  { {0x64830005,0x02be0037,0x6c9a0009,0x6abe0011}},	//   _võiv, ्तीन, ּשִׂ, ्तीर
  { {0x7e7e0006,0xbd430003,0xd4970015,0x20120060}},	//   _lopp, انيي, ерь_, _neyi_
  { {0x68e30070,0x82a60015,0xd3360009,0x7e7e008e}},	//   ïnde, ешне, ׂרֵה_, _oopp
  { {0x6fb30003,0x8717000b,0xadba0003,0xd8f8002d}},	//   _إمكا, _נקבע_, _فهذا_, мної_
  { {0xf8ac001a,0xc5690003,0x66150030,0xd9170223}},	//   ưới_, _يحمل_, vazk, нья_
  { {0x64590101,0x10100037,0x60c2005e,0x753c0034}},	//   _gawi, ारिश_, noom, dtrz
  { {0xe787002d,0x44f5092a,0x547b0009,0xdfd80048}},	//   хуно, _så_, _מטאו, еър_
  { {0xa6e7008a,0x6459003e,0xd5a60003,0x15eb0024}},	//   _nhữ, _zawi, لف_, яємо_
  { {0x765a007a,0x66150002,0xa01b004a,0x7e7e092b}},	//   _maty, razk, hköi, _dopp
  { {0x39130014,0x6ca40015,0x27e90604,0xd6d90034}},	//   _смър, груж, žani_, _ppłk_
  { {0x88bc0009,0xd8080009,0xfaf30012,0x5a350048}},	// [eb0] _מזהי, _אִתָ, اثر_, кнат
  { {0x6d4800c5,0x765a0002,0x645b000d,0x21250012}},	//   _opda, _naty, zdui, َّذِ
  { {0x768f0033,0xfe9c000b,0x672f0002,0x26c30010}},	//   _nøya, _מיזמ, lucj, mojo_
  { {0x251a000b,0x351a0009,0x9d1a0009,0xd0580024}},	//   _קורא, _קורנ, _קורט, ерші_
  { {0x8416000b,0xed59001e,0x02d90012,0x673d092c}},	//   _בקרב_, āžu_, _يوجب_, ntsj
  { {0x945d003e,0x68e9012a,0x645900b6,0xf5ab0009}},	//   końc, _wied, _sawi, ּבֵּ
  { {0x68e903fc,0xd658000b,0x25f20011,0x5ff5092d}},	//   _tied, גיות_, ुड़ी_, _азбу
  { {0x2d510066,0x929d0002,0x764e0002,0xd5ae0012}},	//   _vše_, dpła, zeby, تفى_
  { {0x660c000e,0x443f092e,0x645b0227,0x2d81005e}},	//   élkü, rfu_, rdui, äheb_
  { {0x7b440003,0x23620028,0x387f0444,0x26c30073}},	//   ائيل, ækja_, _hour_, jojo_
  { {0x3ea7000f,0xe9d904b3,0x26c30073,0xb05b0032}},	//   mint_, ько_, dojo_, hläu
  { {0x387f0108,0x64830005,0x98a60695,0x7e0a0011}},	//   _jour_, _mõis, тиме, वर्ग_
  { {0xa4d4007c,0x7aea002a,0x929d0034,0x69ce0064}},	//   _соці, _fift, apła, ýber
  { {0x273b0020,0x9f9e0017,0x64ac000d,0x3ea7092f}},	//   iên_, _ação_, işie, nint_
  { {0x71640003,0x64a60014,0x2918000e,0xd0aa0012}},	//   _مايك, вава, árat_, _يطعن_
  { {0x98a6001e,0xb4be0037,0x672f0002,0xccf20009}},	//   bulā_, ेते_, bucj, שכן_
  { {0x753c003e,0x44320930,0xf4120009,0x2d980031}},	// [ec0] strz, rgy_, יפן_, szre_
  { {0x64830051,0xbab30012,0x8a030189,0x7e7e00b0}},	//   _sõit, لمقب, изуе, _uopp
  { {0xc05a002d,0xa2b30037,0x7bcb0010,0x3ea70054}},	//   діл_, _आदर्, _lygu, dint_
  { {0x387f0061,0xfbc70012,0x2db70009,0xb97a0009}},	//   _cour_, _نت_, _ילין_, ונעי
  { {0x69d5000f,0x64830051,0x929d0002,0x765a0010}},	//   _ezze, _võit, zpła, _paty
  { {0xeaa70003,0xa634002d,0x6f02003a,0x8f9b0009}},	//   _ضع_, ункі, _çocu, ויני
  { {0x387f0036,0x69c3000e,0x64b3000d,0xc5f30009}},	//   _four_, ünet, răin, סדה_
  { {0x70560012,0x765a0034,0xa01b0031,0xc7b90031}},	//   _جنرا, _waty, lköv, _időn_
  { {0xd2500003,0xee3a04f0,0xda660012,0x8c3d0060}},	//   منة_, _она_, نادي, mişl
  { {0x63a9007a,0xe3af0003,0xa01b0931,0x78a4000e}},	//   _ženk, ترى_, nköv, _amiv
  { {0x387f0274,0x63ad0028,0x20d20028,0x66d20028}},	//   _your_, _þann, ráin_, tækn
  { {0x387f014d,0xa9c3007c,0x63a4007a,0x8c3d00a2}},	//   ður_, рськ, _žinu, nişl
  { {0x26c3007a,0x90980048,0xe0df00b8,0x66d20040}},	//   tojo_, твят_, rmò_, rækn
  { {0x6fe9001e,0x2fcd0034,0x945d0034,0x996603b0}},	//   _rīcī, żego_, pońc, _атил
  { {0xc986004c,0x7c220159,0xfcc7004c,0x26c30932}},	//   _јули, _kdor, вљам, rojo_
  { {0x273b008a,0x44f80066,0x3cfe000e,0x998c0034}},	//   yên_, _mé_, ítva_, padł_
  { {0x20190933,0x30840012,0x03d5003c,0x1af40934}},	// [ed0] masi_, _خليف, ужаю, иптя
  { {0x7e55007c,0x3ea7000e,0xb05b0052,0x20190935}},	//   _своє, _önt_, rläu, lasi_
  { {0x387f02b5,0x76900006,0xb6020066,0x68ed000e}},	//   _pour_, _käyn, čáte, _kiad
  { {0x64830051,0xdb1d004a,0x5f950014,0x05b60037}},	//   _võis, _pysä, лиет, _अख़ब
  { {0x9cd6000b,0xb05b004a,0x60080024,0x389c0009}},	//   _תורה_, lläs, тнім_, ויאנ
  { {0x645d00c6,0x0ccb0044,0x273b0020,0x2bc60037}},	//   _hasi, ात्म, rên_, _लड़ा
  { {0x20190889,0x41e4002d,0x387f0936,0x3ea70937}},	//   kasi_, _віта, _tour_, rint_
  { {0x2366001c,0x799a0002,0x25d8000b,0x20190938}},	//   _broj_, dztw, כוון_, jasi_
  { {0x7c840001,0x201901b7,0x645d0939,0x69da093a}},	//   рује, dasi_, _masi, _úter
  { {0x6eda0011,0x44f8093b,0x85a7004c,0x2019004b}},	//   _पीपु, _fé_, _ијед, easi_
  { {0x8c3d00a2,0xe4350012,0xb05b008e,0x2019093c}},	//   lişm, _مفاد, ylät, fasi_
  { {0x2019093d,0x645d093e,0xa9880009,0x98a40073}},	//   gasi_, _nasi, דָשִ, įjį_
  { {0x7bcb00a2,0x68ed093f,0x8c1a0009,0x29180097}},	//   _uygu, _diad, _נוסי, árar_
  { {0xed5a0046,0x248d0066,0x2905006f,0xc7d6000b}},	//   ног_, lkem_, ppla_, טורי_
  { {0x98a6000d,0xceb20009,0xa2ba0009,0xd6cf0012}},	//   gulă_, ציל_, _אמסט, سقف_
  { {0x6abe0037,0xa3ea0345,0x1bea0345,0x64a300b5}},	//   ्त्र, едба_, едби_, баса
  { {0xab660015,0x6b9b0052,0xb05b0248,0xceb60012}},	// [ee0] ывал, nzug, rlät, _محدث
  { {0x248d0005,0x645d002a,0xdde40031,0x39580035}},	//   hkem_, _easi, űrűs, _psrs_
  { {0x645d00c6,0xc1ba0012,0xb05b0032,0x4422016d}},	//   _fasi, رائط_, plät, _tdk_
  { {0x2d8a0073,0x645d0940,0x63b60097,0x44f80941}},	//   mybe_, _gasi, _þyng, _ré_
  { {0x248d0066,0x8c3d003a,0x44f80942,0x66180943}},	//   dkem_, rişl, _sé_, tavk
  { {0x4ab80011,0xbb43004c,0xfaa6004c,0x39580073}},	//   _आदिव, _ћерк, _саго, _tsrs_
  { {0x2019003a,0x7afd0066,0xc0aa0012,0x9a670012}},	//   yasi_, ístn, _كارل_, _حمّل_
  { {0x100a0003,0x27ed0944,0x2b400945,0x6b9b0032}},	//   _سترى_, ženi_, otic_, fzug
  { {0x68ed0026,0x36360003,0xb05b0052,0x7b760003}},	//   _riad, _مراس, klär, اطعا
  { {0x201900b6,0x44f80946,0x171b0009,0xcb570009}},	//   wasi_, _té_, _נובע, נסיה_
  { {0x20190947,0xd0110003,0x6df30012,0x98b40060}},	//   tasi_, يلد_, _اكما, çeği_
  { {0x68e200c5,0x23b40037,0xbb560012,0xdd8f0012}},	//   nmod, ंपाद, _منصب, _عون_
  { {0x201900c6,0x6f1d0052,0x2ca60058,0x96f80048}},	//   rasi_, ussc, _imod_, леят_
  { {0x68ed003e,0x20190947,0x2563003a,0x3eaa0052}},	//   _wiad, sasi_, _yıl_, gibt_
  { {0x645d039c,0x6f040948,0xa2ba0037,0x7690004a}},	//   _pasi, _etic, ्वन्, _täyn
  { {0x75280029,0xb05b0052,0x24580109,0x69d80949}},	//   ádza, rläs, лась_, _izve
  { {0xfbd00003,0x291e001e,0xda15004c,0xbae50012}},	// [ef0] كتك_, lsta_, идањ, لكري
  { {0x291e094a,0x248d0030,0x60c9094b,0x8bd70009}},	//   osta_, zkem_, _skem, רומו_
  { {0xb9b50003,0xd5fa0009,0x41550048,0xda4b0009}},	//   جماع, _בפתר, рвес, עֲמָ
  { {0x765e003e,0x291e094c,0x3cfb0037,0x20cb0012}},	//   _zapy, ista_, _लंबे_, رباي_
  { {0x8c1a0009,0x889c0009,0xd9d10011,0x248d0030}},	//   _בורי, עבדי, _हर्ट, vkem_
  { {0x83fd000e,0xab66001e,0x291e094d,0x68e20328}},	//   zdőd, _daļē, ksta_, amod
  { {0x291c0013,0xd6180003,0x248d094e,0xb6380009}},	//   ávat_, اتها_, tkem_, ארוס_
  { {0xcf270003,0x27e50002,0x06b10066,0x03250373}},	//   _مرئي, ślny_, _řídí_, адин
  { {0x67d4002d,0x8c3d003a,0x291e094f,0xd2990024}},	//   _готу, lişk, esta_, втні_
  { {0x3945002d,0x7aa50014,0x78ab0950,0x6b9b0052}},	//   аног, риоз, ligv, rzug
  { {0xe0da0098,0x291e0951,0xade10037,0x3941002a}},	//   кво_, gsta_, गेशन_, nths_
  { {0x78ab0227,0xd3710012,0x29030035,0x26c70952}},	//   nigv, _وها_, īja_, lono_
  { {0xe28e0953,0xa856000b,0x5ea60003,0x291e0954}},	//   _да_, בירה_, لمحل, asta_
  { {0x539a0009,0x91e50955,0xf5060048,0x68e20956}},	//   _בינו, _коле, изго, zmod
  { {0xcce60012,0xc8b6003c,0x26c700b8,0x3da70048}},	//   لسري, _вспы, iono_, акро_
  { {0x77860014,0x99d40003,0x19ba0009,0x91ba0009}},	//   _влиз, _اتها, _במצב, _במצי
  { {0xd6d20003,0x6f040027,0x7ed6002d,0x0c370012}},	// [f00] _وقع_, _utic, _вінч, شكلة_
  { {0xf9920003,0x3860002a,0x7690004a,0xb7db000b}},	//   يبا_, _hair_, _käym, _בקפי
  { {0x26c70957,0x661c0958,0x20d90017,0x867b0009}},	//   dono_, mark, léia_, _סרטו
  { {0x69ce00f1,0xfc320012,0x351b0009,0x50460959}},	//   _vybe, _بحد_, _בוטנ, редб
  { {0x4733002d,0xdfcf0003,0xe7370148,0x91fc0035}},	//   жніс, ويم_, иец_, ndāc
  { {0x628301a2,0x44fc001a,0xc7d70009,0x454a0024}},	//   _nono, _kí_, בוני_, вчим_
  { {0xb87b0013,0x44fc0066,0xc0e60024,0x66d20097}},	//   dmín, _jí_, _вовк, tækj
  { {0x6d5a009b,0xd5b1001a,0x44fc095a,0xd706004d}},	//   _vsta, _séc_, _mí_, _взаи
  { {0xa2c20044,0x389b000b,0x6d5a0002,0xdc8b0009}},	//   रकल्, _סימנ, _wsta, דְיָ
  { {0x7f3b0093,0x661c00b6,0x291e0051,0x6283095b}},	//   _בעמו, jark, tsta_, _cono
  { {0x09f70093,0x99f7000b,0x44fc0066,0xd1380002}},	//   ימים_, יזיה_, _ní_, dząc_
  { {0x28a7002d,0xdcee0010,0x291e095c,0xe53b0009}},	//   ршог, mybė, rsta_, _יתבר
  { {0x44fc0017,0x3860003a,0xdc9b0009,0xd36f0012}},	//   _aí_, _dair_, _ביאל, _يهم_
  { {0x44fc001a,0x7dc70003,0x27fe0066,0x29860015}},	//   _bí_, لتأك, ětna_, _выиг
  { {0x3f420020,0x4426095d,0xaadb0009,0x3860095e}},	//   _lưu_, _kdo_, _שחור, _fair_
  { {0x316d009b,0x26c708b2,0x897b0009,0xd49805c6}},	//   _čez_, zono_, _ירוצ, ару_
  { {0x26c700b6,0x7de0000e,0x24580021,0x7cf50010}},	// [f10] yono_, tásé, шать_, _išre
  { {0x8c3d003a,0xdcee0010,0x9967095f,0x539b0009}},	//   tişk, kybė, ител, דימו
  { {0x161a0044,0x26c700c1,0x29c80003,0x629a019a}},	//   _नज़र_, vono_, لِكَ_, ihto
  { {0x3f42001a,0xa1770009,0xb4c00011,0x27ed001b}},	//   _bưu_, יעבד_, ंको_, ženu_
  { {0xcc76000b,0xf7490012,0x97a7004c,0x6f650012}},	//   _הערה_, التي_, јрел, إهتم
  { {0xee38007c,0x1af6000b,0x24510081,0x39410132}},	//   ині_, _למשל_, _ạm_, pths_
  { {0x26c701a2,0xb9950003,0x99850003,0x05790003}},	//   rono_, _الأب, _الزو, امعة_
  { {0xa8a4007c,0x629a0006,0x45b8000b,0x2db8000b}},	//   _друк, ehto, יפול_, ילון_
  { {0xdd3b0002,0x26c70960,0x02190024,0x1306003c}},	//   ląże, pono_, лінь_, бный_
  { {0x38600017,0x66d20058,0xafdb0260,0x02450012}},	//   _sair_, rækk, rføl, حَدَ
  { {0xb5a70014,0x661c03ec,0xb87b00d9,0x1c170011}},	//   _трай, vark, rmín, तराल_
  { {0x160b0044,0xafdb0033,0x661c0961,0x628300b6}},	//   _स्तर_, pføl, wark, _wono
  { {0x2d8a008b,0xafdb00c5,0xdee6002d,0x44fc0962}},	//   _über_, lføj, йоми, _sí_
  { {0x20d90017,0xde0300ac,0x66030232,0x2cad041d}},	//   réia_, зпри, зпра, lied_
  { {0x69a70037,0xd1380002,0x753c0052,0x201d0963}},	//   _टेली, rząc_, _ärzt, kawi_
  { {0x44fc0964,0x661c0738,0x201d0002,0x2cad002a}},	//   _ví_, sark, jawi_, nied_
  { {0xc9f6000a,0xd4670104,0xb226002d,0x42260024}},	// [f20] مساع, щите_, ймал, йдав
  { {0x78100037,0xe8100037,0x4b230024,0x9b930012}},	//   ार्क_, ार्थ_, ямув, ألكت
  { {0x32180036,0x3f42001a,0xcad60009,0x600a0313}},	//   _very_, _sưu_, צועת_, гнем_
  { {0xdcee0010,0x30a5002d,0x87260012,0xe81a0012}},	//   vybė, орів, معتم, ازات_
  { {0x6d43001a,0x6456003a,0x2cad002a,0xb8650012}},	//   etna, meyi, died_, تالو
  { {0xa01b0006,0x645600a2,0xdcee0010,0x24800027}},	//   hköp, leyi, tybė, ljim_
  { {0xf653000b,0x2cad0965,0x1ea90012,0xd6390024}},	//   פצה_, fied_, جاني_, рячі_
  { {0x645600a2,0xad1b0009,0x83660012,0x9d1b0009}},	//   neyi, אוקר, مدخل, אוקט
  { {0x6d690039,0xc3270003,0x8e3a0003,0x9e3a0003}},	//   _īpaš, مكين_, _مسار_, _مساء_
  { {0x6fb30003,0x32180029,0xddc50029,0xd25a0294}},	//   _عملا, úry_, _zahŕ, уци_
  { {0x2cad00bd,0xa055002d,0x7e7e0028,0x6d430227}},	//   bied_, овні, öppu, ctna
  { {0x661a02bd,0x91bb000b,0x63bb0097,0x8c3d0060}},	//   _hetk, רמטי, _þung, yişi
  { {0x27ed004a,0xbfab0001,0x67240027,0x9f600097}},	//   äen_, утне_, _cvij, ýrðu_
  { {0x67240027,0xd357000b,0x95cb0014,0x0dcb0345}},	//   _dvij, _לידי_, губа_, губи_
  { {0x321e0966,0xceb30009,0x59cf0011,0xc2ed0030}},	//   maty_, ליש_, _सुपर, řící
  { {0x8c3d00a2,0x3eae0967,0xc7ab0012,0x97270024}},	//   tişi, hift_, _مدخل_, _льод
  { {0xfbd30003,0xf8b40009,0xaae70012,0xd5b10081}},	// [f30] ستر_, _משק_, مسئو, _nén_
  { {0xe718000b,0x8c3d003a,0x95c50012,0x661a0968}},	//   _החזר_, rişi, _ويظه, _netk
  { {0x6f160002,0x67240864,0x32010969,0x79590048}},	//   _zwyc, _zvij, rchy_, риер_
  { {0xd7d50001,0x2d81005e,0x228f0060,0x29070035}},	//   ожењ, ähem_, _sıkı_, īna_
  { {0x7ff40003,0x64ac003a,0xf1cf0011,0x9f040012}},	//   أسما, işil, _सुनन, كونو
  { {0x8cab0011,0x321e0030,0x66d20097,0x999e0073}},	//   _जगहो, jaty_, tæki, netų_
  { {0x7d020029,0x4109000b,0xcd280012,0xc9090009}},	//   _čosk, _כִּ֣, مسين_, _כִּ֛
  { {0xcd98000b,0x1305076b,0x76b20034,0x6d410060}},	//   מדות_, озим, głyb, çlay
  { {0x6287001c,0x6d43096a,0x7e61096b,0x2cad096c}},	//   _kojo, stna, _talp, ried_
  { {0xa9250047,0x6456003a,0x52a900bb,0x03780009}},	//   одол, zeyi, рвом_, מתחת_
  { {0x67240027,0x2cad002a,0x69c6003a,0xf769000b}},	//   _svij, pied_, şken, _שק_
  { {0x43750012,0xdb510012,0xd7ea00b5,0x6298096d}},	//   _وهار, _يَا_, имне_, _elvo
  { {0x661a00a2,0xd5b1001a,0x8f990048,0x644900b0}},	//   _yetk, _kéo_, бърт_, mfei
  { {0xd4910020,0x2169096e,0xdc120011,0xa96906bd}},	//   ền_, _вики_, ़र्ड_, _вика_
  { {0xed5a01ef,0x6456003a,0x98c90011,0x20c90011}},	//   шов_, teyi, िकाए, िकाध
  { {0x7c3b096f,0x776d0970,0x64490971,0x6f160972}},	//   ngur, _frax, nfei, _twyc
  { {0x6724001c,0x6d5e0002,0xbb4302ad,0x52aa00a6}},	// [f40] _uvij, _wspa, метк, авам_
  { {0xd36f0003,0x6456003a,0x24920064,0x1ae30973}},	//   ضهم_, seyi, skym_, доум
  { {0x4c160012,0xa9670048,0xb80a0012,0x661a0974}},	//   _وبحس, жиха_, ليام_, _retk
  { {0x50ca0044,0xd46a0001,0x661a0975,0x6722008e}},	//   रविष, _тиме_, _setk, tsoj
  { {0x44200976,0x67220010,0x24860977,0x4e1e0011}},	//   mai_, usoj, _room_, _बजाई_
  { {0xd2520003,0x6b8b006f,0x44200978,0x96140011}},	//   _تنس_, ägge, lai_, डरेट_
  { {0x69dc001e,0x867b0009,0x80ca0011,0x71760012}},	//   _uzre, ירסו, रवाइ, _ظهرا
  { {0xc5f3000b,0x672d001e,0xe9d7002d,0xeb4a0021}},	//   ודו_, šaja, _єкт_, ачок_
  { {0xee3a002d,0x61050010,0x76b20002,0x69d502f7}},	//   _внз_, _vėle, głyc, üzen
  { {0xfa8a0015,0x20e8003a,0xfbd30009,0xcfa90012}},	//   рсий_, _eşit_, ותח_, _طاقم_
  { {0xe45a007c,0x3257000b,0xdd1c0029,0x69fb0009}},	//   _вже_, חסים_, yšše, יליק
  { {0x68fc0979,0x4420097a,0xd0060012,0x7658008e}},	//   _murd, jai_, عل_, levy
  { {0x61010039,0x7cf50010,0x3866097b,0xff040048}},	//   _vēla, _išra, idor_, дясн
  { {0x2455001a,0x6f790009,0xdee70012,0xbb3b00af}},	//   _ấm_, צְרו, تأجي, _כעדי
  { {0xbae30003,0xbd680189,0x6287097c,0x999e0073}},	//   _تكوي, орте_, _rojo, retų_
  { {0x4420097d,0x90c40001,0x69ae0011,0x4815003c}},	//   gai_, _обје, ंछनी, _эмис
  { {0x1eab0003,0x8c3d097e,0xdee70012,0x28c90011}},	// [f50] _نادي_, mişt, _وأخي, िकसि
  { {0x8c3d097f,0x416b0001,0x8a370012,0x768f00b0}},	//   lişt, ијем_, تعرض, _høyv
  { {0xe9f8002d,0xddc1001e,0x44200980,0x6f090981}},	//   інці_, _valū, bai_, _stec
  { {0x68fc00a2,0xe8f8002d,0x8c3d000d,0x18a40024}},	//   _durd, ілі_, nişt, маєм
  { {0xa2ba0037,0x547a0009,0x9f050012,0x82370012}},	//   ्वश्, _הטרו, أوتو, _ورسا
  { {0x8afa000b,0xcee80003,0x20d2000e,0x12fa0009}},	//   _להשי, يرون_, láit_, _להשב
  { {0x78ad0005,0x8cc70037,0xa2ba0037,0xceb40009}},	//   _omav, ावलो, ्वर्, ויס_
  { {0x6d470054,0x7afd0982,0x54e40012,0x25bc0009}},	//   itja, _kust, وسيق, יצומ
  { {0xe3b10003,0xbf150003,0xdaa90048,0x1306003c}},	//   عرب_, _رواب, йвид_, пный_
  { {0xe2990046,0xbb760009,0x7afd0983,0x539c0009}},	//   сао_, פעתו_, _must, ייחו
  { {0x644f0002,0x76b20002,0x20d2000e,0x88ca00de}},	//   _obci, słyc, káit_, йлов_
  { {0xf9920009,0x7afd0984,0xcea900af,0xf8db05f3}},	//   גרט_, _oust, _גי_, बतिय
  { {0x7afd007a,0xd5b70020,0xf7720012,0xb4c90011}},	//   _nust, ống_, راح_, ोती_
  { {0x442000b6,0x442b0164,0x7ac4004c,0xc2c80012}},	//   wai_, _adc_, _осје, _وبول_
  { {0x7c96002d,0xd5b20003,0xe7eb0037,0x44200985}},	//   прац, رفر_, जेता_, tai_
  { {0x249f0149,0x2be20044,0x8c3d05be,0x7af50035}},	//   nhum_, _परमा, mişs, _aizt
  { {0x7af5000f,0xb89b000b,0xf1fa0003,0x883b000b}},	// [f60] _bizt, _לבקש, معات_, _התפו
  { {0x27e000a2,0x44200986,0x7afd0987,0xea1500af}},	//   _izin_, sai_, _dust, לַ֣י_
  { {0xd5fb000b,0x8dfb0009,0xcee90012,0x44200988}},	//   _לפיר, _להית, _برين_, pai_
  { {0x68fc0989,0x48a90024,0xe0d20012,0x7d7b0009}},	//   _vurd, отім_, رزا_, _הנטו
  { {0x68fc032b,0x67260033,0x6d5c000e,0x7afd098a}},	//   _wurd, nskj, _áraz, _gust
  { {0xba550014,0x4255004d,0x35d4003c,0x7c2b098b}},	//   _отсъ, _отст, молё, _adgr
  { {0xd5b00003,0x7afd0480,0xba9b0009,0xddc70034}},	//   ضفة_, _zust, _פסלי, dejś
  { {0x7de7000f,0x957c0002,0xc5f3000b,0xf7460086}},	//   lésé, _rząd, עדה_, _небо
  { {0x8fa3098c,0xcb67004c,0x8c3d004b,0xe4570009}},	//   _зате, зање_, vişt, ליקט_
  { {0x7de7000f,0xcb13000b,0x8f9b000b,0x7c200851}},	//   nésé, עלת_, _הימי, samr
  { {0xade80037,0x59be0011,0xdc3f0064,0x01d80012}},	//   टेशन_, ्थिर, víľk, تودع_
  { {0x290a0039,0x7bc3000d,0xdd7b0009,0x6d7b0009}},	//   ība_, şnui, _לטבל, _לאבח
  { {0x63a40070,0xd491001a,0x999e000e,0x74130012}},	//   jzin, ềm_, retű_, _أوها
  { {0x7cc100cd,0xf1be0037,0xc7b9000e,0x63a4098d}},	//   mēra, ्थान, _időt_, dzin
  { {0xa4d5002d,0x7de7000e,0x661e00b6,0x7afd098e}},	//   дові, désé, _depk, _sust
  { {0x113b000b,0x68e4000d,0xe45f0028,0x6d47000e}},	//   _התהל, _ghid, _mjög_, rtja
  { {0xa3e70037,0x69d8003a,0x83fd000e,0x0aeb0012}},	// [f70] यें_, üven, zdőo, مرئي_
  { {0x8f9c0009,0x979c0009,0xbe150012,0x92b70012}},	//   _ליחי, _לשחק, _تودع, أحرا
  { {0x2bbe0020,0x63a4098f,0x81440012,0x78bd0990}},	//   ịch_, azin, فنلن, onsv
  { {0xddc70002,0x69d50029,0xddde0027,0xa4d90024}},	//   zejś, _vyze, _uopš, _фдму_
  { {0x5f94007c,0x2fcb0012,0x7afd005e,0x07080012}},	//   ницт, حباً_, _uust, كيني_
  { {0x7a29000e,0xfbd20009,0xe5e50012,0x672d0035}},	//   _kötő, _סתם_, وثغي, šajo
  { {0x24e900fa,0x2ddb0012,0xace907a7,0x249f0602}},	//   омки_, حبشة_, омка_, thum_
  { {0x9f650029,0xb4c90037,0x759c000b,0x644d0025}},	//   _štýl_, ोते_, מיוח, nfai
  { {0x769003fc,0x7d1a000e,0xa0c40012,0xe3b10012}},	//   _käyt, átsz, _أيقو, ضرة_
  { {0xaabf0011,0xe3b6003c,0x20d20097,0x09050542}},	//   ्विक, ьбы_, jáir_, мпон
  { {0x6101001e,0x9f9c0097,0x6e230991,0x63a40992}},	//   _vēlo, læða_, manb, zzin
  { {0x7de7000f,0x7bce0032,0x69c30060,0x672600b0}},	//   zésé, ßbuc, üney, tskj
  { {0x10a3077e,0x97da0012,0x93240012,0xa3c90011}},	//   тиян, تبدأ_, _كرون, लॅश_
  { {0x769003fc,0xddc3000f,0x83fd000f,0x8afa000b}},	//   _näyt, lenő, zdől, _והסי
  { {0x67260993,0x1d070430,0x768f00b0,0x443f0994}},	//   sskj, деси_, _høys, ogu_
  { {0x443f0995,0xe1640012,0x672901e3,0xf9900012}},	//   ngu_, _أدوي, _ovej, _حبه_
  { {0x7de7000f,0x9f440006,0x661e003a,0x6e2300b6}},	// [f80] tésé, ämä_, _tepk, kanb
  { {0x236f0065,0xe1f20003,0x63a40996,0x97370009}},	//   ægja_, نسا_, rzin, _קריא_
  { {0x7de7000f,0x765c0002,0x48660014,0x8e7b0009}},	//   résé, mery, дълб, _וניה
  { {0x7de7000e,0x38ab0002,0x765c0997,0x753c0034}},	//   sésé, _górę_, lery, murz
  { {0x9f9c0028,0x7c240998,0x7de70031,0x61050073}},	//   gæða_, mair, pésé, _vėla
  { {0x6283004a,0x443f0999,0x7c24099a,0xc3330009}},	//   önot, egu_, lair, _בוש_
  { {0xa01b0028,0x5ee90009,0xd826004c,0x6026004c}},	//   fjöl, הַקְ, _одви, _одва
  { {0x7c24099b,0xa01b0028,0x628a099c,0xddde0002}},	//   nair, gjöl, _sofo, _kapł
  { {0xd00f0012,0x63ad099d,0x68e3099e,0x000000c4}},	//   _خلق_, _žanr, înde,
  { {0x4b7b0009,0xed5a0024,0x5b7b0009,0x46130012}},	//   קאיו, _моз_, קריא, _لوكر
  { {0x3a370093,0xca37000b,0xc2370009,0xf9c60024}},	//   ורים_, וניה_, וריו_, ьщин
  { {0xe7f50037,0xa01b000e,0x1074002d,0xa1930024}},	//   ुँचा_, lköz, влюю, таюч
  { {0xfbe20037,0xb9050037,0x23e20037,0x68110066}},	//   _परिम, _बी_, _परिद, vědč
  { {0x768f0119,0x4424099f,0xdd860003,0x69ce003a}},	//   _høyr, lam_, هو_, übes
  { {0x20c70146,0x20d20028,0xa2cb0037,0x7c240440}},	//   _осиг, ráir_, सकर्, fair
  { {0x63a40010,0x690b0009,0x32d4008e,0x7ce50018}},	//   _žiny, _וּזְ, käys_, córd
  { {0xfbd0000a,0xf8bf015d,0x644d0061,0xba2b0003}},	// [f90] لتك_, mné_, rfai, قسام_
  { {0xfd5e0020,0x386909a0,0x9f9c0028,0xf8bf0107}},	//   _quyề, _haar_, væða_, lné_
  { {0x673d09a1,0x442409a2,0xedd50012,0x75d50012}},	//   lusj, kam_, _سيحد, _سيحا
  { {0x386900bd,0x9f9c0028,0xdbd90028,0x61d80024}},	//   _jaar_, tæða_, _fæði, ємця_
  { {0x386900bd,0x76900006,0xe0d8007c,0x6d4a0028}},	//   _maar_, _täyt, єві_, etfa
  { {0x9e64002d,0x45190014,0xa01b000e,0xc3320009}},	//   квід, пция_, gköz, _תום_
  { {0xa2cc0037,0xddde0002,0xfaf90010,0xe5760048}},	//   तकर्, _zapł, yvūs_, езщ_
  { {0x386901e4,0xfdf80093,0x6ac70044,0x2b150014}},	//   _naar_, וצות_, रक्र, ньор
  { {0xe452000b,0xf8bf0107,0x6101001e,0x9f040012}},	//   אֶת_, dné_, _vēlm, _لوقو
  { {0x5778000a,0x44240227,0xf3f9004b,0x236d06f7}},	//   _تصفح_, aam_, deţe_, rvej_
  { {0xe9d90098,0x23600034,0xe2a80012,0x765c09a3}},	//   яко_, zwij_, باين_, very
  { {0x7cc10039,0xc19a000b,0xf8bf0061,0xf649000b}},	//   mēro, פשרי, gné_, _לצ_
  { {0x38690070,0x69ce0052,0x6e210010,0xa2950024}},	//   _daar_, über, _kelb, _паді
  { {0x2cbf0051,0x2bb80003,0x78a205b1,0xddda0035}},	//   lnud_, _تامة_, zhov, _datņ
  { {0x69d8007a,0xf8bf022d,0x6b8b006f,0x7c24099a}},	//   _gyve, bné_, äggn, tair
  { {0xa01b000f,0x2cbf0051,0x673d0033,0xf8bf01bd}},	//   zköz, nnud_, busj, cné_
  { {0x7c2409a4,0xccf20009,0x26d101e3,0x69cb0060}},	// [fa0] rair, רכן_, bozo_, şgel
  { {0x32d4004a,0x0566072b,0x4a430048,0x7cc80030}},	//   väys_, _звон, лнув, měre
  { {0x7d010058,0x7c240503,0x6d4a0032,0x91e6003c}},	//   _nuls, pair, xtfa, хоже
  { {0x7690004a,0xafdb0192,0xf5370009,0x442409a5}},	//   _täys, mfør, _אנטי_, xam_
  { {0xf1d00037,0x2cbf0051,0xa01b000e,0x93fb000b}},	//   _तुरन, dnud_, tköz, _מלכי
  { {0x11d6002d,0xf8bf00d9,0x412a028b,0x6d4a09a6}},	//   _зібр, zné_, _ного_, ttfa
  { {0xb7bd007d,0xa0a6007c,0x78a20163,0xc693000b}},	//   _reţe, _завд, phov, ראו_
  { {0xa3e70037,0x4d730003,0x6d4a09a7,0x60c4017b}},	//   येक_, اطور, rtfa, _njim
  { {0x64400005,0x73d70014,0xf8bf00f1,0xe7370103}},	//   rgmi, ндър_, vné_, _пет_
  { {0xc333015a,0x610c003a,0x6e2109a8,0x0e690012}},	//   נות_, _eğle, _gelb, _يصلي_
  { {0xf8bf09a9,0x76450073,0x2be20011,0xa2a60011}},	//   tné_, _rchy, _परवा, टोग्
  { {0x26f90044,0x7ce50002,0xafdb0260,0x442209aa}},	//   ंद्र_, tóre, dfør, _nek_
  { {0x61080066,0x94a90003,0xf8bf09ab,0xf3f9004b}},	//   _děla, _تطلق_, rné_, teţe_
  { {0x386900bd,0xf8bf014a,0x8f9b0009,0x71260012}},	//   _waar_, sné_, ליכי, _كربل
  { {0xf1d00037,0xf8bf022d,0xafdb03ee,0x8d2b0009}},	//   _तुलन, pné_, gfør, ּ֥לֶ
  { {0x89db000b,0x11db000b,0xc4d80001,0x7cc80066}},	//   _מחוי, _מחוב, еђу_, běre
  { {0x6fb9002d,0x4422003a,0xcb340048,0x628e09ac}},	// [fb0] _ігор_, _dek_, летъ, _bobo
  { {0xd0190037,0x44220051,0xe3b00003,0x52d80015}},	//   दर्भ_, _eek_, حرف_, емую_
  { {0x649c0061,0xd13b0014,0xf2c4003c,0x628e09ad}},	//   _réin, яха_, устн, _dobo
  { {0x8934000a,0x6e21008b,0x7cc10039,0xb4950001}},	//   اعلا, _selb, vēro, _римљ
  { {0x3818000b,0x6e2100b6,0x7d0100b6,0x57fc0009}},	//   תקדם_, _pelb, _suls, פלגו
  { {0xed5900be,0xd1380010,0x539a000b,0x7d0109ae}},	//   док_, krą_, _חישו, _puls
  { {0x6abf0044,0x56920046,0x2cbf0051,0xdca50015}},	//   ्वीर, рајт, tnud_, каки
  { {0x0b190003,0x628e08b2,0x248909af,0xd13809b0}},	//   وقعة_, _zobo, njam_, drą_
  { {0x2cbf005e,0xcc080012,0x20050030,0x22960097}},	//   rnud_, رزين_, ělil_, _sæki_
  { {0xb87b0066,0x2cbf005e,0x7cc80030,0x945d0034}},	//   hlíd, snud_, věre, tońs
  { {0x10a609b1,0x2b58000d,0x2bd80011,0x98a606e5}},	//   винн, ărca_, _भुना, вине
  { {0xf8b30011,0xf3ff0081,0x61fa09b2,0x7c2209b3}},	//   ूचिय, _ngã_, _útle, _geor
  { {0xeb8e05ff,0xfc160009,0xc7b20009,0xd1380034}},	//   _ти_, _סקסי_, ֹ֑ר_, arą_
  { {0x764300c6,0xfe0e0020,0x945d0002,0xceb2000b}},	//   ngny, hững_, pońs, ֑ים_
  { {0xceb20093,0x4422003a,0x9e480009,0xb05b0032}},	//   בים_, _pek_, עֲשִ, unäc
  { {0xafdb024c,0x6fb60003,0x68fb0073,0x628e09b4}},	//   rfør, _لمعا, _niud, _sobo
  { {0x442201bf,0x628e09b5,0x63a909b6,0xe8d70009}},	// [fc0] _vek_, _pobo, nzen, _בוקר_
  { {0xafdb0119,0xb87b0030,0x64ac0060,0x27fe0030}},	//   pfør, smít, eşit, ětnu_
  { {0x68fb007a,0xa69b000b,0x29030017,0x442209b7}},	//   _biud, _חשיפ, _cuja_, _tek_
  { {0x68fb0801,0x76430031,0x63a90602,0x3eb809b8}},	//   _ciud, egny, kzen, lirt_
  { {0xdfd20003,0x63a906e7,0x6f0409b9,0x38330024}},	//   جيش_, jzen, _juic, рнір
  { {0x7c2200c6,0x63a904f4,0x5f930001,0x6e940003}},	//   _seor, dzen, ришт, طلبا
  { {0xed570001,0x3f80000d,0xf653000b,0x6d4e09ba}},	//   вој_, ţiu_, יצג_, ntba
  { {0x61e300a2,0x68fb00c1,0x7ce50018,0x6d4e0529}},	//   ünle, _giud, vórc, itba
  { {0x44f70003,0x3dd20002,0x69dc0572,0xd0750012}},	//   خروج_, ływ_, _hyre, _حدّث
  { {0xbbe20044,0xd13809bb,0x61080030,0x7db6004c}},	//   _परीक, trą_, _děln, _исец
  { {0x9a3b0009,0x60c20025,0x27ff0060,0xf9920009}},	//   ותיק, onom, _ygun_, ׁר֙_
  { {0x60c20119,0x6d5a00a2,0x64ac003a,0x69dc09bc}},	//   nnom, _ipta, işis, _myre
  { {0x63a9003e,0xdfd80048,0xb4be0011,0x69dc00b0}},	//   czen, вър_, ँची_, _lyre
  { {0xf773000b,0xa293002d,0x7afc016d,0x6d4e0987}},	//   בקש_, _ваші, _nirt, ftba
  { {0xddda0066,0xec0f001a,0x5c0701ec,0xe4d70012}},	//   _patř, iếng_, вяза, نترب
  { {0x672d0039,0xec34002d,0x2489001e,0x6ca4003c}},	//   šaji, инсь, ujam_, аруж
  { {0x7afc014d,0xd3700003,0x672d009b,0x6bd40012}},	// [fd0] _birt, يهِ_, _uvaj, لتكر
  { {0x2247000f,0x27e40051,0x60c209bd,0x7e990012}},	//   ünk_, ümne_, enom, _أندر_
  { {0xc692000b,0x98ad0010,0x63a909be,0x7afc09bf}},	//   _האי_, ardą_, zzen, _dirt
  { {0x08d4002d,0x91bb0009,0x99810030,0x69dc09c0}},	//   ація, ומבי, sahů_, _dyre
  { {0xc43a0093,0xd4910020,0xab2b0003,0x7ce50028}},	//   _אתרי, ều_, _تسجل_, jóra
  { {0x44290006,0x4aa70044,0xc1050003,0xfe45002d}},	//   laa_, _गतिव, _موسي, унко
  { {0xf2d2000b,0xd658000b,0xed59003c,0xb87b0018}},	//   _העם_, דיות_, хой_, ilíb
  { {0x2005003e,0x44290006,0x27ed0066,0xf5560003}},	//   ślij_, naa_, ženy_, اليب_
  { {0xddc10013,0xb3850012,0x61080030,0xe8940223}},	//   _dalš, اجعه, _bělo, _тать
  { {0x4545000a,0x4429004a,0xc334000b,0xed600004}},	//   _منطق, haa_, בוץ_, ážku_
  { {0x44290006,0x63a909c1,0x26c3009b,0x61080030}},	//   kaa_, szen, dnjo_, _dělo
  { {0x44290006,0xe73a09c2,0xf8d30011,0x3da40400}},	//   jaa_, нем_, तविय, _труб
  { {0x6f0409c3,0x00760009,0xb8cc0011,0x889a0009}},	//   _quic, אתרי_, _गत_, גברי
  { {0xceb2000b,0x5fb60011,0x98a60035,0x2d9809c4}},	//   ֖ים_, _आइसल, tulē_, tyre_
  { {0xceb2007e,0x2d9e0107,0x6da303e1,0x387f0060}},	//   זים_, áte_, бира, _onur_
  { {0x6d4e09c5,0x0b1a0012,0xc4c50012,0x00da0012}},	//   rtba, فقرة_, لتقو, _ثبتت_
  { {0x0aea0048,0x3cc70048,0x38a20034,0xb87b0030}},	// [fe0] едай_, улто_, _góra_, blíb
  { {0x9a6a000a,0x610c003a,0x9e6609c6,0x20d901e3}},	//   عمال_, _ağla, _свод, béis_
  { {0xd5b10020,0xd12f0012,0x64c60012,0x05ba0012}},	//   _xét_, كمل_, _ميدل, _سددت_
  { {0xc209000b,0x7afc00f7,0x673b080d,0x00da0012}},	//   לה_, _wirt, šuje, ربات_
  { {0x14d70093,0xf76f0012,0x7c260035,0x7c29016d}},	//   _תוכל_, كاو_, _iekr, daer
  { {0x96e70024,0xba1a0012,0xbd6a0217,0x69dc09c7}},	//   льща_, _سيرا_, ерие_, _tyre
  { {0x2aa4000f,0xf9870012,0x91fc0035,0x7c26016d}},	//   _több_, _اب_, ndāt, _kekr
  { {0x35db0044,0xb4be0037,0xb97b000b,0x397b0009}},	//   _मुफ़, ँचे_, _אנלי, _אטלנ
  { {0x4093000a,0xb8930012,0x46160012,0xda6600ae}},	//   _القر, _القع, _موذر, هادي
  { {0x59b80037,0xa5da0003,0xc986004c,0x78a409c8}},	//   _आधार, _كبار_, гуми, _aliv
  { {0x78a409c9,0x6e25003a,0x7c260227,0xdd120060}},	//   _bliv, _rehb, _oekr, _rüşv
  { {0x69c30034,0x7cc80030,0xb87b0030,0x99f70009}},	//   źneg, běra, dlíc, טזיה_
  { {0x44290006,0xe29a0001,0xb87b01e3,0x61080030}},	//   vaa_, _пад_, elíc, _tělo
  { {0x2d98000e,0x7bdd0002,0x386d0584,0x44260081}},	//   _üres_, _rysu, žer_, _heo_
  { {0x44290006,0x26c3009b,0xc5340009,0xd2b70009}},	//   taa_, rnjo_, יָּה_, _תלות_
  { {0x317b0009,0x20d90478,0x89eb0009,0x89330012}},	//   _טרומ, réis_, _אַחֵ, _اعوا
  { {0x4429004a,0x26c3009b,0xc334000b,0xe29f0028}},	// [ff0] raa_, pnjo_, יוּ_, _auða_
  { {0x7ce50065,0xb6030066,0x20d90018,0x7e550024}},	//   jórn, část, péis_, _твоє
  { {0x4429004a,0x27ec0002,0x7bdd0002,0x4efa0009}},	//   paa_, ędne_, _wysu, _שהתו
  { {0xddde0013,0x7c2604a3,0x046709ca,0x80270012}},	//   _např, _gekr, _стом, ارام
  { {0xd366000a,0x8f690003,0x7ce50017,0x501c0009}},	//   _به_, ئمتك_, fórn, תודו
  { {0x13ba0009,0xe7eb0011,0x9a870024,0xbd450012}},	//   _יזרע, जेगा_, _сумл, لنتي
  { {0x200e0028,0x41e40024,0x63ad08f0,0x069800af}},	//   ækið_, _гіта, lzan, רדום_
  { {0x3f150024,0x442609cb,0x2db800af,0xf1b200af}},	//   _вдас, _ceo_, טלון_, _וסל_
  { {0x44260027,0x73050001,0x4f580012,0x7c84004c}},	//   _deo_, јпоз, _مجلد_, сује
  { {0xdfd80098,0xe2990001,0x60c90989,0xd7940003}},	//   _със_, тао_, _hjem, _الْخ
  { {0x20c6002d,0x7e63004a,0x7cc80066,0x26c40029}},	//   ийом, menp, měrn, émom_
  { {0x2c150011,0xc9520009,0xac1909cc,0xe45f0248}},	//   _फ्लू_, חמט_, _роду_, _sjön_
  { {0x78a40066,0x6d4309cd,0x8c1a0009,0x501a0009}},	//   _vliv, luna, _סוסי, כורו
  { {0x96ba0001,0x63ad084b,0xe29609ce,0xbb3a0009}},	//   туму_, dzan, _ваш_, _יעני
  { {0xb60601bd,0x2aba0009,0x6ecd0011,0xfcb6003c}},	//   _uváž, _שמצא, _तदनु, ащаю
  { {0xa7fb0164,0x248d0082,0x60c90604,0xb05b008e}},	//   seña, njem_, _njem, nnäl

  { {0x3b070098,0x7ae10052,0xd467031e,0x3a260024}},	// [1000] ието_, ollt, шите_, имаг
  { {0x29070005,0xb77b000b,0xbf9b0009,0x8eb30012}},	//   _kuna_, _יאפש, _סייש, _وميش
  { {0x7c2600a2,0xb4f70037,0x249f0028,0xbe3b000b}},	//   _tekr, ुदाय_, kkum_, _בעית
  { {0x3ea507e3,0x26d809cf,0x290709d0,0x2ca909d1}},	//   _allt_, loro_, _muna_, chad_
  { {0x63ad003e,0x91fc001e,0x248d09d2,0x290707f4}},	//   czan, ndār, djem_, _luna_
  { {0x60c902d1,0x6d430028,0x8d760012,0xe6930012}},	//   _ejem, funa, لاعا, يلند
  { {0xed870014,0x1ea90003,0x6d4309d3,0xda5b0009}},	//   исък_, داني_, guna, _שכלל
  { {0x7ae10028,0xd497003c,0x60c900b0,0x94170048}},	//   ellt, иры_, _gjem, ажът_
  { {0x7ac60015,0x6d4309d4,0x26d809d5,0xbb470012}},	//   исое, auna, koro_, للين_
  { {0x781f0044,0xd257002d,0x239a0010,0x2907097e}},	//   पर्क_, ацю_, mąją_, _buna_
  { {0x63ad01a2,0x672d080a,0x44260051,0xfa770009}},	//   zzan, šajt, _teo_, בעית_
  { {0xd83f0382,0x6d9b0009,0x04930012,0x55bb0009}},	//   _účtu_, _שבאפ, _وللح, _במבו
  { {0x6105007a,0xc053000b,0x34b30012,0xc43b0009}},	//   _vėli, חזר_, _بمنز, _יתאי
  { {0xdb9b000b,0x26d800b6,0x539b0009,0x3ea50031}},	//   _בסדר, goro_, _בידו, ólt_
  { {0xa2d30037,0x98c70015,0x290700b6,0x6e28009f}},	//   डवर्, _вспл, _guna_, _medb
  { {0x63ad03eb,0x7cc10039,0xbd440003,0x76b20002}},	//   tzan, tēri, تنفي, pływ
  { {0x5a350014,0x78bd0269,0xcfe90012,0x7b67004c}},	// [1010] йнат, misv, _حفظه_, штве
  { {0xda780047,0x7d080070,0x63ad09d6,0xb3c80011}},	//   иях_, _ouds, rzan, _रखरख
  { {0x2f0b00c5,0x63ad0002,0x7cc80066,0xe987004c}},	//   _søg_, szan, věrn, шћан
  { {0x6114002d,0x7cc1001e,0x78bd09d7,0x89340012}},	//   ідчу, pēri, nisv, زعما
  { {0x70520003,0xe7680003,0x96b90001,0x7ae109d8}},	//   سنوا, لحون_, луку_, yllt
  { {0x7d0809d9,0x6d4309da,0x68e2001e,0x23ca0037}},	//   _buds, tuna, alod, ापनद
  { {0x248d009b,0xce38000b,0x6d430051,0xd575027f}},	//   tjem_, באות_, uuna, суль
  { {0x60c9012e,0x4c85002d,0x6295000e,0xd0d40048}},	//   _ujem, слив, _hozo, _досъ
  { {0x248d009b,0x249f0028,0xa3d70037,0x6d4309db}},	//   rjem_, rkum_, िथि_, suna
  { {0x6d4309dc,0x29000051,0xfe700003,0x290709dd}},	//   puna, _siia_, _يدل_, _puna_
  { {0xf7690093,0x26d801a2,0x382a0015,0x7c2d09de}},	//   _רק_, voro_, лжно_, kaar
  { {0x14740012,0x84640048,0x515a0009,0x78bd0097}},	//   _وانج, _мъче, נכרו, gisv
  { {0x29000051,0x9991000e,0x6f0901e3,0x907a0009}},	//   _viia_, _mező_, _juec, אטרי
  { {0xfb1a000b,0x87b90015,0xceb20009,0xa3bd0011}},	//   _עוצמ, руют_, ִין_, ेपन_
  { {0xaab40003,0x6da30237,0xc6920009,0x38a90025}},	//   _بإنش, пира, האם_, _sûre_
  { {0x8936000b,0xdd8f0012,0x67240227,0xdca60048}},	//   _הרקע_, روق_, _twij, щаби
  { {0x7e9a0012,0x26d809df,0x60d9036c,0xccf20009}},	// [1020] _منظر_, poro_, dowm, לכל_
  { {0x7c2d002c,0x7cc1001e,0xe7b70009,0x64560132}},	//   aaar, mēru, _להפר_, sfyi
  { {0x68e2001e,0x7c2d09e0,0x3aba0009,0xcb090009}},	//   tlod, baar, נמענ, תל_
  { {0x6c86000a,0x70560003,0x24190024,0x7cc80030}},	//   _الحم, إنشا, _вірю_, věro
  { {0xddd50066,0x7d080027,0xf4130009,0x62830227}},	//   dezř, _suds, _מפר_, _onno
  { {0x9757000b,0xa7850003,0x442009e1,0x6e2e09d1}},	//   מינו_, تشمو, lbi_, nabb
  { {0xb996000a,0xb05b0066,0x6143046e,0x68e209e2}},	//   _الزب, ížít, _нера, plod
  { {0xe3140001,0x6ad00011,0x26c700b8,0xa06a0048}},	//   омињ, सक्र, anno_, _щаба_
  { {0x4420003a,0x389b0009,0xb7ca0012,0xcc330012}},	//   ibi_, _עימנ, _صبرك_, سريع
  { {0x86ea0003,0xaab4002d,0x78a200f1,0xd91a027f}},	//   _إعرف_, ійні, lkov, льм_
  { {0x290a0005,0x867b000b,0x442d002c,0x75d60012}},	//   _juba_, _תרבו, bae_, _ايضا
  { {0x23690002,0x27e90034,0x8c1a0012,0x290a016d}},	//   ywaj_, żane_, _إيشر_, _muba_
  { {0x274b0015,0x290a0051,0x98b80014,0x4420017b}},	//   ычно_, _luba_, слят_, dbi_
  { {0x291802d1,0x7c2d0070,0x7bdc003a,0x9e14002d}},	//   _otra_, waar, ğrud, здрі
  { {0x3abb0093,0x61020039,0xb05b004a,0x62950029}},	//   _תמונ, _vēlr, nnäk, _rozo
  { {0x58d40014,0x9419004d,0xf1b30009,0xd49809e3}},	//   _нощт, ржат_, _מסצ_, бру_
  { {0x4054000a,0x3866006f,0xdfd10003,0xaa070012}},	// [1030] _رئيس, deor_, _زيد_, مظاه
  { {0x539b000b,0xf8bf0061,0x5a35002d,0x7c2d0269}},	//   אימו, lié_, інет, saar
  { {0x4420000f,0x290a09e4,0xeab10009,0x98170012}},	//   bbi_, _cuba_, וֹא_, مبشا
  { {0xe1f00003,0x6d550052,0xec6b004d,0x55ba0009}},	//   رسل_, mtza, _срок_, _כמתו
  { {0xc058002d,0xdb460012,0x7a430031,0x61080030}},	//   сіх_, _تَ_, nítü, _děli
  { {0xb7c60039,0xfd110003,0x236f0028,0xcf580009}},	//   diģē, وجب_, ægju_, צבות_
  { {0x31350046,0x6d47009b,0xcc890015,0x442b00ed}},	//   _фебр, nuja, ибке_, _kec_
  { {0x7ce50002,0x94790001,0x6e2e000e,0x67d50024}},	//   mórk, рску_, zabb, _добу
  { {0xc64b0003,0xcec8001a,0x52a90339,0x3b850024}},	//   _مجال_, uộc_, ивим_, ілог
  { {0xadf90011,0x3a99003c,0x6e2e0032,0x7cc10035}},	//   ंधान_, ртию_, xabb, eērt
  { {0xf8bf0061,0x71b50015,0x208a02ac,0x39e905fb}},	//   fié_, ющих, айни_, рдно_
  { {0xc689000b,0x98a60010,0xd0060012,0x50b60024}},	//   _בא_, kslą_, توحً, існу
  { {0x2cad00c5,0xa856000b,0x7a43000e,0xa01b0097}},	//   mhed_, חירה_, gítü, tjör
  { {0x443909e5,0x78a909e6,0x78a20004,0x0b160012}},	//   _ads_, _llev, zkov, _بقوة_
  { {0xde03007c,0x78a902bd,0x660301b6,0x80e60012}},	//   дпри, _olev, дпра, _وأعل
  { {0x03260098,0xf8bf0061,0x2cad0058,0x6e2e09c5}},	//   ждан, cié_, nhed_, sabb
  { {0x72360003,0x765c0028,0x6d470010,0x20050066}},	// [1040] قراط, _öryg, auja, ělit_
  { {0xe8220037,0xea870048,0x61e30097,0x36c3003c}},	//   मर्थ_, обул_, _kynl, _обыг
  { {0x78a900c5,0x8916000a,0x7c390002,0xc04f0024}},	//   _blev, زبائ, _odwr, мі_
  { {0x78a909e7,0x6ee401a0,0xf80d0009,0xb7e609e8}},	//   _clev, mòbi, ְהוּ, ожек
  { {0x29070065,0xf8b30093,0xbe8a06fd,0x905b0009}},	//   ínar_, ושא_, иске_, שכנת
  { {0xbea30046,0xfd380003,0x877b000b,0x7d020002}},	//   мачк, مكتب_, יאני, _sios
  { {0x27ed000f,0xd639002d,0x7d020002,0xc8660012}},	//   _ezen_, сячі_, _pios, _وطري
  { {0x2cad00c5,0xd91b000b,0x442b0054,0xa6db0097}},	//   ghed_, _כולל, _xec_, irða
  { {0x7cc10039,0xccf3000b,0x320d003a,0xf3660024}},	//   vērt, וכה_, _şeyi_, ітин
  { {0xb7c6001e,0x2bb70003,0xdcea003a,0x7d020002}},	//   riģē, غاية_, ınır, _wios
  { {0xf8bf0061,0xc27b0009,0x7dc60012,0x76b20034}},	//   tié_, בריי, _بقان, słys
  { {0xbb860003,0x6d47004a,0x2cad09e9,0x7c2b0347}},	//   _ولاي, vuja, ched_, _gegr
  { {0x24860163,0x29180259,0xf8bf0061,0xc4f70009}},	//   _inom_, ūra_, rié_, _ומאז_
  { {0x26dc09ea,0x290409eb,0xda660012,0xaa580012}},	//   novo_, _lima_, _ذاتي, _طلبا_
  { {0xdcbb0098,0x25db0037,0x621b000b,0xf98f0003}},	//   аща_, _खुशी_, _דווק, _لبي_
  { {0x2904009b,0x67f5000e,0x291e09ec,0x629801bd}},	//   _nima_, nüjé, mpta_, _hovo
  { {0x63a000d9,0x309c0009,0xe6bc0011,0x442b09ed}},	// [1050] nymn, _כשהמ, ्चाङ, _vec_
  { {0x98a60010,0x7cd3000d,0x60dd006e,0x93fb0009}},	//   rslą_, măre, losm, שלמי
  { {0x89d90003,0x2d8c09ee,0x248609ef,0xddc50034}},	//   حوار_, ädet_, _onom_, _wchł
  { {0xf771000a,0x644f00c1,0x7d1a000e,0x26c40029}},	//   فات_, _ucci, ítse, émov_
  { {0x8e8509f0,0xb4d70037,0x78a90066,0x0a6b0001}},	//   згле, ाकी_, _vlev, _крви_
  { {0xd6db0046,0x23fa000b,0x7ce509f1,0x26dc017b}},	//   ште_, _להרא, móri, govo_
  { {0xa954002d,0xf5920012,0xa63c0009,0x2cad09f2}},	//   _окрі, فلوج, בגור, thed_
  { {0x7cc1001e,0x27180066,0x442b001a,0x644d09f3}},	//   vērs, něný_, úc_, ngai
  { {0x2cad0058,0xce6b0306,0x61e309f4,0xf77000ae}},	//   rhed_, _вред_, _synl, _لال_
  { {0xf3f9007d,0x2cad09f5,0xd2a90015,0x8d770003}},	//   neţi_, shed_, ское_, _واضا
  { {0x25db0037,0x2169077e,0xa9690264,0xd0f50009}},	//   _खुली_, щини_, щина_, ּמָת_
  { {0x85040012,0x66150034,0xd1960009,0x29040558}},	//   _قولن, eczk, לכתי_, öma_
  { {0x8bb70003,0x291e09f6,0x7ea20061,0x61fe01bd}},	//   _بإضا, apta_, _hôpi, _úpln
  { {0x6298080a,0xb7da000b,0x6d4309f7,0x63c80012}},	//   _govo, מקרי, orna, _بِهِ_
  { {0xf3f9007d,0xb7bd000d,0x91e209f8,0xa6c70012}},	//   deţi_, _deţi, _поше, أوّل_
  { {0x236d0002,0xa93a000b,0x113a0009,0xc5f20009}},	//   owej_, _התקפ, _התקל, תדל_
  { {0x7cd3000d,0x7ce509f9,0x14170012,0x2a620031}},	// [1060] căre, góri, سيلة_, őkbe_
  { {0xf3f9007d,0x96960001,0x67bb0009,0xd36f0012}},	//   geţi_, _хриш, _למפק, طهم_
  { {0x7e9b000b,0x0e9b000b,0xa00a0003,0x5e9b000b}},	//   _הסיו, _השיל, مقال_, _הביק
  { {0x62870503,0xc5eb0009,0x6d430159,0x98bf004b}},	//   _enjo, _לַכֹ, drna, mută_
  { {0x443209fa,0x66e60511,0x6d4309fb,0x98bf004b}},	//   may_, пода, erna, lută_
  { {0xf3f901b3,0xcf890003,0x26dc00c1,0x443209fc}},	//   ceţi_, تضمن_, uovo_, lay_
  { {0xd6570009,0xb6ad0009,0xe1690012,0xb1e60012}},	//   פיקת_, שׁוֹ, _وصفه_, _رأسه
  { {0x44320101,0x493b000b,0x3957000b,0xc1570009}},	//   nay_, _לגלו, _משלם_, _משלו_
  { {0x7d06004a,0x629809fd,0x66150034,0xf74303b0}},	//   _miks, _povo, yczk, _пето
  { {0x443209fe,0x7d0609ff,0x8f8b0009,0x139b0009}},	//   hay_, _liks, _לְבֵ, צביע
  { {0x28f9002d,0xb7bd000d,0x05db03bf,0x79a30015}},	//   жень_, _reţi, _मुंब, еряе
  { {0x62980032,0x7cd3004b,0x60c20a00,0x48ab0a01}},	//   _wovo, tăre, niom, стом_
  { {0xe7870001,0xdfdb0014,0x44320a02,0x7c240060}},	//   чуно, сън_, day_, dbir
  { {0xd24f000a,0xb3e90003,0xb2d30003,0x291e079d}},	//   _منه_, _بعمل_, _كينغ, ppta_
  { {0xda5b000b,0xa2d90037,0xf3f9000d,0xa6db0028}},	//   _הכול, नकर्, veţi_, nuði
  { {0x443201e5,0x7ce50a03,0xb4d70037,0x644d0010}},	//   gay_, tóri, ाके_, ugai
  { {0xf3f901b3,0x883c0093,0x28580003,0x78ad003a}},	// [1070] teţi_, _התחו, _رؤية_, _ilav
  { {0x78ad00f1,0x67540003,0x3860001b,0x64ac0060}},	//   _hlav, _أخير, _zbir_, işiy
  { {0x44320101,0x98bf000d,0xf3f9000d,0xd1300003}},	//   bay_, cută_, reţi_, ُمْ_
  { {0x26c3009b,0xe9f8002d,0xd138002d,0xd1170009}},	//   lijo_, їнці_, яху_, פקדה_
  { {0x3b640098,0x7eaf0119,0xf3f9000d,0x6d580035}},	//   _първ, _løpe, peţi_, etva
  { {0x7fb6000a,0x6447007a,0x26c3009b,0x78ad0a04}},	//   ظهور_, ėjim, nijo_, _llav
  { {0x6724001e,0x60c2005e,0xdb080031,0xa3a905f3}},	//   ģija, biom, ölöt, गैर_
  { {0xc9520009,0x5ba90198,0x98a900ae,0xe58c00af}},	//   _שמן_, жким_, _بُرك_, מָחָ
  { {0x33650024,0x98bf004b,0x2d570060,0x6d5c054e}},	//   євог, zută_, hçe_, _äran
  { {0x2d57003a,0x7c24009b,0x957c0034,0x26c30159}},	//   kçe_, zbir, _cząs, jijo_
  { {0xa3e40037,0x26c30a05,0x5e440012,0x7bce0032}},	//   _पुन_, dijo_, _أَمْ, ßbur
  { {0x78ad0a06,0xcea9000b,0x644a000e,0xb4d70011}},	//   _clav, _די_, őfiz, ाको_
  { {0x610c00a2,0x26c30a07,0x7d060153,0xa0360009}},	//   _işle, fijo_, _riks, וארה_
  { {0xa1c5002d,0x60c20002,0x26c3009b,0x7d060577}},	//   _облд, ziom, gijo_, _siks
  { {0x7cd3007d,0x88c60003,0x44320363,0x84e60024}},	//   cărc, _يتعل, tay_, довж
  { {0x442f045d,0x61fa0028,0x78ad0082,0x5f460012}},	//   _jeg_, _útli, _glav, _قنبل
  { {0x442f0a08,0xa857000b,0x26c3009b,0xa08b000b}},	// [1080] _meg_, _חיפה_, bijo_, _וְיִ
  { {0x26c3012e,0xda660003,0x44320a09,0x8e4a0003}},	//   cijo_, باري, say_, _بلدك_
  { {0x7d06007a,0xa96a0003,0x6d580248,0x44320a0a}},	//   _tiks, تمام_, xtva, pay_
  { {0x291c001e,0x3ce9015b,0x7c2f0832,0xf2c90009}},	//   īva_, clav_, _gecr, בע_
  { {0x9ffa0012,0x69d50032,0xf76f0012,0x60c20a0b}},	//   آراء_, _exze, لاو_, riom
  { {0x442f0005,0xdfcf0003,0xd7f9002d,0xb7db000b}},	//   _aeg_, جيه_, чує_, חקני
  { {0x63a40a0c,0xd5b00012,0xafdb07c2,0x442f0a0d}},	//   lyin, طفة_, ngør, _beg_
  { {0x5ba6002d,0x26c3009b,0x2a7800b6,0x54540048}},	//   дроз, zijo_, _harb_, хвит
  { {0x442f03a0,0xbc1b000b,0xcb670001,0xfc3f0028}},	//   _deg_, חופש, дање_, _slík_
  { {0x610c00a2,0x3b070061,0x68e400b6,0x079b0009}},	//   _eşle, _cinq_, _akid, _וסמל
  { {0x67220039,0x6da60003,0x26c3009b,0xc27b000b}},	//   lpoj, _تمام, vijo_, קרטי
  { {0x3cfa0044,0xa9c3007c,0x1417000a,0x63a4004a}},	//   ्दों_, тськ, _قيمة_, kyin
  { {0x5f940014,0xceeb0003,0xd7e4002d,0x7afd0066}},	//   вият, قرآن_, віро, ůsta
  { {0x2d5700a2,0xeb970001,0x7cd3000d,0xaab70012}},	//   tçe_, _циљ_, măra, _يدور_
  { {0x95c50003,0x26c3009b,0xafdb0058,0x9d180345}},	//   ريره, rijo_, ggør, дост_
  { {0x9f55002d,0x63a4002a,0xddc3000d,0x6b820a0e}},	//   _звич, fyin, lenţ, _krog
  { {0x26c3009b,0x18340012,0x92a60034,0xd1380073}},	// [1090] pijo_, _شريح, _odłą, lsą_
  { {0xe9ab0003,0xddc3000d,0x27e901ea,0xeb910009}},	//   يدان_, nenţ, _iyan_, נָן_
  { {0x7c2f003a,0xd1380010,0x7eab0051,0x629c0a0f}},	//   _tecr, nsą_, _hüpo, _doro
  { {0xd8b80003,0xd1380010,0xf9900012,0x20190031}},	//   ودنا_, isą_, جبك_, ncsi_
  { {0x63b6003e,0xbc1a000b,0x8c1a000b,0xddd5000e}},	//   czyn, _מורש, _מורי, mező
  { {0x442f0119,0xd356000b,0x1d09002d,0xd1380010}},	//   _seg_, _אישי_, пеки_, ksą_
  { {0xddc3007d,0xb05b0a10,0x26c9001b,0x5eec0009}},	//   denţ, nnäs, đao_, קַדְ
  { {0x628a0052,0x6d4703d5,0x8b950015,0xeb9902ad}},	//   _anfo, irja, ероч, зии_
  { {0xe3b10003,0x442f0028,0x7c840001,0x86c50012}},	//   طرة_, _veg_, тује, _كيرن
  { {0xeb92000b,0xddc3000d,0x442f0832,0x2ef4004c}},	//   רָה_, genţ, _weg_, _азур
  { {0xa6db0028,0x442f006f,0x5fc50011,0x6b820a11}},	//   nuðu, _teg_, _लेबल, _erog
  { {0x2d980054,0xddd5000e,0x6c840012,0xc19a0009}},	//   _àrea_, jező, _للمم, לשתי
  { {0x6d410028,0x6d470a12,0xec360009,0xe3ae0695}},	//   álan, erja, _נאסר_, _сб_
  { {0xd2510003,0xddc3000d,0x9f56000e,0x2f14006f}},	//   _صنع_, cenţ, égét_, _väg_
  { {0x98a70066,0x9f630030,0x7ae10a13,0xf3f70081}},	//   éně_, ěvák_, molt, ệng_
  { {0xafdb0058,0x63a40258,0x629c0a14,0x91ba0009}},	//   rgør, tyin, _soro, _ממצי
  { {0xcb670a15,0x88bd0066,0x629c0a16,0x434302ad}},	// [10a0] нате_, spěc, _poro, летв
  { {0x35db0037,0x63b60002,0xb05b006f,0x7ae10a17}},	//   _मुक़, rzyn, snät, nolt
  { {0x63b60002,0xc8660345,0x3ad30012,0xa0a6003c}},	//   szyn, етли, ديلز, нажд
  { {0xd4910020,0x60c600b6,0x2ca9006f,0xddc3000d}},	//   _tùy_, nikm, ckad_, zenţ
  { {0x60c60051,0x10020011,0xb05b0a18,0xfe360009}},	//   iikm, ोशिश_, onär, ֲרֵי_
  { {0x7cd3000d,0xfe6f0003,0x26ce0a19,0xfc3f0030}},	//   văra, مدى_, unfo_, _zdí_
  { {0x6b820034,0xddc3004b,0xe4a60560,0xe7c00011}},	//   _srog, venţ, ерпо, _शेरप
  { {0x91e30015,0x1d070001,0x6722008e,0x515b0009}},	//   _сосе, неји_, ppoj, _מכלו
  { {0xddc3007d,0x68e20051,0x7afe08b9,0xc4770009}},	//   tenţ, mood, ompt, תתפו_
  { {0x9bbb000b,0x394c0054,0x7f3b000b,0x6d470028}},	//   פציפ, tuds_, _מעמו, yrja
  { {0x200d00a2,0xd46a0a1a,0xd2b7000b,0x0c26002d}},	//   şmiş_, _ниже_, גלית_, _змен
  { {0xeb9a0098,0x01370093,0xe61f001a,0x7cd3000d}},	//   _ние_, ערכת_, _đôi_, păra
  { {0x28c00037,0xdefb0015,0xfaa60430,0x79830032}},	//   शोधि, зыв_, _падо, _ernw
  { {0x6d5c0052,0x628a002a,0x7ae10a1b,0xb9940012}},	//   ftra, _unfo, colt, _للتب
  { {0x68e203d5,0xc27b000b,0x627b000b,0x7ce50018}},	//   kood, _מרגי, _מנגנ, pórt
  { {0x61430001,0x60c6003a,0xa3e40011,0x6fb50012}},	//   _сећа, cikm, पअप_, _لمبا
  { {0xfbd00003,0x27e9003a,0x6d4e0a1c,0xf7840012}},	// [10b0] متك_, _uyan_, auba, _مليَ
  { {0x2ca9006f,0x7e7a0027,0xa6db0097,0x1db00011}},	//   skad_, _natp, tuðu, जनात
  { {0xc9840001,0xb8350048,0x6d5c0a1d,0x6d4e0a1e}},	//   луци, веещ, ctra, cuba
  { {0xc5f2015a,0xcd96000b,0x7ae1000e,0xd308001a}},	//   _כדי_, _סדרת_, zolt, _iệu_
  { {0x4c9a000b,0xef18002d,0x03d50009,0xce950048}},	//   _חברו, емі_, _יוֹם_, кадъ
  { {0x7bdc00a2,0x44290a1f,0xc6680001,0xa77c0009}},	//   ğrul, lba_, ешће_, פרופ
  { {0x20e10037,0x6917001e,0xc9e50012,0xc8790060}},	//   नवाध, _aģen, _شكرً, _taş_
  { {0xb062005e,0x44290a20,0x4c850a21,0x000000c4}},	//   äätm, nba_, тлив,
  { {0x6d5c0a22,0x60c60097,0xe4520009,0xdb140097}},	//   ztra, vikm, בֶת_, óaðr
  { {0xa3a80012,0x8cc10011,0x17f80012,0x63a600b0}},	//   عطيك_, रोतो, _سرقة_, økna
  { {0x2a76000b,0x60c60010,0x4429000e,0x2d9a0033}},	//   דעתך_, tikm, kba_, øpet_
  { {0xf9920009,0xbb850012,0x7ae10a23,0xddc30035}},	//   ׁ֨ר_, _للصي, solt, cenš
  { {0x98bf06d4,0x3f840066,0x883a000b,0x44290a16}},	//   nutę_, ímu_, ותרו, dba_
  { {0x442902d1,0xbb420001,0x3f5b001a,0xfaa20a24}},	//   eba_, _тешк, iêu_, _вашо
  { {0x65c30a25,0x8a140003,0x8707002d,0x40960012}},	//   абра, _إظها, терв_, _للغر
  { {0x6d4e0a26,0x44290a27,0xa7d60012,0x5cf60024}},	//   ruba, gba_, _لتخص, тягу
  { {0x6d4e0101,0x25e80037,0x68e2005e,0x8cc10011}},	// [10c0] suba, _चुनी_, vood, रोधो
  { {0x7c29038c,0x96fa0012,0xc87f0032,0x610c0060}},	//   hber, _تعبر_, roße_, _aşla
  { {0x98c60044,0xa2a30037,0xf8c60037,0xda650003}},	//   _लगाए, _गवर्, _लगाय, طالي
  { {0xdb0d000e,0xf9920009,0xd3080081,0x4fc60048}},	//   szaá, ירב_, _hệt_, ксла
  { {0xdfcf0003,0x5f730012,0xc0170009,0xb87b0031}},	//   ييم_, لاور, דקנו_, mlít
  { {0xb87b000f,0x68e20051,0x6d5c0051,0x7c290a28}},	//   llít, sood, _ärak, eber
  { {0xceb3000b,0x95530003,0xd5af0012,0x7c290032}},	//   שיו_, لخيا, يفه_, fber
  { {0xb87b000e,0x29180017,0xfc660048,0xfbd20009}},	//   nlít, íram_, тъкн, ֹת֙_
  { {0x26c7012e,0xd4670001,0x0c730012,0xe29f0097}},	//   bino_, тиње_, شديد, _guðs_
  { {0xc3330093,0xa0210028,0x7c290a29,0x26c70a2a}},	//   סות_, _þörf, aber, cino_
  { {0x3a37000b,0x7c290a2b,0x8d770012,0x80bf0011}},	//   כרים_, bber, _لملء_, लोवे
  { {0x7ccc003a,0xa8a70a2c,0x30a70a21,0xfd570009}},	//   oğru, трок, тров, _ישבי_
  { {0x58d4004d,0x35db0011,0x2d9e0a2d,0x1d07004c}},	//   роят, _मुज़, äten_, _реци_
  { {0x41dd0037,0xd3370009,0xddda0073,0x62340a2e}},	//   _नुकस, _ירדה_, _natū, _секу
  { {0xdce30002,0xe6110009,0x8aab0009,0xba290012}},	//   ewnę, מִן_, _קֹדֶ, _أسهم_
  { {0x44290a2f,0xa6db0097,0x628e0a30,0x5d7b0009}},	//   uba_, irði, _anbo, ואלק
  { {0x09bd0037,0x9be7002d,0x6d4a0052,0x1be30011}},	// [10d0] ्प्य, тівк, hrfa, _कुशल_
  { {0x7c29009b,0xdd03003a,0xf1a70a31,0xf1950024}},	//   zber, ırıc, крен, лизь
  { {0xd0110003,0x6cd50003,0x25a5006f,0x6d5c0051}},	//   ملا_, _مقدا, älld_, _ärah
  { {0x30a70014,0x6019003c,0xf1c30073,0xccf80030}},	//   ързв, ходя_, _rašė_, _zpěv_
  { {0x3ea10051,0x6f650003,0x7b090010,0xa3e40011}},	//   _koht_, اهتم, _užuo, पॅम_
  { {0x999c000e,0xc7320012,0xe7eb0011,0x4df50a32}},	//   _levő_, حفوظ, ड़ेगा_, ляйт
  { {0x7c2904a3,0xc6940009,0xe8030011,0x0dc8004c}},	//   tber, יאס_, रेता_, кући_
  { {0x94750003,0x26c701f3,0x24490012,0x3f82009e}},	//   ادثا, sino_, رجعي_, yvku_
  { {0x26c70a33,0xdce5001e,0x2d9a0033,0x13090055}},	//   pino_, _arhī, øper_, нний_
  { {0x6b67001e,0xe6f20081,0x7dd20031,0x7c290a34}},	//   mīgā, _tườ, nűsé, sber
  { {0x27fa003e,0x24550003,0xaadc0009,0xf2d40009}},	//   ępne_, _مناس, וחזר, יעץ_
  { {0x351a0009,0x1cbb0012,0x629a0a35,0x40960a36}},	//   _טוענ, _غاضب_, ajto, урот
  { {0x7ae502bd,0x239b0003,0xf7720012,0x6b670035}},	//   koht, _تخضع_, حاج_, nīgā
  { {0x7ae5004a,0x2cad0a37,0xe39a0009,0x1bb80012}},	//   joht, lked_, _רֹאש, _جامع_
  { {0x92560001,0x2cad0132,0x96c30011,0x270f0011}},	//   _сајт_, oked_, रफ़ॉ, ादुर_
  { {0x2cad0979,0xc9520009,0x63a90025,0x4f960a38}},	//   nked_, _המה_, oyen, _броу
  { {0x577a0003,0x63bb0052,0xa2d60012,0x6d460035}},	// [10e0] _أصبح_, nzun, هيرت, _ākam
  { {0xa6db0028,0xb87b0042,0xe2450012,0x7e56004c}},	//   yrði, slít, لخمي, _стиц
  { {0x09f60063,0xa84a0012,0x210e0011,0xaa570012}},	//   учая, فلام_, िदेश_, الما_
  { {0x7e7e0a39,0xd7fa0015,0x25a50a3a,0x27ed0a3b}},	//   _happ, нул_, älle_, _byen_
  { {0xbea60021,0x96ea00b3,0xa8570009,0xe3b20012}},	//   ладк, нька_, רינה_, _طرح_
  { {0xdee3027f,0x61050073,0xddc70a3c,0x8b8b0009}},	//   бочи, _mėly, lejš, _אָלֶ
  { {0xb5aa0003,0xccf80066,0x8178000b,0x7b090027}},	//   عاتك_, _opět_, _בְּק, _ožuj
  { {0x6b840051,0xddc70a3d,0x7e7e0a3e,0xb8660012}},	//   ovig, nejš, _lapp, _حاسو
  { {0x6b67001e,0xaaa80037,0x63a9000e,0xa5070001}},	//   cīgā, _गवाक, gyen, ћења_
  { {0x6fb30003,0x5a340014,0xf1260109,0x3a3a013e}},	//   _امكا, шнот, льмо, napp_
  { {0x6b840051,0xa526004c,0xd9170223,0x6da60012}},	//   hvig, _смед, лья_, _حمام
  { {0x2cad0036,0x7a48001e,0x91bb0009,0x6fb50012}},	//   cked_, lītē, תמטי, لمجا
  { {0x7eab0051,0x4fc70083,0x0a9401d4,0xa3e40011}},	//   _hüpi, усна, _валю, _पुल_
  { {0xe6100003,0x07090012,0xddc80a3f,0x7e7e03c1}},	//   كشف_, ئيسي_, _madž, _capp
  { {0xccfb0046,0x7eb00051,0x6b670035,0x291c08ca}},	//   ећа_, _täpn, zīgā, íval_
  { {0xb4c10037,0x895b000b,0x99f50024,0x61f50060}},	//   ्चे_, _נדחת, _тячі, üzle
  { {0x36d50047,0x6bd40003,0x5a350229,0xdc8b0009}},	// [10f0] _вопр, متكر, инат, עְלָ
  { {0xccf80013,0x6b670035,0xdb040034,0x68e90a40}},	//   _zpět_, vīgā, dzió, _sked
  { {0xc0cb0046,0x7dd2000e,0xc6920009,0x1ed80012}},	//   нуде_, rűsé, _ואי_, _حبيب_
  { {0xf771000a,0x3aeb0033,0x31570009,0x7ae5005e}},	//   قات_, løpt_, ריאן_, soht
  { {0xcc56000b,0xf43a0009,0x4c3a0009,0xc43a0009}},	//   _דברי_, _בגרמ, _בתרב, _שתשי
  { {0x6b67001e,0x8afd0066,0xd738000b,0x9e640024}},	//   rīgā, otře, נטות_, йвід
  { {0xd658000b,0x7d0f000e,0xf2d2000b,0x40350a41}},	//   איות_, _kics, _ועם_, _вебс
  { {0x63bb008b,0x58d5002d,0x934505cc,0x27f20034}},	//   tzun, _тобт, ание, żyna_
  { {0x2cad0a42,0xe7ec0011,0x63bb0032,0x88bd0030}},	//   rked_, _छुपा_, uzun, rpěl
  { {0x4e78000a,0x2cad0a43,0x88bd0066,0x63bb0052}},	//   _محمد_, sked_, spěl, rzun
  { {0xbd4b0003,0x67240377,0x80a60012,0x3d110011}},	//   _سؤال_, _stij, لمدن, _दंगे_
  { {0x2541007a,0xa3b50044,0x7c2d0002,0xd59a000b}},	//   dėl_, जना_, jbar, _בבעל
  { {0x26ca0101,0x442d0a44,0xddc70a45,0x889a0009}},	//   tibo_, mbe_, vejš, דברי
  { {0xff16000b,0x49b90003,0xdcfc01bd,0xceb20009}},	//   יקשת_, _لابد_, tvrď, ֗ים_
  { {0xceb20093,0xe506000a,0x3f89000d,0x3c42000e}},	//   חים_, لبري, _erau_, _lévő_
  { {0x3f890a46,0x89da01b0,0x7e7e016a,0x26ca020d}},	//   _frau_, _שחקי, _wapp, sibo_
  { {0xd497001a,0xa6db0028,0x03230104,0xddc70a47}},	// [1100] ờng_, erðu, ждун, rejš
  { {0x23600070,0x6d410a48,0x62810a49,0x7c2d0a4a}},	//   rtij_, _ovla, ndlo, abar
  { {0x3af50015,0x442d000e,0x50260012,0x7c2d0906}},	//   сятс, kbe_, لفاك, bbar
  { {0x387f0039,0x442d0a4b,0x351b0009,0xcfa6003c}},	//   _caur_, jbe_, _שוכנ, ишли
  { {0x7ccd0039,0x442d0133,0x6fd60003,0xdddc000e}},	//   _mērķ, dbe_, جزائ, merő
  { {0xdb04000f,0x6b8b0058,0x7d0402bd,0x78a4004a}},	//   rzió, ægge, lmis, _loiv
  { {0x38560014,0x5096004c,0x409602ba,0x5ee90009}},	//   _възс, _крађ, _крат, נַנְ
  { {0x48e3002d,0x41b30012,0x78a40018,0x442d0031}},	//   _досв, _بمفر, _noiv, gbe_
  { {0x3d160037,0xa3d60037,0x4420000d,0x9ae9002d}},	//   _पूरे_, िपि_, ici_, нiше_
  { {0x29180a4c,0x6d4109d4,0x7d040a4d,0xbae30012}},	//   _kura_, šlai, hmis, يكيي
  { {0x442d01a2,0x44200066,0xf426004a,0x0217000b}},	//   bbe_, kci_, ääsi_, יחים_
  { {0x3866038e,0x6e3c031d,0x649c0054,0xd5770009}},	//   nfor_, earb, _néix, _כתבה_
  { {0x7d040005,0x274b0014,0x78a40061,0x6e3c0052}},	//   dmis, ъчно_, _doiv, farb
  { {0x6e3c0a4e,0x44200a4f,0xbb3b0009,0x13bb0009}},	//   garb, eci_, _יעדי, _שֶׁמ
  { {0x63a2004a,0x42fb000b,0xbafb000b,0x51930003}},	//   äonn, _שהוס, _שהוש, _ولهذ
  { {0xdddc000f,0xb0350001,0xc0350001,0x7d040a50}},	//   gerő, _униш, _униј, gmis
  { {0x8afd0013,0x5c070014,0x2fcf006f,0x4374002d}},	// [1110] stře, рява, _ägg_, жуєт
  { {0xe9870001,0x7c3b0002,0x7d0400e6,0xc20b0012}},	//   ићен, zaur, amis, نغام_
  { {0xa81b0012,0x27fe0034,0x180f0011,0x442d0a51}},	//   نتشر_, ętne_, िश्व_, ybe_
  { {0x7c950003,0xd91b0009,0x29180a52,0x44200a53}},	//   _الحص, דואל, _dura_, cci_
  { {0x7bd800a2,0xb4fa000b,0x9203001e,0x44390a54}},	//   şvur, _תפרי, _šādi, _ies_
  { {0x7cd3007d,0xaec4002d,0x8ee80024,0x45450012}},	//   mări, обіл, амів_, منتق
  { {0x20d20026,0x44390a55,0x27fa0002,0xddc80002}},	//   lšie_, _kes_, ępna_, _gadż
  { {0x25d80093,0x9dd8000b,0xadd8000b,0x80c60037}},	//   יוון_, יווק_, יווח_, _लगें
  { {0xdcb1008a,0x7cd3000d,0x44390a56,0x69ce0029}},	//   _của_, nări, _mes_, úben
  { {0x44390a57,0xc334000b,0x2b4d0054,0x7c2200e7}},	//   _les_, חוץ_, rrec_, _efor
  { {0x7d040a58,0x20d20029,0x63ad00b6,0xa969004c}},	//   ymis, hšie_, hyan, ћима_
  { {0x4439007a,0xcea9000b,0xfdf6000b,0x26de0029}},	//   _nes_, _אי_, _הצעת_, čtom_
  { {0xef19003e,0x20d20026,0x78a40006,0xd308001a}},	//   _już_, jšie_, _voiv, _tệp_
  { {0x249f0065,0x6d55007d,0xfbd00003,0x63ad01ea}},	//   ljum_, fuza, _تتم_, dyan
  { {0x7d040005,0x3ea503eb,0x6e3c0202,0x78a4019a}},	//   tmis, _molt_, rarb, _toiv
  { {0x44390108,0x25a5006f,0xbc19000b,0x2d870051}},	//   _ces_, älla_, רוּש, ivne_
  { {0x6a160003,0x7cd3000d,0x44390a59,0x64a3004d}},	// [1120] مبار, gări, _des_, чата
  { {0x44200a5a,0x3f8f0017,0x44390647,0x249f005e}},	//   sci_, _água_, _ees_, hjum_
  { {0xc6930093,0x9985007a,0x5d860003,0x44390054}},	//   _זאת_, malų_, _الجل, _fes_
  { {0x7cd3000d,0x4439006f,0xcb090009,0x71880009}},	//   bări, _ges_, גל_, יְנַ
  { {0x7cd3007d,0x3ea50a5b,0x3866038e,0x60630012}},	//   cări, _bolt_, rfor_, سهول
  { {0x99850010,0x66e3002d,0x44390070,0x8d760012}},	//   nalų_, поча, _zes_, ماعا
  { {0x11da000a,0xceb3000b,0x44390a5c,0x361b0009}},	//   _صورة_, היג_, _yes_, נוקד
  { {0x2912002c,0x3ce005dd,0x249f0097,0xc0d60012}},	//   _niya_, čivo_, gjum_, _ايرب
  { {0xdfcf000a,0xbb470003,0x99850010,0x68ed0060}},	//   _كيف_, ملين_, kalų_, _rkad
  { {0x2561000f,0x314a000b,0xe3af0012,0x28c40011}},	//   ból_, ְתָּ, عري_, लोरि
  { {0x7cd3000d,0xf09f0054,0x25ed0011,0x5d860012}},	//   zări, tjà_, _आँधी_, _دلال
  { {0x29000020,0xdbdd000e,0x09f70009,0x07b90012}},	//   _chia_, sáér, ממים_, لهجة_
  { {0x33f60003,0x2e4b0048,0x7cd3004b,0x2ca0016d}},	//   _اساس, ляво_, xări, djid_
  { {0xd130000a,0x7d1a02bd,0x20d20029,0x44390a5d}},	//   _قمت_, _kuts, všie_, _ses_
  { {0x2ca60051,0x7e75009b,0x82630012,0x44390a5e}},	//   _kood_, rezp, _رهين, _pes_
  { {0x7cd3007d,0x8cf5007c,0xa5070024,0x35b30024}},	//   tări, ізац, сягл, обґр
  { {0x2ca6021b,0xab940024,0xa4b70009,0xab870048}},	// [1130] _mood_, питі, צלמה_, щувк
  { {0x7cd3000d,0x20d20029,0x7d1a0a5f,0x63ad0a60}},	//   rări, ršie_, _outs, ryan
  { {0x7cd3000d,0xceb2000b,0x63ad0a61,0x89d90012}},	//   sări, _חיי_, syan, جوار_
  { {0x20d20026,0x7cd3000d,0xdfd10003,0x43950014}},	//   pšie_, pări, ويا_, _дамс
  { {0xb05b004a,0x46a50014,0x987c0009,0xe7680012}},	//   liäs, жалв, טראק, محون_
  { {0x79820002,0xf7700003,0x256105d9,0x97580009}},	//   łowa, عان_, tól_, מידו_
  { {0x3ea5000f,0x04590003,0x249f0028,0xfc310003}},	//   _volt_, للغة_, tjum_, وحة_
  { {0x2561000f,0x7eab0051,0xc325004d,0xef190034}},	//   ról_, _küps, омик, _tuż_
  { {0xdb00004a,0x2d8c0052,0x249f0028,0xd299002d}},	//   kymä, _erde_, rjum_, атні_
  { {0x02c5007c,0x2912002c,0x62850a62,0x05670030}},	//   ійно, _siya_, ndho, _číně_
  { {0xd4e7007c,0x6ce7002d,0x2bd00037,0x7d1a0052}},	//   _люди, _ліде, _सेना, _guts
  { {0x2ca6084e,0xc1060012,0x9b950012,0xa3e90011}},	//   _good_, توجي, _ولات, यथा_
  { {0xb4e50037,0x443f02b7,0x10a30048,0xe9ff0081}},	//   पकी_, mau_, фиян, _trặc_
  { {0xdcb10020,0x443f0a63,0x6b890097,0x6d480073}},	//   ển_, lau_, mveg, šdam
  { {0xa1560001,0xc6920009,0xa0c60012,0x6b89005e}},	//   _дају_, ואם_, _ويتو, lveg
  { {0x7afd0010,0x842a00b3,0x6d4303b9,0x62850032}},	//   įstu, ржав_, isna, edho
  { {0xd6d20003,0x5aca01ec,0xd3870063,0xbb4a0012}},	// [1140] _يقع_, алам_, ойте_, شلان_
  { {0x386d008b,0x7cd3007d,0x2ca000b6,0x33d5002d}},	//   _aber_, măru, sjid_, чіст
  { {0x998c003e,0x6d41000f,0x64a60a25,0x68460003}},	//   wadź_, álat, _дана, قَال
  { {0x3f8d0054,0x62950070,0xb05b0a64,0x186a0a65}},	//   _breu_, _enzo, chäd, ради_
  { {0x27e000a1,0x4733002d,0x3f8d0054,0x2ca60070}},	//   çin_, дніс, _creu_, _rood_
  { {0x9f61000f,0xde930001,0xc7b3000b,0x1c0d0037}},	//   ését_, дашњ, ובד_, ाइनल_
  { {0x2ca60051,0x6d43013f,0x20d60024,0xadb70012}},	//   _pood_, gsna, _діас, يهها_
  { {0x5c980098,0xa3ae0011,0x636a004c,0x6aa10040}},	//   ския_, _कथा_, арог_, ejlf
  { {0xae7a0047,0x3f8d0a66,0xdc8b0009,0xdb00008e}},	//   _всех_, _greu_, בְיָ, yymä
  { {0x2ca60a67,0x75960012,0x78a20a68,0xc56a0012}},	//   _wood_, _وجاء, ljov, _نحصل_
  { {0xe29a0020,0x81c60015,0x44320002,0x443f0a69}},	//   _chưa_, ющие, kby_, bau_
  { {0x6d580051,0xb97b000b,0xb05b008e,0x7bdc0032}},	//   muva, בנטי, viäs, ßrus
  { {0xdb00004a,0x6bd60003,0x62830584,0x64400a6a}},	//   tymä, _بتار, _fano, mami
  { {0x7c260058,0x62830a6b,0xb05b008e,0x44320929}},	//   _afkr, _gano, tiäs, eby_
  { {0x9c8306bc,0xa3d00044,0xeca70001,0x31c30048}},	//   íčov, _वेब_, ојан, _осъв
  { {0x4c940015,0x6aaa0052,0x19bb000b,0xb4b50011}},	//   мисс, öffn, _כמוב, झसे_
  { {0x7cd3000d,0x7ce50002,0xdfd10012,0xfbd00012}},	// [1150] căru, tórz, _سيد_, نتك_
  { {0x6d41000f,0xba98002d,0x6d58015e,0x291c019a}},	//   álas, овує_, kuva, _kuva_
  { {0xe2a60065,0x67290013,0xa696000b,0x6d580a6c}},	//   _áður_, _stej, _זכתה_, juva
  { {0x6d580051,0x3f8d0054,0x5d7a0009,0xc19b0009}},	//   duva, _preu_, _פארק, ישבי
  { {0x4c9a0009,0xc49a0009,0xbfb80012,0x64400a6d}},	//   _הברו, _השרת, يطها_, dami
  { {0xcf58000b,0x06c8002d,0xc7d8000b,0x8f7c000b}},	//   קבות_, огій_, חודי_, ינדק
  { {0x60cd0a6e,0xce380009,0xbd450012,0x31780012}},	//   _omam, חאות_, أنبي, _وحفظ_
  { {0xb4e50044,0x64400a6f,0x62830006,0x6d4300bd}},	//   पके_, gami, _sano, rsna
  { {0x38a20002,0x20d20029,0x97250012,0xe4c80012}},	//   _góry_, jšia_, _رفضو, تبون_
  { {0x78a90070,0x644000ff,0x6d58005e,0x7cd3004b}},	//   _hoev, aami, buva, văru
  { {0x64400051,0x6d580027,0xe2a80012,0xceb20009}},	//   bami, cuva, تاين_, _ריב_
  { {0x7d020a70,0xe4d70012,0xd5fa0009,0x64400a71}},	//   _ghos, _بتطب, _הפער, cami
  { {0x69c1000f,0x62830101,0xa295002d,0xdd0c0002}},	//   szle, _tano, _наді, różn
  { {0x7d090a72,0x78bb0164,0xe29a001a,0x0ae80012}},	//   lmes, _lluv, _thưa_, _وروي_
  { {0x2a3a000b,0x443200f1,0x6da609c6,0x6df60012}},	//   _העצמ, tby_, чива, سكرا
  { {0x7d0900a2,0x61fc00a2,0x03260a1a,0x8b260015}},	//   nmes, ürle, здан, здае
  { {0xccf20093,0x305b000b,0x905b000b,0x27ed0054}},	// [1160] תכן_, _הדפד, _הכפת, üent_
  { {0x09e6011f,0x7d090052,0x7c2400c1,0x3e6f0060}},	//   позн, hmes, scir, nıtı_
  { {0xfbc9000b,0xe9da0001,0x7d090a73,0xdee50012}},	//   נת_, љке_, kmes, _تأيي
  { {0xb4e50037,0xd12f0003,0x443d0a74,0x4424003a}},	//   पको_, امن_, _new_, _üm_
  { {0x64400005,0x7d090a75,0x945d0034,0x28bd0011}},	//   vami, dmes, hińs, ्फ़ि
  { {0xab270098,0x33fb000b,0xabfb000b,0x61460a76}},	//   _хора_, _להכנ, _להכר, _нега
  { {0x64400a77,0xda780029,0x09e306bd,0xbd870012}},	//   tami, veď_, _зорн, كنون_
  { {0x89db000b,0x672f0002,0x61db000b,0x11db0009}},	//   _החלי, ypcj, _הקלד, _החלב
  { {0xe737035b,0x8cc10037,0x64400a78,0xdc9b0009}},	//   _нет_, रोटो, rami, מיקל
  { {0xc333015a,0x7d02002a,0x7607000e,0x64400a79}},	//   עות_, _whos, nézé, sami
  { {0x7d020036,0x443d0036,0xdbdd000e,0x64400a7a}},	//   _thos, _few_, váír, pami
  { {0xc7d50014,0x69c10051,0xf8bf0066,0x98ba0010}},	//   джмъ, _ülee, uhé_, rupė_
  { {0xdcb10020,0xdb4f0012,0x74130012,0x76070031}},	//   ểm_, _مَن_, _كوما, kézé
  { {0xba17000a,0xe8030037,0x7cc80066,0x4b7b0009}},	//   _فيها_, रेगा_, věry, _לאדו
  { {0xcaa5000a,0x35e4002d,0x65940015,0x7cd3000d}},	//   _تصني, ецтв, нару, părt
  { {0x20d20029,0x6aaa0a7b,0x41db0009,0x11db0009}},	//   pšia_, _hoff, _לחוס, _לחוב
  { {0x2bc70037,0xd3710003,0xe8030011,0xfbd30012}},	// [1170] _रेखा, ضها_, रेखा_, رتر_
  { {0x7b09001c,0x67bc0009,0xd2510012,0x60080009}},	//   _ažur, _למחק, ئنا_, _מִתְ
  { {0x2d8c0119,0x60dd0a7c,0x2d9e0248,0x63080012}},	//   ådet_, onsm, ätet_, أقلّ_
  { {0x98a6000d,0x1869002d,0xda080012,0x7f75026d}},	//   mplă_, іали_, سينه_, дукц
  { {0xfaf8001e,0x9be4002d,0x62980070,0x8e850001}},	//   klī_, _зірк, _onvo, дгле
  { {0xd2290012,0xe3d40012,0x139a0009,0xf4120009}},	//   _ذكره_, _ستُع, _ובשע, _שפך_
  { {0x78a900bd,0x58d5002d,0x291c0066,0x56920001}},	//   _toev, _жовт, ívat_, тајт
  { {0xcd98000b,0x24f70009,0x62870a7d,0xe3b90147}},	//   לדות_, הֶ֖ם_, _hajo, жби_
  { {0xa3e70037,0x27ff003a,0xf7700003,0x7d090a7e}},	//   _मुख_, _uzun_, _مال_, rmes
  { {0xeab10003,0x25e80037,0xce380003,0x6d470051}},	//   ئعة_, _चुकी_, _فأما_, ksja
  { {0x6d550002,0xba160012,0x76430a7f,0x28c40011}},	//   jrza, ويًا_, many, लोकि
  { {0x644b00c5,0x62980a80,0x2b52003a,0x6d550027}},	//   _udgi, _envo, üncü_, drza
  { {0xa49b001a,0x9b94003c,0x4fa30024,0x945d0034}},	//   _phòn, _пицц, вияв, sińs
  { {0x76430a81,0xad3a0024,0x945d0034,0xbae50012}},	//   nany, жчає_, pińs, _تكتي
  { {0x80a60012,0xd5750842,0x6d410031,0x6d470a82}},	//   _يمتن, нуть, álap, gsja
  { {0x764300b6,0x000000c4,0x000000c4,0x000000c4}},	//   hany,   ,   ,
  { {0x24860026,0xd5b8001e,0x52aa0021,0x76430a83}},	// [1180] ľom_, šā_, овам_, kany
  { {0x0f570093,0x24860a84,0x76430a85,0x6d550a86}},	//   _קיים_, žom_, jany, brza
  { {0x7e9b000b,0xa9670014,0x76430a87,0x5e9b0009}},	//   _וסיו, диха_, dany, _וביק
  { {0xd4160003,0x25870066,0x6aaa0011,0x26de0030}},	//   _يبحث, sílá_, _चक्र, čtou_
  { {0xb9060044,0xe3b20003,0xcf7a0003,0x2eee0202}},	//   _पद_, _شرح_, تصاص_, toff_
  { {0xfbd3000b,0x07a30001,0x67000011,0x998c0030}},	//   _יתר_, таљн, ोगिक_, vadž_
  { {0xf98307e6,0x6d5c0a88,0xdd900012,0x7e7c0a89}},	//   _игро, nura, اوب_, ierp
  { {0x98bf0039,0x2ebb0796,0x6aaa00c1,0xeb4a0198}},	//   kstā_, _उत्त, _soff, очок_
  { {0x764300c6,0xda7a02ac,0x7e7c0a8a,0x0e660a8b}},	//   bany, оян_, kerp, _окан
  { {0x63ab00c5,0x3ce90604,0xcb070012,0x139b0009}},	//   øgni, čava_, ويين_, קביע
  { {0x28f9002d,0x3257000b,0xc27b000b,0x672d0a8c}},	//   зень_, וסים_, חריי, _staj
  { {0x04930003,0x23690002,0x7c930012,0xeb9a0048}},	//   _للمح, ytaj_, _للمص, _мие_
  { {0x6d5c0006,0xa08b0009,0xef640048,0x99620030}},	//   eura, קְטִ, къро, _víře_
  { {0xdcfe0066,0x62980052,0x6d550002,0x93fb0009}},	//   _trpě, _unvo, trza, _ולדי
  { {0x62870a8d,0xda5b0009,0x7eb401a0,0x999e0030}},	//   _rajo, _וכול, _càpi, matů_
  { {0x76430a8e,0xe58b0009,0x90e70012,0x6d470a8f}},	//   zany, חָמָ, _تستن, rsja
  { {0x2d9e008b,0x3f850039,0x2d8c01fb,0x3d160037}},	// [1190] äter_, ālus_, åder_, _पूछे_
  { {0x6d5c060b,0x52770012,0x7e7c0132,0x1a5b0012}},	//   bura, بارز, cerp, تشرة_
  { {0x644f000f,0x51840001,0xe8550012,0x90550198}},	//   ócik, куца, فناد, евец
  { {0x2bd00044,0x7643003e,0x2bcb0001,0x18a40024}},	//   _सेवा, wany, _дуго_, каєм
  { {0x764303d6,0xf388001a,0x62870a90,0x69c50031}},	//   tany, _nợ_, _tajo, szhe
  { {0xbb3a000b,0x69c50051,0x44290a91,0x7d0d0a92}},	//   _מעשי, _üheg, lca_, lmas
  { {0x3f84001e,0x76430a93,0xc6a40048,0x7d0d0a94}},	//   _esmu_, rany, ърци, omas
  { {0x7d0d00a2,0x76430a93,0x60c20a95,0xd7c90012}},	//   nmas, sany, chom, _فوزه_
  { {0x98bf0010,0x6bd50012,0x7e88008e,0x76430a96}},	//   lutė_, عتبر, öspä, pany
  { {0x13060047,0xde970003,0x3eac0621,0x96bb0012}},	//   нный_, _تجرب, _godt_, _بارز_
  { {0x98bf007a,0x644f0002,0x7e7e0051,0x7d0d03ad}},	//   nutė_, _odci, õppe, kmas
  { {0x7eb403eb,0xa156000b,0x3cfb0037,0x2ec80037}},	//   _ràpi, עברה_, ्षों_, रफ्त
  { {0xeb990014,0x5bc40012,0x76410073,0x7eb401a0}},	//   _хил_, _لتوف, _kely, _sàpi
  { {0x09e50047,0x83fd000e,0x3ebe0028,0x98bf001e}},	//   _полн, ggőe, ótt_, rstā_
  { {0x99850012,0xc5d50024,0x75d60012,0x27fa0034}},	//   _ألبو, віть, ريرا, ępni_
  { {0x6d5c08d3,0xf8a90012,0x301a0012,0x7eb00032}},	//   rura, _يديه_, _عتبة_, _päps
  { {0x7c2900c1,0x245a003a,0x42560345,0xa3d00011}},	// [11a0] icer, lümü_, етет, _वेश_
  { {0xae0f0037,0xd2630015,0xb05b031d,0x03950048}},	//   ाधान_, лкуй, nhän, ърся
  { {0x245a003a,0x2726001a,0x2e3b0009,0x6d5c016d}},	//   nümü_, _hôn_, _מגינ, qura
  { {0x70f6000a,0xb87b0013,0x7eb00005,0x442903c1}},	//   رسائ, mníc, _täps, cca_
  { {0xb87b0066,0xbc1b0009,0x20d20159,0x8c1b0009}},	//   lníc, _מוכש, jšim_, _מוכי
  { {0x2726001a,0x7c2b02d2,0x2fc60168,0xbea30538}},	//   _môn_, _afgr, rzog_, лачк
  { {0x91e60146,0xceb3000b,0xf388001a,0x27ec0002}},	//   _чове, ריו_, _sợ_, ędny_
  { {0x69c10051,0xcb1b0037,0x916c001a,0x98bf004b}},	//   _ülea, नदंड_, _gốc_, istă_
  { {0xdcfa000d,0x8c1b000b,0x3eac0a97,0xb05b0032}},	//   _astă, הופי, _todt_, fhän
  { {0xf388001a,0x44290a98,0x2bb70012,0xc1ea0024}},	//   _vợ_, zca_, عاية_, зьме_
  { {0x83fd000e,0x7d0d0a99,0x44290a9a,0x010a0009}},	//   ggőb, ymas, yca_, ּלָּ
  { {0xb87b00f1,0x254c0066,0x8d5500fa,0xa9c30024}},	//   dníc, měl_, _штуч, уськ
  { {0x22450070,0xb05b0052,0x5f940014,0xe0df00b8}},	//   balk_, bhän, гият, rnò_
  { {0x44290002,0x245a003a,0x539b0009,0xdb9b0009}},	//   wca_, bümü_, _מידו, _מסדר
  { {0xfaf7000b,0x212d0030,0x3f840097,0xa4d50024}},	//   _רצוי_, _čeho_, æmur_, вові
  { {0xccf80001,0xf9fb0009,0x79fb0009,0x7d0d020d}},	//   ећу_, _מהומ, _מלוח, umas
  { {0x98bf007d,0x44290a9b,0x7d0d0a9c,0x18340012}},	// [11b0] astă_, rca_, rmas, _صريح
  { {0xb87b05b1,0x62350024,0x7e650032,0xa195003c}},	//   bníc, тежу, _uchp, казч
  { {0xa2b20037,0x395e0054,0x7d0d003a,0xd9990012}},	//   _आकर्, nuts_, pmas, بنات_
  { {0x9f35002d,0x254c0066,0xb9540012,0x69c80060}},	//   веді, děl_, ائلت, izde
  { {0x81bc001e,0x8ca40011,0xc87f0032,0x245a0060}},	//   ucēj, कानो, ieß_, zümü_
  { {0x2ca90a9d,0x03d60009,0xf7740009,0x81bc0035}},	//   ljad_, _יורם_, רקס_, rcēj
  { {0xada50014,0xb5c2002d,0x916c001a,0x5de50048}},	//   тайл, ийшл, _tốc_, ъжка
  { {0xeb99005c,0x69cc0029,0x3af40248,0x3ce909df}},	//   дии_, ôlež, läpp_, čavo_
  { {0xe3b10003,0x6d580051,0x9998000d,0x130900fa}},	//   شرة_, arva, _terţ_, мний_
  { {0x7eb00872,0x68f60a9e,0x8a38003c,0x7c290a9f}},	//   _näpp, _skyd, няют_, scer
  { {0x6016003a,0x395e0054,0x22580034,0xb05b0aa0}},	//   _tümü, guts_, órka_, rhän
  { {0xb87b0145,0x245a003a,0x2d980aa1,0xe5080012}},	//   vníc, rümü_, _área_, _كيلو_
  { {0xfd100003,0xb90a0037,0xb05b0245,0x22950012}},	//   _اجل_, _मद_, mhäl, _للإس
  { {0x79820002,0x5b56000b,0xfaa50001,0xb87b00d9}},	//   łowi, _ישנן_, _јако, tníc
  { {0x26c10029,0xdd920012,0xb05b0032,0xe6430aa2}},	//   _dlho_, جوز_, chäo, респ
  { {0x2726001a,0x97c60003,0xb87b0042,0x47d60012}},	//   _tôn_, _لقبو, rníc, _ليعر
  { {0x46ea064f,0x93590109,0x74130012,0xb87b03a7}},	// [11c0] _один_, ерху_, لوفا, sníc
  { {0x6a160012,0x248d0032,0xb87b08ca,0x63a60248}},	//   نبار, hdem_, pníc, äkni
  { {0xae57000b,0x1e570009,0x7d0a004c,0x67240244}},	//   _בסיס_, _בשיר_, _оног_, _huij
  { {0x63b6004a,0x79950002,0x7eaf0033,0x248d0aa3}},	//   pyyn, _drzw, _søpp, jdem_
  { {0xc0a90003,0x23d00037,0x79950052,0x6f1a0aa4}},	//   عامل_, _तेंद, _erzw, _pitc
  { {0x254c0066,0xe2450012,0x6d5801e9,0x201f00b8}},	//   těl_, _مخفي, trva, _egui_
  { {0xa01b000f,0xe9a3026d,0x6eb30011,0x7b060097}},	//   ldöt, _карп, _अवरु, yðub
  { {0x6f1a0aa5,0xd467004c,0x628a026b,0x26d80aa6}},	//   _witc, виће_, _safo, hiro_
  { {0x2c6d000f,0xc4d3000b,0x7bc90052,0xaa820028}},	//   lódó_, יגה_, gzeu, _þýsk
  { {0xbe85000a,0x69c80052,0x254c0030,0x24800aa7}},	//   _مجمو, tzde, pěl_, heim_
  { {0x4a5b0009,0x6aba0032,0x58d90472,0xf2d30009}},	//   ודיו, rktf, едня_, שעת_
  { {0x98bf007a,0xe3ba020e,0x9f350024,0x138a0012}},	//   kstą_, _обе_, лемі, _يخشى_
  { {0xe7030020,0x35a80011,0xc4cf0012,0x87e70048}},	//   _hướ, _कपड़, _بْن_, тюне
  { {0xbc1b000b,0x11d60003,0x7a48001e,0xb3c1001a}},	//   _חודש, _لتعد, nūtē, _ngýờ
  { {0x2ca90051,0x04670055,0xb05b0248,0xa5f80aa8}},	//   tjad_, ктам, lhäm, веру_
  { {0x20d2009b,0x5454002d,0xba170009,0x02170009}},	//   jših_, ивст, _בחוץ_, _בחום_
  { {0x3a750015,0x68e200f1,0x26d80aa9,0x2ca902eb}},	// [11d0] ллар, dnod, biro_, rjad_
  { {0x2ca90051,0xeab40009,0x7a540012,0x75d50012}},	//   sjad_, נִּי_, لضما, _ميخا
  { {0x68e30164,0xe703001a,0x6b840002,0xceb20009}},	//   éndo, _nướ, awig, _היי_
  { {0x236d0034,0x55ba0009,0xc864004c,0x61fc0aaa}},	//   ytej_, _נמרו, атљи, _dyrl
  { {0xdcb10020,0x7645004a,0x8afd0066,0x78bd0070}},	//   ểu_, _kehy, stři, iksv
  { {0xe7030020,0x0e64002d,0x6234011d,0x7d1d0aab}},	//   _bướ, икін, _веру, _hiss
  { {0xb05b008b,0x4519010c,0xc98400f5,0xa5640012}},	//   thäl, нция_, _кути, لدين
  { {0xe7030020,0x05760003,0x7d760012,0xf5760012}},	//   _dướ, امية_, امير_, اميع_
  { {0xb05b0052,0x2b1501b6,0x7d1d0aac,0x248d0aad}},	//   rhäl, льор, _miss, rdem_
  { {0xc9a90015,0x7bc90052,0xdb140028,0x93fc0009}},	//   евое_, rzeu, ðaðr, ולחי
  { {0x291e0108,0x236d084b,0x0165003c,0xd567004c}},	//   _état_, stej_, ыкно, _штап
  { {0x2f040028,0xa3b50037,0xc6890009,0x81760009}},	//   gögn_, ड़ना_, _מא_, נגרס_
  { {0x442d0aae,0xe28e068f,0xddc70031,0x67240aaf}},	//   mce_, _ла_, dejű, _quij
  { {0x7c2d00b6,0x442d0126,0xfaf90073,0x7c3b0ab0}},	//   ecar, lce_, rtūs_, lbur
  { {0x6281007d,0x5de60014,0xdcfa0002,0x8db5002d}},	//   melo, ужва, _wstą, асті
  { {0xa7d60003,0xa9220014,0x93c5001a,0x62810ab1}},	//   _متخص, _удъл, _trắ, lelo
  { {0x78ad0066,0x98bf0010,0x442d0ab2,0xdcf70012}},	// [11e0] žová, ustą_, ice_, افقت_
  { {0x7f3b000b,0xc332000b,0x2480000e,0xdd04003a}},	//   _רעיו, צוב_, seim_, ırır
  { {0x2d960046,0x442d0013,0x68e200bd,0x49960015}},	//   _српс, kce_, tnod, ышат
  { {0xccfa002d,0x70560003,0x5ca60538,0x34fa0024}},	//   _їхні_, انشا, _симб, _їхню_
  { {0xdfd00003,0x442d0ab3,0x6903005e,0x62810ab4}},	//   غيت_, dce_, mõel, kelo
  { {0x62810ab5,0x6d5c0ab6,0xee2a0012,0x442d0ab7}},	//   jelo, orra, رأته_, ece_
  { {0x72c30001,0xf1a70012,0x62810ab8,0x6446016d}},	//   _убрз, _اء_, delo, _keki
  { {0x6f1e0002,0x7c3b0ab9,0x628e0aba,0x4498003c}},	//   _lipc, gbur, _habo, твию_
  { {0x28a80037,0xe0d50015,0xb4e40321,0x6d5c0032}},	//   गानि, _тюрь, _नदी_, hrra
  { {0x26c7072d,0x49740abb,0x6c1b0009,0x62810abc}},	//   chno_, алос, עֵהו, gelo
  { {0xe9f90081,0x764a0097,0xa2f70009,0xa6970009}},	//   _đả_, mafy, רמיה_, _תכבה_
  { {0x0217000b,0x442d0abd,0x64460abe,0x7c3b0060}},	//   טחים_, cce_, _neki, cbur
  { {0x2d9e021e,0x62810abf,0xb4c00011,0x78bd0ac0}},	//   åten_, belo, ँसी_, rksv
  { {0x442d0656,0x7d1d0005,0x62810ac1,0x623403e2}},	//   _że_, _siss, celo, _теку
  { {0x644600bd,0x7c2d00bd,0xc6b7000b,0xd5780009}},	//   _beki, tcar, נהלי_, כָּר
  { {0x69c50051,0xd1380010,0x57b50024,0x28b90011}},	//   _ühea, mpą_, _вбит, _आवधि
  { {0x7d1d0ac2,0x7c2d0ac3,0x2d910030,0xd25b004c}},	// [11f0] _viss, rcar, _ázev_, еце_
  { {0xf8bf0066,0x25a5006f,0x7d1d0358,0x6e670001}},	//   lké_, älls_, _wiss, _стиж
  { {0x60c4004a,0xaae8002d,0x7bdc0060,0x442d0ac4}},	//   _ylim, уєте_, ğruy, yce_
  { {0x69c10051,0x7f5d0061,0xdd3a0009,0x3d0e0011}},	//   _ülem, orsq, _שערכ, ागों_
  { {0x07a50ac5,0xa858000b,0x442d0ac6,0xa8480012}},	//   ралн, רידה_, vce_, الهم_
  { {0x7c220149,0x05550014,0x442d0002,0xed59027f}},	//   _agor, атия, wce_, вок_
  { {0x442d0ac7,0x8aa80009,0xfd110012,0x62810ac8}},	//   tce_, _עֹשֶ, يجب_, velo
  { {0x62810002,0x628e01ae,0x4735077e,0xed640042}},	//   welo, _zabo, _внас, leží_
  { {0xe7300003,0x62810ac9,0x56670012,0x4b25004c}},	//   _فصل_, telo, _مداف, јмов
  { {0x3b090001,0x442d0aca,0x6ab50048,0xd7740012}},	//   ђено_, sce_, рсих, _دافع
  { {0xb0b90044,0xceb8003e,0xfad6000b,0x787c0033}},	//   _आवाग, _więc_, שותך_, _nåvæ
  { {0x65630017,0x7d560009,0xdcfa0034,0x272b0040}},	//   munh, _כיעד_, _ostę, _køn_
  { {0x644603b9,0xd706035c,0xdcfa0073,0xfaa50400}},	//   _reki, изми, _artė, _вало
  { {0xed5a0046,0x98ab0039,0x7c22012e,0x64460acb}},	//   ког_, ībā_, _zgor, _seki
  { {0x2cbf0013,0x68fb003a,0x2bd90011,0xdcfa0034}},	//   okud_, _okud, _बेता, _astę
  { {0xdcfc0027,0xf8bf0107,0xc952000b,0x628e0acc}},	//   tvrđ, cké_, _ומה_, _sabo
  { {0x69c10051,0x3f8c001e,0x4a460345,0x1eca0001}},	// [1200] _ülej, ādus_, инав, _алпи_
  { {0xed460800,0xcfb7000b,0x19960001,0x499605fb}},	//   _кноп, _כלפי_, ијер, ишет
  { {0xae5b0009,0x365b0009,0x0e5b0009,0xf506003c}},	//   _בכיר, _בכינ, _בדיב, _взно
  { {0x26c500c1,0xe73a0014,0xdfda0014,0x4f660012}},	//   _allo_, вед_, къл_, لاتف
  { {0x16340014,0xddd80066,0xa067035c,0xde580024}},	//   беля, devš, рача_, галі_
  { {0x62980029,0xafdb0058,0xf8bf00d9,0x46d00011}},	//   ôvod, sbøg, zké_, थोंह
  { {0x09fa0003,0xbd870003,0x20d20029,0x91e300fa}},	//   _شفرة_, لنون_, lšiu_, _доре
  { {0x26c50164,0xd4970015,0x44220033,0x7b060028}},	//   _ello_, арь_, øk_, gðun
  { {0xef1a0345,0xdc890009,0x82a60337,0x185b0009}},	//   _ама_, רְצָ, ашне, _שכמע
  { {0x291f007d,0xb2730015,0x657e0033,0x33770009}},	//   _ziua_, ольш, _opph, סעים_
  { {0x2163002d,0x5d860003,0x63bb002c,0xe1d8002d}},	//   отяг, _خلال, ayun, удні_
  { {0xddc50066,0xc5f30009,0x55bb0009,0xd1380073}},	//   _schů, _ודע_, _שמאו, rpą_
  { {0xdb02008b,0x69c50005,0x76480026,0x27ed003a}},	//   _groß, _ühen, _kedy, çen_
  { {0x7648003e,0x26c50164,0xf8bf0145,0x7b100052}},	//   _jedy, ólo_, ské_, läuf
  { {0x3a37000b,0xdddc0027,0xc534000b,0xb87b015b}},	//   _דרום_, adrž, מָּה_, lním
  { {0xc05b007c,0x50d40003,0x6ca406fd,0xdddc0042}},	//   _рік_, _وزير, оруж, bdrž
  { {0x75280acd,0x2bba0002,0x53990015,0x04f4002d}},	// [1210] _ludz, jącą_, ывая_, ізую
  { {0x69c10051,0x2d870002,0xd7fc000b,0x68e90a48}},	//   _ülek, ywne_, _בהחל, _sjed
  { {0xc8ab0014,0xdcfa0002,0x2127001a,0x7bcd000e}},	//   къде_, _wstę, ênh_, szau
  { {0xf771000a,0x859a000b,0xe0d00012,0xd0580024}},	//   كات_, _עשרו, وزن_, арші_
  { {0x2bde0037,0x644d0269,0xdcfa0034,0x83fd0031}},	//   _नेपा, maai, _ustę, ggől
  { {0x141a000b,0xddc5002d,0xb87b05b1,0x6e950012}},	//   _תושב, йбли, dním, إلغا
  { {0xcb12000b,0xd658000b,0x2247003a,0x68e90027}},	//   _מלך_, ביות_, _renk_, _tjed
  { {0x68e90ace,0x20d20030,0x0c220048,0xf8bf0064}},	//   _ujed, nšit_, пмън, _ôé_
  { {0x7b060028,0x2cad0acf,0x1c42003c,0x27ff0060}},	//   rðun, rjed_, чным, _uyun_
  { {0x62850119,0xfbd2000b,0x65630018,0x2cad001b}},	//   neho, פתי_, punh, sjed_
  { {0x63bb002c,0x66c20064,0x60dd0ad0,0x95c803b0}},	//   syun, _dôkl, fism, _куца_
  { {0x397a0093,0x67210ad1,0x297a0009,0xe6040012}},	//   נטרנ, _hilj, נטרא, _بِمَ
  { {0x8ca40037,0x6601004a,0x80aa0037,0xeaae02ad}},	//   कारो, _hylk, टाबे, _ей_
  { {0xceb2000b,0x24180024,0x20d20064,0x7d180031}},	//   ֔ים_, _тією_, všiu_, _évsz
  { {0x628500c5,0xceb20214,0x9595002d,0xe5060003}},	//   deho, ליך_, ошті, مبري
  { {0x70b60037,0x6b890002,0x75d30012,0xd5af0012}},	//   _अकेल, oweg, سيقا, رفق_
  { {0x6b890ad2,0x67560012,0x24920034,0x1d070ad3}},	// [1220] nweg, _اخبر, rdym_, сети_
  { {0x8e860012,0x9e660ad4,0x62850a62,0x20d20064}},	//   _الده, _увод, geho, ršiu_
  { {0x657e07e3,0x499a003c,0xccf90034,0xf8b90011}},	//   _upph, ытая_, koś_, _आवशय
  { {0x443f001b,0x20d20064,0x61fc0032,0x77ca003c}},	//   jbu_, pšiu_, ürli, ллег_
  { {0x44320002,0x4b550014,0x67210ad5,0x7bdd0031}},	//   mcy_, _мърт, _bilj, úsul
  { {0xdfa50003,0x6721048b,0xb87b0066,0x7d040ad6}},	//   تحمي, _cilj, vním, llis
  { {0xb05b0ad7,0x26dc0ad8,0x6721001b,0x91fc0035}},	//   mhäv, rivo_, _dilj, agāj
  { {0x39570093,0x6cd40003,0xccf90002,0xb87b0066}},	//   _לשלם_, تقبا, goś_, tním
  { {0x6c770003,0xab94002d,0x7d040ad9,0xe81a0011}},	//   صحيح_, ципі, ilis, नेमा_
  { {0x52d8002d,0xa9540001,0x0bb70009,0xbf370009}},	//   рмою_, овољ, צלים_, _לאמץ_
  { {0x8afb0009,0x69c50051,0xf297000b,0x7dc50012}},	//   רפיק, _ühel, זכיר_, _وتمك
  { {0x23600027,0x66cb003a,0x60c20ada,0xb87b0adb}},	//   krij_, _müke, nkom, mník
  { {0x6d5a0026,0x02fa0037,0x833a0015,0x44320002}},	//   átan, ्ताह_, _счет_, dcy_
  { {0x7d160029,0x98bf0010,0x43570009,0xf1a60760}},	//   emys, putį_, _פסול_, _грин
  { {0xb6bb000b,0x60c208af,0x6d5a05dd,0x60dd0404}},	//   נצלי, kkom, štan, pism
  { {0xf98f000a,0xa4d40024,0x9c390adc,0x66090030}},	//   _أبو_, посі, рпат_, řeko
  { {0xdc9b000b,0x88bd0002,0x2d8c0058,0x4374002d}},	// [1230] נימל, _liśc, æder_, зуєт
  { {0x3255002d,0x644d0051,0x7afa0add,0x6bd40012}},	//   івер, saai, nott, ستقر
  { {0x20d20066,0x18370003,0x27e00028,0x62850ade}},	//   pšit_, مرشح, úinn_, reho
  { {0x6285002a,0xb87b00d9,0x7afa0adf,0x44320034}},	//   seho, dník, hott, ccy_
  { {0x672901e3,0xdddc004b,0x7afa0ae0,0x38600031}},	//   _quej, perţ, kott, óira_
  { {0xe80f0037,0x98aa001e,0x91fc0035,0x7afa0ae1}},	//   ़ेगा_, ājām_, rgāj, jott
  { {0x443f00f1,0x7afa0ae2,0x67210ae3,0xd6580009}},	//   tbu_, dott, _vilj, זיות_
  { {0xa0c50003,0x7ae809bc,0xe81a0011,0xbd480012}},	//   _بيرو, endt, नेडा_, حؤول_
  { {0xb87b0066,0x7b100052,0xa3c20011,0xe3b6003c}},	//   mníh, bäud, एईए_, жбы_
  { {0x6601003e,0xb87b0042,0x6fb80011,0x68ed005e}},	//   _tylk, lníh, ्नरू, _ajad
  { {0x6b8903de,0x44320034,0xb87b068c,0x7d040ae4}},	//   sweg, ycy_, cník, ylis
  { {0xb87b0066,0xcea90009,0x2eb40011,0x95c40012}},	//   nníh, _בי_, ुस्त, _عينه
  { {0x66090030,0x7d040060,0x9ad50012,0x3cf80031}},	//   řekl, vlis, _وتتض, _írva_
  { {0x4432003e,0x272f003a,0x6b94000e,0x8f9a0009}},	//   wcy_, _dün_, üggő, בישי
  { {0x644b00c6,0x60c907f6,0xc8b90011,0x2d980ae5}},	//   _kegi, _olem, _आवंट, uvre_
  { {0xb87b0066,0x25a5006f,0x23600ae6,0xe0df00b8}},	//   jníh, ålla_, trij_, ciò_
  { {0x272f00a2,0x8b26007c,0xeb970015,0xb87b022d}},	// [1240] _gün_, ідже, оит_, dníh
  { {0xda660003,0x44320002,0xda650003,0x88050012}},	//   تاري, scy_, كامي, _عظيم
  { {0x6459003e,0xe9da0001,0x7d040ae7,0x60c20ae8}},	//   _odwi, јке_, plis, tkom
  { {0xdfd20003,0xa8a30001,0x7afa000e,0x2056002d}},	//   ويض_, дршк, zott, ітер
  { {0x02460012,0x2bd90011,0xb05b0245,0xf76f0012}},	//   _وَحَ, _बेला, phäv, ناو_
  { {0x8f9b0093,0x66cb003a,0xd7f9002d,0xe0df00c1}},	//   ייני, _tüke, щує_, ziò_
  { {0xb05b0163,0x2bde0037,0xb87b0066,0x6da30001}},	//   dkän, _नेता, bníh, дија
  { {0x41270ae9,0xb87b0004,0x60c90260,0xc4f70012}},	//   _фото_, rník, _glem, يعيا_
  { {0x7afa000f,0x8e7601ec,0xe0df00b8,0x644b0aea}},	//   tott, _мужч, viò_, _degi
  { {0xa2a70037,0x3ce00051,0x7afa004a,0x6f790009}},	//   फ़ॉल्, hiiv_, uott, _לְעו
  { {0xd8f9002d,0x2730001a,0xdce30066,0x75d60012}},	//   йної_, _hàn_, ntně, _بيضا
  { {0xa9c3002d,0x6ab70011,0xb87b0030,0xb834003c}},	//   фськ, _आक्र, diíc, меющ
  { {0x69c10005,0x6d5a0026,0xdb240051,0xc053000b}},	//   _ülev, štal, öpäe, וזר_
  { {0x20050039,0xdefb0015,0x2730001a,0x7bdb0009}},	//   āli_, рым_, _màn_, _דקדו
  { {0xc4db0001,0x344b00db,0x15150024,0xe5340024}},	//   ађа_, ичан_, здвя, десь
  { {0x5ce7002d,0xa5f80024,0x8d5b0009,0x27300081}},	//   іюва, цесу_, יכלי, _oàn_
  { {0xb87b0013,0x60c0012b,0x10170012,0x28a80011}},	// [1250] vníh, ömme, _ببغد, गारि
  { {0x501c000b,0x8c1b000b,0xb4c70037,0x2d9e0052}},	//   _דוחו, שומי, _उत्_, _orte_
  { {0x62880aeb,0xb87b0aec,0xdc3f022d,0xdb11000e}},	//   iedo, tníh, líčk, égén
  { {0x15fa000b,0x2730001a,0x26f50037,0x7bc00010}},	//   _להתע, _bàn_, ेत्र_, kymu
  { {0x6d55000f,0xb87b0066,0xa7870012,0x7feb0012}},	//   lsza, rníh, تشاو, جراف_
  { {0x7bc00010,0x59ca0037,0x853c0010,0x62880580}},	//   dymu, ानार, _orėd, jedo
  { {0x6e350002,0x645d0010,0x6b8d00c7,0x62880aed}},	//   iczb, ųsim, lwag, dedo
  { {0x28f8002d,0x60db029a,0x60c909bc,0x2919001b}},	//   _десь_, _umum, _ulem, jmsa_
  { {0xf41f004a,0x2d9e0032,0x6b8d0529,0x644b0aee}},	//   ää_, _erte_, nwag, _vegi
  { {0xdd950015,0x69c50051,0xeb92000b,0x02b60009}},	//   _назы, _ühek, תָה_, ִ֔ים_
  { {0x644b0051,0xe8fa002d,0x6abc09d1,0x62950826}},	//   _tegi, йло_, örfa, _mazo
  { {0x62950aef,0xb05b0248,0x7d7a0009,0x69c1005e}},	//   _lazo, skän, _לנעו, _üleu
  { {0x20040065,0x6d550034,0xb05b0248,0x47c30048}},	//   æmi_, esza, mkäl, ебяв
  { {0xdce30af0,0x6d5a0027,0x539a0009,0x9bb60009}},	//   ytně, štam, _לינו, _מהנה_
  { {0x2d9e0107,0x6d55000e,0x6da300f5,0xd5750024}},	//   íte_, gsza, нира, муть
  { {0x7ae1004a,0x91ba000b,0x19ba0009,0xb87b0030}},	//   lilt, _למצי, _למצב, riíc
  { {0xb05b004a,0xab660048,0xe45f0248,0x23690064}},	// [1260] ikäl, явал, _glöm_, guaj_
  { {0x0e660015,0x3f92002c,0x9f9b000b,0xcff70009}},	//   _экон, _isyu_, _פסיפ, _מצפה_
  { {0xdebb000b,0x3ebb000b,0x7bc00002,0xb6bb0009}},	//   _המיל, _הציב, zymu, _הציי
  { {0xdce30066,0x186a024d,0xf8cc0011,0xba170012}},	//   rtně, сади_, ासिय, سينا_
  { {0x4733002d,0x4c9b0009,0xa8570009,0xce940048}},	//   еніс, _הבכו, פיסה_, далъ
  { {0x99640013,0x29060051,0x9757000b,0x7ae1004a}},	//   může_, sloa_, לינו_, jilt
  { {0xb87b0066,0x65930012,0xb0cc0011,0x673b008e}},	//   mnív, فجير, ासाग, _etuj
  { {0x7bc0007a,0x515b000b,0x20040002,0x2730001a}},	//   tymu, _לכלו, _tymi_, _tàn_
  { {0xfc3f0164,0x66cb0051,0x5b14003c,0x2f040097}},	//   ñía_, _lüka, ммит, lögu_
  { {0x7f3b000b,0x86ea0003,0x2aaa0001,0x7ae10af1}},	//   _לעמו, _اعرف_, стио_, gilt
  { {0x6d5a001c,0x69c10051,0xd6cf0003,0xa63b0009}},	//   štaj, _ület, _حقل_, _הגבר
  { {0xeafa0037,0xab5d0002,0x68e20034,0xd1260012}},	//   ्तुत_, wyże, niod, ضم_
  { {0xa4b7000b,0x04430021,0xc4d30009,0x6cc30148}},	//   _מלאה_, _чечн, _אגף_, _яйца
  { {0x96eb0021,0x8c1b0009,0x7ae10030,0x0ebe0011}},	//   сьма_, _הודי, cilt, ्सिड
  { {0xf297000b,0x7a7b000b,0x4a7b000b,0x67250038}},	//   _זכור_, _הרוס, _הרוב, _vihj
  { {0xb9250003,0x6d550053,0x1cbb0012,0x27f20034}},	//   _تفعي, rsza, حاسب_, żyny_
  { {0x6d550272,0x46be0011,0xfc300012,0xa4d40024}},	// [1270] ssza, ्साह, احف_, хоті
  { {0x88bd0034,0xb05b0032,0xd3d80012,0xc1780073}},	//   _ciśn, chär, سبقا_, otė_
  { {0xc1780010,0x5fca0011,0x66bc0009,0x75150048}},	//   ntė_, ़ैसल, _למזה, _омоф
  { {0xc5f20093,0x2ec50044,0xa3cc0037,0xa3be0037}},	//   _ידי_, वस्त, रना_, ीना_
  { {0x22680066,0x69d80028,0x4c9a0009,0x46d10011}},	//   átké_, úver, _וברו, _हताह
  { {0x60cd02d1,0xc7d8000b,0xbe650012,0x2557004b}},	//   _llam, הודי_, ذهبي, tăl_
  { {0x644f00c6,0xf6500003,0xd1640014,0x60cd003a}},	//   _keci, ائه_, _пъти, _olam
  { {0x68e2000d,0x2ee30070,0xd5780009,0xa2d90011}},	//   ciod, hijf_, פתחה_, फोर्
  { {0x3af5002d,0x3e5f001e,0x7ae10af2,0xbe4b0012}},	//   дянс, tātē_, tilt, _هشام_
  { {0x66cf0119,0x69c10af3,0x78bb0017,0xfb160003}},	//   _bøke, _üles, _houv, وقيع_
  { {0xbe640003,0x208a0014,0xa88a010c,0xca360009}},	//   _أهمي, ойни_, ойна_, ונתה_
  { {0xafe600c0,0xc19a000b,0xd7f8000d,0xa4d40024}},	//   домл, קשרי, şăm_, _похі
  { {0x78bb0061,0x92b50003,0x0056000b,0xe20a0037}},	//   _mouv, _يحتا, ושרת_, _वर्ण_
  { {0x8cab0037,0x60cd002e,0x3ced005e,0x7d090af4}},	//   झावो, _elam, lnev_, lles
  { {0xcb120093,0x66d0004a,0x66030024,0x69c70040}},	//   _שלו_, _näke, впра, øjed
  { {0x78bb0108,0xe8f60003,0x6561000e,0xf50a002d}},	//   _nouv, _تستخ, álha, інал_
  { {0x073a000a,0xa2d40037,0x9f1a0012,0x95e90011}},	// [1280] _بسبب_, योक्, _وآخر_, टपुट_
  { {0x244c001a,0x68e20002,0xba6a0012,0x273b004b}},	//   ếm_, wiod, تحرك_, _mână_
  { {0x27340006,0xc04f002d,0xdce9003a,0x2241005e}},	//   _hän_, кі_, _çoğu, _õhku_
  { {0x7d09000f,0x78bb0061,0x644f003a,0x7bcd001e}},	//   jles, _couv, _geci, _ļaun
  { {0x78a9048b,0xba560014,0x69030051,0x2f040028}},	//   _dnev, _отвъ, võet, sögu_
  { {0x2734006f,0xc7d70009,0x6ea70011,0x46a30048}},	//   _män_, ווני_, खाएँ, качв
  { {0xdcb10020,0x2734006f,0x78660012,0x7d090af5}},	//   _hủy_, _län_, _يدرك, fles
  { {0x8d170003,0x78bb0af6,0x05170012,0x99720030}},	//   وزير_, _gouv, وزيع_, těže_
  { {0x66cf03a0,0x69c10051,0x128a0048,0x228a004c}},	//   _søke, _üler, ощни_, ољно_
  { {0xc17a002d,0x60cd0825,0x80da0011,0x76a60012}},	//   оїм_, _slam, पोरे, _تحرك
  { {0x7d090af7,0xa2d40011,0xba9b0009,0xd6250012}},	//   bles, योग्, קסטי, _كعمي
  { {0xe4a5002d,0xd4c60003,0xc1780010,0x6d580af8}},	//   _пріо, _تغطي, rtė_, msva
  { {0xb33b0149,0x644f0af9,0xc1780010,0xe8f1000b}},	//   _orça, _reci, stė_, אֻם_
  { {0x7d00000f,0x5bb7002d,0xfbd3000b,0xd3b7002d}},	//   loms, _юлія_, _בתנ_, _юлії_
  { {0x12fb000b,0x27fa0002,0x8afb000b,0xf98f0012}},	//   _והגב, ępny_, _והגי, _نبي_
  { {0x7d000afa,0x60cd00b6,0x6ee90027,0x9597000b}},	//   noms, _ulam, džbe, וכלו_
  { {0x66d00163,0xd3710003,0xbf0e0037,0xe3150001}},	// [1290] _säke, طها_, िताभ_, емањ
  { {0xd2510003,0x2904002c,0x78bb0afb,0x32070002}},	//   انا_, _akma_, _souv, żnym_
  { {0x78bb0108,0x2d9e006f,0x7d000afc,0x7d090afd}},	//   _pouv, åtet_, koms, yles
  { {0x629801a2,0x9015002d,0xd0110012,0xc0520009}},	//   _lavo, нфлі, هلا_, ָ֖א_
  { {0x8e85011f,0x6d5a079d,0xc43a0009,0xe7580024}},	//   егле, _avta, _מתרי, дичі_
  { {0x62980133,0x6d580028,0x66cf0033,0x3f4d0035}},	//   _navo, fsva, _søkb, ižu_
  { {0xdce8003a,0xd5b10003,0xade80012,0x66360012}},	//   _ardı, افع_, وفهم_, ركيس_
  { {0x273b007d,0xcf7b000a,0xb9250003,0x9f51000e}},	//   _până_, _وإذا_, _أفري, ából_
  { {0x13e9002d,0x76550002,0x63a20afe,0xf7700012}},	//   ямий_, kazy, _cron, _نال_
  { {0xeab1000a,0xaad90044,0x7dee000f,0x394504b3}},	//   اعة_, योंक, nősé, нног
  { {0x88e60015,0x62980052,0xdce3001e,0x8d740012}},	//   ежне, _davo, aunā, _لانا
  { {0x0ef80037,0xd59a0009,0xea000081,0x63a20aff}},	//   ंक्स_, _מבעל, hiếu_, _fron
  { {0xfb680003,0x62980b00,0xcbc70012,0x63a20b01}},	//   _قصوى_, _favo, _تزاي, _gron
  { {0x2734006f,0x62980010,0x76550002,0x8afd00d0}},	//   _vän_, _gavo, gazy, kuři
  { {0xddc1002d,0x99d70012,0xdd920012,0xb87b0064}},	//   аттi_, _تتشا, دوز_, tnít
  { {0x91fc001e,0x89da0009,0x8b660012,0x7a310031}},	//   rgāt, _מחצי, فاطم, _fűté
  { {0xc32a0003,0x29020073,0xb87b068c,0x6abd05f3}},	// [12a0] سكان_, moka_, rnít, ोसूर
  { {0x6d58004a,0x68e60b02,0x29020b03,0x19f6004c}},	//   ysva, likd, loka_, нџер
  { {0xa84a0003,0x80660048,0x91fc0035,0x6abc0b04}},	//   كلام_, евеж, lgār, _vorf
  { {0x7ae5004a,0x25a50058,0x26150011,0xab5d0034}},	//   aiht, ælle_, _धरती_, zyża
  { {0x1dd80037,0x66e60b05,0xe3b20012,0xa8570009}},	//   _भेजत, нода, _صرح_, תינה_
  { {0x66cb003a,0x6d580b06,0x64560b07,0xda6500ae}},	//   _nükl, tsva, layi, _لافي
  { {0x6728001c,0xe9f9001a,0x867b0009,0x69c1005e}},	//   _vidj, _đế_, פרקו, _ülep
  { {0x62980b08,0xdd990024,0x63a20b09,0x692c004b}},	//   _savo, ьші_, _pron, _eşec
  { {0xe3b20003,0xaf490012,0x1e860229,0x29020b0a}},	//   ارع_, _يشكل_, _плам, doka_
  { {0xdce3001e,0x539b000b,0x6456002c,0x629a0058}},	//   runā, ליפו, hayi, udto
  { {0xb0cc0037,0x28f9002d,0x63a20b0b,0xc27b0009}},	//   ासंग, день_, _wron, הריי
  { {0x63a2008a,0x34560003,0x45b70009,0xdfd10012}},	//   _tron, _أنشأ, _רפאל_, ليج_
  { {0x62980b0c,0xd8db000b,0xbfa80015,0x09dd01e1}},	//   _tavo, לקטר, нтре_, _मध्य
  { {0xb3e90003,0x79820002,0x61eb000e,0xdb060b0d}},	//   _تعمل_, łowy, állá, ämäk
  { {0xc8f50048,0x7ae50159,0xa1940048,0x7dee0031}},	//   _изкъ, viht, _райч, vősé
  { {0xb05b004a,0x47d50012,0x88bd0034,0x68e60064}},	//   kkäi, _ليبر, _piśm, cikd
  { {0x66cb003a,0x7dee000f,0xea670046,0x1b780003}},	// [12b0] _yükl, tősé, ењен, فصلة_
  { {0x69110b0e,0x63bd0192,0x3a74003c,0x2bb800ae}},	//   gåen, øsni, ллур, راقة_
  { {0x1df90015,0x7ae5003a,0xa5f9020e,0xb9250012}},	//   _цены_, riht, _цену_, نفطي
  { {0xf7710351,0xcdb60009,0x7ae503bd,0xa9070012}},	//   لات_, _ספרה_, siht, ربان
  { {0xf8b2000b,0x4cba0009,0xd8b80012,0x7d0d0699}},	//   ישׁ_, _חזרו, عدما_, mlas
  { {0x9f380009,0x7d0d0b0f,0x7b060097,0x67d2004c}},	//   תנגד_, llas, iðus, рољу
  { {0xa2a10037,0x6d5a0027,0x8aa40014,0xbe980012}},	//   _कोष्, štav, _сряд, عضها_
  { {0xa2a90011,0xb47b0009,0x6b84004b,0x7d0d0b10}},	//   घाक्, לָ֖י, _ţiga, nlas
  { {0x98a8000d,0xf7730012,0x66d00248,0x999e0073}},	//   _lună_, _حاز_, _läka, katų_
  { {0x7d0d0107,0x23690027,0x6d430b11,0x97240012}},	//   hlas, iraj_, ppna, _مفقو
  { {0xcb120009,0x999e0073,0xa06a0b12,0xddd50031}},	//   שלי_, datų_, мана_, kezű
  { {0xa2a10037,0x48e60014,0xf992000b,0x23690027}},	//   _कोर्, томв, ברט_, kraj_
  { {0x5bc4000a,0xf3670015,0xe28e05f7,0xe0d70048}},	//   _متوف, _чтен, _ка_, твя_
  { {0x6f030b13,0xdce3007d,0x98a8007d,0xf743002d}},	//   nonc, bună, _bună_, реро
  { {0xfc3f0029,0x82340003,0x7d0d0b14,0xd24e0012}},	//   _kníh_, _إرها, flas, _بنى_
  { {0x7bcd001e,0x98b8001e,0x7d0d0b15,0x753c0031}},	//   _ļauj, _otrā_, glas, _érze
  { {0x24780066,0x8bac0009,0x6f030b16,0x24800018}},	// [12c0] _němž_, ּׁבִ, konc, rfim_
  { {0x4a43002d,0x69c50051,0x7d0d01a3,0xd707003c}},	//   инув, _ühes, alas, _иные_
  { {0x442f0033,0x7d0d0b17,0x6f030b18,0xc30500ae}},	//   _ogg_, blas, donc, ابقو
  { {0x00e60014,0xb5f7000b,0xc8630024,0x85f70009}},	//   ъжен, _יציג_, атши, _יציע_
  { {0xcf77000a,0x7b060028,0x09290003,0xd7ef0003}},	//   نصوص_, iður, رسمي_, يكم_
  { {0xcf930009,0x6d5a0064,0x7d040b19,0xb7db0009}},	//   יטד_, štau, lois, וקני
  { {0x8d730003,0xd5b00003,0xb05b0051,0xafdb0033}},	//   لايا, صفة_, skäi, tbøk
  { {0xd197000b,0xc5f3000b,0x69c3004a,0x6aca0037}},	//   _בכלי_, ידו_, änee, िस्र
  { {0xcb670046,0x09ca0011,0xa3e80011,0xa87b0009}},	//   вање_, ान्य, यपट_, _קאמר
  { {0x02a6007c,0x60c00747,0x7d0d0b1a,0x442f02ed}},	//   трим, _homm, zlas, _egg_
  { {0xddc8003e,0x7d040006,0x6c860012,0x32570009}},	//   _wedł, kois, _للام, כסים_
  { {0xc173000b,0x7d04004a,0xac980012,0x60c00b1b}},	//   סחר_, jois, _سنتا_, _jomm
  { {0x7d04004a,0x8bb30012,0x98a8004b,0x999e0073}},	//   dois, _نصوص, _sună_, tatų_
  { {0x98a8004b,0x645d0073,0x3a3a005e,0x7b060097}},	//   _pună_, ųsit, _üpp_, rðus
  { {0xd6d8007c,0x2fcd001c,0xa4d5002d,0x999e0010}},	//   ття_, šeg_, гові, ratų_
  { {0x2369012e,0x60c00061,0x999e0010,0x442f0058}},	//   traj_, _nomm, satų_, øg_
  { {0x7b32003e,0x59ca0037,0x5c070014,0x7658004a}},	// [12d0] _dług, ानकर, тява, kavy
  { {0x4b7b0009,0xd37b0009,0x19eb0012,0xab5d0034}},	//   ואמו, ורמט, وراً_, zyżo
  { {0x7d0d0b1c,0x69da0052,0x89340012,0x66cb005e}},	//   plas, nzte, لعنا, _lükk
  { {0x60c00b1d,0x71d70009,0xf09f01a0,0x244b00ae}},	//   _comm, כובד_, ndà_, _تجدي_
  { {0x6f030164,0x6d410029,0xa3ad0011,0xc7ab0012}},	//   tonc, _stla, _कपट_, بدال_
  { {0x3ce50011,0x76580073,0xfc3f0030,0x2ed10011}},	//   जोने_, gavy, _sníh_, _हतोत
  { {0xf2d2000b,0xceb4000b,0xb6bc0009,0x7db40048}},	//   _פעל_, ייס_, וצגי, исъц
  { {0x26190037,0x7c3b004b,0x629c0b1e,0x69da0035}},	//   येगी_, ucur, _zaro, dzte
  { {0x64490b1f,0xd5bf001e,0xb8f70037,0xac960012}},	//   rbei, _šāds_, िस_, انًا_
  { {0xa3bb0011,0x4a45003c,0x66cb0060,0x64490b20}},	//   _अपन_, ынов, _dükk, sbei
  { {0xfad60093,0xaad90044,0x59ca0011,0x62810b21}},	//   רותך_, योगक, ानगर, rflo
  { {0x3f6a0b22,0x62810b23,0xf746087f,0x27390b24}},	//   нимо_, sflo, лемо, _kèn_
  { {0x69c8003a,0xe365002d,0x7b060028,0x6b65062c}},	//   ayde, _скли, rður, _скла
  { {0x69c80058,0x249f0028,0xdbd10051,0xe296035c}},	//   byde, ldum_, _müüm, _баш_
  { {0x7d040006,0xf652000b,0xba560009,0x6d5c008e}},	//   tois, מצם_, _עסקו_, usra
  { {0x249f0065,0x6d5c0039,0x97c60003,0x7b100052}},	//   ndum_, rsra, _مقبو, räum
  { {0xdd030010,0xcb67011d,0xd91b0009,0x2d850060}},	// [12e0] ūrėj, лате_, _אוקל, çler_
  { {0xda65000a,0x66cf0033,0x8f9b000b,0x7d04004a}},	//   لامي, _søkn, _טיפי, sois
  { {0x20f80010,0x10a6011d,0x66090030,0x7b320034}},	//   ečia_, лижн, řekr, _złud
  { {0x237f0002,0xa09a0003,0x94060012,0xd12f0012}},	//   ktuj_, عضاء_, _موجه, سمه_
  { {0x69c80002,0x4424001a,0xd037002d,0x70c40037}},	//   zyde, _àm_, узії_, _वकील
  { {0xb8cb015f,0x3b0a0015,0x2ca00051,0xf773000b}},	//   _को_, _чего_, ldid_, מקד_
  { {0x45d402ad,0x067b0009,0x2ca0005e,0x63a40b25}},	//   ройс, תנצל, odid_, lvin
  { {0x2ca00005,0xbd870003,0x76580010,0x7ae80132}},	//   ndid_, انين_, savy, widt
  { {0xc676000a,0x7658007a,0xe64606df,0x66d0006f}},	//   _مطاب, pavy, _безп, _räkn
  { {0x69da008b,0x7afc009b,0xe45f004a,0x63ad00d9}},	//   tzte, črto, _ylös_, _šanc
  { {0xd2b7000b,0xe57a0024,0x58d90024,0xf0b50024}},	//   אלית_, _їзд_, вдня_, айнь
  { {0x8dfb0009,0x85970009,0x853b0009,0x55bb0009}},	//   _אהבת, _תדאג_, _נגדי, _רמאו
  { {0x69da000f,0x63a400bd,0x9f350024,0xf09f01a0}},	//   szte, jvin, регі, rdà_
  { {0x539b000b,0x11d60003,0x98bf0010,0x99d60012}},	//   _ניוו, _متعد, ystė_, _متعا
  { {0x58d50015,0xdce30002,0xfd130012,0x7f440b26}},	//   _войт, suną, مجر_, _etiq
  { {0xddd80030,0x20f80073,0x361b00af,0x000000c4}},	//   ravň, yčia_, תולד,
  { {0x395e0039,0xba550001,0x26c10107,0xbec7001e}},	// [12f0] lsts_, ивај, _toho_, ldīš
  { {0xb05b0052,0xcb680012,0x0ab80012,0x2ca0005e}},	//   rkäu, امله_, ُطلب_, adid_
  { {0x38350021,0x6d5a0067,0x80aa0011,0x24f9003c}},	//   анер, štar, _जोडे, _анны_
  { {0x237f003e,0x7a32000e,0x5c070048,0xda080012}},	//   ytuj_, tűtí, _бяга, ديمه_
  { {0x0a6b0046,0x926b0001,0xb05b004a,0xe72e01d4}},	//   _први_, _прва_, lkäs, же_
  { {0x395e0039,0x0f580009,0x20f80b27,0xe81a0011}},	//   ksts_, ניום_, rčia_, नेटा_
  { {0xa564000a,0xfc31000a,0xb05b004a,0xc694000b}},	//   مدين, يحة_, nkäs, מאס_
  { {0x91f5001a,0x999c000e,0x33650086,0xab6505d4}},	//   hác, _nevű_, авиг, авил
  { {0x395e0185,0x249f030f,0xab760012,0xd7fb0024}},	//   ests_, rdum_, لميا_, _чув_
  { {0x752f003e,0x68eb0070,0x237f0002,0xa01b0028}},	//   _licz, ligd, rtuj_, tfön
  { {0x237f0034,0x395e0035,0x25b90012,0x2a760009}},	//   stuj_, gsts_, _جهاد_, בעתך_
  { {0x68eb0070,0x63a40010,0x752f0002,0x237f084b}},	//   nigd, yvin, _nicz, ptuj_
  { {0x443f0b28,0xa01b03ce,0xb8ee0011,0xe8f70148}},	//   mcu_, sfön, _शक_, рля_
  { {0x443f0b29,0x644d0b2a,0x56b50009,0x06760b2b}},	//   lcu_, ebai, ׁפָן_, шумя
  { {0x2d53007d,0x91e200de,0x65c3076c,0x1c3a003c}},	//   nţe_, _моше, обра, вязь_
  { {0x47c6002d,0x8a140012,0x645b0032,0xdddc0073}},	//   _вбив, _اظها, naui, perž
  { {0x63a4000d,0x2ca00051,0xdcb7001a,0xa01b03ce}},	// [1300] uvin, rdid_, ởng_, nföl
  { {0xc332000b,0x55e60015,0xf8bf0061,0x644d0010}},	//   קוב_, _вооб, rmée_, abai
  { {0x765c0b2c,0x8c3b0032,0xe29706e5,0x21a30048}},	//   mary, _saße, рах_, жихм
  { {0x39a50333,0x270e0037,0x3d0f0037,0x21670103}},	//   _mēs_, ित्र_, ातों_, рици_
  { {0x98a6003a,0x443f0b2d,0x40e90009,0xa01b0031}},	//   nslı_, dcu_, נַעֲ, jföl
  { {0x8c9e0037,0x316b0002,0x644c0002,0xa01b006f}},	//   _खोजो, ńczy_, śnię, dföl
  { {0x69c70058,0xdce1003a,0xf6530009,0x3f85004b}},	//   øjel, _aslı, חצו_, ălui_
  { {0x0ca70015,0xc19b000b,0x499b000b,0x399b0009}},	//   атьи_, _בשלי, _בשלב, _בילד
  { {0x22580070,0xafe60867,0x96960024,0xdce30035}},	//   _kerk_, _тоал, _вреш, urnā
  { {0xdce70002,0x7ac60015,0x78a20b2e,0x6fb30012}},	//   mują, рсие, ldov, _بمكا
  { {0x765c007a,0x3a370093,0x20f80010,0x22580b2f}},	//   dary, ירים_, nčio_, _merk_
  { {0x1bea004d,0xd46707e6,0x6d4a0032,0x4d7b0009}},	//   _идеи_, _вице_, mpfa, _ירבע
  { {0xdce70002,0x98bf001e,0x39490b30,0x77f40011}},	//   nują, lstī_, _čase_, _अशोक_
  { {0x8c1b000b,0x0eeb0055,0x96eb0024,0xddc80035}},	//   _סוגי, тьми_, тьма_, _vedņ
  { {0xeda40339,0xb2bb0009,0x6abc0097,0x91f50081}},	//   ошто, _במגר, örfu, rác
  { {0xb4c30044,0xdce7003e,0x04c90003,0xb05b020b}},	//   ्से_, kują, دوري_, rkäs
  { {0xe3b00003,0x644d0605,0x98bf000d,0x30780012}},	// [1310] ورك_, rbai, aptă_, _ضحية_
  { {0xf6990046,0x6e95000a,0xdce70002,0x443f009b}},	//   _свој_, _الدا, dują, zcu_
  { {0x68eb0070,0x28cc0037,0xa01b0031,0xdb040025}},	//   tigd, ासचि, zföl, iviè
  { {0xa3c705f3,0x000000c4,0x000000c4,0x000000c4}},	//   _उथल_,   ,   ,
  { {0xdce70002,0x4fa50345,0x07a506bd,0x443f0b31}},	//   gują, силв, салн, vcu_
  { {0xaaa60037,0x20180003,0x539a0009,0x5e870024}},	//   _कोलक, جتمع_, _גישו, рудз
  { {0x3ea10051,0xad58003c,0x443f0064,0xdce70073}},	//   _maht_, арых_, tcu_, aują
  { {0xfdf80214,0x85f8007e,0x2d53000d,0x3f820b32}},	//   ימוש_, יצוע_, rţe_, ytku_
  { {0x0ab50003,0xcce40003,0xdce70002,0x68e90b33}},	//   محدد, تسوي, cują, _imed
  { {0x9f950051,0x7b320002,0x443f0b34,0xa01b0b35}},	//   _müüa_, _słuc, scu_, rföl
  { {0x39e9022a,0x60c40b36,0x98a60229,0x9f95005e}},	//   удно_, _poim, бине, _lüüa_
  { {0x236d012e,0xfd1f001a,0xa01b0931,0xc9b60009}},	//   prej_, _nhì_, pföl, צהרת_
  { {0x60c40006,0x66cf0033,0xd7f20012,0x6c320012}},	//   _voim, _nøkk, سكس_, _عفوا
  { {0x2cbf0051,0xc332000b,0x3f820b37,0x501a0009}},	//   ljud_, _זוג_, rtku_, טורו
  { {0x60c40b38,0xdce70002,0x68e9006f,0x765c002c}},	//   _toim, zują, _omed, rary
  { {0xd3ba002d,0x6459002a,0xc212000b,0x2fda0003}},	//   лузі_, _jewi, _מהו_, _موعد_
  { {0x3f9e0039,0x7f860012,0xfa360012,0x273d0081}},	// [1320] ātus_, _الخن, مراد, _gìn_
  { {0x7e560001,0x68fb0327,0xd7bb0009,0xf4120009}},	//   _утиц, _ajud, _עציר, לפן_
  { {0xfbc9000b,0x68fb006f,0x98b90010,0xdce70002}},	//   עת_, _bjud, ūrą_, wują
  { {0x22580369,0xdce70002,0x2fdd003a,0x649a0024}},	//   _werk_, tują, _özgü_, _стор_
  { {0x0eea007c,0x26c50026,0x96ea002d,0x20f80010}},	//   льки_, _bolo_, лька_, sčio_
  { {0xdce70002,0x8f9b000b,0xd7f9002d,0x52750109}},	//   rują, טיני, шує_, _мусу
  { {0x6443003e,0xdce70002,0x6b840b39,0x6e870003}},	//   śnie, sują, ltig, صنيف_
  { {0xdce70002,0xd497003c,0x6b8401a0,0x84d60009}},	//   pują, брь_, otig, מֵ֥א_
  { {0xd250000a,0xa5070001,0x6d4a0032,0x8c43004c}},	//   ونة_, љења_, spfa, чење
  { {0x6b840b3a,0x7bcd001e,0x63ab0b3b,0xfbcf0012}},	//   itig, _ļaut, ågni, عتي_
  { {0x7abb000b,0xd9fa0037,0xddc1000e,0x6b840b3c}},	//   אציו, ्थित_, _felő, htig
  { {0x64590b3d,0x0217000b,0x6b840b3e,0x75d30012}},	//   _gewi, מחים_, ktig, _عينا
  { {0xdfd80014,0x351b00af,0x27220b24,0x000000c4}},	//   бър_, _עודנ, _cưng_,
  { {0xeaf50044,0xd9fa0037,0x2d830031,0x35b50024}},	//   ीकृत_, ्थात_, ttje_, обгр
  { {0x2d9e0013,0x69180164,0xa5d80009,0xbd450012}},	//   _jste_, víen, בַּי, تنزي
  { {0x2eee0052,0xd7c90012,0x9d150024,0x5c07003c}},	//   hiff_, _نوعه_, ідач, бяза
  { {0x6b8400c5,0xe4e4002d,0xfc300012,0x9cd70009}},	// [1330] gtig, чірн, فحك_, צומה_
  { {0x8c1b000b,0xfaf30003,0x10140012,0xfaa7004c}},	//   רומי, أثر_, _عبيد, љшан
  { {0x753a008b,0xfd1f0020,0x399a0b3f,0x7bcd00b6}},	//   _nutz, _thì_, _jūs_, syau
  { {0xa8150001,0x399a001e,0xdced0010,0x26c509ae}},	//   одеш, _mūs_, _įkėl, _solo_
  { {0x660400a2,0x6d48001e,0x49180009,0xa08c0009}},	//   şikl, _atda, זקאל_, רְבִ
  { {0x2f5c0009,0xa75c0009,0x501c0009,0x1f5c0009}},	//   נדונ, נדור, אודו, נדוא
  { {0x2cf60037,0x64590002,0x291f001a,0x26c500c1}},	//   ुकूल_, _pewi, _thua_, _volo_
  { {0xf992000b,0xa3c70011,0x753a0032,0x93450357}},	//   _קרן_, ैनल_, _dutz, оние
  { {0x8c64000a,0x7884000e,0xdcfc001e,0x03a500b3}},	//   سطين, hívó, ntrā, ципо
  { {0x05ba0044,0x399a0039,0xdddc000e,0x20230002}},	//   _उपलब, _būs_, zerű, ąpić_
  { {0xc7a9000b,0xc27a000b,0xda090012,0xad580024}},	//   _שב_, ברתי, شيحه_, _гріх_
  { {0xa17a000b,0x6abc006f,0xb9260003,0xa3d90037}},	//   סטרט, örfr, تفجي, ़ना_
  { {0x98160003,0xbc380003,0xa3bb0012,0x94050012}},	//   تبدا, _اسما_, _حاضر_, _بوشه
  { {0x9f960009,0x73040024,0xb4d20011,0x59c50012}},	//   חדשה_, _епіз, वस्_, _ويشك
  { {0xceb20093,0x845a0098,0x629700f1,0x2b4d009b}},	//   וים_, ират_, dexo, lpec_
  { {0xb9560009,0x60dd0b40,0x9e3c01bd,0x63a90b41}},	//   _ויקח_, chsm, _maďa, oven
  { {0xab66002d,0xd3f4002d,0x6b840052,0x58bb0009}},	// [1340] ювал, нiст, utig, _כמקצ
  { {0xc9d60012,0xe1f20012,0x6b840b42,0xb87b0031}},	//   يزاب, وسا_, rtig, siít
  { {0x9e3c0029,0x6aa30b43,0x18a600de,0x28af0011}},	//   _naďa, _manf, жаем, _जोडि
  { {0xa9880009,0x71880009,0x274a004c,0x765a020d}},	//   מָנִ, מְנַ, ачко_, _sety
  { {0x9ffa0003,0x63a90070,0x5f060686,0xc7960012}},	//   جراء_, jven, озда, تشاب
  { {0x501b0093,0x7d16004a,0x2d850054,0x356a0187}},	//   בונו, llys, àleg_, арин_
  { {0x20d700a1,0x8c3b0052,0xa2da0011,0xa96709c6}},	//   _için_, _maßn, _पॄष्, _мира_
  { {0x66cb00a2,0x0caa002d,0x63a90040,0x94aa0635}},	//   _yüks, ртки_, fven, ртка_
  { {0x394904d2,0x63a90070,0xaa880012,0x290b0b44}},	//   _časa_, gven, منظم_, voca_
  { {0x0bb7000b,0xc6d80009,0xc1740223,0x8f9b0009}},	//   קלים_, _פַּר, площ, _דימי
  { {0x09f80351,0x44270020,0x3f860017,0x6d48021e}},	//   صفحة_, ̀n_, ltou_, _utda
  { {0x7aef0b45,0x859b0009,0x28f9003c,0x23720034}},	//   éctr, _כשבו, семь_, kryj_
  { {0x63a9007d,0x3f860149,0xaae60012,0x54530024}},	//   cven, ntou_, _وستو, _цвіт
  { {0xa3ae0044,0x3f860017,0xe2970345,0xf7730009}},	//   किन_, itou_, _мач_, וקש_
  { {0x7b100052,0x99170012,0x78170011,0xd0d50048}},	//   häus, _وبعض, _तर्क_, _нокъ
  { {0xdcee001e,0xdcb80198,0x66cb005e,0x69c301a4}},	//   tubā, ощу_, _püks, änem
  { {0xdc9b0093,0xe4480003,0x28ab0037,0xa0880009}},	// [1350] סימל, تلقى_, _घोषि, _וְתִ
  { {0x238e001e,0x1ec40003,0x0b140009,0xd33700af}},	//   dējā_, _يقيّ, פַּר_, קרבה_
  { {0xdcfc0039,0x0e9a0009,0xc2c40012,0xf3f9004b}},	//   strā, _השתל, بيلي, iaţa_
  { {0x2366001c,0x41740003,0x7985002a,0x63a90b46}},	//   _ovoj_, باكس, rthw, yven
  { {0xba77000a,0x7d0d0b47,0x97d80012,0x4cba0009}},	//   _واست, moas, يظهر_, _הזרו
  { {0x8f9c000b,0x6da50b48,0x8ee80024,0x7d0d0b49}},	//   יידי, зика, омів_, loas
  { {0xd658000b,0x645d0b4a,0x68ed0b4b,0x53340001}},	//   חיות_, _kesi, _omad, _церт
  { {0xd5fc000b,0xdd8e0003,0x63a9048b,0x7d0d08d4}},	//   יפור, اوي_, tven, noas
  { {0x63a90061,0x2b4d0066,0x645d0b4c,0x20840012}},	//   uven, upec_, _mesi, _تلقّ
  { {0x3964004a,0x78a4004a,0x645d0b4d,0x20f80159}},	//   _ässä_, _saiv, _lesi, ečih_
  { {0xa9690046,0x7d0d0006,0x98a60b4e,0xaf080012}},	//   љима_, koas, пине, _بقلم_
  { {0x21060044,0x645d0b4f,0x71d60009,0xd7ca0012}},	//   रवेश_, _nesi, פורד_, موجه_
  { {0xdfd20003,0x78a40606,0x9d1a0009,0x3ea50b50}},	//   ريس_, _vaiv, _פונט, _kalt_
  { {0x75290b51,0xb145004c,0x78a40132,0x60db01a0}},	//   lmez, _енкл, _waiv, _llum
  { {0xceb20093,0x60db003a,0x645d0b52,0x412a0048}},	//   עיל_, _olum, _besi, _локо_
  { {0x0136000b,0x60c90070,0xb05b004a,0x75290060}},	//   _צרפת_, _noem, ljän, nmez
  { {0x2d870051,0x831a0003,0xa87b0009,0x487b0009}},	// [1360] htne_, مقرر_, _האפר, _הטפס
  { {0xd36f0003,0x80250012,0xd3360009,0x691d0025}},	//   اهل_, _غريم, פרעה_, néen
  { {0x7d1600e2,0xbe3b000b,0x2a6a000e,0x66cb000e}},	//   plys, _לעית, óbbi_, _tükr
  { {0x238e001e,0xc952000b,0x80bf0037,0x55bb000b}},	//   tējā_, גמא_, षाये, _המטו
  { {0xa01b0028,0x44630014,0x20ef0030,0x2d870b53}},	//   rgög, _явяв, dřil_, etne_
  { {0x66e3002d,0xc7f70009,0xdee30024,0x7b100032}},	//   ноча, הזנת_, ночи, räus
  { {0xceb3000b,0x3ea50054,0x60c2001e,0x23660b54}},	//   תיו_, _dalt_, pjom, _svoj_
  { {0xd1320003,0x68130002,0x238e001e,0x61230051}},	//   _أمر_, _będą, pējā_, võlg
  { {0x613a0066,0x3ea500b0,0xd3b80024,0x2d870b55}},	//   _důle, _falt_, ілої_, atne_
  { {0x51f80024,0x28130012,0x3ea50b56,0x8ea50012}},	//   жною_, _أوكس, _galt_, _يصلن
  { {0x1ea90012,0xdd8f0012,0x7aee016d,0x21630b2b}},	//   _باقي_, _مول_, _mmbt, нтяг
  { {0xe53b000b,0x55bb000b,0x09f7000b,0x25d70009}},	//   _התאר, _למבו, למים_, _מובן_
  { {0x7d0d007d,0xcce50003,0xa3cd0037,0xdfd80048}},	//   voas, _تسلي, रहण_, пър_
  { {0x57fb0009,0xdab80012,0xa7fb01e3,0xdb9b0009}},	//   מלכו, _ذهبت_, gaña, _לסדר
  { {0xa3e50044,0x56780015,0x645d0b57,0x7d0d0b58}},	//   _भेज_, ября_, _pesi, toas
  { {0x51fb000b,0xba17000b,0xb4f90037,0x01fb0009}},	//   _להוצ, _מחוץ_, ्केप_, _לפול
  { {0x57f5002d,0x60c90070,0x7d0d0b59,0xf0940009}},	// [1370] _іпот, _roem, roas, _טנק_
  { {0x82370003,0x60db0b5a,0x2d8701bd,0x80180012}},	//   سرطا, _slum, ytne_, _عزيز_
  { {0x69da005e,0x629a0b5b,0x645d0b5c,0x60db0b5d}},	//   _ütel, ieto, _tesi, _plum
  { {0x3ce00013,0x2c750012,0x629a0b5e,0x08d40024}},	//   chiv_, _تُحس, heto, нція
  { {0xdcfc000d,0x7bc6004a,0xf09f001a,0xd91c0009}},	//   stră, äkul, goài_, זואל
  { {0x63ad006f,0x97580009,0x501c0009,0xb3ba0009}},	//   mvan, לידו_, צוגו, _ומשכ
  { {0x65920001,0xa1940867,0x3ea50698,0xe5a20024}},	//   вају, _парч, _valt_, вищи
  { {0x9f5f000e,0x33d5002d,0xdcf90012,0x629a005e}},	//   áról_, діот, تفعت_, eeto
  { {0xac160001,0xb05b006f,0x63a2000e,0x4c920001}},	//   моћу_, tjän, _cson, тињс
  { {0xa3ae0037,0xab5d0002,0x3945027f,0xe299004c}},	//   कित_, wyżs, мног, цао_
  { {0xdb24000e,0xf2d2000b,0x7f4d01c5,0x91e50048}},	//   ésén, דעי_, _ataq, фоне
  { {0x3cf90037,0x290f0b5f,0xa9880009,0x7e63008e}},	//   ्कों_, noga_, הָשִ, lanp
  { {0x691d0061,0xe79c003a,0x2ca9006f,0xa3e00060}},	//   péen, _düğü, ddad_, düğü_
  { {0x2ca901e3,0xb05b008e,0x853c0073,0x8f9a0009}},	//   edad_, ljäl, _grės, חישי
  { {0x386d032b,0x290f0604,0x0446004d,0x8c460048}},	//   _oder_, koga_, дебн, дебе
  { {0xc2120009,0xb05b008e,0xa03a0012,0x98b20035}},	//   _שהה_, njäl, _بأثر_, īzē_
  { {0xccf20093,0xfa8e001a,0x61230051,0x394d0159}},	// [1380] דכן_, _mừng_, kõlb, _česa_
  { {0x89f6000a,0x38600132,0xb05b0248,0x7d090159}},	//   وثائ, _heir_, hjäl, česa
  { {0xdebb000b,0x290f00e5,0xb6bb0009,0x2c0a0011}},	//   _ומיל, foga_, _וציי, _हुईं_
  { {0x69da000e,0x50ba0003,0x657c008e,0x629a0b60}},	//   _ütem, غداد_, murh, zeto
  { {0x4c9b0009,0x38600b61,0xcf260012,0xab2a0048}},	//   _ובכו, _meir_, ورتي, _мома_
  { {0x4733002d,0x386d0af1,0x2bbd0011,0xcdda004c}},	//   вніс, _eder_, ोहरा, жњи_
  { {0xc6930093,0xadd8002d,0x6b890b62,0x69d80040}},	//   דאו_, ямку_, eteg, øved
  { {0x66cf0033,0xdc13003a,0x98a60159,0xc53600af}},	//   _søkt, _ağır, omoč_, וָ֥ה_
  { {0xfa8e001a,0x22490060,0x629a0b63,0x000000c4}},	//   _dừng_, _şaka_, teto,
  { {0x7b320002,0xcdd6004c,0xb2700024,0x4d3a0223}},	//   _tłum, _оцењ, внiш, _дядя_
  { {0xa9c30232,0xfa770009,0x9583004c,0x66d003bd}},	//   всяк, ועית_, _алхе, _läks
  { {0xa3de0037,0x657c0028,0x7549000e,0x63ad003a}},	//   तना_, durh, őszö, yvan
  { {0xd0060003,0x26cc0340,0x00570009,0x6d480030}},	//   ال_, _kodo_, ושכת_, ídan
  { {0x7ce30005,0x7d0d0159,0x8c1b00af,0x853c0b64}},	//   _kõrg, čase, _וודי, _urės
  { {0x9f34007c,0xc327000a,0xdc3a00a2,0x758800fa}},	//   тері, _تكون_, _açık, мств_
  { {0x63ad00bd,0xe7ab0029,0x224d0030,0x26cc0b65}},	//   tvan, _ďaľš, _řek_, _lodo_
  { {0x20f80010,0x63ad0b66,0x2ca90b67,0x68e20b68}},	// [1390] nčiu_, uvan, rdad_, dhod
  { {0x26cc0b69,0x7a540012,0xcf270012,0x63ad0b6a}},	//   _nodo_, نضما, _تربي, rvan
  { {0x0656000b,0x63ad0b6b,0xf6560009,0x7ce3005e}},	//   _איתך_, svan, _אסתי_, _nõrg
  { {0x909b0012,0x6b890034,0x26de0b6c,0xef1f0031}},	//   تضطر_, yteg, _alto_, ztül_
  { {0x26cc066e,0xfa8e001a,0x752d0b6d,0xf7480012}},	//   _bodo_, _rừng_, mmaz, وجوه_
  { {0x752d000f,0x6fb20012,0xa77c0009,0xba740012}},	//   lmaz, اموا, קרופ, _لافت
  { {0x31780012,0x66f20034,0x609b0012,0x66cf00b0}},	//   _يحفظ_, ałko, _وخرج_, _søks
  { {0x2f160028,0x752d003a,0xce380009,0xb6380009}},	//   lægt_, nmaz, ואות_, ורוס_
  { {0xe3b10003,0xf7730012,0xe4520009,0x92f50024}},	//   ارب_, _جاز_, נֶה_, ечні
  { {0x16db000a,0x2001003a,0xbfa30081,0x6b890b6e}},	//   _بذرة_, şhis_, riể, rteg
  { {0xfa8e0020,0x78a90051,0xcb12000b,0x6b890b6f}},	//   _từng_, _kaev, רלי_, steg
  { {0xc689015a,0x98b80039,0x6d41002c,0x26c7013a}},	//   _לא_, _kurā_, _iula, ljno_
  { {0x7e610006,0x291e0039,0x43840003,0xb05b004a}},	//   _kelp, ēta_, _للنق, nkäy
  { {0x78a90051,0x68e200f1,0x6d410b70,0x4ac50012}},	//   _laev, zhod, _kula, _سيبق
  { {0x27e6000f,0x23690b71,0x7bcb0032,0x68e203a7}},	//   zzon_, esaj_, ägun, yhod
  { {0x6d4100c6,0x20f80066,0x7693003a,0xc06f0066}},	//   _mula, nčit_, lıyı, íští
  { {0x6836003a,0x7d1b004a,0x68e201bd,0x91290012}},	// [13a0] _müdü, ilus, vhod, _تسوق_
  { {0xe9ff0020,0x7d1b0052,0x752d0035,0x76930060}},	//   _giải_, hlus, amaz, nıyı
  { {0xae5b000b,0x26cc0010,0xe93a0003,0x365b0009}},	//   _מכיר, _rodo_, سسات_, _מכינ
  { {0xa01b0163,0x89160003,0x68e20066,0x2a650032}},	//   mför, ربائ, uhod, halb_
  { {0x7d1b0051,0xa8570009,0x672e0031,0xb1170012}},	//   dlus, גינה_, ombj, رقها_
  { {0x6d410b72,0x6e940264,0xce940048,0x7ce3005e}},	//   _bula, тику, такъ, _põrg
  { {0x1ea90003,0x7c22000e,0x68e20027,0x4096057b}},	//   باني_, _szor, phod, _прат
  { {0x7ce30005,0xf8bf000e,0x7d1b0b73,0x61e10051}},	//   _võrg, rmék_, glus, _ülla
  { {0xa2c40044,0x26cc060e,0xd10d0037,0xcb980024}},	//   राप्, _todo_, िकरण_, євої_
  { {0x9f97000b,0x026a0015,0xd2570024,0x4bd70012}},	//   _אדמה_, чший_, нцю_, عبيد_
  { {0x5cd6002d,0x7c220002,0x1e57000b,0x8cc00037}},	//   _підх, _wzor, _נשאר_, वादो
  { {0x660900a2,0xa01b006f,0x8d5b0009,0x644901a0}},	//   şekk, dför, _זכאי, ccei
  { {0xf8b3000b,0x7c220027,0x6d410052,0x4e160011}},	//   אשר_, _uzor, _zula, _दुबई_
  { {0x661a004a,0x66d0006f,0xa2c40011,0x629e001b}},	//   _kytk, _säkr, राफ्, jepo
  { {0x673a03eb,0xa7fb0b74,0xef1f000e,0xa2c40037}},	//   _mitj, paño, ltük_, रान्
  { {0x57b50148,0xb6340012,0x88c70012,0xc7ab0012}},	//   _абит, افِع, _ستبل, _فدخل_
  { {0x752d01a2,0xb05b004a,0x9be70024,0x2f160040}},	// [13b0] rmaz, hjäk, хівк, tægt_
  { {0xd7fc0009,0x3f640048,0xa1590198,0x752d0b75}},	//   _מהחל, _стъб, дажу_, smaz
  { {0x07360009,0xea770009,0xc6920009,0x52840012}},	//   _שאתם_, תגבר_, _דאי_, المك
  { {0x6d41000d,0xf9900012,0x6ee20064,0x19b80012}},	//   _rula, إبل_, _vôbe, عطلة_
  { {0xf77f00a2,0x7ce30051,0x317e0052,0x78a90051}},	//   nuç_, _võrd, hutz_, _vaev
  { {0x6d410b76,0xef1f0031,0xcf940009,0x2c7a0060}},	//   _pula, dtük_, רטס_, yüdü_
  { {0x7d1b0005,0xceb40093,0xdcfa00a2,0xddc10039}},	//   tlus, טיס_, _artı, _ielū
  { {0x01340012,0x9479004c,0x20f80030,0xdb060b77}},	//   _معقد, фску_, učit_, _erkä
  { {0x64490b78,0xf5060048,0x7e610035,0x20f80030}},	//   rcei, ънъл_, _telp, rčit_
  { {0xccf80066,0x57f406a5,0x539c0009,0x6d410b79}},	//   _svět_, _спут, ליחו, _tula
  { {0x6d41002c,0x7d1b0051,0x04950003,0x95570003}},	//   _uula, plus, _للاح, _أخطا
  { {0x3f6a0a41,0x95540012,0x629e0034,0xb05b0032}},	//   мимо_, _إخلا, zepo, njäh
  { {0x9cd60093,0xa856000b,0xefc7003c,0xd00f0012}},	//   _שונה_, כירה_, влял_, ْلُ_
  { {0x6b8d00c5,0xa01b0163,0x2cad05aa,0xf1e10011}},	//   dtag, tför, lded_, पनान
  { {0x8d630046,0x92580003,0x2cad0132,0xdddc0034}},	//   ивре, _أشهر_, oded_, warł
  { {0xa01b0b7a,0x2cad0b7b,0xa3ae0037,0xdddc0034}},	//   rför, nded_, किल_, tarł
  { {0xa01b02f1,0xcb6700f5,0x6b8d0b7c,0xdca30024}},	// [13c0] sför, кате_, gtag, шати
  { {0xf1fa0003,0xd36f0012,0xa01b0248,0x7bc401a0}},	//   وعات_, زهم_, pför, rxiu
  { {0xd657000b,0xa01b0028,0xef1f000e,0x1677000b}},	//   _שיטת_, ngön, ztük_, _בגיל_
  { {0x3d0b0044,0x29020028,0xdbd2005e,0xb05b0032}},	//   हकों_, nnka_, tüüp, gjäh
  { {0x2ca00051,0x27290029,0xa0730024,0x2cad0132}},	//   meid_, kúnd_, ргіч, dded_
  { {0x2ca00b7d,0xf413000b,0x2cad002a,0xc7d70009}},	//   leid_, _כפר_, eded_, כוני_
  { {0x4420007a,0x7dc40003,0x5fa90037,0x6aaa0b7e}},	//   _ši_, اقعن, _चैनल, _raff
  { {0xef1f000f,0x2ca00051,0x63a40002,0xfd0f0012}},	//   ttük_, neid_, owin, يجي_
  { {0xccf3015a,0x5b140048,0xc7a30048,0xda7a0357}},	//   יכה_, лмит, _китк, мян_
  { {0x2ca000bd,0x63ab0058,0x29020b7f,0x2cad0b80}},	//   heid_, ægni, enka_, aded_
  { {0x60f900bc,0xc27b000b,0x63a40052,0xf1a30014}},	//   ення_, וריי, hwin, арян
  { {0x6aaa0052,0x85f70009,0xdb04008e,0x249f0b81}},	//   _waff, _בצבע_, lviä, ceum_
  { {0x99620013,0x2ca00051,0x64430002,0x4420001a}},	//   _níže_, deid_, śnik, _ái_
  { {0xb9b40012,0x6b800b82,0x2d470b83,0x09f60012}},	//   _ممتع, mumg, _põe_, _لأعد
  { {0x59c30003,0x63a40b84,0xba9b00af,0xa9e303d2}},	//   _نيوك, ewin, _חסוי, _вещa
  { {0xba370093,0x6b8d0b85,0x32370009,0x27240248}},	//   _בטוח_, ttag, _בטון_, röna_
  { {0xfc640048,0x613a0030,0x39490159,0xe53401c6}},	// [13d0] ръсн, _půln, _časi_, реть
  { {0x24730020,0x7a40022d,0xbb190003,0xab94002d}},	//   ệm_, vští, رياض_, рифі
  { {0x75d50003,0x78ad004a,0x8c3d003a,0xac990003}},	//   _إيجا, _kaav, leşe, _كندا_
  { {0xf7710351,0x98ad003e,0xf2df000d,0x60dd0b86}},	//   مات_, _mieć_, _atât_, nksm
  { {0x747a000b,0x78ad00ff,0xaed5002d,0xb05b0032}},	//   _אנרג, _maav, лодш, rjäh
  { {0xd6db0800,0x0684002d,0x753d04ff,0xb7dc0009}},	//   ьте_, игін, _hisz, וקדי
  { {0x6d450005,0xf3f9007d,0x753d000f,0x29880001}},	//   _juha, maţi_, _kisz, _исто_
  { {0xf3f9007d,0xb9250003,0x644d0b87,0x6d450b88}},	//   laţi_, _إفري, ncai, _muha
  { {0x2cad0666,0x753d0b89,0x5f450012,0xe4a800af}},	//   rded_, _misz, _إنطل, דֹתָ
  { {0xdb040149,0xf3f9007d,0x8c1c000b,0x13060015}},	//   rviç, naţi_, ווחי, лный_
  { {0xa2c40037,0x5dd50012,0xf6520009,0xf3f9004b}},	//   रात्, _حقائ, _הצב_, iaţi_
  { {0xcea90093,0x455a000b,0xf4870001,0xf1c30066}},	//   _מי_, _נכנס, _јужн, _alší_
  { {0x8cc00011,0x2ca0005e,0xf8b60009,0x68430012}},	//   वारो, veid_, אפרי_, صَّل
  { {0x201e0039,0xf3f9000d,0x6d450b8a,0x99d50012}},	//   āti_, jaţi_, _buha, _متبا
  { {0xe2960014,0xf3f9000d,0x2ca00acf,0x66060014}},	//   _сащ_, daţi_, teid_, упва
  { {0x61d6000b,0xd5b7001a,0x753d0b8b,0x645b0227}},	//   _תוקף_, ứng_, _cisz, nbui
  { {0xf3f9000d,0x2ca00b8c,0x141a0012,0x43860012}},	// [13e0] faţi_, reid_, ريطة_, طلاق
  { {0x2ca00005,0xf3f9007d,0x33d5002d,0xab770012}},	//   seid_, gaţi_, шіст, املا_
  { {0x394f007d,0xccf90002,0x68e40066,0x07370009}},	//   _însă_, kiś_, _klid, _תאים_
  { {0x74550098,0xa3e30037,0x7d7b000b,0xb78a004c}},	//   _върх, नना_, _אנטו, ељке_
  { {0xda140037,0x7c26001e,0xf3f9000d,0x3f820b8d}},	//   _तुरत_, _uzkr, baţi_, nuku_
  { {0xf3f9007d,0xf8bf000e,0xe1660003,0x32430014}},	//   caţi_, lmét_, _مدري, _герг
  { {0x91e60047,0xa2f70009,0x8cc00011,0x7d040b8e}},	//   _сове, _עמלה_, वालो, onis
  { {0x5ba60511,0x61d70009,0xd3a60024,0x6b800b8f}},	//   гроз, _גולף_, гроп, tumg
  { {0xd70a0014,0x98ad0002,0x09dc0011,0x4806004c}},	//   _знае_, _sieć_, मन्य, _спав
  { {0x8f9b000b,0x78ad07f6,0x92b60003,0xc27a0009}},	//   _אימי, _saav, احظا, ׂרִי
  { {0x78ad019a,0x6c860012,0x765c0b90,0x7d040b91}},	//   _paav, _ملام, dbry, knis
  { {0xf3f9007d,0x2ba50044,0x3a37000b,0xca37000b}},	//   zaţi_, _ऑनला, טרים_, טניה_
  { {0x20ef0030,0x6d450b92,0x7d040b93,0x60dd0b94}},	//   dřit_, _suha, dnis, rksm
  { {0x6d450051,0xf3f9000d,0xf1a60aa8,0x02a30048}},	//   _puha, xaţi_, _брин, _гръм
  { {0xf3f9007d,0x8c3d000d,0x753d0b95,0x7d0406c4}},	//   vaţi_, reşe, _pisz, fnis
  { {0x4fd5002d,0x7afa0b96,0x54550288,0x7d040b97}},	//   _вжит, litt, рват, gnis
  { {0xf3f9007d,0xdbc60052,0x7afa004a,0x753d0865}},	// [13f0] taţi_, röße, oitt, _visz
  { {0x35f5002d,0x6d450b98,0xcf270012,0x62850132}},	//   _впор, _tuha, _حربي, ugho
  { {0x7d04008b,0xf3f9007d,0x7afa004a,0x753d000e}},	//   bnis, raţi_, iitt, _tisz
  { {0xf3f9007d,0x7afa0006,0x6aa100bd,0x78a20058}},	//   saţi_, hitt, zelf, geov
  { {0x7afa004a,0xf3f9000d,0xddd0015b,0x0b8b0048}},	//   kitt, paţi_, _češt, _ясни_
  { {0x7afa004a,0xf8bf0054,0xd9f60037,0xe7330012}},	//   jitt, omés_, ुपात_, حصص_
  { {0x7afa0b99,0x2d910032,0x2d830b9a,0x6cc50b9b}},	//   ditt, ntze_, nuje_, ийка
  { {0x09e10044,0xeb990015,0xbdf80012,0xe7250081}},	//   पनीय, вии_, درها_, _dưỡ
  { {0x2d830107,0xb4d50037,0x4439006f,0xc1040012}},	//   huje_, _सकी_, äs_, _طوكي
  { {0x3ae4006f,0x7d040b9c,0x7afa0b9d,0xa3c60011}},	//   _köpa_, znis, gitt, _उपर_
  { {0x8a380015,0xd5bb0024,0x5c970012,0x90c60048}},	//   ляют_, _яса_, _مؤشر, абне
  { {0x3c47000a,0xf530000a,0xab95007c,0x7afa008e}},	//   _إضاف, _فإن_, _виді, aitt
  { {0xf74601d4,0x8c3b0032,0x7d040b9e,0x39490b9f}},	//   рего, _maßs, čist, _času_
  { {0x3f82001c,0xaa880003,0xc8e20037,0x60230024}},	//   ruku_, _منهم_, _खत्म_, ідра
  { {0xacf60001,0x20ef0066,0x8afa0009,0xa2c40011}},	//   ачај, třit_, _שהצי, रास्
  { {0x7ce3005e,0x2caf0032,0x765c00b0,0x04430ba0}},	//   _põra, _jagd_, sbry, жетн

  { {0x0b1a000a,0xac050003,0xd455002d,0xe8c70048}},	// [1400] نقرة_, مذكو, стсь, _ъгъл_
  { {0x2d830ba1,0xb7db0009,0x23c80011,0x42260024}},	//   buje_, _סקיי, रमबद, адзв
  { {0xc6930093,0x7e7b000b,0x21a6010c,0x767b0009}},	//   _ואת_, _באיז, рием, _בטיח
  { {0x55bb000b,0x7afa0070,0x38490009,0xa2c40011}},	//   _סמכו, zitt, ְאוּ_, राह्
  { {0x69da0679,0x78a20ba2,0xc60e0011,0x4b550048}},	//   zyte, reov, िथ्य_, _гъст
  { {0xa2e60015,0xdd9a0ba3,0xdd900012,0xf2df0081}},	//   _тогд, вши_, كوت_, _huân_
  { {0x7afa0006,0xafdb00c5,0xf8bf0061,0x5f090037}},	//   vitt, ncør, llée_, _सदस्_
  { {0x7afa0aa7,0x718b00af,0xc15700af,0xd49a0557}},	//   witt, _בְמַ, _כשלו_, трк_
  { {0x807b000b,0xa87b0009,0xc6760012,0x7afa0ba4}},	//   _שנמצ, _שאמר, _نطاب, titt
  { {0x1eaa0003,0xf2df001a,0xeb970009,0xd5b80035}},	//   _جاري_, _luân_, סדיר_, _trā_
  { {0xc333000b,0x2d8301e9,0xd2b70009,0x7b320034}},	//   חוז_, xuje_, בלית_, _słus
  { {0x7afa0006,0xd5fb000b,0xb92a0024,0x2d830ba5}},	//   sitt, _בפבר, нкiв, vuje_
  { {0x2d830002,0xcb540003,0xbb540012,0xdfc60012}},	//   wuje_, _انتظ, _انتب, أي_
  { {0xd7f80015,0x539b000b,0xfaa30014,0xdefb0015}},	//   рую_, _סיוו, _мачо, тым_
  { {0x99840003,0x39470ba6,0x8e380012,0x16380012}},	//   _العو, _guns_, لسفر_, لسفة_
  { {0x9a3b000b,0xddc3000d,0x6d480ba7,0xdb0b0052}},	//   _בתוק, lanţ, _muda, _ergä
  { {0x59ae0037,0x6f950003,0x026b0015,0x68fd00ca}},	// [1410] टिकर, _الخض, вшей_, misd
  { {0xcb57000b,0xa2c40037,0xddc3000d,0x3869002a}},	//   יסמה_, राष्, nanţ, _hear_
  { {0xf9f90003,0xe298002d,0x6f1805b1,0x3ce900b0}},	//   دفاع_, рає_, dovc, phav_
  { {0xb4d50037,0x1128002d,0x3d100037,0xf8bf0061}},	//   _सके_, аючи_, ावों_, blée_
  { {0xc7a80003,0x97a7003c,0x6d480ba8,0xb05b008e}},	//   لدول_, ррел, ídav, ljäs
  { {0x6d480ba9,0x9a840001,0xef18002d,0x6f1802a1}},	//   _buda, _мусл, амі_, govc
  { {0xa2c40037,0x5e780009,0xf6960012,0xd13b0048}},	//   रार्, בתון_, صنيع_, _аха_
  { {0xe919002d,0x3869002a,0x3947002a,0xf2df001a}},	//   _собі_, _near_, _runs_, _xuân_
  { {0xde59002d,0x33920003,0x36d50001,0x368b0014}},	//   _базі_, كليز, _лоар, _асен_
  { {0x39400176,0xcac90015,0xf3ff0018,0x99d50012}},	//   _siis_, угое_, _leão_, متجا
  { {0xc7a90093,0xd9f70037,0x38690baa,0x6d480bab}},	//   _רב_, ंछित_, _bear_, _guda
  { {0xcd96000b,0xaac90037,0x6e3c0031,0x69dc00b0}},	//   _לדעת_, राडक, _úrba, ørea
  { {0xe8f70bac,0x39400051,0x2d730027,0x38690bad}},	//   сля_, _viis_, eće_, _dear_
  { {0x501a000b,0xddc3000d,0x7c2b0bae,0xd9f90011}},	//   רושו, canţ, _izgr, ्पात_
  { {0x3869002a,0x8db5002d,0x6d260012,0x6e290030}},	//   _fear_, ості, معرك, řebn
  { {0xf2df0020,0x39910baf,0x6b840070,0x6f180bb0}},	//   _quân_, más_, tuig, zovc
  { {0x3991000f,0x60c40bb1,0xdcfc001e,0x63a90bb2}},	// [1420] lás_, _inim, gurā, nwen
  { {0x78a6000e,0x16aa0063,0x98a6001b,0x7b1d01a0}},	//   lekv, _свои_, omoć_, cèut
  { {0x38690036,0xf2df001a,0x60d6003a,0x39910a27}},	//   _year_, _tuân_, _koym, nás_
  { {0xe894007c,0xb05b0a50,0x3d210011,0x69c10030}},	//   іаль, ljär, मतों_, _šlec
  { {0x351b0093,0x6d480acb,0x78a60010,0xdefa0015}},	//   _תוכנ, _suda, iekv, лык_
  { {0x3ce600f1,0x6ffc001e,0xef1f003a,0x8f9b0009}},	//   _slov_, mācī, ltür_, ריסי
  { {0xddc3000d,0x42e70001,0x60c40027,0xfe6f0012}},	//   vanţ, _умро_, _onim, ردو_
  { {0x3991000f,0xdbdd0026,0xb87b000e,0xcb540001}},	//   dás_, zšír, lhív, овић
  { {0xb7f20037,0x9696011f,0xddc3000d,0x7cfe0010}},	//   _आइटम_, _греш, tanţ, gūra
  { {0x6d48000e,0x2ca40028,0x41dc0037,0x7ac60015}},	//   _tuda, semd_, _यथास, ссие
  { {0xddc3000d,0xf8bf000e,0x3991000e,0x0e570009}},	//   ranţ, jléc_, gás_, _השבט_
  { {0xa8eb0003,0xa193002d,0x7afe003a,0x692c000d}},	//   اعدك_, чаюч, hipt, _aşez
  { {0x7afe014d,0x9d1b0009,0x53a30198,0x3f860018}},	//   kipt, _גואט, _нацб, nuou_
  { {0x5b13002d,0x8c1b000b,0x3869002a,0x39910bb3}},	//   _еміт, _עוגי, _wear_, bás_
  { {0x5d780009,0x38690bb4,0xcb070012,0x9afb0009}},	//   יָּנ, _tear_, _ديون_, _תפוח
  { {0x99860002,0xddc3001e,0xfb560009,0x69de00b0}},	//   łoś_, nanš, ֶׁ֣ר_, dype
  { {0x8b580003,0x8af900f5,0x69dc0248,0x98c50035}},	// [1430] مجلس_, анас_, äref, ūtīs_
  { {0xb87b000f,0xe509001a,0xa9c7002d,0x2d73001b}},	//   ghív, oặc_, йсек, pće_
  { {0x66d00006,0x69670012,0x02440012,0x394a0bb5}},	//   _näky, صداق, أَمَ, _cubs_
  { {0x38690028,0x0cab0014,0x9bc7003c,0x63ae008e}},	//   úar_, _стои_, _лёгк, ännä
  { {0x39910659,0x78a4005e,0x98b90073,0x89340012}},	//   zás_, õiva, ūrė_, أعلا
  { {0xab5b0052,0x7afe00b6,0xe7390086,0xb579027f}},	//   _prüf, cipt, шел_, ащих_
  { {0xed590015,0xd5750024,0x865c0009,0xc69400af}},	//   шой_, цуль, נדהי, פאק_
  { {0x63a90052,0x3991000e,0x7cfe09d4,0xd5ae0012}},	//   twen, vás_, tūra, ئفي_
  { {0x59e10037,0x69dc00e2,0x42e90001,0xd36e0012}},	//   पनकर, øren, имио_, نهي_
  { {0x68e90013,0x63a9008b,0x39910bb6,0x60c40027}},	//   _hled, rwen, tás_, _snim
  { {0xa9690046,0x54550014,0x64c50012,0xddc30159}},	//   јима_, _двет, _ويطل, banš
  { {0x3ea00027,0x2d8705a7,0x6d5c0bb7,0x39910bb8}},	//   đite_, mune_, vpra, rás_
  { {0x7d240047,0xcaf50012,0xdaf50012,0xe7d60024}},	//   _эффе, _وستب, _وستظ, ціню
  { {0x539a000b,0xd706002d,0x917a001a,0xdc1c001e}},	//   _כינו, ізви, hấy_, aņēm
  { {0x3ea70108,0x82370003,0xc3320009,0xe5670012}},	//   ient_, _ارشا, _חוג_, بط_
  { {0xe45a00ac,0xb05b0038,0x70560012,0xb7da0012}},	//   ржа_, sjär, _بنظا, _نوعا_
  { {0x3ea70bb9,0xbf660012,0xb8ee0011,0xbbd50009}},	// [1440] kent_, _بدعو, रा_, חוּץ_
  { {0x3ea70bba,0x8e860012,0x7d1b0bbb,0x2d87005e}},	//   jent_, _بلده, hous, kune_
  { {0xdcfc000d,0x75240052,0x8c4604b3,0x41aa0014}},	//   gură, pliz, _мене, рвен_
  { {0x9f960051,0xab5b0052,0x08c60048,0xc3290009}},	//   _tüüp_, _brüd, юбен, דו_
  { {0xbba80037,0x7d090bbc,0x027f0066,0xc6900012}},	//   _कनेक, čest, _říše_, ِّت_
  { {0xdc1c001e,0x68e20bbd,0xdee30842,0x6f1c0bbe}},	//   zņēm, skod, мочи, norc
  { {0xab5b0051,0x2d870051,0xe8010037,0xc0e6002d}},	//   _prüg, gune_, _लेना_, _довк
  { {0x1517000a,0x68e90133,0x7f860012,0x88c60012}},	//   يزية_, _gled, _ولأن, _بتسل
  { {0xdcfc001e,0xe7a90011,0x0ba60024,0x3ea70bbf}},	//   ltrē, _चैंप, ішим, bent_
  { {0x7e530012,0x2126016d,0xe3af0012,0x7d090bc0}},	//   _ينقص, lloh_, ئري_, anes
  { {0x2d870bc1,0x6104000e,0xdcfc001e,0x7ce3005e}},	//   cune_, zőle, ntrē, _sõrm
  { {0x5bc60003,0x6b96006f,0xdcee001e,0x23660034}},	//   _وقال, ktyg, ēdēj, _twoj_
  { {0xc49b000b,0x8c3d0060,0x6f1c0bc2,0x493b00af}},	//   _כשאת, neşl, forc, יגטו
  { {0x3f50001a,0xfeca0009,0x6f1c071e,0x7d000bc3}},	//   _màu_, ׁמָּ, gorc, lims
  { {0xfc3f0013,0xd5b80ac5,0x52130001,0xccfb0001}},	//   žít_, ост_, _одшт, аћа_
  { {0x8b67000a,0x9f6b0001,0x6104000e,0x3ea70bc4}},	//   قائم, _кроз_, tőle, zent_
  { {0x43940046,0xa3ab0037,0x9cd70009,0x6f1c0516}},	// [1450] матс, _कैश_, קומה_, borc
  { {0xf43b0093,0x6d5a0b0c,0x2732000d,0xb4db001a}},	//   שתמש, _otta, nând_, _giàn
  { {0x3ea70bc5,0xdcf50002,0x41b50012,0x15ab0048}},	//   vent_, erzą, ثمار, _тъпи_
  { {0xaac90044,0x76550002,0xc2370009,0x7cfe0073}},	//   राहक, lczy, קראו_, dūro
  { {0x8cce0037,0x99540066,0xdcfc000d,0xef0e01ec}},	//   थानो, _výše_, sură, ем_
  { {0x7bda000b,0xd00c000b,0x7d000028,0x76550002}},	//   _הקשו, יּוֹ, eims, nczy
  { {0x63a20017,0xdcf50002,0x69dc0260,0x7d090bc6}},	//   _apon, arzą, ørel, tnes
  { {0xe918002d,0x63ad0002,0xeae30011,0x3cc9004c}},	//   _досі_, owan, गस्त_, слио_
  { {0xff53000a,0x291d0002,0xddc10066,0x63ad0b3a}},	//   _آخر_, mowa_, _delš, nwan
  { {0xdd000039,0x63a0006f,0x2732000d,0x291d0002}},	//   ētāj, _ämne, gând_, lowa_
  { {0x386d00bd,0x4225002d,0x63ad0bc7,0x3a250109}},	//   _keer_, ядов, hwan, ямог
  { {0x8c3d003a,0xd59a000b,0x45b60009,0x9b750012}},	//   leşm, _לבעל, _מפעל_, _فاتص
  { {0x386d00bd,0x7ce3005e,0x7c070012,0x5cd20012}},	//   _meer_, _tõrj, _بباك, _سقوط
  { {0x27320bc8,0x501a000b,0xfc300012,0x02450012}},	//   când_, מורו, _شحن_, _عَبَ
  { {0x291d0002,0x63bb02d2,0xa92801e9,0x63ad0120}},	//   kowa_, lvun, ližš, ewan
  { {0x2732000d,0x317a000b,0x63ad0052,0x291d0002}},	//   mâne_, _האקד, fwan, jowa_
  { {0x291d0002,0x2d83006f,0x61e1004a,0x577a0012}},	// [1460] dowa_, arje_, lyll, _اصبح_
  { {0xe81f0037,0x8b230015,0x78b6003a,0x6b96006f}},	//   _बड़ा_, едуе, _hayv, rtyg
  { {0x6edb0093,0x26db0009,0x7edb0009,0xd6db0009}},	//   _החיפ, _הקימ, _הקיצ, _החיל
  { {0x2732000d,0xdcf50002,0xb60805b1,0x3eaa0032}},	//   zând_, trzą, alší, lebt_
  { {0xdcfc0039,0x4cbb000b,0x9cd70009,0x94bb0009}},	//   strē, _הזכו, _זוכה_, _המכת
  { {0x2d980108,0x8f9b000b,0x7cfe0010,0xb4b40037}},	//   otre_, מיני, tūro, _छोड़_
  { {0x6d46000f,0x2902003a,0x2732004b,0x291d0034}},	//   _kika, kika_, vând_, bowa_
  { {0x2d980061,0x3f50001a,0xdc13003a,0x76550002}},	//   itre_, _tàu_, _aşır, zczy
  { {0x3f670014,0x2732000d,0x76550002,0x7f4a0012}},	//   _нито_, tând_, yczy, _طلاق_
  { {0xdb0d0149,0x386d0070,0x248d0017,0x76480073}},	//   rvaç, _zeer_, agem_, _ugdy
  { {0x44270020,0x7dc50003,0x2732000d,0x5a34002d}},	//   ́n_, _يتمك, rând_, ьнот
  { {0x63ad003e,0x76550002,0x6d460bc9,0x3d160011}},	//   ywan, wczy, _nika, थकों_
  { {0x2732000d,0xb4db0054,0x6123005e,0x613f0035}},	//   pând_, _diàl, põlv, _jūli
  { {0x6d460006,0x44260101,0x61360028,0xd37b000b}},	//   _aika, _iyo_, jálf, _פרוט
  { {0x26da01a2,0x6a9b000b,0xe29b0009,0x06fd0066}},	//   _dopo_, _השונ, _השור, _říká_
  { {0xdb0d000e,0xe81e0037,0xa4d40024,0x31e50012}},	//   óköv, _युवा_, носі, _تسهّ
  { {0xa87c0093,0x2d9c0163,0x6d4600c6,0x0f27002d}},	// [1470] _האחר, _även_, _dika, _ньом
  { {0x61120039,0x7cea022d,0xa3bf0037,0x6eef03ee}},	//   māla, _výra, ुमत_, _købe
  { {0x9b17000b,0x291d0002,0xe8010037,0x7522000e}},	//   לחמה_, towa_, _लेता_, _okoz
  { {0xf7710351,0xf1c0008a,0xddde0013,0xc7b10012}},	//   نات_, ương_, _nepř, َّا_
  { {0x6eef0058,0x3f8b003a,0x6112001e,0x4426002c}},	//   _løbe, nucu_, nāla, _nyo_
  { {0xd246000a,0x386d00bd,0x291d0bca,0xad59024d}},	//   _لن_, _weer_, sowa_, орих_
  { {0x6721012e,0xfe700003,0xd658000b,0x9f440066}},	//   _vklj, اده_, היות_, ámé_
  { {0x6112001e,0xa0c50012,0x7d0d0bcb,0x61e1008e}},	//   kāla, _تيرو, nnas, vyll
  { {0x2d8a0058,0x53c90024,0x1dbd0011,0x6ef0005e}},	//   _åben_, ігом_, ्महत, _häbe
  { {0x6721001c,0xa91d0026,0xe578001e,0x6104000e}},	//   _uklj, buľk, šķi_, dőla
  { {0x6f0301a2,0x68ed0bcc,0x8afd0030,0xf8bf0097}},	//   minc, _blad, jpře, rlén_
  { {0x63a4000d,0x63c80031,0x361a0009,0x6f030bcd}},	//   _ţine, érnö, _וועד, linc
  { {0x889a000b,0x1eaa0012,0x8afd0030,0xdb0f0bce}},	//   חברי, ياسي_, epře, _escé
  { {0x2d980bcf,0x68ed0bd0,0x7d0d0bd1,0x7529018f}},	//   ttre_, _elad, enas, llez
  { {0xceb20093,0x60c9048b,0x2d980061,0xddc7009b}},	//   כים_, _onem, utre_, tajš
  { {0xd1320003,0x7d0d087a,0xa3ea0048,0x61120035}},	//   _جمع_, gnas, одба_, bāla
  { {0x0b46002d,0x2d980bd2,0xaac90037,0xddc7025e}},	// [1480] днан, stre_, रांक, rajš
  { {0xbe660003,0x6d4608bb,0xcaa60012,0x05560048}},	//   _تهدي, _wika, بصري, _отмя
  { {0x6d460039,0x7c260002,0xf3e90009,0x91aa0012}},	//   _tika, _wykr, סף_, تهاك_
  { {0x18670046,0x395c001e,0xcb09000b,0x23600070}},	//   даци_, īvs_, בל_, ppij_
  { {0x6f0300c1,0x4f570003,0x7d04004a,0xda660012}},	//   finc, وجود_, miis, _ياسي
  { {0x644b034e,0x9346007c,0x64590070,0x7522009b}},	//   _aggi, _інве, _afwi, _skoz
  { {0x1ea90003,0xdcf50002,0x2900004a,0x6da30001}},	//   ثاني_, erzę, _omia_, вија
  { {0x29020163,0x75290bd3,0x9be60024,0x84a90009}},	//   _öka_, glez, діок, ִיתִ
  { {0xdca3004c,0x2aaa0bd4,0xb7da00ae,0x22860557}},	//   тањи, отно_, _بوذا_, мунг
  { {0x65c60014,0xddc60001,0x2b470054,0x6d5e0027}},	//   _обза, _обзи, _cinc_, _otpa
  { {0x68ed0058,0xdcf50002,0x6d5e0107,0x75290164}},	//   _plad, arzę, ípad, blez
  { {0xf5030014,0x3f8b0060,0x61120035,0x6ef00248}},	//   _изхо, tucu_, tāla, _näbb
  { {0x7ce30005,0x59b00044,0xe53b000b,0x274b002d}},	//   _kõrv, _जनवर, _ותאר, ючно_
  { {0xe8df0020,0x3f8b003a,0x61120035,0x7c2f0060}},	//   _miền_, rucu_, rāla, ücre
  { {0x442d012e,0xc348001a,0xe8df001a,0xf6280024}},	//   _še_, _nổi_, _liền_, діти_
  { {0x30a70046,0x399802be,0x201e000d,0x7d0d0bd5}},	//   _цркв, més_, ştia_, unas
  { {0x39980bd6,0xe66705cc,0x60db0025,0x7d0d0bd7}},	// [1490] lés_, _отно, _roum, rnas
  { {0x0dcb0098,0x95cb0098,0x19eb0003,0x60db0061}},	//   _думи_, _дума_, يراً_, _soum
  { {0x3f99001e,0xa2c40037,0x60db0025,0x60c90227}},	//   _ūsu_, राज्, _poum, _pnem
  { {0x6f030002,0x30150bd8,0xb815004c,0xa0c50012}},	//   winc, ндер, ндеј, عيشو
  { {0x39980061,0xdbd600ff,0x70760012,0xa3c20011}},	//   hés_, _jääm, رموز_, ्मण_
  { {0x8ca10037,0x217b0012,0x6d580025,0xc1780073}},	//   क्नो, _وحزب_, _évac, ksė_
  { {0x7bc20036,0x6f030bd9,0xed560048,0xada50bda}},	//   _arou, rinc, нощ_, хайл
  { {0x273600c5,0x8c3d003a,0x3998057d,0x7bc20bdb}},	//   mæne_, leşi, dés_, _brou
  { {0x613605b1,0x2409003c,0x68e4008e,0x753b0bdc}},	//   nále, янии_, öide, rmuz
  { {0xbda70003,0xa3c20011,0xe299004c,0x75290030}},	//   _يحاو, ्मत_, чао_, slez
  { {0x39980bdd,0x39490bde,0xd9c90011,0x91e50198}},	//   gés_, _bias_, िमेट, хоне
  { {0xf8bf0042,0x2732004b,0xdcf50034,0xa01b0248}},	//   blém_, mâna_, przę, vgör
  { {0x39490149,0x2b470054,0x7d040269,0x69ce0032}},	//   _dias_, _tinc_, viis, äber
  { {0x61360066,0x7d790009,0xbb760009,0xfbd00012}},	//   dále, ּנּו, _טענו_, _ختم_
  { {0x399802be,0x13c80037,0x18a60055,0x6da300f5}},	//   cés_, रम्भ, _займ, лира
  { {0x7cea0042,0x61120035,0xad390557,0x7c6600ae}},	//   _výro, mālo, дчує_, عازل
  { {0x7d0401a3,0x8ca10011,0xdb040097,0x249f0097}},	// [14a0] riis, क्यो, fvið, ifum_
  { {0xda650003,0x7d040574,0x22160bda,0x915e0081}},	//   نامي, siis, нфер, _hẳn_
  { {0xf969002d,0x22930003,0x10ba000b,0x888605fb}},	//   дрій_, المس, ּזְב, ележ
  { {0xdd2f0013,0xa3c20037,0x3f860bdf,0xadd70009}},	//   pěšn, ्मद_, trou_, _נוכח_
  { {0x3998000f,0x2cad05aa,0x3c770009,0x2d870be0}},	//   zés_, deed_, _אתכם_, erne_
  { {0x7bc4007a,0x39980061,0xe578001e,0xf7730009}},	//   _šiuo, yés_, šķu_, נקו_
  { {0xf9870012,0x399800b7,0xb4fa0009,0x6b490073}},	//   _حب_, xés_, ּפִי, _užga
  { {0xe8df0020,0x71260003,0xc19b000b,0x61f2003a}},	//   _tiền_, _أرسل, _משלי, ıklı
  { {0xdccf001a,0x6b9b002c,0x6d3b0009,0x0aea0012}},	//   _tỉnh_, gtug, התקנ, كردي_
  { {0x39980be1,0x877b000b,0x7bc20070,0x13f30015}},	//   tés_, _מאמי, _vrou, узья
  { {0xe6d90028,0x27e60be2,0x22f70009,0x929b0009}},	//   _þráð, lyon_, גזין_, היית
  { {0xa3c20037,0x7cfe0010,0x2cad002a,0x7bc20be3}},	//   ्मा_, kūri, ceed_, _trou
  { {0xe8df0020,0x39980be4,0xb9090037,0x2d9c000e}},	//   _hiển_, sés_, _मक_, ltve_
  { {0x39980be5,0x9f35002d,0x61360042,0xf09f01a0}},	//   pés_, тегі, vále, sfà_
  { {0x2d9c000e,0x26de0be6,0xb2bb0009,0x7cf50030}},	//   ntve_, _moto_, _זמור, _dárf
  { {0x98a40001,0x612a0097,0x61e503a7,0x26de0be7}},	//   _биће, býli, vyhl, _loto_
  { {0x3eba000d,0x853b0009,0xfa87004c,0xa2cd0011}},	// [14b0] _fapt_, לגלי, ећем, साल्
  { {0x26de00c1,0x78a4001b,0x61360030,0x3ce90159}},	//   _noto_, _zbiv, rále, skav_
  { {0xab5b008b,0x7b0b001e,0x249f0028,0x7d0200b8}},	//   _grün, kļuv, yfum_, _omos
  { {0xa954007c,0x3eae0070,0x82340003,0xdb040028}},	//   укці, eeft_, اركا, svið
  { {0xcc760009,0x7f190024,0x9b580048,0x5ff50048}},	//   _שעשה_, міку_, _пият_, ъзду
  { {0x752d01a2,0x86980014,0xe8df001a,0x6e290066}},	//   llaz, етът_, _biển_, řebu
  { {0x5b140001,0x7db20003,0x27e60be8,0x623400b3}},	//   _смрт, لموص, ayon_, _беру
  { {0x752d02d1,0x270e0011,0x78bd0897,0x26fe0011}},	//   nlaz, _सद्र_, jdsv, _उग्र_
  { {0xf6990046,0x78af000d,0x2cad0be9,0x249f0bea}},	//   _овај_, decv, reed_, rfum_
  { {0x99d50003,0xc43c000b,0x7d020beb,0x4c3c0009}},	//   نتجا, התחי, _emos, התחב
  { {0xe4e7002d,0xc332000b,0x9f440030,0x2d9c0064}},	//   _підн, שוי_, ámí_, ctve_
  { {0x23b5000a,0x69c3009b,0x67230bec,0x658e0031}},	//   _لمؤس, _vrne, lonj, sőhá
  { {0x78bb0061,0x907a0009,0x3ae40248,0x1867004c}},	//   _mauv, וטרי, _köpt_, ђари_
  { {0x60cd0bed,0xdb240031,0x6723016d,0x6b890bee}},	//   _enam, ésün, nonj, mreg
  { {0x7c960014,0xd627096e,0x27e6003a,0xc6920009}},	//   крац, воре_, zyon_, יאם_
  { {0xfbe7008a,0xe6d90028,0xc5f2000b,0x7c85004c}},	//   _thể_, _þræð, בדל_, луђе
  { {0x3eba0033,0x0326024d,0x6d4b0a83,0x1c4607b9}},	// [14c0] _tapt_, вдан, _miga, тнам
  { {0x073a0003,0xd36f0003,0x6d4b0bef,0x394a05b1}},	//   _تسبب_, تهك_, _liga, _časy_
  { {0x63a9001e,0xd9460001,0xe2970bf0,0x7c290040}},	//   _ģene, вежи, тах_, _øern
  { {0x6b890070,0x21670294,0x8ca10011,0x480a0048}},	//   kreg, тици_, _कॉलो, меен_
  { {0xa8570093,0x4fb30003,0x60230015,0xd12f0003}},	//   דינה_, لصور, адца, آمن_
  { {0x57fb000b,0xc9860003,0x61380066,0xdb0f0018}},	//   ולנו, _لشري, díle, _escâ
  { {0x27e60bf1,0x6d4b002c,0x80b20011,0xf7470012}},	//   syon_, _biga, ज़ाइ, خلوي_
  { {0x6abc0225,0x399c0054,0x5bb8010c,0x621b0009}},	//   _harf, mís_, елия_, _חולק
  { {0xdfa50003,0x26de00f1,0x9696002d,0x6d4b02a5}},	//   _محلي, _toto_, _ареш, _diga
  { {0x61310163,0xc43b000b,0xb87b000e,0x2ac60001}},	//   håll, ותפי, nkív, тљив
  { {0x68e00028,0x4dda0012,0xa2c30011,0x399c0bf2}},	//   _komd, _توضح_, रयत्, nís_
  { {0xb97b000b,0x7cf8000e,0x78bd0227,0x7cea0097}},	//   ונטי, _hírf, udsv, _dýrk
  { {0xe9ff008a,0x61380066,0x7cf501c4,0xb8fb0011}},	//   _phải_, cíle, _sárg, _डच_
  { {0x6d4b0032,0x6d400bf3,0x61360bf4,0x3d950bd4}},	//   _ziga, lmma, tálc, лигр
  { {0x5e58007c,0x7bc6003e,0x9e090003,0x09e30001}},	//   тися_, _arku, ريرك_, _војн
  { {0xe4a70014,0x6d4e0061,0x6594004c,0x853c0073}},	//   ърго, _ébau, јату, _spėj
  { {0xe3b00003,0xb8f70037,0xe9ff001a,0x6d580061}},	// [14d0] يرك_, सा_, _thải_, _évan
  { {0x8c440046,0x539b000b,0x78bb0061,0xe8df001a}},	//   ређе, וימו, _sauv, _miễn_
  { {0x6136000f,0x78bb0061,0x2247006f,0x2d580061}},	//   lála, _pauv, änk_, _née_
  { {0xfc640098,0xf8bf0061,0xa2a90011,0xfc3f01e3}},	//   _върн, ndé_, _जॉन्, _maíz_
  { {0x6136000f,0x9cd6000b,0x8c3d000d,0x07a50103}},	//   nála, _עושה_, neşt, уалн
  { {0x539a0093,0x2d910066,0xa5b90001,0xa3c00037}},	//   _אישו, ouze_, ећих_, ंटर_
  { {0x69dc0051,0xdb1d0018,0x3f8f005e,0x399c026b}},	//   ärel, _ersã, sugu_, cís_
  { {0x38c2000e,0x7cfe0010,0xce380009,0x91fc0035}},	//   térő_, kūru, כאות_, abāk
  { {0x1b4900de,0x6d4b0bf5,0x07090012,0xd2990024}},	//   нзии_, _viga, _كيري_, нтні_
  { {0xe8df0020,0xe9d90046,0xa6f90009,0x6b890bf6}},	//   _diễn_, еко_, _אִ֣י, rreg
  { {0x0495000a,0x394d0070,0x7c2b0002,0x61380066}},	//   _ملاح, _kies_, _wygr, síle
  { {0xa6e20065,0x6b890bf7,0xdcbb0024,0xbd010030}},	//   _öðru, preg, _іще_, _šéfe
  { {0x7cfe0010,0x6136000e,0x6c7a0009,0xae070011}},	//   gūru, gála, _נאספ, _वेतन_
  { {0x2cbf0051,0x394d0bf8,0xe29905fb,0xe8d00011}},	//   ldud_, _lies_, _чак_, _सच्च
  { {0xd336000b,0xe7370014,0x82d6000b,0x2cbf0051}},	//   _גרסה_, уер_, _תוצג_, odud_
  { {0x7d0904fa,0x2cbf0051,0x399c0054,0x8c3d004b}},	//   nies, ndud_, vís_, beşt
  { {0x8c3d000d,0x6abc0b87,0x752400eb,0x80d10011}},	// [14e0] ceşt, _parf, roiz, धारे
  { {0x80a00044,0x7bc40010,0xd36f0003,0x7d090bf9}},	//   ग्रे, _šiuk, سهم_, hies
  { {0xcd360003,0x7ce30051,0x6abc006f,0x869b0009}},	//   _مرحب, _võrr, _varf, _אייז
  { {0x50ba0003,0x4f660003,0x399c0840,0xa8760012}},	//   عداد_, هاتف, rís_, اطات
  { {0x394d0bfa,0xdee609b1,0x62830bfb,0xc4d30009}},	//   _dies_, лоди, _odno, _הגר_
  { {0x2d80001e,0xd5b00003,0x3f72001e,0x7bcb0009}},	//   ņiem_, قفت_, iņu_, _אֶלֶ
  { {0xc693000b,0xae070037,0xf6570009,0xfa770009}},	//   צאה_, _वेदन_, נסקי_, _תעלת_
  { {0xfc3f0164,0xc5f3000b,0x7d090bfc,0xa534004c}},	//   _raíz_, מדו_, gies, јнич
  { {0xd250000a,0x4e960003,0x9cd7000b,0xc6960012}},	//   ينة_, _مشار, רופה_, _مشاع
  { {0x6136000f,0x8c3d000d,0x3f72001e,0x7cf8000e}},	//   vála, veşt, dņu_, _hírd
  { {0x62340001,0x28f900b3,0x7d090bfd,0xb1150024}},	//   рену, вень_, bies, имош
  { {0x8c3d000d,0x361b0009,0xecb80011,0xe8df0081}},	//   teşt, _אובד, _आसिफ, _tiễn_
  { {0x8cbf0044,0xe4e90012,0xf8bf0bfe,0xead40367}},	//   _लोगो, _جعله_, rdé_, _воль
  { {0x4383000a,0xbb83000a,0x8c3d007d,0xb3bb000b}},	//   _الوق, _الوي, reşt, _נמוכ
  { {0x4a5b000b,0x8ca10037,0x6d580061,0x8c3d000d}},	//   _אדוו, क्वो, _éval, seşt
  { {0xa99b000b,0xdb190052,0x6136000e,0x319b0009}},	//   _נבחר, _erwä, láln, _נבחנ
  { {0xe8df008a,0x1bd40014,0xab950024,0xa3d4003c}},	// [14f0] _hiện_, ботя, ризі, ботч
  { {0xe8df0020,0x7d090002,0xab94002d,0x8c1b0009}},	//   _kiện_, zies, сифі, תומי
  { {0x38600065,0xc333000b,0x9055002d,0x91f90012}},	//   _yfir_, צוע_, авец, خفاء_
  { {0xd7f10003,0xb97b000b,0x02440003,0x7cf50bff}},	//   يكا_, תנאי, حَمَ, _márc
  { {0xdb090028,0x248e0066,0x7d09072a,0x613601bd}},	//   kveð, íjmů_, vies, káln
  { {0x7d09031f,0x2f5c0009,0xb8080012,0x41770012}},	//   wies, עדונ, ديهم_, _مارس
  { {0x8aa4007c,0x4519085b,0xe4510003,0x394d0c00}},	//   _уряд, кция_, يضة_, _ties_
  { {0x7cf80056,0x2bc90011,0x290b017b,0xdcf80035}},	//   _vírg, रिपा, jica_, duvē
  { {0x54a40003,0x28f80021,0x7cf50031,0xe4a80009}},	//   صحيف, _сеть_, _párb, אֹתָ
  { {0x42550046,0x03a80003,0xe8df001a,0xfbd2000b}},	//   штит, اديو_, _biện_, קתי_
  { {0x186a0014,0x7cf8000e,0x6b8d00b6,0x290b0c01}},	//   кани_, _híre, hrag, fica_
  { {0xe8df0020,0x61fa0051,0x3f72001e,0x0fc6002d}},	//   _diện_, _ütle, tņu_, аймн
  { {0x6112001e,0x613d000e,0x07a60001,0x69dc03ee}},	//   nāli, zélg, јагн, ører
  { {0xdcee0066,0xabfa0009,0x0f560009,0x2fc90c02}},	//   ědče, _שהסר, יישם_, _drag_
  { {0x2d9e0108,0xb87b01c4,0xa5460003,0x6b8d00b6}},	//   îte_, tkít, لضرو, erag
  { {0x6b8d08fa,0x3fe6002d,0x82340012,0x3e830060}},	//   frag, _вжив, _ارها, _açtı_
  { {0x6136000f,0x42560014,0x70b20037,0x6d4f0c03}},	// [1500] lálo, атет, ज़ील, _dica
  { {0x8ccc0044,0xe1f20003,0x68e400ff,0xb77b0009}},	//   _दोनो, يسا_, _hoid, _שאיש
  { {0x6d4f0149,0x98da0011,0x61360636,0xf8da0011}},	//   _fica, _बचाए, nálo, _बचाय
  { {0x68e40006,0x3ead0027,0x2c5c0002,0xdbdc014a}},	//   _joid, đete_, _bądź_, lšíc
  { {0x684a0010,0x2635001a,0xd1170009,0x6b8d0c04}},	//   būdž, _áo_, סקנה_, crag
  { {0xdfcf0003,0x160b0011,0xcf930009,0x613d0031}},	//   بيه_, _हेडर_, קטו_, méle
  { {0x80c10037,0xd5b00003,0x6136000e,0x8d63004c}},	//   _रोके, سفة_, váln, овје
  { {0x3ea00013,0x54b80014,0x61360030,0x61380097}},	//   řit_, угия_, dálo, bíla
  { {0x2bc90037,0x3ebe0033,0x7e7c0c05,0x2eb60695}},	//   रिया, _tatt_, karp, _всес
  { {0x60c2007a,0x8f9b000b,0xe8010037,0xdbdc01bd}},	//   ldom, _בימי, _लेगा_, jšíc
  { {0x60c20010,0x32570009,0x20d50012,0xdcf60030}},	//   odom, יסים_, مقدس, ýběr
  { {0xab5b008b,0xe8df001a,0x7e6e006f,0x613d000e}},	//   _früh, _viện_, ebbp, kéle
  { {0x7cf10623,0xb4fb0009,0xe8010011,0x57640012}},	//   _dårl, _בלאר, _लेखा_, قدِّ
  { {0x7e7c006f,0xe8df001a,0x6136000e,0x6b8d00f6}},	//   garp, _tiện_, láll, vrag
  { {0xbbb60044,0x13b60044,0x5bb60037,0x94d5002d}},	//   _अनुक, _अनुभ, _अनुव, бовц
  { {0x89db000b,0x2fc60027,0x6136000e,0x6b8d0c06}},	//   _יחוי, kvog_, náll, trag
  { {0x113c000b,0xfbd00003,0xf7730012,0xdd2f0030}},	// [1510] _בתהל, وتك_, _باع_, _těžb
  { {0xf9c700c0,0xe2930003,0xb4e30011,0xfeb9004c}},	//   ищен, تذر_, _नक्_, _слој_
  { {0x60550003,0x31580003,0xb4db0054,0x6d4f0c07}},	//   مناط, لجنة_, _diàr, _tica
  { {0x6b820027,0x6112001e,0x7bdd005e,0x60c00c08}},	//   _ovog, tāli, äsuk, _camm
  { {0xf8bf0061,0x7d0d0c09,0x9cd60009,0x684a0073}},	//   llés_, mias, _הורה_, pūdž
  { {0x6136000f,0xaf04002d,0xb8820028,0x6112001e}},	//   eáll, опіл, _þíni, rāli
  { {0x61380013,0x645a000d,0x2909004a,0xeef8000b}},	//   síla, _ştii, _omaa_, שמור_
  { {0xa618000b,0x201e000d,0x613601c4,0xeb9902ad}},	//   יקוד_, ştii_, gáll, гии_
  { {0xe5040003,0xe3b10012,0x7cfe0035,0x7cf80031}},	//   تبوي, سرة_, tūrr, _hírc
  { {0x6d440002,0x6b82001b,0x23620097,0x7d0d0c0a}},	//   zmia, _dvog, íkja_, hias
  { {0x7e7c0028,0x613d000e,0x7ae30c0b,0x68e40c0c}},	//   varp, zéle, _vont, _poid
  { {0x3f6a0046,0xa2c90037,0x61d6000b,0xc2120009}},	//   лимо_, _होस्, צורף_, להי_
  { {0x68e40006,0x7e7c0071,0x320b0002,0xe5360009}},	//   _void, tarp, ńcy_, _פטנט_
  { {0x7afa04a3,0x60c20c0d,0x96630048,0x4ac40012}},	//   chtt, zdom, зкре, _وينق
  { {0xf8bf02d1,0xa2db0044,0xb9950003,0x99850003}},	//   glés_, नान्, _العب, _البو
  { {0x4bda0015,0xa9050003,0x62870c0e,0x6ab70011}},	//   льзя_, _وبين, _adjo, _असुर
  { {0xb8de0037,0x7cfc000e,0x61360029,0xdbdc00d9}},	// [1520] ुए_, _férf, nálm, pšíc
  { {0x6136000e,0x3fdb0009,0xf8bf0025,0x290e0034}},	//   záll, _עקיב, blés_, ślać_
  { {0xc879003a,0x7d0d0c0f,0x1e570009,0x613d0025}},	//   _beş_, bias, _לשיר_, séle
  { {0x2732000d,0x3f820002,0x69dc008e,0xd9430048}},	//   mâni_, osku_, ärei, пехи
  { {0x44240020,0xccf3000b,0x7bcd0010,0x2bc90011}},	//   _âm_, _זכר_, _šaun, रिणा
  { {0xb8ef0044,0xbb430024,0x3b0a003c,0x61120035}},	//   _वो_, _неяк, _сего_, mālu
  { {0xa3c20044,0xceb3000b,0xdbf10066,0x6b820027}},	//   ्मक_, פיה_, _dřív, _svog
  { {0xd2170093,0xdb1d006f,0x915e001a,0x8a17000b}},	//   _הקלק_, _ersä, _gắn_, _החלו_
  { {0x6112001e,0x24180015,0x3f820c10,0x369a0012}},	//   nālu, ропы_, jsku_, _مضاد_
  { {0x27f90051,0x7cf5000e,0x2bc90037,0x66e50012}},	//   _üsna_, _vára, रिता, _وألق
  { {0xd2500012,0x5eeb0009,0x7bcb0c11,0xe6c50012}},	//   بند_, _עַמְ, _ergu, _بتقي
  { {0x3a370093,0x7cfc0065,0xca37000b,0x6136000e}},	//   מרים_, _sérf, מניה_, lálj
  { {0x6d5a00c6,0xdcee001e,0x28b80011,0xdb0d0097}},	//   _huta, arbī, इज़ि, kvað
  { {0x6136000f,0x28cf0037,0x7d0d0002,0xf8bf000e}},	//   nálj, _सोनि, wias, tlés_
  { {0x427b000b,0x7d0d0038,0x7a530012,0x7a7b0009}},	//   _גאוג, tias, _عضوا, _גרוס
  { {0xe2170093,0xa4f100a2,0xf8bf000e,0xba17000b}},	//   _לקוח_, _dışı_, rlés_, _לחוץ_
  { {0x28d60044,0x63a40960,0x212b0064,0x99620064}},	// [1530] धारि, gtin, moch_, _ríše_
  { {0xda670003,0x6e950003,0x39460c12,0x3ce6005e}},	//   صائي, _بلدا, emos_, _loov_
  { {0x7cfc000f,0xb9b50003,0xdcfc001e,0x6d5a0b86}},	//   _kérd, تماع, gurē, _nuta
  { {0xd0110003,0x9cb50003,0xc5e80009,0x2ba90011}},	//   ولا_, _بمحت, _הַשֹ, _कहला
  { {0x2919069f,0x63a40c13,0x69d8008e,0xdbf10030}},	//   insa_, ctin, äver, _přív
  { {0x6287000e,0x6136000e,0x3983003a,0xd00c0009}},	//   _udjo, gálj, yıs_, טּוֹ
  { {0x7bc70039,0x05790003,0x3f760002,0x212b0029}},	//   ājum, جمعة_, ału_, koch_
  { {0xe919002d,0x212b0029,0xfdf80009,0xab650400}},	//   _тобі_, joch_, מצות_, овил
  { {0x212b0c14,0x6136000e,0x290f0c15,0x9f4e0030}},	//   doch_, bálj, miga_, žném_
  { {0x290f0c16,0x13090015,0xdb1d02f1,0x29190c17}},	//   liga_, рной_, _ursä, ensa_
  { {0x61460014,0xd9460210,0xc1060012,0x6d5a0c18}},	//   жена, жени, قودي, _guta
  { {0x63a40065,0x290f0051,0xa2a90321,0x7cf5000e}},	//   ytin, niga_, _जॉर्, _zárn
  { {0xe73a035b,0x3f840107,0x7cf5029d,0x6136000e}},	//   ием_, ému_, _háro, lálk
  { {0x7cea0028,0x78ad005e,0x2f5a0009,0x68f80035}},	//   _nýrr, _ebav, ידשנ, īvdi
  { {0x39400274,0x954a0003,0x6916009b,0xdd920012}},	//   _this_, لشرق_, jšeg, ظور_
  { {0x6136000e,0x20d6002d,0x6112001e,0x63a40c19}},	//   zálj, _фікс, tālu, ttin
  { {0x6ef00005,0x23690003,0x290f0c1a,0x2d910034}},	// [1540] _läbi, محلي_, diga_, arze_
  { {0xdcfc0039,0x2d910002,0x29f5001a,0x290f0010}},	//   turē, brze_, óa_, eiga_
  { {0x6136000e,0x7cf50042,0x6da60012,0x80a70011}},	//   válj, _náro, _بمجم, ट्वे
  { {0x7cfc000f,0x61360028,0x290f0051,0x6d5a0c1b}},	//   _kére, dálk, giga_, _ruta
  { {0x39460c1c,0x87ba0015,0xdb040070,0x6916009b}},	//   rmos_, рует_, ntië, ašeg
  { {0x7cfc000e,0x3ce60051,0x141b000b,0x758a0014}},	//   _mére, _soov_, _כוכב, асив_
  { {0xccfa0001,0x6136000e,0x98ca0011,0xaf070012}},	//   ићи_, rálj, ियाए, تقوم_
  { {0x443d008b,0x3eb80052,0xf6530009,0x60c40c1d}},	//   _bzw_, hert_, וצו_, _naim
  { {0xa6860c1e,0x7d030012,0x14a60011,0x212b0064}},	//   _млад, بِيه, क्षण, voch_
  { {0x61360c1f,0x3f800010,0xd25a0001,0x6d5a0c20}},	//   lálh, šius_, шци_, _tuta
  { {0xd62a0015,0xa2db0037,0x212b0029,0x4a5b000b}},	//   _тоже_, नात्, toch_, ידיו
  { {0x6136000f,0x2480000e,0x613d0028,0x2d980c21}},	//   nálh, jaim_, féla, dure_
  { {0x212b0029,0x3eb80c22,0x2d980c23,0x7cfc0018}},	//   roch_, fert_, eure_, _cére
  { {0x6b840058,0x212b0029,0x2d910002,0x539b0009}},	//   dsig, soch_, trze_, _כידו
  { {0x6d42008a,0xa4d5007c,0x2d85000e,0x77f80011}},	//   _khoa, пові, éle_, ्छुक_
  { {0x01fb000b,0x2d830002,0x69dc004a,0x2458027f}},	//   _כפול, rsje_, äreu, жать_
  { {0x2bcd0037,0x7cfc0061,0x20020002,0x6b84002c}},	// [1550] ़िया, _gére, czki_, gsig
  { {0xad670003,0x80a70037,0xdb040061,0x60c40c24}},	//   _واجه, ट्रे, ntiè, _zaim
  { {0x63bb0052,0x6b840c25,0x76ba0009,0x6cd50012}},	//   zwun, asig, _המתפ, _فقدا
  { {0x915e001a,0x63670029,0xab5b0032,0x2fcd00b0}},	//   _sẵn_, nčný, _brüt, _preg_
  { {0x3f99003a,0x9f35002d,0xb8e30011,0xd7f8004c}},	//   nusu_, педі, _ऍस_, жуј_
  { {0x290f0a9d,0xd7bc0009,0xdfce0012,0x1fd80012}},	//   siga_, שֶׁך, ايو_, تظمة_
  { {0x5e78000b,0x63670029,0xad580015,0x7cf80066}},	//   חתון_, kčný, орых_, _mírn
  { {0x7cf5000f,0xd5ae0003,0x20d70003,0x9f44000e}},	//   _váro, افي_, _بتسج, ámú_
  { {0x3ec40006,0x1309002d,0xb8ff0037,0x2d980c26}},	//   östä_, йний_, ता_, _åren_
  { {0x7bc90108,0xa205002d,0x7cf5000e,0x63bb0052}},	//   rveu, зпод, _táro, rwun
  { {0x3eb80c27,0xdcf70012,0xcb120009,0x61360018}},	//   vert_, _وأصب, תלי_, láli
  { {0x443d0002,0x3eb80052,0x3ea10832,0xecbb0012}},	//   _tzw_, wert_, _acht_, _خططت_
  { {0x3eb80c28,0xe28e0a25,0x26c500b6,0x60c40269}},	//   tert_, _па_, _kalo_, _vaim
  { {0xb8f3015f,0xfe670003,0xf6d5002d,0x3eb80052}},	//   _हो_, عد_, міся, uert_
  { {0x3eb80119,0x57b80037,0x60c40051,0x2480000e}},	//   rert_, _इन्ह, _taim, taim_
  { {0x0457000a,0x3eb80c29,0x7d1b015e,0x26c5002c}},	//   كلفة_, sert_, nnus, _lalo_
  { {0x3f99003a,0x6136000e,0x7d1b0c2a,0xc9530009}},	// [1560] cusu_, válh, inus, _אמה_
  { {0x2d9801a2,0x6b8400c5,0x6627000e,0xc7b30009}},	//   pure_, rsig, érké, _טבח_
  { {0xc219002d,0x217a0012,0x365b0009,0xc4bd0011}},	//   оєї_, صحاب_, _לכינ, ्याओ
  { {0x7cf5000f,0x00e60015,0xb05b004a,0xc7c60015}},	//   _bárm, яжен, ydäm, зски
  { {0x6136000e,0x9f980024,0xab5b0032,0x7cf80031}},	//   rálh, івку_, _drüs, _híro
  { {0x7d1b0051,0x6e940001,0x62810c2b,0x8b8b0009}},	//   enus, фику, jalo, _לָלֶ
  { {0x6281000f,0x1ea90003,0x43430bac,0x613d0066}},	//   dalo, تاني_, _черв, déln
  { {0x68e900bd,0x7cf80066,0xf653000b,0x2120013a}},	//   _goed, _míro, עצה_, _njih_
  { {0xd4670001,0xe3c30012,0x6d5e0c2c,0x26c50018}},	//   чиње_, فْيَ, _lupa, _falo_
  { {0xe3af000a,0x98b8007a,0xfee90003,0x6ec50003}},	//   اري_, _kurį_, _وعلى_, _يتلق
  { {0x6d420020,0x672e012e,0x6e930003,0xf2d3000b}},	//   _thoa, dobj, _ألما, געת_
  { {0x93aa0003,0x0217000b,0x63a4000d,0x2df70009}},	//   _هاتف_, לחים_, _ţinu, _מצבך_
  { {0x6d5e0c2d,0x57f40063,0xdb040025,0x3f860018}},	//   _aupa, епят, ptiè, nsou_
  { {0xddc80010,0x628a0058,0x6d5e00b6,0xe5730012}},	//   _medž, _udfo, _bupa, فطر_
  { {0xdd910012,0xa2db0011,0xa5f80560,0x5eef0011}},	//   ضوء_, नास्, перу_, _अवस्_
  { {0xa99b0093,0x2eb90044,0x645a007d,0xc19b000b}},	//   _הבהר, _इस्त, _ştir, _השהי
  { {0x201e00a2,0xd0080046,0x3f860013,0xb05b004a}},	// [1570] ştir_, _неће_, jsou_, hdäk
  { {0x61360149,0xd7fc000b,0x57fc000b,0x7cf8000e}},	//   váli, _להחל, _ללחו, _hírl
  { {0xc692000b,0xf1c20035,0x68fb0c2e,0x4aae0011}},	//   _באי_, jušā_, _plud, ज्यव
  { {0xf9900003,0x89370012,0x7aea0c2f,0x62810c30}},	//   ابل_, أعطا, _loft, zalo
  { {0x68e90070,0x37ab0229,0x3ce00011,0x6f640024}},	//   _voed, стен_, काने_, евіз
  { {0xe8da0037,0x2d510066,0x8f9c000b,0xf7780009}},	//   _बच्च, _všem_, מידי, לעדי_
  { {0x2732007d,0x1ea80003,0xb0f60028,0x95990024}},	//   vânt_, ساوي_, þýða, ітку_
  { {0xed560098,0x7cf5000e,0xd5fc0009,0x5dfc0009}},	//   мощ_, _zárj, מפור, מפונ
  { {0xa2a10037,0xd7940048,0x6d490c31,0x7cf50064}},	//   _खाद्, _питъ, rmea, _hárk
  { {0xcda90003,0x6136000e,0xff530003,0xe4520009}},	//   _وهذه_, nálv, _أخر_, כֶת_
  { {0x63a4007d,0x260d0011,0xf8f90081,0x613d0031}},	//   _ţint, _डेली_, ượt_, réln
  { {0xc6890093,0x7cf5000e,0xdb0401e3,0x2bb60011}},	//   _כא_, _márk, rtié, _अनचा
  { {0x73e4002d,0x62810c32,0x9f4e08ca,0xe8df0081}},	//   _поїз, palo, žním_, _nhọn_
  { {0x387f0108,0xe6120012,0xa3c10011,0x63a90c33}},	//   _leur_, نشأ_, ंबन_, mten
  { {0x64a60014,0x35a30024,0x613d0031,0x63a90c34}},	//   мава, карг, célo, lten
  { {0x249f014d,0x205604fb,0x417a0009,0x6eef0040}},	//   ngum_, _отпр, _ונקב, _købs
  { {0xe8df008a,0xb4db0020,0xb4be0044,0x61380030}},	// [1580] _chọn_, _thàn, _इसी_, sílk
  { {0xf1fa0003,0x7cf5000e,0x613801d7,0xc2c60012}},	//   يعات_, _bárk, míli, بيئي
  { {0x8ca60037,0x7cf5000e,0x6edb0009,0x7edb0009}},	//   _छापो, _várj, _וחיפ, _וקיצ
  { {0x63a90c35,0xdfda0048,0x7cf50030,0x31be0030}},	//   kten, жък_, _dárk, _vůz_
  { {0x4cbb0009,0x69da001b,0x387f0227,0x2d850030}},	//   _וזכו, _šted, _deur_, šlet_
  { {0x61360028,0xdcfc0010,0xbd6a0048,0xad660012}},	//   málu, turė, орие_, وابه
  { {0x63a90c36,0xceb3000b,0x3f860017,0x6136000e}},	//   eten, דיו_, ssou_, lálu
  { {0x2ca00051,0x89d70003,0x249f0028,0x6128003a}},	//   ngid_, _توفر_, ggum_, nıld
  { {0x2ca00051,0x70560012,0x28dd0011,0x8f970012}},	//   igid_, _آنذا, यासि, _ينفذ_
  { {0xbb470012,0x7cfc0025,0x2732004b,0x57430048}},	//   ولين_, _déra, râns_, _ануб
  { {0x6128003a,0x7dc60012,0xdee30048,0xd915003c}},	//   kıld, _تتذك, _шофи, едны
  { {0x61e3006f,0x05770012,0x7bcd0073,0x61360031}},	//   änli, _آمنة_, yvau, zálv
  { {0xa294002d,0xacf7002d,0xcd020002,0xaae60012}},	//   _залі, _іншу_, reść_, _يستو
  { {0xbbbc0011,0x4c3b0009,0xa3d20011,0x2ca0005e}},	//   ्टीक, _ותדב, विन_, egid_
  { {0xfcc70001,0xf92b0003,0x929b000b,0x6136000e}},	//   мљам, _وأبو_, _ויות, válv
  { {0x3ea9001b,0x66250035,0xa2d605f3,0xb86700ae}},	//   đati_, _ārkā, बाक्, _غابو
  { {0xa87c000b,0x4374002d,0x2bbb0012,0x7bcd008e}},	// [1590] _ואחר, вуєт, غارة_, uvau
  { {0xab94002d,0x7bcd0872,0x20dd0011,0x28dd0011}},	//   тифі, rvau, यावध, यावि
  { {0x387f0061,0x98a20034,0x61360031,0x50b500b5}},	//   _peur_, soką_, rálv, еслу
  { {0xf7710003,0x6f15003a,0x1dc20011,0xdcf50035}},	//   هات_, lizc, _वैधत, irzī
  { {0x7afd001e,0xdfa40012,0x63a90c37,0x3f890025}},	//   ūsti, نحوي, xten, éau_
  { {0xd2460351,0x4f9c000b,0x6136000e,0xf774000b}},	//   _من_, קבוצ, lált, דקס_
  { {0x8d550147,0xa8a705d8,0xddd8001b,0x62850c38}},	//   нтич, _орак, tavš, maho
  { {0xd6580093,0x6136000e,0xc9840001,0x6d4d0c39}},	//   ויות_, nált, _јури, nmaa
  { {0x249f0028,0xfbd10003,0x6d4d004a,0x6f15003a}},	//   rgum_, اتب_, imaa, kizc
  { {0x62850101,0xe3c80020,0x63a90c3a,0xc2c50012}},	//   naho, _dự_, rten, ريجي
  { {0x613d000e,0xfeb80012,0xc3320009,0xb87b0030}},	//   mélj, _زالت_, רוי_, ajím
  { {0xb4be0044,0xcea90093,0x60c9005e,0x7cfc0097}},	//   _इसे_, _לי_, _jaem, _hérn
  { {0xb8e80044,0x6d4d0070,0x68ed0018,0x7cfc0031}},	//   _उस_, dmaa, _doad, _kérn
  { {0x6d59002c,0x201e000d,0x6d4d0c3b,0x645d020d}},	//   _hiwa, ăti_, emaa, _agsi
  { {0xe8160037,0x65610017,0x6128003a,0x7cf5000e}},	//   _देना_, _julh, tıld, _párh
  { {0x045a0003,0x65610017,0x6136000e,0x6d4d06f9}},	//   سلطة_, _mulh, gált, gmaa
  { {0x44260149,0x2bd20037,0xf1c9001a,0x6128003a}},	// [15a0] ço_, तिया, _hạ_, rıld
  { {0x28ac0037,0x60db0c3c,0xa857000b,0x6d4d06cf}},	//   ट्रि, _anum, _איפה_, amaa
  { {0x6128003a,0x61360031,0x91fc0035,0x499a0223}},	//   pıld, bált, ecāj, ятая_
  { {0x01fa000b,0xc7ca003c,0x6d46008e,0xf1c90081}},	//   הפעל, зыке_, _uhka, _mạ_
  { {0xf1c9001a,0x703a0012,0x69c30040,0xf0930009}},	//   _lạ_, أساس_, æner, רנד_
  { {0x8f75007c,0xc6f7002d,0xe5c60146,0x7bc60c3d}},	//   туці, нніх_, есио, _isku
  { {0xe3c80020,0xd5b7003c,0x7ec80035,0x6da3004c}},	//   _sự_, есы_, _rūpē, гија
  { {0xed570046,0x35c50037,0x273b001a,0xaa570012}},	//   ној_, विज़, hênh_, _ألفا_
  { {0xe8b500a2,0x7d04004a,0x6d590c3e,0x68ed0c3f}},	//   lışı, ihis, _diwa, _road
  { {0x55e6002d,0x51f8002d,0xf1c9001a,0x6136000e}},	//   _позб, дною_, _bạ_, zált
  { {0x13170093,0x7d04006f,0x61360028,0x7cf80066}},	//   תחיל_, khis, jáls, _círk
  { {0xe3c80020,0x753b000d,0x7bc60c40,0x040b0081}},	//   _tự_, cluz, _osku, _cưỡn
  { {0x0457000a,0x6136000f,0x7d16003a,0x7cfc0c41}},	//   _كلمة_, vált, diys, _héro
  { {0x3ea5000f,0x7bdb000b,0xe8b50060,0xf4570009}},	//   ült_, _מקדו, kışı, _ניגר_
  { {0x7521000e,0x7af5000e,0x27360028,0x6d4d0c42}},	//   élzo, özte, vænt_, tmaa
  { {0x23b70037,0xf98f0003,0x7cf5000e,0x823b0009}},	//   _अहमद, _ابو_, _pári, _מעוצ
  { {0x54550014,0xb9050037,0x628e0002,0x6136000e}},	// [15b0] тват, ना_, óbow, rált
  { {0x7cf50149,0x2d8c0027,0xab18002d,0x6d4d0c43}},	//   _vári, _ovde_, нієї_, smaa
  { {0x394900b6,0xf1c9001a,0xceb20009,0x6d4d0c44}},	//   _khas_, _xạ_, _דיי_, pmaa
  { {0x628500f1,0x44390504,0x05760009,0x628a0031}},	//   saho, _tys_, _שגרם_, ófor
  { {0xc1040003,0x7cfc0061,0x31580012,0x6d59016d}},	//   دوني, _aéro, رجمة_, _riwa
  { {0xa3c00037,0x9f400097,0x613d0031,0x93fa0009}},	//   ूटर_, áið_, félk, _חלשי
  { {0x2bc90037,0x6da20048,0xa9280064,0x613d0031}},	//   रिका, аища, nažé, rélj
  { {0x92580098,0x7cfc0061,0x9ddc000b,0x63ad0839}},	//   _част_, _déro, לקוח, otan
  { {0x3f8b0002,0xd4680012,0xcf270012,0x8e850012}},	//   jscu_, رحيم_, _كرئي, _للذه
  { {0xa3d20037,0xe6cb0037,0x69d50002,0xdcfc001e}},	//   वित_, ायोज, _krze, turī
  { {0x7cfc0c45,0x6d59002c,0x63ad0c46,0xf2d20009}},	//   _kérl, _tiwa, htan, בעי_
  { {0x61360031,0x6b890c47,0xa3c10011,0xdddc001b}},	//   váls, pseg, ंबा_, jarš
  { {0x63ad000e,0x7bc70035,0x7cfc0c48,0xa78c0009}},	//   jtan, ājus, _mérl, ּאלֹ
  { {0x78a2001c,0x69c70027,0xf8c7000e,0xa444002d}},	//   zgov, _osje, áért_, _снід
  { {0x7d160060,0x386d004b,0x63ad0c49,0xad5a04a5}},	//   tiys, _ofer_, etan, драх_
  { {0xad39002d,0x7d04005e,0x7aee01a0,0x61360064}},	//   ечує_, uhis, _sobt, ráls
  { {0x63ad0101,0xa3d20037,0xa03a0012,0x44630024}},	// [15c0] gtan, विध_, _تأثر_, рвув
  { {0x69d50002,0x62830c4a,0x13030237,0xc7d70009}},	//   _brze, _jeno, азум, _יופי_
  { {0x1d0a0345,0xf9690024,0xba170012,0x7bc60034}},	//   _жени_, ерій_, نيكا_, _wsku
  { {0x69d50002,0xa3d20037,0xe8b5003a,0x25d70009}},	//   _drze, विद_, rışı, _סוכן_
  { {0x69d50052,0x10a30c4b,0xc6fa0009,0xe7b40012}},	//   _erze, ричн, ֽלֶך, امتد
  { {0x4733002d,0xcdda0001,0xdd900003,0xf7730009}},	//   аніс, дњи_, موت_, סקו_
  { {0x27e0007d,0xceb3000b,0x69d50002,0x69d80058}},	//   ţin_, ייג_, _grze, æved
  { {0x23ab0058,0x5f960003,0xc5f30009,0x80ca0011}},	//   føj_, _للرئ, שדה_, _सोचे
  { {0xf8bf0061,0x7d03000d,0x62830c4c,0x6d3b0009}},	//   nnée_, _înse, _beno, ותקנ
  { {0x6e29003a,0xe6c50012,0xf1aa0012,0x38600c4d}},	//   şebi, _متمي, واجه_, _agir_
  { {0x26de0036,0x29fc0020,0xe8160044,0xcb13000b}},	//   _into_, ủa_, _देता_, שלת_
  { {0x63ad0c4e,0x62830031,0xcdf700af,0x51f703d2}},	//   ytan, ónoz, _שמאי_, тнюю_
  { {0x7cd70012,0x63ad0c4f,0x62830c50,0x69160c51}},	//   _جونز_, xtan, _feno, pšen
  { {0x8c43035b,0x62830c52,0xd7f80109,0xc0530009}},	//   _тече, _geno, тую_, יזר_
  { {0xd7880020,0xf8bf000e,0xb2bb0009,0x41b40012}},	//   hể_, tnéd_, _חמור, _إمبر
  { {0x26cc01c5,0x6924001b,0x3ead0030,0xcdb70009}},	//   _lado_, nđel, řet_, כפלה_
  { {0xf8bf0061,0xac180001,0x67d5003c,0x613d0031}},	// [15d0] gnée_, воту_, _сопу, vélh
  { {0x69d50656,0x613d0c53,0x80d80011,0x62880c54}},	//   _prze, déli, _नोबे, nado
  { {0xe298002d,0xf9c70014,0x6128003a,0x3264002d}},	//   тає_, ъщан, lıla, ртув
  { {0x45fa0009,0xa3d50011,0x67350034,0x7cf50031}},	//   _נהרג, हिम_, lozj, _járt
  { {0x612800a2,0x69d50002,0x6d5d002c,0xdc9a000b}},	//   nıla, _wrze, _iisa, _אירל
  { {0x69d5003e,0x57fc0009,0xa8580009,0xdb0f01a0}},	//   _trze, ולדו, דידה_, _escò
  { {0x609b0003,0x6d5d0c55,0x26cc052e,0x7cf80c56}},	//   _يخرج_, _kisa, _dado_, _síri
  { {0x248900bd,0x7d02084e,0x23ab0058,0x6128003a}},	//   naam_, _clos, tøj_, kıla
  { {0x6b8d0149,0x7cfc000f,0xed110020,0x6d5d00c6}},	//   nsag, _kérj, _đối_, _misa
  { {0x6d5d0005,0x7d020c57,0x6128003a,0xc43c0009}},	//   _lisa, _elos, dıla, ותחי
  { {0x20100073,0xd1b90012,0x8a160009,0x7cfc0031}},	//   ėlių_, رادا_, ָ֗יו_, _mérj
  { {0x2489005e,0x6d5d0c58,0x29190c59,0x63a00c5a}},	//   jaam_, _nisa, gisa_, bumn
  { {0x6128003a,0x511a0009,0x80a50011,0xe299020f}},	//   gıla, תֵינ, _कारे, _зал_
  { {0x3392000a,0x8c1a000b,0x539a000b,0x6b8d014f}},	//   _الوز, _אוני, _ניצו, dsag
  { {0xd6270345,0x291901ea,0x64460034,0xb1760081}},	//   горе_, bisa_, _szki, _trượ
  { {0x6128003a,0x29190c5b,0x649900b3,0xc5090012}},	//   bıla, cisa_, ктур_, نتقل_
  { {0x612800a2,0x6b8d0c5c,0xf0930009,0x93aa0012}},	// [15e0] cıla, gsag, _הנח_, عارف_
  { {0xf8bf0061,0x877b0009,0x36c60048,0xa2db0011}},	//   rnée_, _ראיי, _сбог, नाग्
  { {0x17570009,0x71650012,0xe1650012,0xaaa60011}},	//   _תסיר_, لانك, لدني, _खासक
  { {0x62880c5d,0x40960012,0x30a50024,0xa926003c}},	//   zado, الشر, ирів, ыдел
  { {0xd12f0003,0xb4c00037,0x62880c5e,0xc4d30009}},	//   أمن_, ंजी_, yado, _פגש_
  { {0xa3c10037,0xa857000b,0x62880c5f,0xc7b30009}},	//   ंबर_, אינה_, xado, צבו_
  { {0x7d03007d,0x6128003a,0xbb3b000b,0xb05b0c60}},	//   _însc, zıla, _נעלי, ndär
  { {0x612800a2,0x7cfc0844,0x3fa60003,0xd37a0c61}},	//   yıla, _térm, _مصطف, нчо_
  { {0x60cd0005,0x29040005,0x7bcd001e,0x9f5100d9}},	//   _raam, _ilma_, _šaur, žbám_
  { {0x26de002a,0x60cd00b9,0x24890070,0xba0a0048}},	//   _unto_, _saam, zaam_, ехме_
  { {0x22580051,0xef1f000e,0x7cf5000e,0x867b0009}},	//   ärk_, ssük_, _párt, _נראו
  { {0x612800a2,0xa055002d,0x6b9b0c62,0x7cfc000e}},	//   tıla, ивні, brug, _mérk
  { {0x33f60012,0x6446005e,0x6b4b0032,0x7cf50031}},	//   _حساس, ükid, lüge, _várt
  { {0x612800a2,0x6d5d0289,0xd5a60003,0x69c5002a}},	//   rıla, _sisa, يف_, ywhe
  { {0xbcfb0108,0x2904003a,0x6b4b0052,0xdb000051}},	//   _liée, _olma_, nüge, rtmä
  { {0x612800a2,0x75240c63,0x3ce70011,0xab5b005e}},	//   pıla, gniz, झाये_, _tsük
  { {0xaae00037,0x6d400038,0x6d5d0c64,0x30780012}},	// [15f0] नांक, ilma, _visa, _صحية_
  { {0x6d5d00c6,0xa3d50037,0x722b0021,0x8c1b0009}},	//   _wisa, हित_, нцев_, גומי
  { {0x6b8d0c65,0x26c30159,0x6d5d0c66,0x929b0009}},	//   ssag, mejo_, _tisa, תיבת
  { {0xe5c4002d,0x69c50132,0x26c30478,0x6b8d0c67}},	//   _усьо, rwhe, lejo_, psag
  { {0x7cfc01c4,0x17550024,0xdb040c68,0x97d80012}},	//   _térj, авдя, stiá, ُظهر_
  { {0x6b4b008b,0x539a000b,0x26c30c69,0x8c1a0009}},	//   füge, _בישו, nejo_, _יורי
  { {0xf4ba0028,0x7cfc0031,0xfce50681,0x26dc0009}},	//   _þýða_, _kérh, иоко, תקומ
  { {0xd6180003,0xe93b0012,0xcdcf004c,0x2d9e001b}},	//   دتها_, _أسست_, тњa_, šteg_
  { {0x69d80005,0x76a70003,0x60c40051,0xab5b0051}},	//   _arve, _محاك, õime, _psüh
  { {0x26c3012e,0x57f40001,0x98140012,0x05870024}},	//   jejo_, _упут, _طبقا, _будм
  { {0x628702d1,0x69d80027,0x26c3009b,0xf8c90011}},	//   _mejo, _crve, dejo_, _रसाय
  { {0x69de0026,0x33d5002d,0xc236000b,0x69d80027}},	//   _špec, _вікт, ירתו_, _drve
  { {0xa9360009,0x320c0034,0x95540012,0x62950159}},	//   שטרה_, azdy_, _اخلا, _odzo
  { {0x3ced012e,0x7cf5000e,0xa856000b,0x394d0017}},	//   ljev_, _társ, יירה_, _lhes_
  { {0xad3a0024,0x2d980c6a,0x94aa0012,0x98bf0060}},	//   вчає_, _året_, َارِ_, aptı_
  { {0x25ed0044,0xc5f2000b,0x88830014,0xa3d20011}},	//   _अपनी_, חדל_, _длъж, विल_
  { {0x75240c6b,0xf7720003,0xed570686,0x6b4b0032}},	// [1600] rniz, _باب_, рот_, züge
  { {0xa25a000a,0x75e80024,0xa696004c,0xbf130012}},	//   نشاء_, _блоґ_, _триј, _وويب
  { {0xa2a70037,0x09fa0003,0x7e9b000b,0x7cfc000e}},	//   _चार्, خفضة_, _בסיו, _férh
  { {0x40690009,0x42550024,0x6143003c,0x53a60c6c}},	//   ְיוּ_, стут, оеха, _камб
  { {0xdfd20003,0xe3b20003,0x43750c6d,0x67d4004c}},	//   تيش_, _برج_, _густ, солу
  { {0x98ab003e,0x9ea70046,0xc7d7000b,0xe29a0015}},	//   mocą_, авља_, יוני_, _шаг_
  { {0xb23a0003,0x4420000d,0x7cfc0061,0xce890003}},	//   _شكرا_, _ţi_, _héri, ائهم_
  { {0x92a6003e,0x6d400c6e,0x7d090c6f,0xd6570009}},	//   _wyłą, ulma, ghes, סיקת_
  { {0x6f1c0052,0x515b0009,0x889b0009,0x409b0009}},	//   kirc, _יכלו, _שבמי, _שבמס
  { {0x2d9c0066,0x0bb70009,0x7cfc0c70,0xfbb70009}},	//   prve_, סלים_, _méri, ספית_
  { {0x98af001e,0x79a30306,0x42fb0009,0x26c30c71}},	//   logā_, оряе, דהיס, vejo_
  { {0x8dfb000b,0xe58b0009,0x6d8b0009,0x1dd30011}},	//   _שהאת, _יָדָ, _יָדְ, थिरत
  { {0x8c430538,0x3945001e,0x394d0035,0x6aab0248}},	//   _деце, ēls_, ķes_, ämfö
  { {0x7cfc0028,0xa2d30003,0x63a40c72,0xabfb0009}},	//   _sérh, _وينت, duin, _בהדר
  { {0x26d1003e,0xe2970001,0x7cfc0061,0xfa770009}},	//   rdzo_, _тај_, _aéri, _דעות_
  { {0x26c30c73,0x63a40097,0xda5b0009,0x65680c74}},	//   sejo_, fuin, _בכול, _mudh
  { {0x63a40c75,0x3ce70037,0xea670001,0x2d58027f}},	// [1610] guin, झाते_, ањен, рить_
  { {0x6e2d00a2,0x883c000b,0xc7b2000b,0x7cfc0061}},	//   şabi, _בתחו, _צבי_, _déri
  { {0x75d50003,0xc3330009,0x32190012,0xdb060031}},	//   _ايجا, קוע_, دياد_, émáb
  { {0xc7950012,0xa3d60011,0x1869004c,0x7bcb0097}},	//   مشتب, ाटा_, ћали_, ægus
  { {0x7f19002d,0x2d910002,0x28ac0011,0x69ca0040}},	//   ліку_, lsze_, ट्टि, æfer
  { {0x16a90014,0x69160066,0x60080024,0x099b0012}},	//   увки_, ašeh, шнім_, _لضرب_
  { {0x92940001,0x3ced0027,0xcee80012,0xc5d50024}},	//   _фасц, tjev_, شرون_, сіль
  { {0xb9250003,0x7af5000e,0xf1b20009,0x2ca90c76}},	//   _افري, _hozt, _מסל_, ngad_
  { {0x3ced009b,0xe4a80009,0x3ec70024,0x7d1b0c77}},	//   rjev_, בֹתָ, _всеб, rius
  { {0xfe700003,0x5f450003,0xfaa50001,0xddde01bd}},	//   _قدم_, _انطل, љано, _lepš
  { {0x5dd50003,0xdb040017,0x2d910002,0xc692000b}},	//   _دقائ, stiç, jsze_, _זאב_
  { {0xf4d40012,0xb47c0024,0x91fc0035,0xe4d40012}},	//   _وتنظ, _акцi, ecās, _وتنب
  { {0xeb9901d4,0xc0520009,0xdb0b0040,0xa2d20011}},	//   _сил_, ּ֖ר_, _opgø, _भोक्
  { {0xa3c10037,0x656800b6,0x613d000e,0xda7b01d4}},	//   ंबई_, _yudh, féls, _ряд_
  { {0x7ae30119,0x6b500163,0xfce60198,0x644e0034}},	//   _innt, lägg, бово, ębie
  { {0x7cfc0108,0x99360003,0x2ca9006f,0x40960003}},	//   _péri, _دفعت, ggad_, _الظر
  { {0x6128003a,0x044a035c,0xc9530009,0xc4d20009}},	// [1620] nılm, упак_, _צמח_, הגן_
  { {0x7cfc0108,0x7c2e0052,0x2d910034,0x2ca90035}},	//   _véri, ßbri, bsze_, agad_
  { {0x8db6002d,0xa75b000b,0x68f6003a,0x28dd0011}},	//   _успі, _תדיר, _koyd, याचि
  { {0x6128003a,0xc9850003,0x94790024,0x3d140011}},	//   kılm, تشكي, _всру_, नोशे_
  { {0xc7a30538,0x2902019a,0x31b1000e,0x8fa300fa}},	//   зичк, ikka_, ház_, заче
  { {0xb033002d,0x09e60048,0x98af0035,0x9f550097}},	//   чніш, _логн, rogā_, æfðu_
  { {0xfb1b000b,0x6d440010,0x867b0009,0x21750048}},	//   _עולמ, olia, ארצו, _мутр
  { {0xbb740046,0xd197000b,0x5398010c,0xdb04004a}},	//   огиј, _לכלי_, авия_, stiä
  { {0x3006002d,0x9f63000e,0x67380027,0xc4d30009}},	//   _узаг, ívül_, povj, לגה_
  { {0x6d440c78,0x6568000e,0x78ad0c79,0x2d910034}},	//   hlia, _tudh, _scav, ysze_
  { {0x4427001a,0xf5390066,0x69da009b,0x69cf0002}},	//   ̃n_, boť_, _štej, łcen
  { {0x4a5b0009,0x613d0031,0xe10b00af,0xd46a0a36}},	//   טדיו, véls, ָּטָ, _сиде_
  { {0x2d91003e,0x34560012,0xb0aa0011,0xc3d70012}},	//   wsze_, _انشأ, _कारग, _هبوط_
  { {0x98be001e,0xa3d50011,0x29020097,0x31b10064}},	//   ētā_, हिर_, akka_, báz_
  { {0xde59002d,0x2d850061,0x95c50012,0xb05b008e}},	//   раві_, èle_, غيره, meäm
  { {0x6d4401a2,0x2d910053,0x32430012,0xbca50012}},	//   glia, rsze_, _عنيف, تمري
  { {0x36d50046,0x4918000b,0x2d91000e,0x6a670003}},	// [1630] _допр, _לקהל_, ssze_, مطال
  { {0xdb510003,0x2d910002,0x4427001a,0xbb840003}},	//   ذَا_, psze_, ăn_, سلمي
  { {0xd879000a,0x2bcf0037,0x6115002d,0x6128003a}},	//   لمات_, _तैना, оджу, zılm
  { {0xe894002d,0x628a000e,0x6128003a,0xda4b0009}},	//   заць, _lefo, yılm, אֲדָ
  { {0xcf9b0046,0x60c40051,0x69dc0c7a,0x7cfc0025}},	//   ује_, õima, _erre, _jéru
  { {0x7d0d0272,0x291d0101,0x7ac70001,0x6b50006f}},	//   lhas, siwa_, _усме, vägg
  { {0xceb4000b,0x24e90264,0xace90c7b,0x7d0d0c7c}},	//   פיק_, имки_, имка_, ohas
  { {0x612800a2,0x28d90037,0xc1050012,0x8b950bd8}},	//   tılm, _बोलि, _بوري, ороч
  { {0x5f740003,0x628a0c7d,0xe3b10003,0x13090511}},	//   _فالر, _befo, ذرة_, иний_
  { {0x6128003a,0xe2990001,0x3dd20002,0x2909008e}},	//   rılm, јан_, ływa_, _alaa_
  { {0x90c60015,0x60c6001e,0x613d000e,0x61280060}},	//   обне, tekm, vélr, sılm
  { {0xf992000b,0x6128003a,0x320b0002,0x7cfc0c7e}},	//   ורט_, pılm, ący_, _sérv
  { {0x3c47000a,0x60c6003a,0x7529000d,0x2902004a}},	//   _اضاف, rekm, mnez, rkka_
  { {0x2bcf0044,0x7ae30033,0xb4c90037,0xcc560009}},	//   _तैया, _unnt, _लघु_, _ובני_
  { {0x7bcf000d,0x96040037,0x96630232,0x6b500a50}},	//   _ascu, रनेट_, дкре, näge
  { {0x681c001e,0x68e40c7f,0xf8bf0031,0xd4670c80}},	//   tādī, _unid, nnél_, жите_
  { {0xd7ef000a,0x6d440a5f,0x2480004b,0xf8bf0031}},	// [1640] _لكي_, rlia, rbim_, inél_
  { {0x681c0333,0x98ad0029,0xcaa60003,0x26c70c81}},	//   rādī, _cieľ_, تصري, jeno_
  { {0x7c2d0065,0xf8bf000e,0x26c70c82,0xe81f0011}},	//   _þarf, knél_, deno_, _मेबा_
  { {0x7d0d0c83,0x61fe0c84,0x61ee0602,0x69160c85}},	//   chas, rypl, äbli, ašev
  { {0x7cfc000e,0xa3ce0011,0x6fca0011,0x67490097}},	//   _mért, _शनि_, िबिं, _ásjó
  { {0x7d040006,0xb7db000b,0xd00f0012,0x644b005e}},	//   lkis, יקני, خله_, ügie
  { {0xb0aa0037,0xbd670015,0xa3d20037,0x62810c86}},	//   _कांग, орые_, विक_, dblo
  { {0x61e1000f,0x3ea00c87,0x88860015,0xe628001a}},	//   _álla, şit_, _флаж, _đồ_
  { {0x2f0b00c5,0x63b60c88,0xd0070103,0x26c70121}},	//   _søge_, ntyn, _дете_, beno_
  { {0x7d0d000e,0x8c1b000b,0x39460c89,0x62810c8a}},	//   zhas, יופי, llos_, gblo
  { {0xfd4d001a,0xaadb0009,0x32db0009,0xbe160012}},	//   ghiệ, בחיר, בחינ, _بوضع
  { {0x39460052,0x6be60012,0x26f50011,0x10740024}},	//   nlos_, _وكام, ीघ्र_, млюю
  { {0xc864007c,0x645d0010,0xc1b70037,0x232a0472}},	//   дтри, žsir, _इङ्ग, _коди_
  { {0x600b0009,0xdb040025,0x8d770012,0x98af0034}},	//   בִלְ, quiè, قارا, mogą_
  { {0x98af0010,0xf27b000b,0xf8bf0066,0x39460071}},	//   logą_, _דרוש, lném_, klos_
  { {0x92a9003e,0x26c70584,0x6b4f0058,0x7d04000e}},	//   kułó, zeno_, røge, gkis
  { {0x6b4f00c5,0x7d0d00c6,0x026b0015,0xc2990021}},	// [1650] søge, rhas, ашей_, йках_
  { {0x32b80003,0x657a000e,0x61360031,0x39460c8b}},	//   قدمة_, _otth, dály, elos_
  { {0xceb2000b,0xc1b90048,0x6924001b,0x7d0d0c8c}},	//   _איי_, слех_, rđev, phas
  { {0x657a000e,0x39460c8d,0x6b500c8e,0x3cda0011}},	//   íthe, glos_, väge, _खोले_
  { {0xf8bf0066,0x66e50048,0x69d80248,0xe72e0306}},	//   jném_, зола, åver, ее_
  { {0xef18002d,0xfe710003,0xf8bf0066,0x644f0c8f}},	//   омі_, ردت_, dném_, _izci
  { {0xf8bf000e,0x753b0002,0x39460c90,0x26c70c91}},	//   tnél_, touz, blos_, reno_
  { {0x6136000e,0x6b500052,0x7d760003,0x2f0f0031}},	//   bály, räge, أمير_, _függ_
  { {0x7645004a,0xe49f001e,0x6b500245,0xf8bf0031}},	//   _lyhy, dēļā, säge, rnél_
  { {0x386900c6,0x753b0066,0x13090015,0xf8bf000e}},	//   _agar_, souz, сной_, snél_
  { {0xcb12000b,0x752f0034,0x7af80064,0x673c09df}},	//   גלי_, _ojcz, _dovt, vorj
  { {0x63b6004a,0x80b80011,0x62810c92,0x2fdf0c93}},	//   ytyn, ेजें, sblo, _krug_
  { {0x673c012e,0xb4d70037,0xe7d5002d,0x8f75002d}},	//   torj, ायी_, мірю, дусі
  { {0xa3cf0037,0x3f9e0107,0x4e1f0037,0x3ebe0028}},	//   _वैध_, čtu_, _बधाई_, ýtt_
  { {0xc27a000b,0xdb040061,0xec2d001e,0x386d0584}},	//   _פרקי, quié, šķām_, žera_
  { {0x2cad0036,0x141a0003,0xa99a000b,0x63b6004a}},	//   nged_, ميزة_, _הבקר, ttyn
  { {0x644f0002,0x7d040c94,0xf42a0029,0xd3f40024}},	// [1660] _czci, rkis, _opäť_, кiст
  { {0xe8160044,0x6fdb0009,0xa3dc0011,0x43460048}},	//   _देगा_, _פקיס, डित_, чезв
  { {0x63b60c95,0x4efb01b0,0xd6fb0009,0x7bdb008e}},	//   styn, _הליג, _הפיכ, hvuu
  { {0x2fdf00c5,0x26ca0026,0x63a900b6,0x92a90002}},	//   _brug_, lebo_, kuen, tułó
  { {0xe8160037,0x2efa0052,0x61e1000e,0x39460c96}},	//   _देखा_, _kopf_, _álln, rlos_
  { {0x69c300bd,0x2fdf0c97,0x290b001e,0x7d0b0051}},	//   _opne, _drug_, ībai_, _algs
  { {0x7bc2072d,0xf8bf0025,0x2fdf0227,0x39460420}},	//   _spou, liée_, _erug_, plos_
  { {0xd3a6002d,0xc19b000b,0x25710066,0x2cad0c98}},	//   проп, _לשלי, _dál_, gged_
  { {0x63a901a2,0x7cfc0065,0xcb670001,0x628e00b6}},	//   guen, _sérs, пање_, _kebo
  { {0xa3ab0037,0x877b0009,0xa3180024,0x957c0034}},	//   गढ़_, _לאמי, іжну_, _prąd
  { {0x64460065,0x02b7000b,0x7bdb004a,0x867b0009}},	//   _lyki, הליך_, avuu, _הרבו
  { {0x63a40c99,0x2906008e,0x68e90035,0x63a90c9a}},	//   krin, nkoa_, ķedo, buen
  { {0x63a902d1,0x5f940098,0x63a40058,0xc6e70024}},	//   cuen, ният, jrin, півп
  { {0x7cfc000e,0x628e0c9b,0xf8bf0025,0x63a40923}},	//   _térs, _nebo, diée_, drin
  { {0x3abb000b,0xb2bb000b,0x2906004a,0x3cfb0037}},	//   _המונ, _המור, kkoa_, ैसले_
  { {0xca47000a,0xf8bf0108,0x645d0097,0xb8830030}},	//   _عليه_, fiée_, ýsig, říbu
  { {0xa3d50044,0x889c0093,0x24580047,0xdb00000e}},	// [1670] हिए_, _הבחי, зать_, ermé
  { {0xd25b0015,0x2bb80012,0x26ca0c9c,0x628e0c9d}},	//   бце_, ثافة_, cebo_, _cebo
  { {0x63a40101,0x3f80000d,0x69160066,0x76ba0009}},	//   arin, ţiul_, pšet, _ומתפ
  { {0xf42a0029,0x5fb10011,0x25e00011,0xf8bf0031}},	//   _späť_, _जमाल, किनी_, dnék_
  { {0xf8bf0061,0x98f40003,0xd7f8004c,0x0efa0011}},	//   ciée_, عثما, зуј_, ्सूस_
  { {0x8d750003,0xd00c000b,0x85790015,0x628e01e0}},	//   وابا, מּוֹ, осит_, _gebo
  { {0x69da012e,0x752d00c1,0x20020002,0x30a70063}},	//   _štev, onaz, zyki_, _нрав
  { {0xb4d70037,0x6b4b0052,0x2fdf0052,0xa3d20011}},	//   ाये_, zügl, _trug_, विच_
  { {0x2be00037,0x2cad0979,0x2f0f0052,0x69dc0260}},	//   निया, rged_, _züge_, æren
  { {0x68fb00bd,0x1a050014,0x78bd0028,0xdddc0010}},	//   _houd, дпом, efsv, varž
  { {0x60d60c9e,0x67230c9f,0x6ce70024,0x68fb0ca0}},	//   _paym, minj, _ніде, _koud
  { {0x27e0007d,0x20020002,0x67230ca1,0x68fb008e}},	//   _prin_, tyki_, linj, _joud
  { {0xcaf50012,0x88ba0009,0x68fb0ca2,0xe29907eb}},	//   _يستب, חזרי, _moud, _дал_
  { {0xdb230006,0x20020002,0x672308e2,0x9a690012}},	//   äräi, ryki_, ninj, _بمثل_
  { {0xa3d50037,0x6e430001,0x68e90029,0xdd1c00d9}},	//   हिक_, верз, _oned, _vážn
  { {0x27e000c5,0x752d00c1,0x68fb004a,0x7bc3000d}},	//   _trin_, gnaz, _noud, ănun
  { {0xdb000028,0xe3b9000e,0x59d50037,0xc953000b}},	// [1680] lumá, ntű_, धिकर, _במה_
  { {0xbf660012,0x67560012,0xf8bf0025,0x89790009}},	//   _تدعو, _تخبر, riée_, ַרְצ
  { {0x3ebe0051,0x67230604,0x63a40ca3,0x2906008e}},	//   õttu_, dinj, srin, tkoa_
  { {0xc5f3000b,0x8fa60014,0x58ba0003,0x66030002}},	//   _סדר_, даде, تائج_, dynk
  { {0xc0570024,0x7b090031,0x2906008e,0x628e0ca4}},	//   міш_, ástó, rkoa_, _tebo
  { {0x8f89000b,0xf8bf000e,0xdddc0002,0x0efa0011}},	//   פְנֵ, tnék_, karż, ्सेस_
  { {0xd5af0014,0x82d70009,0x66e3004c,0xdee3004c}},	//   ъс_, _קולג_, тоја, тоји
  { {0x88c60003,0x25a00ba1,0x68fb0ca5,0xed57004c}},	//   _تتسل, čil_, _goud, мој_
  { {0x644e0002,0x6723001b,0xe04308e0,0x7afc0ca6}},	//   ębio, binj, _анти, _kort
  { {0xadba000a,0x68fb0070,0x6ffb0009,0xd7fb0009}},	//   _وهذا_, _zoud, _והמפ, _והמל
  { {0xf2d30093,0x36060003,0x2d9e0066,0x6d490ca7}},	//   דעת_, _تواف, átel_, blea
  { {0xe5060003,0xcb6a0345,0xd1310012,0xc5f30009}},	//   _تبطي, _даде_, امح_, _שדף_
  { {0xbd5b0009,0xdfc60012,0xd467004c,0x6d400ca8}},	//   _וכאש, دي_, _жице_, moma
  { {0x7afc0ca9,0xdc020030,0xa6f80009,0x33170012}},	//   _nort, nčíc, הִֽי, _يزود_
  { {0xa3d60037,0xccfb0001,0x64550002,0x828b0009}},	//   ाटक_, оћа_, ęzie, _וְחֶ
  { {0x57b5002d,0x657a000e,0x6b50006f,0x50670294}},	//   _збит, ítha, väga, _отпа
  { {0xdb0d0149,0x752d00c1,0x3b5507e8,0xf66b0012}},	// [1690] ntaç, rnaz, екар, _وحده_
  { {0x68e9006f,0x68fb0caa,0x93b70009,0xdb0d0018}},	//   _sned, _soud, ולמו_, itaç
  { {0xda0e0037,0x68fb0cab,0x67230604,0xa7380012}},	//   ानित_, _poud, vinj, _تثير_
  { {0x08d40024,0x97d90024,0xe7f30011,0x2d830227}},	//   кція, зьку_, _आपदा_, mpje_
  { {0x26170037,0x547a000b,0x68fb0061,0x28c10037}},	//   _भेजी_, _מטרו, _voud, ष्यि
  { {0x63ad00b6,0xcaa70003,0xe7330003,0x6b500248}},	//   muan, _تصحي, خصص_, lägn
  { {0xe81f0044,0x672306b6,0x20090cac,0xbef80009}},	//   _मेरा_, rinj, šai_, וצגו_
  { {0x6128003a,0x67d50188,0xdfd5003c,0xc5370009}},	//   nılt, _побу, _побы, וָ֖ה_
  { {0x6d5b0c74,0x386d0cad,0x6d490cae,0x63ad0caf}},	//   rmua, _iger_, rlea, nuan
  { {0xa3e00044,0xfaf1000a,0xf772000b,0xfbd2000b}},	//   थित_, اثة_, _עקב_, נתי_
  { {0x3f990028,0xe126024d,0x6d490cb0,0x76480073}},	//   essu_, емни, plea, _gydy
  { {0xdb090149,0x6d4004da,0x63ad0cb1,0x6cd80024}},	//   nteú, coma, kuan, _офіс_
  { {0x13f40014,0x63ad0cb2,0x6d5a01a0,0x6fe20011}},	//   _изця, juan, ïtam, पियं
  { {0x63ad00b6,0x2d9e001b,0x9ad50012,0x98af0034}},	//   duan, štem_, _ستتض, rogę_
  { {0x2f140163,0x63bb0cb3,0x2d8c0061,0x7d090010}},	//   _lägg_, ltun, ède_, okes
  { {0x1da70011,0x621a0009,0xbe630012,0x7c240412}},	//   _गिनत, _מוצק, اهِي, _žiri
  { {0x63bb0cb4,0xe81f0011,0x61e10031,0x7afc0cb5}},	// [16a0] ntun, _मेला_, _állj, _port
  { {0xdbc60005,0x7fd7000b,0x63bb0cb6,0x77bb0009}},	//   _tööa, _טופס_, itun, _צמיח
  { {0xd8da000b,0x7afc03c0,0xceb70009,0xfd4a0048}},	//   ּקְר, _vort, _אפיק_, _нзок_
  { {0x6601004a,0xc329000b,0xe5f70009,0xf1b20009}},	//   älke, זו_, _נזכר_, רסא_
  { {0xc6fa000b,0x43750001,0x6d460cb7,0xd12f0012}},	//   ּלֶך, _ауст, _ikka, حمن_
  { {0x98c5001e,0xcf93000b,0x479b0009,0xd5b00012}},	//   ītās_, נטו_, לינס, لفت_
  { {0x27420066,0x26da009b,0x2d9a0cb8,0xceb30009}},	//   méně_, _mapo_, épe_, איו_
  { {0x91bb000b,0xc5f3000b,0x6d40004a,0x63bb0052}},	//   _ממלי, רדה_, uoma, ftun
  { {0xd4e30047,0x5ce30015,0xdb040061,0xa1570009}},	//   ующи, ующа, triè, _טבלה_
  { {0x2d6e0013,0x6b4f00c5,0x0bb7000b,0xdb0d0017}},	//   _před_, søgn, עלים_, rtaç
  { {0x6d460065,0xdb040061,0xdb0d0017,0xddc80034}},	//   _okka, rriè, staç, _wzdł
  { {0x69b10044,0xcdf70009,0x8d770009,0xdb0d0018}},	//   _अमरी, _רמאי_, _נגדו_, ptaç
  { {0xa2c10037,0xf8bf01cf,0x389b0009,0xe5050012}},	//   र्ड्, rfé_, היכנ, _جبلي
  { {0x5453007c,0x26da00c1,0x32050066,0x39420051}},	//   _світ, _capo_, byly_, aoks_
  { {0x7c870001,0x692b0066,0x39420cb9,0x6b84005e}},	//   еузе, třed, boks_, epig
  { {0x290b0039,0xa4d4002d,0x04c90012,0x799a0034}},	//   ības_, лосі, بوري_, mstw
  { {0x8aa700be,0x8d5b0009,0x113c0009,0x94740012}},	// [16b0] еред, לכלי, _מתהל, ادفا
  { {0x63ad0cba,0xd25b004c,0x5c370009,0x2fc9020d}},	//   ruan, пце_, תרמן_, _ipag_
  { {0xf9930003,0x692b0066,0x63bb000e,0x39780024}},	//   ابط_, před, ztun, есію_
  { {0xd23b000b,0x7d0f000e,0x60dd0cbb,0xc60d0011}},	//   הגבל, _ulcs, ndsm, सनीय_
  { {0xb8c90044,0x69d5003e,0x389c000b,0x2489009b}},	//   _गए_, _wsze, ליאנ, mbam_
  { {0x6d4d03d5,0x6da50662,0x99850012,0xc0540009}},	//   llaa, вика, _للسو, נזס_
  { {0xda090003,0x7d0900ff,0x6d460028,0xdd910012}},	//   _غيره_, tkes, _ykka, جوع_
  { {0x386d0058,0x6d4d006e,0x63bb0cbc,0x60dd0040}},	//   _uger_, nlaa, ttun, jdsm
  { {0x7d090cbd,0xdb00019a,0x7d03000d,0xdcfc001e}},	//   rkes, kumä, _însu, nprā
  { {0xf8aa0044,0x613d01c4,0x2a030029,0x49b90012}},	//   कल्प, mély, ačať_, واجد_
  { {0x6d4d03fb,0x2fc9002c,0xc27a000b,0x799a0227}},	//   klaa, _apag_, ורתי, gstw
  { {0x6d5a0010,0x60db0cbe,0xbcfb0018,0x9c870012}},	//   įtak, _jaum, _fiéi, _أشاه
  { {0x9d1a000b,0x644b0051,0x26da0017,0x7d06004a}},	//   _קונט, ügil, _papo_, ökse
  { {0xdb040108,0xe1f10003,0x656b0cbf,0x4ed50686}},	//   prié, _نسب_, _high, люст
  { {0xceb2015a,0x7e230001,0xcb12000b,0xc1060012}},	//   יים_, адрж, _דלג_, _لوثي
  { {0x657c000e,0xc172000b,0x68ed0032,0x61280060}},	//   _érhe, _דחה_, _gnad, rıls
  { {0x656b0036,0x26da0010,0x036a0048,0xf8bf0031}},	// [16c0] _migh, _tapo_, диак_, tnév_
  { {0x656b0cc0,0x613d000e,0x29000051,0x7d1e000e}},	//   _ligh, dély, _hoia_, épsz
  { {0x63a9008b,0x644b007a,0xdb1d0058,0x60db0cc1}},	//   hren, _lygi, _opsæ, _baum
  { {0xdcfc001e,0x6b9b0051,0xdcfe001e,0x656b0cc2}},	//   bprā, ksug, īvīb, _nigh
  { {0xab660002,0xa0670001,0xdefa003c,0x6843003c}},	//   _pożą, ваца_, дый_, анца
  { {0xa3c10044,0x501b000b,0xde58002d,0x799a0002}},	//   ूबर_, וונו, налі_, ystw
  { {0xdb040164,0x5db30012,0x63a90cc3,0x2be00011}},	//   stió, لإير, eren, निवा
  { {0x63a90cc4,0x6d590034,0x7d03004b,0xd37a0365}},	//   fren, _chwa, _înst, мчо_
  { {0x63a90cc5,0x50460695,0x799a0034,0xd8770012}},	//   gren, _реаб, wstw, _شملت_
  { {0x86ea0003,0x656b002a,0x68ed0066,0x51f8002d}},	//   _تعرف_, _eigh, _snad, еною_
  { {0x656b002a,0x63a901b7,0x7c2d0097,0x87170009}},	//   _figh, aren, _þarn, _שקבע_
  { {0x94260047,0xe8e0001a,0x799a0120,0x6e170012}},	//   _имее, _trời_, rstw, _جيمس_
  { {0x692b0013,0xf8bf0164,0xc7f80024,0xdb0003bd}},	//   třeb, bién_, вняє_, tumä
  { {0x9f600028,0xf7730009,0x19ba0012,0xf8bf01e3}},	//   ærðu_, יקש_, _قطعة_, cién_
  { {0xf628002d,0x7e28002d,0xdb00006f,0xce940048}},	//   віти_, віта_, rumä, расъ
  { {0x1bd50048,0xfe370009,0x2d580198,0x69d80060}},	//   лобя, דרלי_, вись_, _isve
  { {0x5455059a,0xfbd00003,0x6d4d0cc6,0x24890cc7}},	// [16d0] уват, يتك_, rlaa, rbam_
  { {0xf1b60037,0xe3b00003,0x6d4d0643,0x60080009}},	//   _अमान, ترف_, slaa, _יִתְ
  { {0x60db0101,0x2578000e,0x6d4d0114,0x41740012}},	//   _paum, _nél_, plaa, لانس
  { {0x30150447,0xf9900012,0xe0df00b8,0xf8bf0025}},	//   лдер, تبك_, ndò_, mnés_
  { {0xe8d9008a,0x251a000b,0x443f001a,0xfd56000b}},	//   _chỉ_, _נושא, _âu_, _תשרי_
  { {0x69ca0052,0x656b0cc8,0x8c1a0009,0xa3e00011}},	//   _opfe, _sigh, _טורי, थिर_
  { {0x2578000f,0xddda000e,0xf8bf0061,0x7d0d0a60}},	//   _cél_, _betű, nnés_, okas
  { {0x3ea9007d,0x25780cc9,0x76580009,0xd6580009}},	//   şat_, _dél_, כבוד_, כיות_
  { {0xdc3100a2,0xfc050015,0xa7740024,0x69ca0032}},	//   _düğm, уппо, _влуч, _apfe
  { {0xe1f90047,0x2578000e,0x63a90cca,0x692b0030}},	//   его_, _fél_, rren, yřec
  { {0x9afa000b,0xa2ca0037,0x656b0ccb,0xaaab0011}},	//   תפתח, _सॉफ्, _tigh, _चयनक
  { {0xc2360009,0x3a360009,0xdb1b0025,0xcd2b0012}},	//   טרתו_, טרתם_, itué, _غسان_
  { {0x60d6000b,0xc2c50012,0x2900004b,0x6f010ccc}},	//   נושא_, _ميشي, _voia_, _kolc
  { {0x6295022d,0xa8560009,0x90560009,0xe4500012}},	//   _nezo, טירה_, טברו_, _بضم_
  { {0x7d0d0ccd,0xf8bf0061,0xdd1d0066,0xad5a0055}},	//   fkas, gnés_, lářs, ерах_
  { {0x7d0d0a60,0xa2c10011,0xd24e0012,0x98a20034}},	//   gkas, र्स्, _عني_, ynkę_
  { {0x62950369,0x38bd000e,0xd117000b,0x6eac0011}},	// [16e0] _bezo, záró_, _תקפה_, _जयपु
  { {0x7d0d0cce,0x8a3a0015,0xaf0a0003,0x070a0012}},	//   akas, няет_, _أقدم_, _أيدي_
  { {0xd24f000a,0x88860014,0xdebb0009,0xb05b0032}},	//   كنك_, глеж, _אמיל, nfän
  { {0x7aeb001e,0xc0960012,0xcb090009,0xa3e30011}},	//   ēgta, اجات, הל_, कटाप_
  { {0xa3d2015f,0xdd1d0066,0x316d0164,0x889b0009}},	//   _हैं_, jářs, _diez_, תבני
  { {0xa8570093,0x05b40003,0xdd1d0066,0x629504a3}},	//   ניסה_, لمتح, dářs, _gezo
  { {0x645d014d,0xceb30093,0xdb1b0061,0x6b820027}},	//   ýsin, ציה_, ctué, _stog
  { {0xd1320012,0x5c740306,0x25780097,0x386d001b}},	//   _امر_, шлит, _vél_, žeri_
  { {0x28dd0037,0xa2c10011,0x46b60012,0xdb040018}},	//   _नोटि, र्व्, _محاس, guiç
  { {0xa3d20011,0x8bd70009,0x2d96004c,0x03d70009}},	//   _हैः_, נויו_, _брдс, נוים_
  { {0xaac60044,0x4ac60037,0xd2500003,0x22f70009}},	//   र्यक, र्यव, تند_, אזין_
  { {0xdb040017,0x644b0051,0xf6530009,0x63e60012}},	//   buiç, ügik, _הצע_, _مستك
  { {0xe8d90020,0xa3b30044,0x6f01003a,0x6d440073}},	//   _giờ_, जूद_, _yolc, čiad
  { {0x8c1b000b,0x3dd20002,0x74330024,0x3dda0032}},	//   _אודי, ływu_, _уніф, _bspw_
  { {0x7d020176,0x627b000b,0x05d50011,0xa3dc0011}},	//   _koos, _אנונ, _डैशब, डिक_
  { {0x9983000a,0xf1a90044,0x23e00037,0xa77500b3}},	//   _اليو, _कितन, निंद, _клич
  { {0x89340003,0x7d0d0ccf,0x7b770012,0x2aab004c}},	// [16f0] _دعوا, rkas, اطرا, етео_
  { {0x212b008b,0x6eb20044,0x26de0cd0,0x7d0d0cd1}},	//   lich_, _जाएँ, _nato_, skas
  { {0xe8d90081,0x212b0034,0x7d0d0cd2,0x629509ef}},	//   _nhị_, oich_, pkas, _vezo
  { {0x6f01008b,0x3264059a,0xd0110003,0xc5fa0009}},	//   _solc, стув, يلا_, _ספרט
  { {0xc49a0009,0xdc9a0009,0x6b4b0032,0x1869004c}},	//   _בשרת, _שישל, fügt, њали_
  { {0xaec4007c,0x212b002a,0x945d0002,0x7ceb006f}},	//   йбіл, hich_, zeńs, _förä
  { {0x212b003e,0x41e4002d,0xe8d9001a,0x9f440066}},	//   kich_, _літа, _chị_, ímé_
  { {0xdb040017,0x212b0107,0x63f50003,0x63ad0cd3}},	//   tuiç, jich_, لأخر, oran
  { {0x9ed90098,0x26de0017,0x7529001e,0x92f50024}},	//   _имат_, _fato_, riez, ачні
  { {0x0325002d,0x13090015,0xdb040017,0x63ad0cd4}},	//   рдон, тной_, ruiç, iran
  { {0xcb14000b,0x75290cd5,0xc1060012,0x63ad0cd6}},	//   מלץ_, piez, لودي, hran
  { {0x656f032b,0x95670098,0x3e55001a,0x61e1000e}},	//   _nich, _създ, _ít_, _állu
  { {0x6446005e,0x4ac60011,0x248d0018,0x6d4b0035}},	//   ükit, र्डव, mbem_, _ikga
  { {0xb05b0cd7,0x8c1a0009,0x98630012,0x6b890cd8}},	//   pfän, _בוני, زُّه, mpeg
  { {0x98a2001e,0x27e90cd9,0xf4960055,0xad660012}},	//   aikā_, _eran_, ираю, لاره
  { {0x7de0000f,0x212b0026,0x2a3a000b,0x656f0002}},	//   lásá, cich_, _בעצמ, _cich
  { {0x8b260015,0x03260479,0xb6020030,0xb05b0032}},	// [1700] адае, адан, _řádn, nfäl
  { {0x305b000b,0x9f9b000b,0x4f9b000b,0x905b0009}},	//   _בדפד, _שסיפ, _שביצ, _בכפת
  { {0x656f0cda,0xbcfb0025,0x69c10cdb,0xa2bd0011}},	//   _fich, _piét, ntle, _शान्
  { {0x2ba60044,0xe1650003,0x3fe60001,0xb05b006f}},	//   _खिला, مدني, ижев, kfäl
  { {0x69c10051,0xa81a0003,0xb87b01e3,0x18360012}},	//   htle, ختار_, ndía, جراح
  { {0xa3cf0037,0x656f0070,0xfda60001,0xa857000b}},	//   _वैट_, _zich, ајим, בינה_
  { {0x7de0000f,0x96f70012,0x692b0030,0x60c4005e}},	//   dásá, شعور_, dřen, õims
  { {0xd94305fb,0x5bb8010c,0x44f4072b,0x1da70011}},	//   _деси, глия_, спис, _गिरत
  { {0x69c1003e,0xbcfb000e,0x26de0cdc,0xaac60011}},	//   etle, _kiér, _tato_, र्थक
  { {0xe8d90020,0x5b140075,0xada6002d,0x9b430003}},	//   _thị_, смот, _важл, ينيو
  { {0x29040065,0xd25a0014,0xbcfb0bb6,0x212b0cdd}},	//   _koma_, ъци_, _miér, tich_
  { {0x64460051,0x2d570060,0xfc660048,0xddd40034}},	//   ükis, eçen_, _кълн, łaśn
  { {0xa3dc0037,0x2f14006f,0x656f0cde,0x212b0cdf}},	//   डिओ_, _säga_, _rich, rich_
  { {0x656f008b,0x69dc009b,0x69ce0c62,0x8cc90011}},	//   _sich, _osre, _opbe, ह्नो
  { {0x2d8500bd,0x35e4002d,0x257c0066,0x7afc0028}},	//   ële_, оцтв, _cíl_, örtu
  { {0x2f140005,0xf993000b,0x79690002,0x5c7505f0}},	//   _väga_, _ורק_, _oświ, слат
  { {0xa3dc0044,0xd3710003,0xdc8b0009,0x113c0009}},	// [1710] डिट_, سها_, דְבָ, _שתחל
  { {0xf1da0044,0x656f008b,0xb9da0011,0x8c1b0009}},	//   _बनान, _wich, _बनाऐ, דומי
  { {0x644f0002,0xc692000b,0xf8750003,0x3f8b009b}},	//   _wyci, _מאי_, مهاج, lpcu_
  { {0x7de0000f,0xc879003a,0x69130060,0xf1a90011}},	//   zásá, _başa_, _eçen, _किसन
  { {0x27e90164,0x68e0002c,0x80a80024,0x6b5d0025}},	//   ían_, _damd, рвів_, lège
  { {0x2d950046,0x629804c7,0xc724002d,0x7bdd0ce0}},	//   брис, _nevo, одій, _issu
  { {0xe7f3015f,0x692b0013,0x63a20106,0x7de0000e}},	//   _आपका_, vřen, _avon, vásá
  { {0xce38000b,0xdb090051,0x8638000b,0x5bc50003}},	//   יאות_, steü, ירוב_, مقبل
  { {0x7de0000f,0x692b0066,0xa3d20037,0x62980832}},	//   tásá, třen, हौल_, _bevo
  { {0xf770000a,0xe9d9027f,0xb05b08ec,0xa2ca0011}},	//   _قال_, гко_, rfäl, स्प्
  { {0x7c3b0065,0xa2aa0037,0x7de0000e,0x6e450003}},	//   _þurf, _फ़ार्, rásá, _انضم
  { {0x89360003,0xcdf40003,0x79690002,0x7de0000e}},	//   إعدا, _بأكث, _yświ, sásá
  { {0x4385000a,0xbb850003,0x63850001,0xcc760009}},	//   _التق, _التي, _угла, _הגנת_
  { {0x629800bd,0xc6920009,0xe2990048,0x68e20764}},	//   _gevo, ּאן_, _сак_, zdod
  { {0xba9a0093,0x321e0002,0x7d1b0051,0x057a0003}},	//   _עסקי, czty_, ohus, امرة_
  { {0x31a300a2,0x61430232,0x6564020d,0x82340012}},	//   mız_, _неща, umih, _برها
  { {0xe2920003,0xe45a0ce1,0xed570367,0x29040ce2}},	// [1720] كذا_, ужа_, сот_, _roma_
  { {0xda660003,0x57fb000b,0x7ed5002d,0x62810ce3}},	//   ماضي, _עליו, _діюч, nclo
  { {0x31a300a1,0xd36f0003,0xe0df0054,0x16770009}},	//   nız_, رهم_, clòs_, _לגיל_
  { {0xc8b60003,0xd83f009b,0x752d0ce4,0xa9670048}},	//   إصاب, šček_, ciaz, биха_
  { {0x765a0034,0x68e20035,0x26130081,0x90970024}},	//   _szty, rdod, ẹo_, світ_
  { {0xd0070046,0x201a0002,0x47330024,0x07080012}},	//   сеље_, ąpi_, пніс, شيعي_
  { {0x76a9002d,0x63a20028,0x69dc0027,0x6d410ce5}},	//   ртів_, _svon, _usre, élag
  { {0xc5f3000b,0x25610028,0x629e0ce6,0x7644003a}},	//   לדו_, hólf_, lapo, şiyo
  { {0x2613001a,0x7d060010,0x97bd0024,0x1eaa0012}},	//   ạo_, _moks, _архi, _ماضي_
  { {0x5a340014,0x44200ce7,0xbea30959,0x8c1b0009}},	//   жнот, izi_, _наук, טופי
  { {0x60f900bc,0x14ca0047,0x9cca0047,0x8afb01b0}},	//   ання_, _были_, _была_, אליז
  { {0x54e50012,0xe8d90081,0xbce50012,0x32570009}},	//   _وسنق, _thọ_, _وأنو, מסים_
  { {0x395f0039,0x6ebf0037,0x321e0002,0x4420000e}},	//   ķus_, ल्कु, szty_, jzi_
  { {0x3bbb000b,0x98bd0002,0x44200ce8,0x421a0012}},	//   _עמוד, mową_, dzi_, _مزعج_
  { {0x91860003,0x98bd0002,0x7d060ce9,0x7588003c}},	//   _اجتم, lową_, _boks, йств_
  { {0xf237000b,0x5d55002d,0xa3e50011,0xaac60011}},	//   _לרוץ_, ікат, पटल_, र्सक
  { {0x93970003,0xba99002d,0x2d58027f,0x1b7b0012}},	// [1730] إجرا, иває_, сить_, اصرة_
  { {0x394b0054,0x692b0066,0x9f530034,0x20d30081}},	//   locs_, zřel, ądów_, _ải_
  { {0xe5c700db,0x7bc401a0,0xdb0d0097,0x555905d8}},	//   _успо, atiu, ptaþ, _ваня_
  { {0x7644003a,0x98bd0002,0x905504ad,0xe1f00012}},	//   ğiyl, kową_, овец, عسل_
  { {0x493c000b,0x7bc40cea,0x692b0030,0x98bd0034}},	//   נגדו, ctiu, vřel, jową_
  { {0xdb16001a,0x31a3003a,0x98bd0002,0xa8580009}},	//   huyê, yız_, dową_, ציגה_
  { {0xe8d90020,0x395f002a,0x7d06003a,0x4519022a}},	//   _nhỏ_, _thus_, _yoks, иция_
  { {0x2a7b0010,0xdb850048,0xddc80034,0x394b01a0}},	//   šybą_, огии, _bydł, jocs_
  { {0xfc31000a,0x02c60037,0x6b8d0070,0x4ac60037}},	//   بحث_, र्वभ, npag, र्वव
  { {0xf1c30066,0xe2990001,0x693c00f1,0x69c504a3}},	//   _naší_, шао_, nčen, othe
  { {0x3f8900ec,0x442001a2,0x69c50ceb,0x3e350012}},	//   _atau_, zzi_, nthe, _بفار
  { {0xe56e007c,0xc6890093,0x31a300a2,0x6b8d0070}},	//   _із_, _יא_, rız_, kpag
  { {0x31a3003a,0xb05b0032,0x98bd0034,0x69c5016a}},	//   sız_, nfäh, cową_, hthe
  { {0x60cd0051,0x7d06000e,0x9f440018,0x6b8d0227}},	//   _ebam, _soks, _irmã_, dpag
  { {0x4da90009,0x75d60012,0x6b8d0cec,0xec9a004c}},	//   יֹּ֣, غيرا, epag, итај_
  { {0x7ae301ad,0x44200054,0x92580012,0xa01b0245}},	//   _hant, tzi_, _اشهر_, rbör
  { {0x629e0101,0x44260020,0x73060014,0x7d060623}},	// [1740] tapo, ào_, опаз, _voks
  { {0x78a90ced,0x7ae30cee,0x44200cef,0x29020604}},	//   _adev, _jant, rzi_, ljka_
  { {0x629e004a,0x4420000e,0x75460014,0x6b8d002c}},	//   rapo, szi_, _мноз, apag
  { {0x4fea0014,0xf4b60003,0x290204d2,0x6b8d0cf0}},	//   имен_, _بإدخ, njka_, bpag
  { {0x7e9a000a,0x2ca00051,0xdb16004a,0x493b0009}},	//   لنشر_, maid_, ttyä, סגנו
  { {0xf4130093,0x291d00b6,0x7ae30cf1,0xe7b20011}},	//   _חפש_, ahwa_, _nant, _जिनप
  { {0x629c0039,0xd5b00003,0x29190071,0x27ed0cf2}},	//   _iero, رفة_, ūrai_, _eren_
  { {0x7ae300bd,0x4ac60037,0x98bd0002,0x1d070001}},	//   _aant, र्रव, tową_, жећи_
  { {0xa2ca0037,0x7ae30807,0xa2c10011,0xdddc001b}},	//   स्थ्, _bant, र्क्, jbrž
  { {0xbb470012,0x98bd0034,0xddc9004b,0x26d80cf3}},	//   يلين_, rową_, înţe, jero_
  { {0xdcfc0010,0x98bd0002,0x2ca00051,0xc27b0009}},	//   sprę, sową_, kaid_, יריי
  { {0x2ca00cf4,0xa2ca0037,0x7c060012,0x2d8e0032}},	//   jaid_, स्त्, _وبشك, mpfe_
  { {0xdb040017,0x5f940014,0xb4b60037,0x64360012}},	//   criç, мият, जली_, _براء
  { {0xa3d70037,0xc7b30009,0x7ae30cf5,0x629c0cf6}},	//   ाबर_, ובש_, _gant, _nero
  { {0xf1c30013,0xfb1b0093,0xc1c90037,0xd49b0c1e}},	//   _vaší_, _דוגמ, _रहेग, ира_
  { {0x692b0066,0x68e4001e,0x98a20010,0x6b4f0058}},	//   zřej, _gaid, tiką_, søgt
  { {0x2bb80003,0x26d800c1,0x0ca80014,0xfc300012}},	// [1750] قالة_, bero_, ютри_, نحك_
  { {0x660e0066,0xb87b0066,0x2fc60058,0x693c0584}},	//   ínká, zdíl, dtog_, učen
  { {0x6b8d0070,0x63a40cf7,0xa2bd0011,0xe7e30011}},	//   spag, asin, _शास्, खिका_
  { {0x6f1a000d,0x69c50cf8,0x644b0051,0x27ed0054}},	//   _altc, rthe, ügis, _pren_
  { {0x6cfa015a,0xb4fa000b,0xe4fa000b,0xdb090017}},	//   _הפרס, _הפרי, _הפרש, queç
  { {0x27e40097,0xb05b0032,0x6d4d008e,0xd7ee0012}},	//   æmni_, rfäh, loaa, اكو_
  { {0xb05b0052,0x6d440cf9,0xf5ab0009,0x20d70012}},	//   sfäh, čian, ׁבַּ, _وترج
  { {0xd4d9007c,0xa63c0009,0xdb040018,0xbe3c0009}},	//   ські_, יגור, triç, יעות
  { {0x27ed0070,0x692b0066,0x26c10164,0xe3b10003}},	//   _uren_, přej, _ocho_, ررة_
  { {0x68e40289,0xb436000b,0x441c0009,0xb87b0030}},	//   _said, לָיו_, יוחס, sdíl
  { {0xfc460065,0x63a4003a,0xdb0d0164,0xc0490009}},	//   _þíns_, zsin, ntañ, _עז_
  { {0xef190002,0x7ae30a5f,0x26c10017,0x2ee50cfa}},	//   _duże_, _want, _acho_, _half_
  { {0x2ca00005,0x645d0051,0xd47a0009,0x98560024}},	//   vaid_, üsid, _האנל, ятош
  { {0x65690052,0xdb1c000e,0x9af50012,0x69240031}},	//   lmeh, özün, _ركعت, tőes
  { {0x8afa000b,0xdb0d0061,0x2ca0000e,0x6b4f0058}},	//   _להסי, traî, taid_, søgs
  { {0x629c0cfb,0xdb000002,0x26d80b69,0xaa560012}},	//   _sero, bumó, sero_, _عليا_
  { {0xe1650003,0x1d070294,0x2ca0021b,0x629c0cfc}},	// [1760] _تدوي, чети_, raid_, _pero
  { {0x63a400a1,0x6b500248,0x98bd0034,0xe29a0cfd}},	//   rsin, vägs, mowę_, саж_
  { {0x1e97000b,0x8e7b000b,0xf67b000b,0x63a40cfe}},	//   _מכיל_, _לניה, _לאימ, ssin
  { {0xd5fb0009,0xfd120012,0xf79a0012,0xa9670048}},	//   _הפטר, _أجد_, منصب_, пиха_
  { {0xd5b10020,0x6f08003e,0x4abd0037,0x28c10037}},	//   ớc_, _podc, ्भाव, ष्टि
  { {0xdbc70051,0x7d040033,0xb8e30011,0x6b500032}},	//   tööt, ljis, _एफ़_, rägs
  { {0x39810149,0xdb04006f,0xc1da0011,0x2fc6001b}},	//   _nós_, rriä, _बनेग, stog_
  { {0x718b000b,0xdce40027,0x7d160cff,0xc0e304ac}},	//   _לְמַ, kmič, nkys, _поск
  { {0xdb0d0028,0xd9430103,0x9cd70009,0x61430048}},	//   otað, _чети, לוקה_, _чета
  { {0xfbcf0003,0xef170015,0xdb0d0028,0x65690029}},	//   اتي_, _ему_, ntað, ameh
  { {0x656200b6,0x98a20911,0x75960012,0xa2c10011}},	//   _thoh, likę_, _رجاء, र्ट्
  { {0x2d57003a,0x3a37000b,0x7d7b0009,0x7aeb0035}},	//   rçek_, לרים_, _הנאו, ēgti
  { {0x50640046,0xe9070009,0xdb0d0097,0xdb1b0018}},	//   етра, הֶם֙_, ktað, stuá
  { {0x05770012,0x8d770012,0x941e0060,0x7c24017b}},	//   كارد, كارا, ığıy, dzir
  { {0x9757000b,0x66140066,0x9f440030,0xdb090248}},	//   פילו_, _čeká, ímá_, tteö
  { {0x2a3b000b,0x693c0027,0x91bb000b,0x9a3b000b}},	//   _לעומ, učel, _המהי, _לתוק
  { {0x7f840003,0x98650012,0xdb0d0018,0x50fa0009}},	// [1770] _كلين, _تُظه, nuaç, _וִיד
  { {0x501c000b,0xc3540001,0xf8380009,0x7d040d00}},	//   _לוחו, екуј, _מנחת_, ajis
  { {0xdb040061,0x69c80d01,0x99d90012,0xceb20009}},	//   isiè, ntde, تواء_, _ביי_
  { {0x98a20002,0xf8bf0061,0x31140024,0x62850d02}},	//   fikę_, ngé_, нфіс, scho
  { {0xdb0d0164,0xa8780003,0xe7a8002d,0xe72e035c}},	//   stañ, أحمر_, звіл_, ве_
  { {0x8ae4007c,0x3ce90051,0x7528001e,0x69c8013f}},	//   _післ, ldav_, īdze, ktde
  { {0xf2d2000b,0x78ad0d03,0xcb120009,0x45d2004c}},	//   _שעל_, _odav, _ילך_, војс
  { {0x7ae7000e,0xfdf8000b,0x3ce90051,0x838901b6}},	//   _hajt, לצות_, ndav_, обив_
  { {0x1c45002d,0xfc310003,0x656900a8,0x92b50012}},	//   ьним, ضحة_, rmeh, وحدا
  { {0xc9a90015,0x39810017,0xab290024,0x89a907e6}},	//   овое_, _pós_, іона_, оков_
  { {0x46150003,0xb2090014,0xd9460210,0xcb120009}},	//   _توار, ценз_, дени, דלי_
  { {0xcea90093,0x39810d04,0x07a60048,0xf8bf0d05}},	//   _כי_, _vós_, мамн, diés_
  { {0xbcfb0061,0x200b01a0,0xd9aa0011,0xdb0d0018}},	//   _phén, _àcid_, _चट्ट, cuaç
  { {0xab64002d,0xf8bf0061,0x4b7a0009,0x7ae70d06}},	//   _звіл, fiés_, _ואסו, _najt
  { {0xbb520003,0x28c60037,0xc5d50024,0xf8bf0025}},	//   _جنوب, _वापि, ніть, giés_
  { {0x2cbf0005,0xa99a0009,0x2d530018,0x7d0b0031}},	//   ngud_, _ובקר, mães_, _jogs
  { {0x3ce60026,0x7bc90d07,0x4e7a0012,0x5f2a003c}},	// [1780] ľov_, nteu, _وحدد_, _моим_
  { {0xe8d9008a,0xa3cf0044,0x446302ac,0xe7b70009}},	//   _thể_, _शहर_, твув, _קהיר_
  { {0xf8bf0d08,0xa50a0014,0x4efb01b0,0xaacf0011}},	//   ciés_, _дена_, _והיו, त्यक
  { {0xdb0d0065,0xda650003,0x693c0029,0x44240034}},	//   stað, رالي, mček, yzm_
  { {0x31da0037,0x97da0003,0x98a30406,0x10a30829}},	//   _बन्ध, تظار_, тиче, тичн
  { {0x6d440010,0x66e30001,0x758a00fa,0xdee3004c}},	//   čiam, воља, осив_, вољи
  { {0x7d0b00c5,0xbd870012,0xf1dd0011,0xf5360009}},	//   _bogs, ونون_, _फैलन, ֽנִי_
  { {0xdb0d0017,0x7ae70d09,0xfbaa003c,0xe0d70557}},	//   tuaç, _zajt, отой_, _овс_
  { {0xaec60001,0x33740001,0x693c0030,0x4d730012}},	//   _обал, нгир, yčej, خطور
  { {0x60c40017,0x98a00002,0x2545001e,0x764d003a}},	//   _acim, _imię_, vēle_, şaya
  { {0xe1350047,0x02b7007e,0x69350015,0x19590015}},	//   енны, והים_, енну, заны_
  { {0xdb040061,0x2d850030,0x9da50012,0x26dc0d0a}},	//   ssiè, ílem_, _أصله, levo_
  { {0x7bc90106,0xf8bf0061,0xb5a00001,0xdbd80028}},	//   cteu, rgé_, _енcи, _gæða
  { {0xf8bf0025,0xdb0d00ce,0x272d0c85,0x000000c4}},	//   tiés_, traí, ožni_,
  { {0xb9e6002d,0x3abb000b,0x7ae70102,0xb2bb0009}},	//   _ціли, _ומונ, _rajt, _ומור
  { {0x8c3d003a,0xf8bf0061,0x7ae70d0b,0x04c90012}},	//   laşa, riés_, _sajt, ثوري_
  { {0x3f670047,0x24580015,0xbbb9002d,0x291909d4}},	// [1790] _отоб, дать_, ягає_, ūras_
  { {0xbcfb0061,0xae1e0037,0x60dd0d0c,0xc3340009}},	//   _théo, बनान_, lesm, ׂוּ_
  { {0x6735009b,0x7ac40014,0x85750015,0x26dc080b}},	//   mizj, ъсте, _плох, devo_
  { {0x25f40037,0x60dd02dd,0x67350972,0xdb1d07ef}},	//   ्मनी_, nesm, lizj, _ppsó
  { {0xf8bf0061,0x9f35002d,0x24b60009,0x7aca0011}},	//   chée_, неді, _אהרן_, _सॉकॅ
  { {0x2f180047,0x8c180003,0x539a0009,0x38180009}},	//   мочь_, _غيّر_, _מישו, וקדם_
  { {0xa3e70037,0x9694002d,0x6d480061,0xc3320009}},	//   भिक_, тріш, édag, _עול_
  { {0x3ea10051,0x248900b6,0xeb990015,0xef190002}},	//   _leht_, ncam_, пии_, _duża_
  { {0x24890d0d,0x7f840012,0x2cbf005e,0x4ac60011}},	//   icam_, _للقن, rgud_, र्कव
  { {0x07f80003,0xa205046e,0x60c40d0e,0x7bc906e2}},	//   _ترفع_, епод, _scim, rteu
  { {0xaf340003,0x63bb0038,0xba9a0009,0x68fb0d0f}},	//   _شركت, suun, הסתי, _knud
  { {0x4acf0037,0xaacf0037,0x7bc90061,0x628a00d4}},	//   स्तव, स्तक, pteu, _effo
  { {0x395e001e,0xdce10073,0xbcfb0d10,0x38550048}},	//   ēts_, _sulė, _chém, върс
  { {0xdb090054,0x656d0d11,0x83b60009,0x63a90d12}},	//   dreç, emah, _נפצע_, msen
  { {0xceb20093,0xfb1a000b,0xc3320009,0x61360035}},	//   טים_, _מוסמ, _גוג_, ašla
  { {0x63b6003e,0xe7b60012,0xd5b10081,0x92a90034}},	//   tryn, _كمعد, ớn_, ysłó
  { {0xc2b60001,0x63a90d13,0xa93b0009,0xe3ba0148}},	// [17a0] ељењ, nsen, _מתקפ, яба_
  { {0x3ea10052,0x20ec0081,0x656d020d,0x2489016d}},	//   _geht_, _ới_, amah, acam_
  { {0x217a0003,0x569b000b,0xfe720012,0xda0f0011}},	//   سحاب_, _מייצ, _حدة_, ाहित_
  { {0xc7c6005c,0x98ab000d,0x63a90d14,0xf8bf0025}},	//   ески, mică_, ksen, phée_
  { {0x98ab000d,0x41a60037,0xd47b0009,0x2906008e}},	//   lică_, _कौनस, _מאכל, rjoa_
  { {0x7bcb000b,0x6d5b00b6,0x26dc0164,0xeb91000b}},	//   _מֶלֶ, elua, uevo_, _כָל_
  { {0x98ab007d,0xe357000b,0xc693000b,0x78a60027}},	//   nică_, _נשלח_, נאה_, kakv
  { {0x44f40001,0x63a90040,0xdb09008e,0x78a60097}},	//   тпис, fsen, hreä, jakv
  { {0xcf4606e6,0x64590002,0x8c3d0b47,0x96960024}},	//   _знай, _cywi, taşa, _зреш
  { {0x6d5b004a,0x64590002,0x212000b6,0xbbd30012}},	//   alua, _dywi, _alih_, ازيغ
  { {0x225800c5,0x75d30003,0x60dd0d15,0x7e820035}},	//   ærk_, _ميلا, tesm, ātpā
  { {0x98ab000d,0x67350002,0x28c60011,0x6d5b0c4d}},	//   dică_, wizj, _वाणि, clua
  { {0xd7fb0046,0xac970003,0xc879000d,0x63a9000e}},	//   чун_, _أنها_, _paşi_, csen
  { {0x98ab007d,0xabfb0009,0xc0510009,0x2919020d}},	//   fică_, _מהדר, ׁ֖ם_, sksa_
  { {0xa01b000f,0xaa570d16,0x51f30003,0x98ab000d}},	//   nböz, _كلها_, _مسير, gică_
  { {0xbcfb0061,0x7aea039d,0x4a5b000b,0x5d780015}},	//   _thém, _haft, _מדוו, ейся_
  { {0x7ff70003,0x656d04b0,0x5c750014,0x24890d17}},	// [17b0] _أسعا, rmah, тлат, rcam_
  { {0xdbc70005,0x883c0009,0x24890018,0x3dd20034}},	//   _tööp, _מתחו, scam_, ływy_
  { {0xc333000b,0x6b8200c1,0x6595002d,0x9758000b}},	//   נוע_, _luog, _шану, _איזו_
  { {0x63a9003a,0x5dc80009,0x85960009,0x75240d18}},	//   ysen, _אֶשְ, _שדרג_, chiz
  { {0x34dd0037,0x3d040037,0x6b820010,0x2571001b}},	//   _मसौद, वाने_, _nuog, _ušli_
  { {0x141a0009,0x8f9c0009,0x45d50048,0x60c20073}},	//   _חושב, לידי, вцит, agom
  { {0x40950003,0xd7580003,0xb8950012,0x1ea80012}},	//   _للأر, رجها_, _للأع, راوي_
  { {0xdb1c000e,0xa5f60001,0x5dfc000b,0x63a90d19}},	//   özön, ђењу_, לפונ, tsen
  { {0x777a03eb,0x44290d1a,0x98ab000d,0x6d5b00b6}},	//   _fitx, nza_, zică_, rlua
  { {0x63a90d1b,0x6d5b0097,0x8e840012,0x692b0030}},	//   rsen, slua, _ملكه, zřet
  { {0x2726001a,0x7aea00b6,0x64590002,0x7bcd004a}},	//   _hông_, _daft, _wywi, htau
  { {0x2726001a,0xe8f700b3,0xcd960009,0x6d680012}},	//   _kông_, влю_, _ידעת_, _كملف_
  { {0x692b0066,0x7d090027,0xb87b0066,0x74290012}},	//   vřet, mjes, zdív, _تكشف_
  { {0x81bc0039,0x98ab007d,0xb464002d,0xb05b006f}},	//   izēj, tică_, _скіл, tfär
  { {0xed5a08b0,0x2d9e0061,0x6da30014,0x7d0f000e}},	//   дов_, ète_, иира, _bocs
  { {0x98ab000d,0x693c09d2,0x7d090d1c,0xe4da0012}},	//   rică_, lčev, njes, بورت_
  { {0xa05a0003,0x2726001a,0xb05b02f1,0xed570021}},	// [17c0] _تؤثر_, _nông_, sfär, тот_
  { {0x3ea70d1d,0x7d1b0051,0x81bc001e,0x6d440010}},	//   jant_, hkus, dzēj, čiai
  { {0x18a60075,0x99f5002d,0x7d1b0d1e,0x636b0052}},	//   ваем, ляці, kkus, künf
  { {0x60c20010,0x6ec40037,0x67210154,0x9c660012}},	//   ugom, _राहु, _allj, _لهجو
  { {0x2726008a,0x4429003e,0x2ba90044,0x7c290070}},	//   _công_, cza_, _चौपा, jzer
  { {0xef190002,0x7d090002,0x7c290d1f,0xceb30009}},	//   _dużo_, ejes, dzer, ֑יו_
  { {0x200001b3,0x19b90015,0xceb3000b,0x7afe0054}},	//   ţii_, _путь_, ביו_, _òpti
  { {0x6fb60003,0x2545001e,0x291c001e,0xaa430752}},	//   _لمرا, tēla_, īvas_, _тесл
  { {0xb87b000e,0x765a0002,0xe6c60012,0x98ab0034}},	//   ndít, _wyty, _لتضي, nicą_
  { {0x2d6e0013,0x7d1b004a,0xf8eb0037,0x6d580028}},	//   _přes_, akus, _जोड़ा_, _ívaf
  { {0x691300a1,0xc3330093,0x44290d20,0x3abb000b}},	//   _içer, שות_, zza_, ומינ
  { {0xfe370009,0x64410034,0xf4830d21,0x7c830365}},	//   _ברבי_, _ślim, _кушн, _куше
  { {0xead40047,0xc058002d,0x7c290002,0xc953000b}},	//   _боль, вір_, czer, שמר_
  { {0xdb2300a2,0x21f40003,0x7bc00d22,0x692b0030}},	//   örün, _مكتس, mumu, třes
  { {0x5b7b000b,0xaabe0037,0xde740012,0x912b0012}},	//   _קרוא, _एफ़एक, لدفع, _يسبق_
  { {0x442903eb,0xdb21003a,0x7bcd0a58,0x2a57000b}},	//   tza_, ştür, ttau, _שבהן_
  { {0x2d5808b0,0x3ea70573,0x09340012,0x39ae0073}},	// [17d0] тить_, yant_, _خروج, lęs_
  { {0xdd110039,0x8c3d00a2,0x7d1b009b,0x692b0066}},	//   _kļūd, daşl, zkus, přes
  { {0x9f4900a2,0x44290d23,0x2726001a,0x6d480061}},	//   _araç_, sza_, _sông_, édac
  { {0x7bc00039,0x5df6000b,0x21390d24,0xd23b0009}},	//   kumu, _עזרא_, nish_, וגבל
  { {0x7bc00039,0xdfd10003,0x7d090027,0xa054002d}},	//   jumu, صيغ_, vjes, авці
  { {0xa294002d,0x39ae0010,0x68ed0269,0x36690d25}},	//   _варі, kęs_, _laad, нало_
  { {0x63ad01a2,0xed5906e6,0x39ae0010,0xdce20029}},	//   lsan, нок_, jęs_, _choď
  { {0x7c290d26,0xa3e90014,0x1be90075,0x61fa000e}},	//   tzer, едиа_, едии_, _átla
  { {0xa2ca0037,0xdb0d0017,0x7d090571,0x2139002a}},	//   स्क्, graç, rjes, dish_
  { {0x8c44003a,0x7c290bb2,0x539a0009,0x693c0159}},	//   _öğey, rzer, עיתו, učev
  { {0xbbd00044,0x7c290d27,0x636b004e,0xc6920009}},	//   _सङ्क, szer, münd, _האב_
  { {0x8c3d00a2,0xb05b0052,0x63ad093e,0x3ea50846}},	//   laşm, rgän, ksan, _helt_
  { {0x78a40033,0xb8ec0037,0x68ed0227,0xdb000040}},	//   _veiv, _ला_, _daad, dsmæ
  { {0xf5390026,0x8afc003e,0x8c1a000b,0x248d009b}},	//   liť_, ględ, _רוסי, lcem_
  { {0x63bb001e,0x693c0604,0x657d041d,0xd62a05f7}},	//   lrun, očet, _bish, хове_
  { {0xf5390026,0xf4950015,0x693c0066,0xaacf0011}},	//   niť_, ирую, nčet, त्रक
  { {0x4466002d,0x27f70012,0x63ad0d28,0x3d040011}},	// [17e0] ував, _مفيد_, gsan, वाते_
  { {0x8c3d003a,0xe3b10012,0x69c10d29,0xb87b0d2a}},	//   vaşl, ترِ_, oule, rdít
  { {0x2b890020,0x63bb008b,0xe8d9001a,0xd36f0012}},	//   _lúc_, hrun, _nhớ_, أهل_
  { {0xb95a000a,0xf5390029,0x215a0012,0x69c10034}},	//   رجاء_, jiť_, رجاع_, iule
  { {0xf5390026,0xb8dc0037,0x645d0051,0x6d440002}},	//   diť_, _आय_, üsil, mnia
  { {0x96b70001,0x7bc00d2b,0x6d44044c,0xceb30009}},	//   гућу_, vumu, lnia, ֖יו_
  { {0x6da30001,0x3ea501fb,0x63bb0d2c,0x6d440d2d}},	//   бија, _delt_, erun, onia
  { {0x39ae0010,0xdb0d0017,0x7e640066,0xed570001}},	//   vęs_, traç, řipo, лој_
  { {0x68ed0114,0x3ea501d0,0x69c10025,0x9f8b005e}},	//   _raad, _felt_, eule, _sööt_
  { {0x68ed00b9,0x51f8002d,0x2139002a,0x693c009b}},	//   _saad, вною_, wish_, ačet
  { {0xf5390026,0x21390036,0x69c10d2e,0x68ed0051}},	//   biť_, tish_, gule, _paad
  { {0x63bb09d1,0x63ad0d2f,0xea270024,0xa9270012}},	//   brun, ysan, уцьк_, اعده
  { {0x9cd70093,0x68ed00b9,0x29000002,0x6d440002}},	//   _תודה_, _vaad, _dnia_, dnia
  { {0x6d440d30,0xa294002d,0x69dc0d31,0x7ae10d32}},	//   enia, _такі, _opre, celt
  { {0xde59002d,0x201f0010,0xaab70012,0x2d850025}},	//   таві_, šui_, _صدور_, êle_
  { {0x5c070014,0x636b0d33,0x865b0009,0x2d870031}},	//   ляза, zünd, גדלי, _énem_
  { {0xf8a80037,0x2b89001a,0x8335025c,0x0b940012}},	// [17f0] _कड़िय, _xúc_, анах, مجلد
  { {0xf5390026,0x6d440005,0x63ad0d34,0x2ca9002c}},	//   ziť_, ania, rsan, saad_
  { {0x645d0d35,0x8f7a0009,0xcad70009,0x9f7a0009}},	//   _wysi, _שנתק, רובת_, _שנתח
  { {0x7ae1003a,0x645d0002,0xf1b3000b,0x2d8507ac}},	//   zelt, _tysi, מסע_, _rule_
  { {0xf5390026,0xe6c50003,0x636b004e,0x69c10d36}},	//   viť_, لتغي, tünd, zule
  { {0x645d0051,0xf7960003,0x7d0d0d37,0x95c50012}},	//   üsim, جنوب_, ljas, ليته
  { {0xf5390026,0xdce80010,0x636b0d38,0xff180009}},	//   tiť_, _judė, ründ, רקות_
  { {0x7d0d0006,0x3ea50052,0xa3b90037,0xb605000e}},	//   njas, _welt_, _घटा_, _aláí
  { {0xdcfa0039,0xf5390026,0xf5760003,0x7ae10d39}},	//   _attē, riť_, جميع_, telt
  { {0xadf70037,0xe1f9002d,0xf5390029,0x2d8501a3}},	//   ुमान_, вго_, siť_, _tule_
  { {0x8e84000a,0x7d0d0065,0x06840003,0xf5390029}},	//   _المه, kjas, _المُ, piť_
  { {0xdb000051,0x69c10d3a,0x2b890081,0x63bb0d3b}},	//   esmä, rule, _túc_, prun
  { {0x6d440cf9,0x7d0d0d3c,0x47c30048,0x98ab0034}},	//   čiat, djas, обяв, nicę_
  { {0xf772000a,0xf863002d,0x6d440002,0x98ab001e}},	//   تاج_, івро, wnia, ējās_
  { {0xe8d90020,0x442d0d3d,0x7d0d0028,0x6d440002}},	//   _giữ_, lze_, fjas, tnia
  { {0x7aee00b6,0x69c40011,0xfe430024,0x7786004c}},	//   _sabt, ांसी, інто, _клиз

  { {0x2d98007d,0x69dc0d3e,0x5aca002d,0xeab20003}},	// [1800] spre_, _spre, клам_, قعا_
  { {0x1303002d,0x69dc0033,0x442d0d3f,0x6d440d40}},	//   озум, _ppre, ize_, snia
  { {0xdebb000b,0x2d850066,0x88860447,0x3ebb0009}},	//   _במיל, ílet_, алеж, _בציב
  { {0x316d0061,0x71d6000b,0x7d0b006f,0x9c8301e9}},	//   _chez_, יועד_, ögst, účtu
  { {0x442d0070,0xe8d9001a,0xec47003c,0x59d20011}},	//   jze_, _nhờ_, _взял_, _सहकर
  { {0x501b000b,0x6996002d,0x442d037f,0x47330024}},	//   כונו, _врах, dze_, оніс
  { {0x32070006,0x69dc0029,0xceb3000b,0x98a6002d}},	//   änyt_, _upre, קיה_, _вибе
  { {0x636b00a2,0x75290d41,0xd1970009,0x7dfc004b}},	//   rüne, ghez, _ככלי_, _răsă
  { {0x6eb60003,0x4306002d,0xe8d9001a,0x673c07f6}},	//   _نصائ, аїна, _chờ_, kirj
  { {0x8f9b0009,0x03d70009,0x7dfc004b,0x661c0248}},	//   _סיבי, סוים_, _păsă, kyrk
  { {0x7c2d01a2,0xd5b10020,0xf1c30081,0xe9190024}},	//   zzar, ới_, _ngờ_, гоні_
  { {0xdb000058,0xd1260003,0x7afd001e,0x3946086e}},	//   dsmå, سم_, ēsta, nnos_
  { {0xab94000a,0x442d003e,0x9b940003,0x33940003}},	//   _التغ, cze_, _التت, _التز
  { {0xd724002d,0x69cf000d,0xdced01bd,0x6d480025}},	//   офсп, ăcer, rmač, édan
  { {0xdb000d42,0xeca70001,0x8d770003,0x28d70011}},	//   gsmå, ијан, لارا, ण्डि
  { {0x8a7b0093,0x427b000b,0x3946000e,0x4a7b000b}},	//   _באות, _באוג, jnos_, _ברוב
  { {0x29e8007d,0x67da001e,0xfa870001,0x957c0034}},	// [1810] _aşa_, nājā, аћем, _brąz
  { {0x39460d43,0x39590032,0x75290031,0x7d0d0a94}},	//   enos_, loss_, zhez, sjas
  { {0xeab1000b,0x7c2d0002,0x442d0d44,0xa3b30011}},	//   לֹא_, szar, zze_, _टिक_
  { {0x645d0051,0xa3b30011,0xe45f008e,0xe0020011}},	//   üsik, ड़ूँ_, _työ_, लमंद_
  { {0x2f19002d,0xb8ef0011,0x6aa70031,0x61260097}},	//   лодь_, _शा_, _tejf, _jóla
  { {0x6fb20003,0x86980014,0x394601c5,0x66e5022a}},	//   أموا, атът_, anos_, сока
  { {0xcdc80003,0x98af0010,0x9f4e000e,0x7de40012}},	//   لذين_, eigą_, énél_, قسيم
  { {0x442d0d45,0xf532000b,0x7ae50038,0xcd050337}},	//   tze_, ּ֥ה_, leht, спий
  { {0xc9520093,0x442d0d46,0x5f940198,0x7b16004b}},	//   _זמן_, uze_, _митт, _râur
  { {0x7d02009b,0x442d0d47,0x9b450012,0x2d8c0030}},	//   _enos, rze_, إندو, ídek_
  { {0x442d0d23,0x5d850003,0x5f740003,0x6d440029}},	//   sze_, _الصل, _ذاكر, čiar
  { {0x2d680052,0xe8d9001a,0xacf40012,0x61360064}},	//   eßen_, _thờ_, _وسنت, ošli
  { {0x95540003,0x7ae503bd,0xdb040097,0x59c90011}},	//   _بخلا, keht, krið, ांडर
  { {0x539a000b,0x6b96000b,0xa856000b,0x254c0066}},	//   _עיצו, _הכסף_, מירה_, měla_
  { {0xdb090164,0x69c50051,0xd627072b,0x7e690030}},	//   queñ, juhe, боре_, řepn
  { {0x63a4003a,0x63620d48,0x61360cac,0x8a160009}},	//   _çinc, môni, kšli, _לחצו_
  { {0x138a0003,0x63620017,0xc953000b,0x1bed0011}},	// [1820] اخرى_, lôni, _ממה_, जिटल_
  { {0xed590066,0xadf90037,0xdb040017,0x6ac60012}},	//   hož_, ्मान_, isiç, إقام
  { {0x63700052,0x63620017,0x61460015,0xed590066}},	//   häng, nôni, бежа, kož_
  { {0xf992000b,0x2561000e,0xa2d80011,0xfc270012}},	//   פרד_, bóli_, _नॉर्, _فح_
  { {0x39460d49,0x80250012,0x63aa0030,0x68e60073}},	//   rnos_, يرهم, álně, iekd
  { {0x65640065,0xc7d70009,0x254c0030,0x7d02001b}},	//   llih, מוני_, děla_, _snos
  { {0x3d040037,0x6da3004c,0xf2a3004c,0xe8d90081}},	//   वाले_, пија, _хисп, _nhở_
  { {0x71260003,0x6370031d,0x5bb8022a,0x778604ac}},	//   _ارسل, fäng, алия_, _глаз
  { {0xa3cb0044,0x63700d4a,0xccf3000b,0x7d02009b}},	//   रूप_, gäng, לכה_, _vnos
  { {0x2d820d4b,0x7b390066,0x49d8002d,0xaaa80037}},	//   _like_, lňuj, адою_, गरिक
  { {0xd5b9007c,0x23a90037,0x61260028,0x71270003}},	//   _всі_, चीबद, _sóla, مرحل
  { {0x81bc0039,0x6c860003,0xa2d80037,0x59c90037}},	//   dzēt, _الإم, न्त्, ांतर
  { {0x3959002a,0xa2d30037,0xe3af0012,0x7d1d0d4c}},	//   ross_, _बॉक्, _كرو_, össe
  { {0x6e940015,0xa7fd000e,0x2d680052,0x656402a0}},	//   зиру, _szűk, ußen_, elih
  { {0xa3cb0037,0xd9ec0037,0xe189001a,0xee310009}},	//   रंभ_, _जनित_, _hẳn_, ֵֽל_
  { {0x3eae03e4,0x61260028,0x6144004c,0x7e690030}},	//   haft_, _tóla, _неја, řepo
  { {0xdb040d4d,0xb8cd0037,0x7b3905b1,0x82870012}},	// [1830] trið, गर_, dňuj, مجال
  { {0x8c1b000b,0x69c50028,0xd3710012,0xbcfb0025}},	//   אומי, tuhe, ذها_, _chér
  { {0x60990012,0xa3a90011,0xed690097,0xceb20009}},	//   لناس_, _गौर_, nnþá_, _קיט_
  { {0xc1050012,0xa0c50012,0x2ee10011,0x6d5d020d}},	//   توصي, زيتو, फ़्त, _uksa
  { {0xf7710351,0xb3670048,0x8e8505fb,0x78a9005e}},	//   وات_, _гъвк, огле, _veev
  { {0xa2d80044,0x69c5004a,0x2d9505f0,0xb6a50d4e}},	//   न्द्, puhe, орис, цикл
  { {0xf592000a,0x8d750003,0x212900b6,0x78a90051}},	//   ولوج, يابا, _olah_, _teev
  { {0xa63c000b,0x6370006f,0xb9250012,0x321e0034}},	//   טגור, täng, _بفري, dyty_
  { {0x798a0052,0x63700032,0x27ed026b,0xdce80035}},	//   _aufw, bänd, _usen_, _zudī
  { {0xdb160006,0xe9d90838,0x1c420015,0x9dab0014}},	//   styö, ако_, ьным, _бъда_
  { {0x81bc0039,0xeab2000b,0xc869000b,0x07080012}},	//   dzēs, וֹר_, _סן_, _ديلي_
  { {0xf1b2000b,0x637002f1,0x62830029,0x63620018}},	//   וסט_, mäne, ľnoh, rôni
  { {0x6d4901b3,0x2904003a,0xbf87001a,0xd5b1001a}},	//   mnea, ıma_, _điển_, ấn_
  { {0x907a000b,0xe2990094,0xd5b8001e,0xd5dd0011}},	//   יטרי, _так_, šām_, _महाज
  { {0xad3a002d,0x6d49000d,0xe5060012,0x5fb60011}},	//   ачає_, onea, يبري, _अटकल
  { {0x39b50039,0xc5f2000b,0x62950070,0x0566002d}},	//   mās_, ודל_, _afzo, іван
  { {0x39b50039,0x656400b6,0x39a7000e,0x25a00027}},	// [1840] lās_, rlih, lős_, ćili_
  { {0x70b40037,0x7e640030,0x5de60700,0x6b830d4f}},	//   ुल्ल, řipi, _джоа, _jing
  { {0x63700d50,0x39b50039,0xa3a90037,0xe2970015}},	//   vänd, nās_, गीत_, цах_
  { {0x80660014,0x752d0164,0xdd0f003a,0x6d410025}},	//   овеж, chaz, mışs, élat
  { {0xb4e60037,0x69c10052,0x63700d51,0x7b3901e9}},	//   फ़ी_, hrle, tänd, rňuj
  { {0xab2a0046,0x39b50039,0xa857000b,0x6b830d52}},	//   _тога_, kās_, חינה_, _ning
  { {0x39b50039,0x76a9002d,0x272f0052,0x386d000e}},	//   jās_, стів_, _fünf_, _ezer_
  { {0x39b50039,0x63700c60,0x6d490623,0xc19b0009}},	//   dās_, sänd, gnea, _כשלי
  { {0x44200d53,0xad1b0009,0x25a9001b,0x6b830d54}},	//   nyi_, שופר, ćala_, _bing
  { {0xa3cb0037,0xd3700003,0x63bd000e,0x7bdb0009}},	//   रंत_, عهد_, ásna, סקיו
  { {0x39b5001e,0x6aaa0028,0x28d10011,0x8f750024}},	//   gās_, _veff, _हामि, _хуті
  { {0x394d0149,0xe8d90020,0x6b8308fa,0x94d40003}},	//   ões_, _phố_, _eing, _ريتش
  { {0xf8b3000b,0xb0340015,0x1dc60011,0xdfdb0048}},	//   ושר_, дняш, रूरत, шън_
  { {0x7d06007a,0x44320002,0x2545001e,0x7bd5000d}},	//   _anks, dzy_, vēli_, ăzut
  { {0x39b5001e,0x6d40004a,0xdce20034,0x98af0073}},	//   cās_, oima, _choć, aigę_
  { {0x2545001e,0x6d400d55,0x2d8c0018,0x2129016d}},	//   tēli_, nima, _mude_, _ulah_
  { {0x6d400051,0xe3b30012,0xbe870012,0x69c80d56}},	// [1850] iima, برز_, _وجدو, lude
  { {0x539b007e,0x99d70003,0x2d8c0070,0x78ad0d57}},	//   יימו, قتصا, _oude_, _heav
  { {0x8c3d003a,0x6d400d58,0x2d8c0d59,0x91b00081}},	//   laşt, kima, _nude_, _đạo_
  { {0x6d40007a,0xc4c70012,0xec150012,0xad190009}},	//   jima, _بتدو, _فوجد, _הוֹר
  { {0x4432003e,0x3ce30037,0x07a50014,0x394b000e}},	//   czy_, कड़ों_, чалн, incs_
  { {0x37070047,0x78ad0036,0xf3ff0017,0x6370004a}},	//   ючев, _leav, _irã_, täne
  { {0x6aa70037,0xf62500b3,0x69c80d5a,0xdb020032}},	//   _ग़ौर, ядко, jude, _stoß
  { {0x39b50039,0xdb1b0054,0x69c80051,0x2d8c0d5b}},	//   vās_, truï, dude, _dude_
  { {0x1c450024,0x6d490d5c,0x6b830d5d,0x0d3c00af}},	//   яним, rnea, _ping, יגהב
  { {0x39b50039,0xfbd2000b,0x395d0444,0x49c9085f}},	//   tās_, עתי_, lows_, блон_
  { {0xeccb0037,0xc4cb0037,0x644d0010,0x69c80d5e}},	//   िलाफ, िलाओ, _žaid, gude
  { {0x39b50039,0x69d70054,0x3cf80012,0x6b83096c}},	//   rās_, itxe, _وعند_, _wing
  { {0x39b5001e,0xa3f4002d,0x67070011,0xc796003c}},	//   sās_, _опці, शांक_, ярны
  { {0x39b50039,0x539a000b,0x2d96004d,0x69c80d5f}},	//   pās_, _היסו, зрас, bude
  { {0x64a60d60,0x66030024,0x78a20042,0x8c3d004b}},	//   заба, нпра, ybov, raşu
  { {0x49ba0093,0x78ad0070,0x4420004a,0x19ba000b}},	//   _המקס, _geav, tyi_, _המקב
  { {0x44260020,0xa08b0009,0x5046004c,0x39420a94}},	// [1860] áo_, _לְיִ, _хепб, miks_
  { {0x443204fa,0x883b0009,0x44200d61,0x6d400d62}},	//   rzy_, _לתפו, ryi_, zima
  { {0x2730008a,0x68f600a2,0x4432003e,0xe9da0838}},	//   _hàng_, _kayd, szy_, ске_
  { {0x39420051,0x66010058,0x7d190002,0x7ae80034}},	//   niks_, ælke, _nows, zedt
  { {0x6d40007a,0xf3ff0017,0x78a20d63,0x7d7b0009}},	//   vima, _grã_, rbov, _לנטו
  { {0x39420051,0xb5a60024,0x27300081,0x28d10011}},	//   hiks_, прий, _màng_, _हाथि
  { {0xa5d70003,0x91e3011f,0x2730001a,0x7ae80722}},	//   كبير_, _поре, _làng_, vedt
  { {0x2cea002d,0x5398010c,0x69c80d64,0xa2aa0011}},	//   сько_, овия_, vude, टरव्
  { {0x39420051,0x7bc90d65,0xb8e20011,0x27300081}},	//   diks_, gueu, ूल_, _nàng_
  { {0x59d0015f,0xab970003,0xaacc0037,0xdce60010}},	//   _हमार, أخير_, ालिक, _tikė
  { {0x78ad0005,0x2d8c0051,0x6d400d66,0x69c800ff}},	//   _peav, _uude_, pima, uude
  { {0x39420051,0x63b6004a,0xd5b1001a,0xdb1b0097}},	//   giks_, ksyn, ấm_, stuð
  { {0x27300020,0x63ae0066,0x645d0051,0x69c80d67}},	//   _càng_, áhně, üsit, sude
  { {0x2730001a,0xcb540003,0x3942001e,0x3f850028}},	//   _dàng_, _تنتظ, aiks_, ölu_
  { {0x7bc40005,0x78ad0005,0x68f6003a,0xa4d5002d}},	//   eriu, _teav, _fayd, мові
  { {0xf549001a,0x9a670003,0x04c90012,0x8d740012}},	//   hấn_, _عميل_, توري_, فاقا
  { {0xdcfa001e,0x2bb80003,0xc158000b,0x88bc000b}},	// [1870] _attī, كالة_, _משהו_, _המחז
  { {0x539b0009,0x60dd016a,0xc7b20009,0x6f1a0132}},	//   ציבו, lfsm, _שבי_, _notc
  { {0x79a40015,0x2a980003,0xa3b90011,0x91870012}},	//   ерче, سئلة_, _घटक_, سجام
  { {0xda7b0009,0x7bc4036c,0xf9930009,0x637401a0}},	//   זנבר, briu, גרף_, lànd
  { {0x7bc403eb,0x9f35002d,0x636b003a,0x6d4d0647}},	//   criu, меді, lünm, mnaa
  { {0x6d4d0070,0xdb1b0056,0x7afd0035,0xf77300ae}},	//   lnaa, truí, ēstk, راش_
  { {0x7d19003e,0x80bf0037,0x6d4d00ff,0x272f003a}},	//   _pows, ्लाइ, onaa, _güne_
  { {0xe8d9001a,0xc1050012,0x7bc90025,0x637009ee}},	//   _khổ_, _توري, tueu, mäna
  { {0x47d50003,0x6d480025,0x63a40060,0xab5d0034}},	//   _زيار, édai, _çinl, erża
  { {0x2730001a,0xd7740012,0x80d90011,0x68eb0227}},	//   _ràng_, _كالع, फ्रे, legd
  { {0x2730001a,0x39420d68,0xa0c60012,0x6f7a0009}},	//   _sàng_, tiks_, ويدو, _וְאו
  { {0xd7d10044,0x25450039,0xe7d10044,0x69c5004a}},	//   _समाच, tēlu_, _समाप, irhe
  { {0x69c50052,0x39420d69,0x636b003a,0x316c001e}},	//   hrhe, riks_, tünl, ēdz_
  { {0x2730001a,0x59c50037,0x3942005e,0x65690d6a}},	//   _vàng_, _विपर, siks_, lleh
  { {0x212d00ec,0x636b0060,0xb956004c,0xd62a0365}},	//   _oleh_, rünl, _отић, цове_
  { {0x2730001a,0xa5070048,0x1d0706bd,0x65690d6b}},	//   _tàng_, меса_, меси_, nleh
  { {0x6b8700bd,0x7bc40010,0x5fd20037,0x04430c1e}},	// [1880] _bijg, uriu, _तमिल, ветн
  { {0xdcfd0039,0xd7760003,0xd5b1001a,0x63b60192}},	//   _visā, _تابع, ớp_, rsyn
  { {0x2005001e,0xfe720012,0x56b70009,0x2d950048}},	//   ālie_, _جدة_, _קפטן_, _пряс
  { {0x98b9000d,0x7bc4000d,0x9dc10011,0x98a6003c}},	//   misă_, priu, रूज़ो, фиде
  { {0x69c508de,0x38490009,0xeb9a0048,0x65690030}},	//   arhe, ּאוּ_, _фиг_, dleh
  { {0xa0370009,0xf8370009,0xf5490081,0xdd9a0c6c}},	//   ואנה_, וננת_, uấn_, оши_
  { {0xdd900003,0xac940024,0x66e00011,0x77ea0011}},	//   دوب_, найш, ख्यक_, टबुक_
  { {0x6ba50163,0xdce40d6c,0x13f40048,0xb90306bd}},	//   _åtgä, klič, езия, _изск
  { {0xbcfb0066,0x6f930012,0x98b9004b,0xf8630d6d}},	//   _okén, _للقض, hisă_, _авто
  { {0x7e970003,0x39400061,0x61260028,0x521402ad}},	//   _ينقر_, _amis_, _fólk, едот
  { {0x28f900b3,0x8e4a0012,0xdce407a5,0xa2cf0011}},	//   пень_, _بلاك_, elič, _दार्
  { {0xf3880020,0x0c2606bd,0x7e640030,0x4035003c}},	//   _lợi_, _омен, řips, еемс
  { {0x28d10037,0x63740054,0x60dd0028,0xb05b006f}},	//   _हासि, tànd, rfsm, egär
  { {0x44240002,0x39930017,0x6560000e,0x3940004b}},	//   mym_, _fãs_, lomh, _emis_
  { {0x200d000d,0xf1c50037,0x1df8003c,0x56940bda}},	//   ţei_, _वियन, меры_, таст
  { {0x636b00a2,0xe8d9001a,0x765b003a,0x91bb0009}},	//   rünm, _phổ_, şuyo, _ומהי
  { {0x6d4d0d6e,0x44240d6f,0x68eb0031,0x351b0009}},	// [1890] rnaa, nym_, vegd, קומנ
  { {0x6d4d0070,0x026b00fa,0x59c50011,0xf79c0009}},	//   snaa, ошей_, _विमर, _ובזמ
  { {0x69cf0002,0x69da0d70,0xf9900012,0x6d4d0227}},	//   ąceg, ntte, لبن_, pnaa
  { {0x69da03fc,0xe8d9001a,0xc27b000b,0x44240029}},	//   itte, _thổ_, קראי, kym_
  { {0x7feb0003,0x63700d71,0xc49a0009,0x01380009}},	//   تراف_, männ, _משרת, וראת_
  { {0x7d1d000f,0x98a50073,0x44240d72,0x63700d73}},	//   _hoss, ėlę_, dym_, länn
  { {0xdce4048b,0xf388001a,0x62830029,0xa3cb0037}},	//   zlič, _gợi_, ľnos, रूर_
  { {0x7d1d0006,0x657b002c,0xccf20009,0x69da0032}},	//   _joss, umuh, ָ֛ה_, dtte
  { {0x13e60015,0x2d9e0d74,0xd7770012,0x8b250048}},	//   емый_, _ette_, _قاطع, едпе
  { {0x2545001e,0x65690d75,0x8c9f0011,0x7d1d0d76}},	//   tēls_, sleh, _ग्रो, _loss
  { {0xcb12000b,0x6370006f,0x3869003a,0xb0620872}},	//   אלי_, känn, _ayar_, _ääri
  { {0x7d1d0149,0x44240002,0x20140002,0x6370008e}},	//   _noss, bym_, ścił_, jänn
  { {0x44240002,0xb4270003,0x6370008e,0xdb0b0d77}},	//   cym_, _تعاو, dänn, _avgå
  { {0x7529000f,0x61f5000e,0x7bdb0028,0xb05b006f}},	//   lkez, _oszl, mtuu, tgär
  { {0xc6920093,0x6721006f,0xdd920003,0x6e930003}},	//   ראל_, ölja, اور_, الفا
  { {0x7989003e,0x2d9e001e,0x2a3a0009,0x98b9004b}},	//   _niew, īte_, _מעצמ, risă_
  { {0x7ff60003,0x7d1d04d4,0x7bdb0d78,0x32d90009}},	// [18a0] _أسبا, _doss, ntuu, ּחֲנ
  { {0x272b00b0,0x7c360034,0x7bdb008e,0x48dc0011}},	//   _sønn_, rzyr, ituu, ग्रो_
  { {0xda660003,0x44240002,0xf8bf0061,0xe8d9001a}},	//   راطي, zym_, chés_, _chỗ_
  { {0x7bdb0005,0x8c9f0037,0x69c30164,0xd59b0009}},	//   ktuu, _ग्लो, ánea, _מבטל
  { {0xa7fd000f,0x7f46027f,0xd4360012,0xef660048}},	//   _szűr, недж, _أعجب, нъко
  { {0x57f30001,0xa8470003,0x3cdd0037,0x254c0066}},	//   упшт, علوم_, क्से_, měli_
  { {0x4424003e,0x4ea5002d,0x68e40b2d,0x7d780012}},	//   wym_, тріа, _obid, ومتر_
  { {0x89db000b,0x7529000e,0x2fc60058,0x442404f3}},	//   _מחלי, gkez, prog_, tym_
  { {0x8497000a,0x27340248,0xa8060024,0x39460d79}},	//   رئيس_, _känd_, _язал, mios_
  { {0x307508b0,0x6560024c,0xa91d009b,0x44240002}},	//   _русс, somh, _nižj, rym_
  { {0xc333015a,0xd337000b,0x19590015,0xa1590447}},	//   רות_, גריה_, даны_, дану_
  { {0x98a90029,0xa3cb0011,0xb7f40011,0xdde90012}},	//   _tlač_, रूँ_, _इनाम_, _تركه_
  { {0x7bdb00bd,0xc953000b,0x63700d7a,0xe8030037}},	//   ctuu, רמר_, jäno, लिया_
  { {0x254c0066,0x999e000e,0x636b000e,0x539b0009}},	//   děli_, sztő_, rünk, _ציוו
  { {0x39460010,0x80a20037,0x6370004a,0x8afb0009}},	//   kios_, _क्वे, tänn, _מהגי
  { {0x59c50044,0x9d180ac5,0x63660028,0xc4cb0011}},	//   _वितर, ност_, rðnu, िलेख
  { {0xdb0d0c7e,0x63a4002c,0x7d1d0d7b,0xa8a80009}},	// [18b0] nsaç, gpin, _voss, _אֹתִ
  { {0x69c800bd,0x6370004a,0xdb0d0164,0x86990223}},	//   orde, sänn, trañ, _юкос_
  { {0xd251000a,0xa2d801e1,0xc2c40003,0x200400c1}},	//   جنا_, _मान्, طيني, _armi_
  { {0x69c8000f,0x25ba000b,0x55ba0009,0xad270012}},	//   irde, _קצרמ, _קמרו, _أردو
  { {0x79890087,0x656d00b6,0x69c80052,0xa4b60009}},	//   _view, mlah, hrde, _שלשה_
  { {0xd0060048,0xd00c0009,0x36690d7c,0x2d8b01e3}},	//   теше_, לּוֹ, мало_, _hice_
  { {0x75290272,0x56920046,0x39460d7d,0xed590a2c}},	//   tkez, шајт, bios_, мок_
  { {0x39460d7e,0x7bdb004a,0x61260028,0x27340248}},	//   cios_, ttuu, _tóli, _täng_
  { {0x80a20044,0x442b0020,0x7f950098,0x75290d7f}},	//   _क्षे, ác_, _разх, rkez
  { {0x3eb30036,0xeab10003,0x69ca0017,0x63740054}},	//   _next_, جعة_, áfeg, vànc
  { {0x68fb0176,0x7bdb06cb,0x3f920060,0x75290031}},	//   _kaud, stuu, _suyu_, pkez
  { {0x2eaa0044,0x9e48000b,0x6721006f,0x63740054}},	//   कर्त, _אֲנִ, öljn, tànc
  { {0x69c809a0,0xf8bf0066,0x20040d80,0x88ba0009}},	//   arde, ckém_, ími_, וזרי
  { {0x80a20044,0x07a3024d,0xec360009,0x6f63003c}},	//   _क्रे, рарн, _באנר_, ивяз
  { {0x63bd0163,0x9a690003,0x165901d4,0x3aba0009}},	//   _avsn, _تمثل_, ерть_, _חמצנ
  { {0x68fb0d81,0x57d10037,0x140d0037,0x291f000d}},	//   _naud, _समूह, समूह_, _noua_
  { {0xb87b0d04,0x2d8b0d82,0x69c30064,0xc2b6004c}},	// [18c0] rfíc, _dice_, ánen, вљењ
  { {0x5fb7000b,0x577a0003,0x63a40d83,0xffb70009}},	//   _שהיא_, _تصبح_, rpin, _שליש_
  { {0x394602d1,0x3ebe0028,0x63a40d84,0x9b650012}},	//   tios_, óttu_, spin, اطقه
  { {0xd5b80039,0x1e57000b,0xd0260048,0xc7a60472}},	//   šās_, _ישיר_, кмей, видк
  { {0x68fb0039,0x291f000d,0xa3ba0012,0xf7f30012}},	//   _daud, _doua_, _تاجر_, لسود
  { {0x3946007a,0x8fa30001,0x2d8b000d,0x1eaa0012}},	//   sios_, шаље, _zice_, ذاتي_
  { {0x41aa002d,0x68fb0061,0x39460d85,0xe1f7003c}},	//   _іван_, _faud, pios_, _игр_
  { {0xed570046,0x29dc0164,0x6564004a,0x7bc90d86}},	//   кој_, mía_, noih, freu
  { {0xb8660003,0x1c050011,0x3eb80d87,0x9f4d01e3}},	//   _شارو, रियल_, kart_, _creó_
  { {0x68fb001e,0xe44f0012,0xdb0d0018,0x69c8001b}},	//   _zaud, تضى_, rsaç, trde
  { {0xf2d3000b,0x29dc0d88,0xa3c60037,0x6370006f}},	//   בעת_, nía_, ैंड_, vänl
  { {0x91bb000b,0xf8bf000e,0x2d800002,0x216400fa}},	//   ומטי, mkék_, jmie_, итяг
  { {0x4fc70014,0xdb040164,0xb4ae0037,0x3eb8013f}},	//   ъсна, nsió, करी_, fart_
  { {0x63a20101,0x0ccb0037,0xe8030037,0x2d8b0066}},	//   _iton, िल्म, लिता_, _sice_
  { {0x80d30037,0xcb670001,0xee2e0024,0x29dc01e3}},	//   _डाले, _шаље_, йнi_, jía_
  { {0x29dc0164,0xdb1b0017,0x850d0011,0xa2d80011}},	//   día_, truç, हाइट_, _माड्
  { {0xfbd00003,0x25a90027,0x50b80003,0x3eb8013f}},	// [18d0] قتل_, ćali_, _شديد_, bart_
  { {0xe4e20044,0x29dc02d1,0x1fa40014,0x764e000e}},	//   क्ति_, fía_, _тръг, ányá
  { {0x29dc02d1,0xc6920009,0x99870030,0xdbd10032}},	//   gía_, _לאי_, ánů_, _füße
  { {0xd5b1001a,0x7c32000e,0x63a2051f,0x08d40024}},	//   ấu_, ókró, _oton, иція
  { {0xb8db0037,0x08c40024,0x68fb08a7,0x7d0f0031}},	//   _आज_, рбін, _vaud, _incs
  { {0x29dc02d1,0x7afc0d89,0x2abc0030,0x7bc90ae5}},	//   bía_, _gart, rábí_, vreu
  { {0x29dc02d1,0x69de0070,0x44290d8a,0xc3320009}},	//   cía_, ctpe, lya_, _פול_
  { {0x9f4d00b8,0x7bc90d8b,0x7afc0032,0x63bb0d8c}},	//   _creò_, treu, _zart, tsun
  { {0xe3b1000a,0xbcfb0026,0x7bc90061,0x7d760012}},	//   حرب_, _akék, ureu, دمير_
  { {0x63bb00a2,0x7bc90c23,0xddeb0012,0x89a908d1}},	//   rsun, rreu, _يراه_, нков_
  { {0x5cd50003,0x63bb0d8d,0xe8df0081,0x2d800034}},	//   _مقاط, ssun, _ngừa_, ymie_
  { {0x34950046,0x7fd6002d,0x89360003,0x7bc9000d}},	//   _садр, лігі, اعدا, preu
  { {0x59c50044,0x752d0042,0x798d016d,0x1dcf0011}},	//   _विवर, dkaz, _diaw, सूरत
  { {0x3cff005e,0x61260031,0xdbd10032,0x7d1b0d8e}},	//   lduv_, _rólu, _süße, ljus
  { {0xceb20093,0x442900a2,0xa2d80037,0xe4f90037}},	//   מים_, eya_, _मात्, ्यपि_
  { {0x5c160047,0x29dc02d1,0x4429003a,0xb4c00011}},	//   льзу, vía_, fya_, ीले_
  { {0x07fa0003,0x2d800826,0x7c290d8f,0x2ecf0011}},	// [18e0] _أربع_, rmie_, nyer, _हफ़्त
  { {0x7d1b0005,0x57fb000b,0x0ed20037,0x2d800029}},	//   hjus, _טלפו, _साइड, smie_
  { {0xd5b1008a,0x7afc0757,0x6370006f,0x18a60063}},	//   ất_, _vart, länk, гаем
  { {0x29dc02d1,0x7afc0d90,0x386d0260,0xc3290009}},	//   ría_, _wart, _byer_, הו_
  { {0x6d46003a,0x7afc0d91,0xe8070037,0x6721080a}},	//   _imka, _tart, शिया_, _bolj
  { {0xdb0402d1,0xa2d80037,0xbcfb0029,0x75d40012}},	//   rsió, _माध्, _akéh, ليتا
  { {0xf41f0006,0x7de60003,0x67210027,0x316c001e}},	//   ään_, استم, _dolj, _ūdzu_
  { {0xb4ae0011,0x42530012,0x7c3b0032,0xaa430365}},	//   करे_, _انفر, fzur, _уесл
  { {0x68e40051,0x08f90012,0x14d50011,0x8afc0034}},	//   õidu, _جرّب_, _धारण, klęt
  { {0xef830229,0xeab60009,0x79820034,0x77830024}},	//   _глуп, נִ֥י_, lmow, _глуз
  { {0x6e93000a,0xe693000a,0x5e93000a,0xf6560024}},	//   _الما, _المد, _المط, _стаю
  { {0x286b002d,0xe8d9001a,0x7c29002c,0x7d1b0034}},	//   ерго_, _khứ_, byer, cjus
  { {0xac970003,0xaf370012,0x69cd0073,0xab2a064d}},	//   _إنها_, هرست, _įneš, _пода_
  { {0x88bd003e,0x7bfb000b,0x4aba0048,0xb2a60012}},	//   _kośc, _נפוצ, _чудя_, _صحته
  { {0x637008b5,0x95c800f5,0x2bc70011,0xe5730012}},	//   mänh, лута_, _लिहा, مطر_
  { {0x79820002,0x6aba000e,0x88bd0034,0x316909df}},	//   jmow, latf, _mośc, _ukaz_
  { {0xb8f90044,0x29270002,0x93970003,0x394b0d92}},	// [18f0] ाल_, ętać_, اجرا, mics_
  { {0xdce9080f,0x752d0404,0xd25b0d93,0x44290d94}},	//   vleč, skaz, нце_, rya_
  { {0xdb580015,0x7bcb0028,0xdce90027,0x320700d9}},	//   уют_, águb, zmeđ, íny_
  { {0x97c50003,0x44290115,0x394b0d95,0xbebc0035}},	//   لقصو, pya_, nics_, _slīp
  { {0x94ba0009,0xe8d9001a,0x6721048b,0xa295002d}},	//   _שמשת, _chứ_, _polj, _вагі
  { {0x394b0d96,0x386d0248,0xd70503d2,0x000000c4}},	//   hics_, _vyer_, рзки,
  { {0x7bcd0065,0x67210470,0x2365009b,0xf2040014}},	//   lrau, _volj, volj_, _лято
  { {0x7bcd0032,0xdce90073,0x6d2500b5,0x661a008e}},	//   orau, pleč, рдиз, ätki
  { {0x75ec000f,0x36d50015,0xec790014,0x394b0ce3}},	//   _közö, _возр, ъпи_, dics_
  { {0x82350003,0xef670014,0xff530003,0x96f80012}},	//   لرجا, _събо, _اخر_, _معمر_
  { {0xf7840003,0x7bcd0052,0x88bd0002,0x394b0ce3}},	//   _اللَ, hrau, _gośc, fics_
  { {0x6370006f,0x2b170037,0xab660002,0x00860103}},	//   tänk, नाडु_, _zażą, илно
  { {0x2ba7004c,0xdfd20012,0x2cad0912,0x61260097}},	//   _сјев, غيس_, mbed_, _sóls
  { {0x82a50047,0x79820002,0xc43a000b,0x6370031d}},	//   _такж, zmow, _שתסי, ränk
  { {0x29560098,0x69c30aa3,0x28a70011,0x76000031}},	//   _въпр, šnej, _क्वि, mázá
  { {0xf3880020,0x7600000f,0x636b0d97,0x27ed0d98}},	//   _hợp_, lázá, zünt, _open_
  { {0x4d63002d,0x6a960024,0x9346004c,0xdb000d99}},	// [1900] ікув, ареє, анае, rsmö
  { {0xa87b000b,0x2d8f0d9a,0x487b0009,0x67bb0009}},	//   _באפר, _lige_, _בטפס, _שמיק
  { {0x4add0037,0xe9da069b,0x80a60003,0xa2d80037}},	//   _मानव, тке_, لمان, _मास्
  { {0x88e60047,0xa3e60037,0x865b0009,0x55bb0009}},	//   ржде, _पहल_, _ידיי, _במטו
  { {0xdefa0047,0x79820002,0x76000066,0xa09b000b}},	//   вый_, rmow, kázá, דינט
  { {0xeea70014,0xf4570009,0xceb30009,0xd00f0012}},	//   атък_, _כיכר_, ֗יו_, بله_
  { {0x636b00a2,0x2dd70003,0x6370004a,0xceb30009}},	//   rünt, لبية_, jäni, חיו_
  { {0xe8d90020,0x2cea0024,0xc6170009,0x5ca90009}},	//   _thứ_, тько_, שחקי_, ְׁתַ
  { {0xa5070001,0x61e90027,0xe4e20011,0xc7a30048}},	//   рења_, _ćeli, क्षि_, _митк
  { {0xbb540012,0x7bc60073,0xdfcf0012,0x69cf0034}},	//   إندب, škuo, _آيل_, ącen
  { {0x2bc20037,0xd257002d,0x3377000b,0x2cad002a}},	//   _शिका, ицю_, שעים_, bbed_
  { {0xdd8f0003,0x6d5e0031,0x80a20011,0x26cc0031}},	//   _قول_, épad, कुले, ódon_
  { {0xe53b000b,0xc05b002d,0x29050066,0xad1b0009}},	//   _בתאר, тін_, ěla_, _שודר
  { {0x28a70044,0x20090061,0x29050002,0x6d5602a0}},	//   _क्रि, _vrai_, śla_, enya
  { {0xdb7b000b,0xa3d40037,0x2d840d9b,0xd3370009}},	//   _שנוכ, सूस_, omme_, _דרגה_
  { {0xef190002,0x7bcd0d9c,0xc0cb096e,0x20090d9d}},	//   _duży_, trau, _руке_, _trai_
  { {0x44980015,0x2d8408b5,0x3cde0011,0x2bb80012}},	// [1910] рвую_, imme_, _गाने_, لالة_
  { {0x27340051,0x6d56010a,0x7bcd0d9e,0xdab90012}},	//   _täna_, anya, rrau, اهات_
  { {0xa2dd0044,0xa294002d,0x636b0052,0x40950012}},	//   _पाठ्, іаці, wüns, ملار
  { {0x7bc00010,0x301500fa,0x637d0007,0x27390025}},	//   ksmu, йдер, mène, _mène_
  { {0x98e40003,0x83870015,0xe6c50003,0xcfe90012}},	//   تكنو, _выве, متغي, افته_
  { {0xf549001a,0xb7670021,0x2d8f0d9f,0xcf440024}},	//   hất_, штей, _sige_, оній
  { {0x7bc20061,0xf1590014,0x91f40012,0xd7380009}},	//   _avou, _бивш_, _وأفا, שטות_
  { {0x28a7015f,0x1e580093,0xf658000b,0x067c000b}},	//   _क्लि, ישור_, יסוי_, כנול
  { {0x4034022a,0x63a90da0,0x2cad021b,0x637d0025}},	//   _детс, upen, rbed_, hène
  { {0x7de7007c,0xf5e7007c,0x7c2d003a,0xada40029}},	//   _відд, _відм, iyar, _spĺň
  { {0xa2d80044,0xe8d90020,0x22490001,0xc332000b}},	//   _मार्, _chữ_, упни_, פוט_
  { {0x7c950003,0x04950003,0x645e0002,0x9e760009}},	//   _الإص, _الإح, _śpie, _הגעה_
  { {0x6c85000a,0xd4960009,0xfc670048,0x6d4d0da1}},	//   _الشم, _הכנת_, _тъжн, diaa
  { {0xe4500003,0x39490da2,0xceb20009,0x6d500034}},	//   _تضم_, _emas_, ּין_, ądał
  { {0x5b7a0093,0xd5b10020,0x9f4b000e,0x442d0da3}},	//   _גרסא, ấp_, óját_, lye_
  { {0xe0da0046,0xad390024,0x66d10031,0x1543004c}},	//   _сви_, ачує_, tókü, песм
  { {0x6d5600c6,0x443f0052,0x442d00b6,0xd4690003}},	// [1920] rnya, nzu_, nye_, لحكم_
  { {0x8a3a0015,0x6c330012,0x6c550024,0x442d0060}},	//   ляет_, أفكا, іттє, iye_
  { {0x2d840da4,0xb4f90011,0x6d4d005e,0x7c2d020d}},	//   ymme_, ्याय_, biaa, ayar
  { {0x6d4d0070,0xf9690024,0x661a03bd,0xf77f0060}},	//   ciaa, арій_, ätku, rtçe_
  { {0x3eba002a,0x2912003a,0x2bba0003,0x7b01004a}},	//   _kept_, ıya_, _حاجة_, öytä
  { {0x443f0333,0xc7b3000b,0x29000da5,0xd6cf0012}},	//   dzu_, לבד_, žia_, فقه_
  { {0x7abb000b,0xddea0003,0xe7f40011,0xa3b00011}},	//   _תצלו, ارته_, _इनका_, टीई_
  { {0x7bc60010,0x5c980048,0x88c50012,0x3e830025}},	//   škum, шкия_, _وتقل, lété_
  { {0x251b000b,0x442d000e,0xfc4a0030,0x389b0009}},	//   רופא, gye_, blíž_, _תימנ
  { {0x7d040006,0xdced00eb,0x93fb0009,0x87250012}},	//   hdis, vlač, נליי, _وعلم
  { {0x69c10da6,0x99520066,0xb4c80037,0x7c2d0034}},	//   gsle, lář_, _ईयू_, _żart
  { {0xd257002d,0xf549001a,0xdced01e9,0x78a20042}},	//   сць_, uất_, tlač, ncov
  { {0xc867085b,0x6725004a,0x443f0002,0xad650003}},	//   стни, _pohj, czu_, _باله
  { {0xa857000b,0x00570009,0x88bd0034,0x78bd0035}},	//   מיכה_, משכת_, _nośn, sasv
  { {0x81a60003,0x8d770003,0xb2bb0009,0x99520030}},	//   _احتل, مارا, _גמור, hář_
  { {0xbd6b0015,0x5575002d,0xdced02a1,0x39490018}},	//   урге_, ігат, plač, _umas_
  { {0x24180015,0x68ed00b6,0x7bd600b6,0xac1801d4}},	// [1930] боты_, _ibad, guyu, боту_
  { {0x2b110037,0x6440001e,0x7d040da7,0xe3b00012}},	//   ़ाएँ_, izmi, adis, عرق_
  { {0x7c2d00c6,0x637d0054,0xd095003c,0x314b0009}},	//   syar, lènc, ошлы, ְתְּ
  { {0x27300020,0x26de0b45,0x82340012,0x7c2d0132}},	//   _hành_, _acto_, أركا, pyar
  { {0xa0690001,0x18690001,0xdb09005e,0xb9010011}},	//   јала_, јали_, tseü, _दा_
  { {0xc7d8000b,0x7a3f000e,0xe7360662,0x442d0060}},	//   מודי_, _játé, жеш_, vye_
  { {0x63ad0058,0xf7700003,0x0d850015,0x6569004a}},	//   lpan, راه_, олкн, toeh
  { {0xdce00039,0xbd450003,0xce38000b,0x6f010002}},	//   tomā, تنبي, מאות_, _walc
  { {0x753b000e,0xeb990001,0x63ad0da8,0xfaf50024}},	//   rhuz, јио_, npan, очню
  { {0x637d0054,0x2d9e0066,0xa1c50da9,0x0ee00011}},	//   dènc, ítek_, обод, _नायड
  { {0xf2d2000b,0x443f0002,0x61e50daa,0x5f1d0011}},	//   ועי_, szu_, nthl, मान्_
  { {0x208a0014,0x394f0052,0xa96a035c,0x69c10dab}},	//   ийни_, nigs_, рима_, rsle
  { {0x41c50037,0x637d0054,0xe76a0012,0x27300081}},	//   _विकस, gènc, لحسن_, _bành_
  { {0xdfcf0003,0x179a000b,0x69c10262,0x6b960009}},	//   ضيف_, יישב, psle, _וכסף_
  { {0x2730001a,0x41b50012,0x88bd0034,0x60c90dac}},	//   _dành_, _بمعر, _rośn, _odem
  { {0x2fcd012e,0x6cd60003,0x7d040dad,0x0d99003c}},	//   šega_, تقرا, udis, стры_
  { {0xccf20093,0x637d0054,0x78a201e9,0x8b260a32}},	// [1940] וכן_, cènc, vcov, одае
  { {0x60c902d1,0x636f0260,0xe3b70024,0x7bd60060}},	//   _adem, møns, юбу_, ruyu
  { {0x11d70012,0xf8bf0025,0x6370008e,0xdb0901e3}},	//   قولة_, ckés_, dänt, nseñ
  { {0xcb090093,0xbfaa0001,0x99520030,0x69c30dae}},	//   כל_, атке_, tář_, ânea
  { {0x98a30015,0xbc1a0024,0x38600060,0x65610031}},	//   фиче, _тіні_, çir_, élhe
  { {0x200d008b,0x60c9003a,0xfda60001,0x60090009}},	//   _drei_, _edem, ојим, מִצְ
  { {0x64490065,0x99520066,0xa3dc0011,0x64620034}},	//   _þeir, sář_, तंभ_, źwię
  { {0x6abc014d,0xe0d7002d,0x200d0daf,0xc6930009}},	//   _herf, _мвс_, _frei_, ואו_
  { {0x6abc0065,0x74140003,0x64400027,0x7bc40db0}},	//   _kerf, سودا, uzmi, nsiu
  { {0xba0a0014,0x78790009,0x128a0048,0x9a8a0048}},	//   ахме_, _הָעו, ищни_, ищна_
  { {0xba9b000b,0xa6a90003,0x9af7000b,0x329b0009}},	//   יסיי, _طالق_, חזיק_, יביד
  { {0xe8d90020,0x637d0054,0xe1670012,0x29040db1}},	//   _thử_, tènc, تدخي, _jama_
  { {0x74130012,0x87070048,0xb89a0030,0x2cbf0064}},	//   _يوما, ояве, _šťáv, _ľud_
  { {0x637d03eb,0x290400c6,0xcc770009,0xfe790030}},	//   rènc, _lama_, _ועדה_, řům_
  { {0xda6f002d,0xce940014,0x637d0054,0x454b002d}},	//   _ця_, даръ, sènc, ачам_
  { {0x5c9908b0,0x2905001e,0x29040db2,0xa6340024}},	//   ская_, ēlas_, _nama_, єнті
  { {0xdfdb0014,0x6370006f,0x6abc00b6,0xdb16008e}},	// [1950] _тъй_, jäns, _berf, ksyä
  { {0xd371000a,0xc7b2000b,0x501c000b,0xf549001a}},	//   رها_, _רבי_, _כוחו, hấp_
  { {0x78bb0108,0x6abc0989,0x7bc40db3,0x637008fb}},	//   _peuv, _derf, asiu, vänt
  { {0x26080011,0xc0cb004c,0x7af70db4,0xc9870681}},	//   हिरी_, руже_, sext, цузи
  { {0x251a000b,0x6370004a,0x78bb0025,0xb4c90011}},	//   _הורא, tänt, _veuv, ैली_
  { {0x7052000a,0xa858000b,0x200d000d,0x46a50014}},	//   عنوا, חידה_, _vrei_, чакв
  { {0x31c40001,0x67280027,0x99d40012,0x637401a0}},	//   _оств, _dodj, _يتفا, càni
  { {0x200d000d,0x365c0009,0xb65c0009,0xbdf80012}},	//   _trei_, יכונ, ידוש, ترها_
  { {0xdb090028,0x69bd0037,0x27ff005e,0xdb1b0018}},	//   fseð, वीनी, _usun_, ssuí
  { {0xeb9f0058,0x466b0db5,0x60dd0db6,0x4a450db7}},	//   _esøg_, _крем_, egsm, знов
  { {0xe8030044,0xce380003,0xa2dd0037,0x6aa50032}},	//   लिका_, _وأما_, पलब्, ichf
  { {0x6d4b0052,0xb6070010,0x6723017b,0x69c50db8}},	//   _umga, rašė, ljnj, ishe
  { {0x88bd0002,0x4c9a0009,0xc49a0009,0x17fa0012}},	//   _rośl, _הבנו, _השנת, حرجة_
  { {0x2d9c000f,0x539a000b,0x69c70027,0x395f0248}},	//   _évek_, _פיצו, _ovje, _ljus_
  { {0x6b9d008b,0xb2ba000b,0xa2ba0009,0x2aba0009}},	//   _ausg, _המצר, _המצט, _המצא
  { {0xe9a80003,0xccf90002,0x69c50db9,0xdb0d0060}},	//   _بدون_, neś_, dshe, asaü
  { {0xf993000b,0x7bc40010,0x68fb0051,0xc9850012}},	// [1960] _ארה_, usiu, õude, _تشوي
  { {0x7bc4007d,0x63740054,0x799c00b6,0x6370008e}},	//   rsiu, tàni, _purw, väns
  { {0xa2dd0044,0x27340163,0x6abc0732,0xa69b000b}},	//   _पार्, _länk_, _verf, _לשיפ
  { {0x2367001b,0x637401a0,0xdcfe0073,0x6abc016a}},	//   čnja_, ràni, _rupė, _werf
  { {0x29040027,0x67280dba,0x216706bd,0x29060dbb}},	//   _vama_, _podj, чици_, rdoa_
  { {0x63700163,0x4733002d,0x98890009,0x7d060060}},	//   räns, нніс, חָצֵ, _haks
  { {0x27e601d5,0x7d06083c,0xde930001,0xa3c60037}},	//   ston_, _kaks, нашњ, ैंक_
  { {0xda5b000b,0xc5f30009,0x20c90012,0xf8db0011}},	//   _הכלל, גדה_, _وبقي_, _भाइय
  { {0x69c70027,0xad1b000b,0xdbf80011,0x711b0009}},	//   _zvje, מוקר, ्टेड_, _פומפ
  { {0x883b0093,0x5a340014,0xbec2001e,0x44200054}},	//   _התמו, днот, šība, ixi_
  { {0x7643003e,0x6d950010,0x65870028,0xcb130009}},	//   czny, _išan, árhæ, גלת_
  { {0x44320006,0x395f0051,0xfe370009,0xc27b0009}},	//   kyy_, õus_, _מרבי_, מריי
  { {0x60dd0058,0xfc2f0012,0xcfa7003c,0x2fc60097}},	//   rgsm, _محو_, яшни, nsog_
  { {0x69c5004a,0x3da705cc,0x2c170009,0xa0370009}},	//   yshe, зраб, _מקדש_, לאכה_
  { {0x9e14002d,0x7afa0dbc,0x4b7b0009,0xaa57076b}},	//   ндрі, mett, _האגו, _нишу_
  { {0x3ebe0dbd,0x4a5b000b,0xda5b000b,0x60c20051}},	//   _lett_, _לדוו, _לכול, jaom
  { {0xd11a0037,0x69c70027,0x6d4a001a,0x0fdb0012}},	// [1970] धारण_, _svje, _đoá, _ابعث_
  { {0x2bd40037,0x883c000b,0x69da00f6,0x7afa0dbe}},	//   _दिना, _לתחו, oute, nett
  { {0xf9f90003,0x26c3009b,0x6aa50052,0xceb20009}},	//   تفاع_, majo_, rchf, _שיט_
  { {0x7afa0b0c,0x69da0051,0x26c3009b,0x6aa50032}},	//   hett, iute, lajo_, schf
  { {0xfc640014,0x394d009b,0x96c10011,0x7afa0dbf}},	//   _зърн, _vmes_, वरपॉ, kett
  { {0x7afa0dc0,0x8c1a0009,0xb9e70024,0xe29a0081}},	//   jett, _וושי, _ніби, _ngư_
  { {0x69c7001c,0x945d0002,0xb4d70037,0x69da0dc1}},	//   _uvje, kańc, _साफ़_, jute
  { {0xbe3c000b,0xa294002d,0x76430002,0x69da03bd}},	//   מעות, _часі, rzny, dute
  { {0x7afa01a2,0xb4ad0044,0x26c3009b,0x67d40dc2}},	//   fett, _कभी_, kajo_, _поту
  { {0x26c3012e,0x6fd20037,0x7afa0dc3,0x81c90593}},	//   jajo_, _सितं, gett, огов_
  { {0x26c3009b,0x2d9e0052,0xb6350012,0xc3320009}},	//   dajo_, _gute_, _تفاع, דוי_
  { {0x2734006f,0x6d400dc4,0x7afa079b,0x2d9c0031}},	//   _tänk_, chma, aett, _évei_
  { {0x7d060039,0x6b400163,0x307a0003,0xf8bf000e}},	//   _raks, _höge, تحدة_, rkép_
  { {0x7afa0dc5,0xdb0b006f,0x26c3009b,0xf456000b}},	//   cett, _avgö, gajo_, _קיסר_
  { {0x2d9e0108,0x4df5007c,0x7d060175,0x55e30021}},	//   ête_, нятт, _paks, корб
  { {0x4432004a,0x19ba0009,0xc1ba0009,0x2bd40011}},	//   tyy_, _ומקב, _ומקש, _दिमा
  { {0x26c30164,0xb9020037,0xd3720012,0x7d090dc6}},	// [1980] bajo_, दल_, نهر_, ides
  { {0x2b160037,0x7d09004a,0x32110066,0x753d000e}},	//   ताएँ_, hdes, _brzy_, _elsz
  { {0x00e6007c,0x3ebe0dc7,0x63510066,0x4432004a}},	//   джен, _rett_, měně, syy_
  { {0x3cf90037,0x3ebe0dc8,0x7afa0dc9,0x7d0600b0}},	//   ्यों_, _sett_, zett, _uaks
  { {0x07fa0003,0x48e30037,0x2d9e000d,0xa09b0009}},	//   تراع_, ट्टो_, _sute_, קיסט
  { {0x4375007c,0xeb9f038e,0xf1c00064,0x69da020d}},	//   _зуст, _prøv_, úšky_, yute
  { {0x68e40017,0x7d090227,0x7afa0dca,0x8a0307e8}},	//   _ocid, fdes, vett, _изре
  { {0x26c3009b,0x3ce00058,0x1d070001,0x69da019a}},	//   zajo_, ngiv_, дећи_, vute
  { {0x7afa0dcb,0x3ebe0dcc,0x14180012,0x671e0011}},	//   tett, _tett_, سيدة_, पादक_
  { {0x2004003a,0xcb670001,0xf7720003,0x7afa0b19}},	//   _ismi_, мање_, _شاء_, uett
  { {0x8f8b000b,0xcad7000b,0x2d9e0051,0x26c3009b}},	//   _וְאֵ, ווית_, _uute_, vajo_
  { {0x914b002d,0x7afa0dcd,0x7d7a0012,0xd257003c}},	//   ічна_, sett, _بمصر_, ьцы_
  { {0xb9070037,0x7afa0dce,0xf5370009,0x945d0034}},	//   _पा_, pett, _קנדי_, rańc
  { {0xab770003,0x637400c1,0x60c00dcf,0x2d8c0227}},	//   _قمنا_, tànu, _lemm, ïden_
  { {0x26c3012e,0xf2060014,0x254c0002,0xe5c40210}},	//   rajo_, _цяло, eśli_, ксто
  { {0x9d180014,0xab5d0002,0x60c00dd0,0x20040dd1}},	//   мост_, duży, _nemm, _osmi_
  { {0xc2cb0003,0xd0110012,0x88bc0009,0xa9680012}},	// [1990] قبال_, _إلخ_, _ומחז, _تميم_
  { {0x3211003e,0x7d0904d7,0xdb090018,0xdb0d0097}},	//   _przy_, zdes, mpeã, gsað
  { {0xe8d90020,0x7d090006,0xd2510003,0xe8070037}},	//   _chủ_, ydes, دنا_, शिका_
  { {0xdce4003a,0xd2570009,0x59df0011,0xeb9f00b0}},	//   mliğ, ושבה_, पंतर, _brøt_
  { {0xdce400a2,0xf4090003,0x7ac70c1e,0x7d090dd2}},	//   lliğ, _عيسى_, _осве, vdes
  { {0x26c1014a,0xaadd0037,0x670f0037,0x32110002}},	//   _jeho_, _माइक, ायिक_, _trzy_
  { {0xd5b1000a,0xdce400a2,0xd0d50014,0x60c00dd3}},	//   دفع_, nliğ, _повъ, _femm
  { {0xd5b10020,0x60c000c5,0x7d09004a,0x629c0002}},	//   ấy_, _gemm, udes, _zgro
  { {0x2d990dd4,0x47d50003,0x6d5a0061,0xe4a80009}},	//   _mise_, _سيار, étai, וֹתָ
  { {0xdce4003a,0x26c10029,0xeab10012,0x42250dd5}},	//   kliğ, _neho_, دعة_, едов
  { {0x9f8a0006,0x4ae20037,0x4439001e,0x78a402a1}},	//   töön_, _पासव, šs_, žive
  { {0xa06a0001,0xfe360009,0xcdb60009,0x186a01c6}},	//   зама_, _ארעי_, _נפנה_, зами_
  { {0x2c6c0030,0x98a40035,0x66050dd6,0x6aaa0dd7}},	//   _kódů_, _jomā_, _ashk, _ffff
  { {0x9f8a004a,0xdb090051,0xcc560009,0x2d990025}},	//   söön_, tseõ, _אבני_, _aise_
  { {0xa3e20037,0xe61701d4,0xd62a02ac,0xbb3a0009}},	//   नून_, ндр_, чове_, _מעסי
  { {0x6283001c,0xa1c20048,0x68e4004b,0x20040097}},	//   _izno, _сбъд, _ucid, æmis_
  { {0xb3860015,0xb7960001,0x4f960103,0x26010011}},	// [19a0] елал, _проћ, _проу, _वैसी_
  { {0xe8d90020,0x539a000b,0x60c0000e,0x661b0030}},	//   _phủ_, פיעו, _semm, ácký
  { {0xdebb000b,0xda1f0037,0xb6bb000b,0x599a000b}},	//   _ממיל, यमित_, _מציי, ִשְׁ
  { {0xe1ff003e,0x7bd50002,0xdb1d006f,0xdb0d0028}},	//   łów_, ązuj, _avsä, ssað
  { {0x7bcf0d85,0x213f0030,0x6d56016d,0x69c80031}},	//   ácul, _dluh_, miya, zsde
  { {0xe8d90020,0x2d99000d,0x629c0a35,0x657b016d}},	//   _thủ_, _zise_, _ugro, eluh
  { {0xceb30093,0x7a460061,0x6b630dd8,0x60c00dd9}},	//   ניה_, _mété, _скра, _temm
  { {0xe2970b05,0x7afe0dda,0x6d440018,0x6d560ddb}},	//   _час_, lept, nhia, niya
  { {0x1be70046,0xa3e70001,0xcd97000b,0xe3b20003}},	//   едњи_, едња_, עדפת_, درع_
  { {0xfd1f0020,0x39400ddc,0x6fb30012,0x3e860030}},	//   _nhìn_, _alis_, _إملا, _cítí_
  { {0xf41f0051,0x7f2b0009,0xd25a0048,0x6d44016d}},	//   äär_, _מֵאֶ, яци_, khia
  { {0xfc660098,0x224500a2,0x84660014,0x88bd0002}},	//   _пълн, _ülke_, _пъле, _dośw
  { {0x6d5600b6,0xd0060003,0x2d9900a5,0x54330012}},	//   diya, جل_, _rise_, _مرور
  { {0x8c1b000b,0xcf980001,0x69de0ddd,0xb9c60012}},	//   _מודי, ејс_, kupe, _كتبه
  { {0xe2130003,0x63a2004a,0x8f8b0009,0xa2bb0064}},	//   _مبيع, _huon, לְלֵ, äčše
  { {0xdce400a2,0x4a7b000b,0x26c1000e,0x8a7b000b}},	//   rliğ, _מרוב, óhoz_, _מאות
  { {0x28b40003,0x2d990dde,0x98170012,0x63a2008e}},	// [19b0] _صحيح, _vise_, _أبعا, _juon
  { {0xdce4003a,0x2d99002a,0x26cc000e,0x5f9500b5}},	//   pliğ, _wise_, ódot_, _шипт
  { {0xcad70093,0xda67000a,0x63a20006,0x32190012}},	//   תובת_, رائي, _luon, بياد_
  { {0xacbb0061,0x6d4406b5,0x7fd50024,0x41550048}},	//   _coût, chia, вікі, ъвес
  { {0xb4cd0037,0x63a2002c,0xf8b20009,0x33950012}},	//   रणी_, _nuon, ׁשׁ_, _للحز
  { {0xbec2001e,0x95c50012,0x25770060,0x7d0d0ddf}},	//   šīna, نيته, rçlu_, ldas
  { {0xfd110003,0xff180009,0xae140011,0xc3320009}},	//   لجة_, תקות_, डियन_, _דום_
  { {0x63a20de0,0x2d9903f7,0xacbb0025,0xfe700012}},	//   _buon, öse_, _goût, حده_
  { {0x2d8d00bd,0x2734006f,0xfc310012,0x59640048}},	//   rmee_, _känt_, شحة_, _съра
  { {0x7d0d004a,0x88bd0002,0x78ad01a0,0xd36e0012}},	//   hdas, _pośw, _afav, يهي_
  { {0xcb12000b,0x61460345,0xd9460de1,0xa96a0de2}},	//   בלי_, вена, вени, дина_
  { {0x7afe0052,0x9c390001,0x7db40003,0x45b60009}},	//   zept, _опет_, _إصلا, _יפעל_
  { {0x62830002,0x60c6003a,0x69de0de3,0xeb8e0de4}},	//   _wzno, rakm, zupe, _ви_
  { {0x41d10037,0x661a006f,0x75290864,0x7d0d07ea}},	//   _हिंस, åtko, ljez, edas
  { {0xc8b60015,0x752f0002,0x6d560de5,0x50b6096e}},	//   _испы, _bocz, tiya, _испу
  { {0xe8d90020,0xc56300de,0x32070032,0xdcf60073}},	//   _phụ_, акск, _isny_, plyč
  { {0x7d0b0101,0x7afe007d,0x64490052,0xf74a0012}},	// [19c0] _mags, tept, nzei, _يلبي_
  { {0x60c405df,0x6d560de6,0x4e7a0003,0x8c95002d}},	//   _heim, siya, _يحدد_, урсі
  { {0x64490052,0x3cea0037,0x7afe0de7,0x6d56020d}},	//   hzei, _छापे_, rept, piya
  { {0x7d0b0101,0x6c860003,0xe8d9001a,0xdfd20012}},	//   _nags, _للجم, _thụ_, ليص_
  { {0x87e30015,0x68e20de8,0xacbb0025,0xc0e301c6}},	//   ающе, rgod, _voût, рочк
  { {0x27340051,0xe72f0003,0xdbdb0097,0x75290031}},	//   _tänu_, قصى_, _ráðg, ejez
  { {0x24800039,0x63a200c1,0x64490052,0x2d9c000e}},	//   _šim_, _suon, ezei, _éves_
  { {0x90a50003,0x64490052,0xda4b0009,0x26c7020d}},	//   _محكم, fzei, _חֲמָ, aano_
  { {0x7d0b0de9,0xe8d7000b,0xbb74004c,0x6be30012}},	//   _dags, _שומר_, лгиј, لكيم
  { {0x63a20006,0x39460149,0xdced0027,0x7d0d000e}},	//   _vuon, lhos_, plać, zdas
  { {0x1b770003,0xf549001a,0x2bd40011,0xd3370009}},	//   خصية_, hấy_, _दिवा, דריה_
  { {0x39460149,0x51870001,0x96550048,0x0e570009}},	//   nhos_, ђуна, _съуч, _בשבט_
  { {0x1b2a0003,0x752f0002,0x934603e2,0xe53b0009}},	//   _يأتي_, _rocz, _инде, _קתדר
  { {0x53330001,0xec37000b,0xf0930009,0xee87003c}},	//   _вешт, _באדר_, ינר_, выбо
  { {0x752f003e,0x7e860013,0xa4d5007c,0xa3a80037}},	//   _pocz, _úspě, лові, _खंड_
  { {0x3544002d,0xc1790010,0x7d000ccd,0x90450012}},	//   ахув, rtės_, nems, _منعه
  { {0x24580047,0x7d0d00c6,0xc1790010,0x26c70dea}},	// [19d0] вать_, rdas, stės_, yano_
  { {0x16020044,0x7d1d000e,0x7cde000d,0xdf390012}},	//   लबार_, össz, tărâ, _أكدت_
  { {0x26c70deb,0xb9c40012,0x752f0034,0x995c0030}},	//   vano_, لقلي, _tocz, líř_
  { {0x26c7003e,0x28a70011,0xdce00030,0x09e40024}},	//   wano_, कुचि, romě, роїн
  { {0x69da0052,0x386901d7,0x7529001b,0x26c70dec}},	//   hrte, çar_, vjez, tano_
  { {0xa03c000b,0xaed20001,0x99d70012,0xda660012}},	//   ועדפ, бољш, _لترا, _هُ_
  { {0x7d0b0101,0x78a40ded,0xb062004a,0x15f50012}},	//   _pags, živa, _ääni, استح
  { {0xf3ff05ab,0x24090047,0x39460dee,0x7bcd001e}},	//   ção_, ении_, chos_, osau
  { {0xeb99035b,0xa1580001,0x91b0001a,0x69da0def}},	//   нии_, _рату_, _đảo_, erte
  { {0x6449008b,0x2b1c0044,0xe7300003,0x753b0066}},	//   rzei, नाएँ_, _وصل_, skuz
  { {0x64490df0,0x7d0b09c5,0x7ae50df1,0x2bc40011}},	//   szei, _tags, ight, लीबा
  { {0x4a42002d,0x6146003c,0x48e30024,0x4c150012}},	//   снюв, уема, боюв, _مبتس
  { {0xe5700012,0x44270012,0xed590030,0xfd1f0081}},	//   _بطل_, _جراف, miž_, _chìm_
  { {0xe8e00011,0x06760048,0xed59009e,0x26c509ef}},	//   _पञ्च, губя, liž_, _jelo_
  { {0x2009016d,0xad660012,0x39590df2,0x26c50df3}},	//   _esai_, هاره, biss_, _melo_
  { {0x41b20003,0xc27a000b,0x2cad0df4,0xf1b20009}},	//   _امير, _ארצי, nced_, _פסח_
  { {0xc953000b,0x7ff60003,0x61e10df5,0xf2da0012}},	// [19e0] _למה_, _إسبا, lull, فظات_
  { {0x909b000b,0xec7702e2,0x68e90017,0xaf060187}},	//   _אספק, упу_, _aced, _спол
  { {0x21200066,0x61e10df6,0x6fc10011,0xe0da05c6}},	//   _knih_, null, रीसू, еве_
  { {0x9fca0015,0x6b400028,0x2bd40037,0xa3a60012}},	//   егда_, _gögn, _दिला, _محسن
  { {0x6b9c001e,0xf7f30003,0xc7af0012,0x43860012}},	//   _tirg, مسود, كّن_, _ملحق
  { {0x26c504d2,0xd00f0012,0x1eaa0012,0x96f80048}},	//   _celo_, ثله_, راتي_, тект_
  { {0x21200027,0x7bdb004a,0x26c502a1,0xaa460048}},	//   _onih_, eruu, _delo_, _севл
  { {0x65640028,0x29020027,0x69da0066,0x1d340014}},	//   nnih, jeka_, vrte, рния
  { {0x69d50066,0xdd040010,0x7866064f,0xb8660003}},	//   ázen, ūrės, _сказ, _صارو
  { {0x25a50df7,0x57fb0009,0x69da0159,0x26c50713}},	//   _full_, _אלמו, trte, _gelo_
  { {0x0377000b,0x6576004a,0x87170009,0x5ce60012}},	//   רתית_, koyh, _תקבע_, _مكال
  { {0x26c5012e,0x63700052,0x64a60df8,0xd7e70024}},	//   _zelo_, gänz, _сада, ліго
  { {0xd0e60044,0x3f9e0010,0xdce9003a,0x54360003}},	//   _कारण_, _kitu_, lleğ, _حرار
  { {0xa294002d,0xb4cd0011,0x69da0159,0x92940451}},	//   _калі, रण्_, prte, _калц
  { {0x3f9e0051,0x63a60028,0x99ea0012,0x56950024}},	//   _mitu_, _aukn, _أعتق_, равт
  { {0x2d800df9,0x721b0009,0x867b0009,0x7bcd0dfa}},	//   glie_, _טווח, גרלו, tsau
  { {0x200900b6,0x26050011,0x5c99003c,0x13b40012}},	// [19f0] _usai_, _हैरी_, ткая_, مصلح
  { {0x7ae5002a,0x94740003,0xd4980dfb,0x6d5a0025}},	//   ught, صدقا, урс_, étar
  { {0xaadb000b,0x05790003,0x798d00b6,0x70b50003}},	//   תחבר, _لمدة_, _khaw, لماض
  { {0x7bcd03fc,0x11280014,0x481501de,0x82340012}},	//   psau, лючи_, имес, حركا
  { {0xf771000a,0x26c50149,0x25a501a2,0xf1050011}},	//   يات_, _pelo_, _sull_, _रसीद_
  { {0x3f9e0039,0x7bda000b,0xddc80010,0x45d505fb}},	//   _citu_, _בקשו, _dydž, ацит
  { {0x6b40008b,0xddc20063,0x65c202ad,0xed5900d9}},	//   _mögl, общи, обща, tiž_
  { {0x61e10006,0xd6580093,0x25a50054,0x6b400097}},	//   vull, טיות_, _vull_, _lögl
  { {0x2d53007d,0xa3e50037,0x2cad0dfc,0x442901a0}},	//   nţei_, बंध_, rced_, nxa_
  { {0x3f9e00b6,0xab350001,0x61e10dfd,0x44290521}},	//   _gitu_, рхиј, tull, ixa_
  { {0x2902017b,0x7bdb0269,0xcb120009,0x69260229}},	//   teka_, sruu, קלט_, амна
  { {0x273d0020,0xb33b003a,0xe8f7002d,0x60cb0dfe}},	//   _hình_, _suçl, алю_, nagm
  { {0x290200ec,0x22590034,0x88ba0009,0xb4db01a0}},	//   reka_, ńsk_, כזרי, _plàn
  { {0x61e1004a,0x6c840012,0x8f760024,0xd007004c}},	//   pull, _الهم, румі, јере_
  { {0x26ca012e,0x273d0020,0x3f84001e,0x6f0301e3}},	//   rabo_, _mình_, ēmu_, ienc
  { {0xdca30109,0x20560dff,0x6f030e00,0x6d490e01}},	//   жати, _втор, henc, nhea
  { {0x7c3b00b6,0xb97b0009,0xebe60024,0x717b0009}},	// [1a00] nyur, _בנקי, розп, _שנפס
  { {0xa03b0009,0xdcfb001b,0x224d0030,0xf746004c}},	//   _סעיפ, dluč, _řeka_, _ђено
  { {0x6edb000b,0x6b81006f,0xa3e50037,0x7edb0009}},	//   _בחיפ, illg, बूत_, _בקיצ
  { {0xd9460001,0x61460001,0x3f9e06db,0xc05a0024}},	//   једи, једа, _situ_, кіл_
  { {0x273d0020,0x4cbb000b,0x88bd0002,0x7d040723}},	//   _bình_, _בזכו, _pośr, meis
  { {0xed590029,0x69c30444,0x7d040e02,0x9f530024}},	//   ďže_, _owne, leis, овіч
  { {0x69d50066,0xbd6a0014,0x76a90024,0xad460357}},	//   ázel, крие_, утів_, ихик
  { {0x7d040006,0x6d490e03,0xc0e30e04,0x2fda0012}},	//   neis, ghea, _моск, _لورد_
  { {0xc34a0014,0x7cf1000e,0xdee605f7,0x6f030e05}},	//   вяне_, lóró, _вози, benc
  { {0x79820036,0x6370004a,0xef170024,0x7d040e06}},	//   llow, täny, _кму_, heis
  { {0x7d04050d,0x32180030,0x6d46008e,0x7e970012}},	//   keis, íry_, _olka, _ننكر_
  { {0x7d04004a,0x9257003c,0x6d490e07,0x5a330024}},	//   jeis, рают_, chea, інят
  { {0x386d003a,0x5f770012,0x2bdd0011,0x67220011}},	//   çer_, لاسر, _मिया, मांक_
  { {0xc058002d,0x6d460e08,0x1bfb000b,0xc43b000b}},	//   рію_, _alka, _סלוב, _בתדי
  { {0xd378001c,0x8b8b0009,0x7aef01bd,0x84c7004c}},	//   moć_, _בָהֶ, žitý, иљад
  { {0x929b0093,0xe29b000b,0x4a9b000b,0x44290054}},	//   _ביות, _בשור, _ביוג, txa_
  { {0xf8bf03eb,0x79460002,0x6d400070,0xdfd10003}},	// [1a10] mbé_, _wówc, ikma, _عيد_
  { {0x442903eb,0x6d460070,0xa87c000b,0x2d53004b}},	//   rxa_, _elka, _באחר, rţei_
  { {0x55590014,0x3f8300eb,0x92b40012,0x41e70024}},	//   _баня_, mlju_, تحقا, різа
  { {0x97c50003,0xae1a000b,0xd8b80012,0x79820034}},	//   مقصو, _עורכ, لدها_, glow
  { {0xa054002d,0xb8f20012,0x69de0e09,0x3f830412}},	//   овці, سكوب, arpe, olju_
  { {0xdc9a0009,0xd2460012,0xc5f50012,0x366904a5}},	//   _תישל, _فن_, مثبت, лало_
  { {0x60cb002c,0xed590a2c,0xd5e80012,0x6e440012}},	//   pagm, лок_, لعين_, ينهم
  { {0x7c290054,0x7bdf0e0a,0x9f5f0097,0xc5370009}},	//   txer, orqu, _eruð_, יָ֖ה_
  { {0x273d0020,0x7c3b0060,0x6d490e0b,0x2eb70011}},	//   _tình_, uyur, rhea, _अभूत
  { {0x6aa400a2,0x3b090001,0xf7850012,0x2bdd0011}},	//   _şifr, ћено_, _الطَ, _मिठा
  { {0x60c90e0c,0xdce9001b,0x27e90073,0xbe150012}},	//   _keem, sleđ, šinę_, _دواع
  { {0x64580002,0xcea90009,0xd12f0012,0xa3e20011}},	//   _ściś, _טי_, ّمَ_, नूँ_
  { {0x8d74000a,0x05740003,0x7d740003,0xd05a002d}},	//   _بالا, _بالد, _بالط, урні_
  { {0x7d04008b,0xf1a70037,0x60c9000e,0x8c1a000b}},	//   weis, गदान, _leem, _תוסי
  { {0x19b50003,0x78a9009b,0x7bdf0054,0xf8bf000e}},	//   _احتج, ževa, erqu, bbé_
  { {0x60c90070,0x3f8308ab,0x42360009,0x90c60148}},	//   _neem, alju_, _לנצל_, _убие
  { {0x44260149,0x3f830027,0x7d040e0d,0x6d580073}},	// [1a20] ão_, blju_, reis, _įvad
  { {0x291202d1,0x7d04015e,0x63bb0e0e,0x00570009}},	//   _haya_, seis, ipun, _לשפת_
  { {0x29120175,0x993a002d,0xe9da096e,0x88bd0034}},	//   _kaya_, ляду_, уке_, _pośp
  { {0xc693000b,0x291200b6,0x908a0012,0xf1b20009}},	//   _מאת_, _jaya_, هناك_, פסד_
  { {0x8ff7000a,0xdfcf0003,0x69d50066,0xe73a0e0f}},	//   مرور_, فين_, ázej, лед_
  { {0x78250003,0xa09b000b,0xceb30009,0x389b0009}},	//   تعمل, אינט, ֔יו_, איננ
  { {0xceb3007e,0xd6d9002d,0xa96a00f5,0x2dd70012}},	//   היו_, рті_, _бива_, مبية_
  { {0x93b40024,0xfc4608ca,0x7d1c0035,0xebd80b2b}},	//   обиц, šími_, ērso, адиш_
  { {0x63bb0e10,0x3cf70012,0xe56f0012,0xcbc60012}},	//   gpun, صعيد_, عطى_, حزبي
  { {0xaaba0044,0x51f8002d,0x68fb0b32,0x68ed06d5}},	//   ेरिक, аною_, _zbud, _scad
  { {0x8e860003,0x3f830027,0x7c240010,0x3f9b0025}},	//   _الاه, vlju_, _šird, ïque_
  { {0xa8990001,0x71470015,0xdd8f0012,0x000000c4}},	//   икну_, схож, _كول_,
  { {0x291200c6,0x04960003,0xdfc60012,0xf8bf0025}},	//   _daya_, _الشح, بي_, rbé_
  { {0xf8bf0031,0xec670009,0x000000c4,0x000000c4}},	//   sbé_, _ל֑וֹ_,   ,
  { {0xd5d80009,0x98b90035,0x637d01a0,0x99d30012}},	//   יַּש, aksā_, rènt, _فتيا
  { {0x52830003,0x29120e11,0x78a4001b,0xe16b0012}},	//   _عليك, _gaya_, živj, _حصته_
  { {0x99480003,0xfd4f001a,0x8335022a,0xe5340024}},	// [1a30] _دليل_, _khiế, онах, четь
  { {0x60c90e12,0x394900d9,0xe3c40012,0x02a70217}},	//   _seem, _hlas_, سْمَ, срам
  { {0xe5350015,0x8afc0002,0x27ff0e13,0x3ce900ad}},	//   _день, międ, _spun_, pgav_
  { {0x6f070034,0xb9250012,0x28f9003c,0x6b400097}},	//   lejc, تفصي, редь_, _lögh
  { {0x6aa9000d,0x88c80024,0x95160009,0x63bb0e14}},	//   _şefu, слів_, _וקרא_, xpun
  { {0x8afc0002,0x43940048,0x68fb0034,0xfd4f0081}},	//   nięd, _наяс, _wbud, _nhiế
  { {0x60c9035f,0xc5d5002d,0x39490717,0xaa5d0557}},	//   _teem, ціль, _olas_, _ревi
  { {0x2bd40044,0x63bb0e15,0x68fb0027,0x1c450024}},	//   _दिखा, tpun, _ubud, жним
  { {0x69da0163,0x291200c6,0x1425002d,0x6fe00037}},	//   _åter, _raya_, ідом, _नियं
  { {0xfd4f008a,0x291200ec,0x6d5e0061,0x98880009}},	//   _chiế, _saya_, épar, _הָעֵ
  { {0x6f070066,0x63bb0e16,0x6d4809d4,0x466b0048}},	//   dejc, spun, ūdai, _срам_
  { {0x6fe00037,0xdced0027,0x7c240027,0x78a900eb}},	//   _निमं, klađ, _šire, ževn
  { {0x29120164,0x224d0066,0x88f60009,0x8d740012}},	//   _vaya_, _řekl_, חזרו_, _عاما
  { {0x409a000b,0x39490017,0x65690e17,0x889a0009}},	//   יברס, _elas_, lneh, יברי
  { {0x0b780003,0xa3e50011,0x4536052c,0x9ae80009}},	//   _اصنع_, बूर_, охат, _הַפִ
  { {0x63a307f6,0x6d43000d,0x91b0001a,0x6283002c}},	//   _hinn, _înal, _đào_, _iyno
  { {0x63a30005,0xe577002d,0x5aca0109,0xd9970012}},	// [1a40] _kinn, ізу_, илам_, _بنيت_
  { {0x5db60012,0x261a0011,0x657b0064,0xf77f0018}},	//   _وإجر, _मछली_, houh, puça_
  { {0x0b170003,0x443f00b6,0x8afc0002,0x321c0004}},	//   تقلة_, hyu_, sięg, ívy_
  { {0x63a30176,0x6d4d0070,0x3a99003c,0xe3a70012}},	//   _linn, chaa, стую_, _ير_
  { {0xee020044,0x34a7002d,0x65690029,0xc9530009}},	//   लब्ध_, _євро_, dneh, ומא_
  { {0x501b000b,0xcdda0001,0x175404b3,0x6d440010}},	//   יונו, ањи_, явля, lkia
  { {0x7946003e,0x63ab0065,0x65690052,0xdce4017b}},	//   _równ, _augn, fneh, hnič
  { {0x6d44007a,0x628e048b,0x91030001,0xf8bf000e}},	//   nkia, _izbo, _опсе, njét_
  { {0x63a300bd,0xfd4f001a,0xddce0002,0x6d440010}},	//   _binn, _phiế, ódło, ikia
  { {0x60c20010,0xba540001,0x7d16004a,0xdce40e18}},	//   lbom, звој, hdys, dnič
  { {0x6d44004a,0x8f9b000b,0xdb0f000e,0x63a30802}},	//   kkia, _כימי, ödés, _dinn
  { {0x63a305df,0x8ba60148,0x3ce40011,0x443f020d}},	//   _einn, _дидж, गलों_, byu_
  { {0xfd4f0020,0xe0870012,0x299b0009,0x69d80030}},	//   _thiế, تجدي, יסטמ, ávej
  { {0xdb20004a,0x62660012,0x6d440073,0x3b070048}},	//   ätäm, _واثق, ekia, _мечо_
  { {0xcf57000b,0x26cc0017,0x4db80009,0xc5b80009}},	//   קבלת_, _medo_, מֶּנ, מֶּר
  { {0xdfd10012,0x2010008e,0x26cc0e19,0x63a30e1a}},	//   _كيب_, äliä_, _ledo_, _zinn
  { {0xb2ab0015,0x54550014,0x3172000e,0x6d4d0e1b}},	// [1a50] атеж_, чват, ézze_, rhaa
  { {0x2bdd0037,0xce950014,0x60c20033,0x60cd005e}},	//   _मिसा, _напъ, ebom, _heam
  { {0xa2ad015f,0x60cd00b6,0xc4c70012,0x5f740012}},	//   जशब्, _keam, _وتحو, _تاير
  { {0x7ff50003,0x6440004a,0xa1590001,0x89a80024}},	//   كستا, kymi, љаду_, іків_
  { {0x6fc60037,0x65690029,0xecb60009,0xf48402bb}},	//   रीलं, vneh, _מפרץ_, _журн
  { {0xdc3a000b,0x4c9a0009,0xc43a0009,0x2bc40011}},	//   _העשר, _לברו, _התשי, _लौटा
  { {0x65690e1c,0xa2a20011,0x86980048,0xc3320009}},	//   tneh, _कृप्, отът_, _אום_
  { {0xe5050012,0x70b50011,0x442d01a0,0x63a30e1d}},	//   سبعي, ंडोल, txe_, _sinn
  { {0x399b0333,0xb4bb0044,0x65690e1e,0x69dc000e}},	//   _jūsu_, _अभी_, rneh, áren
  { {0x399b0039,0xaacb0044,0x657b0066,0x6d930e1f}},	//   _mūsu_, िरिक, souh, lçad
  { {0x171a000b,0x6d440e20,0x63a30e21,0x60cd0e22}},	//   _לֵאמ, ykia, _vinn, _beam
  { {0x8dfa000b,0xdce40027,0xf9920003,0x6d930e23}},	//   _להעת, tnič, عبد_, nçad
  { {0x62830002,0xd40b0012,0x10160012,0xe81e0011}},	//   _wyno, _ختام_, أبجد, पिया_
  { {0x26cc0149,0x907a000b,0x20dc001a,0x61e80d1f}},	//   údo_, מטרי, ửi_, budl
  { {0xdce409ea,0x65c60014,0xd946096e,0xf8bf000e}},	//   snič, ябва, _неки, tjét_
  { {0x2a3a000b,0x7d090e24,0x89da000b,0xb33b0017}},	//   _לעצמ, nees, _החקי, _muçu
  { {0x6fb30012,0x945d0034,0x6d440e25,0x23e50557}},	// [1a60] _كميا, mańs, rkia, дієв
  { {0x7d090006,0x8eea002d,0x8afc0002,0x629a0042}},	//   hees, _умов_, mięc, _útok
  { {0x64400002,0x26cc0e26,0x7f3b0009,0x2f3b0009}},	//   zymi, _redo_, _העיו, _הגיד
  { {0x7d09008e,0xd1300012,0xfaf80035,0x33d60024}},	//   jees, ضمت_, lnīt_, _нігт
  { {0x2d82045d,0x8afc003e,0xc953000b,0xad1b000b}},	//   _ikke_, nięc, עמד_, _הוכר
  { {0x6d4b0005,0xc7d70009,0x6d930018,0xb33b0060}},	//   _alga, לוני_, açad, _buçu
  { {0x945d0002,0xb5aa0003,0xa91b0028,0x78ad080a}},	//   kańs, حاتك_, amþy, žava
  { {0xe5a30001,0x6da30001,0x945d0002,0x64400e27}},	//   нији, нија, jańs, tymi
  { {0x6fb60003,0x945d0034,0xd37a0048,0x7bd6016d}},	//   _رمضا, dańs, йчо_, nsyu
  { {0xcc57000b,0x49d8002d,0x2900000d,0xdc8b0009}},	//   פסיק_, одою_, _abia_, מְיָ
  { {0x60cd0005,0xc333000b,0xf1c3001a,0x22f70009}},	//   _peam, תות_, _nhớ_, הזין_
  { {0xf8cc0044,0x39460010,0xce050012,0x2fd90012}},	//   ारिय, nkos_, _تذكي, يوجد_
  { {0xb97b000b,0xb4e80011,0xc9530009,0xcc290012}},	//   מנטי, बली_, תמר_, _وأهم_
  { {0x90980014,0x4c9b0009,0xd7f80842,0x8beb00af}},	//   явят_, _הבדו, чую_, _הַה֗
  { {0x8afb000b,0xfe700003,0x12fb007e,0xb87b000e}},	//   _להגי, هدف_, _להגב, egít
  { {0x2d580047,0x6b400065,0xe8d90081,0x25bb00af}},	//   пись_, _mögu, _thự_, מצלמ
  { {0x6b400028,0xcf270003,0x6728001b,0x8afc0034}},	// [1a70] _lögu, _فردي, _ondj, cięc
  { {0x2aab0046,0x43740012,0xe9ff0081,0x722b0223}},	//   стао_, ّهْر, _hoại_, йцев_
  { {0x442b0020,0x7f3c000b,0x32b80003,0x2247000e}},	//   ̣c_, _לעזו, سدلة_, ánk_
  { {0x2bdd01e1,0xe298002d,0xa3b5002d,0xbcfb0164}},	//   _मिला, чає_, _обмі, _ejér
  { {0x29d80020,0xdb1b02d1,0x16a90015,0x6d930c56}},	//   hĩa_, spué, овли_, rçad
  { {0xe9ff0020,0x7d090070,0x69d800c1,0x40320001}},	//   _loại_, wees, _ovve, тељс
  { {0x7d090006,0x8afc0002,0x8e090024,0x32110034}},	//   tees, zięc, інив_, _uszy_
  { {0x6b400028,0xe3b90829,0x25de0011,0x9e640012}},	//   _dögu, оби_, _गिरी_, عاون
  { {0x46bf0037,0x656d002c,0x69d80e28,0x96bf0011}},	//   ्राह, inah, _avve, ्राउ
  { {0x99060037,0xaadd0037,0xdb030e29,0x7d090038}},	//   षज्ञ_, मणिक, _xinè, sees
  { {0xdb030066,0x63a70070,0x02b60009,0x66f20011}},	//   _jiné, _mijn, ולתך_, _घातक_
  { {0x2ec60037,0xe6c60037,0x69d80017,0xdce00010}},	//   वर्त, वर्ज, ávei, domė
  { {0x657c000e,0x5b350003,0xdb030025,0x945d0034}},	//   _írha, _يعتر, _liné, rańs
  { {0x4c9a000b,0x1ea90012,0x626500db,0x22680030}},	//   _ובנו, كافي_, _овла, átká_
  { {0x8afc003e,0x656d0052,0x945d0002,0x2aba0009}},	//   sięc, fnah, pańs, _ומצא
  { {0x19870014,0xa1870014,0x8afc0034,0x656d0e2a}},	//   _общи_, _обща_, pięc, gnah
  { {0x63a70070,0xf9930009,0x31600060,0x69c10e2b}},	// [1a80] _bijn, _ברה_, _imiz_, lple
  { {0x394d000d,0x656d002c,0xdb090164,0xe8410030}},	//   _ales_, anah, mpeó, ůběž
  { {0xceb30093,0x6b52014f,0xdb030c70,0xe2930009}},	//   _בית_, _lægg, _ciné, תְּ_
  { {0x39460010,0x78ad013a,0x76430034,0xceb90030}},	//   ukos_, žavn, dyny, ěře_
  { {0x6b400028,0xaac60012,0x41170012,0xb4db01a0}},	//   _sögu, _يتسن, بينج_, _clàu
  { {0x394d0149,0xd5ba011f,0x46140003,0xcfa90003}},	//   _eles_, оси_, فوتر, ساهم_
  { {0x53a70044,0xda650003,0x90e60003,0x7769032f}},	//   _कूटश, _كافي, _يسرن, éexi
  { {0x69c10070,0x63a70070,0xb4e80037,0xa2c60037}},	//   dple, _zijn, बले_, िरक्
  { {0xcd330003,0x6fb30012,0xa2a20011,0x0083004c}},	//   ضريب, _لمقا, _कृत्, _алто
  { {0x5a340014,0x628f0002,0x883b0009,0x25f60011}},	//   енот, ęcon, _ותמו, _एमपी_
  { {0x6b400163,0xcb13000b,0x6e460012,0x290b0e2c}},	//   _högs, דלת_, _تنام, teca_
  { {0x1c460001,0xdb1b0097,0x041a0012,0x3ea30031}},	//   _онем, ssuð, _ويضع_, _újta_
  { {0x6d43007d,0xfc2f0003,0x104b002d,0xb8d70011}},	//   _înai, _نحو_, іями_, _जल_
  { {0x290b013a,0x2bb50011,0x4034004c,0x0b180012}},	//   seca_, _अंबा, њерс, _رقبة_
  { {0x63a70834,0x656d0032,0x6b400097,0xd9f20011}},	//   _rijn, tnah, _lögs, _अमित_
  { {0x994400a2,0x61e506dd,0xa87b00ae,0x63a70a82}},	//   mış_, vrhl, _وحظر_, _sijn
  { {0x656d0052,0x1eab0003,0x78ad0051,0x9944003a}},	// [1a90] rnah, _وادي_, _igav, lış_
  { {0xa3e60044,0x1b780003,0x8c1b000b,0x656d0e2d}},	//   _बटन_, وصلة_, חומי, snah
  { {0x3992000f,0x27e60164,0x44220033,0x64b30066}},	//   lása_, eron_, _erk_, třič
  { {0xe4eb0003,0x7e9a0009,0x0e9a0009,0x63a70227}},	//   _بعده_, _מסתו, _משתל, _wijn
  { {0x80270003,0x3992000e,0x7d0d0e03,0xb8220011}},	//   برام, nása_, meas, मियम_
  { {0xf773000a,0x7d0d0e2e,0x9944003a,0x7643004a}},	//   خاص_, leas, kış_, tyny
  { {0x753d003e,0xce490015,0x27e60e2f,0xc1770012}},	//   _kosz, язке_, aron_, _قدرت
  { {0x929400bb,0x7d0d0e30,0x27e60e31,0x39920031}},	//   _расц, neas, bron_, kása_
  { {0xf8b2000b,0x9985000e,0x10140012,0x98140012}},	//   _תשמ_, _élő_, _لبلد, _لبلا
  { {0x3992000f,0xfeb80003,0x6b40006f,0xdb06000e}},	//   dása_, _قامت_, _högr, _kuká
  { {0x5999000b,0xc332000b,0x7c22000d,0xdcfb0066}},	//   ּשָׁ, אוי_, _eror, louč
  { {0x361a000b,0x753d0b8b,0x4abf0011,0xdc75003c}},	//   _מועד, _nosz, _श्रव, _пыль
  { {0x291e0066,0x2d800e32,0x84470012,0x61fa0132}},	//   ěta_, voie_, _تخال, attl
  { {0x7d1b0005,0x79460002,0xa856000b,0xb5aa0012}},	//   ldus, _mówi, גישה_, كارك_
  { {0xceb2000b,0x51f50003,0x2365006f,0xd5b20012}},	//   ריל_, _أستر, milj_, افر_
  { {0x7d1b0e33,0x6fe00037,0x3992000e,0xdb090164}},	//   ndus, _निलं, bása_, mpeñ
  { {0x753d0002,0x6d49004a,0x6b520040,0x032600db}},	// [1aa0] _dosz, ikea, _læge, ндан
  { {0xe2920003,0x7d1b004a,0xa2bb0037,0x6c830012}},	//   هذا_, hdus, शुल्, الْم
  { {0xb4db01a0,0xeef70009,0x6d49008e,0x9af30012}},	//   _clàs, _אמיר_, kkea, اكمت
  { {0x61e3000f,0x7d0d0e34,0x25f60011,0x6a950024}},	//   ánla, ceas, _एमबी_, трує
  { {0x14d7000b,0x5883003c,0xe7860198,0xfc320012}},	//   _אוכל_, лыша, нуко, _صحح_
  { {0x7bc40e35,0xab7a0012,0xf0930009,0x27e60b19}},	//   mpiu, _رمزا_, אנד_, rron_
  { {0x3992000f,0x3872000d,0x6b660061,0x6b810e36}},	//   zása_, _ţară_, _légè, dolg
  { {0x7c22080a,0x21a30001,0x88c50003,0x39ac0066}},	//   _pror, _бисм, _لتكل, _měst_
  { {0x6b81008b,0xb6030039,0x442003eb,0x60d7000b}},	//   folg, āšan, nvi_, _רומא_
  { {0x41e6002d,0x7d1b0051,0x9944003a,0xb7d70003}},	//   німа, adus, tış_, _أولا_
  { {0x44200005,0xf6290003,0xf7770009,0x8b570009}},	//   hvi_, _يسمى_, _טעמי_, גייס_
  { {0x3992000f,0x9944003a,0x44200027,0x6d46006f}},	//   tása_, rış_, kvi_, ökad
  { {0xe53b000b,0x7d0d000d,0xd4090012,0x3d190011}},	//   _מתאר, veas, _يتهم_, _मोटे_
  { {0x7d190002,0x3992000e,0xdca30001,0x23780012}},	//   _zaws, rása_, _сачи, _تمتد_
  { {0x753d003f,0xd5b1001a,0x831b000b,0xa4d5002d}},	//   _posz, ế_, _מוגז, кові
  { {0x2bb50037,0x69da0e37,0xdce00e38,0x39920031}},	//   _अंदा, mste, domī, pása_
  { {0xb97c000b,0xe7cf0037,0x69dc0624,0x7d0d0e39}},	// [1ab0] _מנהי, _सौंप, _avre, reas
  { {0xb4db01a0,0x69da0e3a,0x7d0d0e3b,0xa3e50011}},	//   _plàs, oste, seas, बूट_
  { {0x5ee8000b,0xdcfd001e,0x7d0d0038,0xeb910009}},	//   _אַרְ, _eksā, peas, בָא_
  { {0x6b81000f,0x7bdd0031,0xd4c70024,0x64c40bb7}},	//   zolg, ásuk, _ясоп, nčič
  { {0x69da0052,0x808b0012,0x12e70024,0x399e0030}},	//   hste, أضاف_, _півг, _růst_
  { {0x82370012,0x6f1a0e3c,0x23650248,0x3f830e3d}},	//   _كرزا, _catc, _ölj_, noju_
  { {0xc8f50098,0xceb4000b,0x69da0e3e,0x6b810e3f}},	//   _извъ, ניק_, jste, volg
  { {0x69da0e40,0x6db10035,0xab640060,0xad650012}},	//   dste, _jāai, rmüş, ضاعه
  { {0x6d490e41,0xeb9900de,0x290f0e42,0x69da0e43}},	//   rkea, мии_, mega_, este
  { {0x290f0e44,0x69da0e45,0x42250024,0x26d30478}},	//   lega_, fste, вдов, _nexo_
  { {0x2bd101e1,0x2d68003a,0x2fc003ce,0x69da0128}},	//   _दौरा, iğer_, _stig_, gste
  { {0x290f012e,0x8afc003e,0x50460001,0x44200010}},	//   nega_, wnęt, вемб, yvi_
  { {0xc8da000b,0x7d1c001e,0x50da0009,0x84440012}},	//   וקרט, ērst, וקרא, _مخول
  { {0x69da0e46,0xdf15007c,0x290f0e47,0x5f060048}},	//   bste, льсь, hega_, ъзга
  { {0x290f019d,0x9a240003,0x02190024,0xf77f0018}},	//   kega_, _معين, _ціль_, arço_
  { {0x290f0470,0x44200d6c,0xa2a20321,0x2d680060}},	//   jega_, tvi_, _कृष्, eğer_
  { {0x290f0005,0x8c430015,0x7bdb00ff,0xc4d20009}},	// [1ac0] dega_, аете, nsuu, יגן_
  { {0x7bdb004a,0x212d00b6,0x74130012,0x60090009}},	//   isuu, _aneh_, ؤولا, _נִפְ
  { {0xa9a60014,0xab5b0052,0xcb12000b,0x5d860012}},	//   вижд, _stüc, שלב_, _للدل
  { {0x290f0859,0xd7e60024,0xadd70009,0x106a003c}},	//   gega_, віко, _בוטח_, мией_
  { {0x6fb30003,0x39400061,0x212d009b,0xdfcf0003}},	//   لمنا, _mois_, _dneh_, قين_
  { {0xbcfb0013,0x69dc0039,0x39400573,0x6d930e48}},	//   _jmén, šrei, _lois_, nçan
  { {0x6f0300a2,0x67040044,0x3999000f,0xceb3000b}},	//   _önce, श्यक_, lése_, סיה_
  { {0x6f1a0a5f,0x4c94022a,0x9418003c,0x69da0e49}},	//   _watc, лийс, ежит_, vste
  { {0x3157000b,0xa5070001,0x3999000e,0x98a30df8}},	//   _סימן_, тења_, nése_, _вите
  { {0x69da0e4a,0x5fdc0011,0x4c9b0009,0xbb540012}},	//   tste, _बिजल, ושפע, اندب
  { {0x39400061,0x26d80010,0x28f9002d,0x995e0030}},	//   _bois_, daro_, нень_, _můž_
  { {0xbcfb0061,0x26d30e0a,0x69da0e4b,0x29e70097}},	//   _amén, _sexo_, rste, _síað_
  { {0x394002b1,0xdb030017,0x3f830071,0x69da0e4c}},	//   _dois_, _dinâ, toju_, sste
  { {0x20e3001a,0x3999000e,0xe6bf0037,0x7c650012}},	//   ổi_, dése_, ्रेज, _حامل
  { {0x39400108,0x7e440001,0x98c70001,0x3f420028}},	//   _fois_, ахте, _испл, _yður_
  { {0xb7d90012,0x8d740012,0xb063008e,0x2d840e4d}},	//   _كوبا_, لاقا, ääss, nome_
  { {0x290f0e4e,0x9da80048,0x5399003c,0x6d5e0025}},	// [1ad0] vega_, търа_, евая_, épay
  { {0x61e3000e,0x93fb000b,0xdca40001,0xa2d50012}},	//   ánlo, ולמי, рађи, ايات
  { {0x6d5c007a,0x290f0e4f,0x7c260052,0x2d840e50}},	//   _įran, tega_, _erkr, kome_
  { {0xe5350015,0x2d840010,0xdced001b,0x98e50012}},	//   _семь, jome_, onač, اكشو
  { {0x69c5002a,0x85960009,0xb4c10011,0x00e40024}},	//   sphe, _תדרג_, ुरी_, ржін
  { {0x7784007c,0x20d10020,0x290f0e51,0xf412000b}},	//   аліз, ại_, sega_, _הפך_
  { {0x6234002d,0x64460033,0xfd110003,0x81d40015}},	//   _керу, økin, مجة_, _восх
  { {0xdb0d02d1,0x2d8d004a,0x6d4d0e52,0x02bd0011}},	//   mpañ, ulee_, nkaa, ोर्न
  { {0xfc310003,0x39400061,0x6b520097,0x26d8020d}},	//   صحة_, _rois_, _hæga, yaro_
  { {0x8fa40001,0xdced0027,0x7c840001,0x7d1d0e53}},	//   _вађе, dnač, јуће, _lass
  { {0x6d4d0006,0x3999000f,0xe6590003,0x39400e54}},	//   kkaa, zése_, _ثلاث_, _pois_
  { {0x2d840036,0x7bdb008e,0x7bc10030,0x6d4d0b8f}},	//   come_, psuu, _člun, jkaa
  { {0xeb8e0098,0xd9e00044,0x2bdd0037,0x39400061}},	//   _ги_, _पट्ट, _मिटा, _vois_
  { {0x224c0031,0x7d1d020d,0x39990031,0x65690e55}},	//   ökké_, _aass, vése_, lieh
  { {0xd3360093,0xb4c10037,0x8db5002d,0xb0630051}},	//   _תרצה_, ुरू_, исті, äärs
  { {0x39990272,0x291e0039,0x23b50037,0x6d4d002c}},	//   tése_, ētas_, _अंशद, gkaa
  { {0xdce00039,0xb8f80037,0xb4e40037,0x7d1d0e56}},	// [1ae0] nimā, िर_, _नयी_, _dass
  { {0x3999000e,0x46f6005c,0x65690052,0xa263001a}},	//   rése_, _счит, hieh, _tuổ
  { {0x3999000f,0xeb970001,0x1efb000b,0x60ea0048}},	//   sése_, ћих_, _אליע, емем_
  { {0x39400065,0x3ce20011,0xfd120012,0xdb090018}},	//   ðis_, _गयें_, _اجد_, mpeõ
  { {0x6f1e0272,0x48e30014,0x2d8404cf,0x61fe0e57}},	//   _kapc, сочв, vome_, stpl
  { {0xe7370014,0xa773002d,0x6df40003,0x8c2b0009}},	//   леч_, бліч, لكتا, _אֵלֵ
  { {0x5fe00037,0x29d1009b,0x7c2402d2,0x62830034}},	//   _निकल, jša_, lvir, żnor
  { {0x44260e58,0x74140003,0xb7d60012,0xf6530009}},	//   _pro_, لوبا, _مقرب, מצו_
  { {0x38560014,0x136a0345,0x9b6a00f5,0x69c30071}},	//   _съвс, ешни_, ешна_, _atne
  { {0xa3e50044,0x07a60046,0xbcfb0108,0xdd04003a}},	//   _फिर_, _сазн, _amél, ırıy
  { {0xe1350047,0x19590015,0x65690029,0x69350015}},	//   анны, ваны_, bieh, анну
  { {0x65690026,0x69de00c1,0x44260e59,0xdbd1005e}},	//   cieh, ispe, _مرتف, _püüe
  { {0x64460051,0xf7730003,0x4426009b,0xdce00035}},	//   äkid, ماس_, _uro_, cimā
  { {0x2b8f008b,0x1bf70009,0x8c1b0009,0x2bf70009}},	//   rück_, _עצור_, _נווי, _עמון_
  { {0xb2bb000b,0xe5c40014,0x3abb000b,0xadd50001}},	//   _אמור, йсто, _אמונ, робљ
  { {0x60d60065,0x7c240065,0x6298080a,0x6d4d004a}},	//   _geym, fvir, _izvo, ukaa
  { {0x24580015,0x1d640012,0x53a50012,0x7afd001b}},	// [1af0] гать_, حدَّ, لمرك, đstv
  { {0x6569008b,0x7d1d0e5a,0x2b990061,0x45d5004c}},	//   zieh, _wass, pèce_, _коос
  { {0xc2c40003,0x6db1001e,0x7d1d0e5b,0xdce40034}},	//   صيني, _jāat, _tass, hnię
  { {0xdce4003e,0xf8bf0061,0xdd860003,0x2a980012}},	//   knię, ncé_, _ذو_, ائكة_
  { {0x6d9308bf,0xdb0d0bce,0xc9780009,0x69de0e5c}},	//   nçam, spañ, נגדי_, aspe
  { {0x6d580010,0xb8ec0037,0x99d70012,0xddc50024}},	//   _įvai, _श्_, _مترا, абки
  { {0xf8c90061,0x93c6000d,0x05550048,0xeef80009}},	//   _créé_, rtăş, ития, אמור_
  { {0x15450015,0xf1a404ba,0xdce40034,0xdce00035}},	//   реим, _грун, fnię, timā
  { {0x3201002a,0xc9520009,0x1c42003c,0x6e280032}},	//   lthy_, _ומן_, жным, _erdb
  { {0x3b090001,0x33650021,0xe7870129,0x7bdf0e5d}},	//   њено_, рвог, _субо, isqu
  { {0xdce0001e,0x291f0051,0x069b0012,0x46150012}},	//   simā, _kaua_, _أخذت_, _خوار
  { {0xb4e40044,0xfe70000a,0xa96a0a25,0xc4f80003}},	//   _नये_, _عدل_, тима_, _معها_
  { {0xb4c30044,0xc916000b,0x61e3000e,0x6d93003a}},	//   ्री_, בחרת_, ánlj, rçal
  { {0x2d8b0066,0xfaa50264,0x6446008e,0xab5b0032}},	//   _akce_, _кало, äkie, _stün
  { {0x59760015,0x60d60028,0x6d930054,0x8afc0002}},	//   _выпу, _teym, pçal, zięk
  { {0x7c240e5e,0xda7a007e,0xc27a000b,0x2c090037}},	//   tvir, _שנקר, _ברצי, _वहां_
  { {0x7d040028,0x25a50054,0xdee60e5f,0x3ab6004c}},	// [1b00] rfis, ïlla_, _копи, аљет
  { {0x3fdb000b,0xb7db000b,0x9e660109,0x7c240e60}},	//   _שקיב, _שקיי, _ввод, rvir
  { {0xbd8a0003,0x2be20037,0x8afc0002,0x11d70012}},	//   _لندن_, _पिका, więk, لولة_
  { {0x6d43007d,0x929a000b,0xb4db001a,0x48c3004c}},	//   _înap, דיעת, _hoàn, ољша
  { {0x628e003e,0xb6a30081,0xdb0d0097,0xdb0f004b}},	//   _wybo, huẩ, ppað, _ducâ
  { {0x35e60001,0x69de0248,0x69c30030,0x61eb0060}},	//   ацив, pspe, ínec, ümlü
  { {0x09e3004c,0x65c3004c,0x4367076b,0xe9d70048}},	//   _морн, обја, _тарн_, _вкс_
  { {0xa5340046,0x27e90039,0x1d340048,0x22470032}},	//   снич, šana_, сния, änke_
  { {0xef1a0ac5,0xf8bf0061,0x93460003,0x9c370014}},	//   _има_, ndée_, لخدم, ипът_
  { {0xd00f000a,0xda26002d,0x316b0e61,0xbb830012}},	//   _تلك_, аємо, wicz_, يليي
  { {0xd2b7000b,0x71670012,0xd2500012,0x8ab70009}},	//   ילית_, لاحك, سنح_, יהיו_
  { {0xed590066,0xdb1b0061,0x26dc0a05,0x8c480060}},	//   chž_, nquê, lavo_, _kağı
  { {0xb4d20044,0xf8bf0d65,0x64a6035c,0xca6b0024}},	//   वरी_, rcé_, _тада, дiлi
  { {0x6d930017,0x5bc30012,0x26dc0e62,0xe7870e63}},	//   rçam, _بقول, navo_, румо
  { {0x139b000b,0x539b000b,0xdcfb003a,0xc1790010}},	//   _שבוע, _שיוו, nluğ, urės_
  { {0x48670014,0x0657000b,0x39440c23,0xdd910012}},	//   _въоб, בילך_, _noms_, سوء_
  { {0x96270039,0x3f87003a,0xe97c0009,0x99480012}},	// [1b10] _saņē, yonu_, _שנחש, _خليل_
  { {0x7bdf0108,0x26dc012e,0x2ef50df8,0xdcfb0060}},	//   rsqu, javo_, _узор, kluğ
  { {0x49b80003,0xd1b80003,0x26dc0010,0xaab40024}},	//   لاند_, لانا_, davo_, ійці
  { {0x8c48003a,0xc1040003,0x58d90024,0xc1050012}},	//   _bağı, قومي, уддя_, صوتي
  { {0xf536000b,0xc1040012,0x9be40024,0x656d0e64}},	//   _הנרי_, توني, _мірк, miah
  { {0x8c4800a2,0x20e7001a,0x442b0cea,0x6f640024}},	//   _dağı, ối_, _irc_, овіз
  { {0xcf58000b,0x57580009,0x6b520040,0x60dd0e65}},	//   שבות_, שבוע_, _mægl, kasm
  { {0x7415000a,0xe678000b,0x387e000d,0x5e78000b}},	//   موعا, יתוח_, ştri_, יתון_
  { {0x69c70027,0xb3450018,0x2120016d,0x26dc0e66}},	//   _htje, _noçã, _raih_, bavo_
  { {0xda0e0037,0x4374002d,0xdce0000d,0x798d002c}},	//   _सहमत_, жуют, timă, _akaw
  { {0xe695000a,0x3992000f,0x5e950003,0x72190009}},	//   _الاد, lási_, _الاط, נוֹח
  { {0xf6520093,0x7bc90e67,0x04c90012,0xe8f70055}},	//   _מצב_, ppeu, _صوتي_, блю_
  { {0xe81b0037,0x17fa0003,0x2bbb0012,0xa4b60009}},	//   _पैदा_, درجة_, _شاشة_, _הלנה_
  { {0x200201ae,0x889a0009,0x7c940012,0x8f760024}},	//   rtki_, טברי, _بشما, сумі
  { {0xceb2015a,0x75d60003,0xa6e30028,0x2002053b}},	//   לים_, إيرا, íðar, stki_
  { {0x26dc0e68,0xc212000b,0xba740012,0x39920e69}},	//   zavo_, _זהה_, _باهت, kási_
  { {0x0ab60003,0xdcfb0060,0xdca30024,0x39570009}},	// [1b20] محاد, zluğ, зати, _לשקם_
  { {0xef1a0046,0xb05b0163,0x39440070,0x3992000e}},	//   _смо_, rbät, _soms_, dási_
  { {0x26dc0010,0xf1fa0012,0x8c480060,0x636b0034}},	//   vavo_, طعات_, _sağı, ażno
  { {0x00da000a,0x9fe60003,0x24f60024,0xb4c30011}},	//   ابات_, مسته, _учор, ्रो_
  { {0xdb0e0e6a,0xdb1b0018,0x81bc0035,0x2be20011}},	//   _libé, rquê, evēl, _पिटा
  { {0xa09b000b,0x66e30001,0x501b0009,0xe2aa0012}},	//   ניסט, поља, טונו, _مازن_
  { {0x67210416,0x26dc0e6b,0xe737004c,0x6dbc0064}},	//   _dalj, ravo_, сеј_, _očam
  { {0x6d460006,0x39b7000d,0x75240e6c,0xfe6f0012}},	//   _joka, _găsi_, ndiz, عدو_
  { {0x6d460010,0xe043004c,0xdce00073,0x3f8a001b}},	//   _moka, _енти, jimą, kobu_
  { {0x8c1b0093,0x69c10108,0x60c20e6d,0x88570009}},	//   נויי, _élec, lcom, _השמע_
  { {0xd9150015,0x6d5a001e,0x7c2b0052,0x6115003c}},	//   одны, ītaj, _ergr, одну
  { {0xf53f006f,0xd7fb027f,0x27e00e6e,0xfe370009}},	//   _ihåg_, луг_, šinu_, _לרבי_
  { {0xbfb60020,0xc058002d,0x7d16003a,0xa98b0009}},	//   _điểm_, бір_, deys, רָיִ
  { {0x93fb000b,0xac970003,0xc058002d,0x4aba003c}},	//   _עלוי, _انها_, сію_, _судя_
  { {0x3992000f,0x6f150164,0x656d0029,0xef110009}},	//   zási_, rezc, tiah, וּן_
  { {0x6db1001e,0xb5980003,0xea770009,0x2d980012}},	//   _jāap, مَّا_, _לגור_, مَّد_
  { {0x81bc0039,0xc1740093,0x6d9301f2,0x7ff70003}},	// [1b30] zvēl, _מחק_, nçai, _اسعا
  { {0x656d0026,0xfbd00012,0xcaf40012,0x98880009}},	//   siah, عتق_, كسمب, _לָתֵ
  { {0xfbda0037,0x50b50695,0x82150012,0xf1c80012}},	//   _मौसम, ослу, تواص, مولى_
  { {0x6d460006,0x3992000f,0x75220029,0x9105002d}},	//   ökal, tási_, _naoz, іпле
  { {0x672100b9,0xd91c000b,0xa2d50012,0xf745003c}},	//   _palj, טואל, _ويحت, жело
  { {0x3992000e,0xec36000b,0xf41f008e,0x81bc0035}},	//   rási_, _ואשר_, _isä_, tvēl
  { {0x69c70027,0xe81b0037,0x67210e6f,0x96fc0009}},	//   _utje, _पैसा_, _valj, אלות
  { {0xdd910003,0xd658000b,0x6b520097,0x60c20e70}},	//   بوع_, מיות_, _nægj, ccom
  { {0xe3b600e3,0x6b40000e,0x764e0002,0xb8df0037}},	//   обы_, _rögz, zyby, ूँ_
  { {0x98ad0029,0x8c1c0009,0x75240060,0xdce90073}},	//   _hneď_, רוזי, zdiz, mieč
  { {0x442900ff,0xdce90e71,0xc3340009,0x9e750012}},	//   hva_, lieč, לוץ_, _بهات
  { {0xdb03008e,0x46580012,0xa2f70011,0x44290e72}},	//   _sinä, _اؤكد_, ुभुज_, kva_
  { {0x7d16008e,0x3ea90030,0xdce90073,0xb4270012}},	//   veys, žitě_, nieč, _دعاو
  { {0xbf9b0017,0x83fd000e,0x20ea001a,0x44290e73}},	//   stên, rződ, ời_, dva_
  { {0x7d160006,0x657a0025,0x44290e74,0xdce00073}},	//   teys, étho, eva_, simą
  { {0xdce90010,0x7c290e75,0x27ed0e76,0x442909ee}},	//   kieč, over, šena_, fva_
  { {0x0b460594,0xceb60003,0xdce90010,0xf9930009}},	// [1b40] онан, _وحدث, jieč, _קרח_
  { {0xb2960046,0x6be80009,0x752400b8,0x6d460034}},	//   ојећ, מַעַ, sdiz, _woka
  { {0x32050036,0x8afc003e,0xe8220037,0xc8ca0012}},	//   ntly_, mięt, मिका_, لوان_
  { {0x7c290c16,0x629c0a47,0xc3290009,0x22470248}},	//   kver, _vzro, כו_, änka_
  { {0xb4d60037,0x88160003,0x629c0002,0x6dbc0029}},	//   हरी_, تباط, _wzro, _očak
  { {0x8afc003e,0xe3a7000a,0x7c290e77,0x6d590087}},	//   nięt, _زر_, dver, _alwa
  { {0xd6d900bc,0xd5b70047,0xda0e0037,0x629c0027}},	//   сті_, осы_, _सहित_, _uzro
  { {0xd1320003,0xceb30009,0xb5aa0012,0x6da3004c}},	//   _تمر_, ויו_, جاتك_, мија
  { {0x8b660003,0xd37a0472,0x32050132,0x83fd0031}},	//   قادم, ичо_, etly_, ezőb
  { {0x3f76003e,0x501b000b,0xc7b9000e,0xa3dc0011}},	//   dług_, _דומו, _erős_, णीय_
  { {0x2b470108,0x7abb0009,0x3abb0009,0x2b940032}},	//   _donc_, יציו, ימינ, räch_
  { {0xa9c3007c,0x81bc0039,0x2c830010,0xb4b90037}},	//   ьськ, lvēk, _būdą_, _चले_
  { {0x3205002a,0x20060e78,0x6c7600ae,0xc7f80557}},	//   atly_, ntoi_, _بطائ, оняє_
  { {0xdfd00012,0x46e8003c,0x8afc0034,0x6d930521}},	//   ئيّ_, ждён_, gięt, nçav
  { {0xd250000a,0x32050036,0xb4d60011,0xf41f008e}},	//   _سنة_, ctly_, हरू_, _ssä_
  { {0x6ecb0044,0x865b0009,0xd1310012,0xb87b0018}},	//   _त्रु, בדלי, _أمة_, raíb
  { {0x4c940015,0x351b000b,0x69080009,0xd7fb0048}},	// [1b50] дитс, סומנ, _וּתְ, _туй_
  { {0x8afc0002,0xdce90073,0x60db016d,0x5b14003c}},	//   cięt, vieč, _seum, ммут
  { {0x7bcd039c,0xa2dc0037,0xdb0e000e,0x99870066}},	//   spau, _फ़र्, óján, ínů_
  { {0xdb0b006f,0x7bcd004a,0xdb1b0e79,0xa3b60011}},	//   _utgö, ppau, rqué, _चूक_
  { {0x67250005,0xdd3a000b,0x5d3a000b,0x3d3a000b}},	//   _kahj, _הערכ, _התרא, _הגרס
  { {0x3992000e,0x70b70037,0xfbd2000b,0xa81c0009}},	//   lást_, ःशुल, _אתך_, שֵׁי
  { {0xf7740009,0x63bd0e7a,0xdce90073,0x64460e7b}},	//   וקס_, _husn, sieč, äkin
  { {0x25a90052,0x1c45002d,0x6725019a,0x867c0009}},	//   nmal_, зним, _lahj, ירוו
  { {0xc1040003,0x29190054,0xc5680003,0xf3f10003}},	//   _توقي, desa_, تحول_, رأة_
  { {0x25a90052,0x6d5a001e,0xa0880009,0xdce40060}},	//   hmal_, ītai, _וְעִ, kniğ
  { {0x39490017,0x29190e7c,0x83640012,0x95570012}},	//   _boas_, fesa_, بديل, _وخصا
  { {0x3205002a,0xd24e0003,0xa5c60028,0x9f4205b1}},	//   rtly_, انَ_, slóð, mské_
  { {0x9f420e7d,0x3992000e,0x3205027b,0xbd9a0009}},	//   lské_, dást_, stly_, _פסנת
  { {0x80cc0011,0x32050132,0xf7560012,0x2c1905f3}},	//   _थ्रे, ptly_, أنسج, _नैइं_
  { {0x63bd0052,0x6da602e2,0x8f9a000b,0x3f760002}},	//   _ausn, зива, מישי, sług_
  { {0x3cf60037,0xf8b9001a,0xb4d60037,0xf9920012}},	//   इलें_, _ngũ_, हरे_, _ثبت_
  { {0x29c10020,0x60fb000b,0xfbd10012,0x81a50012}},	// [1b60] _hóa_, _ההפק, َتْ_, _تحول
  { {0x8b230015,0x9479002d,0xed160034,0x25a90e7e}},	//   ндуе, істу_, _łódź_, amal_
  { {0xdebb000b,0xb6bb000b,0x3d1c0037,0x3ebb000b}},	//   _למיל, _לציי, _मसले_, _לציב
  { {0x7ae1008b,0x2d800029,0xf969002d,0xf9920012}},	//   halt, čiek_, орій_, ربا_
  { {0x28cb0011,0xa4b70009,0x9f420030,0x7ae10e7f}},	//   ाड़ि, _מלכה_, eské_, kalt
  { {0xbb4a000a,0x2006004a,0x7ae1004a,0xc49b0009}},	//   _الآن_, rtoi_, jalt, _לשכת
  { {0x6b520028,0x20060e80,0x7e2a0024,0x657b0097}},	//   _nægi, stoi_, сіла_, fnuh
  { {0x6360000f,0xceb3000b,0x7cf6003a,0x6d440e81}},	//   _böng, עיה_, dürü, njia
  { {0x9f59009f,0xdc3a0024,0x7ae10e82,0x6eb60012}},	//   ltså_, ицiї_, falt, _فصائ
  { {0x3992000e,0x6360003a,0xba540001,0xd8770012}},	//   zást_, _döng, двој, _عملت_
  { {0x44270020,0xc333000b,0x442f0070,0xa3dc0037}},	//   ̉n_, גות_, _erg_, णीत_
  { {0x55bb000b,0x7ae100ff,0x1e570009,0x3cf60011}},	//   _המאו, aalt, _משבר_, इलों_
  { {0xbd430003,0xc9530009,0xc0580024,0x45430012}},	//   _سنوي, גמר_, пір_, _سنوق
  { {0x27e601da,0x2327003c,0xbf9b0025,0xbb4305c8}},	//   ison_, _ночи_, ptêm, _печк
  { {0x3992000f,0x44220e83,0x639b0009,0x9aeb0009}},	//   tást_, _ask_, _הסגנ, _הַחִ
  { {0x69fb000b,0x63600028,0x8a7b000b,0x26de04d2}},	//   _הלהק, _lönd, _לאות, _leto_
  { {0x18680001,0x3992000e,0x68ed0e84,0x61fa0e85}},	// [1b70] _наћи_, rást_, _idad, lutl
  { {0x7b770003,0x32130002,0x6d5600b6,0xfaa70594}},	//   أطرا, łbyś_, akya, пшен
  { {0x29c10020,0x98bf007d,0x2b0e0011,0xaa190012}},	//   _xóa_, _nouă_, त्यु_, تياط_
  { {0xe1f00003,0xdb060052,0x9f4200d9,0x7ae10e86}},	//   اسل_, _zukü, vské_, zalt
  { {0xea000020,0x7b02004a,0x63600248,0x7ae10077}},	//   _tiếp_, äytö, _bönd, yalt
  { {0x9f4200d9,0x7c2d0e87,0xbae50012,0xdc3a0009}},	//   tské_, mvar, _زكري, _ועשר
  { {0xe7080003,0xa3df0037,0x7ae1004a,0x63600457}},	//   ستون_, धीन_, valt, _dönd
  { {0x98bf007d,0xe7ee0037,0x27e9006f,0x30150001}},	//   _două_, _जिला_, _ovan_, _одбр
  { {0xbcfb000e,0x7d1a0009,0xf5920012,0x3af50223}},	//   _elég, חֵיה, خليج, мянс
  { {0x636000a1,0x9f420066,0x7cf6003a,0xc43c0009}},	//   _gönd, pské_, türü, מתחי
  { {0x6d5d003a,0x7c2d005e,0x98700064,0x425405d8}},	//   _olsa, hvar, rúča_, етят
  { {0x442f02a1,0x29e7001b,0x2d680060,0x7cf60060}},	//   _trg_, rđa_, nşet_, rürü
  { {0xcfaa0012,0x63600060,0x995c068c,0x7d1b0e88}},	//   قاسم_, _yönd, níš_, meus
  { {0xdfcf0003,0x03d6000b,0x26de0029,0xb3ba0009}},	//   شيف_, _חוסם_, úto_, _ומסכ
  { {0xab280003,0x7d0d0052,0x490e0011,0x79750034}},	//   _رسول_, ffas, ण्डो_, nąws
  { {0x75290e89,0xe5a30e8a,0x99f60009,0x6d4b0e8b}},	//   ndez, виси, _חזקה_, _joga
  { {0x9f5f0e8c,0x9f520028,0x6d4b0e8d,0x71250012}},	// [1b80] _aquí_, ðbót_, _moga, _سريل
  { {0xeb9f0033,0x0aea0024,0xda660012,0xeab20012}},	//   _spør_, ідей_, واضي, نعا_
  { {0x0f57000b,0xc7b3000b,0x9757000b,0x7d1b004a}},	//   _חיים_, _שבת_, _חייו_, keus
  { {0x442d0027,0x27e60e8e,0x3cfa0012,0xcb090009}},	//   kve_, tson_, _بعدد_, יל_
  { {0xd0100003,0x10470048,0xbfaa003c,0x48e30048}},	//   الت_, дящи_, отке_, точв
  { {0x64460051,0x20ee001a,0x61fa003a,0xd6cf0012}},	//   äkim, ội_, yutl, لقه_
  { {0x27e60e8f,0xa3c80011,0x657e0025,0xe80e0011}},	//   sson_, ैठक_, épho, ाढ़ता_
  { {0x636000a2,0x6f1c0e90,0xad660012,0x61fa0060}},	//   _döne, herc, باته, vutl
  { {0x6d4b09ea,0xea00001a,0x15ea0011,0xaf0609cc}},	//   _doga, _khắp_, _टिकर_, _опал
  { {0x6d930d04,0xba0a0048,0xc7260024,0x7e560472}},	//   nçar, охме_, _ідей, _отец
  { {0x7d0d00a2,0x6d4b000f,0x3999000f,0x442d0e91}},	//   yfas, _foga, lési_, ave_
  { {0xbfa3001a,0x316b0024,0x7de50012,0x7c2d0073}},	//   hiế, ішно_, _أسلم, yvar
  { {0xf773000a,0x3999000e,0x28a700b3,0x4c560012}},	//   ناس_, nési_, ьшог, _تضار
  { {0x636000a2,0x69c3000e,0x4c9b0009,0x5f450012}},	//   _yöne, ínek, _ובדו, رنزل
  { {0x7dc7003a,0x42fb000b,0x12fb0009,0xe7eb0011}},	//   _kısa, _והוס, _והוב, _झटका_
  { {0x6728009b,0x7c2d0e92,0x91870012,0xbcfb0e93}},	//   _ladj, tvar, _تجتم, _amér
  { {0x6d4c001a,0x7d0d0052,0x8afc0002,0x2d580061}},	// [1b90] _đoạ, rfas, chęc, _réel_
  { {0x3999000e,0x67280027,0x6f1c0e94,0x7c2d0e95}},	//   dési_, _nadj, cerc, rvar
  { {0x2fcd0163,0x50f50867,0x442d0e96,0xe3b00012}},	//   _steg_, езет, zve_, شرك_
  { {0x6d930e97,0xdb1d0061,0x8aa40e98,0x02a409c2}},	//   rças, _musé, труд, трум
  { {0x8d5a0009,0xf9900012,0x27e90025,0xe7390e99}},	//   _זכרי, جبل_, éan_, зел_
  { {0x25a6000f,0x6d4b0052,0x9f590061,0x92f40012}},	//   _ahol_, _soga, fusé_, _لأفض
  { {0xf7700003,0x6d4b0e9a,0xed59003c,0x3eb30248}},	//   جان_, _poga, зой_, äxt_
  { {0x442d0e9b,0x6f1c015d,0x94250083,0xdb1b0164}},	//   tve_, zerc, емие, rquí
  { {0x442d0108,0xdb0e000f,0x7529000e,0x395f0051}},	//   uve_, _hibá, rdez, _ilus_
  { {0x7ae500a2,0x13090015,0x8bd6000b,0x03d60009}},	//   naht, чной_, עותו_, עותם_
  { {0x8f680003,0x44200002,0xa3e60011,0x06380012}},	//   _تملك_, zwi_, _यौन_, _يسمع_
  { {0xdc330029,0x99f60009,0x04c80012,0xb87b0097}},	//   lúče, עזרה_, _قومي_, raín
  { {0xdbd70269,0x93590024,0xa1560009,0xc4a90011}},	//   _jäät, _нрку_, גברה_, कधोख
  { {0x7ae500b6,0x25ad005e,0x63600032,0x75ca0034}},	//   jaht, lmel_, _mönc, _węze
  { {0x3999000f,0x59c60037,0x6996068f,0xdbd7005e}},	//   zési_, _रूपर, _прих, _läät
  { {0x44200034,0x6f1c0e9c,0x04460024,0x8c46028b}},	//   twi_, serc, небн, небе
  { {0xdde3001e,0x68e00010,0xac860055,0x6f1c0e9d}},	// [1ba0] ērša, _remd, хгал, perc
  { {0xe6250020,0x6b520058,0x68b70009,0x76260024}},	//   _đông_, _nægt, _אלפא_, _змоз
  { {0xfce60731,0x4ae10037,0x7641004a,0x76550002}},	//   _поно, _फ़रव, älyt, cyzy
  { {0x39990272,0x29020e9e,0x68e6002c,0xab5b0052}},	//   tési_, ngka_, nakd, _stüt
  { {0x394d0036,0xc0e70003,0x2d800e9f,0x6576008e}},	//   _does_, رفون_, mnie_, miyh
  { {0x2d800ea0,0x395f0051,0xa2d60012,0xb2d60012}},	//   lnie_, _elus_, _سيرت, _سيرغ
  { {0x3999000f,0x63830014,0x25e30037,0x69ce07a8}},	//   sési_, _сгра, टीपी_, _utbe
  { {0x394d002a,0x3999000e,0x1d340014,0x2d800ea1}},	//   _goes_, pési_, тния, nnie_
  { {0x9f86002d,0xfd660081,0x39b8004b,0x61fe0ea2}},	//   _згад, _khuế, _răsp_, lupl
  { {0x5a340662,0x70170009,0x61fe0ea3,0xdce20ea4}},	//   внот, _אחמד_, oupl, _omoć
  { {0x7d060163,0x6fa70037,0x2d800002,0xd0d50014}},	//   _ocks, _गठबं, knie_, конъ
  { {0xea000020,0x2d800002,0x629801bd,0xc27b0009}},	//   _nhập_, jnie_, _vyvo, לריי
  { {0x2d80003e,0x2bb20037,0xa5690012,0xc5690012}},	//   dnie_, ीददा, _تصلك_, _تحلل_
  { {0x2d80003e,0x61fe0bec,0x291d0034,0xab640060}},	//   enie_, kupl, zewa_, nlüğ
  { {0xdb030013,0xbe88072b,0x6b520028,0x3da7010c}},	//   _jiný, есте_, _lægs, ераб
  { {0xba9b0093,0x65640101,0x5eb40015,0x1a9b000b}},	//   _מסוי, ghih, уйст, _מיוע
  { {0x7ae50051,0x61fe0025,0xab640060,0x2418003c}},	// [1bb0] taht, eupl, klüğ, ноты_
  { {0xd6db0047,0x2d800002,0xa87c0009,0x04940012}},	//   _эти_, anie_, _מאחר, الْح
  { {0x395f0ea5,0x2d800002,0xdbd7004a,0xa4d9027f}},	//   _plus_, bnie_, _säät, _одну_
  { {0xd879000a,0xdbd70006,0x2d80003e,0x60b50012}},	//   ومات_, _päät, cnie_, نمائ
  { {0x7ae50006,0xbcfb0b45,0x61fe005e,0x753d0ea6}},	//   paht, _eléc, aupl, _insz
  { {0x0eac0037,0xbcfb0025,0x23a20097,0x291d016d}},	//   टइंड, _fléc, yðja_, sewa_
  { {0x86980014,0xc9770003,0x7f2c0009,0x62340048}},	//   нтът_, _كارث, לֵהֶ, _йеру
  { {0x1da70037,0x69c70042,0x752d0ea7,0xa63c0009}},	//   _कीमत, íjem, ndaz, לגור
  { {0xe4c80012,0x6c52004c,0x25ad0ea8,0x6d4f0ea9}},	//   ربين_, икћу, rmel_, _moca
  { {0x799d008b,0x6b520028,0xf412000b,0x999f0010}},	//   elsw, _hægr, ספי_, kytų_
  { {0x36d40047,0x2d80003e,0x44260164,0x68e6002c}},	//   _сохр, ynie_, _eso_, takd
  { {0x27e90039,0x999f0010,0x4ad10037,0xf8c10037}},	//   šanu_, dytų_, _द्रव, एशिय
  { {0x25fd0037,0xf1b2000b,0xe5880009,0xfd560009}},	//   रूरी_, יסט_, _אָסָ, _ששני_
  { {0x2d80003e,0x2905000f,0x6b520028,0x5f090011}},	//   wnie_, őlap_, _lægr, _साफ्_
  { {0x66060014,0x2d800ea0,0xa59600de,0xa6e30024}},	//   ъпва, tnie_, вращ, ржсл
  { {0x27ed0eaa,0x16020011,0x106a0012,0xee370048}},	//   _oven_, रंतर_, _يحظى_, ънс_
  { {0xc9530093,0xe3ba0345,0x7ae30eab,0xb8f60011}},	// [1bc0] _כמה_, дба_, _kent, ाँ_
  { {0xd7fb0093,0xab5b0052,0x68e40eac,0xa2cd0011}},	//   _קהיל, _stür, _heid, दुल्
  { {0xeb970046,0xea00001a,0x6dbc080d,0x48e600de}},	//   њих_, _thập_, _včas, воев
  { {0xb2950001,0x81bc001e,0xb8f30012,0xba170012}},	//   ујућ, ovēr, لكمب, ضيها_
  { {0xdb0b003a,0x68e40ead,0x7a130030,0x4c830048}},	//   _bugü, _meid, větš, _вляв
  { {0x3999000e,0xe3b20003,0x7d040eae,0xa8570009}},	//   lést_, _خرج_, lgis, כינה_
  { {0x27ed0eaf,0xab64003a,0x7c240032,0x0f7b0009}},	//   _even_, rlüğ, lwir, ורסל
  { {0xdb190002,0xdce9003a,0x39990eb0,0x63bc0032}},	//   _otwó, rneğ, nést_, _hirn
  { {0x3166000e,0x7c240052,0x7ae30eb1,0x8ca70011}},	//   mhoz_, nwir, _bent, _चरणो
  { {0x4426009b,0xdb18000e,0x3166000e,0xa263001a}},	//   _vso_, _kivé, lhoz_, _trố
  { {0x79820002,0xa2660014,0x81bc001e,0x02fb000b}},	//   onow, тъпл, evēr, ולימ
  { {0xd5e90003,0x92570015,0x99810073,0x316600e9}},	//   _أعلن_, тают_, _čių_, nhoz_
  { {0x7ae3000e,0xf8db0009,0x39990031,0xad650012}},	//   _fent, וחכמ, dést_, _حاله
  { {0x6ae10037,0x999f0010,0x64a30001,0x75200eb2}},	//   _फ़ेर, tytų_, _тача, lemz
  { {0x3166000f,0x79820431,0xd3780eb3,0xbcfb0025}},	//   khoz_, know, mić_, _aléa
  { {0x8ab7000b,0x2bb20037,0x7ae30052,0xd9440001}},	//   _בלוג_, ीदवा, _zent, _већи
  { {0x69c30052,0xd4070015,0x3166000e,0x629c002c}},	// [1bd0] _zune, ъяви, dhoz_, _ayro
  { {0x7ae80002,0xd3780eb4,0xf0e30037,0x7658004a}},	//   nadt, nić_, _ख़ुद_, kyvy
  { {0xfdb900ac,0xa6e30097,0x6d4f009d,0x3f83001b}},	//   _площ_, íður, _toca, mnju_
  { {0xb65a000b,0x79820002,0xa4d5002d,0x31790123}},	//   _נדרש, gnow, _щомі, nisz_
  { {0xb4fa000b,0xe0d8002d,0x9f4205b1,0xbbeb0012}},	//   _אפרי, тві_, lská_, _ترجم_
  { {0x63600028,0xf0940009,0x8fa50012,0xaf040024}},	//   _hönn, סנס_, دمته, ипіл
  { {0x6360008b,0x2d550058,0xd3780027,0x60c404cf}},	//   _könn, _fået_, dić_, žima
  { {0xceb4000b,0xc3d9002d,0x81bd001e,0xdb1d0107}},	//   סיק_, ньої_, zvēr, _musí
  { {0x7ae30eb5,0x6d5b00b6,0xb8e90037,0xcc350003}},	//   _pent, rkua, ोड_, اربع
  { {0x7ae8000f,0x3999000f,0x69c3000d,0x2902006f}},	//   gadt, zést_, _pune, _ökar_
  { {0x52e10037,0x7dc7003a,0xdb030164,0x3f830027}},	//   _फ़ैस, _kısm, _sinó, dnju_
  { {0xf5300003,0x3cfd0037,0x5e440012,0xd4350012}},	//   _وإن_, एलों_, _خَمْ, _معتب
  { {0x68e40333,0xd378003e,0x39990066,0xe9e90029}},	//   _veid, bić_, vést_, dnúť_
  { {0xd378003e,0xa8750015,0x40850001,0x7ae301e3}},	//   cić_, рующ, руџб, _uent
  { {0x3999000f,0x2bdf0037,0x81bd001e,0x79820002}},	//   tést_, पीरा, rvēr, ynow
  { {0x31790002,0x81bd001e,0x6ae10011,0x96d40011}},	//   cisz_, svēr, _फ़ॉर, _ब्रॉ
  { {0xdb19003e,0x3999000e,0xd467022a,0xfafa0012}},	// [1be0] _utwó, rést_, гите_, فراغ_
  { {0x87260047,0x443205b1,0x3999000e,0x83fd000e}},	//   _смож, rvy_, sést_, ezők
  { {0x7c240052,0x3166000e,0x3999000e,0xe8fa072b}},	//   swir, thoz_, pést_, еле_
  { {0xd378003e,0x88e60063,0x629c0042,0x867b0009}},	//   zić_, ужде, _vyro, _טריו
  { {0xdfcf000a,0x629c0002,0x83fd000e,0x3166000e}},	//   كين_, _wyro, szőj, rhoz_
  { {0xe3c80020,0x3166000f,0x25a00051,0x8f340662}},	//   _lực_, shoz_, llil_, рекц
  { {0x6b6300bc,0xd378001c,0xd6d9002d,0x15f30003}},	//   _укра, vić_, тті_, مسيح
  { {0xd378003e,0x5d540014,0x20020060,0x13f40148}},	//   wić_, ркит, kuki_, азия
  { {0xe644003a,0x88860001,0xd3780027,0x90290012}},	//   ılığ, _слаж, tić_, _لألف_
  { {0x96d401e1,0x31790002,0xfbcf0003,0x6c170003}},	//   _ब्लॉ, wisz_, أتي_, اتيح_
  { {0x7bc600e6,0x395202d5,0xc3330009,0x85060012}},	//   _luku, _boys_, מוז_, _موان
  { {0x6ae10037,0x2ee50070,0xe3c8001a,0xd3780404}},	//   _फ़्र, _zelf_, _cực_, sić_
  { {0x8d93000a,0xf5930003,0x69c10061,0xd3780404}},	//   _النش, _النج, _élev, pić_
  { {0x3179003e,0x9f4200d9,0x8cba0011,0x63600097}},	//   sisz_, tská_, ्शनो, _sönn
  { {0x58d50098,0x3179003e,0xe9e90029,0x8b9b0009}},	//   _койт, pisz_, tnúť_, _רבות
  { {0xb4d502ad,0x5839010c,0x9f4200d9,0x39400132}},	//   ржащ, _азия_, rská_, _gnis_
  { {0x7bc600c6,0xa9bc000b,0xe8d8000b,0x3f830027}},	// [1bf0] _cuku, _אזהר, _עוזר_, pnju_
  { {0x7bc600b6,0x9f420066,0xa3e60011,0x88bd0034}},	//   _duku, pská_, यीय_, _zaśw
  { {0xe9e90029,0x77ba000b,0xc0d50003,0x9b170009}},	//   pnúť_, _שמתח, لياب, רחבה_
  { {0x2ee50eb6,0xdc3401bd,0x4dda0009,0x2d99005e}},	//   _self_, _zúča, _שחרו, _ukse_
  { {0xb0af0037,0x50450048,0x83fd0031,0x88c80024}},	//   जेंग, релб, rzők, улів_
  { {0x6d4d0005,0x2b140037,0x7ff40012,0x44390eb7}},	//   ljaa, न्दु_, إسنا, _irs_
  { {0xcf58000b,0x7bc60052,0xf1c9001a,0x42290009}},	//   רבות_, _zuku, _mạc_, _בֵּ֣
  { {0x52840003,0xf1c9001a,0x6d4d0eb8,0xdb1d0018}},	//   _الفك, _lạc_, njaa, _fusã
  { {0x50670046,0x87070003,0x68eb002c,0x69ce0030}},	//   _ства, _مبال, magd, íben
  { {0x466b002d,0xdced003a,0xd7a40037,0x44390503}},	//   _прем_, ynağ, _खींच, _mrs_
  { {0x38ba00a2,0xc332000b,0x6723048b,0x75d1001e}},	//   _türü_, קוט_, menj, _bāze
  { {0xdc340026,0x27e0007d,0x69c70164,0x68eb002c}},	//   _súča, ţine_, _muje, nagd
  { {0xe3c80020,0x7db40003,0xf1c9001a,0xfc3f000e}},	//   _vực_, _اصلا, _bạc_, _szín_
  { {0x8f750024,0x23ab0040,0x7ae70030,0xeb080012}},	//   бусі, føje_, _nejt, _مقهى_
  { {0x7bc6050d,0x200200b6,0x7bca0035,0x39520bb5}},	//   _suku, suki_, ēmuš, _toys_
  { {0x39400061,0x7bc600b6,0xdbd2005e,0x64460248}},	//   _unis_, _puku, _tüüt, åkig

  { {0x68eb0101,0x6723000e,0x31570012,0x5f760012}},	// [1c00] dagd, kenj, _خليج_, _نادر
  { {0x6723080a,0xaae50003,0xdb59002d,0x2bb60034}},	//   jenj, مسمو, лює_, _płci_
  { {0x6723012e,0xe5a6002d,0x66030010,0xb87b0066}},	//   denj, _вини, junk, abíd
  { {0xe3c80020,0x3f980002,0x7bc60eb9,0x66030eba}},	//   _lựa_, loru_, _tuku, dunk
  { {0x6360003a,0x38600028,0x33d5002d,0xd8f70024}},	//   _yönl, áir_, _гіст, рнії_
  { {0x752f003e,0x2b030037,0xa0370009,0x92e90012}},	//   _zacz, _लाएँ_, יאנה_, _مرفق_
  { {0x22470052,0xf62a002d,0xfb1b0009,0x7e2a0024}},	//   änkt_, тіли_, _שולמ, тіла_
  { {0xa6e90020,0x3f980066,0xb4c20037,0x8e570009}},	//   _ngươ, horu_, ्डे_, ייצג_
  { {0x8c430001,0x4d730012,0x70fb0009,0x53460048}},	//   жење, تطور, _שהמח, ахна
  { {0xdb15000f,0x44970015,0x6723013a,0xf4130009}},	//   _kizá, рвью_, cenj, קפת_
  { {0xe3c80020,0xa159002d,0x69c1000e,0x69c0000e}},	//   _dựa_, гану_, _élet, _kime
  { {0x2c5e001e,0x867b0009,0x6446005e,0x65690ebb}},	//   _kādā_, _ברבו, äkis, cheh
  { {0xb8cf015f,0x938a0014,0x752f0002,0x60f8003c}},	//   _कर_, _иска_, _racz, шняя_
  { {0x0b930003,0xc43b000b,0x8c1b0009,0x93930012}},	//   _وجود, _שתגי, _סווי, _وجوا
  { {0xa1870015,0x99420002,0x7ae70ebc,0xeb910009}},	//   _выпл, _dół_, _rejt, _מָה_
  { {0xcdf7000b,0x6360003a,0x3abb000b,0x69c00ebd}},	//   ימלי_, _dönm, _במונ, _nime
  { {0x2ac70001,0x65a5000e,0x31580009,0x39580009}},	// [1c10] аљев, zóho, _כיהן_, _כשהם_
  { {0x34a70037,0x889c000b,0xa4b7000b,0x69c00ebe}},	//   _खरीद, _בבחי, שלמה_, _aime
  { {0xc879004b,0x7648008e,0x6d42004b,0x32790012}},	//   _ieşi_, ädyt, _onoa, دماج_
  { {0x91ac0020,0x7afd0010,0xc198002d,0x5184046d}},	//   _đọc_, ėsti, атії_, оуча
  { {0x7ae70026,0x68eb0101,0x68270015,0x89340003}},	//   _tejt, ragd, рьез, تعلا
  { {0xf1c90003,0xf8bf000e,0x66030b95,0xf4560009}},	//   _موسى_, ldés_, tunk, _הישר_
  { {0x6723001c,0x68eb002c,0xdf480003,0xd6ce0012}},	//   renj, pagd, شؤون_, رقي_
  { {0x9985000a,0x66030961,0x44290002,0xcd29003c}},	//   _الرو, runk, owa_, ужие_
  { {0x681a0039,0xdd2f0066,0xbc390003,0x44390cbe}},	//   gādā, _těžk, اسبا_, ís_
  { {0xe730000a,0xb4e60037,0xe4520009,0x75d50012}},	//   _يصل_, _बड़ी_, לֶת_, _هيئا
  { {0x442900c6,0xcb12000b,0x69c1000e,0xb6350012}},	//   hwa_, הלי_, _éles, _دفاع
  { {0x442900b6,0xce6800a6,0x3f980b2c,0x35b50842}},	//   kwa_, _труд_, woru_, _убер
  { {0x68e909de,0x7d090d33,0x55ba0009,0xbcfb0025}},	//   _meed, mges, _עמנו, _clém
  { {0x59cf0044,0x20f8001a,0x50d80037,0x7d090ebf}},	//   _संपर, ọi_, _भ्रष, lges
  { {0xc879000d,0x59b90037,0x25fd0037,0x03ac0009}},	//   _deşi_, ेदार, रंटी_, _שׁוּ
  { {0x68e90036,0xbf9b0017,0x7d090ec0,0x3f980ec1}},	//   _need, quên, nges, soru_
  { {0x75240039,0x7ff60003,0x7c290ec2,0x3f980ec3}},	// [1c20] reiz, _اسبا, nwer, poru_
  { {0x290d000d,0x7d090052,0x61fe09d2,0xdc880009}},	//   _acea_, hges, trpl, בְעָ
  { {0xcf570093,0x7c29008b,0xb9c1003a,0xe1fa0731}},	//   _הבית_, hwer, _üçün, уге_
  { {0xb4e60037,0x7d090070,0xea00001a,0xf53f0029}},	//   _बजे_, jges, _nhấp_, áťte_
  { {0x7c290070,0x38490009,0xd12f0012,0x68e90ec4}},	//   jwer, ֹאוּ_, عمه_, _deed
  { {0xaa46036f,0x07b70012,0x0ce00011,0x7c2902a2}},	//   _легл, مهنة_, नर्म, dwer
  { {0x6b630015,0x65880066,0x7c290ad2,0x7d090480}},	//   _экра, běhl, ewer, fges
  { {0xea000020,0x2c5e001e,0xbebc001e,0xb5aa0003}},	//   _chấp_, _tādā_, _saīs, داتك_
  { {0x7866048c,0x7ac60024,0x23b40012,0x69c20011}},	//   _указ, йсне, يمبس, _रंजी
  { {0x681a0039,0x26190044,0x6e3c0164,0xd7ef0012}},	//   rādā, _पहली_, _árbo, _أكل_
  { {0x4429003e,0xcb9b000b,0x7f3b000b,0x6e960003}},	//   zwa_, רסיט, _תעבו, _الضا
  { {0x44290002,0x3da5002d,0x3abb0009,0xa0b9004c}},	//   ywa_, _дріб, טמינ, игну_
  { {0xf8ba0037,0x91ca0011,0xdc1d07ee,0x000000c4}},	//   ेशिय, _संवै, kņāt,
  { {0xd7f80015,0x995c0066,0x69da0ec5,0x600b0009}},	//   щую_, jíž_, ppte, נִכְ
  { {0xf1c90020,0x15f80009,0x13170009,0x9df80009}},	//   _hạn_, יִּמ, _החול_, יִּז
  { {0x44290961,0x46d90011,0x98c70ec6,0x6b9a01a0}},	//   twa_, _ब्रह, _ускл, lotg
  { {0x69cd001e,0xf8bf057d,0x8fa50012,0x83fd0031}},	// [1c30] ēneš, rdés_, _ومعه, szőv
  { {0xe2f9002d,0x9aab0003,0x44290002,0xf1c90081}},	//   режі_, هداف_, rwa_, _mạn_
  { {0x442900c6,0x7c2900f7,0x201f004b,0x6aba0097}},	//   swa_, zwer, _spui_, _útfl
  { {0x80e30037,0x4429002c,0xe9190024,0xc1040012}},	//   खरेख_, pwa_, роді_, كومي
  { {0xf1c9001a,0xb4e60037,0xf1940024,0x7af80064}},	//   _nạn_, _बड़े_, чиць, _odvt
  { {0x6d810039,0x7c2f0ec7,0x9e090012,0xef180024}},	//   rķau, _iscr, ليتك_, ймі_
  { {0xc332000b,0x7d09036a,0x68e90051,0x2d580025}},	//   _קול_, tges, _teed, _réer_
  { {0xf1c9008a,0x7c290369,0x160b0037,0x25b60003}},	//   _bạn_, twer, संबर_, يهود_
  { {0x69ca0052,0x69d80259,0x7d090ec8,0x7c290ad2}},	//   _aufe, _atve, rges, uwer
  { {0x7d090732,0xdce00010,0x2d83000e,0x4374027f}},	//   sges, kimė, ője_, зуют
  { {0xea000020,0x7aea003a,0x7d090070,0xdd990004}},	//   _thấp_, _deft, pges, poň_
  { {0x26130017,0x7bdb004a,0x98a60014,0x24190015}},	//   mão_, ppuu, жиме, _воды_
  { {0x26130017,0x9b750012,0xb87b0a19,0x7c2f0ec9}},	//   lão_, _واتص, daís, _nscr
  { {0xe73a0046,0x5334003c,0x26130018,0x88ba0009}},	//   шег_, _нечт, oão_, יזרי
  { {0x3ebe0eca,0x26130017,0x7c2f0ecb,0xd62a0488}},	//   ätt_, não_, _ascr, шове_
  { {0x656d01e5,0xe9730012,0x9f420064,0x7bc30ecc}},	//   ghah, _يهود, nskú_, _hinu
  { {0x64a30046,0x7bc3002c,0x8fe60012,0xe7320012}},	// [1c40] дата, _kinu, _بأعم, _قصد_
  { {0xdb18000f,0x6360008b,0xaac90037,0x8a3a0015}},	//   _kivá, _köni, रशिक, ияет_
  { {0x7bcb0ecd,0x77830024,0x2d9e0025,0x7c2f0ece}},	//   _lugu, _ілюз, îtes_, _escr
  { {0x26130017,0xdce20ecf,0x67160011,0x02aa0011}},	//   dão_, _ploč, द्रक_, _करीन
  { {0x644b0051,0x274a0ed0,0x6d460ed1,0x79b70009}},	//   ägit, ичко_, _inka, קלנד_
  { {0xb033002d,0x883b0009,0x8e3a0012,0xdb1d0060}},	//   ьніш, יתנו, لسعر_, _rusç
  { {0xdbd10017,0x26130017,0x6725005e,0xf1c90081}},	//   qüên, gão_, õhja, _sạn_
  { {0x7bc30005,0xdd900003,0x442200b6,0x54540ed2}},	//   _ainu, عوة_, _kpk_, звит
  { {0xdca30046,0xf1c9001a,0x7bc3002c,0x69ca000d}},	//   маћи, _bạo_, _binu, _sufe
  { {0x8c1b000b,0xb4db0054,0xf1c90081,0x2d680060}},	//   סויי, _anàl, _vạn_, rşey_
  { {0xf2d3000b,0x78ad000e,0x26130017,0x8b030066}},	//   ועת_, _szav, cão_, _úřed
  { {0x7bc30065,0xdb1d008b,0xdb030017,0x3cf60011}},	//   _einu, _zusä, _sinô, ेलों_
  { {0x7bcb0a60,0xf8b00012,0xf5770012,0x75360034}},	//   _gugu, َةُ_, _بمنع_, ddyz
  { {0x60210028,0xf1c9001a,0x83fd000e,0x42560012}},	//   _hámö, _gạo_, rzőt, _ونشر
  { {0x69d80ed3,0xcdd80001,0x1634022a,0x7bcb0032}},	//   _utve, жњу_, меря, _zugu
  { {0xb87b02d1,0xd657000b,0x3f9c0027,0x798d0002}},	//   abía, חילת_, hovu_, _ujaw
  { {0x26130017,0x78ad00d9,0x4422001b,0x3f9a0097}},	// [1c50] zão_, _uzav, _cpk_, ófuð_
  { {0x8aa70294,0xfaa70ed4,0x43740024,0x6a670012}},	//   оред, ошен, муєт, يطال
  { {0x26130017,0x64400028,0x68ed00b6,0xa2be0037}},	//   xão_, _ámin, _kead, _वृद्
  { {0xdeb6015a,0x81c80024,0x26130018,0xe1d80024}},	//   _מפתח_, ігів_, vão_, ідчі_
  { {0x9f420029,0x9cd60009,0x80270012,0x60080024}},	//   vskú_, _מורה_, ترام, жнім_
  { {0x26130149,0xdfce000a,0x3f9c0027,0xd2460003}},	//   tão_, ديو_, govu_, _كن_
  { {0xa6fc000b,0x7bcb0cb1,0xa9550024,0xed590024}},	//   שִׂי, _sugu, _екві, йок_
  { {0x26130149,0x7bcb03eb,0x7bc30ed5,0x7d0d0ed6}},	//   rão_, _pugu, _sinu, ngas
  { {0x26130149,0x9c220015,0x7bc3002c,0xdfd80048}},	//   são_, едыд, _pinu, _дъх_
  { {0x3b090046,0x59cf0037,0x26130017,0x31b60011}},	//   љено_, _संदर, pão_, ृद्ध
  { {0x7c2d03c0,0xe6100012,0xe2990578,0x27e9016d}},	//   hwar, _لشن_, сан_, _awan_
  { {0x50cb0011,0x661c005e,0x22580ed7,0x7c2d0ed8}},	//   िशिष, _ärka, ärka_, kwar
  { {0xf1c90020,0xa4870003,0xa3ab0037,0x69c40051}},	//   _tạo_, _بجان, खता_, _viie
  { {0x5456000b,0xcc56000b,0x69de004a,0xe1f10012}},	//   _מסנן_, _מבני_, yppe, _كسب_
  { {0xb5aa0003,0xd6cf0003,0x0b780012,0x68e20132}},	//   مارك_, اقف_, _بصنع_, ybod
  { {0x442d0002,0x7d0d002c,0x3cca0001,0xf9fa0009}},	//   owe_, ggas, слао_, _ההקמ
  { {0x2bba0012,0x07fa0012,0xa2be0011,0x7c2d0ed9}},	// [1c60] مائة_, _اربع_, वेन्, gwar
  { {0x083b0093,0x103b000b,0xf1c9001a,0xc2b6004c}},	//   _פעיל, _פגיע, _lạm_, пљењ
  { {0xa926005c,0xb6a30061,0xa2ce0037,0xa75b000b}},	//   здел, éâtr, तशब्, _הדיר
  { {0xc7c60001,0x31b205b1,0xcb090009,0x7c3b0040}},	//   пски, báze_, טל_, kvur
  { {0x6d3b000b,0xdbd10054,0x6b810028,0x68e200c7}},	//   _התכנ, qüèn, kilg, rbod
  { {0x501b000b,0xe3a70003,0x33b5003c,0x60c90eda}},	//   מונו, _سر_, _жёст, _egem
  { {0x7d1b0edb,0x7c220edc,0x60cd0035,0x3f9c0edd}},	//   ffus, _spor, žama, rovu_
  { {0x7d780003,0xb063004a,0x3f9c0580,0x1513003c}},	//   تمبر_, ääks, sovu_, едъя
  { {0x69d50066,0x68ed0ede,0x3cf70012,0x6b810248}},	//   ízen, _read, سعيد_, filg
  { {0x68ed03fb,0x44770093,0x27f70013,0x51f8002d}},	//   _sead, פעיל_, ření_, оною_
  { {0xd5be0037,0x68ed0051,0x7edb000b,0xe3af0012}},	//   ्दाज, _pead, _הקבצ, دري_
  { {0x7982003e,0x7aee0052,0xe3b8003a,0xc05b0024}},	//   niow, _lebt, smı_, біг_
  { {0x7c22066e,0xe53b000b,0x4346022a,0x85570009}},	//   _upor, _לתאר, _недв, _משאב_
  { {0xc7c400bb,0x1cbb0009,0x33940012,0xb9040011}},	//   есси, _המדע, _تلتز, _प्_
  { {0x68ed0005,0xd7880020,0x66b40001,0x69ce01e3}},	//   _tead, yển_, ебру, _nube
  { {0x7c2d0edf,0x82330012,0xe5090012,0x4ddb0009}},	//   twar, _أروا, تيرو_, מחלו
  { {0x2d5804b3,0x78fc000b,0x79820002,0x212b0066}},	// [1c70] чить_, _הפחו, diow, mech_
  { {0x212b0ee0,0x6e2d0034,0x8afc0034,0x7c2d0ee1}},	//   lech_, łabi, chęt, rwar
  { {0x20190051,0xbdb50001,0x3f830ee2,0x7aee0bb5}},	//   ltsi_, _обој, miju_, _debt
  { {0xfc3f0020,0x212b0ee3,0x92b40012,0x6b820025}},	//   _trí_, nech_, رحلا, éogr
  { {0x20190051,0x7e61006f,0xdd3a0009,0x5d3a0009}},	//   ntsi_, älpf, _וערכ, _ותרא
  { {0x80a00044,0xf838000b,0x25a90ee4,0xa3ab0011}},	//   _ऐडसे, פנות_, llal_, _कीं_
  { {0xf770000a,0x6d590002,0x26170017,0x644600ad}},	//   دان_, _powa, nço_, åkin
  { {0xc212000b,0x79820002,0x61fa0028,0x1c450055}},	//   _שהן_, ciow, _ætla, дним
  { {0x442d00bd,0x212b0066,0x200b0027,0x6b810ee5}},	//   uwe_, dech_, juci_, tilg
  { {0xf8b2000b,0xe1f90ee6,0x25a90060,0x8c1a0009}},	//   _ישן_, ого_, hlal_, קותי
  { {0xc2c5000a,0xf1c90020,0x290f006f,0x6d590ee7}},	//   بيدي, _tạm_, ogga_, _towa
  { {0x7bdd0005,0x290f0807,0x15f40003,0xd17a002d}},	//   _otsu, ngga_, _أسلح, існі_
  { {0xbf9b0017,0x02aa0037,0x3f830027,0x071f0011}},	//   rrên, _कर्न, fiju_, म्भव_
  { {0x3f830027,0x3ea0000d,0xae210011,0x79820034}},	//   giju_, şite_, _महान_, ziow
  { {0x7bcf0108,0xddd40029,0xad5a0055,0x46a30048}},	//   _aucu, ňažn, орах_, варв
  { {0xdb180006,0x7bcf000d,0x212b0030,0xd1ba0012}},	//   _eivä, _bucu, cech_, _باتا_
  { {0xeafa0003,0x3f830027,0x7bc70ee8,0x672104d2}},	// [1c80] قرات_, biju_, _biju, _oblj
  { {0x3f830ee9,0x63720058,0x91e6004d,0x2d8d0032}},	//   ciju_, _mæng, доже, hnee_
  { {0x637200c5,0x7bc700b6,0x539a0009,0x39990031}},	//   _læng, _diju, קיעו, vész_
  { {0x2d850031,0x257a0035,0x290f0248,0xd2560009}},	//   élet_, pūli_, _ögat_, ושעה_
  { {0xdfcf000a,0xe5710009,0x20890009,0xccf30009}},	//   لين_, _גַם_, ּתוֹ_, _בכר_
  { {0x212b0eea,0x9e140024,0xcdda004c,0x6d5d0248}},	//   zech_, едкі, оњи_, ösan
  { {0x79820002,0x8b030066,0x6360000e,0xde93004c}},	//   piow, _úřad, _dönt, кашњ
  { {0xd8260046,0x60260001,0x3f830027,0x71260012}},	//   _одби, _одба, ziju_, _ترسل
  { {0xf8b20037,0x212b0066,0xc0d30012,0xb8660012}},	//   _जरिय, vech_, _شيلب, _غارو
  { {0xd3700003,0xc21a0024,0xba54004c,0x185b0009}},	//   اهد_, оєм_, евој, _וכמע
  { {0xc3330093,0x212b0066,0x9f59000e,0x3f830027}},	//   דות_, tech_, pusú_, viju_
  { {0xf6530093,0xd788001a,0x7c260058,0x63720eeb}},	//   _בצע_, iểm_, _opkr, _hænd
  { {0x6360003a,0x3205002a,0x55bb000b,0xa3c00037}},	//   _yönt, arly_, _ומאו, ुदा_
  { {0x2d840eec,0x6360006f,0x200b0027,0x2905003a}},	//   lime_, _möns, ruci_, şla_
  { {0x212b01e9,0x3f830eed,0x63600248,0x639b0009}},	//   pech_, riju_, _löns, _וסגנ
  { {0x26170017,0x39490164,0x6360006f,0x69fb0009}},	//   rço_, _unas_, _oöns, _ולהק
  { {0x93b50001,0x91b80003,0x9f4200d9,0x3f830eee}},	// [1c90] ебац, _تطور_, lský_, piju_
  { {0x339b0012,0x326b0012,0x20190035,0x31960035}},	//   آخرة_, يحاً_, _īsi_, rāze_
  { {0x15e80044,0xeab4000b,0x09e4002d,0x2d840010}},	//   टीआर_, תִּי_, воєн, kime_
  { {0xaadf015f,0x4adf0044,0x02df0044,0x394902d1}},	//   _प्रक, _प्रव, _प्रभ, ñas_
  { {0x752d000d,0x63600028,0x60cd0035,0x99870031}},	//   meaz, _pönt, žamo, ínű_
  { {0x752d007d,0xbcfb0017,0xbae50003,0xe7360048}},	//   leaz, _elét, _سكري, ееш_
  { {0x69ca0037,0x11d40003,0x61ca0011,0x17580009}},	//   _संगी, _لتقد, िदृष, וסגר_
  { {0x63600163,0x752d007d,0xf532000b,0xe5050012}},	//   _föns, neaz, ָ֥ה_, ربعي
  { {0x64420108,0x7d1a0009,0x20fb0011,0x4426016d}},	//   _croi, הֵיה, ्लैश_, _cpo_
  { {0x64420108,0x60cd00c6,0xf1c9001a,0x636d0028}},	//   _droi, _agam, _hại_, _búna
  { {0x249b0010,0x80c20011,0x2d840073,0x60c40073}},	//   _žymę_, रेने, bime_, žimt
  { {0x6d5d0eef,0x25d6000b,0x752d000d,0x64420061}},	//   _nosa, _טוען_, jeaz, _froi
  { {0xc7960015,0xf1c9001a,0x26cc0029,0xeb8e0ef0}},	//   ервы, _mại_, ždom_, _би_
  { {0xf1c9008a,0x0dca0003,0x25710066,0x99710002}},	//   _lại_, كبرى_, _dále_, nął_
  { {0x443f0028,0x21cc0030,0x63a10031,0x753b001b}},	//   lvu_, _běhu_, moln, oduz
  { {0xed57057b,0x443f0027,0x6d5d0317,0x753b0ef1}},	//   нос_, ovu_, _cosa, nduz
  { {0xf1ca001a,0x09b70009,0xdced03a7,0x6d5d0ef2}},	// [1ca0] _nại_, _אפקט_, chač, _dosa
  { {0x138a0003,0x909b000b,0x99710002,0x8877000b}},	//   أخرى_, _מספק, jął_, _נתיב_
  { {0x2bb20044,0x32170003,0x9f5f000e,0xa3c00037}},	//   ुगता, فيلد_, _órán_, ंगत_
  { {0x7e61006f,0x443f0027,0xf1ca001a,0x2d840203}},	//   älpe, kvu_, _bại_, xime_
  { {0x40340098,0xa0670001,0x18670345,0xf9930009}},	//   телс, наца_, наци_, נרד_
  { {0xb9070037,0xfc3f0030,0x78ad005e,0xf1ca0081}},	//   _म्_, _vzít_, üava, _dại_
  { {0x8cba0037,0xe5c6022a,0xaac60012,0x8e370012}},	//   ्शको, нсио, _ستسن, فسير_
  { {0xf653000b,0xdb1c003a,0x6da30001,0x44320002}},	//   רצה_, _birç, лија, owy_
  { {0xe4520003,0x70af0037,0x63720058,0xed5e0081}},	//   اضع_, _घरेल, _tænd, _đột_
  { {0x752d007d,0xbf9b0061,0x5c7301d4,0x2d840ef3}},	//   zeaz, trêm, ульт, sime_
  { {0x443f0039,0x2a6a000f,0x7e9a0003,0x672e0058}},	//   avu_, ább_, _عنصر_, debj
  { {0x64420108,0x9f400028,0x32020042,0x9f420042}},	//   _troi, _svið_, čky_, rský_
  { {0x752d000d,0x38660ef4,0xb97b0009,0x48ab04a5}},	//   veaz, nyor_, לנטי, ятом_
  { {0x6601000f,0x33980012,0xd4370009,0xbf9b0025}},	//   álko, _تنتج_, _נטוי_, prêm
  { {0x752d007d,0x79a70104,0x6447001e,0xf1a70ef5}},	//   teaz, _прие, ājie, _прин
  { {0x55580014,0x99710034,0x1cbb00ae,0x2d9c0ef6}},	//   нася_, zął_, كاذب_, _ível_
  { {0x752d007d,0x6d5d0054,0x91bc0009,0xfbd30012}},	// [1cb0] reaz, _vosa, _צמחי, اتر_
  { {0x752d000d,0x673a0027,0xe6950012,0x5e950012}},	//   seaz, _natj, _للخد, _للخط
  { {0x69c90039,0xc987096e,0x61fa074f,0x443f01bd}},	//   _piee, нуди, nstl, zvu_
  { {0xbcfb000f,0x7ff50003,0x92b40003,0xd70e0011}},	//   _elér, نستا, احكا, _साउथ_
  { {0xfbe7001a,0xa3c00037,0xa3c20011,0xf1b40009}},	//   _chế_, ंगा_, ्दा_, אסף_
  { {0x083c000b,0x21040010,0xd7020048,0x257e0030}},	//   פעול, mčių_, азши, vůli_
  { {0xed590015,0xab94002d,0x63a105b1,0x3e320012}},	//   дой_, _сирі, voln, لفور
  { {0xf1ca0020,0x63a1003e,0x27ed0066,0x75d1001e}},	//   _tại_, woln, šeny_, _jāzi
  { {0x2104007a,0xe894002d,0x67d5002d,0x02c90037}},	//   nčių_, _бать, _розу, रश्न
  { {0x21040010,0x4a450695,0x9c180009,0x200f0a94}},	//   ičių_, внов, תחזק_, mugi_
  { {0x44320002,0xf2d2000b,0x443f0269,0xc0e60187}},	//   zwy_, יעי_, svu_, конк
  { {0x63a1000e,0x3f870ef7,0x1e560009,0x44320034}},	//   soln, linu_, _בשער_, ywy_
  { {0x63a1012e,0x8d740003,0x78fa0009,0xe14f0024}},	//   poln, _حالا, ופרו, рсiв_
  { {0x25ad0ef8,0x25a002a1,0x25bf004b,0x82850012}},	//   llel_, čile_, lmul_, _لجعل
  { {0x539a000b,0xe3c8001a,0x21040010,0xf8c7000e}},	//   _קיצו, _cựu_, ečių_, éért_
  { {0x395f0ef9,0x16140037,0x44320002,0x63860025}},	//   _nous_, तंबर_, twy_, _ténè
  { {0x3f870065,0x8cc40037,0xccf2000b,0x711b0009}},	// [1cc0] kinu_, ाइयो, יכן_, _חופפ
  { {0x09ca0037,0x200f0051,0x7e61006f,0xc8870052}},	//   िद्य, dugi_, älpc, ößer_
  { {0xf506057b,0xc332000b,0x7ae50051,0x21040073}},	//   _изно, שוב_, _õhtu, ačių_
  { {0x4a5a015a,0x8e970009,0xb8160011,0x53e60012}},	//   ודעו, _ידיו_, _तमाम_, _لأسف
  { {0x394d014a,0x26140037,0x3f870028,0x200f005e}},	//   _dnes_, नूनी_, finu_, gugi_
  { {0xbf9b0108,0x18670001,0xa0670001,0x07080012}},	//   quêt, ђаји_, ђаја_, ريعي_
  { {0x2bd80037,0xd6270001,0x6aa30052,0x7bca00b8}},	//   _भंडा, воје_, ünft, _rifu
  { {0xfbe70020,0xc693000b,0xc5f3000b,0x2ef80032}},	//   _thế_, יאו_, בדה_, harf_
  { {0x711b0009,0xd0e30011,0xbfc6076b,0xb7d70012}},	//   _קומפ, _क्षण_, _абак, _لوقا_
  { {0x3ce20011,0x3f870efa,0x6376004b,0x1eaa0012}},	//   _ट्रे_, cinu_, _mâng, _قاضي_
  { {0xcb130093,0xd257002d,0x6376000d,0x2ef80052}},	//   בלת_, вця_, _lâng, darf_
  { {0x25a60101,0x79a4003c,0x21040073,0x867b0009}},	//   _ukol_, иряе, yčių_, _קראו
  { {0x69d80066,0xf1bf0018,0x7d020018,0x38340365}},	//   ívej, rmá_, _idos, аняр
  { {0x25750623,0x61fa0032,0x248d0073,0x27e6020d}},	//   _måle_, pstl, _žemo_, ipon_
  { {0xfbb70093,0x0bb70093,0x26060011,0xba550081}},	//   _שפות_, _שלום_, सूची_, _vắcx
  { {0x69cb0037,0x3f870ee2,0xc115004c,0xbe3b0009}},	//   _सूची, zinu_, _смиј, ועלת
  { {0xc05b002d,0x0dc80291,0x511a0009,0x64c40012}},	// [1cd0] _цій_, тури_, _אֵינ, ليفل
  { {0x395f0108,0x41e7002d,0x201e000d,0x81c7001e}},	//   _sous_, віда, ătit_, zmēģ
  { {0x7d020026,0x2104007a,0xe8cb0037,0xe8050037}},	//   _odos, sčių_, िश्च, _रिहा_
  { {0xe4e4002d,0x200f005e,0xe1f00012,0x67d50934}},	//   _вірн, tugi_, تسك_, году
  { {0x395f02b5,0x3f870efb,0x2bce0321,0xb97c0009}},	//   _vous_, tinu_, _हंगा, ונאי
  { {0x753d0272,0xf1ca001a,0x61e50097,0x69c80030}},	//   _hasz, _hạt_, pphl, íjez
  { {0x395f0108,0x6376004b,0x25bf004b,0x753d0efc}},	//   _tous_, _mând, tmul_, _kasz
  { {0x2294007c,0x22490027,0x394d08b9,0x442b00b6}},	//   _тися, _čak_, _unes_, _kpc_
  { {0x69dc0026,0x3af500fa,0xcfab0003,0x753d0a8e}},	//   íren, лянс, _قائم_, _masz
  { {0x69d5003a,0x25bf000d,0xf1ca001a,0xb8820029}},	//   _kuze, smul_, _lạt_, číto
  { {0x75150003,0x200b0efd,0x198a00f5,0xa18a0294}},	//   _مواض, erci_, ебни_, ебна_
  { {0x753d003e,0x9f5e0066,0x058400b3,0x44390efe}},	//   _nasz, čtí_, _кучм, _oss_
  { {0x291e0002,0xb4fa0009,0xe44e0063,0x636401a0}},	//   ęta_, _נפסי, _уж_, _còns
  { {0x6d4f0b4a,0x8c280009,0xa8560009,0x7af50030}},	//   _anca, _יֵצֵ, אישה_, _nezt
  { {0x7bc1008b,0xa3c20037,0x539a000b,0xdb22000e}},	//   mmlu, ्दर_, _איסו, _óráb
  { {0x6d5b00c6,0x656d002c,0x64a60c80,0x7e610248}},	//   njua, gkah, габа, älpa
  { {0x9f4f0028,0xe3ba0ba3,0x2d9200b0,0x7af50eff}},	// [1ce0] yrgð_, еба_, rnye_, _bezt
  { {0x74130003,0x6376000d,0x0057000b,0x656d002c}},	//   صوما, _gând, _עשית_, akah
  { {0xe216000a,0x471b0009,0xccf90034,0x614606e5}},	//   طباع, _אויג, kaś_, лежа
  { {0xfe37000b,0x7c2b0f00,0x22580051,0xba170012}},	//   _ערכי_, _opgr, ärki_, طيها_
  { {0x673e000e,0x68f6003a,0xd12f0012,0x58d70024}},	//   _kapj, _meyd, ثمن_, удія_
  { {0x321e004a,0x8fa30339,0x753d0002,0xeef60009}},	//   ytty_, баче, _zasz, אמַר_
  { {0x7bdd0065,0x09cf0037,0x7c2b098f,0x5e260012}},	//   ísun, _संगठ, _apgr, اعتق
  { {0x4420007a,0x673e000e,0x7bce00b6,0x9f960051}},	//   oti_, _lapj, _hibu, lüüs_
  { {0xb716000a,0x7524000e,0x44200f01,0xa3c00011}},	//   _مباش, ifiz, nti_, ंगल_
  { {0xf0630046,0x673e000e,0x41e6002d,0x69d80011}},	//   _укуп, _napj, ліма, _नंदी
  { {0x6376000d,0x442007f6,0x28c70037,0x2bb70012}},	//   _rând, hti_, रेनि, داية_
  { {0x8446000a,0x7d02003e,0x44200f02,0xddb60012}},	//   _مختل, _udos, kti_, _صحاب
  { {0x4420009b,0x01370009,0xcebf0030,0x200b0025}},	//   jti_, ארכת_, ěřen_, urci_
  { {0x8417000b,0x7524000e,0x44390f03,0xdc3b0009}},	//   _עקוב_, efiz, _rss_, _נעור
  { {0x7afa0006,0x63030003,0xaadb000b,0x75240052}},	//   matt, _طويل, _אחור, ffiz
  { {0x63a50052,0x3d0f0011,0x6d400f04,0x75240031}},	//   wohn, िलें_, ndma, gfiz
  { {0x656d0101,0x44200071,0x8d4b0009,0x0fb9004c}},	// [1cf0] rkah, gti_, עֲלֵ, _илић_
  { {0x2d81000f,0x59d90037,0x753d0002,0x656d005e}},	//   éhez_, _बंदर, _wasz, skah
  { {0x7bce0f05,0x44200f06,0x64400035,0x7afa00b8}},	//   _dibu, ati_, _šmit, iatt
  { {0xd788001a,0x7afa0f07,0x2d8c0031,0x6d4f0f08}},	//   iểu_, hatt, édet_, _unca
  { {0x68f9003e,0x69da0061,0x6cfa000b,0xb4fa0009}},	//   rawd, _éten, _בפרס, _בפרי
  { {0x6d470039,0x7afa0006,0xdb01043d,0xf7450695}},	//   ējam, jatt, polé, реко
  { {0x7afa0b0c,0x539a000b,0xff040055,0xfaa90012}},	//   datt, _יישו, сячн, _شهري_
  { {0xdb01006f,0x05650f09,0x63bc0064,0x24920073}},	//   illå, рвин, _zhrn, _žyma_
  { {0x6d5b00b6,0x320b0002,0x28c70011,0x7afa0f0a}},	//   rjua, ącym_, रेमि, fatt
  { {0x25a0066e,0xb7bd007d,0xba750012,0xe3b10012}},	//   čila_, _opţi, لاجت, غرة_
  { {0x67250051,0x45d50014,0xc3320009,0x44200031}},	//   õhju, _тоес, חוי_, zti_
  { {0x213f00c6,0x64430039,0x44200f0b,0x69d80017}},	//   _jauh_, ānij, yti_, ívei
  { {0x671c0037,0x44200097,0x6fa60012,0x85c80012}},	//   _नामक_, xti_, لإسك, _إِنْ_
  { {0xb4c10037,0xcb6603ff,0x6c7a0009,0xa875003c}},	//   ंधी_, _ваше_, _ברנד, сующ
  { {0x0fc3007c,0x7bce00b6,0xacf60001,0x24f605fb}},	//   ійсн, _ribu, ичај, ичар
  { {0x1a9a000b,0x44200f0c,0x7d160010,0x257100d9}},	//   _ביצע, tti_, ugys, _málo_
  { {0x31bc0066,0xd4670014,0xbbba0012,0x5baa0223}},	// [1d00] níze_, аите_, ندئذ_, вкам_
  { {0xfbdf008a,0xb7fb0009,0xc6960012,0xdcf60060}},	//   _trên_, _שפית, _نشجع, ıcın
  { {0x201f0149,0x69c20070,0x644401a3,0xb2d30012}},	//   _aqui_, tmoe, svii, زينغ
  { {0xc8ca000a,0x39400010,0x7afa000e,0x44200f0d}},	//   نوان_, _jais_, zatt, pti_
  { {0x39400f0e,0xa01b0052,0x97c60695,0x69c20f0f}},	//   _mais_, rzög, айде, rmoe
  { {0x6e33000e,0x26cc05b1,0x88c50012,0xe3a70012}},	//   _újbó, ždou_, حتمل, _ذر_
  { {0x7afa06cb,0xd6d9002d,0x9c8701bd,0x539b0009}},	//   vatt, уті_, počí, _סילו
  { {0x5d540098,0x28c70044,0x39400101,0x64430002}},	//   скит, रेडि, _nais_, łnie
  { {0xa3e70001,0x1be70001,0x4d770009,0xc0aa0012}},	//   адња_, адњи_, יתקל_, _شارل_
  { {0x395203eb,0xd6f8000b,0x7ac60dd8,0xa6f80009}},	//   _anys_, _תִּש, исне, _תִּי
  { {0x0bb7000b,0x9f7b000b,0xfe720003,0x83b7000b}},	//   שלים_, _שנבח, _بدء_, שפיע_
  { {0x64490010,0xa1940024,0xc2370009,0x51f7003c}},	//   _šeim, жаюч, ברטו_, шнюю_
  { {0xb87b0066,0x63760017,0xe0df00b8,0xc8640f10}},	//   dcíc, _cânc, rcò_, отри
  { {0x3ea9007d,0x93fb000b,0x547b000b,0xd7f801ec}},	//   şate_, _ילדי, _שְׁנ, шую_
  { {0x63a800c5,0x3bbb000b,0xf1bf0029,0x39400061}},	//   modn, _שמוד, žšia_, _fais_
  { {0xda5b0093,0x661c005e,0x224d00eb,0x2129016d}},	//   _יכול, _ärku, _ček_, _ubah_
  { {0xa99c000b,0x91bc000b,0x54b90015,0xe4500012}},	// [1d10] _שבחר, _במהי, угая_, وضك_
  { {0x8ae7007c,0x28c70037,0xddce0029,0x2d8c0061}},	//   ріал, रेणि, ždňo, éder_
  { {0xcb370009,0x69da0031,0x1ba80012,0x69d80f11}},	//   שאבי_, _étel, جُلٌ_, _juve
  { {0x291900c6,0xb87b000e,0xe298002d,0x645d079b}},	//   ngsa_, bbít, шає_, äsik
  { {0x8d5a000b,0x59d00037,0x90450012,0x55ba0009}},	//   _עכשי, _संघर, إنته, _תמרו
  { {0x69d80061,0x6fd4002d,0xf1ca001a,0xef180024}},	//   _ouve, іціє, _lạp_, имі_
  { {0x64460028,0xb9e4002d,0x92580021,0x8e490012}},	//   ækin, _міти, _карт_, البك_
  { {0xf1ca001a,0x06980009,0x1e980009,0x59dd0011}},	//   _nạp_, ידום_, יכול_, _नंबर
  { {0x26130011,0xe8180012,0x39400f12,0x69d80f13}},	//   _धमकी_, _نزلت_, _rais_, _auve
  { {0xc6a70046,0x39400f14,0x63a80f15,0x4ea70469}},	//   _креи, _sais_, godn, _креа
  { {0x636d0bff,0xd94605fb,0x8b640012,0xb87b0030}},	//   _júni, бени, تايم, ycíc
  { {0xf7690009,0x598309f8,0x69d80f16,0xdb050b77}},	//   _אק_, злюб, _duve, llhä
  { {0x6be50003,0x493a0009,0xb9000011,0x63a80f17}},	//   _اكتم, נגשו, _तल_, bodn
  { {0x2bdb0044,0x5334022a,0xdee30863,0x75c30031}},	//   _बढ़ा, _мечт, зори, _tőzs
  { {0x26180037,0x1d0a02ac,0x69d80f18,0xfce60024}},	//   बंधी_, леви_, _guve, йово
  { {0xf1d00302,0xa1930001,0x6e930012,0xdb1a0097}},	//   _सूचन, _најч, ألفا, mmtá
  { {0x69d80052,0xb87b0f19,0xd1170009,0x442f0f1a}},	// [1d20] _zuve, rcíc, _הקפה_, _jpg_
  { {0x26180037,0x67350002,0x0b150009,0xcef6004c}},	//   बंदी_, cezj, מַ֣ר_, _учињ
  { {0xbf9b0025,0xeb97004c,0xab270048,0x20020f1b}},	//   rrêt, љих_, соха_, lski_
  { {0x9f490065,0xf8fa0003,0xda650012,0xa1130012}},	//   _hvað_, اءات_, غالي, كومت
  { {0x20020082,0x3014002d,0xb87b000e,0xbf9b0025}},	//   nski_, ідкр, lbír, prêt
  { {0x7c24001e,0x39400073,0xb87b01e3,0x69dc0031}},	//   mtir, žis_, ncía, írek
  { {0x8afb0093,0x7c240f1c,0xbb770009,0xcf250012}},	//   _תהלי, ltir, _פעלו_, ترني
  { {0x25a0066e,0xb9960003,0x8cc40037,0x63a80002}},	//   čilo_, _الرب, ाइलो, wodn
  { {0x20560001,0x69d80f1d,0x26180011,0x0caa003c}},	//   _утвр, _suve, बूती_, ытки_
  { {0x4f650003,0xc43b000b,0xc1ea0015,0x20020f1e}},	//   _والف, נתיי, льме_, dski_
  { {0xe1350047,0x69350015,0xdb1c0061,0x644b05ac}},	//   онны, онну, _chré, _ergi
  { {0xd2b70093,0x721b000b,0x68e204a3,0xba9b0009}},	//   מלית_, נוכח, ncod, רסטי
  { {0xbda50003,0x55bb0009,0x63a8064b,0x6d440f1f}},	//   _بحلو, _עמדו, podn, ddia
  { {0x7bdf0061,0x661c005e,0x24800dac,0x6d440f20}},	//   _équa, _ärks, dzim_, edia
  { {0xf1ca001a,0x41e60003,0xa5f90001,0xa293002d}},	//   _tạp_, _استف, ребу_, _наші
  { {0x7c240028,0xd0110012,0x6bd70012,0x3d060011}},	//   ftir, _قلب_, متطر, _षयों_
  { {0xe5200037,0xf9940009,0x2419003c,0x68e20227}},	// [1d30] _यानि_, _מרק_, розы_, dcod
  { {0x68e20070,0x2474001a,0x6d47001e,0x25a90018}},	//   ecod, ìm_, ējai, soal_
  { {0x7a35000a,0xa4d5002d,0xd2510003,0x42990012}},	//   تفاص, _моні, بنا_, جناح_
  { {0xdb0105db,0xc2c40012,0x621b0009,0xac190f21}},	//   volí, سيني, רואק, _кому_
  { {0xe8f8002d,0xc88b0003,0xe9d00003,0xa3b80011}},	//   слі_, دخال_, رغم_, चता_
  { {0x2d9a000e,0x8cbe0011,0xd7c80012,0xc0180009}},	//   épen_, _शरतो, مونه_, מקדו_
  { {0xdb180042,0xb5790024,0x24740081,0x65c50842}},	//   _chví, ищих_, èm_, обка
  { {0x2409005c,0x637b0025,0x20020b2c,0x2d9c0031}},	//   ании_, _dîne, yski_, _ívet_
  { {0x75ca003e,0xdb20003a,0x3ea90002,0x93590538}},	//   _języ, ütçe, łat_, арну_
  { {0x3b090001,0x1a050695,0x387200b0,0x6d440064}},	//   јено_, опом, øyre_, zdia
  { {0xeab1000a,0xcb12000b,0xe6950003,0x2474001a}},	//   بعة_, ולי_, _بلاد, àm_
  { {0x20020416,0x3a980015,0xf5b70012,0x68fb0025}},	//   tski_, стью_, _اصطد, _jeud
  { {0x443d0052,0xcfaa0003,0xd78a0012,0x644b0f22}},	//   _usw_, لاسم_, لنحو_, _urgi
  { {0xf767000a,0x7d1b0051,0xe8df001a,0x94740012}},	//   ذا_, lgus, _baịn_, _عدنا
  { {0xfc3f02d1,0x212d0f23,0x7d1b0a94,0x64490f24}},	//   _así_, _obeh_, ogus, lvei
  { {0x752900b8,0x20020f25,0x057a0012,0x7d1b0f26}},	//   nfez, pski_, جمرة_, ngus
  { {0x7d1b0051,0x6fb60003,0x64490f27,0xf6d60024}},	// [1d40] igus, _ومعا, nvei, _міня
  { {0x2575006f,0xe2920012,0xda660012,0xc2b6004c}},	//   _håll_, وذا_, ياضي, ољењ
  { {0xcf570009,0x021a0024,0xe0da0f28,0x3946003c}},	//   _ובית_, різь_, аве_, жнег
  { {0x64430002,0xdebb000b,0x7afe0ce7,0xc1780073}},	//   łnia, _כמיל, sapt, _įės_
  { {0x18360003,0x257c0066,0x4fc604ac,0xade00011}},	//   تراح, _cíle_, оска, _खंडन_
  { {0xe4510093,0xbb560003,0xdce2003a,0x7d1b0f29}},	//   _אֶל_, _بنسب, _bloğ, egus
  { {0xd95a0001,0x7afc004b,0xa1160012,0x3f8e0073}},	//   _краљ_, _iert, _ووست, rifu_
  { {0x2fc7020d,0xdb210031,0x31960035,0xd6a90012}},	//   amng_, ütöt, bāzi_, حدهم_
  { {0x7afc0179,0x644900b0,0x7d7b00af,0xe81605f3}},	//   _kert, gvei, ינקו, _तमगा_
  { {0xe3b20003,0x8afc0002,0x7d1b002c,0x1dda0011}},	//   برع_, djęc, agus, भदात
  { {0x64490010,0x27e90f2a,0x394601c5,0xd3370009}},	//   avei, _stan_, odos_, חריה_
  { {0x69dc0f2b,0x39460f2c,0xddcb0b64,0x7afc0f2d}},	//   _mure, ndos_, čiūn, _lert
  { {0x7dd5007a,0xf8ca0037,0xd7fb0001,0xe5710009}},	//   _išsa, िधिय, јум_, _רַב_
  { {0x28c70037,0xb4c80011,0xa6f80009,0x29040097}},	//   रेषि, ोखी_, מִֽי, ómar_
  { {0xccfb0001,0x2e480014,0x86240015,0x55590014}},	//   ића_, оято_, мьте, бавя_
  { {0xdd910012,0x66020034,0x98ca0011,0xc1790073}},	//   روء_, _łokc, िधाए, rpės_
  { {0x7afc00c6,0xd3750001,0x0bd50003,0xdcef000d}},	// [1d50] _bert, плаћ, سياح, _alcă
  { {0x20190f2e,0x27e9001e,0xbbd70009,0x9715003c}},	//   musi_, ķinā_, קובץ_, _эмоц
  { {0x69dc007d,0x64490039,0xea00001a,0x28c70037}},	//   _cure, zvei, _đảo_, रेरि
  { {0xf5590012,0x05590012,0x3f910220,0x69dc0f2f}},	//   _الحب_, _الحظ_, lizu_, _dure
  { {0x8d5a000b,0xe3170012,0x7afc0f30,0x66e503cd}},	//   _הכרי, _وبسب, _fert, пола
  { {0xa3f6000b,0x69dc0061,0x37ab0001,0x394601c5}},	//   _ממשק_, _fure, штен_, ados_
  { {0x7c3900a2,0xfe710012,0xf7700012,0x7bdd0060}},	//   şarı, عدت_, خان_, _husu
  { {0x7afc008b,0xdb01000e,0x7c3b0052,0xf2d20009}},	//   _zert, dolá, twur, _טעם_
  { {0xdbd60051,0x7d1b0673,0xc8640015,0x20190f31}},	//   jään, rgus, _отфи, jusi_
  { {0x547c000b,0x25710028,0x20190f32,0x3f140001}},	//   יטחו, _máli_, dusi_, _одус
  { {0x8d770003,0xa91d0010,0x63720058,0x7ae50832}},	//   _واصا, _amži, _sænk, icht
  { {0xac190047,0x24190015,0xb6ba000b,0x89360012}},	//   _году_, _годы_, _הצעי, أعدا
  { {0x62810102,0x04580012,0x28c70011,0x48b60048}},	//   szlo, _وجهت_, रेलि, ящот
  { {0x2b180011,0x39460073,0x03b70012,0x3f9e005e}},	//   _दाएँ_, zdos_, _بإصد, õtu_
  { {0x272f00a2,0x3ebe0f33,0x644b0028,0x20190010}},	//   mını_, ått_, ægin, ausi_
  { {0x18a6002d,0xceb2000b,0x7ae60066,0x63720058}},	//   _найм, גיל_, ěkte, _tænk
  { {0xd5af000a,0x7afc0f34,0xdca30469,0xf3f10081}},	// [1d60] افق_, _pert, еати, _ặc_
  { {0x272f003a,0xef860055,0x7bdd016d,0x6e2d0034}},	//   nını_, _хлоп, _dusu, łaby
  { {0x6edb000b,0xd6db000b,0x19ba027f,0xeef70009}},	//   _לחיפ, _לחיל, будь_, _ממיר_
  { {0x7afc008b,0x7bdd000d,0xe5a6004d,0x7ae504a3}},	//   _wert, _fusu, _хими, acht
  { {0x7afc00c6,0x69d60101,0xdb01000e,0xdb1e000e}},	//   _tert, _miye, zolá, ampá
  { {0x4cbb000b,0x6d460f35,0x94bb0009,0x272f0060}},	//   _לזכו, _haka, _למכת, jını_
  { {0x2902002c,0x272f003a,0x6d460f36,0xfaa30dc2}},	//   kaka_, dını_, _kaka, _заро
  { {0x7ec7000f,0x6d460947,0xd29b000b,0x2d92003a}},	//   lépé, _jaka, _השלט, niye_
  { {0x6d460f37,0x29020e6f,0x7d000f38,0xb4c80011}},	//   _maka, daka_, rams, ोखे_
  { {0xa87b000b,0x807b000b,0x68430014,0xfc2f0003}},	//   _האמר, _הנמצ, _януа, احي_
  { {0x2d92003a,0xcf250003,0x0cb90011,0xe1390024}},	//   kiye_, _ترقي, _आर्म, озні_
  { {0x6d460f39,0x2019093d,0xdb01000e,0x644a001e}},	//   _naka, tusi_, rolá, āfij
  { {0xdb01000f,0xb0c70037,0x272f003a,0x2d92003a}},	//   solá, रेंग, bını_, diye_
  { {0x272f003a,0x6442008e,0x7bdd0415,0x321a0f3a}},	//   cını_, _isoi, _rusu, kupy_
  { {0x29020163,0x7bdd0f3b,0xae1d0037,0x8b8b000b}},	//   baka_, _susu, बंधन_, _לָהֶ
  { {0x20060006,0xdbd60006,0xd2b7000b,0x6a9b000b}},	//   ksoi_, sään, _מלות_, _לשונ
  { {0xea000020,0xa0080012,0x03d50024,0xfce80012}},	// [1d70] _đạo_, _فقيل_, джаю, سفلي_
  { {0xa87c0093,0xe3b8003a,0x64430002,0x0bb4027f}},	//   _לאחר, nlı_, łnio, ебую
  { {0x7bd5007d,0x6d4600a2,0x7ae50052,0xe3b00003}},	//   _vizu, _faka, rcht, ارق_
  { {0x644203fc,0x637300a2,0x7ae50052,0xd8790003}},	//   _osoi, _sını, scht, يمات_
  { {0xe3b8003a,0x272f003a,0xb4d90011,0x25ad0227}},	//   klı_, yını_, ाशी_, voel_
  { {0x501c0009,0x44290f3c,0x6d460f3d,0x29020f3e}},	//   מודו, mta_, _zaka, zaka_
  { {0xee39007c,0x81bd0039,0x6d46030a,0x95c50012}},	//   іни_, ttēl, _yaka, ويته
  { {0xd6580093,0xd11f0037,0xc2c40012,0x13e90024}},	//   ליות_, _भाषण_, _سيقي, омий_
  { {0x272f003a,0x2d830010,0x2009001e,0xe3b80060}},	//   tını_, ėje_, _nvai_, flı_
  { {0xd389002d,0xe2990001,0xb2f40015,0x44290f3f}},	//   ійне_, жао_, няющ, ita_
  { {0x272f00a1,0x442900b9,0x8e990003,0x29020f40}},	//   rını_, hta_, _بناء_, taka_
  { {0x272f00a2,0xc692000b,0x3d070011,0x8c590012}},	//   sını_, _באב_, षणों_, _ولاء_
  { {0xa01b000f,0x9a99001e,0x3205002a,0x8c4502ad}},	//   szön, _šādā, ssly_, _целе
  { {0xdfd20003,0x81bd001e,0x6d490f41,0x29020f42}},	//   ئيس_, ntēj, ldea, saka_
  { {0x2d92003a,0x290204d2,0x6d460f43,0x32160012}},	//   tiye_, paka_, _paka, _قيود_
  { {0x60d60010,0x9f59004a,0x44290f44,0xf9fa0009}},	//   žymi, essä_, fta_, _והקמ
  { {0x2d92003a,0xdb070028,0xad250012,0x6f030f45}},	// [1d80] riye_, _skjá, عرفو, kanc
  { {0x6d49004a,0x257c0066,0x2d92003a,0xdcef0035}},	//   hdea, _díla_, siye_, ādāt
  { {0x2d800f46,0x753b0070,0x2d9a000e,0x673c0811}},	//   phie_, keuz, épek_, merj
  { {0x27e00006,0xe3b800a2,0xc329000b,0x321a0002}},	//   _kuin_, zlı_, יו_, rupy_
  { {0x7d04083c,0x27e00061,0xe3b8003a,0x29000017}},	//   mais, _juin_, ylı_, _meia_
  { {0xdc8b000b,0x7d040f47,0x29000f48,0x673c0f49}},	//   _וְלָ, lais, _leia_, nerj
  { {0x2f970009,0x27ed0227,0xda090011,0x25780097}},	//   וכסן_, _eten_, _विगत_, _féll_
  { {0x7d040f4a,0x27ed004b,0x7c290f4b,0x6da3004c}},	//   nais, ţeni_, fter, кија
  { {0x4f260046,0x673c00c6,0xe3b8003a,0x2b470f4c}},	//   _одаб, kerj, tlı_, _banc_
  { {0x661c0010,0x2d98000e,0x7d04086e,0x36360012}},	//   kurk, őre_, hais, _يراس
  { {0x7d040006,0x81bd0039,0xe3b800a2,0xa3de0037}},	//   kais, stēm, rlı_, _दूर_
  { {0x2d9e000f,0xc5f3000b,0x7d04004a,0x298b002d}},	//   étel_, _ידע_, jais, існо_
  { {0xdb0801e3,0x9f59008e,0xe3b80060,0x290001a0}},	//   lodí, yssä_, plı_, _deia_
  { {0x81bd001e,0x1cbb0009,0xc0580024,0x7dea0073}},	//   otēk, _ומדע, фію_, _tęsd
  { {0xdfd400e3,0x05770003,0x67d400bb,0x79a702ad}},	//   торы, وارد, тору, _орие
  { {0x9e4b0009,0xf9880012,0x7d040f4d,0x62850159}},	//   חֲמִ, _ينوي_, gais, vzho
  { {0x8cc40037,0x644d0061,0x44290f4e,0x3b550538}},	// [1d90] ाइटो, uvai, uta_, нкар
  { {0x31a4003a,0x752d0f4f,0xa3c30011,0x257c0097}},	//   mıza_, sfaz, ्षय_, _víla_
  { {0xc9150046,0xa1150003,0xb1150001,0xdb1c0028}},	//   едећ, فوات, емеш, _virð
  { {0x6f030f50,0x7c290f51,0x443f0034,0xae1a0009}},	//   wanc, yter, ywu_, _צורכ
  { {0x31a400a2,0xa3c30044,0xe4a70001,0x06f30011}},	//   nıza_, ्षम_, _црно, _अभाव_
  { {0x9f050003,0xf1ca001a,0xabfa0009,0x70520012}},	//   روبو, _dạy_, _מהשר, انوا
  { {0x81bd0039,0xbbbd0037,0x6d49000d,0x45d50014}},	//   rtēj, ्गीक, tdea, нцит
  { {0x7982003e,0x6f030f52,0x443f0034,0x81bd0035}},	//   chow, sanc, twu_, stēj
  { {0x27ed0119,0xfc480020,0x7c290f53,0x81bd001e}},	//   _uten_, _cử_, uter, ptēj
  { {0x2d8c0061,0xfaf10003,0xe3c50012,0x27e00f54}},	//   édez_, دثة_, عْدَ, _ruin_
  { {0x673c0f55,0x7bd80f56,0x68e409ef,0x3a99003c}},	//   verj, _divu, žide, ятию_
  { {0x46380003,0xf2d2000b,0xbd450012,0xe4510012}},	//   _تأكد_, טעי_, _سنتي, _مضت_
  { {0x6007007c,0x27e00054,0xdb01004a,0xa3db0011}},	//   нням_, _quin_, tolä, _ढंग_
  { {0xfbc50842,0x661c0f57,0x5c9a0009,0xa875003c}},	//   _ябло, turk, _צֹאנ, тующ
  { {0xcb12000b,0x8f9a000b,0x02450012,0xf7720009}},	//   _עלה_, לישי, _أَبَ, נקל_
  { {0x2d9f0061,0x661c003a,0x27e00227,0x3f83005e}},	//   nnue_, rurk, _tuin_, ahju_
  { {0xfc480020,0xa99b000b,0xc19b000b,0xdee60209}},	// [1da0] _xử_, _מבקר, _משקי, _попи
  { {0x7d040f58,0x9b460003,0x74130003,0xe3b709e3}},	//   sais, عناو, اولا, ебу_
  { {0x61eb007d,0xc332000b,0xe9da0838,0xdb1c0042}},	//   _înlă, רוב_, чке_, _chrá
  { {0xfbdf0061,0xa87a01b0,0xcb090009,0x25710097}},	//   _prêt_, ּאַר, מל_, _máls_
  { {0x26c70030,0x75c30031,0xa3de0011,0x75e70060}},	//   _únor_, _főzz, _दूं_, _rıza
  { {0xdfcf000a,0x501b000b,0x3dc60f59,0xa8a90009}},	//   مين_, פוצו, _show_, וֹצִ
  { {0xfc48008a,0xe2870003,0xe60f0012,0xf7730009}},	//   _sử_, _إذ_, مشي_, רקו_
  { {0x7bd803fc,0x5d540014,0xc6930009,0x25a0005e}},	//   _sivu, ткит, טאו_, nnil_
  { {0x64a30001,0x6f010f5a,0xdca3004c,0x10a307b9}},	//   лаћа, _felc, лаћи, _битн
  { {0xb8f30037,0x54330003,0xf8bf0025,0x25a00159}},	//   हे_, ارير, ngée_, hnil_
  { {0xc3330093,0xf6560024,0x25a00159,0x26de020d}},	//   אות_, _ятаю, knil_, _igto_
  { {0xbfa50020,0xfc480020,0x546a0014,0x4c86010c}},	//   hiệ, _tử_, _наем_, _плев
  { {0xc953000b,0xb9090037,0x2571000e,0x99840012}},	//   אמר_, _बल_, _vált_, الُو
  { {0xa3c30044,0x25a0012e,0x60c4001e,0xd5df0037}},	//   ्षण_, čilu_, _dzim, _पूँज
  { {0x9757000b,0xde580024,0x83690012,0x4e340009}},	//   עילו_, нарі_, _تصنف_, כָּן_
  { {0x7abb000b,0x257c0066,0x3abb0009,0xd5b8026d}},	//   _מצוו, _dílo_, _ממונ, есу_
  { {0x2ef50098,0x68ed003a,0x321e0002,0x71d80009}},	// [1db0] _изпр, _ifad, luty_, _אוהד_
  { {0x889c000b,0x339b0012,0x35b20011,0x8aa70103}},	//   _מבחי, أخرة_, ँकड़, нред
  { {0x22590003,0x321e0975,0xdd910012,0x314b0009}},	//   بلاد_, nuty_, _نود_, ּתְּ
  { {0x3978002d,0xc0d50012,0x621b0009,0xeab10009}},	//   нсію_, نياب, לובק, בֹד_
  { {0x6d5d0f5b,0x00e40024,0xb0cb0011,0xb87b0030}},	//   _insa, ужін, ़ेंग, ucíh
  { {0x7bdf0108,0x656f008b,0x2b1e0037,0x39490708}},	//   _équi, _hoch, _पाएँ_, žas_
  { {0xfbdf0149,0xb87b000e,0xe7080003,0x63720028}},	//   _três_, gbíz, رتون_, _vænt
  { {0x7dd5007a,0x6f010f5c,0x11d40003,0x6d4d0f5d}},	//   _išsk, _welc, _متقد, ndaa
  { {0x6d4d004a,0x7d02000d,0xb87b0066,0x69c9008e}},	//   idaa, _deos, abíz, _ihee
  { {0x69da0061,0x20c80012,0x87d70012,0x44390f5e}},	//   _éter, _أبِي_, _أغرا, _mps_
  { {0x6a860108,0x60c4000e,0xdce6001e,0x7c2d0f5f}},	//   _réfé, _szim, _lokā, htar
  { {0xc7a9000b,0x656f0f60,0x04b50048,0x7c2d0f61}},	//   _וב_, _noch, _исля, ktar
  { {0x8ccd0044,0x15180003,0x35db0037,0x5d78002d}},	//   देशो, _أزمة_, _मंज़, _яйця_
  { {0x24890f62,0x6d4b0f63,0xaba90012,0xfc460030}},	//   dzam_, _haga, _تهتم_, řích_
  { {0x6d4b0101,0xd62706a5,0x85b60001,0xc7b20009}},	//   _kaga, коре_, вљач, יבך_
  { {0x40960003,0xceb2000b,0x6d4b0f64,0x6d5d004b}},	//   _للعر, ׁים_, _jaga, _cnsa
  { {0x1ae60015,0x60c40027,0x7c2d0aba,0x6d4b0f65}},	// [1dc0] возм, _uzim, gtar, _maga
  { {0x8ad6000a,0xa3c10037,0x3eba0070,0xa3c30037}},	//   نتائ, ंति_, _typt_, ्षि_
  { {0x4dd60003,0xa77b0009,0xf8bf0025,0xdb080030}},	//   _لتحس, _חריפ, rgée_, nodá
  { {0xa1130003,0x69c90f66,0x3f9800b6,0x6d4b0f67}},	//   لومت, _chee, liru_, _naga
  { {0xa3c30044,0xa3c10037,0x95c70024,0xc9530009}},	//   ्षा_, ंता_, _шлюб_, ימא_
  { {0x44200f68,0xbb760014,0x18670001,0x69c90070}},	//   mui_, _румъ, таљи_, _ehee
  { {0x44200f69,0x6d4b050a,0x2d840061,0x96270012}},	//   lui_, _baga, thme_, نكوك_
  { {0x657b002c,0xe5c6004c,0x3ea0004b,0x442d0f6a}},	//   gkuh, њско, ăit_, fte_
  { {0x37e6007c,0xa3c00044,0x75e700a2,0x98be0066}},	//   _розг, ूगल_, _hızl, ětě_
  { {0x61e300a2,0x2bba0003,0x8e3a0012,0x671c0011}},	//   _bunl, باعة_, _يسار_, _नाटक_
  { {0x442000c6,0x831b000b,0x3377000b,0x9a860015}},	//   hui_, וויז, דעים_, тупл
  { {0x6d4b0160,0x64460028,0x6f070034,0x9695004c}},	//   _gaga, ækis, wajc, _сруш
  { {0x44200f68,0x68ed0164,0x442d0f6b,0x96eb0223}},	//   jui_, ñadi, cte_, дьба_
  { {0x321e002a,0x6d4b09d6,0xdce60035,0x29040f6c}},	//   puty_, _zaga, _rokā, _lema_
  { {0x35e4007c,0xda6f0098,0x91e30001,0x7c2d0002}},	//   ицтв, _тя_, _које, wtar
  { {0x29040f6d,0xed14002d,0x6d400f6e,0x7c2d0f6f}},	//   _nema_, имсь, nema, ttar
  { {0x54550047,0x44200f70,0xdb1a000e,0xc7ab0003}},	// [1dd0] ыват, gui_, elté, _يدخل_
  { {0x2d8200bd,0xd9cb0037,0x656f0052,0xbcfb0061}},	//   _elke_, िष्ट, _woch, _poés
  { {0x7bdc00b6,0x521500b3,0x31ae00d9,0x656f0f71}},	//   _diru, удет, lýzy_, _toch
  { {0x4420007d,0x27e400c6,0x6d400f72,0x442d0f73}},	//   bui_, _bumn_, jema, yte_
  { {0x4420053a,0x442d0f74,0x351a0009,0x7bdc0f75}},	//   cui_, xte_, _אורנ, _firu
  { {0x7dd5007a,0x07090003,0x69c9002a,0x442d00f1}},	//   _išsi, ريبي_, _whee, vte_
  { {0x3e320012,0xdcf60034,0x69c90834,0x6d4b0f76}},	//   مفور, łcąc, _thee, _paga
  { {0xc5f40009,0x0554003c,0x58050012,0xa3e70011}},	//   בדק_, атья, _مورك, _मंद_
  { {0xf1bf0026,0x656900ff,0x28050066,0x33d50024}},	//   dlá_, rjeh, ávně_, ліот
  { {0x9ee90003,0xc0c80014,0x2904001e,0x200909d4}},	//   _أفضل_, _русе_, _zema_, šais_
  { {0xadf5022a,0x3f98013a,0x6d400f77,0x6d4b0f78}},	//   _спеш, viru_, bema, _taga
  { {0x2d9a000e,0xeab20009,0x8dfa0009,0x29040f79}},	//   épet_, מֹר_, _נהנת, úma_
  { {0x628e0029,0xd096003c,0xdb080031,0x3f98016d}},	//   úbor, ушны, sodá, tiru_
  { {0x3ced009b,0x749a000b,0xdb080f7a,0xe7c30011}},	//   lcev_, _אינפ, podá, षतिप
  { {0x98a4003a,0xdbd10051,0x6fc00032,0xa3d70011}},	//   ımı_, _müüj, löck, ागन_
  { {0x22580058,0x3ced009b,0x7d090027,0x9da50012}},	//   ærke_, ncev_, naes, لصقه
  { {0x25bf000d,0xe0da01b6,0x75d30012,0x3942005e}},	// [1de0] ilul_, _яви_, إيقا, meks_
  { {0xdd0400a2,0xbb4a0003,0x39420289,0x44200f7b}},	//   ısın, علان_, leks_, rui_
  { {0x63af004b,0x7984016d,0xa3e40011,0x0f570009}},	//   _ţinâ, _kliw, _पूर_, _עיטם_
  { {0x11d70003,0x673b0027,0x39420051,0xfe9b0009}},	//   هولة_, đuje, neks_, _טיימ
  { {0x644a001e,0x79b70009,0x18330012,0x26c50064}},	//   āfis, נלנד_, مروح, ýlov_
  { {0x39420051,0xc808001a,0x47330024,0x6fb40011}},	//   heks_, rở_, йніс, ंकिं
  { {0x63ab000e,0x63830001,0x8cd60011,0x3942005e}},	//   égne, _угра, मेनो, keks_
  { {0x644d0051,0x746a0593,0x78260003,0x81bd001e}},	//   _üliõ, еров_, _معطل, ntēt
  { {0x6d400f7c,0x69d80073,0x9f9a008e,0x39420f7d}},	//   rema, įved, _pään_, deks_
  { {0x6d8702d1,0x5a340014,0xbc370003,0x6d400f7e}},	//   _añad, анот, اسيا_, sema
  { {0xee290003,0x2d9a000e,0xfbb70009,0x0bb70009}},	//   _لأنه_, épes_, רפית_, רלים_
  { {0xc9870012,0x3942005e,0x25bf004b,0x6fc00b77}},	//   اشدي, geks_, clul_, böck
  { {0x05b30012,0xa3d70011,0x63760f7f,0xb97b00af}},	//   _امنح, ागम_, _sânu, תרכז
  { {0x6376000d,0xba0a0003,0xead40f80,0xf1bf0f81}},	//   _cânt, _كتبك_, _коль, slá_
  { {0xa3c30044,0xa3c10037,0x6b7b000b,0x9bbb0009}},	//   ्षर_, ंतर_, _ארגנ, _רצופ
  { {0xbca50003,0x25ad013a,0x79840034,0xc6150011}},	//   لمزي, čelo_, _gliw, _तटीय_
  { {0xe04b0012,0x33f40012,0x3ebe00b0,0x6376004b}},	// [1df0] _أشبه_, مسلس, _lytt_, _fânt
  { {0x98b9001e,0x290b0f82,0xeb930012,0xf8bf01a0}},	//   cesā_, laca_, حظر_, sfés_
  { {0x3ebe028e,0xd6db002d,0x7d060031,0x69df0031}},	//   _nytt_, _яти_, _feks, _épes
  { {0x3135002d,0xe4e4002d,0x99d40003,0x3547002d}},	//   редр, _гірн, متنا, _схов
  { {0x3ced009b,0xd7050c7b,0xa1ac00af,0xf1940557}},	//   vcev_, азли, עֱבִ, щиць
  { {0x9e090003,0x17f80003,0x9172001a,0x3ebe07c7}},	//   نيتك_, ارنة_, rở_, _bytt_
  { {0x2778000b,0x25bf000d,0x6d4f00b6,0x7d09004a}},	//   רגון_, tlul_, _kaca, taes
  { {0x290b001b,0xed590148,0x6e920012,0x6fc00032}},	//   jaca_, тои_, غليا, töck
  { {0x0d82007c,0x3ebe0065,0xb81c0037,0x57270003}},	//   ільн, _eytt_, _नियम_, _مراق
  { {0x30840003,0x15e50011,0xa75700ae,0x6d4f0f83}},	//   _الكف, कदार_, _حضرت, _laca
  { {0x39420005,0x3ced009b,0x5ac6003c,0xc8690009}},	//   teks_, pcev_, ильм_, _קן_
  { {0xd2b6000b,0x49960024,0xe29601c6,0x7c2d004b}},	//   ילתת_, ршот, раю_, _ţaru
  { {0x764e0028,0x6d7a000b,0x39420051,0x7d060f84}},	//   _ábyr, _שאנח, reks_, _reks
  { {0x394203fb,0x8c1a000b,0x6376000d,0x3c8a0009}},	//   seks_, _יוני, _dâns, _שָׁ֑
  { {0x3ebe0028,0x290b00b6,0x539a01b0,0xe81c0011}},	//   ætt_, baca_, _ביסו, _निभा_
  { {0x60c9009b,0x99900002,0x41b30012,0x64590034}},	//   _ozem, żała_, _ومور, _krwi
  { {0x81bd001e,0xcaf60003,0x19bb000b,0x07a60560}},	// [1e00] rtēt, لساب, _במקב, _вапн
  { {0x6e2f000e,0xb8820066,0xddd80010,0x187b0009}},	//   önbö, říkl, tyvū, _סטיב
  { {0xeb970001,0x4a460449,0x590a0048,0x00e60a21}},	//   јих_, рнев, веем_, ажен
  { {0xc2360009,0x7dc50031,0x3f850522,0x7d0605ed}},	//   ירעו_, dóso, _allu_, _ueks
  { {0xa01b000e,0x33d6002d,0x60c90002,0x70540003}},	//   szöv, _вівт, _czem, إنتا
  { {0x2d800002,0xc7a30014,0xa857000b,0x90570009}},	//   lkie_, оичк, יינה_, יבנו_
  { {0xbb3b000b,0x7fd7000b,0x7c240b45,0xe8e00081}},	//   _שעלי, בוסס_, luir, _muối_
  { {0x3f850051,0xdb070f85,0x44320504,0xad660012}},	//   _ellu_, _skjø, oty_, شابه
  { {0x290b0f86,0x89db0009,0x69c2005e,0xf486091c}},	//   vaca_, _יחלי, mloe, руйн
  { {0x6e3e0033,0x44320f87,0xda7a0048,0xdf490012}},	//   _oppb, ity_, вям_, _مؤمن_
  { {0x61e000a2,0xa6960001,0x4432004a,0xcb13000b}},	//   _kiml, _трај, hty_, חלת_
  { {0x6b9a0054,0x60c0004a,0x25780031,0x067b0009}},	//   sitg, _kymm, _célt_, _שנאל
  { {0x248d0002,0xdbdc0066,0x6d440018,0x2d800034}},	//   czem_, lšíh, deia, dkie_
  { {0xe8e00020,0xdb05006f,0x7c24020c,0x6d4f0b45}},	//   _cuối_, llhö, duir, _saca
  { {0xada50029,0xf2060014,0x603a001e,0x290b0027}},	//   skúš, _тяло, lāmā, paca_
  { {0xccf80001,0x443203d9,0x69c8001e,0xaadb0009}},	//   ићу_, fty_, _ūden, _בחור
  { {0x4424014d,0x6562014a,0x5b1500fa,0x7c240f88}},	// [1e10] num_, _mnoh, ймат, guir
  { {0x6d4f00b6,0x8c1b000b,0x9cd7000b,0x2d800002}},	//   _waca, כומי, שומה_, akie_
  { {0xd251000a,0x5a350014,0x32670001,0x60c9000e}},	//   ثنا_, снет, штав, _szem
  { {0xac19002d,0x10150003,0x2d800f89,0x44240f8a}},	//   _йому_, مبتد, ckie_, kum_
  { {0x765a003e,0x44240efb,0x7d0d0f8b,0x27e90f8c}},	//   _arty, jum_, maas, _juan_
  { {0xbb85000a,0xcc76000b,0x44240f8d,0xe7fa0011}},	//   _السي, _הגשת_, dum_, ्ठता_
  { {0x6fcd0029,0xe718000b,0x8e390012,0xff180009}},	//   júce, בחור_, استر_, בקות_
  { {0x44240065,0xa01b0052,0x69c20054,0x31b20029}},	//   fum_, nzös, cloe, bázy_
  { {0x44240f8e,0xec790015,0xe3b90867,0x000000c4}},	//   gum_, упп_, лби_,
  { {0xd774000a,0x5f740003,0x8c1a000b,0x248d0679}},	//   _والع, _والر, נותי, rzem_
  { {0xe9da0098,0xc3320093,0x7c24000d,0x248d0053}},	//   лко_, הוי_, zuir, szem_
  { {0xa06a0001,0xe9a6002d,0x186a01d4,0x6a960009}},	//   гама_, самп, гами_, מכתא_
  { {0x4424007d,0xb09a002d,0x645d0058,0x79ba0009}},	//   cum_, утнє_, æsid, רֶיה
  { {0xa0270065,0xdce9001c,0x5456000b,0xcc56000b}},	//   _stöð, iječ, _לסנן_, _לבני_
  { {0xc9f5000a,0x51f50003,0x2d800002,0x64490052}},	//   _استع, _استر, tkie_, lwei
  { {0x443201d5,0xceb2000b,0x752901e0,0xb6a3048c}},	//   tty_, פין_, ngez, числ
  { {0x98b9007d,0x6449008b,0x69c20070,0x1ddf0037}},	// [1e20] resă_, nwei, vloe, _पूछत
  { {0x212d00b6,0x5f460003,0xa01b000e,0x2d800250}},	//   _aceh_, _اندل, rzöt, skie_
  { {0x7d0d0051,0xd36f0003,0xe8fa0001,0x64490f8f}},	//   baas, عهم_, гле_, hwei
  { {0xed5f0029,0x64550035,0x32170012,0x75290227}},	//   ážte_, āzij, إيند_, jgez
  { {0xa3e70044,0xc013002d,0x3a250070,0x7c240502}},	//   _मूल_, зміщ, hulp_, quir
  { {0xe8200044,0x2fd70003,0xa0070003,0xef0e0048}},	//   _बिना_, موند_, حقول_, амa_
  { {0x52860003,0xb7db000b,0x44240002,0x442007c4}},	//   _الأك, נקצי, wum_, lri_
  { {0x3f9c0006,0x64490052,0x9f84004a,0x9bf40024}},	//   sivu_, fwei, löä_, озич
  { {0x40960003,0x161a0011,0x9dad0011,0x79820034}},	//   _الذر, _नटवर_, ँकड़ो, mkow
  { {0x44200065,0xd2140001,0x7a380024,0x7b660148}},	//   iri_, омоћ, апор_, стие
  { {0xb7d70003,0x8afc0002,0x44240f90,0xd4e60048}},	//   _اولا_, djęt, sum_, _люли
  { {0x7982003e,0x44240065,0x6562004a,0x8afc0002}},	//   nkow, pum_, _unoh, ejęt
  { {0x39520036,0xd0060003,0x27e90f91,0x853b000b}},	//   _days_, بل_, _quan_, _תגדי
  { {0x799d00c6,0x9cd70009,0xf0930009,0xd5be0035}},	//   sisw, _הודה_, לנר_, žādo_
  { {0x7a1c007d,0x53370009,0x4b370009,0x877b0009}},	//   nătă, _לנגן_, _לרגל_, נאלי
  { {0x63ba012e,0xe9a40001,0x7df1001e,0x32530014}},	//   lotn, _најп, _jāsa, _хвър
  { {0x79820002,0x44200f92,0x2d580021,0x6fb50012}},	// [1e30] dkow, gri_, щить_, _ومبا
  { {0x7d0d0051,0x5b150024,0xdce9001b,0x2d9e08cf}},	//   saas, імет, vječ, éter_
  { {0x26c70029,0x7d0d004a,0x64490032,0x27f80159}},	//   _áno_, paas, zwei, _črna_
  { {0xf1c90044,0x41c90037,0x44200f93,0xdce90027}},	//   रतिन, रतिस, bri_, tječ
  { {0xa3d50014,0x63ba0f94,0x18690209,0xe72e0294}},	//   _момч, kotn, рали_, ме_
  { {0x36190047,0x98b90010,0x66fb0011,0xdce9001b}},	//   ацию_, cesą_, ्रिक_, rječ
  { {0x994d0026,0xdce90027,0xdb010060,0xff180009}},	//   môžu_, sječ, rolü, זקות_
  { {0x4c85007c,0x25a90597,0x64490f95,0x06960012}},	//   жлив, nnal_, twei, غنية_
  { {0x61ea0052,0xb4650024,0x39520132,0x13e6003c}},	//   _aufl, ікол, _rays_, омый_
  { {0x6449008b,0x290f0f96,0x3952002a,0xeb9900db}},	//   rwei, laga_, _says_, рио_
  { {0x89aa0047,0x39520108,0x6449008b,0x753d0002}},	//   иков_, _pays_, swei, _obsz
  { {0x290f01b7,0x15a80048,0x44200f97,0xf7690009}},	//   naga_, _лъчи_, yri_, _בק_
  { {0x2bbe0044,0xfd100012,0x43850012,0x25a908ca}},	//   ्तमा, _سجن_, _ولصق, dnal_
  { {0x3952002a,0x79820002,0xbae50012,0x290f0f98}},	//   _ways_, zkow, _بكثي, haga_
  { {0xdb01000f,0x290f0f99,0x79820002,0xaf99027f}},	//   soló, kaga_, ykow, стях_
  { {0xa0a6002d,0xa3c30037,0x290f002b,0xf6520009}},	//   _майд, ्षक_, jaga_, וצל_
  { {0x7d0b000f,0x9f840006,0x0eb60037,0xa7d60012}},	// [1e40] _megs, töä_, _आँकड, _وتخص
  { {0x76410e46,0x44200f9a,0x2bcf0037,0x7d0b0f9b}},	//   _oply, rri_, _सीमा, _legs
  { {0x7982003e,0x98b9007a,0x4375002d,0x61400028}},	//   tkow, resą_, чутт, _nálæ
  { {0x08c6004d,0xed5a04fb,0xae570009,0x9f84008e}},	//   обен, _том_, _וסטס_, söä_
  { {0x79820002,0xf993000b,0x9172001a,0x69c6009f}},	//   rkow, ורא_, iờ_, ilke
  { {0xdfcf000a,0x79820002,0x9af60012,0x394601e3}},	//   نين_, skow, _ذكرت, seos_
  { {0x290f01b7,0xa3d70011,0x394601e3,0x46140012}},	//   baga_, ागर_, peos_, أوبر
  { {0x61e4004a,0x63ba0d61,0xd5b00012,0x71660012}},	//   _niil, wotn, عفة_, _باسك
  { {0x236a0001,0xb143002d,0x61ea000d,0x63ba0826}},	//   ајно_, _інфл, _sufl, totn
  { {0xc43b000b,0x25ad0133,0x2480003a,0x61fe07c7}},	//   סתיי, čeli_, iyim_, oppl
  { {0x3266002d,0x5ea60012,0x63ba0f9c,0xdb0101a0}},	//   ітов, _بمال, rotn, tolò
  { {0x63ba009b,0x656f0052,0x9c660012,0xdebb0009}},	//   sotn, öcht, _وهاو, _דמבל
  { {0x7dd50010,0xdb0101a0,0x7df10035,0x83f80048}},	//   _išsp, rolò, _jāsn, _уелс_
  { {0xa2940024,0x35c30011,0x5bc60012,0x60cd0159}},	//   _налі, _वीज़, _بتصف, _vzam
  { {0x69330013,0x25a00051,0x9df8000b,0x290f002c}},	//   _přeč, fiil_, מִּז, yaga_
  { {0xf568002d,0x481500f5,0xd0110012,0x74a70a36}},	//   ошук_, _емис, _كلب_, ојзе
  { {0x6ebb0037,0x99d40003,0xe8e0001a,0x290f0051}},	// [1e50] _शुरु, _تتوا, _buổi_, vaga_
  { {0xd25b069b,0x03d4002d,0xbcfb0064,0xdb1a0097}},	//   ице_, джую, _iném, amtö
  { {0x25a00051,0xdced0027,0x8aa70024,0xfc3f0081}},	//   biil_, ljač, црад, _axít_
  { {0x99810030,0xdced001b,0xb5a7052c,0xe81c05f3}},	//   ruhů_, ojač, _фрой, _निशा_
  { {0x644f00c1,0x24920002,0xdd100f9d,0xdca60012}},	//   _usci, czym_, _užši, _أى_
  { {0x442900c6,0xdceb0034,0x637f0018,0x69c00060}},	//   mua_, _mogą, _têni, _ekme
  { {0x64420017,0x44290f9e,0xf96b0264,0x91720081}},	//   _apoi, lua_, _край_, hớ_
  { {0x3cf70037,0x76410029,0x4429004b,0x66150031}},	//   ीरें_, _vply, oua_, iszk
  { {0xc9520009,0xdced001b,0x752d0031,0xc0580024}},	//   _אמן_, jjač, igaz, _міф_
  { {0xcf780003,0x4429004b,0xab29004c,0xe3b10012}},	//   _وإلا_, iua_, љона_, عرة_
  { {0x61e4004a,0x764101e9,0x656f0032,0xb6030030}},	//   _piil, _uply, öchs, ýšle
  { {0xe8020044,0x4429004a,0x644f0058,0xed580024}},	//   रीका_, kua_, æcis, _моє_
  { {0x38550014,0x25a0005e,0x66150efc,0x61e40f9f}},	//   мърс, viil_, eszk, _viil
  { {0x442906ac,0xddc10066,0xcc760009,0xabfa0009}},	//   dua_, _splň, _מענה_, _ההסר
  { {0x6abc0032,0x7c290fa0,0x61e4008e,0x25a0005e}},	//   ürft, luer, _tiil, tiil_
  { {0x291e0010,0xceb20009,0xa06a004c,0x63a10fa1}},	//   ėtas_, ׂים_, _гаиа_, liln
  { {0x201a0003,0xd4670a31,0x98a600f5,0xc4c60012}},	// [1e60] _اتبع_, пите_, _хипе, سترو
  { {0x645b004a,0xe7ef0011,0x63a109df,0x909b0009}},	//   ivui, _चढ़ा_, niln, _לספק
  { {0x61fe0065,0xb77b0093,0x2492003e,0x877b000b}},	//   uppl, _האיש, szym_, _האיי
  { {0x3cf70037,0x290d000d,0x7e610058,0x673c0028}},	//   ीरों_, _ceea_, ælpe, lfrj
  { {0xa3cb0044,0xe8e0001a,0xbc190024,0x93c6004b}},	//   लता_, _tuổi_, _мірі_, epăş
  { {0x26c50013,0x68ed0029,0xfbc70012,0xbf9b0025}},	//   _bylo_, ľada, _ست_, mpêc
  { {0x68ed0013,0x63a1012e,0x6b630024,0x16370012}},	//   žada, diln, _якра, كسية_
  { {0x7c290164,0xb6080066,0x63be001b,0x63a10032}},	//   fuer, jišť, lopn, eiln
  { {0x8e200024,0xbd870012,0xbcfb0064,0x26080011}},	//   рiв_, ثنين_, _poéz, _सबकी_
  { {0x57fb0093,0x53be0037,0x70170009,0x53980024}},	//   _ללמו, ्तिश, _מחמד_, івня_
  { {0xfbcf0012,0x7c290032,0x7df10035,0xa3e40011}},	//   دتي_, auer, _jāsl, _पूछ_
  { {0xed590107,0x63be014a,0x9f4401a0,0x6d49004b}},	//   tože_, hopn, _humà_, ceea
  { {0x7c290164,0x53340015,0xf1bf0064,0xf1b00012}},	//   cuer, _желт, ýšia_, اءٍ_
  { {0x44290006,0x61ee0061,0x44a50012,0x07090012}},	//   vua_, _oubl, _تحمّ, تيسي_
  { {0x8b3b000b,0x433b000b,0x733b000b,0xc6680001}},	//   _התוצ, _העוב, _העוס, пште_
  { {0x7d04002c,0x44290fa2,0x7c240fa3,0x66150031}},	//   gbis, tua_, frir, rszk
  { {0x3f8c003a,0x6fcd0029,0x752d000e,0xd91c000b}},	// [1e70] _oldu_, dúcn, rgaz, _הוחל
  { {0x3b540fa4,0x026b003c,0x25a00030,0x7d040fa5}},	//   нкур, йшей_, čily_, abis
  { {0x7bda0065,0x798d0002,0x4429086e,0xb606001b}},	//   imtu, _klaw, sua_, nošć
  { {0xc5f80039,0x44290fa6,0x7dc501c5,0x99d70012}},	//   ģēt_, pua_, pósi, ستضا
  { {0x27ed001a,0x98c70012,0x7c240025,0x44290fa7}},	//   _quen_, أغان, crir, qua_
  { {0xf7710003,0x777a0054,0x394b0025,0xdb23008e}},	//   ضات_, _cotx, hecs_, äräa
  { {0xdce9001e,0x63a10fa8,0x6e950012,0x64420025}},	//   pieļ, viln, بلغا, çoiv
  { {0x27ed0fa9,0x63a10034,0xdb0501a0,0x3f8c0097}},	//   _tuen_, wiln, cohò, _eldu_
  { {0x97250012,0x69c30025,0xed590159,0xfd580009}},	//   _يفرو, îneu, tožb_, לשהי_
  { {0x7d0f000e,0x7d040052,0x33990012,0x645b0227}},	//   _lecs, zbis, تخبة_, rvui
  { {0xcb12000b,0x3ce60029,0x63a10faa,0x3dc9002c}},	//   כלי_, ľovi_, riln, klaw_
  { {0xa96a0046,0x499a007c,0x7c240065,0x7c290164}},	//   цима_, ітня_, yrir, puer
  { {0xbcfb0029,0xc9160009,0x7c290fab,0xd1160009}},	//   _inéh, וחרת_, quer, וקרה_
  { {0x7df50010,0x8c420de1,0x7c240fac,0x3f8c00d9}},	//   _sąsa, _реше, vrir, ódu_
  { {0xaa92000a,0x7d0f000f,0x25ad0058,0xe7370015}},	//   _للوث, _becs, onel_, ьер_
  { {0x3cf50044,0xceb2000b,0x25bf000d,0x99520010}},	//   एँगे_, דיל_, noul_, ršų_
  { {0x7d040101,0x64a30001,0xa01b004a,0x6fcd0029}},	// [1e80] rbis, вата, lyön, júco
  { {0x387f0052,0xaad10011,0x6fcd0064,0x1c39003c}},	//   äure_, _हराक, dúco, яясь_
  { {0x68ed0064,0x72030012,0x7dc50031,0x63be0fad}},	//   ľadn, َوْم, lósu, ropn
  { {0xdce90013,0x2f0a0002,0xda650003,0x80a60012}},	//   ěněn, _mógł_, عالي, ومان
  { {0xb8f60044,0x7bc80028,0xd7ef0003,0x7bc3016d}},	//   _हर_, yldu, لكن_, _oknu
  { {0xa634002d,0x61ee0051,0x4b550048,0x25ad0060}},	//   енкі, _tubl, _пъст, enel_
  { {0x9f8d0028,0x69c40fae,0x97c50012,0x114a0012}},	//   nþá_, _okie, رتهم, _وجرى_
  { {0x2dd7000a,0x99860066,0x1d340048,0xba9b0009}},	//   وبية_, dulů_, хния, _וסלי
  { {0x7e870010,0xdb18068c,0x21a30faf,0x5b7400ae}},	//   _įspū, _akvá, _ритм, ُّخذ
  { {0x42740015,0xa87b0009,0x807b0009,0x307b0009}},	//   егос, _ואמר, _ונמצ, _ואמנ
  { {0xe9f8002d,0xfe460024,0xa159004c,0x798d016d}},	//   янні_, _індо, пану_, _plaw
  { {0xc486007c,0x2167002d,0x1ea90012,0x85f70009}},	//   _олек, фтог, _عالي_, _חמאס_
  { {0xc058002d,0xf5770003,0x10740109,0xa3e70011}},	//   мір_, _تمنع_, вляю, _मंच_
  { {0x0efb0037,0xbc670012,0x27c400ae,0x880605f3}},	//   ्रेस_, _آمون_, َيَّ, सीएफ़_
  { {0x7dea0002,0x3bbb0009,0x5b330012,0x386d004b}},	//   _gęst, _ומגד, _شعور, ţer_
  { {0xcdd80001,0x58d5003c,0x99990034,0x03f9004c}},	//   дњу_, _пойт, żyła_, знај_
  { {0xdb01005e,0x7d0201e3,0x60c00032,0x69dd0fb0}},	// [1e90] rolö, ñosa, ümmt, mmse
  { {0x6d97000d,0x2bb80012,0x1a8b0012,0x43740024}},	//   nţar, والة_, يضاً_, куєт
  { {0x98ac0002,0xdcee0030,0xc50b0012,0xe7e80011}},	//   ędą_, ýděl, _وتحل_, _टूटा_
  { {0x68ed0029,0xe5070012,0x8aab0009,0x7d1d0032}},	//   ľado, _تبدي, חֹדֶ, _udss
  { {0x6cfa0093,0x50670003,0xb4fa000b,0x68ed0107}},	//   _מפרס, بطاق, _מפרי, žado
  { {0x6d420132,0xd00e0012,0x7e550fb1,0x657d0fb2}},	//   _aboa, حلو_, етиц, _hosh
  { {0xee3900bc,0x2bbe0037,0x7c2d0fb3,0x23be0037}},	//   їни_, ्तरा, luar, ्तरद
  { {0xc8670048,0x50670048,0x63a5016d,0xec790048}},	//   _отзи, _отза, lihn, зпи_
  { {0x73e50048,0x25ad0fb4,0x25bf004b,0xed590fb5}},	//   ноиз, rnel_, roul_, rdž_
  { {0xa3bf0037,0x69c401f6,0xe2990001,0x99860066}},	//   ँकि_, _skie, зао_, tulů_
  { {0x61e90006,0x20190028,0x6d4d004a,0x7c2d0051}},	//   _kiel, essi_, keaa, huar
  { {0x865a0009,0xf9920012,0x4c950048,0x99d60012}},	//   _מדעי, ابد_, _пиес, عتدا
  { {0x7a3500a2,0x5576000b,0x656b00c1,0x9c870012}},	//   _bütç, _רענן_, _ingh, _تشاه
  { {0x61e90039,0x7dea007a,0x7c2d08b3,0x69cb0052}},	//   _liel, _tęst, duar, hlge
  { {0x0b780003,0xcb660015,0x3c43001e,0x6d590fb6}},	//   _تصنع_, _чаще_, hīvā_, _kawa
  { {0x6d5900c6,0x6d5b0167,0x52740003,0x69c40034}},	//   _jawa, ndua, _جاهز, _ukie
  { {0x6aa80037,0xeb39000b,0x6d590a60,0x809f0011}},	// [1ea0] कप्र, ּעֲש, _mawa, _खेले
  { {0x68ed0002,0x6d5900b6,0xe45f008e,0xa3c10011}},	//   _zgad, _lawa, _työn_, ूति_
  { {0xc4c9000b,0xe7330009,0xa92603cd,0x2d8f005e}},	//   צג_, _עֵץ_, едел, _olge_
  { {0xb17b006f,0x61e90fb7,0x6d590fb8,0x6d4d0227}},	//   rmåg, _ciel, _nawa, ceaa
  { {0x6376007d,0xd117000b,0x4fc6004d,0x61e90fb9}},	//   _vânz, תקנה_, нска, _diel
  { {0x501b000b,0xdb070028,0x7d160fba,0xfaa60fbb}},	//   לונו, _skjö, lays, _заго
  { {0x6d590160,0x61e90fbc,0x3ce60064,0x7c3b0fbd}},	//   _bawa, _fiel, ľovu_, etur
  { {0xdd970015,0x09e30578,0x6d59016d,0x89da0012}},	//   ешь_, _босн, _cawa, _روذر_
  { {0x7c3b002c,0x6d590fbe,0x98af0073,0xdb1e01a0}},	//   gtur, _dawa, degė_, topè
  { {0x09c90044,0x9696046d,0x61e90fbf,0x51f80024}},	//   रत्य, _преш, _ziel, мною_
  { {0x200d008b,0xeb97000b,0xdb080002,0x61e9002a}},	//   _zwei_, גדיר_, wodó, _yiel
  { {0x6d590a60,0xbbbe0011,0xdb01008e,0x442d0fc0}},	//   _gawa, ्तुक, enlä, bue_
  { {0x20190061,0xe82a0009,0x802a0009,0xc19b0009}},	//   ussi_, הוָֽ, הוָ֥, לשטי
  { {0x6d59003e,0x7bc1007d,0xa3cb0011,0xdb080034}},	//   _zawa, colu, लतः_, rodó
  { {0x7dc50065,0x39820065,0x6f15009b,0x2e4800b3}},	//   póst, _póst_, razc, нято_
  { {0x40950003,0x7bde00b6,0x99810030,0xb8950012}},	//   _للبر, empu, vrhů_, _للبع
  { {0xf9940009,0xb81c0011,0x83350048,0x6d4d09e0}},	// [1eb0] _תרפ_, _निगम_, кнах, reaa
  { {0xb17b0058,0x61e90606,0x3df500f5,0xe9df0031}},	//   småd, _siel, _изос, lmú_
  { {0x61e90039,0x6d4d0fc1,0xfbd00012,0x7c2d0fc2}},	//   _piel, peaa, صتك_, suar
  { {0x4ac40003,0x3c43001e,0x628500d9,0x361a0009}},	//   ديمق, tīvā_, ryho, _קורד
  { {0x61e90fc3,0x6d5900b6,0x89340012,0x7c3b030d}},	//   _viel, _rawa, اعما, xtur
  { {0x61e9003e,0x4429000f,0xdce90027,0x77f8000b}},	//   _wiel, mra_, ljeć, עמוד_
  { {0xead40015,0x44290fc4,0xcf580009,0xcb120009}},	//   _борь, lra_, גבות_, _כלם_
  { {0x1c45002d,0x7c3b0fc5,0x7bc10002,0x8d65004d}},	//   вним, ttur, wolu, твие
  { {0xe432000a,0x44290fc6,0xfc160012,0xddc90031}},	//   لفيد, nra_, نقيب_, ínűb
  { {0x6d5902a0,0x44290fc7,0x7bc1008e,0xe7190012}},	//   _wawa, ira_, uolu, _آيات_
  { {0x36750003,0xa2a70037,0x6d59060b,0xfbd20009}},	//   _جهاز, _टेम्, _tawa, שתי_
  { {0xe4d90003,0x44290fc8,0xdb1e0fc9,0xf8a70012}},	//   _قوات_, kra_, ropé, لة_
  { {0x291200a1,0x9f9b0051,0x4429000e,0x442d0fca}},	//   _veya_, pääs_, jra_, que_
  { {0x44290fcb,0x7aa50003,0x7c290fcc,0x321a0034}},	//   dra_, _لإعل, mrer, yspy_
  { {0xd4f6003c,0x99860012,0x395b0fcd,0x7d0201e3}},	//   вязы, _للثو, _faqs_, ñoso
  { {0x3205002a,0xf86605fb,0xdd920012,0x89360012}},	//   mply_, _авио, جور_, _شعبا
  { {0xa91d001c,0xd7060098,0x2bf60015,0x5f060014}},	// [1ec0] _možd, _изпи, тябр, _изпа
  { {0xaf0a0003,0x6e2e00c1,0x78ad0066,0x7d16002c}},	//   _تقدم_, pubb, šová, says
  { {0x7c29008b,0xfeba0012,0xd24f0012,0xdee6004c}},	//   hrer, _زادت_, ينك_, _јони
  { {0x104a0024,0x9975003c,0xdd05004b,0x637e0030}},	//   дяки_, лучш, ăsăr, _záně
  { {0x81bd001e,0xa8ad0009,0x44290fce,0x7d090fcf}},	//   frēj, ּבוֹ, cra_, dbes
  { {0xe7180003,0x889b000b,0x7dd50010,0xc66a003c}},	//   ريبت_, ובני, _išsy, дшие_
  { {0x98b200a2,0x092a0003,0x7c290fd0,0x1e960048}},	//   ıyı_, _يسري_, erer, ърдр
  { {0xed87002d,0x6ce6002d,0xceb3000b,0x7d090fd1}},	//   вськ_, кіпе, ייו_, gbes
  { {0xdb1c0066,0xc0450012,0x32050132,0xc0e3076b}},	//   _zkrá, _مخلو, eply_, _вотк
  { {0xf4130093,0xe3af0012,0x98750060,0x32540430}},	//   ספת_, ْرَ_, lüğe_, гвор
  { {0xc3330093,0xc56a0003,0xd6250012,0x44290fd2}},	//   בות_, _يحصل_, _معني, zra_
  { {0x6f18009b,0x44290fd3,0x7c290fd4,0x316d0bce}},	//   lavc, yra_, brer, ñez_
  { {0x9c9a0012,0xf2060011,0x60d60034,0x7c29032f}},	//   _تنشط_, वीज़_, _czym, crer
  { {0x547b0093,0x44290fd5,0xe9df0029,0x9cd70009}},	//   _קטגו, vra_, smú_, _סוגה_
  { {0xdb060030,0xb8ca0011,0xcb8b0009,0x2bec05f3}},	//   ámýc, _गे_, _קְדֹ, _अंजू_
  { {0x865b0009,0xa91d0030,0x7bc704a7,0x7afd0030}},	//   ודלי, _kože, _skju, ěste
  { {0xdb1c0065,0xfbd90001,0xfaff001e,0xb4d5003c}},	// [1ed0] _skrá, едај_, žīms_, ужащ
  { {0xa91d077d,0x8f55007c,0xfecb0003,0x17550014}},	//   _može, _свої, _يبدو_, _своя
  { {0x4429000f,0x61ed000e,0x75220b28,0xc2c40012}},	//   sra_, _kial, _odoz, ليكي
  { {0x3264002d,0x629a000e,0x7d090070,0x29190fd6}},	//   штув, izto, xbes, nasa_
  { {0xc19c000b,0x90450003,0x63a80027,0x23b40011}},	//   ושאי, انته, kidn, ुवाद
  { {0x291900c6,0x752200b8,0x2d820fd7,0x89fb0012}},	//   hasa_, _adoz, öken_, _يعزز_
  { {0x6d5d01e5,0x3f810013,0x86980014,0x27ec002a}},	//   _kasa, _mohu_, ктът_, _didn_
  { {0x63a80fd8,0x7c290fd9,0xe4590e5f,0x99d40012}},	//   eidn, trer, ежи_, _نتقا
  { {0x60cd00b6,0x1be9003c,0x6d5d0fda,0x629a0035}},	//   _nyam, ндии_, _masa, ezto
  { {0x60d60002,0x2bd90037,0x7d090fdb,0x7c290fdc}},	//   _rzym, _बीमा, sbes, rrer
  { {0x6fcd0026,0x7d090c86,0x16380012,0x60d60034}},	//   júci, pbes, _لسنة_, _szym
  { {0x6fcd0029,0x2d940024,0x32050132,0x7c290fdd}},	//   dúci, _кріс, rply_, prer
  { {0x9b45000a,0xc952000b,0x7bc50051,0xb0de0011}},	//   _منشو, צמך_, kohu, नेंग
  { {0x9474000a,0x443f0039,0x656f0fde,0xa142001e}},	//   _خدما, mtu_, _anch, ēķin
  { {0x29190101,0x443f065a,0x629a0002,0x62880002}},	//   basa_, ltu_, czto, cydo
  { {0x61ed00c1,0xd5e606bd,0x5de60fdf,0x6da3004c}},	//   _gial, ужби, ужба, биса
  { {0x6d5d00c6,0x69c60010,0x4fb60012,0xfca90012}},	// [1ee0] _dasa, moke, _مصدر, ناكو_
  { {0x443f0fe0,0x28b70037,0x6fcd0fe1,0x656f0fe2}},	//   itu_, _आख़ि, búci, _ench
  { {0x443f0051,0x092a0015,0x201f0054,0x5757000b}},	//   htu_, ежей_, _avui_, _גביע_
  { {0x7d56002d,0x644b014f,0x8d56076b,0x05560fe3}},	//   _стої, _opgi, _сточ, _стоя
  { {0xdefa0047,0x657b0051,0xa0670001,0xa2ca0037}},	//   ный_, djuh, лаца_, _सुन्
  { {0x6d5d0fe4,0xa857000b,0xcb760001,0xdb1c0058}},	//   _zasa, טינה_, _сумњ, _skræ
  { {0x6d5d00a2,0xa01b004a,0x69c6004a,0x569400a6}},	//   _yasa, työk, koke, райт
  { {0x7df5039c,0x99420002,0x010a0012,0x8e470012}},	//   _sąsk, _cóż_, _سترو_, اليك_
  { {0x443f001e,0x41270014,0x94760012,0x35b90011}},	//   gtu_, _щото_, ادعا, आवज़
  { {0x40930003,0xb8930003,0xf2060014,0x291902a0}},	//   _الكر, _الكع, лямо, wasa_
  { {0xc333000b,0x73770009,0xf363003c,0xa1750024}},	//   זות_, אגיד_, стын, агні
  { {0x443f00b6,0x7df50034,0x2919016d,0xdb010018}},	//   btu_, _wąsk, uasa_, gilâ
  { {0x291900c6,0x629a0fe5,0x7d1d0028,0x6d5d0fe6}},	//   rasa_, szto, ðsse, _rasa
  { {0xd3700003,0x98a90002,0x22580058,0x6fcd0fe7}},	//   _ذهب_, żać_, ærks_, túci
  { {0xcddb0046,0x69c6079d,0x25a90fe8,0x12fb0009}},	//   ења_, boke, tial_, _אהוב
  { {0x5558002d,0x2d5804b3,0x56940232,0x3cb50048}},	//   лася_, лись_, щаст, айбр
  { {0xe3150001,0x9986000e,0xdb080018,0x39490fe9}},	// [1ef0] имањ, cslő_, vidê, _ibas_
  { {0x25a90fea,0xa01b004a,0x9cd7000b,0x39b10010}},	//   sial_, vyöh, רומה_, mąsi_
  { {0xd251000a,0x7ceb000e,0xaa55035c,0x3255034a}},	//   تنا_, _körü, рвеш, рвер
  { {0x3d0e0037,0x25fb0011,0x321e0034,0x7bc5005e}},	//   सरों_, _लंबी_, isty_, sohu
  { {0x9987000e,0x443f0107,0xb8fd0037,0xf3ff0017}},	//   énő_, xtu_, _डर_, _irão_
  { {0x8ae7002d,0x16390003,0xdb080017,0xd7020024}},	//   _бібл, نسبة_, sidê, озши
  { {0xed590047,0x66240003,0xd7380009,0xb3ba0009}},	//   вой_, مريك, אטות_, _ימשכ
  { {0xd6ce0003,0x7c2d00c1,0xd5b10003,0x3869000d}},	//   بقى_, orar, تفع_, _orar_
  { {0x9984000a,0x0c360003,0xed600030,0xf9920009}},	//   _القو, لكية_, ážit_, _ורן_
  { {0x657b0051,0x2d8d0feb,0x4a4503db,0x395f0fec}},	//   sjuh, skee_, анов, _haus_
  { {0x659500b3,0x7d0d006f,0xa2cb0011,0xeab10012}},	//   _кажу, kbas, _तुम्, تعة_
  { {0x9f490065,0x2fc70fed,0x88e60021,0x7c2d0fee}},	//   _stað_, long_, ижне, krar
  { {0xa2a70037,0x69c60fef,0x7d1b0ff0,0x2d820159}},	//   _टेस्, roke, maus, _roke_
  { {0x2fc70101,0x2329002d,0xdc9a000b,0xdb1a000e}},	//   nong_, _роки_, _בינל, potá
  { {0x442d000e,0x66e60ff1,0x9f4501a0,0xdee60ff2}},	//   lre_, рова, _milà_, рови
  { {0x7ceb00a1,0x2fc70101,0x7d0d002c,0x442d0ff3}},	//   _görü, hong_, gbas, ore_
  { {0x2fc70175,0xd6d90002,0x6d440ff4,0xdb080025}},	// [1f00] kong_, ęła_, rfia, fidè
  { {0x442d0108,0x8b26002d,0x4432001a,0xdb230028}},	//   ire_, рдже, ruy_, ærða
  { {0x2fc70101,0x442d008b,0x7d1b0cce,0x2d9e0061}},	//   dong_, hre_, kaus, ètes_
  { {0xdb1c006f,0x7d1b0d66,0x61460ff5,0x3ebb0009}},	//   _skrä, jaus, реда, _יציב
  { {0x442d0058,0xed570014,0x79b70009,0x7bdc0ff6}},	//   jre_, _тоя_, סלנד_, _thru
  { {0x2fc701e5,0x5f930001,0x44200190,0x7df50ff7}},	//   gong_, жишт, msi_, _sąsi
  { {0x257c0066,0xd5ba09ca,0x09e60024,0x8e370012}},	//   _síly_, кси_, _вовн, لسير_
  { {0x3006002d,0x7d1b0010,0x395f0010,0x2fc7002c}},	//   _взаг, gaus, _gaus_, aong_
  { {0x2fc70101,0x9f4c0066,0x44200ff8,0x90490012}},	//   bong_, _lidé_, nsi_, _مؤلف_
  { {0x883b0093,0x46a60098,0x23c60037,0xbea60024}},	//   _בתמו, _казв, वविद, _казк
  { {0xd257002d,0x442d0ff9,0x64400ffa,0xa2f70009}},	//   аця_, are_, stmi, ימיה_
  { {0x7d1b0036,0x44200ffb,0x04460014,0xc27b000b}},	//   caus, ksi_, _ведн, דרטי
  { {0xdcef0039,0xd0060003,0x9f840028,0x98b3001e}},	//   ādīt, ثل_, töð_, _ādīt_
  { {0x7c2d075e,0x395f09d4,0xe4510009,0x8c1b0009}},	//   vrar, žus_, _זֶה_, _יודי
  { {0x61410272,0x44200006,0xe5730012,0x22570012}},	//   náló, esi_, يطر_, _نجيب_
  { {0xf27b000b,0x527b000b,0xb1150048,0xb594003c}},	//   _ירוש, _ינוא, _умиш, оисш
  { {0x2fc701e5,0xe4e7007c,0xdce6007a,0x5ce7002d}},	// [1f10] yong_, рівн, _mokė, рюва
  { {0x47350001,0xea670001,0x09bf0037,0x0eb60011}},	//   _унос, ињен, एक्य, _अखंड
  { {0x1756000b,0x442d0ffc,0x44200ffd,0x59bb0011}},	//   _הסתר_, zre_, asi_, _उदार
  { {0xdb080054,0x442d0ffe,0xa91d0412,0x7bc8009e}},	//   sidè, yre_, _boža, hodu
  { {0x2fc70160,0x7d1b004a,0x4dda000b,0x44200f7a}},	//   tong_, vaus, _תחרו, csi_
  { {0x2fc7002c,0x442d0fff,0xdb010031,0x905800af}},	//   uong_, vre_, kilá, יבדו_
  { {0x2295000a,0x1ec90047,0xa6c90015,0xaa950003}},	//   _الأس, ылки_, ылка_, _الأث
  { {0xc6b8000b,0xdeb80009,0xa2a00011,0x05620048}},	//   יהוי_, יפוח_, _गेट्, звън
  { {0x291d0101,0x442d1000,0x31600017,0x2fc71001}},	//   mawa_, ure_, _raiz_, pong_
  { {0x291d002c,0x7d1b0052,0xb4f40011,0xb35f0024}},	//   lawa_, saus, _अल्प_, змiщ
  { {0x442d000f,0xdb06000e,0x7d1b1002,0xa91d0159}},	//   sre_, émák, paus, _zoža
  { {0x291d0101,0xcf89000b,0x6f1c0002,0x68ed022d}},	//   nawa_, _אט_, warc, žadu
  { {0x8d5a000b,0xa4d4002d,0xafe6002d,0xe8d50009}},	//   _תכני, _доці, йомл, מוֹר_
  { {0xa7da0003,0x5bc40012,0x6b9a01e0,0xe8190011}},	//   اوسط_, _وتوف, chtg, नीया_
  { {0xc7d6000b,0xc7af0012,0x644f0035,0x44200a94}},	//   מושי_, رّف_, _apci, wsi_
  { {0x442001a3,0xe5a31003,0x6dac0060,0x3d120011}},	//   tsi_, писи, aşan, ़रें_
  { {0x7b06000f,0x0326002d,0xdd8f0003,0x6141000e}},	// [1f20] _érté, йдан, روك_, záló
  { {0x44201004,0x74130012,0xc9100011,0xa3dd0011}},	//   rsi_, سوما, ार्म_, _थीम_
  { {0xdb07000f,0xa96a0001,0x44201005,0xe1f20012}},	//   ámár, лижа_, ssi_, سسا_
  { {0xf1a5007c,0x291d0101,0xa91d0107,0x6141000e}},	//   орін, gawa_, _poža, váló
  { {0x53c70044,0x25ad0029,0x629e0123,0x493b0009}},	//   रकाश, diel_, szpo, רגנו
  { {0xbb860003,0x9b960003,0x6d4b0052,0x98ad0034}},	//   _الآي, _الست, _abga, żeć_
  { {0x25ad00bd,0x3f851006,0x6444004a,0x8e470012}},	//   fiel_, _dolu_, ltii, ملوك_
  { {0x7bc8003e,0xe5c60001,0xdb011007,0x5bd00011}},	//   wodu, љско, vilá, हत्व
  { {0x764300b6,0x64440038,0x7c960012,0x53980148}},	//   atny, ntii, إشعا, ивия_
  { {0x388e0039,0x5c5b0009,0xa3d80011,0x61e60227}},	//   _vērā_, נדיק, ाति_, emkl
  { {0x64d50044,0x25ad0070,0x3f850028,0x6444004a}},	//   _दर्श, biel_, ölum_, htii
  { {0x64440176,0xb2bb0009,0xad650012,0x3d120011}},	//   ktii, רמטר, _وانه, ़रों_
  { {0xa3d80044,0x23e6002d,0x3f85003a,0x200b094e}},	//   ाता_, _лікв, _yolu_, upci_
  { {0xdbf10013,0x0a94002d,0x92940014,0x291d1008}},	//   _příl, _малю, _малц, zawa_
  { {0xa1430039,0xd6d90002,0x56941009,0xaba50012}},	//   šķir, ęło_, парт, _بإنه
  { {0x81bd0035,0x7df10035,0x6f1a100a,0x000000c4}},	//   grēt, _jāsp, _letc,
  { {0x49b80012,0x5fba0011,0x4dd40012,0x75e70031}},	// [1f30] _داود_, ेवाल, ستفس, _tűzv
  { {0x81bd001e,0xdb1a006f,0x7a050073,0x09f90012}},	//   arēt, botå, _lėte, لفئة_
  { {0x9f840051,0xa5f90001,0x92590015,0x72b90003}},	//   töö_, _њему_, рает_, جهاز_
  { {0xd7f10081,0xbae40012,0x40950012,0x6444005e}},	//   _sĩ_, سكني, يلار, btii
  { {0xc9740003,0x4acf0037,0x3f850404,0x291d100b}},	//   ثالث, _सुनव, _polu_, rawa_
  { {0xcc760009,0x501c0009,0x3f690faf,0x8e7500ae}},	//   _ועשה_, רוגו, рико_, قابض
  { {0x6234002d,0xfd110003,0x2902100c,0xfbd20009}},	//   _неру, وجة_, ycka_, _חתם_
  { {0x7dc5000e,0x91fc001e,0x84290024,0x6fd20040}},	//   lósz, rvāl, ажив_, ræci
  { {0x6d950028,0xa2b90037,0x25ad100d,0xf1b20009}},	//   _fáan, ्थव्, riel_, _חסן_
  { {0x4225062c,0xe3b10012,0xb17b0d1c,0x25ad100e}},	//   одов, ظرة_, smål, siel_
  { {0xc332000b,0xdcfb0082,0xf98a0003,0x25ad100f}},	//   ווי_, ljuč, لندي_, piel_
  { {0x41c90037,0x6d9c0025,0x6444008e,0xe3b80060}},	//   िकिस, _réag, ytii, anı_
  { {0xe45f0006,0x6d560132,0x61e61010,0x29020972}},	//   _myös_, veya, rmkl, rcka_
  { {0xaab90037,0xe3b30012,0xe73a004c,0x6d490e00}},	//   _आशंक, _عرش_, јев_, lfea
  { {0x59c90044,0xf772000b,0xceb20009,0x41c90011}},	//   िकार, וקם_, ֥ין_, िकास
  { {0x64440006,0x799d0052,0xa01b008e,0xf50a0a21}},	//   ttii, chsw, työt, рнал_
  { {0xd4670098,0x81bd001e,0x97c60012,0x47d60012}},	// [1f40] оите_, arēs, _وقبو, _ويعر
  { {0x2d990503,0x0326002d,0x644400ff,0xeab20012}},	//   _else_, іден, rtii, وعا_
  { {0xc3050003,0xa01b004a,0x64441011,0xe8fa1012}},	//   سبلو, syöt, stii, але_
  { {0xfd120003,0x94060012,0x11e90012,0xb2d30012}},	//   _تجد_, _ووجه, معني_, ذينغ
  { {0xe056000a,0xe3b8003a,0x7d041013,0x11d70012}},	//   تخاب, ynı_, mcis, آونة_
  { {0x7d04045a,0xf0930009,0x60290024,0x262a004c}},	//   lcis, ונד_, сіїв_, ацио_
  { {0x4432002a,0xdd9a1003,0x41ca0011,0xbf9b0025}},	//   lry_, иши_, रवास, mpêt
  { {0x44320b0b,0x69cb1014,0x38aa0034,0xe45f008e}},	//   ory_, coge, tórą_, _työt_
  { {0xdb01004a,0xdb1e0058,0x44321015,0x61fc1016}},	//   kilä, ropæ, nry_, _hurl
  { {0x0b8a0075,0xa3e70001,0x6fb60012,0x66760012}},	//   рсии_, одња_, _بمطا, _ودار
  { {0x9d4605cc,0x5b57000b,0x20091017,0x6b830028}},	//   _межд, חייב_, _stai_, öngi
  { {0x9633002d,0xa194002d,0x7c24017b,0x78a2001b}},	//   _ініц, даюч, ksir, ozov
  { {0xa2ca0037,0x9f4c0066,0xd5e90012,0xd1300012}},	//   _सुर्, _lidí_, _اعلن_, ضمّ_
  { {0xc058007c,0x09b70037,0x69cb0052,0xdceb0035}},	//   цію_, _अद्य, zoge, _ungā
  { {0x99d7000a,0x8d770003,0xc6680001,0x44320b0b}},	//   _وتعا, يارا, оште_, ery_
  { {0x7c2400b6,0x212900b6,0x62830052,0x44320504}},	//   fsir, _udah_, änom, fry_
  { {0xb9c40003,0xe571000b,0x7dda0054,0x8d5b0009}},	// [1f50] _تقيي, עַל_, aïso, סכמי
  { {0x67e0004a,0x63ba0052,0x78a20029,0xef1f0002}},	//   töje, nntn, dzov, ążka_
  { {0x7c24007a,0x44321018,0xd1310012,0x6b510097}},	//   asir, ary_, فما_, _aðgæ
  { {0x7dc5000f,0x44260416,0x39591019,0x4432101a}},	//   sósz, _ovo_, ness_, bry_
  { {0xf994000b,0xa2cb0037,0xdb1e005e,0x5d7a0009}},	//   ורף_, _तुर्, fopä, _הארק
  { {0x23fa000b,0xf838000b,0xfc160009,0x38640097}},	//   _להשא, קנות_, _מקשי_, æmri_
  { {0xa3d80037,0xa2ca0011,0xff180009,0x4426101b}},	//   ातर_, _सुल्, חקות_, _avo_
  { {0x79820002,0xc4850294,0x6de40012,0x386d00b0}},	//   cjow, злик, وثيق, _trer_
  { {0x93790003,0xe3b10003,0x29d9101c,0xfc310012}},	//   مصدر_, فرد_, réal_, رحة_
  { {0x79890070,0x29dc0164,0xeb99035c,0xcc760009}},	//   _hoew, nían_, сио_, פעתה_
  { {0x7d040002,0xc3320009,0x4426101d,0xe664003c}},	//   ycis, עוט_, _evo_, _отцо
  { {0x7d1d101e,0xc7a90009,0xc19a0024,0x499a0148}},	//   _ness, _גב_, стої_, стоя_
  { {0xb4fa000b,0x764b0010,0x34fa0009,0x515a0009}},	//   _הפני, žnyč, _ההנד, זכרו
  { {0xfaa50751,0xcb680012,0x6bd70012,0x6dac0060}},	//   _нало, _ومنه_, _بتصر, rşam
  { {0xa5960014,0x4b7a000b,0x29dc0164,0x7d1d101f}},	//   пращ, _לאסו, dían_, _bess
  { {0xb88306bc,0x91e30014,0x39591020,0x7c240b86}},	//   _klíč, _поще, cess_, tsir
  { {0xe319001a,0xed590029,0xeafa0003,0x113b0009}},	// [1f60] _điể, iež_, مرات_, _התפל
  { {0xa01b008e,0x33630024,0xdbf10030,0x44321021}},	//   pyör, нвуг, _přál, rry_
  { {0x4efb000b,0xafdb00c5,0xc332000b,0xe717000b}},	//   _להיו, ktøj, תוב_, _מחיר_
  { {0xfbc9000b,0x9f4c015b,0xe9d20012,0xc1ba0012}},	//   את_, _vidí_, رغا_, حائط_
  { {0x29dc0164,0x4424001a,0x31660031,0xed5909df}},	//   bían_, _ìm_, rdoz_, dež_
  { {0xc7a3057b,0xae000037,0x39590052,0xa2a70037}},	//   ничк, _लंदन_, zess_, _टेक्
  { {0x44260065,0xdb1e1022,0x539b000b,0xa3c10037}},	//   _svo_, ropä, _פילו, ्कन_
  { {0x2abb000b,0x5c980048,0x5c740a32,0xfe6f0012}},	//   _המלא, жкия_, длит, ادو_
  { {0xa5070001,0x65661023,0x6c470012,0xdb0801e3}},	//   чења_, _makh, كليف_, sidí
  { {0xe44f000a,0x389b000b,0x889b0009,0x7ac60adc}},	//   اضي_, _הימנ, _השמצ, зсме
  { {0x39590b5a,0xa9350024,0x3a3a005e,0xa9240064}},	//   tess_, менш, nupp_, ĺžni
  { {0x867b000b,0xd6eb000b,0xd2b7000b,0x02b7000b}},	//   _לרבו, _הַדָ, ללית_, להים_
  { {0x6ab90011,0xa91d00eb,0x6d42004b,0x39591024}},	//   _आश्र, _božj, _icoa, ress_
  { {0xdb1a000e,0x39591025,0xcb670024,0x6447004b}},	//   eltö, sess_, _наче_, ăjit
  { {0x7d1d0149,0x29dc0164,0xc7d70009,0xc3330009}},	//   _pess, vían_, פולי_, _טוס_
  { {0x98b9001e,0x7abb000b,0x61e4000d,0xcad70009}},	//   nesī_, _לצוו, _ghil, _מוות_
  { {0x6ecd0037,0x29dc01e3,0x69cf08ca,0xa3d00011}},	// [1f70] _दुरु, tían_, moce, वकप_
  { {0x889c000b,0xb89c000b,0x25a00b70,0x64a4004c}},	//   _לבחי, _לשחז, ahil_, хађа
  { {0x29dc0164,0xecf9002d,0xbb840003,0x2480004b}},	//   rían_, _менш_, علمي, axim_
  { {0x25a00070,0xc2c40012,0x69cf1026,0x29d20097}},	//   chil_, ريني, noce, láar_
  { {0xf2110011,0x67e01027,0x000000c4,0x000000c4}},	//   डीज़_, löja,   ,
  { {0xccf20009,0xf7730012,0xbc7a0009,0x2d8b001b}},	//   _שכך_, عاش_, _ונשת, _hoce_
  { {0x79890070,0x6b830028,0x99d70012,0x9e640012}},	//   _toew, öngu, _فترا, فاين
  { {0x96270039,0x6d4d00c6,0x6d9c0061,0x75d50003}},	//   _ieņē, nfaa, _réac, بيعا
  { {0x29000029,0x1c420015,0xa834004c,0x73e5019c}},	//   žiac_, вным, _петљ, моиз
  { {0x69d90052,0x57b40024,0xdc880009,0x9f530025}},	//   llwe, _збут, לְתָ, _fixé_
  { {0x6723048b,0x52db0037,0x9f340024,0x7e7e0248}},	//   manj, _भरोस, _чехі, äppt
  { {0xa5c60065,0x2d821028,0x67231029,0x24550012}},	//   rkóð, öket_, lanj, _يناس
  { {0xa5c60028,0xa3bf0011,0xfbbf0011,0x21a3003c}},	//   skóð, ुका_, ्वाम, тиям
  { {0x61e40036,0x98b20002,0x27ff004a,0x7c3b004a}},	//   _whil, żyć_, _muun_, muur
  { {0xd5b20003,0x7c3b005e,0x6449102a,0xba1900ae}},	//   نفس_, luur, ltei, _بيعا_
  { {0xf2d2000b,0x6449001e,0xdb1a0061,0x672304d2}},	//   _שעה_, otei, entè, hanj
  { {0x6723102b,0xbfc60014,0xb9b30003,0x66e7000e}},	// [1f80] kanj, _обик, _جميع, téké
  { {0x6723102c,0x61b80037,0xd9b80037,0x7ed60012}},	//   janj, ेक्ष, ेक्ट, _يزدا
  { {0x2367012e,0x6449083c,0x6723080a,0xb77b0009}},	//   _manj_, htei, danj, _ואיש
  { {0x3a3a0d64,0xe0da102d,0xdcfd0034,0x7c3b102e}},	//   rupp_, ове_, _posą, kuur
  { {0x260302d1,0xdb0e0065,0x9fca0015,0xdcb90015}},	//   _año_, þjón, огда_, _ещё_
  { {0x31bb0037,0x09bb0037,0x6d42000d,0x2367009b}},	//   _उद्ध, _उद्य, _scoa, _nanj_
  { {0x88bd0002,0xc34e0081,0x6449102f,0xda630337}},	//   _odśw, _bổng_, etei, _иври
  { {0xc34e0081,0x64490032,0x7a8b0009,0x661a0064}},	//   _cổng_, ftei, _וָמַ, átky
  { {0x3f980097,0x6e3c0060,0x8e200024,0xdb1a0031}},	//   kkru_, hurb, сiв_, lnté
  { {0x67230604,0xdb050060,0xef180035,0xdb1a1030}},	//   canj, rihç, _poļu_, onté
  { {0xd3370093,0xa294002d,0x3f9b0061,0x53370009}},	//   וריה_, хані, êque_, ונין_
  { {0x6e3c0028,0x64490032,0x6dac0060,0x49740198}},	//   durb, btei, ağaz, влюс
  { {0x14e20044,0x2d8b0013,0xdb1c0066,0xd7770003}},	//   _परिण, _roce_, _skrý, واسع
  { {0x61ee0029,0x9b440012,0x36d500db,0x6e3c0132}},	//   _ďale, _أنغو, еогр, furb
  { {0x5b570093,0x433b0009,0x8b3b0009,0xeb3b0009}},	//   _חיוב_, _ועוב, _ותוצ, _ועוש
  { {0x7bda0028,0x672300eb,0x69360030,0x3f8c0034}},	//   lltu, zanj, _přež, _lodu_
  { {0x2d8b034e,0xf1bf0485,0xdb1a057d,0x3f9e008e}},	// [1f90] _voce_, mná_, enté, _oltu_
  { {0x291f0054,0x4fc7002d,0xc7c7002d,0x7f5c0054}},	//   _seua_, _іспа, _іспи, cerq
  { {0x67231031,0x27f80064,0xc955003c,0x64490035}},	//   vanj, ženú_, етлы, ztei
  { {0x25190009,0xead80024,0xc1050012,0xf1bf1032}},	//   _מוֹא, ємці_, روتي, nná_
  { {0x67230416,0xd8b80003,0xe72e002d,0xb9920012}},	//   tanj, ودها_, ле_, طلوب
  { {0xf7710003,0x141a000b,0xa3dd0037,0x63b10066}},	//   طات_, _מושב, _थीं_, édně
  { {0xe919002d,0x53340001,0x67230082,0x291f01a0}},	//   _нові_, _јест, ranj, _teua_
  { {0x217b000a,0x6723080a,0x64491033,0xf1bf00d9}},	//   _بحسب_, sanj, ttei, jná_
  { {0x64490010,0xf1bf01a8,0x44291034,0x7de30031}},	//   utei, dná_, nsa_, _kősz
  { {0x2d820163,0x4374002d,0x44291035,0xdaa9035c}},	//   öker_, вуют, isa_, звод_
  { {0xc34e0020,0xfbd2000b,0x752f0002,0xd946048c}},	//   _tổng_, רתי_, _odcz, нени
  { {0x0efa015f,0xa96a0001,0x46580003,0x216a1036}},	//   ्ड्स_, чима_, _تؤكد_, чими_
  { {0xaacf0044,0x7524007a,0xb9080037,0x25bf000d}},	//   _सुरक, vaiz, _भर_, mnul_
  { {0xbb850003,0xb464002d,0x2d8f0422,0xe4360009}},	//   _سلبي, _шкіл, ögen_, _נרצח_
  { {0x66010006,0xdce2001e,0xf1bf01bd,0x7c2601bd}},	//   _julk, _bloķ, bná_, škrt
  { {0xdd920003,0xf1bf00d9,0xec160012,0xceb20009}},	//   دور_, cná_, فورد, איל_
  { {0x81bd001e,0x28060002,0xc5f2000b,0xdca30a76}},	// [1fa0] ksēj, ówną_, רדן_, гати
  { {0xa3c10037,0x7d090002,0x6d9c0061,0x672101a3}},	//   ्कि_, hces, _néan, _nelj
  { {0xdb1c0002,0x7d090002,0xe7e30011,0xa91d0159}},	//   _skró, kces, गतना_, _zoži
  { {0xb8660003,0xc329000b,0x6da6002d,0x7c291037}},	//   فاتو, מו_, _чима, kser
  { {0xa3c10037,0xfaf8001e,0x44290031,0x50650012}},	//   ्का_, ldīt_, csa_, َاهِ
  { {0xd7ef000a,0x67210159,0xf1bf1038,0x7c291039}},	//   مكن_, _celj, zná_, dser
  { {0xdb1c0002,0xd2cf0037,0xfbc30015,0x672102a1}},	//   _wkró, _सुलझ, _сбро, _delj
  { {0xceb30009,0xfaf80035,0x6601103a,0xa9670681}},	//   טיו_, idīt_, _dulk, _писа_
  { {0xb7da0003,0xf1bf022d,0x9f4a0054,0x6fb60012}},	//   _فورا_, vná_, ambé_, _كمرا
  { {0x8c530003,0x4274002d,0xdd00003a,0xa8570009}},	//   ائيا, вгос, ıtıl, _אימה_
  { {0xf1bf00f1,0x442902f7,0x9bb70009,0xdc030030}},	//   tná_, zsa_, תהיה_, včíh
  { {0xa91d103b,0x23a4006f,0x6721001b,0xd5b20012}},	//   _poži, _höjd_, _zelj, _حفص_
  { {0xc1730093,0x67e0006f,0x7c290ebc,0x4fc70048}},	//   אחר_, röjn, cser, есва
  { {0xe47b000b,0xf1bf0042,0x69c40035,0x53340511}},	//   _מרדכ, sná_, _ejie, _рект
  { {0x6be30003,0x68e4000e,0x36d50001,0xf1bf0042}},	//   _حكوم, _ezid, товр, pná_
  { {0xcdd80001,0xfa770009,0x4429103c,0xa91d0159}},	//   ењу_, _טעות_, tsa_, _toži
  { {0x41c40003,0x24580015,0x98b90010,0x4429103d}},	// [1fb0] _حقيق, нать_, mesį_, usa_
  { {0x61c90037,0x23a4006f,0x73d80198,0x4429103e}},	//   िक्ष, _nöjd_, едур_, rsa_
  { {0x4429103f,0xa2d40011,0x69dd005e,0x98be0034}},	//   ssa_, _बुद्, olse, ętą_
  { {0xd2b7000b,0x98b91040,0xc198002d,0xfaf8001e}},	//   עלאת_, nesį_, нтії_, ldīs_
  { {0x6601004a,0x0904002d,0x395d0132,0x3f6905c6}},	//   _sulk, упін, rews_, дило_
  { {0xec36000b,0x660109d4,0x5f770012,0xd7f8004c}},	//   _באשר_, _pulk, عاشر, нуј_
  { {0xbbbf0044,0x36660014,0x8fa20015,0x67211041}},	//   ्वीक, ващо_, раще, _velj
  { {0xf67c000b,0xdd8e0003,0x25bf004b,0x644d1042}},	//   לאומ, قوى_, unul_, otai
  { {0xdd8e000a,0x9f5303eb,0x67210fc4,0x25bf000d}},	//   توي_, _així_, _telj, rnul_
  { {0x7d0900c1,0xe2990001,0x75c80066,0x66011043}},	//   sces, дао_, věze, _tulk
  { {0x644d0006,0xb2f40015,0x7a080030,0x25fa0011}},	//   htai, ляющ, _pěta, _ऊंची_
  { {0x7afa0028,0xdb08004a,0x644d0213,0xe2960055}},	//   _útte, eidä, ktai, таю_
  { {0x0db80003,0xd00f0012,0x2ca9001b,0x8c451044}},	//   _ثالث_, يلَ_, jzad_, _реле
  { {0x69dd0005,0x2d8f0070,0x8c1a0009,0x52850012}},	//   alse, _hoge_, _חוסי, _للتك
  { {0x443f004a,0xfaf8001e,0xecc3001e,0xfe670012}},	//   luu_, udīt_, šķās_, جد_
  { {0xdb1a0002,0x3f850028,0x91fc0035,0xfce608d1}},	//   botó, ölur_, rvāt, вобо
  { {0x656b1045,0x443f1046,0x23bf0011,0xc5e90009}},	// [1fc0] _magh, nuu_, ्वंद, ַד_
  { {0xb17b0033,0x91fc001e,0x4e060406,0x61e90051}},	//   småt, mvār, _изоб, _ahel
  { {0x6a860098,0x179b000b,0xe2860014,0x6287004a}},	//   ължа, _חייב, ължи, äjoh
  { {0x656b0101,0x443f00e6,0x61e91047,0xceb30009}},	//   _nagh, kuu_, _chel, _כית_
  { {0xd0070098,0x70540003,0x91fc001e,0x9f340024}},	//   вече_, انتا, nvār, гелі
  { {0x8cc50037,0xdefa0015,0x4fd3002d,0x61e90032}},	//   ापनो, мый_, ажіт, _ehel
  { {0xdb010030,0xacbb0025,0x6d44005e,0x6eb70011}},	//   chlé, _jeûn, ogia, ोपयु
  { {0xc693000b,0x7ae3000e,0xb5aa0003,0x6d441048}},	//   שאה_, ünte, باتك_, ngia
  { {0x91fc001e,0x9f4c004a,0xe7320012,0x80e10011}},	//   jvār, _pidä_, _نصا_, _नरें
  { {0x96b6004c,0x000000c4,0x000000c4,0x000000c4}},	//   _исељ,   ,   ,
  { {0xc7d7000b,0xbb3b000b,0x32630014,0xdfcf0012}},	//   _יומי_, ועיי, атяв, _بيل_
  { {0xf2d3000b,0xc05b0024,0x9f4503a7,0xdd8f0012}},	//   יעת_, міг_, _milý_, _وول_
  { {0x1d070046,0x91fc0039,0x20840003,0x8c43046e}},	//   _речи_, gvār, للَّ, _вече
  { {0xc7c40015,0x64401049,0xf4570009,0x6d44104a}},	//   асси, mumi, _סיור_, egia
  { {0x75e5000f,0xa3c10037,0x7c3a001e,0xe7e30011}},	//   lóza, ्कर_, _ātra, गतता_
  { {0xa2b80044,0x6d4401a2,0xa3b50037,0x644d104b}},	//   ्पन्, ggia, _जगह_, ttai
  { {0x6d9c0108,0x5c75003c,0x39490018,0x6440104c}},	// [1fd0] _réal, ылат, _icas_, numi
  { {0x765a003e,0xe8d8000b,0x5b14002d,0xbbbf0037}},	//   _opty, _בוחר_, имут, ्वेक
  { {0x63af01a0,0x61e9104d,0x644d104e,0x6e95104f}},	//   ècni, _phel, stai, _сину
  { {0x200400b6,0x64401050,0x644d1051,0x81140012}},	//   _bumi_, kumi, ptai, لذها
  { {0x64400039,0x28f8002d,0x97d900fa,0x5d3a0009}},	//   jumi, вець_, ньку_, _אתרא
  { {0x289c000b,0xb6050107,0x889c000b,0x53a70037}},	//   וידא, hláš, ובדי, _गतिश
  { {0x656b01e5,0xc6a70014,0x45d50048,0x28da0011}},	//   _pagh, ърди, лцит, _युनि
  { {0x4efc0093,0x443f004a,0x96fc0009,0x5e560012}},	//   ולוג, tuu_, ולות, اليس_
  { {0x60db003a,0x64401052,0xe4320012,0x2bb90012}},	//   _uyum, gumi, مفيد, فادة_
  { {0x8c1a000b,0xca350009,0x75c80030,0xdd1c0030}},	//   עותי, ְנָה_, tězc, háňk
  { {0xb6070048,0x8ab60009,0xd7df0011,0xf7700012}},	//   _рязк, ָ֔יו_, _पीएच, _باق_
  { {0xa1360003,0x98b2003a,0xf7690009,0x443f0269}},	//   دردش, _sayı_, _מק_, puu_
  { {0xe8f70024,0x98b20060,0x7c2d0248,0x79ba0009}},	//   ллю_, _payı_, jsar, תֶיה
  { {0xdc3a0009,0xafdb00b0,0x7d1b1053,0xe46a0097}},	//   _נעצר, dtøs, lbus, sröð_
  { {0x442d0828,0xfe710012,0x46a30024,0xed5a03e1}},	//   lse_, يدِ_, барв, нов_
  { {0x442d1054,0x69c3014e,0xceb20009,0x09e60024}},	//   ose_, énel, צין_, _щойн
  { {0x5fc30037,0xb4250012,0x70770012,0xc4e6003c}},	// [1fe0] वचाल, لعلو, _مميز_, ужай
  { {0x2bba0003,0x442d1055,0x200403fe,0x8fca0012}},	//   راءة_, ise_, _rumi_, _سِجل_
  { {0x77f7000b,0xb17b0058,0x442d05ac,0x7d0d0132}},	//   _תמיד_, slåe, hse_, bcas
  { {0x442d03fb,0x6dac003a,0xafdb0033,0xcb09000b}},	//   kse_, aşar, støt, לל_
  { {0x25d70093,0x64e20037,0xdfda0014,0x69c20070}},	//   _תוכן_, _परेश, нък_, rnoe
  { {0x64401056,0xa8570009,0xb8070012,0x442d1057}},	//   vumi, ריסה_, ديوم_, dse_
  { {0xe2870003,0xaab80011,0x7c3b1058,0x65600031}},	//   _اذ_, _आधिक, erur, temh
  { {0x64401059,0xc0460012,0xca970009,0xdb1a0097}},	//   tumi, _مخطو, _גדלי_, rntí
  { {0xd32606e6,0xb9930003,0x5b260015,0x48e30014}},	//   льни, _القب, льна, _готв
  { {0x53340001,0x6440105a,0x3946105b,0xbb3a0009}},	//   јент, rumi, lgos_, ׂעִי
  { {0x442d09f5,0x66e60015,0x7c2d001e,0x45460003}},	//   ase_, _сожа, zsar, _مناق
  { {0x3946105c,0xd1260012,0x6440105d,0x7d1d0097}},	//   ngos_, غم_, pumi, ðsst
  { {0xc5f30093,0x6fb50003,0x7c3b000d,0x88bd0002}},	//   _הדף_, لمحا, crur, _leśn
  { {0x66050051,0xe4fb0009,0xf4130009,0x7d0d105e}},	//   _puhk, _נפגש, _הפס_, wcas
  { {0x539b000b,0xa2d40011,0xee84003c,0x7d0d0132}},	//   _איגו, _बुल्, быто, tcas
  { {0x7c87002d,0xc27b0009,0xf1270024,0x63ba105f}},	//   лузе, _טרוי, _сько, litn
  { {0xdfd10003,0x69c30061,0x442f000e,0x3869040f}},	// [1ff0] _ويب_, énem, ég_, _usar_
  { {0x212b04f3,0xe3b30012,0x17550048,0x8f550024}},	//   lach_, حرر_, _твоя, _твої
  { {0x7d02009b,0x442d059b,0x6ffa0009,0xd3d80012}},	//   _ogos, zse_, _שהתפ, ابقا_
  { {0x212b1060,0x442d1061,0xd567038f,0x71270012}},	//   nach_, yse_, _стоп, ارال
  { {0x39490039,0x63ba00b6,0xf8690012,0x18690c80}},	//   ļas_, kitn, ئمتي_, тали_
  { {0x442d0051,0xad9c0029,0xe7360014,0xb65900bb}},	//   vse_, _stĺp, аеш_, вших_
  { {0x7c22001a,0x244f003a,0x212b1062,0x16a60ec6}},	//   _awor, lüm_, kach_, ивши_
  { {0x212b0002,0x629a1063,0x442d1064,0x30150024}},	//   jach_, dyto, tse_, _вдар
  { {0x244f003a,0x212b0120,0x442d1065,0x656f0ec8}},	//   nüm_, dach_, use_, _mach
  { {0x92f5002d,0xeb990001,0xb8940003,0x442d1066}},	//   ичні, тио_, _الْع, rse_
  { {0x212b00f7,0xf0890009,0x9bb60009,0x93b60009}},	//   fach_, _קנ_, שהתה_, שלתו_
  { {0x645d1067,0x212b0002,0xa2b80037,0x656f1068}},	//   _opsi, gach_, ्पत्, _nach
  { {0xd83e0026,0xc5f2000b,0x76431069,0x15f40012}},	//   _účte_, _ודא_, luny, _اسلح
  { {0x629a0029,0xf746004c,0x9c820030,0x1eaa0012}},	//   byto, јево, účel, نازي_
  { {0xc7b20093,0x645d007a,0x39460010,0x7db602ac}},	//   קבל_, _apsi, ygos_, асац
  { {0x3d200037,0x4ad90037,0x212b0002,0x7bc50017}},	//   बरें_, _बुधव, cach_, enhu

  { {0x0446106a,0x6fdf0061,0x8b260015,0x03260760}},	// [2000] резн, pêch, идае, идан
  { {0x109b000b,0x764300b6,0xafdb0722,0x389b0009}},	//   _סביב, kuny, stør, _סיינ
  { {0x7f3b000b,0x32070054,0x34e20011,0x2f3b0009}},	//   _בעיו, _juny_, _पर्द, _בגיד
  { {0x3946007a,0xd2e60037,0x244f003a,0xd1300012}},	//   ugos_, _करीब_, büm_, سمت_
  { {0x629a0120,0x3946106b,0xadf80011,0x69c6106c}},	//   zyto, rgos_, ंगठन_, inke
  { {0x81bd0039,0x57b3002d,0x212b047f,0x656f106d}},	//   lsēt, обіт, zach_, _zach
  { {0xd719002d,0x7c22002a,0x7643016d,0x569409f8}},	//   уючі_, _swor, guny, сайт
  { {0xac540003,0xe5c60001,0x0d96000b,0xb0160003}},	//   منبث, јско, יכֶם_, _نورث
  { {0x88bd003e,0x9da70014,0x2fd8006f,0xf7460001}},	//   _jeśl, ръща_, korg_, _везо
  { {0x26de0013,0x61ed106e,0x212b0002,0x629a0010}},	//   _tyto_, _shal, wach_, tyto
  { {0xc3330093,0xa4e30044,0x212b003e,0x33770009}},	//   חות_, _खर्च_, tach_, בעים_
  { {0x7c22003e,0x3d200037,0x629a106f,0xbd490012}},	//   _twor, बरों_, ryto, _مؤهل_
  { {0x656f1070,0xe53b0009,0x99990031,0x212b1071}},	//   _rach, _יתאר, érő_, rach_
  { {0xd83f0382,0x644f03eb,0xfc5b000b,0x212b1072}},	//   _účet_, àcie, _סכומ, sach_
  { {0x212b0002,0x67280604,0x92580ef5,0xaffc0024}},	//   pach_, _medj, _сайт_, торi
  { {0xdce6001e,0x42fb0009,0xaada0011,0xf9900012}},	//   _sakā, _בהוס, _भड़क, _يبي_
  { {0x19b80003,0xdce6001e,0x25a91073,0x9bc90012}},	// [2010] _خطوة_, _pakā, rhal_, هورك_
  { {0x656f0369,0x244f003a,0xa3e60037,0x82370012}},	//   _wach, rüm_, पति_, لرصا
  { {0xed590013,0x6ff40003,0x7ff40012,0x8bd70009}},	//   liže_, _بسيط, _بسيا, סובו_
  { {0x998d0002,0x29dc01e3,0x7cd90012,0xc1720009}},	//   erdź_, días_, _موجز_, ּ֗א_
  { {0xa2d80037,0xa3e60011,0xe7390229,0x75c80030}},	//   _नुस्, पता_, гел_, tězn
  { {0x785a0039,0x764300b6,0x29dc0164,0x94f60009}},	//   dāvā, tuny, fías_, _לצרף_
  { {0xf7700003,0x61e2003a,0xed590015,0x29dc01e3}},	//   بان_, blol, гой_, gías_
  { {0x9f960028,0x76431074,0xca480012,0x0d850dc2}},	//   hæð_, runy, _خلفه_, слин
  { {0x69d90002,0x24520003,0x7643016d,0xa3db05f3}},	//   mowe, كنيس, suny, डकप_
  { {0x29dc0164,0x2cad0002,0x764300b6,0x69d91075}},	//   bías_, rzed_, puny, lowe
  { {0x29dc0164,0xe1fa004d,0x6b951076,0xc8690009}},	//   cías_, лго_, _mozg, _רן_
  { {0x69d90002,0x35f51077,0x4a5a0009,0x05740012}},	//   nowe, _упер, נדרו, _واند
  { {0x2fd80028,0x14190003,0xf1b20009,0xb8860064}},	//   torg_, _صيغة_, לסט_, _opíš
  { {0xf4120009,0x141a0009,0x999f0030,0x65640032}},	//   _צפו_, _עוצב, butů_, weih
  { {0x69d90002,0x644b0054,0xeb900003,0x6b8304eb}},	//   kowe, àgin, _تظن_, _inng
  { {0xdced0026,0xa2b80037,0x29000010,0x69d90002}},	//   adač, ्पस्, žiai_, jowe
  { {0x7984002c,0xf7460001,0x69d91078,0x16040011}},	// [2020] _iniw, _лепо, dowe, _शंकर_
  { {0x68e0006f,0x25b9005e,0x65641079,0x25a0107a}},	//   _rymd, _emsl_, seih, skil_
  { {0x4906000a,0xd7fb0009,0x2f970009,0x6564008e}},	//   مواق, _תהיל, _הכין_, peih
  { {0x5d860003,0x6146107b,0x443f107c,0x69d90a8f}},	//   _الحل, седа, kru_, gowe
  { {0xb033002d,0xdb03000e,0x783a0001,0x55f70009}},	//   зніш, _elné, уџет_, _למטב_
  { {0xccf90002,0xa857000b,0x33d5002d,0xe0850012}},	//   reśl_, מינה_, _діст, تجمي
  { {0x62650003,0x443f0da7,0xda650012,0x69d90b2c}},	//   _وافق, eru_, _وافي, bowe
  { {0x76a9002d,0x29dc0164,0x86070003,0x443f107d}},	//   штів_, rías_, حقيق_, fru_
  { {0xdb1a0108,0x6ab20037,0xfd0f0003,0x02b80037}},	//   lité, ुप्र, رجي_, _आधुन
  { {0xa3b40024,0x037a0012,0x5a34107e,0x29dc107f}},	//   ібні, احظت_, онот, pías_
  { {0x22580015,0x4df80037,0xe7170009,0x5f170009}},	//   шины_, ंगाई_, _החבר_, _החבא_
  { {0x394d03eb,0x44321080,0x2001005e,0x1d0a0451}},	//   ües_, ksy_, _sihi_, _седи_
  { {0x443f007d,0xac940014,0xcb340048,0x9f960097}},	//   cru_, _фалш, _делъ, tæð_
  { {0x33f60046,0x4fc70015,0x69d90034,0xbce50012}},	//   _учес, ссма, zowe, _بأمو
  { {0xfa330003,0x9f5e0061,0xd357000b,0x6b950002}},	//   _فريد, _cité_, _השוק_, _rozg
  { {0xb8860066,0xe6540024,0xdb1a0025,0x64401081}},	//   _spíš, явсь, dité, ormi
  { {0xe4500003,0xe4e70024,0xbbb90024,0xdd94003c}},	// [2030] فضل_, сівн, агає_, чаты
  { {0x6ac40044,0xa3b30037,0x69d90002,0x2cb80012}},	//   वपूर, जों_, wowe, حافظ_
  { {0x69d9003e,0xb8860026,0x97560009,0xa2b80011}},	//   towe, _vpíš, _ושתף_, ्पष्
  { {0x7bda004a,0xa15902e3,0xec150012,0xda7b0009}},	//   hotu, раду_, _ووجد, טנבר
  { {0x7bda0006,0x6845002d,0x69d908ce,0xf09f01a0}},	//   kotu, інка, rowe, nyà_
  { {0x8cdc0044,0x645c007d,0x69d90002,0xa2d40011}},	//   _पड़ो, ăril, sowe, _बुक्
  { {0x7bda1082,0x86980014,0xdb1a1083,0x753d0031}},	//   dotu, йтът_, cité, ószo
  { {0xa2b80044,0xd0d50014,0x443f1084,0xe6280003}},	//   ्पर्, _добъ, tru_, حثون_
  { {0x386d006d,0xc7c8001a,0x23650082,0x4c850024}},	//   _user_, uốc_, telj_, ілов
  { {0xdfdb0048,0x7e2b0024,0x6d490032,0xdb0e0097}},	//   _съб_, _біда_, sgea, _embæ
  { {0x6d5d0628,0x016601ec,0x64401085,0x32b90012}},	//   _obsa, окно, armi, شددة_
  { {0xdb01004a,0xc1060012,0xdb1a008e,0x7d020073}},	//   kilö, توحي, entä, žosi
  { {0xa3d90044,0x629e0002,0xa156000b,0x25bf004b}},	//   ावा_, zypo, חברה_, miul_
  { {0x6b830033,0x25bf000d,0x6d4f03a2,0x6d5d031d}},	//   _unng, liul_, _acca, _absa
  { {0xa50a010c,0x11d60012,0x1d0a0048,0x99d60012}},	//   иева_, _وتبد, иеви_, _وتبا
  { {0x25bf007d,0xdb1a0061,0x79840002,0x14260014}},	//   niul_, vité, _uniw, ждам
  { {0x29050066,0xf7720012,0xe73a0024,0x249f013d}},	// [2040] ělat_, _قاد_, _кеп_, nyum_
  { {0x1666002d,0x21220011,0x83870024,0xbfc3003c}},	//   _двом, मर्श_, обув_, _обык
  { {0x7a080030,0x75390034,0x3dc9020d,0xed5a1086}},	//   _pěti, _odwz, bnaw_, _кон_
  { {0xf3e90093,0xe9da096e,0x00e607d1,0x80a60012}},	//   דף_, шке_, ожен, يمان
  { {0x25bf000d,0x999c000e,0x7bc80028,0xdb1a1087}},	//   diul_, évő_, yndu, sité
  { {0x907b000b,0x2d991088,0x8bd80009,0x25ad005e}},	//   יטני, ösen_, _הַֽח, ehel_
  { {0x59ca0037,0xf8bf0025,0x5e440012,0x6d470073}},	//   ाचार, mbée_, أَعْ, ėjan
  { {0xdb070065,0x2dd70003,0x1d340014,0x25bf004b}},	//   ámör, يبية_, чния, giul_
  { {0xc5f30093,0x27170066,0xdb1a004a,0x6eda0037}},	//   ודה_, nění_, yntä, _पुरु
  { {0xa3ea0037,0x7c29003a,0x68ed0002,0xdfa60003}},	//   मति_, _çere, _rzad, _بحري
  { {0x86c6000a,0xcb13000b,0xcf93000b,0xd37b0009}},	//   _بيان, ולת_, _קטע_, בריט
  { {0x44260036,0x25bf000d,0xb6060027,0x29000010}},	//   _two_, ciul_, rišć, žiau_
  { {0xf1bf0029,0xa3ea0011,0xcf9b004c,0xa0c50012}},	//   riá_, मता_, ајв_, سيسو
  { {0x27170066,0xa6170012,0x33730024,0xc6a705c8}},	//   dění_, قبرص, _огір, орби
  { {0x3ea5000e,0xc5fb0003,0xb5c90012,0x387e0035}},	//   ált_, لعرض_, موسم_, ātra_
  { {0xdb010051,0xbdf4000b,0x42370009,0xa3b30011}},	//   gilõ, לֶּה_, _ונהל_, जोई_
  { {0xcd97000b,0x030e0037,0xc19c0009,0x5fbc0011}},	// [2050] קדמת_, _सलाह_, _כשהי, ्चाल
  { {0xd3710003,0x8c1b0009,0xda7b0048,0xdc8b0009}},	//   عها_, יומי, ияе_, יְבָ
  { {0xdb01004a,0x9ff80012,0x65a3005e,0x17f800ae}},	//   silö, _بريء_, _jõhk, _برية_
  { {0x6b980260,0x3f9a0097,0xe1f00012,0x661a0e69}},	//   _lovg, öpun_, نسن_, ítke
  { {0x9516000b,0xdcef0010,0xb97c0009,0x65a3005e}},	//   _מקרא_, _įdėk, ינאי, _lõhk
  { {0x6cfa0093,0x6d4d09de,0xb4fa0009,0xe4fa0009}},	//   _לפרס, lgaa, _לפרי, _לפרש
  { {0x67ed000e,0xdf360012,0x2d991089,0x69dd108a}},	//   gúja, سكيت_, _kose_, kose
  { {0x3228002d,0x39150024,0xf1bf0031,0x52140024}},	//   _фірм_, _хмар, _öá_, _ідут
  { {0x65a30005,0xcc350003,0x25bf000d,0x04560003}},	//   _põhj, أربع, riul_, كلية_
  { {0x5ba9108b,0x2d99108c,0x69dd108d,0xfb960009}},	//   ском_, _lose_, eose, ִ֣ית_
  { {0x0dcb002d,0x95cb00bb,0xa3b30011,0xe9da0a38}},	//   _куди_, _куда_, जोए_, йко_
  { {0x186a01d4,0x2d99108e,0x6456008e,0x9df9004c}},	//   бами_, _nose_, ytyi, _унет_
  { {0x69cb0b04,0xda0b0011,0x920b0011,0xd4c70012}},	//   inge, _सूरत_, _सूरज_, _بغاي
  { {0x8c1a000b,0xa4fa000b,0xbca40012,0x69cb0032}},	//   _הוסי, _פלסט, _تمهي, hnge
  { {0xcb120093,0xa3b80003,0x6d4d0070,0x644903b9}},	//   _אלו_, _بانر_, fgaa, luei
  { {0x27170013,0xf9920003,0x2d9900c1,0x6456004a}},	//   tění_, _سبب_, _cose_, ttyi
  { {0xddc1001e,0x1c4600b3,0x6ac40011,0x644901a0}},	// [2060] _aplū, янам, वप्र, nuei
  { {0x287b000b,0x69cb00ed,0x7bc1108f,0x395f1090}},	//   _פנימ, enge, nilu, _abus_
  { {0x4f9b000b,0xbf9b000b,0xa79b000b,0x9f9b000b}},	//   _הביצ, _הייש, _השיח, _הסיפ
  { {0xa158002d,0xa2d30012,0xb2d30012,0xfe370009}},	//   іалу_, رينت, رينغ, _צרכי_
  { {0xd12f0003,0x7d7b000b,0x3f9a001e,0x20051091}},	//   امه_, _הנכו, _kopu_, _bili_
  { {0x26110020,0xb6020066,0x64490054,0x44200ffd}},	//   _báo_, žáda, duei, mpi_
  { {0x2611008a,0x2005003a,0xdbc70269,0xe5c60048}},	//   _cáo_, _dili_, töös, зспо
  { {0xdceb001e,0x69c3000e,0x91e30024,0xad260012}},	//   _sagā, énet, _зосе, أرثو
  { {0xdce40010,0xdceb001e,0x7bc11092,0xc5130012}},	//   keič, _pagā, filu, ربيت
  { {0x0b8a0047,0xa08b0009,0xb8050012,0x76430034}},	//   ссии_, _לְבִ, _قبله, brny
  { {0xf773000b,0xde170012,0xd2570024,0x0ac60223}},	//   _רקע_, _فقلت_, пця_, ящим
  { {0x92570015,0x6d9c0164,0x64490054,0xc27b0009}},	//   чают_, _véas, buei, צרכי
  { {0x64490108,0x7bde004a,0x387f0028,0x2d9902d5}},	//   cuei, kopu, íur_, _rose_
  { {0x22590002,0x6f150002,0xf43b0009,0x6606008e}},	//   ńska_, uczc, _פגומ, _aikk
  { {0x6a130003,0x735b000b,0xe5ab0001,0x2d9902d5}},	//   _كبير, _הכוח, бњак_, _pose_
  { {0x91e40001,0x6606000e,0x9172001a,0x75240031}},	//   _поје, _cikk, rợ_, gbiz
  { {0x113c000b,0x53990015,0x6d4d1093,0x93270003}},	// [2070] _התחל, овая_, rgaa, كران
  { {0x2bbb0012,0x8c1b0009,0x7bde03fe,0xbb850012}},	//   حارة_, צובי, gopu, بلطي
  { {0xdb010052,0xcb080012,0x81c80035,0x44201094}},	//   chlä, أيمن_, _orēķ, api_
  { {0x64440051,0xc7c8001a,0xdb1e004a,0x69cb1095}},	//   brii, uốn_, enpä, unge
  { {0x200d00c1,0xe72e0024,0x320e0034,0x7ff50012}},	//   _quei_, ке_, _lufy_, وستا
  { {0xedf70011,0x7bde004b,0x6d470073,0xdceb004b}},	//   ुद्ध_, copu, ėjam, _lagă
  { {0xe9190024,0x7bc100b8,0xff180009,0xe7300012}},	//   _мові_, vilu, הקות_, اصه_
  { {0x64491096,0x31c40024,0x4c8502ab,0x2005020d}},	//   tuei, _зсув, длив, _wili_
  { {0x20050006,0xd6d90002,0x752f0002,0x2bb90003}},	//   _tili_, ęły_, _mecz, قادة_
  { {0xe2a20020,0x2bb90003,0x1bb90003,0x752f0002}},	//   _thử_, تابة_, تابع_, _lecz
  { {0xc332000b,0xd9461097,0xd6270012,0x753d0034}},	//   כוי_, мени, _رعاي, _odsz
  { {0x5dd8002d,0xc7a90009,0xf8a70012,0x44200073}},	//   _ефір_, _דב_, نة_, ypi_
  { {0x660601a3,0x644901d7,0x7bc11098,0x85040012}},	//   _rikk, quei, pilu, _كومن
  { {0x6606024c,0xeab10003,0xb4fa0009,0x34fa0009}},	//   _sikk, _لعب_, _ופני, _והנד
  { {0x7a080066,0x660601a3,0xe57a0024,0xb9c60012}},	//   _děts, _pikk, озв_, _يتعه
  { {0x69bf0037,0x85ea0024,0x6e930012,0x7aee0032}},	//   लोमी, ідав_, خلفا, übte
  { {0x5f760003,0xa5c60028,0x718b0009,0x61e41099}},	// [2080] _قادر, ljóð, _וְיַ, _ikil
  { {0x443901b3,0x4e1a0012,0x6444005e,0xafdb00b0}},	//   _dvs_, _وتجد_, rrii, ktøy
  { {0x9a6a0003,0x6444109a,0x799b0070,0x1d0a046d}},	//   تمال_, srii, _bouw, _мени_
  { {0x6444109b,0x4420109c,0xfbc90009,0x08c603b0}},	//   prii, ppi_, בת_, мбен
  { {0xd4360012,0x644f01a0,0x2f1801c6,0x7bde109d}},	//   _تعجب, àcil, поль_, popu
  { {0x7a0c007d,0xdb1a109e,0xe3a70012,0xf8b70009}},	//   _aşte, zitâ, _شر_, ופני_
  { {0x63a3109f,0xa3db0011,0x6b9c10a0,0xba5600ae}},	//   önne, डकर_, _iorg, _تنزع
  { {0x65a30005,0xbdf70003,0x5c740c1e,0xdd900012}},	//   _põhi, وريا_, елит, اوة_
  { {0x690b000b,0xe10b000b,0x69c010a1,0x236a004c}},	//   _וּבְ, _וּבָ, _imme, ојно_
  { {0x889b000b,0xb89b0009,0x409b0009,0x6b9c10a2}},	//   _ובמי, _ובמש, _ובמס, _jorg
  { {0x3ddf0070,0x316b0002,0x2b160011,0x6b9c10a3}},	//   bouw_, tecz_, दुएँ_, _morg
  { {0xc6930009,0xca370009,0xc2370009,0x31790031}},	//   _שאף_, ונטה_, ורטו_, udsz_
  { {0x8dfb0009,0x6b9c0227,0xdb1a0018,0xdb1c0031}},	//   _והאת, _oorg, ritâ, _emré
  { {0xead404b3,0x2cb0003a,0x65a3005e,0x5bc60012}},	//   _поль, ıldı_, _jõhv, _تتصف
  { {0xbd050061,0xa3cb0037,0xa3bd0011,0xef670009}},	//   _théâ, रचर_, ीचर_, וֹן֙_
  { {0xc5f80035,0x21e7005e,0xa0210097,0xa9c40557}},	//   _spēj_, põhi_, _þögg, _аськ
  { {0x94ab002d,0xd37b002d,0x24580015,0x6b9c10a4}},	// [2090] цтва_, жче_, мать_, _borg
  { {0x08f80003,0x21f20029,0x47d50012,0xf0920009}},	//   _غريب_, máha_, _سيجر, _עני_
  { {0xc2c40012,0xcff60009,0x656206dd,0xafdb00b0}},	//   نيكي, _רצתה_, _oboh, nrøm
  { {0xd1b80003,0x77b0006f,0x4efa0009,0x32640048}},	//   وانا_, _växe, _מהתו, ътув
  { {0xb06b0003,0xe0ce002d,0x6b9c10a5,0xa9680012}},	//   تصال_, ув_, _forg, ظمهم_
  { {0xdce400a2,0xf41f004a,0xf4560009,0xafdb00b0}},	//   ldiğ, _itä_, _אישר_, ttøy
  { {0x644d10a6,0x4ad90011,0xdcfd0073,0x9ea908d1}},	//   luai, _बँटव, _posė, явка_
  { {0xdce4003a,0x6b9c10a7,0xe1f00012,0xc6a40048}},	//   ndiğ, _zorg, _نسق_, ърчи
  { {0x37c50012,0x443910a8,0x3ddf0227,0x644d10a9}},	//   _كيرف, és_, rouw_, nuai
  { {0x61e410aa,0x56670012,0x57780012,0xf7730012}},	//   _skil, _يداف, _يصلح_, _جار_
  { {0x25a9000f,0x2d8b10ab,0x98a4000d,0x5e450012}},	//   kkal_, _once_, _temă_, _أَصْ
  { {0x5d840003,0x22590034,0x65a3005e,0xa91d0073}},	//   _للمل, ńsko_, _kõhu, _požy
  { {0x54a70012,0x2904054e,0x0c240024,0x7bf9004c}},	//   _تحاف, äma_, _амін, _ендр_
  { {0xdb1a10ac,0x644d10ad,0x649a0009,0xd7f20012}},	//   cità, duai, _מינה, اكس_
  { {0xa6a90003,0xfe670003,0x645b10ae,0x7a090030}},	//   وافق_, دد_, ltui, _větr
  { {0xdb1a10af,0x65aa01bd,0x2aba0009,0xb2ba0009}},	//   pitã, _výho, _ממצא, _ממצר
  { {0xd467031e,0xf3900081,0x04430c80,0xb9060024}},	// [20a0] ните_, _mảnh_, летн, _язик
  { {0xda660003,0x6abd0037,0x32d600ac,0x69c610b0}},	//   فاصي, ्पूर, нцес, like
  { {0x6b9c008b,0x69c6004a,0xdb1a10b1,0x0f570009}},	//   _vorg, oike, nitá, _איים_
  { {0x2d9d003e,0x69c610b2,0x317b0009,0xed5f068c}},	//   _nowe_, nike, ּ֨אמ, ížte_
  { {0x69c6004a,0xf5370009,0xd7e60024,0x645b0227}},	//   iike, _אנכי_, ніко, jtui
  { {0x69c60051,0x7c240f67,0x7bcf10b3,0x61eb10b4}},	//   hike, mpir, écul, algl
  { {0x61fd0065,0xda0b0037,0x61460001,0x412a0294}},	//   ymsl, _संगत_, _пева, _ново_
  { {0xc6930093,0xf3900020,0x22470026,0xd5b70800}},	//   ראה_, _cảnh_, ánke_, есь_
  { {0xdce6001e,0xd5770009,0xb88600d9,0x645b0227}},	//   _nokļ, תתפה_, _blíž, gtui
  { {0x765c0002,0x61e20051,0x10090012,0x883b0009}},	//   ktry, lool, _قتلى_, _מתמו
  { {0xf8bf014d,0x6fb3000a,0x62830027,0x0bb7000b}},	//   _þér_, _حملا, _crno, גלים_
  { {0x765c0572,0x248004d7,0xc2370009,0x67350034}},	//   dtry, kvim_, ערכו_, wazj
  { {0xc86405fb,0xc0ab0012,0xf1c00011,0x644d0018}},	//   лтри, ساحل_, शोधन, xuai
  { {0x32940003,0x7c24009b,0x36d50594,0x22940012}},	//   _للتأ, dpir, вогр, _للتس
  { {0x61e20005,0xc987002d,0xf41f004a,0xdb1a10b5}},	//   kool, _зупи, _stä_, citá
  { {0x69c610b6,0x644d10b7,0x2a570009,0xf0a60081}},	//   cike, tuai, _נבחן_, _đành_
  { {0xdce400a2,0xd1640014,0x59640014,0x26110037}},	// [20b0] rdiğ, _същи, _съща, _दूरी_
  { {0x65a30051,0x3f9e003a,0x657b10b8,0xa91d10b9}},	//   _rõhu, _notu_, zduh, _inži
  { {0xc333000b,0x325500be,0x644d10ba,0x8c440060}},	//   רוע_, твер, suai, ışar
  { {0xaadb0009,0x65a3005e,0x000000c4,0x000000c4}},	//   החבר, _põhu,   ,
  { {0xed600066,0xb9540012,0xef0e026d,0x644d07b5}},	//   ížet_, ائمت, им_, quai
  { {0xf7710003,0xa08c000b,0x98a20aa8,0x10a2004c}},	//   شات_, לְוִ, рише, ришн
  { {0x68e90034,0x3f9e0035,0xb1aa0097,0x03d60009}},	//   _wyed, _dotu_, þýðu, _יושם_
  { {0x65a30051,0xfc3f014a,0xd6ce0003,0x645b10bb}},	//   _tõhu, ším_, تقى_, ttui
  { {0x75c80066,0x672c0031,0x645b008e,0xa5f6004c}},	//   vězt, éljü, utui, њењу_
  { {0x645b0ca5,0xdb1a0031,0x43740024,0xb4fc0009}},	//   rtui, titá, гуют, הפחי
  { {0x2fc709e5,0xcb12000b,0x3869000d,0xe6950012}},	//   ming_, ילי_, _apar_, _جلاد
  { {0xcec40030,0x2fc710bc,0x765c10bd,0xdb1a10be}},	//   hoří_, ling_, vtry, ritá
  { {0x98a40010,0xe6040012,0x2fc70bb5,0xa93a0009}},	//   _temą_, _إِنَ, oing_, ותרפ
  { {0xf7720003,0x69c610bf,0x645c004b,0xdb1a10c0}},	//   جاح_, sike, ărit, pitá
  { {0x644910c1,0xd00700bb,0xdee60d7c,0xed5a10c2}},	//   lrei, тере_, тови, мов_
  { {0xceb20093,0x661c000f,0xb6020028,0x7d1b10c3}},	//   ביל_, _érke, _þátt, ncus
  { {0xe8fa0014,0x69c40002,0x973c0027,0xff2600de}},	// [20c0] _юли_, _imie, _hoće, _импо
  { {0xf837000b,0x4b23002d,0x236a0012,0xa8370009}},	//   _שנית_, имув, بحري_, _שריד_
  { {0x6449008b,0xf1c60037,0x2d9e0061,0x3bd50015}},	//   hrei, _लगान, êtes_, уютс
  { {0x644910c4,0xba9a0009,0xe2450012,0xd9180012}},	//   krei, וסעי, اخلي, ريتش_
  { {0x61e20005,0xdfda0014,0xc9530009,0xe0d20012}},	//   rool, мък_, שמד_, جزا_
  { {0xb17b0163,0x66f60037,0x2fc710c5,0x6e8a004c}},	//   llåt, _इराक_, ging_, дљив_
  { {0x61e20005,0x16370003,0x8fa30001,0xc7b3000b}},	//   pool, نسية_, раје, שבו_
  { {0xfa77000b,0x55740014,0xadf80037,0x644910c6}},	//   _בעלת_, угит, ंगटन_, frei
  { {0x7aea006f,0x7c3b002c,0x644910c7,0xc7c8001a}},	//   _syft, gsur, grei, hối_
  { {0x2fc710c8,0x75c80030,0xafdb0040,0xef83004c}},	//   cing_, tězs, msøg, _клуп
  { {0x7c3b0bad,0xcfb70009,0xafdb0040,0x75290031}},	//   asur, _שלבי_, lsøg, bbez
  { {0xf1a70fdf,0x200c020d,0x644910c9,0x8c1a0012}},	//   трон, _hidi_, brei, _قيصر_
  { {0xc173000b,0xe1ff0164,0xafdb0058,0xbb860012}},	//   בחר_, rmó_, nsøg, _للإي
  { {0x9f5303eb,0x2618001a,0x5c370009,0x5334034d}},	//   _això_, _kéo_, _ירדן_, _сект
  { {0xf8bf0149,0x9f34002d,0xda7a0014,0xcec40066}},	//   mbém_, ресі, _цял_, voří_
  { {0x7c2204b4,0x200c0066,0x798d10ca,0xb9550048}},	//   _ktor, _lidi_, _unaw, _свищ
  { {0x2fc70036,0x6abd0037,0x69c30061,0x85140024}},	// [20d0] ying_, ्प्र, ènem, рмує
  { {0x02a7007c,0x69c404f4,0x98be000d,0xdb07000e}},	//   крем, _zmie, ştă_, _aljá
  { {0x9f5e0006,0xafdb0058,0xd25b0015,0x2fc710cb}},	//   _mitä_, esøg, ьца_, ving_
  { {0x7bc800c6,0xdd950047,0xdb1a10cc,0xe919002d}},	//   hidu, _самы, litä, ході_
  { {0x3944002d,0xafdb0058,0x91bc0009,0x2fc710cd}},	//   рніг, gsøg, ומאי, ting_
  { {0xdb07000f,0xdb1a0052,0x3fe40024,0x68380030}},	//   _eljá, nitä, ажів, _súdá
  { {0xe1db0012,0x37080012,0x6e950012,0xc2c50012}},	//   _قبرص_, نْهُ_, العا, _إيزي
  { {0xf2d2000b,0x7c3b10ce,0xdd8e0012,0xafdb0040}},	//   _העל_, tsur, كوى_, bsøg
  { {0xdb010030,0x91fd0035,0x200c00b8,0x6738001b}},	//   dklá, itād, _fidi_, bavj
  { {0xdb010570,0xa3d90011,0x7c3b10cf,0x7529016a}},	//   eklá, ावट_, rsur, sbez
  { {0xdb1a10d0,0x35550012,0x02c50024,0x68f60034}},	//   entó, _مناز, уйно, _szyd
  { {0x24860274,0x64460010,0x645c000d,0xe5730012}},	//   _from_, škia, ărir, _خطط_
  { {0x35c60037,0xf5390029,0xdb08008e,0x7bc801e3}},	//   रोफ़, mať_, ehdä, bidu
  { {0xf5390029,0x8e7610d1,0x7bc810d2,0x000000c4}},	//   lať_, лубч, cidu,
  { {0xc7c80081,0xf9920012,0x7bda0009,0xdb1a08f4}},	//   uối_, _هبة_, _אקסו, antó
  { {0xceb2000b,0xf5390029,0x69c410d3,0x25ad10d4}},	//   זיל_, nať_, _umie, nkel_
  { {0xb17b0248,0x657d0db9,0x808a00ae,0xcce500ae}},	// [20e0] rlåt, _dash, _أضعف_, لسكي
  { {0xb17b00b0,0x9f5e004a,0x550301d4,0x28970009}},	//   slåt, ötä_, спуб, _עדין_
  { {0xf5390029,0xdb1a003a,0x2ca9002c,0x25ad10d5}},	//   kať_, sitç, ayad_, kkel_
  { {0xe9e5002d,0xf5390029,0x22460029,0x83fd000e}},	//   аціо, jať_, čok_, ltőd
  { {0xf5390026,0xe8940094,0x200c0051,0x07a610d6}},	//   dať_, раль, _pidi_, ладн
  { {0x2d8f0163,0xafdb00c5,0xdb010030,0x7bc810d7}},	//   _ange_, rsøg, zklá, xidu
  { {0x1a78000b,0x6738009b,0x200c00eb,0x72780009}},	//   _בְּמ, ravj, _vidi_, _בְּצ
  { {0x442a0046,0x6d560101,0x9f5e0006,0x7bc80002}},	//   нцом_, ngya, _sitä_, widu
  { {0xa84a0003,0x6d56002c,0x61e610d8,0xa4d40024}},	//   _سلام_, igya, dokl, ропі
  { {0x99860010,0x21f20030,0xdb1a0032,0x7bc8005e}},	//   kslų_, sáhl_, xitä, uidu
  { {0x7bc80005,0xdb1a03d7,0x7c220034,0xf5390064}},	//   ridu, vitä, _wtor, bať_
  { {0x2eb00044,0xd9f60037,0xf5390064,0x25ad10d9}},	//   जनीत, ेषित_, cať_, ckel_
  { {0xab940024,0xcdf70009,0xdb1a02b9,0x7bc810da}},	//   _вилі, _עמדי_, titä, pidu
  { {0x14d7000b,0x2a660002,0xcc570009,0x2d8010db}},	//   _גודל_, łoby_, _עסוק_, edie_
  { {0x9f8b0051,0xe2460012,0x16350048,0x83370009}},	//   _töös_, _إختي, ребя, _גאוס_
  { {0xca470003,0xfe370009,0xa968004c,0x4a5b0009}},	//   _إليه_, טרלי_, _бића_, _נדחו
  { {0xdb1a074a,0x24180024,0x33870048,0xe58b0009}},	// [20f0] pitä, гією_, лужв, עָלָ
  { {0x61e9039c,0x91fd0039,0x6ee7000a,0xf5390026}},	//   _skel, stād, _مسجل, zať_
  { {0x92590015,0x20f4001a,0x7bdb0009,0xfbd00012}},	//   тает_, _ài_, עקבו, ستك_
  { {0xd257000b,0xe9ce002d,0x5e880012,0x62080012}},	//   רשאה_, ік_, _إنَّ_, هْلِ_
  { {0xf53904b4,0xd5b10020,0x3d3a000b,0xdd3a0009}},	//   vať_, _lúc_, _בגרס, _בערכ
  { {0x2259003e,0xdd1c0010,0x10380009,0xf8380009}},	//   ński_, _iššo, נטום_, ננות_
  { {0xfd110003,0x25ad0051,0xf5390029,0xf7700012}},	//   يجة_, tkel_, tať_, ثان_
  { {0xada50015,0x644d0f27,0x067c0009,0x61e90073}},	//   раил, orai, תנהל, _ukel
  { {0x442900c6,0x98480098,0xf5390029,0x644610dc}},	//   npa_, _бяха_, rať_, škin
  { {0x7ff7000a,0xf5390029,0xec680003,0x81bd001e}},	//   _إسرا, sať_, اصيو_, spēl
  { {0x8b88000b,0xaa490014,0x22490014,0x25b0000e}},	//   אָרֶ, ъпна_, ъпни_, álló_
  { {0x69cb008b,0x61e60010,0x6aba003a,0xdb0105b1}},	//   nige, uokl, _ütfe, chlý
  { {0x61e60066,0x81bd001e,0x8fe60012,0x644d0031}},	//   rokl, opēj, لأسم, jrai
  { {0xd0f6000b,0xdfd20003,0x69cb0052,0x7c2910dd}},	//   שמשת_, زيز_, hige, mper
  { {0xa91d00f1,0x6da60015,0xe73703e1,0x5f060048}},	//   _každ, аива, рес_, рзва
  { {0xceb2000b,0x32da000b,0x63a308c5,0x9f43008e}},	//   קין_, _שחקנ, _honn, eljä_
  { {0xb425000a,0x63a3008b,0xa91d0010,0xec7a0014}},	// [2100] معلو, _konn, _mažd, ъпа_
  { {0xeab20003,0x7c2910de,0xaec60024,0x60fb0009}},	//   يعا_, iper, _вбол, _בהפק
  { {0x69cb0052,0xd5b10081,0x6d460031,0xdb010040}},	//   fige, ếc_, ókak, sklæ
  { {0x673c009b,0x69cb0052,0x291200b0,0x629a01a0}},	//   larj, gige, øya_, _àtom
  { {0xdcee0039,0x443f0002,0x660401a3,0x20890009}},	//   ādīj, jsu_, mmik, ָתוֹ_
  { {0x98a40013,0x7c29000e,0x673c009b,0xc66a0015}},	//   _země_, dper, narj, вшие_
  { {0x29560014,0x69cb0052,0x91fd001e,0x66730003}},	//   _възр, bige, ntāc, قدير
  { {0xd378001c,0xef18001e,0x18a6002d,0x443f00b6}},	//   moći_, _daļa_, _кабм, fsu_
  { {0x26160044,0xb0c50037,0x63a303b1,0x6da30012}},	//   _पूरी_, _लेंग, _bonn, تميم
  { {0x6be30003,0x0ba60024,0x63a310df,0xeb060ba0}},	//   يكيم, ршим, _conn, ично
  { {0x63a30edb,0xdb010052,0x673c009b,0x6d460107}},	//   _donn, chlü, darj, _odka
  { {0x7c260027,0xd6cf0003,0x31c70aa2,0x32180034}},	//   _otkr, _تقم_, рсов, _mury_
  { {0xf7730003,0x84630014,0x55bb0009,0xc5f30009}},	//   ياس_, _дъще, _במאו, _ודף_
  { {0x442601e5,0x644d0061,0x660401b7,0xd1030011}},	//   _ito_, vrai, emik, रेषण_
  { {0xc3fb000b,0x639b000b,0x7c260071,0x644010e0}},	//   _שלוש, _בסגנ, _atkr, lsmi
  { {0x79820002,0x44260fae,0xa91d017b,0xf5310009}},	//   jdow, _kto_, _kaže, ּ֥ן_
  { {0x61ed002c,0xdb1e004a,0x752d10e1,0x69fc0009}},	// [2110] _ikal, kipä, rbaz, _בלהק
  { {0xa91d0010,0xdb0e000e,0x69d80061,0xfa870001}},	//   _maže, _elbí, éven, ићем
  { {0x69cb00d6,0xd1310012,0x39150012,0x386d10e2}},	//   tige, كما_, مواز, _sper_
  { {0xf5950003,0x442610e3,0x64400a4a,0x8d950012}},	//   _الحج, _oto_, ksmi, _الحش
  { {0xfd96000b,0xbcfb0061,0xe6cb0028,0xf8690012}},	//   _הדרך_, _obéi, _íbúð, امتي_
  { {0x6d58003a,0xdb1e0051,0x18780009,0x79820034}},	//   ıbaş, gipä, יעדר_, adow
  { {0x98ab0002,0x644210e4,0x3f8110e5,0x86980048}},	//   racę_, _avoi, _mahu_, итът_
  { {0x81bd0333,0xc1c60037,0x63a310e6,0x443f078a}},	//   spēj, _लगेग, _sonn, tsu_
  { {0xb4f50037,0xdb1e0051,0x63a3004a,0x60d5000b}},	//   _आरोप_, bipä, _ponn, _הוּא_
  { {0x5f440003,0x443f10e7,0x6395003c,0x63ba0a0c}},	//   _ونقل, rsu_, сшиф, ghtn
  { {0x443f0065,0x673c009b,0xf7700003,0x2fe40012}},	//   ssu_, varj, _زال_, _بكلف
  { {0x261c0164,0xc7a9000b,0x59990009,0x443f10e8}},	//   _río_, _אב_, אשֹׁ, psu_
  { {0x628a008b,0x95c40003,0x3e61000e,0x973c0027}},	//   _erfo, _بينه, lót_, _moćn
  { {0x79820002,0x232606bd,0x261c01e3,0x63ba0529}},	//   zdow, _лоши_, _pío_, chtn
  { {0xdfcf000a,0x539a000b,0xa91d0b68,0x4b360009}},	//   ريف_, _תיצו, _zaže, _הרצל_
  { {0xdb010422,0xfd950024,0x09e30048,0x91e30048}},	//   rklä, ошую, _нощн, _ноще
  { {0x660410e9,0xe3160003,0xc9b7000b,0xd5af0003}},	// [2120] rmik, مباب, _להקת_, رفك_
  { {0x69c90051,0xa3ca0037,0xdd3c0002,0xb09b0009}},	//   _amee, रोप_, lążk, _עייר
  { {0x8e8610ea,0x9f4c001a,0x0a4a0021,0xdddc0027}},	//   _الجه, _đoàn_, узей_, avrš
  { {0xe93a0003,0xe9da0015,0x7982010f,0x6d460040}},	//   اسات_, ыке_, udow, _udka
  { {0x7982003e,0x60000248,0x67ed0031,0x0f140024}},	//   rdow, römf, yújt, омлю
  { {0xc059007c,0xdefa0015,0xd0f7000b,0xa6660012}},	//   рії_, лый_, זמנת_, مطبو
  { {0xa91d0027,0xf773000b,0x79820052,0xf8bf000e}},	//   _saže, פקה_, pdow, zzé_
  { {0xa91d0010,0xfad7000b,0xdb1e00ff,0xc6930009}},	//   _paže, _הולך_, sipä, לאו_
  { {0x2d820036,0xe0da0001,0x5bb8004d,0xd7f20012}},	//   _make_, _сва_, илия_, _فكر_
  { {0x547b000b,0x4f660003,0xd4e30015,0xa91d0027}},	//   נטיו, _دارف, яющи, _važe
  { {0xc333000b,0xc7b3000b,0xe2f8002d,0x9f8d0066}},	//   הות_, _צבע_, рені_, uží_
  { {0xdb1c0028,0x6456002c,0x9d1a0012,0xc2b70024}},	//   _umræ, kuyi, _إزاء_, слює_
  { {0xafdb03ee,0x673a004a,0x5c060472,0x98a20034}},	//   drør, _ketj, _ляка, ybką_
  { {0x7bcf0061,0x9cd70009,0xf8bf0031,0x439410eb}},	//   écut, _פוגה_, rzé_, _факс
  { {0x25a600ca,0x2bf70009,0x5bc50012,0x15f70012}},	//   _kool_, _המגן_, _بتنف, مسرح
  { {0xd2570009,0xf9930012,0xe4e70024,0x58d50048}},	//   _השהה_, _ربع_, бізн, _мойт
  { {0x3f8100c6,0x3e61000f,0x21f90042,0xf9900012}},	// [2130] _tahu_, zót_, lého_, _أبى_
  { {0x3cfb000b,0x8c1b0009,0xd3710012,0x261a0011}},	//   רלמנ, טומי, ظها_, _मूवी_
  { {0xdb030054,0x21f90107,0x02d90003,0x62750012}},	//   _conè, ného_, جواب_, تهائ
  { {0xd3780027,0x9f4c001a,0x92b40003,0xeab1000b}},	//   moću_, _đoán_, أحكا, וֹד_
  { {0x8fa50063,0x3dcd10ec,0x21f900d9,0xe7390681}},	//   жале, view_, hého_, аел_
  { {0xa858000b,0x21f9014a,0x3e61000e,0x7e8b0009}},	//   מידה_, kého_, tót_, ָאֵ֖
  { {0x56920046,0x99890002,0x39490b45,0x8e550024}},	//   дајт, _miał_, _odas_, іткі
  { {0x3e610053,0x0c250086,0x8c490024,0x75d50012}},	//   rót_, омин, апив_, تيعا
  { {0x61eb10ed,0x28f80024,0x6f000031,0xe3b90b4e}},	//   mogl, _геть_, _kábí, иби_
  { {0xfbc5002d,0x2d84005e,0x394910ee,0x4a4506eb}},	//   ібно, adme_, _adas_, онов
  { {0xdb1a0006,0xe9da0a25,0x69d90002,0x569410ef}},	//   yntö, ико_, onwe, _нафт
  { {0x3e45001e,0x7c2d10f0,0x6c850012,0x7a13004b}},	//   mēt_, kpar, _ولضم, _bătr
  { {0x7a13007d,0x3e450039,0x15180012,0xdca506bd}},	//   _cătr, lēt_, _ازمة_, _фали
  { {0xd5b10020,0x4407022a,0x2d8210f1,0x99890034}},	//   ến_, _учеб, _sake_, _ciał_
  { {0x3e45001e,0xb9c60003,0x2489003a,0x2d8200b6}},	//   nēt_, _وقتي, evam_, _pake_
  { {0x28c50044,0x6b8310f2,0x60000248,0x65690032}},	//   _लेकि, _hang, döme, nfeh
  { {0xfaf80039,0x90c30047,0x7c2d002c,0x61eb10f3}},	// [2140] _šī_, _объе, gpar, dogl
  { {0x6b8300c6,0x0b46002d,0x442d10f4,0xdb1c10f5}},	//   _jang, інен, ipe_, _områ
  { {0x2d8210f6,0x61eb10f7,0x65b501bd,0xd36f0012}},	//   _take_, fogl, _náho, ئهم_
  { {0x673a0065,0x3e450039,0x61eb10f8,0xdb0310f9}},	//   _setj, dēt_, gogl, _coné
  { {0x7984002c,0xb033002d,0x7c2d0018,0x00da0012}},	//   _maiw, дніш, cpar, جبات_
  { {0x6b830167,0x5f930001,0xe7930001,0x69d902a2}},	//   _nang, дишт, дишњ, anwe
  { {0x25a60b7b,0x171b000b,0x8f1b0009,0xd6d00012}},	//   _pool_, בוצע, בוצת, عقب_
  { {0x6b8300bd,0x21f900f1,0x798408bb,0xc0e60024}},	//   _aang, vého_, _naiw, _добк
  { {0x2d820029,0x6b8310fa,0x65b50030,0xc4f70012}},	//   ľke_, _bang, _táhn, يعًا_
  { {0x6444004a,0x7996002a,0x661a0855,0x21f90042}},	//   isii, _anyw, _tutk, tého_
  { {0x0377000b,0xe919002d,0x3e45001e,0x0ac60015}},	//   חתית_, йоні_, cēt_, ющим
  { {0x64440006,0xd46a06fd,0x21f901bd,0xd1260012}},	//   ksii, _виде_, rého_, عم_
  { {0x6d400891,0x395f001e,0xdd8f0003,0x14c70015}},	//   mama, ļus_, _جون_, _мыши_
  { {0xcb670046,0xa91d0010,0x6d4010fb,0x48a80024}},	//   _даље_, _maža, lama, ітям_
  { {0x09f70012,0x81f70012,0x179b0009,0xdb210097}},	//   _وأعد, _وأعط, סילב, ótís
  { {0x65b50013,0x2489009b,0xb2bb0009,0x22510064}},	//   _náhl, tvam_, _כמור, ázke_
  { {0xb4b50044,0x3e450039,0x54550014,0x7bda000d}},	// [2150] जने_, zēt_, яват, ontu
  { {0x6d4010fc,0x2bbb0012,0xc3980024,0xfe500060}},	//   hama, جارة_, окує_, üçük_
  { {0xd3780002,0x6d4010fd,0x877a0009,0x65aa0042}},	//   ieć_, kama, _האתי, _výhr
  { {0xa3ca0044,0x63a7003e,0x3eac0052,0x3e45001e}},	//   रोत_, _wojn, ädte_, vēt_
  { {0xf1b40093,0xd8b80003,0x759a0009,0x7dc50010}},	//   וסף_, يدها_, _הסרג, iųst
  { {0xec36000b,0x907c000b,0x8e490003,0x0058000b}},	//   _מאשר_, שְׁפ, ملتك_, קשות_
  { {0x5f740003,0x1f380009,0x41770012,0x69cd03bd}},	//   ظاهر, חרור_, _وارس, _omae
  { {0x753d003e,0x3e450039,0x3179003e,0x26dc000b}},	//   _jesz, rēt_, jesz_, יקומ
  { {0x442d0108,0xe4510003,0x3e45001e,0x6b8310fe}},	//   upe_, رضة_, sēt_, _pang
  { {0x69dd0108,0x3fb70003,0x753d10ff,0x3e45001e}},	//   éren, _بإرس, _lesz, pēt_
  { {0xa3ca0037,0x9ee90003,0x65690052,0x2bca0037}},	//   रोध_, _افضل_, pfeh, ाफ़ा
  { {0x216a0021,0xe8e0001a,0x6d401100,0x442d1101}},	//   щими_, uyệt_, cama, ppe_
  { {0x251a000b,0x6b831102,0x43950511,0x60d50009}},	//   _הונא, _tang, _надс, לוֹא_
  { {0x78a90051,0x5bc40003,0xa0880009,0x3b840024}},	//   äeva, _يتوف, קְרִ, _оліг
  { {0x753d000f,0xa3b80012,0xbb3a0009,0x7aee00d9}},	//   _besz, _ظاهر_, _העצי, čité
  { {0x3179003e,0x3f8500c6,0x64440005,0x9c261103}},	//   cesz_, _lalu_, tsii, здад
  { {0x39420005,0x43760047,0x49bb000b,0x90460003}},	// [2160] maks_, зует, _למקס, _عنده
  { {0xb9030047,0x0e661104,0x39420cb1,0x64441105}},	//   _язык, _екон, laks_, rsii
  { {0xae0e0044,0x68120066,0x74130003,0x66091106}},	//   ागमन_, _vědě, روما, kmek
  { {0x58860015,0xd3780002,0xa91d0010,0x39420051}},	//   зыка, zeć_, _paža, naks_
  { {0x66090051,0x59bd0011,0x03950035,0x6d401107}},	//   dmek, ्फ़र, _ķīnā_, vama
  { {0x6d4b00c5,0xa857000b,0x39420051,0xa91d0027}},	//   _adga, פיצה_, haks_, _važa
  { {0x7c2b0039,0x39420051,0x6d401108,0x3e870030}},	//   _atgr, kaks_, tama, mítá_
  { {0x0576000a,0x39420051,0x9adb000b,0x8d760003}},	//   ساعد, jaks_, _החלט, ساعا
  { {0x39420051,0xa91d001b,0x3f85056b,0x83fd0031}},	//   daks_, _kažn, _falu_, rtőn
  { {0x88bb000b,0x39420051,0x644f1109,0x58bb0009}},	//   _הזמי, eaks_, ácia, _הממצ
  { {0x21fc0013,0x2179003c,0x2c660064,0x6d40110a}},	//   ního_, ойны_, hôd_, pama
  { {0xdcfd001e,0xa91d017b,0x5afb0009,0xf1bf0030}},	//   _lasā, _lažn, מליצ, uhá_
  { {0xd5b10020,0x4420007d,0xed57002d,0x753d0053}},	//   ếm_, _îi_, _хоч_, _resz
  { {0xad9b008a,0xba760012,0xd7f10081,0x75380034}},	//   _chún, _فاعت, ỗ_, ńczą
  { {0x33fb000b,0x21fc0066,0x93fb0009,0x6e94003c}},	//   _ההגנ, jího_, _הלגי, ниру
  { {0x22f7000b,0xfaf7000b,0xe4e70024,0x9df90024}},	//   _מזון_, _מצוי_, пізн, інат_
  { {0x753d000e,0xa91d0010,0x7c150024,0xc1050012}},	// [2170] _vesz, _bažn, ддає, _توظي
  { {0x88bc0009,0x58bc0009,0xd9b50011,0x753d0034}},	//   _למחז, _למחצ, ंस्ट, _wesz
  { {0xa91d007a,0x753d000f,0x22950003,0x2247000e}},	//   _dažn, _tesz, بلاس, énk_
  { {0x6aaa006f,0x31350055,0x69dd110b,0xc27b0009}},	//   äffa, федр, nnse, מרבי
  { {0xdce0001e,0xdb18000e,0xc5fb0037,0xdbc7004a}},	//   iemē, _elvé, ्षीय_, töäs
  { {0xbcb6000b,0x76550002,0xa6950001,0xab840264}},	//   _חפשו_, orzy, дриј, _пуск
  { {0x21fc0013,0xdb09003a,0x63a30028,0x660905ea}},	//   cího_, ünün, önnu, tmek
  { {0x25bf0051,0x69dd110c,0xa4c0003a,0xe1f30012}},	//   uhul_, érel, nüşü_, _أسس_
  { {0x91fd0333,0x39420005,0xed600066,0x6609110d}},	//   rtāl, vaks_, ížit_, rmek
  { {0xe3b10003,0x63aa0002,0x76550002,0xa3b00011}},	//   ئرة_, _cofn, krzy, टॉप_
  { {0x39420051,0x76550002,0x7afd0002,0x6609001e}},	//   taks_, jrzy, ęsto, pmek
  { {0x44b50047,0x68f60006,0x6d4b0058,0xa91d0010}},	//   _обес, _pyyd, _udga, _mažo
  { {0xe87c00a2,0x76550002,0x21fc0066,0xa3ca0011}},	//   _düşü, erzy, zího_, रोह_
  { {0x39420005,0xa84d0030,0x6be50012,0x6f040030}},	//   saks_, énář_, _تكتم, řice
  { {0xe9d2000a,0x7a420030,0xc3320009,0x248d110e}},	//   _لغة_, _vítá, _יוג_, lvem_
  { {0x2176002d,0xcb120009,0x7bc10097,0x68f6008e}},	//   _цукр, _בלו_, lhlu, _tyyd
  { {0xdcfd001e,0xa91d0027,0xceb80010,0x60040054}},	// [2180] _pasā, _pažn, šę_, lòme
  { {0x22ba0003,0x76550002,0x67220011,0x21fc0030}},	//   يداع_, brzy, _मलिक_, tího_
  { {0xa91d001c,0x4f9b0009,0x994a0012,0xbf9b0009}},	//   _važn, _וביצ, قلال_, _וייש
  { {0x200500b6,0xa91d001e,0x02de0011,0xbbaa0011}},	//   _ahli_, _dažo, _मशीन, _चक्क
  { {0x765c004a,0x7bc100b6,0x6d440182,0xa87a0012}},	//   lury, khlu, maia, تحار_
  { {0x62830082,0x7bdd0061,0x6d4402a5,0x3940110f}},	//   _osno, ésul, laia, _leis_
  { {0x5a550014,0x2e4a0014,0xf7730009,0x60090009}},	//   _пъту, цяло_, דקו_, הִקְ
  { {0x77b403eb,0x1dde0037,0xdb0a0058,0x986a0012}},	//   _màxi, नचित, _ilfø, _وحذف_
  { {0x9be6002d,0x69dd08cf,0xdbc6005e,0xa06a0373}},	//   дінк, érem, _möön, _фаза_
  { {0x5a340014,0xc6760003,0x4bda0003,0x69c20227}},	//   ннот, _يطاب, تبعد_, lhoe
  { {0x8aa3002d,0xcb57000b,0x6d441110,0x5b570009}},	//   вряд, וסיה_, kaia, וייב_
  { {0xf5930003,0x8d930003,0x85060003,0xa194002d}},	//   _للمج, _للمش, _قوان, ваюч
  { {0x3cfa0011,0x5064004c,0x22590034,0x69dd1111}},	//   ्धों_, ктра, ąska_, rnse
  { {0x7655003e,0x7bc10052,0x7d020027,0xafdb0033}},	//   trzy, chlu, _izos, msøk
  { {0xafdb0033,0x99d70003,0x05b20011,0xef110009}},	//   lsøk, _يتعا, _जवाब, ָּם_
  { {0x69d6000e,0x41e70012,0xe3b80060,0xa91d0035}},	//   ézet, _تستف, lkı_, _ražo
  { {0xe9df0026,0x656d008b,0x113c0009,0xa4c00060}},	// [2190] mnú_, rfah, _ותחל, rüşü_
  { {0x76550002,0xe9df0029,0x8c1b0009,0x6606005e}},	//   przy, lnú_, קובי, _ehkk
  { {0x248d0066,0x77b0006f,0x6fd40012,0x33f40248}},	//   zvem_, _växt, _جزيئ, växt_
  { {0xd5a60003,0xe9df0029,0xd258003c,0x29d20159}},	//   _صف_, nnú_, ьцу_, jšal_
  { {0xe4e7002d,0xe3b8003a,0x53470015,0x99d40012}},	//   _цінн, kkı_, _охва, ختلا
  { {0x40920012,0xe79b0012,0xe9df0064,0xdc3a0009}},	//   الور, تخصص_, hnú_, _מעשר
  { {0xfe710003,0xafdb0033,0xe9df0029,0x660d004a}},	//   ادت_, esøk, knú_, omak
  { {0xff18000b,0x91fd001e,0x2247022d,0x660d1112}},	//   וקות_, stāj, ánku_, nmak
  { {0xe9df0029,0x6000006f,0xd5e80012,0xd7fb004c}},	//   dnú_, dömn, بعون_, _дуж_
  { {0xa3ca0037,0xd5b1001a,0xa91d0073,0x87070012}},	//   रोल_, _múi_, _mažm, _قبال
  { {0xe29905f7,0x7bc10097,0xbb3a0009,0x660d1113}},	//   чан_, rhlu, העתי, kmak
  { {0xdb070065,0x3ce00604,0xcb120009,0x8d740012}},	//   _hljó, _žive_, טלי_, _لاها
  { {0xd4c40012,0xbcfb1114,0xdb050032,0x660d1115}},	//   _لغوي, _scén, chhö, dmak
  { {0x78a4019a,0x6d4408ee,0xa2e5003c,0x64491116}},	//   äivi, waia, _полд, msei
  { {0x670f0037,0xe9df0029,0xa91d0027,0x64460010}},	//   ाधिक_, bnú_, _pažl, škit
  { {0xe9a90012,0xe6170048,0x62860035,0xe9df0064}},	//   _يدين_, едс_, ākot, cnú_
  { {0x6b560003,0x64491117,0x998d0034,0xe3ba0048}},	// [21a0] فضائ, nsei, _mień_, пба_
  { {0x43860003,0x64560a39,0x6d441118,0x26cc0017}},	//   علاق, rryi, saia, údos_
  { {0x443201f6,0x14170012,0x6d441119,0xdbc6005e}},	//   spy_, ريمة_, paia, _töön
  { {0x50660014,0x7aba000b,0xc8660867,0x6449111a}},	//   етка, הצעו, етки, ksei
  { {0xad1b000b,0x351b000b,0x83fd0031,0x69c2111b}},	//   _מוכר, _מוכנ, rtőj, rhoe
  { {0xd0100012,0xf41f008e,0xe9df0064,0x7f580d21}},	//   جلت_, _eräs_, znú_, факс_
  { {0x539b000b,0x644b079d,0xc7b30009,0x7d020034}},	//   _צילו, _avgi, רבו_, _szos
  { {0xafdb0033,0xa91d009b,0x7b06001e,0x9f4a00d9}},	//   tsøk, _lažj, ērtē, dobí_
  { {0xdb070065,0xe9df0029,0x91fd001e,0x69c0111c}},	//   _fljó, vnú_, stāk, _ilme
  { {0xa3ca0044,0xafdb0119,0x660d111d,0xe1fb0011}},	//   रों_, rsøk, zmak, ृष्ण_
  { {0xa159111e,0xe9df0029,0x2ec60003,0xdb0e090d}},	//   ману_, tnú_, _ثقاف, _albú
  { {0xe3b8003a,0x64490052,0xb6bb000b,0x3e4c0030}},	//   skı_, bsei, _מצבי, mět_
  { {0x98b80014,0xe9df0029,0xe3b80060,0xecd00011}},	//   елят_, rnú_, pkı_, _सेलफ
  { {0xc5fb0037,0xe9df0029,0x8c1b0009,0x69c000b0}},	//   ्ष्य_, snú_, _זוגי, _llme
  { {0x442203c2,0xd5bb07f5,0x02930012,0x65bc0025}},	//   _auk_, пса_, _مؤيد, _jého
  { {0x7c22004a,0x660d002c,0xdcfb001b,0xb7b50081}},	//   _kuor, umak, uduć, _kịc
  { {0xd7fb0024,0xf3f9004b,0xfc300012,0xf3f10081}},	// [21b0] _нуо_, suţe_, محل_, _ự_
  { {0xa295002d,0xd3710003,0x7c2200b8,0x660d111f}},	//   казі, ؤها_, _muor, smak
  { {0xd1310003,0xb7b5001a,0x660d1120,0x2bb80012}},	//   لما_, _lịc, pmak, راكة_
  { {0x3e4c0013,0x91f60020,0x6449004a,0xdeb60009}},	//   dět_, hún, ysei, _יפתח_
  { {0x7c22050d,0xf7710012,0x690c0009,0x74150012}},	//   _nuor, لاث_, ִּדְ, _لوحا
  { {0x2d8b02d1,0x69c00236,0xa91d0010,0x64490051}},	//   _hace_, _elme, _kažk, vsei
  { {0xbea50365,0x9e090012,0xedcb0009,0xdfce00ae}},	//   тайк, ويتك_, ּמִֽ, تيو_
  { {0xc694000b,0xdcf90002,0x64491121,0xbbb90011}},	//   ראק_, _zawę, tsei, इस्क
  { {0x6d42007d,0xd5ae0003,0x7c2200c1,0xe3b10012}},	//   _deoa, تفي_, _cuor, لرد_
  { {0xb7b5008a,0x25a90051,0x64491122,0x98170012}},	//   _dịc, hjal_, rsei, _أبرا
  { {0x13090047,0x443d1123,0x2b580034,0xbcfb0025}},	//   ьной_, _www_, órca_, _scél
  { {0x7c2200c1,0x2d8b01e3,0x32090081,0x3eba00b0}},	//   _fuor, _nace_, _chay_, øpte_
  { {0xef18001e,0x9b950003,0xe5880009,0xbb850012}},	//   _daļu_, _للإت, _רָעָ, _للشي
  { {0x44221124,0xdce60064,0x61fd0097,0xd75a0012}},	//   _ruk_, ámče, alsl, بلست_
  { {0x7c220052,0xb9c60012,0x63ae001b,0xdb070030}},	//   _zuor, _لتظه, _robn, _bojí
  { {0xc6920009,0xa91d0035,0x44221125,0x2d8d1126}},	//   סאן_, _dažk, _puk_, ndee_
  { {0xdb070066,0xad250012,0x11d70012,0x30060048}},	// [21c0] _dojí, ارفو, _جوية_, _изиг
  { {0x291f0164,0xa01b0028,0xdce4001e,0x25a9005e}},	//   _agua_, svör, ediģ, ajal_
  { {0x68fb02d1,0xcf57000b,0x69c60051,0xdb03000e}},	//   _ayud, _בבית_, ohke, _elnö
  { {0xfbc9000b,0x3e4c0066,0x29d50030,0xf1bb0081}},	//   חת_, vět_, sťan_, _luơn_
  { {0x4153002d,0xf9930009,0x6443001b,0xc7c60306}},	//   рвіс, ירא_, ćnic, кски
  { {0x3e4c0066,0x57f30024,0xc7af0012,0xd7f70048}},	//   tět_, апіт, يّن_, кущ_
  { {0x7c220006,0x6e940003,0xb7db0009,0x7dde0035}},	//   _suor, البا, וקסי, līsi
  { {0xd657000b,0x96b70001,0xceb30009,0xa5330048}},	//   דיקת_, ђују_, שיה_, анъч
  { {0x7dde001e,0x8a17000b,0xc1570009,0x6d42005e}},	//   nīsi, _יחלו_, _ששמו_, _veoa
  { {0x2d80007d,0x7c22004a,0x3e4c0066,0xa7850012}},	//   heie_, _vuor, pět_, _مشمو
  { {0xd7ef0003,0xe3af0003,0x0bb7000b,0x5ea60012}},	//   _بكل_, تري_, דלים_, _جمال
  { {0x7c22004a,0x04960003,0x61e21127,0x3035003c}},	//   _tuor, _للصح, nnol, лемё
  { {0x7c2d003a,0x2d8b04f2,0xdb030031,0x3f8c0522}},	//   _çarp, _race_, _voná, _kadu_
  { {0x7dde0039,0xe7300003,0x6b8a0040,0x40340223}},	//   dīsi, قصف_, _uafg, рерс
  { {0x3209008a,0x8c1b000b,0xa6f80009,0xdb7b0009}},	//   _thay_, _קווי, גִּי, _חנוכ
  { {0x69c6008b,0x6564002c,0xda4b0009,0x13170009}},	//   chke, ggih, _חֲזָ, _בחול_
  { {0x33750019,0xa5f81128,0x61e202a8,0x1df8003c}},	// [21d0] лгар, тету_, dnol, теты_
  { {0x389a000b,0xf092000b,0x1b7b0003,0xd5b1001a}},	//   _ניתנ, _פני_, بصرة_, _hút_
  { {0x387e000d,0x798d020d,0xc9590012,0xf60b0012}},	//   ătre_, _kaaw, فلاش_, _يتجه_
  { {0xe1ff000e,0x83fd0031,0xdb1a04e7,0x61e21129}},	//   nló_, rtői, bitö, gnol
  { {0x80cd0044,0xd5b10020,0x040d001a,0x7fd50024}},	//   _देखे, ếu_, _cườn, лікі
  { {0xa91d007a,0x040d001a,0xf7710012,0x1d160009}},	//   _maži, _dườn, صات_, _תקשר_
  { {0xf770000a,0x2f54002d,0x9e640012,0xb05b0032}},	//   تان_, ртіс, لاين, szäh
  { {0xd5b1001a,0xdddc0066,0x2c6b014f,0x8e760012}},	//   _nút_, zvrž, tød_, اميذ_
  { {0x40590012,0x53b70011,0x661d112a,0x644d112b}},	//   _سلاح_, _आकाश, _misk, nsai
  { {0x3944001e,0x3f8c001e,0x2d8b015b,0x600008af}},	//   _zems_, _gadu_, žce_, tömm
  { {0xd94603e1,0xd5750a2c,0xd5b10081,0x7dde0035}},	//   лени, _буль, _bút_, zīsi
  { {0xcf890009,0xe0c70012,0x661d112c,0x69d90d61}},	//   _מט_, مز_, _nisk, niwe
  { {0xeb8e0909,0x256d0031,0x644d0035,0x6000008e}},	//   _ли_, zóló_, jsai, sömm
  { {0x6c520046,0xd8da000b,0x8b940014,0xe1ff000e}},	//   _укљу, תקשר, _връч, aló_
  { {0x3ebe0028,0xa91d001e,0x2eb50015,0xe2a80012}},	//   átt_, _daži, астс, _لاين_
  { {0x7dde0039,0x0c3a0012,0x8886112d,0x01660048}},	//   tīsi, فكرة_, _ближ, _скио
  { {0xb0d20044,0xb97b0009,0x6b810227,0x69c4004b}},	// [21e0] _देंग, _טנקי, oelg, _ilie
  { {0xdd03007a,0x798d0002,0xdb030061,0x8b2601b6}},	//   ūrėk, _zaaw, _conç, удже
  { {0x7afd0002,0xd7bb0009,0x7dde0035,0x644f0060}},	//   ęstw, _נצטר, sīsi, _evci
  { {0xd5b10020,0xc329000b,0x91fd001e,0xf1fa0012}},	//   ết_, לו_, stāv, رعات_
  { {0x7bc30005,0x6d46001e,0x935a0001,0x69c40064}},	//   _olnu, _ieka, _прву_, _mlie
  { {0x91fd0039,0xa634002d,0x661d01bd,0xdb030411}},	//   ltāt, анкі, _zisk, _gonç
  { {0x03d7000b,0x6d4600b6,0x63aa0028,0xf1c101e9}},	//   _עולם_, _keka, öfnu, ášky_
  { {0x040d001a,0xbdb40001,0xf1b9013a,0x5454112e}},	//   _tườn, рбиј, _piše_, авит
  { {0x136a0014,0xd5b1001a,0x89db0009,0x86070012}},	//   ншни_, _rút_, _נחמי, دقيق_
  { {0xf1b9001c,0xe0d7004c,0xaa74004c,0xf6260024}},	//   _više_, _сву_, агољ, _бджо
  { {0xb3450017,0x69c40052,0x41b50012,0x8cd40011}},	//   _seçã, _blie, لمدر, _बेरो
  { {0x645b01e4,0x6d46112f,0xf2d30009,0xd915003c}},	//   brui, _neka, מעת_, идны
  { {0x7c26007a,0xf3f9000d,0x201e0010,0xa91d0010}},	//   _nukr, suţa_, _kiti_, _paži
  { {0xa3e8015f,0xdb18000e,0x69d90034,0xc7c70048}},	//   _यदि_, _elvá, ziwe, усми
  { {0x8f9b000b,0x69c40e22,0x7bda1130,0xba730012}},	//   עילי, _flie, mitu, _هايت
  { {0x7bda00b9,0x44260010,0x69c40778,0x49bb0012}},	//   litu, _kuo_, _glie, _ساعد_
  { {0x41c40003,0x24580015,0x44260010,0x03d500b3}},	// [21f0] _دقيق, лать_, _juo_, ажаю
  { {0xf1bf0066,0x36d50015,0x201e013a,0x661d0227}},	//   lká_, _воор, _niti_, _wisk
  { {0x44260006,0x644d1131,0x99350003,0x7bda0051}},	//   _luo_, ssai, لفات, iitu
  { {0x3ebe0722,0x6b81059b,0xa1190012,0x89370012}},	//   øtte_, zelg, نقاط_, اعضا
  { {0x4426007a,0x201e0082,0x7bda1132,0x80db0011}},	//   _nuo_, _biti_, kitu, _पेमे
  { {0x7bd50052,0x201e1133,0x62980c57,0x65b501bd}},	//   _umzu, _citi_, _orvo, _náhr
  { {0x74d90037,0xdb050028,0x7de1001e,0x6b811134}},	//   _नेतृ, rkhó, lēsi, velg
  { {0xf2d2000b,0x201e0010,0x4426002c,0x370a0011}},	//   _ועל_, _eiti_, _buo_, ाधड़ी_
  { {0x62980006,0x05a60015,0x7bda1135,0xbf670012}},	//   _arvo, рвый_, fitu, _مداو
  { {0x61e90119,0xe2990001,0xf7730003,0x7bda002b}},	//   _hjel, вао_, _دار_, gitu
  { {0x11d60012,0x8bd60009,0x179a0009,0xd7c80012}},	//   لتحد, שותו_, _שיעב, _حوله_
  { {0x11d60024,0x3f910035,0x6b8107a2,0x6e3a00af}},	//   ріор, edzu_, selg, _יתעד
  { {0x629800bd,0x69c40070,0x91f6000b,0xdb1a004a}},	//   _ervo, _vlie, שמרו_, ehtä
  { {0x6d460acb,0x25ad0051,0xd5eb001a,0x7d06003a}},	//   _seka, ljel_, _đíc, ükse
  { {0x61fb1136,0x6d461137,0x8f880009,0xe6b20011}},	//   _okul, _peka, נְשֵ, ीनेज
  { {0xceb20093,0x96630014,0xf1bf0107,0x67170037}},	//   חיל_, юксе, cká_, धेयक_
  { {0x9f5e004a,0xf9fb0009,0x74160012,0xcce50012}},	// [2200] _yhtä_, _בהקמ, لورا, مسكي
  { {0x91fd00cd,0xe29a00dc,0x909b0009,0x1d1904a5}},	//   grāf, каз_, _יספק, уюсь_
  { {0xa9260015,0x6d46047b,0xaf5b0009,0x2f5b0009}},	//   адел, _teka, _בכיכ, _בדינ
  { {0xc05a002d,0x61e90027,0x201e1138,0x70560012}},	//   вік_, _cjel, _siti_, لنصا
  { {0x61e90027,0x61e60010,0xdb070066,0x6d3b000b}},	//   _djel, inkl, _vojá, _בתכנ
  { {0x91fd0039,0xdfcf0003,0xf1bf05b1,0x3ce01139}},	//   ntār, وين_, zká_, _živo_
  { {0x442601a2,0x6442003e,0x4b7b0093,0x7bda113a}},	//   _suo_, _swoi, _שאלו, vitu
  { {0x61e90119,0xafdb0119,0x420a0024,0x6e970048}},	//   _gjel, nsør, _рнбо_, рвър_
  { {0x2d8f00c5,0xbc670003,0x6c830012,0x98bd0034}},	//   _dage_, لمين_, قليم, tawą_
  { {0xa5070001,0xa91d0010,0x61e6113b,0x6298113c}},	//   шења_, _pažv, enkl, _prvo
  { {0x3f830010,0x7de1001e,0xa91d001e,0x8ae6002d}},	//   veju_, zēsi, _dažu, ріпл
  { {0x6442003e,0x4426113d,0x76bb0009,0xdebb0009}},	//   _twoi, _tuo_, _שמאפ, _שמאל
  { {0xdb0e003a,0x6e2801bd,0xedd30012,0x80b30011}},	//   _albü, _hudb, _بيند, ुनें
  { {0xdcfb00a2,0x2d84039f,0xc7c40015,0xf1bf0145}},	//   lduğ, leme_, осси, ská_
  { {0xba540012,0x69dd113e,0x55590048,0x3f83113f}},	//   _انبع, éres, лавя_, reju_
  { {0xdcfb00a2,0x59d40003,0xf99f0054,0xcb090024}},	//   nduğ, _وغير, rmès_, _схід_
  { {0x69dd1140,0x91fd001e,0x4c940015,0x26e20011}},	// [2210] mise, stās, оитс, गपुर_
  { {0x7de10039,0x61e90428,0x78fc0009,0x3949005e}},	//   rēsi, _sjel, _בפחו, _heas_
  { {0xe695000a,0x6e95000a,0x600d0065,0x20030604}},	//   _الجد, _الجا, núme, mlji_
  { {0x62860002,0x2d841141,0x7de10035,0x7e63008e}},	//   łkow, jeme_, pēsi, vunp
  { {0x9f510066,0x60f80024,0xe4a7004c,0x2d841142}},	//   hozí_, анця_, _трно, deme_
  { {0x69dd0005,0x7dde001e,0x70520012,0x8a370012}},	//   hise, zīst, أنوا, _نعرض
  { {0x320d0036,0x4e950003,0x91fd001e,0x2d8f1143}},	//   _they_, إشتر, orād, _page_
  { {0x59f90015,0x39400028,0x77bd0054,0x63b5000e}},	//   _себя_, ðist_, _mèxi, _hozn
  { {0x69dd0005,0x26c10026,0x7bc70331,0x04560003}},	//   dise, šho_, _klju, ملية_
  { {0x78bd0006,0xb8dd0037,0x6e280027,0xd6db0048}},	//   dysv, ुई_, _fudb, _ите_
  { {0x69dd0119,0x7dde001e,0x2d8f1144,0x3dc61145}},	//   fise, tīst, _tage_, _flow_
  { {0xc9760003,0x3949000d,0x2d8401bd,0xd378001b}},	//   حادث, _ceas_, ceme_, viće_
  { {0x34ab0003,0x27f802c7,0xa9fa0009,0x31fa0009}},	//   _جداً_, torn_, רִית, רִיע
  { {0x6d4b0028,0x7c3b1146,0xd378001b,0x91fd0035}},	//   ðgan, mpur, tiće_, erād
  { {0xada6035b,0xed5a048c,0x96060012,0xfa350012}},	//   бавл, лов_, مبرم, _ارتد
  { {0xd5b10020,0x65690480,0x249f001b,0x1d26004c}},	//   ếp_, ngeh, _šuma_, смам
  { {0x998d0002,0x69d80061,0x61f90002,0x7bc1001e}},	// [2220] _wieś_, èvem, dowl, oklu
  { {0x7f860003,0x91fd001e,0x7dda0066,0x65bc0061}},	//   _الدن, arād, půso, _véhi
  { {0x79860070,0xdceb001e,0xce95001e,0xdcfb003a}},	//   oekw, _angļ, šējā_, yduğ
  { {0x7bc7000e,0xdb1c006f,0x65690070,0xdd9f0064}},	//   _elju, _omrö, jgeh, áňte_
  { {0xdfda0014,0x28d20321,0xc9530009,0xa8770012}},	//   лък_, _देखि, למא_, محور_
  { {0xdfd0000a,0x824a0003,0x3dc6002a,0x660408a0}},	//   بيت_, _مشرف_, _slow_, llik
  { {0x8f9b000b,0x65690052,0x69dd004a,0x29d20035}},	//   טיסי, fgeh, yise, nšas_
  { {0x63b50026,0x69cb0052,0x66041147,0x629c1148}},	//   _zozn, chge, nlik, _irro
  { {0xdcfb003a,0xc34a0d25,0x91bb0009,0x3949005e}},	//   rduğ, ляне_, _עממי, _reas_
  { {0xdee60046,0x2d840051,0x6604003a,0x91fd001e}},	//   _лози, seme_, hlik, zrād
  { {0xd5af085b,0x2904003a,0x5f370009,0x4b7b0009}},	//   _ес_, üman_, _הטבע_, נאטו
  { {0x31c70015,0x59f90015,0x9c830010,0x78bd004a}},	//   ссов, ремя_, ščiu, tysv
  { {0x66040118,0x600d01e3,0xf5060024,0x7bde1149}},	//   dlik, súme, _уздо, kipu
  { {0x7bc1008b,0xcc57000b,0x6ee70003,0x69dd114a}},	//   cklu, _פסוק_, مسأل, sise
  { {0x7de5007a,0x98a500a2,0x91fd001e,0x6377000b}},	//   lėsi, ğlı_, trād, _הגוף_
  { {0xaae50003,0x98a5003a,0x7bcb001e,0x6604114b}},	//   _بسهو, şlı_, īgum, glik
  { {0x5455007c,0xb4b50037,0x7bcb001e,0x73d9004c}},	// [2230] юват, ड़ने_, ūgum, адар_
  { {0x2bbb0003,0xe4d40003,0x3b550024,0xbed9003c}},	//   دارة_, ستقب, ікер, _вдох_
  { {0xc3330093,0x7bc70159,0x6d4d020d,0x69c00031}},	//   פוף_, _vlju, paaa, ömeg
  { {0xdb030026,0x7de50010,0x90990593,0x225c05b1}},	//   _ponú, kėsi, ивет_, ávka_
  { {0xa01b000e,0x628e114c,0xf8650024,0xfd960009}},	//   dvöz, _esbo, івко, _ודרך_
  { {0x44390036,0x7de50010,0x98480015,0x4fe8002d}},	//   _its_, dėsi, сяца_, бмін_
  { {0x5fbc0093,0x65690480,0x2fd60012,0x7ff40012}},	//   רצונ, tgeh, توود_, أسنا
  { {0x442300bd,0xe4590751,0x95990024,0x59c50012}},	//   _hij_, ажи_, ртку_, _بيرك
  { {0x65690052,0xa3b00011,0x6e22114d,0x7de50073}},	//   rgeh, टॉक_, _diob, gėsi
  { {0xd7fb106a,0xa3d30037,0x69dd0061,0x65690052}},	//   _суб_, सों_, èren, sgeh
  { {0x656f00c1,0x44230070,0x6616004a,0xc9aa0ec6}},	//   _occh, _mij_, ymyk, авне_
  { {0xb1da002d,0x7de50010,0x216a01d4,0x7c3b114e}},	//   рьох_, bėsi, шими_, ppur
  { {0xd00a0083,0x23b50012,0x98bd0034,0x6d4b0035}},	//   иеме_, _ومؤس, tawę_, _iega
  { {0x61b60044,0x657d00b6,0xd9b60037,0x69c90070}},	//   _अक्ष, _absh, _अक्ट, _llee
  { {0x6d4b00b6,0x98bd0002,0x3f8709d4,0x6604114f}},	//   _kega, rawę_, ienu_, tlik
  { {0xa3d70044,0x61ed0065,0xe5a3029b,0xc692000b}},	//   ़ोस_, _gjal, миси, ואל_
  { {0x442301e4,0xfc1a0003,0x6d4b1150,0x66041151}},	// [2240] _bij_, لقرب_, _mega, rlik
  { {0x66040005,0x3f870027,0xe73a0001,0x833a052c}},	//   slik, jenu_, _њен_, рчат_
  { {0xdcff001e,0xe29701b6,0x69c90644,0x44391152}},	//   īvāk, жах_, _blee, _ets_
  { {0xf653000b,0x60000052,0xf8bf01a0,0xd1300012}},	//   _קצר_, römu, ccés_, رمت_
  { {0x91fd001e,0x10470014,0x8b660003,0xe7c50011}},	//   duāl, оящи_, _واسم, वसंप
  { {0xc059007c,0x7de1001e,0x44230070,0x6d4b0051}},	//   сії_, zēst, _gij_, _aega
  { {0x60040054,0x69c90802,0x6d4b1153,0xe6660024}},	//   nòmi, _flee, _bega, ітко
  { {0x442300bd,0x5d540014,0xbdf70012,0xd378001b}},	//   _zij_, чкит, يريا_, dića_
  { {0xab5c001e,0x4f5a0003,0xd12f0012,0x7de10035}},	//   ekļa, _نجاد_, _شمل_, vēst
  { {0x7de50010,0x61ed0028,0x547b0009,0x9f580025}},	//   rėsi, _sjal, סטיו, boré_
  { {0xc333000b,0xc7b3000b,0xba0b0014,0x69c9004a}},	//   וות_, _קבע_, ихме_, _ylee
  { {0x7c230052,0xc2b70024,0xbca60012,0x645d0073}},	//   _einr, іляє_, _وماي, šsia
  { {0xc953000b,0x80db0037,0xa50700f5,0x05b30012}},	//   ומר_, _पेशे, _деца_, _تمنح
  { {0x29050039,0x6d4b0002,0xcf270012,0xa2e60012}},	//   āla_, _zega, ترحي, _وأثن
  { {0xcddb1154,0x163b000a,0x7c2b008b,0x454b0014}},	//   ања_, ؤسسة_, _zugr, ичам_
  { {0xa4d5002d,0xca830003,0x442b0054,0xd1310012}},	//   побі, _آليً, _puc_, _ثمة_
  { {0xf8bf0025,0x69c0005e,0x6b880227,0x91bc0009}},	// [2250] rcés_, ömee, oedg, _כמהי
  { {0x29150002,0x69c91155,0xc43b0009,0xaac70012}},	//   ądać_, _slee, יתמי, يتان
  { {0x8ae7007c,0xaa950003,0x0af90003,0x3f871156}},	//   ціал, ثلاث, حفاظ_, venu_
  { {0x44230070,0xd1b80003,0xe2900003,0xd8750012}},	//   _wij_, يانا_, خذك_, كاتب
  { {0x8fa5002d,0x3f870061,0xc0c80001,0x76550002}},	//   зале, tenu_, жује_, lszy
  { {0x94ba0093,0x9f580026,0x9f470061,0x6d4b1157}},	//   _המשת, toré_, onné_, _sega
  { {0xed590047,0x7c2b0010,0x91fd001e,0x92580e0f}},	//   бой_, _sugr, tuāl, _март_
  { {0x656d1158,0xd3780027,0x8d750003,0x61fd001e}},	//   ngah, vića_, سابا, josl
  { {0x478b0015,0x20540015,0x6d4b1159,0x61fd115a}},	//   _всем_, _октя, _vega, dosl
  { {0x4439001e,0xcb690001,0xd378001b,0x0bb60009}},	//   īs_, љане_, tića_, ִ֜ים_
  { {0xc869000b,0x44390113,0x76550002,0x9f4e0066}},	//   _תן_, ūs_, jszy, áním_
  { {0xf1b9001c,0x224700f1,0x76550034,0x61eb0032}},	//   _još_, ánky_, dszy, nngl
  { {0x394d0051,0x29040028,0xa3ae0011,0xf8bd0011}},	//   _mees_, æma_, काम_, ्निय
  { {0x78a60065,0x4c9a000b,0x394d0070,0xe8d6000b}},	//   _ákve, _לבנו, _lees_, לורר_
  { {0x60120028,0x443f115b,0xb7bd004b,0x9f58004b}},	//   væmd, lpu_, _cuţi, borî_
  { {0x09fa0003,0x82d6000b,0xc8bd0037,0x52d6000b}},	//   _دفعة_, _מוצג_, ्नाट, _מוצע_
  { {0xdd8f000a,0x2ea80037,0x76550002,0xe5060012}},	// [2260] دوق_, _कप्त, aszy, سبري
  { {0xdb030108,0x909b000b,0x1877000b,0x317f000d}},	//   _anné, _פסיק, _צעיר_, _abuz_
  { {0x67bb0093,0xd36f0003,0x91e60001,0xf1b9009b}},	//   _המיק, اهم_, поже, _boš_
  { {0x69c60137,0x6fcb003a,0xa96a07b9,0xf9920012}},	//   nkke, _tücc, сида_, عبا_
  { {0x6d44115c,0x859b0009,0xb0330024,0xc7b80024}},	//   mbia, _השכו, еніш, оґа_
  { {0x6d440010,0xdb03000e,0x3f98115d,0xa8570009}},	//   lbia, _enné, ndru_, לינה_
  { {0x3a24007d,0x63b8022d,0x6146115e,0x32060132}},	//   _timp_, _rovn, _нева, ploy_
  { {0x6fcb003a,0xda5b0009,0x99500064,0x86c30012}},	//   _müca, _לכלל, lúži_, عيين
  { {0x69dd0061,0xc3340009,0x4df10011,0x71730012}},	//   èrem, ֽוֹ_, ँकड़े_, _سهلا
  { {0x883b000b,0x7de50010,0xfbaa00fa,0x88570009}},	//   _לתמו, lėst, стий_, _משמע_
  { {0x7f3b000b,0x443f029f,0x11d90012,0x28cf0011}},	//   _העבו, apu_, قودة_, सैनि
  { {0x7c3a0030,0x61e2115f,0x3f980764,0x394d01e3}},	//   _čtrn, niol, edru_, úes_
  { {0x76550002,0x859b0009,0x1da90011,0x77bd01a0}},	//   wszy, _לשאו, कारत, _tèxt
  { {0xb7bd007d,0xfbcf0003,0xcce50003,0x8c180012}},	//   _puţi, _متى_, _تسمي, _بيتر_
  { {0xdb7b0093,0x4b7b007e,0x6b950416,0x64400070}},	//   _הנוכ, _האוו, _razg, lpmi
  { {0x76550002,0x69c60052,0x644a0034,0x9f470064}},	//   rszy, ckke, ćfin, rnné_
  { {0x99f8000b,0x39780003,0x7de50010,0x57f502ca}},	// [2270] _מזהה_, _رصيد_, dėst, _опит
  { {0xbca4000a,0xa3d70037,0x76550002,0x394d1160}},	//   عملي, ़ों_, pszy, _sees_
  { {0x6602000e,0x6b95003a,0x6d441161,0x9f7a0009}},	//   _okok, _vazg, bbia, _ונתח
  { {0x68e20010,0x27e30070,0x9f5c01a0,0xe6640024}},	//   _žodi, lijn_, lovè_, _ятьо
  { {0x759a0009,0x31580009,0x859a0009,0x394d005e}},	//   _וסרג, ליאן_, _ושרו, _vees_
  { {0x4639003c,0x394d0227,0x8b070030,0x10a20024}},	//   очия_, _wees_, _jiří, тишн
  { {0xc3320093,0x6d4f00b6,0x9f5e0025,0x1da90011}},	//   _יום_, _keca, ôté_, कालत
  { {0xf19404b3,0x248d0002,0x7c271162,0x6e380031}},	//   _пись, twem_, _hijr, _évbe
  { {0x6f090030,0x6d4f1163,0x657b0032,0x572700ae}},	//   řech, _meca, rfuh, _فراق
  { {0x0ae90015,0x69cd0051,0x3e57004b,0x999f0073}},	//   ждой_, _alae, păt_, kstų_
  { {0x7c2f1164,0x198a00f5,0xd7580012,0x53360009}},	//   _lucr, обни_, _رجلا_, ונתן_
  { {0x65150003,0x71da002d,0x88e600b3,0x96fa0009}},	//   _قوائ, ієнт_, джме, _ולעת
  { {0x69c60006,0xc1560009,0x66090060,0x999f0073}},	//   rkke, ושרו_, mlek, estų_
  { {0x02450012,0x66091165,0x8b030030,0x61e21166}},	//   _قَتَ, llek, ářsk, ziol
  { {0x6d4f0036,0xe80e0011,0x99d60012,0x44271167}},	//   _beca, ितता_, _يتبا, _iin_
  { {0xc9f6000a,0x7e610065,0x661b004a,0x44271168}},	//   _تستع, álpa, nmuk, _hin_
  { {0x1d070001,0x6d441169,0xe5e50012,0x4376003c}},	// [2280] дети_, rbia, رثفي, дует
  { {0xabaa0003,0x7d060010,0x836a0012,0x4cc80009}},	//   غهام_, _vyks, تصرف_, הֶעֱ
  { {0x6eb50044,0x7549000e,0x7d060002,0x6456004a}},	//   _उपयु, észü, _wyks, ssyi
  { {0x6d4f0480,0xc8ca0012,0xfe9b0009,0x9f5c01bd}},	//   _geca, يوان_, _ויטמ, mové_
  { {0x9f5c014a,0x645d0042,0x91fd0035,0xa3cd0011}},	//   lové_, ásil, krān, रसा_
  { {0x442700a2,0x6602116a,0x661b016d,0x945d0034}},	//   _nin_, _skok, emuk, zyńc
  { {0xd6d0000a,0x6e93002d,0x34b80037,0xc246002d}},	//   طقة_, вищу, ेन्द, _інак
  { {0xd5b0000a,0x27e30227,0x68f6116b,0x4427116c}},	//   افة_, zijn_, _oxyd, _ain_
  { {0x9f5c00d9,0xbdf70012,0x1b4a0012,0xc5f70012}},	//   hové_, بروا_, يؤدي_, بعوض_
  { {0xdfa6000a,0x3946007a,0xa3d80037,0xe8d7000b}},	//   _تحري, lbos_, ठों_, _חומר_
  { {0xbcfb116d,0x2fd70012,0x9f5c0042,0x63bc116e}},	//   _idée, _تولد_, jové_, _morn
  { {0x4427116f,0x7dc30051,0xf6690003,0xb257000b}},	//   _ein_, _tõsi, _رحمه_, ובטח_
  { {0x27e30070,0x44271170,0xeb9a003c,0xa0c50012}},	//   tijn_, _fin_, _мид_, ريسو
  { {0x6d4f00c6,0x73c40012,0x9f5c0030,0x91fd0035}},	//   _seca, _سيعم, fové_, ntāz
  { {0x442f0052,0x12b30012,0xabfb0009,0xd5bb03e2}},	//   _zug_, _لإيج, _והגר, оса_
  { {0xdb18014a,0x8e970009,0x44271171,0x999f0073}},	//   _nové, ודלו_, _zin_, rstų_
  { {0x84150014,0x6d4f001e,0x42180012,0x27e30227}},	// [2290] емах, _veca, _تزوج_, pijn_
  { {0x44271172,0x2fc70020,0xcc77000b,0x60c01173}},	//   _xin_, _ông_, וגמת_, ämme
  { {0xddc3000d,0x2a6c009b,0x9f5c08ca,0x6d4f06a7}},	//   nunţ, nudb_, cové_, _teca
  { {0x28c60044,0xeab00012,0x471a0009,0x6d5d0040}},	//   रैकि, جعك_, _מותג, _udsa
  { {0xdd3a0093,0xf1b40009,0x52ca0011,0xb53a0009}},	//   _מערכ, כסף_, ानुस, _מגרש
  { {0xa6950046,0xdfd10003,0x63bc0864,0xe73900bb}},	//   ериј, طيع_, _gorn, чек_
  { {0x44271174,0x6b68000e,0xed590015,0x77360012}},	//   _rin_, ségü, пой_, ركيز_
  { {0x9f580029,0x44271175,0xa87b0012,0xbbb90011}},	//   vorí_, _sin_, _وحذر_, ेस्क
  { {0x6609006f,0x661b00b6,0x0efc0011,0x9f5c00d9}},	//   rlek, rmuk, _एड्स_, zové_
  { {0xe3b1000a,0x78a60028,0x02ca0037,0x9f580029}},	//   ارة_, _ákva, ानून, torí_
  { {0x8c1c0009,0x1309003c,0xdb1a0032,0x63b80248}},	//   חוזי, яной_, chtü, övni
  { {0x7e9a0093,0x44271176,0x7643020d,0x9f5c06dd}},	//   _מסעו, _win_, mpny, vové_
  { {0x44271177,0xdb030002,0x2ec80011,0xa3c40011}},	//   _tin_, _ponó, रन्त, ौसम_
  { {0x4cba0093,0xa5bb000f,0x9f5c0042,0x44271074}},	//   _מזנו, _fiók, tové_, _uin_
  { {0xb9070044,0xa3ae0037,0x39460010,0x2d991178}},	//   _ये_, कास_, ybos_, _base_
  { {0xceb2000b,0xdb1c0061,0x9f5c0042,0x2d990936}},	//   נין_, _forê, rové_, _case_
  { {0x91690020,0x62870039,0x7de80066,0x9f5c0042}},	// [22a0] _gửi_, _apjo, měst, sové_
  { {0x61e6003a,0x395f000d,0x2d990132,0xa87b0009}},	//   likl, _adus_, _ease_, _צריח
  { {0x599a000b,0x160f0037,0x63bc0052,0xa99a000b}},	//   ּשְׁ, ातार_, _vorn, ּבְר
  { {0x78a41179,0x2d990032,0x249f0097,0x61e6117a}},	//   _kriv, _gase_, kvum_, nikl
  { {0xa927007c,0xb3460017,0xe89400be,0x61e60051}},	//   ніше_, niçõ, таль, iikl
  { {0x6d56117b,0x80a30012,0x2d99117c,0x6444117d}},	//   laya, امون, _zase_, mpii
  { {0x8e2600de,0x61e60b02,0xaade0011,0x628b0034}},	//   нфид, kikl, _फेंक, łgor
  { {0xceb30093,0x3f9a0039,0xa3ae0037,0x39490028}},	//   ריה_, _lapu_, काव_, ðast_
  { {0x61e6117e,0x6444008e,0x53e60842,0x31570009}},	//   dikl, npii, ецна, _רימן_
  { {0x3c77000b,0x3a2900b6,0xb3460017,0x6d560a60}},	//   עתים_, _siap_, diçõ, haya
  { {0xd257002d,0x6d560160,0x61e603ad,0xe1d50024}},	//   нця_, kaya, fikl, вжнь
  { {0xab64003a,0xa1940024,0x7df3004b,0x60120097}},	//   ldüğ, гаюч, păsa, væma
  { {0xdd8f000a,0x7dca00f1,0x6d5602a0,0x8c43004c}},	//   _دون_, _výsl, daya, _бече
  { {0xb4be0037,0x2ca0006f,0x20050029,0x7aeb000e}},	//   ीनी_, dvid_, ôli_, áltá
  { {0xdb9b000b,0x3a2900b6,0xdb15117f,0x78a400ff}},	//   _מסגר, _tiap_, _pozí, _eriv
  { {0x32530098,0x6d560101,0x3ebe00e5,0x49740048}},	//   _свър, gaya, ätta_, _блъс
  { {0x24f80015,0x51fc0009,0x2d991180,0xa4d40024}},	// [22b0] енты_, _מההצ, _vase_, готі
  { {0x1cb80012,0x799d07c2,0x000000c4,0x000000c4}},	//   راقب_, ldsw,   ,
  { {0x6d560160,0x20030010,0x2d991181,0x07360009}},	//   baya, moji_, _tase_, _באתם_
  { {0x2003003a,0x7dde09d4,0x66ee0031,0x645d0031}},	//   loji_, būsi, sőké, ásik
  { {0xe72e0014,0x7dda0066,0xa3ae0037,0x71d80009}},	//   ие_, růst, काश_, עודד_
  { {0xdee50046,0xa01b0028,0xf838000b,0x660d1182}},	//   коли, stöf, ענות_, llak
  { {0xa3ae0044,0x17980009,0x34c90011,0x60c60064}},	//   कार_, גדול_, िन्द, zykm
  { {0x4c850015,0xb4be0011,0xcee80012,0xc485052c}},	//   влив, ीनू_, عرون_, влик
  { {0x91a9001a,0x660d02a0,0x61e61183,0xc8e00011}},	//   _giả_, ilak, vikl, _पेंट
  { {0xf7700003,0x20030010,0xe4c80012,0xd7590012}},	//   _هام_, joji_, عبين_, _آلات_
  { {0x6d560101,0xc64b0003,0x27e709d8,0xeb920009}},	//   yaya, _رجال_, minn_, בָר_
  { {0x27e71184,0x60160017,0x5ee80009,0xb3460018}},	//   linn_, râme, _אַנְ, tiçõ
  { {0xc952000b,0x6d491185,0x320200d9,0x69cb0227}},	//   סמך_, mbea, roky_, ikge
  { {0xb3460017,0x2003009b,0x290c001e,0xa856000b}},	//   riçõ, goji_, āda_, כישה_
  { {0x52b20003,0xb3460017,0x07a30001,0x26c70010}},	//   _نموذ, siçõ, јасн, nyno_
  { {0x660d002c,0x799b0070,0xac9a0012,0x69cb0227}},	//   glak, _nauw, ونزا_, jkge
  { {0xa3ae0037,0x27e70028,0x91fd001e,0x645b0025}},	// [22c0] काल_, kinn_, krāj, nsui
  { {0xa3dc0044,0x201a000a,0x7c2a0054,0xfaa60109}},	//   तों_, _تتبع_, _xifr, казо
  { {0x6d560175,0x660d000e,0x799b0052,0x64440269}},	//   paya, blak, _bauw, spii
  { {0xd5af002d,0x442a00b6,0x7aba0009,0x645b019a}},	//   _всi_, _wib_, וצעו, ksui
  { {0x27e70028,0xf7720003,0x76410073,0x629e0030}},	//   finn_, لاغ_, _atly, _ápov
  { {0x14d7000b,0x27e710c7,0xda660012,0xe123004c}},	//   _יוכל_, ginn_, _لاري, јмљи
  { {0x7dc30051,0xab64003a,0x539b000b,0x6566000e}},	//   _tõst, rdüğ, _קילו, ókho
  { {0x6b9c00c6,0x69cb008b,0x6604004a,0x2bca0037}},	//   _harg, ckge, noik, िस्थ
  { {0xb4cc0044,0xb4be0044,0xdb0a0061,0x60120097}},	//   रने_, ीने_, _infé, væmn
  { {0x67450013,0x799b0002,0x43940001,0xc3320009}},	//   čují, _zauw, ћанс, יו֙_
  { {0xa3e30037,0x6b9c1186,0x5d860012,0xe7f60011}},	//   _नगर_, _marg, _للال, ँचना_
  { {0xdb1c10b7,0x799d0227,0x245d0030,0x9e770009}},	//   _coré, udsw, námý_, _יגבה_
  { {0xf9930009,0xc8670048,0x20031187,0x50670048}},	//   ברר_, ътни, toji_, ътна
  { {0x5ba30098,0x9f580029,0xa3e10011,0x3f850064}},	//   _връз, torá_, नोद_, ýlu_
  { {0x660d000f,0x9e07007c,0x27ed001c,0x6d5d0097}},	//   tlak, вчал, đen_, ðsag
  { {0xa2630020,0x27ed000e,0x59670014,0x95c50012}},	//   _muố, ően_, _ръка, ديره
  { {0x660d00c6,0x08fb0003,0x24580015,0x9d1500de}},	// [22d0] rlak, _ترغب_, кать_, удач
  { {0x9cd7000b,0x6b9c1188,0x6fb50012,0x92eb0012}},	//   דומה_, _carg, _إمدا, وراق_
  { {0x6b9c0778,0x69c00227,0x6fcb0032,0x65620064}},	//   _darg, _bome, _lück, _odoh
  { {0xa1150003,0xa3d70011,0xcad70009,0x27e70032}},	//   هوات, ़ोज_, כובת_, winn_
  { {0x27e70065,0x6b9c0119,0xa3c30037,0x30850012}},	//   tinn_, _farg, _एकल_, التف
  { {0x628a0058,0xe8160011,0xd7f8004c,0x828b0024}},	//   _opfo, णतया_, куј_, _осбб_
  { {0x27e70065,0x2eb40014,0xa263001a,0x645b0132}},	//   rinn_, исъс, _cuố, wsui
  { {0xf1a40001,0x3f910052,0xd2290012,0xf1b9001b}},	//   _крун, hezu_, _أكره_, _pišu_
  { {0x27e70028,0xad9b0029,0x6b9c003a,0xc7f9002d}},	//   pinn_, _akúk, _yarg, _знає_
  { {0xd9cc0037,0xb8f70037,0x60c4004a,0x69c00070}},	//   ास्ट, ान_, äime, _zome
  { {0xdb1c0017,0x39ea0146,0x8bd6000b,0x645b0017}},	//   _poré, едно_, רותו_, ssui
  { {0x6627000a,0xcb120093,0xa06a0001,0x186a00be}},	//   _شراك, מלי_, нама_, нами_
  { {0xa91d007a,0x89da0009,0x8d5a0009,0x6fcb0032}},	//   _pažy, תחרי, _נכסי, _küch
  { {0x3a2d0227,0x5a951086,0xed59001b,0xdee60545}},	//   _liep_, _бриф, laž_, гоги
  { {0xa2630020,0xf7430014,0xcb56000b,0x7dca0028}},	//   _xuố, сесо, _עסקה_, _hýsi
  { {0x29560014,0xa01b000e,0x63b50010,0x2d9f1189}},	//   _съкр, gtöb, šanč, ndue_
  { {0x6da30014,0xb8860066,0xd4670136,0x5baa01c6}},	// [22e0] щита, _kníž, лите_, нкам_
  { {0xa01b004a,0xc053000b,0x6604004a,0x69c0118a}},	//   ttöe, _הזז_, soik, _some
  { {0xc3320093,0x7dca0028,0x69c00a16,0x63bc118b}},	//   צוא_, _lýsi, _pome, örni
  { {0x6b9c00c6,0x7229002d,0x7db60003,0x1da30011}},	//   _warg, вців_, _إصدا, _खोलत
  { {0x2d9200a2,0xd7e6002d,0x6fcb0052,0x17540fbb}},	//   meye_, ліко, _büch, авля
  { {0x6fcb008b,0xccab000b,0x69c0002a,0xc059002d}},	//   _rück, _אֱלֹ, _wome, тії_
  { {0xa263001a,0x96f80015,0x25a00051,0xb765002d}},	//   _quố, ъект_, odil_, ртій
  { {0x7a8b000b,0x25a00051,0x1d340014,0xd5b3000b}},	//   _אָמַ, ndil_, шния, ֶׁת_
  { {0x2480118c,0xf746118d,0xa3ae0011,0x9876004c}},	//   ntim_, _безо, काऊ_, _љубљ
  { {0x54330003,0xe47b000b,0x66da003c,0x14d70009}},	//   حرير, עריכ, _пьер_, טופל_
  { {0x0bb7000b,0x2d92003a,0x3f910027,0x7ac605fb}},	//   אלים_, keye_, vezu_, успе
  { {0x2e160003,0x7dde001e,0x4a5b0009,0xc2b70024}},	//   _صباح, gūst, עדכו, улює_
  { {0xc0ab0012,0x506401c6,0x2d92118e,0x3f91001b}},	//   راحل_, йтра, deye_, tezu_
  { {0x7d060051,0x749b0009,0xed590073,0xddc70159}},	//   üksu, _ניופ, _žž_, dujš
  { {0xa6f8000b,0x3f910027,0x62980027,0xa3ae0011}},	//   דִּי, rezu_, _usvo, काई_
  { {0x4a7b000b,0xb8860029,0xf9930012,0x6dc4003c}},	//   _נרחב, _zníž, _طبع_, бсуж
  { {0xdb6b002d,0x8c250012,0xcb55004c,0x3a2d0227}},	// [22f0] ерел_, لفره, иваћ, _riep_
  { {0x25a0118f,0xcb680a36,0x000000c4,0x000000c4}},	//   adil_, лађе_,   ,
  { {0x17f80003,0x82a70015,0x7f3a0009,0x24801190}},	//   _حرية_, ышае, _בעתו, atim_
  { {0x9f470061,0xe45f0028,0x69cf0030,0xe1ee0024}},	//   miné_, _tvö_, nkce, іг_
  { {0x3f9e00b6,0x24800132,0xbcfb0025,0x25f40011}},	//   _batu_, ctim_, _idéo, ्करी_
  { {0xf7710003,0xdcfd001e,0xa858000b,0x6d4d0227}},	//   زات_, _lasī, ריגה_, lbaa
  { {0x45d50098,0x3f9e1191,0xd7580012,0xf6960012}},	//   ицит, _datu_, اجها_, لنوع_
  { {0xb8860066,0x6d4d0070,0x05a90021,0x2d94003c}},	//   _sníž, nbaa, твий_, брьс
  { {0x61eb00c1,0x9c89002d,0x851f0037,0xed5909ef}},	//   migl, ерiа, मेंट_, raž_
  { {0x98170003,0xa2f50009,0x3d1d0011,0x5f740012}},	//   _إبرا, ֹמֹה_, _मरने_, _هامر
  { {0x6d4d00bd,0xb6040010,0x6b60000e,0xb9c60012}},	//   kbaa, ūšiu, lágí, لقدي
  { {0x78a90119,0x20071192,0x10a6022a,0xdeba0009}},	//   _krev, loni_, аимн, _במעל
  { {0x20070005,0x21a30015,0x76450028,0x9f5c022d}},	//   ooni_, циям, _athy, lová_
  { {0xfe461193,0x61eb00b8,0x6d5b1194,0x20071195}},	//   инго, higl, laua, noni_
  { {0x2d92003a,0xdd920003,0xed5a048c,0x9f5c00d9}},	//   teye_, يوس_, ков_, nová_
  { {0x7bc30028,0x75d60003,0x38600027,0x12fa0009}},	//   _honu, جيرا, širi_, _בהצב
  { {0xd5b70020,0x61fd000e,0x7bc31196,0x2d92003a}},	// [2300] ớng_, érle, _konu, reye_
  { {0xf7460001,0x9f5c0042,0x27ed0025,0x74130012}},	//   _њено, ková_, éent_, قوقا
  { {0x3f9e1197,0x7f5c1198,0xfc3f01e3,0x20071199}},	//   _ratu_, marq, _frío_, doni_
  { {0x3f9e00c6,0x180e0037,0xdb1a038e,0x2251022d}},	//   _satu_, ित्व_, rktø, ázky_
  { {0x4c67002d,0x2715001a,0x2007119a,0x38600025}},	//   _киян_, _án_, foni_, éir_
  { {0x6f09003a,0xc6fa0009,0xcb6a003c,0x26170025}},	//   şece, ֣לֶך, _шаге_, nçon_
  { {0xd1760015,0xfe770012,0x8c2b0009,0x61eb119b}},	//   _вызы, لصيغ_, _יֵלֵ, bigl
  { {0x69d9008b,0x7e610028,0x69c4119c,0xd29b0009}},	//   chwe, álpi, _noie, _בשלט
  { {0x62810002,0x030b0037,0x05730012,0xdb0a0032}},	//   etlo, _सुबह_, زايد, _wofü
  { {0x66e60339,0x9f5c0042,0xa87b0009,0x8e200024}},	//   _коза, bová_, _באמר, хiв_
  { {0x1fb5005c,0xe7370015,0x442e0025,0x69c4004b}},	//   _устр, _тех_, _vif_, _boie
  { {0x09f90003,0x92570015,0xd378001b,0x69cf0a86}},	//   افحة_, шают_, viću_, ukce
  { {0x90981103,0xa3e70037,0x10740109,0x645d119d}},	//   авят_, _बगल_, оляю, ásit
  { {0x92170011,0xad1b0009,0x628e0227,0xc8840060}},	//   _धीरज_, _סוגר, _opbo, mağı_
  { {0x6d4d0070,0x8c1b000b,0x63bc0028,0xdb23003a}},	//   tbaa, _שווי, örnu, ürün
  { {0xcdd80046,0xaabb0009,0x26170025,0xd6d90034}},	//   ању_, _יזוכ, açon_, ął_
  { {0xdce600a2,0xc884003a,0x61eb00c1,0x7f5c119e}},	// [2310] _bakı, nağı_, vigl, barq
  { {0xd795000a,0x2fe40012,0x92a7004c,0x2b58004b}},	//   _الدخ, _وكيف, ијел, _cerc_
  { {0x644600a2,0x99350012,0x6d4d0227,0x69d9119f}},	//   _etki, مفات, pbaa, thwe
  { {0xf9930003,0x7dd80066,0xd1670048,0x8e960009}},	//   تبط_, _píse, ръжи, _פדרו_
  { {0xcdb6000b,0x9f47004a,0xa98c0009,0x98a50aa2}},	//   _הפרה_, ynnä_, דָוִ, силе
  { {0xec36000b,0x9f5c01bd,0x2ba60011,0xfba60011}},	//   _לאשר_, tová_, _कोला, _कोलम
  { {0xe61f0081,0x24950060,0x6f7a0009,0x6b600031}},	//   _khô_, şamı_, רְנו, ságí
  { {0x7bc300a2,0x44390005,0xa3b50044,0x29f8009b}},	//   _sonu, _kus_, झाव_, nčal_
  { {0xdce600a2,0x443911a0,0xcdb8000b,0x9f8f003a}},	//   _yakı, _jus_, שפחה_, _güç_
  { {0xa3e10044,0x3cff0044,0x69c40061,0xe2990001}},	//   नों_, _रखने_, _soie, гао_
  { {0x11d6000a,0x15f90037,0x9f51000e,0x644911a1}},	//   متحد, ्कार_, hozó_, spei
  { {0x9f51000e,0x44390007,0xf9920012,0xd9f70011}},	//   kozó_, _ous_, أبد_, ंचित_
  { {0xc884003a,0x69c4042f,0xf5360009,0xd46911a2}},	//   cağı_, _voie, _הנני_, _силе_
  { {0x7bda03e4,0x6d5900b6,0x7dca0028,0xa01b004a}},	//   chtu, _hewa, _lýst, ttöa
  { {0x4439032b,0xdb180272,0x1ddb0037,0xf99f0054}},	//   _aus_, _tová, _बतात, glès_
  { {0x4439007a,0xf5b5002d,0x41e50012,0x44310035}},	//   _bus_, осую, _وسيف, _aiz_
  { {0x5b360003,0x443111a3,0x2b58000e,0x6d5900b6}},	// [2320] معار, _biz_, _perc_, _mewa
  { {0x6d5900b6,0x2f560538,0x10bb0009,0x443911a4}},	//   _lewa, _утис, _עזיב, _dus_
  { {0x44310149,0x63060003,0x7dd80028,0x80250012}},	//   _diz_, حوال, _vísb, _بريم
  { {0xda650012,0xc2360009,0x11760012,0x60120097}},	//   زامي, צרנו_, إطاح, dæmi
  { {0x1cba0003,0xdce6003a,0xc7c60104,0x443911a5}},	//   _صاحب_, _takı, йски, _gus_
  { {0x161c0037,0x7dd50028,0xd3ba002d,0x61e911a6}},	//   _भीतर_, _rása, _сумі_, _emel
  { {0x8f9b000b,0xe0df00b8,0x2fc50159,0x91fd0035}},	//   ריצי, zzò_, _dolg_, nsāc
  { {0xceb3000b,0xd6d9002d,0x1af7000b,0xc884003a}},	//   ליו_, шті_, _המלל_, tağı_
  { {0x6d5900b6,0xdb1c0054,0x200a11a7,0x493b0009}},	//   _dewa, _horà, kobi_, _תגמו
  { {0xcf890003,0xfa6a0009,0x7bda005e,0x91fd0035}},	//   _نضمن_, ְכָּ, uhtu, ksāc
  { {0x51f9002d,0x200a009b,0x9f58000e,0x91fd001e}},	//   иною_, dobi_, ború_, krāt
  { {0x6d590347,0x2e370009,0xc27b0009,0x600d0097}},	//   _gewa, _הראש_, נרכי, búms
  { {0xae1b000b,0x91fd0035,0xb87b0064,0x645d0073}},	//   _עודכ, drāt, dzíc, šsir
  { {0xa3a80037,0xe47b0009,0x443911a8,0x3ce00159}},	//   _खोल_, _ערוכ, _rus_, dziv_
  { {0xe246000a,0xd35b0093,0x443911a9,0x8a460003}},	//   _اختي, _גדול, _sus_, _ائتم
  { {0x443100a2,0x8e15002d,0x0615002d,0xca470003}},	//   _siz_, ідац, ідаю, _اليه_
  { {0x91a90020,0x320b0002,0xd1310012,0x71f80012}},	// [2330] _giá_, mocy_, _تمة_, _دروس_
  { {0x61e9014d,0x660900bd,0x6fd00052,0x44d4001a}},	//   _smel, zoek, _näch, ì_
  { {0xfbd00003,0xe5350015,0x2b580034,0x3ce0001b}},	//   رتك_, _мень, órcy_, aziv_
  { {0x443902d1,0x7dd10058,0x60120028,0x3264002d}},	//   _tus_, _måsk, væmi, ятув
  { {0x44390005,0x8934000a,0x229a001e,0x718c000b}},	//   _uus_, أعما, _lūk_, רְבַ
  { {0x61ef11aa,0x644d11ab,0xae990012,0xd6a90012}},	//   hicl, mpai, لضبط_, لدعم_
  { {0x644d004a,0x2fc50070,0x9f580029,0xa01b11ac}},	//   lpai, _volg_, torú_, ytön
  { {0x2d8a000e,0x59f90015,0x307b0003,0x61e911ad}},	//   őben_, _тебя_, _محطة_, _umel
  { {0x44390017,0x644d008e,0x6fd00032,0x7bc7005e}},	//   ês_, npai, _fäch, _koju
  { {0x64980098,0x7ff70003,0x3a20002a,0xdb1c11ae}},	//   стър_, _اسرا, _ship_, _horá
  { {0x44d40020,0xdb1c000e,0x6d5900b6,0xf8a90009}},	//   à_, _korá, _tewa, _שש_
  { {0xee2e002d,0x6fd0006f,0x6285002a,0x8ed80012}},	//   _ін_, _täck, itho, _اذكر_
  { {0x349402e3,0xf74609f8,0x7bf90a32,0xa01b11af}},	//   _нацр, жего, _кндр_, rtön
  { {0x2329059a,0xc2c50012,0x8c420060,0x3a200132}},	//   _коли_, _ويشي, üğme, _whip_
  { {0xa01b0028,0x539a000b,0x443f0061,0xdced001e}},	//   mtöl, _כיסו, lqu_, adaļ
  { {0x7dd5000f,0x69dd008b,0xa01b000f,0x78ad03ee}},	//   _máso, chse, ltöl, _frav
  { {0x7dd80066,0x8e200024,0x44660024,0x2f230025}},	// [2340] _císa, цiй_, ював, tégé_
  { {0xab66002d,0x14170003,0x798d0034,0xe3b703cc}},	//   івел, قيقة_, _zbaw, обу_
  { {0x5fb7000b,0xe29a0014,0x78ad009b,0x2ca90051}},	//   _והיא_, рае_, _zrav, avad_
  { {0x9f990028,0x44d40081,0x6fd00032,0x7ddc0031}},	//   láðu_, ỳ_, _säch, _kése
  { {0x91a00020,0xc0960003,0xa3da0011,0x224d0159}},	//   _chỉ_, تجات, ़सद_, _čeke_
  { {0x3cff0044,0x6fcb003a,0x3f98029f,0x6d4400b8}},	//   _रखते_, _hücr, neru_, lcia
  { {0xcdda004c,0x6e430012,0xfa6711b0,0x6d4411b1}},	//   ињи_, ونوم, _марк_, ocia
  { {0x39420005,0x85480010,0xa01b000e,0x7bc70070}},	//   _üks_, brėž, etöl, _zoju
  { {0x2249009b,0xa01b0097,0xa3c80011,0xad9b0064}},	//   _čaka_, ftöl, ैसल_, _zkús
  { {0x69c20070,0x657b002c,0x3f9811b2,0x63a311b3}},	//   ljoe, aguh, jeru_, _cann
  { {0x8c1b000b,0x61ef11b4,0xdfcf0012,0x8ae30024}},	//   שויי, ticl, _جيل_, діял
  { {0xa01b004a,0x51f8003c,0x78ad11b5,0xc4c600ae}},	//   ttöo, жнюю_, _prav, _وتشو
  { {0x2d87000e,0x7dd50004,0x09070024,0x3f980eb3}},	//   őnek_, _záso, ючом, feru_
  { {0x7ddc0061,0x80270003,0xa3ce0011,0x6d4611b6}},	//   _dése, ترجم, _रवि_, _afka
  { {0xbcfb0017,0x9f34002d,0x33770009,0x63770009}},	//   _idéi, дері, _ותוך_, _וגוף_
  { {0x7dd50145,0x7dd8119d,0xd5b8112d,0x29d70060}},	//   _násl, _písa, осу_, _açan_
  { {0xad9b0026,0x61ed0027,0x04590003,0x71880009}},	// [2350] _skús, _imal, صلاة_, _וְתַ
  { {0xdb1c000e,0xa3e50037,0x57f40015,0x7dd80028}},	//   _sorá, बों_, _опыт, _vísa
  { {0x61ed009b,0xe298002d,0x539b000b,0x979a000b}},	//   _kmal, жає_, שיבו, _השתק
  { {0x6d4400c1,0x7df3000d,0x628511b7,0x02fb0009}},	//   ccia, năst, rtho, סלאמ
  { {0x55ba0093,0x6d5d0039,0xadc3001a,0x98f40012}},	//   _המרו, _iesa, hoản, وثها
  { {0x6d5d00a1,0x05a30037,0x1da30011,0xb659003c}},	//   _hesa, _खोजब, _खोजत, бших_
  { {0x6d5d00c6,0xcf58000b,0x61ed0038,0xf4120009}},	//   _kesa, חבות_, _omal, _נפל_
  { {0xbca50003,0xb2220028,0x96fc000b,0xe7080003}},	//   كمبي, áætl, ילות, غتون_
  { {0x2bb90003,0x9627001e,0xa01b004a,0xb4d50037}},	//   مادة_, _izņē, ttöl, सने_
  { {0x7ddc0108,0x95f90011,0x33d40024,0x5f440012}},	//   _rése, ्कुट_, діют, _ينقل
  { {0x443f0108,0xe8e10020,0x2fe40003,0xa01b0028}},	//   squ_, _đều_, _تكلف, rtöl
  { {0x63a300bd,0xdb1c0058,0x6d5d11b8,0xa01b11b9}},	//   _wann, _foræ, _nesa, stöl
  { {0x5d3a000b,0xe4490003,0xe20b0028,0x9f43004a}},	//   _התנא, _التى_, _slóð_, kijä_
  { {0x2bbb000a,0xa01b008e,0x64a20048,0xddc30073}},	//   _خاصة_, ltöj, _чаша, ksnū
  { {0x9f990065,0x6d5d11ba,0x7c3d0052,0xa3b50037}},	//   ráðu_, _besa, _ausr, झाई_
  { {0xa01b004a,0x60120028,0xf0660103,0x6df60012}},	//   ntöj, væmu, _екип, أكرا
  { {0xdd8f0003,0x75d30003,0x99920010,0xe97b0009}},	// [2360] طول_, ريكا, ūzų_, _הנפש
  { {0x69db0006,0x6d4400c1,0x66160623,0xe81b0011}},	//   _alue, scia, slyk, _पीला_
  { {0x8c1a000b,0xcf57000b,0x7f3b000b,0x17570009}},	//   צועי, _מבית_, _לעיו, _מסיר_
  { {0x6d5d008b,0xf3f1001a,0x79a30021,0x20180028}},	//   _gesa, hị_, ерше, llri_
  { {0xf5370093,0x6e290051,0x2d82006f,0x60160017}},	//   _מרכז_, dmeb, _icke_, lâmi
  { {0x9f5c0029,0xd0100003,0x56940247,0xf8670012}},	//   lovú_, خلت_, дакт, أموي_
  { {0xcf260003,0x60160017,0xc7b30009,0xa6c80012}},	//   أرشي, nâmi, תבו_, توغل_
  { {0xade3007c,0x21a30146,0x8afb0009,0x9f5c0064}},	//   ецьк, _писм, _ההלי, novú_
  { {0xdb1c003a,0xbf360012,0x65600097,0x9f94008e}},	//   _borç, _فراغ, ramh, _kää_
  { {0xa01b004a,0x6560006f,0x9f5c0029,0x61ed11bb}},	//   ttöm, samh, hovú_, _smal
  { {0x9f5c0064,0x6b670031,0x394601e3,0x9f94079b}},	//   kovú_, légí, ocos_, _mää_
  { {0x2617003a,0x394611bc,0x9f470018,0x3ddf0227}},	//   rçok_, ncos_, miná_, chuw_
  { {0xdb1c0e23,0x7dd80066,0x7de50012,0x9d1a0012}},	//   _forç, _písn, _تسلم, _ازاء_
  { {0x4c9b000b,0xa5bb001a,0x7a230051,0x6d5d0a12}},	//   _לבדו, _chón, mõte, _sesa
  { {0x6d5d11bd,0xbc1b0009,0x7c3d11be,0xd61b0012}},	//   _pesa, _הוגש, _susr, مترا_
  { {0x42fb0093,0x12fb0009,0xa6340024,0x52830012}},	//   _להוס, _להוב, енсі, _أليك
  { {0x4c940189,0x64400c04,0x82340012,0x50f50024}},	// [2370] нитс, _émil, _ثروا, _ізот
  { {0xd3710003,0x394601e3,0x2d820032,0xdd9906dd}},	//   ئها_, ecos_, _ecke_, zeň_
  { {0xdb580015,0xdd0c0002,0x38690028,0x69da0010}},	//   яют_, góło, _hvar_, _įter
  { {0xd131000a,0x386911bf,0x61fd0028,0xc333000b}},	//   نما_, _kvar_, nnsl, גוע_
  { {0xc0c80001,0xdd990042,0x28f80024,0x186904d6}},	//   зује_, veň_, пець_, цали_
  { {0x25a9000e,0x94ba000b,0x27c7003c,0x945d0034}},	//   ldal_, _ומשת, ящег, zyńs
  { {0x56920001,0x92940345,0xe1f30012,0xa01b008e}},	//   вајт, _парц, _كسر_, ttöj
  { {0x96270039,0x56b80093,0x26dc000b,0x533402d3}},	//   _uzņē, לפון_, מקומ, _чест
  { {0xea00001a,0x248911c0,0xdd990029,0x7dd50028}},	//   _ngại_, ntam_, reň_, _hásk
  { {0xa3e9002d,0x320f11c1,0xcad50009,0xa01b008e}},	//   ідна_, logy_, ֥וֹת_, stöj
  { {0x3ed5000a,0xfe700003,0xf3f1001a,0xdcee001e}},	//   _تقار, _مدن_, rị_, ādāj
  { {0x7dd5000e,0xa01b004a,0x5e440012,0x04950012}},	//   _másk, ltöh, _أَنْ, _يلاح
  { {0xa5bb001a,0xb87b000e,0x25a9000e,0x644b07a8}},	//   _phón, szín, ddal_, _utgi
  { {0x0c24007c,0xe8200037,0x94040012,0x62950227}},	//   _змін, यतया_, _كونه, _opzo
  { {0x16a70098,0x2cad002a,0x6b9c005e,0x9f5c0064}},	//   мври_, lved_, õrge, tovú_
  { {0xcb120093,0xe61a002d,0xc692000b,0x7b03000d}},	//   _שלה_, іда_, כאל_, ăută
  { {0x39a6039c,0x9f94004a,0xa00a0012,0x9f5c0064}},	// [2380] _jūsų_, _pää_, _وقبل_, rovú_
  { {0x39a6007a,0xafdb038e,0x2cad002a,0x9f5c0029}},	//   _mūsų_, spør, ived_, sovú_
  { {0x67bb000b,0xd7bb0009,0xbe660012,0xa5bd0073}},	//   _ומיק, _וציר, _تهجي, rmųj
  { {0xe61a0024,0xa01b008e,0x38660031,0xa1ba0012}},	//   _фдм_, ytök, tsor_, غطاء_
  { {0x395f0c56,0x5fd20011,0xd59b0009,0x6d9b0009}},	//   _deus_, _हवाल, _ובכל, _ובכפ
  { {0xb033007c,0x7a230051,0x77630054,0xdfd00012}},	//   вніш, võte, ganx, طيب_
  { {0x2cad002a,0x61fd0028,0xa3b10037,0xdaba0003}},	//   eved_, ynsl, _ऑफ़_, _ظهرت_
  { {0x6564004a,0xa01b11c2,0x26130018,0xdb080025}},	//   naih, ttök, dãos_, _élép
  { {0xd49a002d,0x23830028,0xc0460012,0xff760012}},	//   іри_, _þrjá_, _آخرو, _يُرج
  { {0x7ddc0108,0x6f0d003a,0x9f580029,0x4e960003}},	//   _désa, şaca, torý_, _يشار
  { {0x33770214,0x0377000b,0xc7b3000b,0xdb030028}},	//   ועים_, ותית_, _שבע_, _ennþ
  { {0xc3330093,0x2b5100a2,0x61e201fb,0x22ac0030}},	//   כות_, ızca_, nhol, _věk_
  { {0x7dd10163,0xe4d60012,0xe4ea0012,0xa01b008e}},	//   _måst, _تتاب, _بعضه_, ltöi
  { {0x251b0009,0xbb840012,0x7dd10d77,0xad1b00af}},	//   _וודא, _ألغي, _låst, _וודר
  { {0xe613000a,0xb595096e,0x637b0009,0x40340bd8}},	//   نشر_, нивш, _ונוד, терс
  { {0x63a7000f,0x2489000e,0x443811c3,0xe5730012}},	//   _sajn, ttam_, _air_, ضطر_
  { {0x443800a1,0x61e200c5,0xb4d90037,0xd7e7002d}},	// [2390] _bir_, dhol, ़ने_, _жіно
  { {0x395f0e23,0x6fd40054,0xd8380a3d,0x1b7b0012}},	//   _seus_, _fàci, _nič_, تصرة_
  { {0x1756000b,0x2cad001e,0x97560009,0x0f560009}},	//   _אסתר_, zved_, _איתו_, _איתם_
  { {0x3ebe0033,0x20110027,0xda080012,0x7c3811c4}},	//   åtte_, lozi_, ويله_, _livr
  { {0x7b67035b,0x6e2d11c5,0x395f01a0,0x443811c6}},	//   _отве, mmab, _veus_, _fir_
  { {0x44380119,0x187c000b,0x60d80009,0x80a80024}},	//   _gir_, קטוב, וודא_, ьвів_
  { {0x6820000e,0x395f08b6,0xe7360313,0xe80e0011}},	//   ködn, _teus_, неш_, ाक़ा_
  { {0xd738000b,0xd5b10003,0x442c0070,0x6fdd0054}},	//   וטות_, افظ_, emd_, _dèca
  { {0x660200b6,0x60120040,0x91fd0035,0x973c0034}},	//   _djok, kæmp, rsāl, _zaćm
  { {0x7dd5000e,0x2cad11c7,0xddc80035,0xf7480012}},	//   _mási, rved_, ļoša, _يلقي_
  { {0xf412000b,0xd6d10003,0x291e0034,0x7c3811c8}},	//   רפי_, _حقا_, ętam_, _divr
  { {0xc332000b,0x7dd801bd,0xcf890009,0x6fd401a0}},	//   טוי_, _písm, _לט_, _ràci
  { {0x6c840003,0x26170017,0xea00001a,0x656411c9}},	//   _للنم, nçou_, hiết_, vaih
  { {0xa7da000a,0xd0f6000b,0x661b083c,0x201100c1}},	//   أوسط_, תמשת_, lluk, gozi_
  { {0x4427008b,0x66e60dfb,0x66060048,0x661b005e}},	//   _ihn_, хова, епва, oluk
  { {0xa3a80044,0x78a40051,0x764100b6,0x6da30177}},	//   _खोज_, _tsiv, _muly, лиса
  { {0x91fd0333,0x0c260867,0x9c260867,0xfce30400}},	// [23a0] ksāj, еман, едад, гото
  { {0x08570093,0xf0930009,0x656411ca,0x44270032}},	//   _רבים_, _ענת_, saih, _jhn_
  { {0x2f5b0093,0x443811cb,0xe7320012,0xd2590024}},	//   _מדינ, _vir_, _حصة_, дці_
  { {0x4438008b,0x2a6a000f,0xceb3000b,0xe2160012}},	//   _wir_, ábbi_, _עיר_, رباع
  { {0x6d3b000b,0x661b0d9a,0xba170012,0x61e21101}},	//   _מתכנ, dluk, ريها_, rhol
  { {0x4ea6004d,0xdc8b0009,0x74160012,0xc6a60048}},	//   ериа, _מְלָ, _أوسا, ерии
  { {0x09e6002d,0xfe6f0003,0x877b0009,0x8f7b0009}},	//   _зовн, مدي_, לאסי, לנסק
  { {0x291e0002,0xbef70003,0xe7f20011,0x7bce005e}},	//   ętaj_, عروض_, _अगवा_, _hobu
  { {0xe58b000b,0x09e30055,0x6d8b0009,0x98ab0060}},	//   הָיָ, _сотн, הָיְ, yacı_
  { {0x44380163,0xb8d40037,0x3ea90002,0xa01b004a}},	//   ör_, जट_, łata_, ltöv
  { {0x45e4008a,0x7c380d65,0x442c11cc,0x79820002}},	//   _đượ, _vivr, rmd_, ogow
  { {0x79820002,0x225c0042,0x61360060,0xd6db0009}},	//   ngow, ávky_, _gülü, _מחבל
  { {0xd5e90003,0xf1b30009,0x9f5800b8,0xe1ff11cd}},	//   _تعلن_, אסר_, vorò_, rnó_
  { {0xb8c90044,0x7dd50028,0x29f80029,0xa3e40011}},	//   _गई_, _rási, očas_, _नति_
  { {0xab270001,0x7a3e0010,0x98ab003a,0x6e9400de}},	//   _поља_, _būte, racı_, лиру
  { {0x63aa0065,0x34950015,0x6e2d002c,0x11d70012}},	//   _hafn, кабр, umab, _ستعد
  { {0x7dd80107,0xe4e70024,0xfd130012,0xdfd10012}},	// [23b0] _získ, хівн, اجز_, _نية_
  { {0x63aa0065,0x661b0060,0x7bda11ce,0xdce00412}},	//   _jafn, zluk, nktu, jamč
  { {0xa0360093,0xbb840003,0xf8360009,0x9f8f005e}},	//   _שאתה_, المي, _שנתת_, _müü_
  { {0x9f580065,0x7ae50051,0xdb0e0017,0xd6560009}},	//   lorð_, _ühte, _robô, _שירת_
  { {0xf994000b,0x9914002d,0x7bda0028,0x9f47008e}},	//   טרף_, льші, kktu, yinä_
  { {0x63aa0065,0x62980070,0x36950109,0xf0940009}},	//   _nafn, _opvo, вшис, רנס_
  { {0x97ac000b,0x5f050014,0xd7050048,0x9f47008e}},	//   לֹהֵ, ъзка, ъзки, vinä_
  { {0xa8490003,0x7ddc0061,0xceb4000b,0xf9930012}},	//   _يلزم_, _déso, ריק_, _حبس_
  { {0x661b046c,0x9f5c0042,0x91fd0035,0x6d4911cf}},	//   rluk, lový_, asāk, rcea
  { {0x91aa0037,0x66dc008e,0x67240030,0x7dd80030}},	//   _जोड़े, näkö, řija, _písk
  { {0xd6db0047,0x8d950003,0x7ddc000e,0xb17b0989}},	//   _эта_, _للاش, _késl, rhån
  { {0x9998001e,0xa06a05fb,0x9f47008e,0x186a0a21}},	//   _kurš_, мама_, sinä_, мами_
  { {0x91a0001a,0xd1320003,0x88c70024,0x95c40012}},	//   _chí_, شمس_, вляв_, _حينه
  { {0x9f5c00d9,0xcc760009,0xbc07003c,0xa0a3004c}},	//   kový_, _יענה_, _ячей, јард
  { {0x91a0001a,0xfaa502c4,0x9f5c01e9,0x96630357}},	//   _thì_, _райо, jový_, икре
  { {0x98be003a,0xceb2000b,0x386d11d0,0xc27a0009}},	//   ştı_, סין_, _over_, _חרקי
  { {0xd4670098,0xe7f20037,0x9f580028,0x91fd001e}},	// [23c0] ките_, _अगला_, borð_, zsāk
  { {0xeafa0003,0x987b0009,0x80890012,0x73ac0009}},	//   ورات_, _קריק, _أضيف_, ּיאֵ
  { {0x386d01a2,0x2777000b,0x2905003a,0x74130012}},	//   _aver_, _בגין_, şlat_, جولا
  { {0xe9da002d,0x7ddc0061,0xc332000b,0xe8fa01ec}},	//   ьке_, _réso, בוב_, мле_
  { {0x7bce0010,0xe8940055,0xb8940012,0x88e60048}},	//   _tobu, уаль, التع, ъжде
  { {0xdfcf000a,0xb4de0037,0x25a00061,0x248d0328}},	//   يين_, तनी_, leil_, dtem_
  { {0x386d002a,0x6fdd0054,0x79960002,0x5ea30012}},	//   _ever_, _tècn, _obyw, لمول
  { {0x63aa0028,0xa01b11d1,0xdbe30025,0x27f80032}},	//   _safn, ltöt, _réél, hirn_
  { {0xc5f30093,0xdb010058,0x9987000d,0x64420061}},	//   ידה_, ndlæ, ţiţi_, _quoi
  { {0x32020026,0xa857000b,0x660d009b,0x6e960003}},	//   enky_, _סיבה_, čaka, _للطا
  { {0xe9f9007c,0x51f9002d,0x5b7b000b,0x5a35010c}},	//   енні_, енню_, וריא, лнот
  { {0x91a00020,0xcb130093,0x91a90020,0xadb70012}},	//   _phí_, ילת_, _khả_, _لهما_
  { {0x386d0108,0x5c730024,0x79540012,0x7a0b0034}},	//   éer_, _вліт, شَّا, jęte
  { {0xdb1c03ee,0x92f60012,0x2005005e,0x2480004b}},	//   _forø, _لأعض, õli_, duim_
  { {0x9f58014d,0xc2c30003,0x25a007c9,0x6b9b0009}},	//   rorð_, _نيوي, feil_, _חשוד
  { {0x32530098,0x1dc50011,0x9f580097,0xdb370009}},	//   _твър, वायत, sorð_, _בנוח_
  { {0x80be0044,0xf367002d,0x99990010,0xdb0a0192}},	// [23d0] ्हों, втен, ūrų_, _anfø
  { {0xc3540001,0x7c840001,0x7dd50028,0x9f5c01bd}},	//   икуј, јуте, _hást, tový_
  { {0xeb910009,0x8ff80012,0x93880048,0x0b880048}},	//   מָא_, _جرير_, ъста_, ъсти_
  { {0xe7e50037,0x9f5c01bd,0x261701d7,0x27ef0034}},	//   कसभा_, rový_, rços_, żoną_
  { {0x248d0066,0xdfd5003c,0x9f5c0042,0xd5b60011}},	//   xtem_, лоды, sový_, _अफ़ज
  { {0x9f5c0004,0x77840024,0xba770012,0x9f840024}},	//   pový_, иліз, _لارت, игід
  { {0x2f98000b,0x4e950003,0xa01b004a,0xdb1805b1}},	//   דכון_, اشتر, ltös, _pový
  { {0x0696000a,0x7dd500f1,0x248d09c5,0x26c90027}},	//   انية_, _nást, ttem_, ćao_
  { {0xbfab002d,0xb17b006f,0xa01b086e,0x248d11d2}},	//   _отже_, rhål, ntös, utem_
  { {0x7dd80028,0x2003001b,0x03a5004c,0xb17b0248}},	//   _vísi, jnji_, ћино, shål
  { {0x17f80003,0x16030037,0x2003048b,0xdb03000e}},	//   _شركة_, रचार_, dnji_, _taní
  { {0xc7a90009,0x64b50012,0x95570012,0x6e3d11d3}},	//   _מב_, _محتر, _شخصا, _nisb
  { {0x6d5b00c6,0x69cb0227,0x6d5d0097,0x20040018}},	//   mbua, ijge, ðsau, émio_
  { {0x69dd083c,0x291e001e,0x75fe001e,0x443c0572}},	//   akse, āta_, vīzi, _giv_
  { {0xf3f0000a,0x25a00052,0x65ba0001,0x93bc000d}},	//   _بأن_, teil_, нуар_, rmăt
  { {0x290500a2,0x75d60003,0x69dd0052,0xdce0001e}},	//   ğlar_, ديرا, ckse, lamā
  { {0x290500a2,0x037a0003,0xb4de0037,0x25a00061}},	// [23e0] şlar_, فحات_, तने_, reil_
  { {0x3d040037,0x7dd501bd,0x07a6004c,0x35c50011}},	//   _रखीं_, _zást, _саон, वाड़
  { {0xa2a90011,0x232a003c,0xdce40073,0x628111d4}},	//   टिट्, хожи_, maič, nulo
  { {0x7cda0039,0x00e6010c,0xc332000b,0x2247004c}},	//   _pārā, лжен, זוב_, упци_
  { {0xd917002d,0xbddb0061,0x78a9000e,0x8a17000b}},	//   льш_, _sièg, _csev, נחנו_
  { {0x660411d5,0xf1bf000e,0xc4d3000b,0xda660003}},	//   lnik, lmát_, _הגש_, _ماري
  { {0x69dd0006,0x1ae60015,0x63a30051,0x998d0029}},	//   ykse, _совм, õnne, _sieť_
  { {0xa01b006f,0x6446004a,0x91a9001a,0x7bde006f}},	//   ntör, _kuki, _thả_, lkpu
  { {0x71d7000b,0xdce411d6,0x2449001a,0xa3e80037}},	//   _עומד_, kaič, _cúm_, _बता_
  { {0xda7a007c,0x644f0017,0x27f8003a,0xb8f80011}},	//   ням_, ícia, _örn_, ाह_
  { {0xd00f0003,0xa01b03ad,0x644611d7,0xdb0301a0}},	//   _علم_, ktör, _luki, _canà
  { {0xa01b11d8,0x69dd0006,0x15460146,0xe1350015}},	//   ytös, ukse, _седм, инны
  { {0x98b80048,0x2003001b,0xa01b0031,0x5c5611d9}},	//   глят_, tnji_, dtör, _стеф
  { {0xdce0001e,0x7d1d006f,0x6fc70011,0x69dd005e}},	//   camā, _ryss, लायं, skse
  { {0x9f35007c,0x539b000b,0xaab70003,0x628111da}},	//   реві, _ניהו, _مدير_, culo
  { {0xa01b07cc,0xddd5000e,0x5d5502ac,0x6446013d}},	//   gtör, tsző, ркат, _buki
  { {0x55070014,0x200304d2,0xc4540012,0x5f160011}},	// [23f0] учва, pnji_, مضلع, _पुस्_
  { {0x9f4b004a,0x2ef5003c,0x69c011db,0x9cd70009}},	//   äjät_, _взор, _anme, אומה_
  { {0x6604012e,0xdb0300f1,0xddd5000e,0x23740003}},	//   bnik, _kaná, ssző, صالح
  { {0x6d420020,0x316b0002,0xc3330009,0x19950472}},	//   _ngoa, nacz_, צוף_, радя
  { {0x6016007d,0xad9b0028,0x601f0017,0xa9680012}},	//   tâmp, _ljúk, lêmi, امهم_
  { {0x3d180037,0x6c7a0009,0x2d840060,0x6cfa0009}},	//   _पड़े_, _באשפ, _ömer_, _יפרס
  { {0x0f58000b,0x65c50015,0xcee6002d,0x97580009}},	//   ניהם_, ибка, идше_, ניהו_
  { {0xbca50003,0x660d009b,0x9cb50012,0x3e320012}},	//   لمبي, čako, لمعت, يفور
  { {0x6d5b00b6,0xe572000b,0xcd290014,0x629c0066}},	//   rbua, חַת_, ъжие_, _zpro
  { {0xdb1802d1,0xabd50001,0x628111dc,0x9cd80009}},	//   _enví, рциј, tulo, טוחה_
  { {0x2cb8001e,0x09f60003,0x660404f3,0xdce40010}},	//   ārda_, لأحد, ynik, vaič
  { {0xdb070013,0xb1da002d,0xb4950001,0x93bc000d}},	//   _nají, тьох_, _видљ, umăr
  { {0x7dd80013,0x3d040044,0x7a230051,0x93bc000d}},	//   _míst, _रखें_, võtl, rmăr
  { {0x6604003e,0x3075003c,0xa9360009,0x917a0081}},	//   wnik, щуюс, יטרה_, _mẩu_
  { {0x316b003e,0xb7f80037,0x09e6005c,0x9bfa000b}},	//   bacz_, ्चतम_, _войн, _שהצט
  { {0xe9df0029,0x395f0097,0xf5060148,0x4a9a00af}},	//   ckú_, ðust_, азбо, _ייצג

  { {0xa356000a,0x629c11dd,0xe4360012,0x6c360012}},	// [2400] لخاص, _spro, لفرد, لفرا
  { {0x66040416,0xd8db000b,0x6820000e,0x3ff30012}},	//   snik, _סקיר, ködi, _وكير
  { {0x463a0003,0x2367000e,0xb77b0009,0x877b0009}},	//   _لأحد_, _menj_, _באיש, _באיי
  { {0x6446004a,0xe0da0001,0xfc48001a,0x201811de}},	//   _tuki, кве_, _lửa_, lori_
  { {0x629c003e,0x9f5111df,0x20870048,0x4fc611e0}},	//   _wpro, lizá_, ийци_, иска
  { {0xdb070066,0x22400051,0xfc48001a,0x67240030}},	//   _zají, _liik_, _nửa_, řijm
  { {0xb765007c,0x539b000b,0x7ddc0061,0xc14b0081}},	//   стій, _שילו, _hési, _câịp_
  { {0x9fa30065,0xba57000b,0xd5b7027f,0xf6570009}},	//   síðu_, _כסלו_, ась_, בסקי_
  { {0x64400061,0xe4e60024,0xe97b0009,0x717b0009}},	//   _émis, рійн, _שנמש, _שנמס
  { {0xfc480020,0x47aa0003,0x60e8003a,0x66090027}},	//   _cửa_, _جارٍ_, ırmı, čeki
  { {0x91fd0039,0x0bb7000b,0xb4db001a,0xa6ca0012}},	//   ksāt, בלים_, _ngàn, _جوال_
  { {0x54a60012,0xedd30012,0xd49a091c,0x7dd80e1f}},	//   _نحتف, _ويلد, _арк_, _míss
  { {0xf993000b,0x2bc90037,0xf8c60011,0x7ae5005e}},	//   חרר_, रामा, लमिय, _ühtn
  { {0xd7fb0046,0xb7f80037,0x7a230051,0x9b940003}},	//   тум_, ्चिम_, võtm, _طلبت
  { {0xdb03000e,0x62350014,0x52840012,0xbddb0025}},	//   _taná, _леку, _العك, _nièc
  { {0x8b3b000b,0x5d780015,0xdb180054,0x433b0009}},	//   _בתוצ, ийся_, _invà, _בעוב
  { {0x40950003,0xb87b000e,0x06140024,0x22a80060}},	// [2410] _الخر, gzít, ідую, _aşk_
  { {0x7ddc0061,0xf4570009,0x6b880248,0x61fd1106}},	//   _dési, יימר_, ngdg, lisl
  { {0xeb480024,0xfb150012,0x2ac7004c,0x4c140012}},	//   рчук_, حواج, шљав, زبكس
  { {0x6d470066,0xc2440024,0x29d70060,0x321901e9}},	//   ějak, інік, _açar_, nosy_
  { {0xc104000a,0xa8a70015,0xdb0a0052,0xdb030032}},	//   يومي, ррек, _anfü, _unnö
  { {0xf7710003,0x764811e1,0x9f580025,0x656d016d}},	//   سات_, _budy, tiré_, laah
  { {0xd00e0003,0x21290064,0xfc480081,0xa49b01a0}},	//   على_, ťah_, _rửa_, _exòt
  { {0xfc480020,0x63a500df,0x78ad0038,0x61fd10b8}},	//   _sửa_, lehn, _osav, jisl
  { {0x22400051,0xdb01000e,0x1fa7002d,0x22470132}},	//   _riik_, melé, _врег, _sunk_
  { {0x91fd001e,0xa7d40012,0x9f580025,0x53c91012}},	//   ksās, _وتلص, piré_, угом_
  { {0x7a230005,0xae78007c,0xf8a9000b,0xcad50009}},	//   võtj, _всіх_, _רש_, צוֹת_
  { {0xdb030392,0x7db40012,0x6fdd0025,0x98a60357}},	//   _lanç, _وصنا, _sèch, биме
  { {0xeb990014,0x91ba000b,0x63c20066,0x201811e2}},	//   _бил_, אמרי, ávní, tori_
  { {0xd91a000b,0x7ddc0061,0xd1160009,0xb4e30011}},	//   רושל, _rési, מקרה_, ननी_
  { {0x67290013,0xdb01000e,0x200711e3,0x20181017}},	//   řejn, kelé, inni_, rori_
  { {0xfbdf001a,0x2291000e,0x93bc000d,0xdb1c0052}},	//   _quên_, mák_, plăc, _vorü
  { {0xbddb0108,0xdb180149,0x2291000e,0x7bd5003a}},	// [2420] _sièc, _invá, lák_, _bozu
  { {0xbddb0061,0x6faa0001,0x77860001,0x9f860055}},	//   _pièc, _свог_, _улоз, _угод
  { {0xfe72000a,0xb87b000f,0x24920002,0x6c330003}},	//   _عدد_, szít, stym_, أفلا
  { {0xed5a0014,0xda650012,0xdb010031,0x69d611e4}},	//   _щом_, تاكي, gelé, _joye
  { {0x69d60108,0x69c40002,0xdb1c0002,0xcdb7000b}},	//   _moye, _mnie, _poró, _הפכה_
  { {0x2291000e,0xba6a0003,0xf8b3000b,0xa09b0009}},	//   kák_, _محرك_, פשו_, ריסט
  { {0xc6770003,0x2291024a,0x645b0061,0xcaa50012}},	//   محيط_, ják_, epui, _وصفي
  { {0xfbc90037,0x3ebe004a,0x7bc311e5,0x442e018a}},	//   राथम, ätty_, _annu, _shf_
  { {0x8afc0002,0x92a80002,0xf1c300d9,0x61fd0042}},	//   zbęd, _małż, šší_, visl
  { {0x13f4002d,0x9cd7000b,0x03f80001,0xb2740129}},	//   ізня, צויה_, рној_, олош
  { {0x1757000b,0x7ae50051,0x639b0009,0x8c1b0009}},	//   _הסבר_, _ühtl, נסטנ, רויי
  { {0xa3b10037,0x14c80037,0x60dd004a,0x63a50052}},	//   _फ़ोन_, रमाण, tysm, zehn
  { {0x682d0029,0xdca3031e,0x361b0009,0x69c411e6}},	//   súde, _наци, _גואד, _dnie
  { {0xdb01000f,0x229111e7,0xe5070009,0xad250012}},	//   zelé, bák_, _ל֖וֹ_, _برمو
  { {0x63970093,0x93fb000b,0x7bfb000b,0xdd9b0014}},	//   _הדוא_, _תלוי, _תפוצ, лша_
  { {0x91ad0020,0xbcfb000e,0x69c40002,0x9f4700d9}},	//   _thẻ_, _idéz, _gnie, diný_
  { {0xdb01000f,0xe3c50012,0xe1ff01e3,0x63a511e8}},	// [2430] velé, يْرَ, mió_, tehn
  { {0x7d1d0052,0x290c003a,0x69c40002,0xab940024}},	//   üssi, ğdat_, _znie, зифі
  { {0xdb01000e,0xa6ab0012,0x539b0009,0x92670012}},	//   telé, _صادق_, ריבו, صدام
  { {0x3ebe00c5,0x201e11e9,0x99840012,0xe1ff11ea}},	//   ætte_, _akti_, كلمو, nió_
  { {0x7ddc0061,0xfe09001a,0x224d11eb,0x00850024}},	//   _jésu, hắc_, _čeku_, ілко
  { {0x6f87002d,0x7e550229,0xf2e703e1,0x988c0009}},	//   судж, отиц, _любо, רָאֵ
  { {0xdcfb0027,0xdb0108c5,0x501c0009,0x99850012}},	//   oguć, pelé, אוגו, _ولسو
  { {0x91a90020,0xcb120009,0x8af80048,0xa194003c}},	//   _nhà_, _חלל_, _унсс_, _насч
  { {0xb4e30044,0xa5090014,0xe1ff11ec,0x1d090048}},	//   नने_, репа_, dió_, репи_
  { {0x69c40039,0xe2910003,0x2291000e,0x69d60061}},	//   _snie, وذج_, ták_, _soye
  { {0xd1ca0046,0xa9a606a5,0xe29911ed,0x2329024d}},	//   алне_, оинд, шан_, рони_
  { {0x36340003,0xbba60011,0xe1ff11ee,0x229111ef}},	//   _فرنس, _ऑस्क, gió_, rák_
  { {0xfba90037,0x69d60061,0x33f50012,0x9f450025}},	//   क़दम, _voye, _وستس, _allé_
  { {0x248000a2,0x69c40034,0x9f470478,0xc49a0009}},	//   vrim_, _wnie, minó_, _כשנת
  { {0x7f430800,0x61e211f0,0x4ded0037,0xfe670003}},	//   держ, ykol, _जताई_, بد_
  { {0xe1ff11f1,0x64430101,0x660911f2,0xceb20009}},	//   ció_, _hini, nnek, ויל_
  { {0x656b000f,0xe617002d,0x6e2400b6,0x644311f3}},	// [2440] _megh, іду_, rlib, _kini
  { {0xdb07000f,0x62810070,0xdb1c0028,0xd9e20011}},	//   _sajá, orlo, _borð, पस्ट
  { {0x442511f4,0x661b11f5,0x16190011,0x479b0009}},	//   ill_, kouk, दवार_, _דייס
  { {0x18a6002d,0x661b004a,0x64590002,0xa92607e8}},	//   жадм, jouk, _otwi, одел
  { {0x61e211f6,0x75fa0066,0x62810032,0x9f430097}},	//   rkol, hůzk, hrlo, mhjá_
  { {0xdb1c0028,0x644311f7,0xe1ff000e,0xb7d70012}},	//   _forð, _nini, zió_, يونا_
  { {0xfe6f0003,0x644b0010,0x1dc50011,0xdb070097}},	//   ندي_, _augi, वांत, _snjö
  { {0x9343007c,0xe1ff0054,0x1af70009,0xdd900012}},	//   _інте, xió_, _ומלל_, روخ_
  { {0x64430101,0xe1ff0164,0x644b00b8,0x9f4701e3}},	//   _bini, vió_, _cugi, ginó_
  { {0x7ddc0108,0xa2f4002d,0x5397003c,0x88bd0034}},	//   _résu, зпоч, овья_, _wyśc
  { {0xe3b8003a,0xe1ff11f8,0x883b0009,0x64430c3e}},	//   llık_, tió_, _כתמו, _dini
  { {0x6443008b,0x201c11f9,0x644b11fa,0x442511fb}},	//   _eini, lovi_, _fugi, all_
  { {0xc1730093,0xe1ff0164,0xe3b8003a,0x2e370009}},	//   וחר_, rió_, nlık_, _וראש_
  { {0xd250000a,0xe1ff03eb,0xbebc001e,0x93b3002d}},	//   _كنت_, sió_, _dzīv, _обіц
  { {0x3dc60036,0x67e20029,0x2ee50028,0x356b0103}},	//   _know_, _môjh, álf_, иран_
  { {0x7a120039,0xc3390066,0xe3b8003a,0x6288009b}},	//   tāte, čítá, klık_, mudo
  { {0x34940a1a,0x94ab0001,0x5ce7002d,0x39490051}},	// [2450] матр, штва_, цюва, _igas_
  { {0xbc680003,0xa2be0037,0xa8580009,0x23cd0011}},	//   تمكن_, षिप्, _ויזה_, ़ायद
  { {0x28380003,0x201c11fc,0x224d0035,0x66000034}},	//   _بأية_, dovi_, _čeks_, kimk
  { {0xda78002d,0x66000066,0xd3370009,0x41e40024}},	//   іях_, jimk, קראה_, міча
  { {0x998d0026,0xa6e20028,0x63a811fd,0xf8cb0011}},	//   _tiež_, öðva, kedn, ामिय
  { {0x27c70015,0x3d3a000b,0x1a5b0003,0x63a808ff}},	//   ющег, _לגרס, _نشرة_, jedn
  { {0xfbd2000b,0xd6a80003,0x64590002,0x2ba90037}},	//   _אתם_, قديم_, _stwi, क़सा
  { {0xee390001,0x2bc90011,0xb9550048,0xc2c40012}},	//   љни_, रावा, _хващ, _تيفي
  { {0x321d0002,0x644311fe,0x9990000d,0x24890018}},	//   mowy_, _pini, ţaţi_, nuam_
  { {0x321d003e,0x80a40003,0x76c70012,0x7ae5005e}},	//   lowy_, _تمكن, _وغال, _ühtk
  { {0x7bd801a2,0xf0890009,0xca350009,0x4b250024}},	//   _dovu, _תנ_, ּנָה_, ямов
  { {0x644b0051,0x321d0002,0xfad60009,0x3d950294}},	//   _tugi, nowy_, לותך_, _хидр
  { {0xdb1801ab,0x6288007a,0x6443002c,0x7bc70498}},	//   _anvä, audo, _tini, _onju
  { {0x9cd6000b,0x3a26000e,0x9f5c11ff,0xdfd20012}},	//   _מונה_, zlop_, tivé_, ريز_
  { {0xfaa20098,0x321d0002,0x92640003,0x92590012}},	//   _защо, kowy_, _قديم, _اشتر_
  { {0x32da000b,0xceb2000b,0xda7a000b,0x9f5c0061}},	//   _לחצנ, עין_, _הנקר, rivé_
  { {0x321d0002,0xac860472,0xd5af0012,0xa5bb0031}},	// [2460] dowy_, ягал, دفق_, _skóc
  { {0x917a001a,0x60fb000b,0x70fb0009,0xa0970009}},	//   _hầu_, _להפק, _להפח, _צדיק_
  { {0xe7db0093,0xb7db000b,0x38690052,0x6fdb000b}},	//   _הקיש, _הקיי, _zwar_, _הקיס
  { {0x63a8003e,0x8c460015,0x628f0002,0x04460015}},	//   zedn, _неме, ńcow, _немн
  { {0x55bb000b,0xdb18006f,0x63c70030,0x29120060}},	//   _המכו, _invå, ární, çya_
  { {0xdb0e02d1,0xe3b8003a,0xdb0a006f,0x3dc61200}},	//   _habí, rlık_, _infö, _snow_
  { {0xfbc90044,0xfaa30434,0x63a80b31,0x7a23005e}},	//   रारम, _паро, vedn, võtv
  { {0x9aeb000b,0xceb3000b,0xe3b8003a,0x9daa0048}},	//   _הַמִ, תיה_, plık_, съка_
  { {0x7bd80027,0x6135000e,0x660008e2,0x201c1201}},	//   _povu, rülé, rimk, povi_
  { {0x628810ad,0x7ae100b0,0xb05b0ed7,0x7ddc0018}},	//   tudo, fylt, lväg, _péss
  { {0xa75b000b,0x6135000e,0x443a000d,0x32020004}},	//   _הדבר, pülé, imp_, fiky_
  { {0xdb0e0013,0x917a0020,0x80b30037,0x62880058}},	//   _nabí, _cầu_, _इनमे, rudo
  { {0x7a230051,0x4fc70014,0x3cf80037,0x25a90132}},	//   mõtt, псва, ूपों_, veal_
  { {0xdd3b000b,0x853b000b,0x2d9c000e,0xa01b000e}},	//   _העדכ, _הגדי, ővel_, ltöz
  { {0x752f003e,0x539b007e,0xb05b006f,0xf413000b}},	//   _szcz, _היוו, kväg, _אפס_
  { {0x63b5001c,0xe3b800a2,0x3ebe0028,0x02450003}},	//   _sazn, ldı_, ætta_, _تَعَ
  { {0x61ed0101,0xb97c000b,0x67ef0058,0xfbd90001}},	// [2470] _ilal, _הנחי, _høje, одај_
  { {0xe3b800a2,0x6725004a,0x68ef003a,0x321d0002}},	//   ndı_, _tyhj, ındı, wowy_
  { {0x98b900a2,0x321d003e,0x24521202,0x25a91203}},	//   ması_, towy_, _lâm_, peal_
  { {0xa954002d,0x68320058,0x22951204,0x7a3f0cac}},	//   екці, ræde, råk_, _būti
  { {0x7a12001e,0x99d40003,0x321d0002,0x7a150002}},	//   nāta, عتما, rowy_, jąte
  { {0x7a230051,0x656f1205,0x389c000b,0xb8d50037}},	//   võtu, _hech, ציונ, _जन_
  { {0xd5e10011,0xcf580009,0x321d0034,0xdce60035}},	//   _नवाज, הבות_, powy_, _iekā
  { {0xb9c5000a,0xe45900f5,0x660d1206,0x7bdc0795}},	//   _تقري, ожи_, nnak, örun
  { {0x660d0101,0x98b9003a,0xdcfd003a,0xe45f0028}},	//   inak, kası_, _kası, _drög_
  { {0x7a12001e,0x13090015,0x2452001a,0xf794003c}},	//   dāta, жной_, _dâm_, _пауэ
  { {0x442b001e,0x32020042,0x69c90132,0x2003013a}},	//   ēc_, tiky_, _knee, diji_
  { {0xd6d80047,0x645d07f6,0x69db0061,0xf1bf0066}},	//   _эту_, _otsi, _joue, slán_
  { {0x917a001a,0x98b9003a,0x660d1207,0x05740012}},	//   _cấu_, fası_, dnak, _ساند
  { {0xdcfd00a2,0x917a0020,0xdce60039,0x67ef0058}},	//   _nası, _dấu_, _nekā, _føje
  { {0x645d039c,0x9f581208,0xfbd20009,0x43720012}},	//   _atsi, rirà_, _בתג_, _شهير
  { {0x7a12001e,0x656f0504,0xf5b50024,0x6e290032}},	//   bāta, _cech, нсую, nleb
  { {0xdcfd00a2,0x2452001a,0x25fd0037,0x200300eb}},	// [2480] _bası, _xâm_, रोधी_, biji_
  { {0x7a3f001e,0x2003048b,0x9f451209,0x9f580d85}},	//   _rūti, ciji_, _allí_, birá_
  { {0x645d0006,0x2cb8001e,0x656f084f,0x7a3f001e}},	//   _etsi, ārdi_, _fech, _sūti
  { {0x79a30046,0xf1a30001,0x6d4b00b6,0x8b08000b}},	//   врше, вршн, _ngga, הִנֵ
  { {0x7a230005,0xe3b8003a,0xb05b006f,0xd9ae0011}},	//   võtt, ydı_, rväg, _घसीट
  { {0x6d590070,0x66040038,0xd0f70009,0xb05b0ed7}},	//   _afwa, liik, ומנת_, sväg
  { {0x7a230051,0x66730012,0x69db0025,0xb05b0248}},	//   tõtt, ندير, _foue, pväg
  { {0x1dd10037,0xc883003a,0x66040872,0x16370012}},	//   हायत, üğü_, niik, وسية_
  { {0xe4520012,0x9f5c0030,0x98b90060,0x9f580018}},	//   خضع_, liví_, yası_, zirá_
  { {0x88bd0002,0x7a12001e,0x8af8046d,0xf1bf0031}},	//   _myśl, vāta, знос_, alál_
  { {0x660d003a,0xe3b8003a,0xddcb0a48,0x200300eb}},	//   ynak, rdı_, žišt, viji_
  { {0x24520020,0x3869004b,0x7c660012,0xdb1c0248}},	//   _tâm_, ţare_, _قاتل, _inrä
  { {0x98b900a2,0x660d0029,0x3e7a001e,0x20030027}},	//   tası_, vnak, līt_, tiji_
  { {0x656f0052,0xa2be0037,0x9f58052e,0xd3b70024}},	//   _sech, षिद्, tirá_, _олії_
  { {0x3e7a0039,0x98b900a2,0xdb08000e,0xa3d20037}},	//   nīt_, rası_, kedé, वान_
  { {0x98b9003a,0x628501bd,0x200300eb,0x9f580b45}},	//   sası_, vrho, siji_, rirá_
  { {0x2298000e,0xd7f10003,0x656f120a,0x20030825}},	// [2490] lék_, _مكة_, _vech, piji_
  { {0xd3710003,0xfbd30003,0x656f0052,0xbcfb000e}},	//   اها_, ختر_, _wech, _beér
  { {0xc7b2000b,0xdcfd003a,0x7bdc0042,0xa0360009}},	//   _גבי_, _vası, _doru, _ראתה_
  { {0x3e7a0039,0xd131000a,0xf1bf120b,0xc333000b}},	//   dīt_, هما_, klám_, דוע_
  { {0xc0c80001,0x07a500f5,0xa0690686,0x8d5a0009}},	//   дује_, еалн, чала_, _מכרי
  { {0x63b8024c,0xdb07120c,0xf1bf0029,0x2298000e}},	//   _navn, _majú, dlám_, kék_
  { {0xd6d1000a,0x26c10013,0xfc480020,0xdce00066}},	//   اقع_, ího_, _gửi_, pamě
  { {0x2486039c,0x917a0020,0x7bdc003a,0x2298000e}},	//   šome_, _mẫu_, _zoru, dék_
  { {0x7bdc003a,0x91ad001a,0xdb070029,0xdb010029}},	//   _yoru, _ghé_, _najú, delá
  { {0xeb990001,0x2e4b0014,0x44230029,0xc0520009}},	//   чио_, _дядо_, ôj_, _עזב_
  { {0x2bb20037,0xe9ff001a,0x212900b6,0xdd00001e}},	//   ीयता, _giản_, _ayah_, ātāj
  { {0x61f900a2,0xe1f20012,0xdeba0009,0xbbdc0011}},	//   _çalı, اسد_, _ממעל, _मक्क
  { {0x442100c6,0x04c80012,0xc4fb0012,0x39440248}},	//   koh_, _يومي_, _بعضا_, äms_
  { {0xcc760009,0x7fd60024,0xdb0e0248,0x16020011}},	//   _טענה_, хімі, _inbö, रोनर_
  { {0xada60015,0x6604004a,0xf7530003,0x4421120d}},	//   навл, tiik, انفج, doh_
  { {0x7bdc00a2,0x11d60003,0xc1ba0003,0xf1b90082}},	//   _soru, _ستبد, _رابط_, _naš_
  { {0x66040051,0x3e7a001e,0x7bdc09b5,0x63a60031}},	// [24a0] riik, zīt_, _poru, őkne
  { {0x1f66002d,0x6604004a,0x25ad08de,0x394d00a5}},	//   _яком, siik, heel_, _ages_
  { {0x88bd003e,0x7a12001e,0x74130003,0xf1b90027}},	//   _wyśl, nāto, دولا, _baš_
  { {0xe9da0198,0x7bdc0032,0x60c4120e,0xf8a405f3}},	//   яке_, _woru, _krim, _ओहाय
  { {0x317b0093,0x25ad0070,0xf123027f,0x7c210040}},	//   פרסמ, deel_, льшо, kolr
  { {0x3e7a0039,0xc059002d,0xdb08000e,0x907b0009}},	//   tīt_, фії_, sedé, לטני
  { {0x4438008b,0x7bdc0028,0xa96a02ac,0x63b8017b}},	//   _ihr_, örum, _нива_, _ravn
  { {0x3e7a0039,0xe2a60028,0x71660003,0xf653000b}},	//   rīt_, öðum_, _سارك, נצח_
  { {0x3e7a0039,0x248d0d04,0x35c50011,0x6e3b0009}},	//   sīt_, guem_, वाज़, התקד
  { {0x2298000f,0xa87b000b,0x64970009,0x44380032}},	//   ték_, _מאמר, עדיף_, _jhr_
  { {0xda770015,0x6e20009b,0x7dd8000e,0x0566120f}},	//   няя_, pomb, _dísz, _звен
  { {0x629a0575,0xcb130009,0xddea0012,0xf1bf0031}},	//   rtto, טלת_, _عرضه_, mlák_
  { {0xf8bf0061,0xc0cb0001,0xebe60406,0xfca90012}},	//   uvé_, чуне_, _подп, _ياهو_
  { {0xf8bf0bfe,0xecb70009,0x7a120035,0xab620522}},	//   rvé_, _נפוץ_, bāto, üüdu
  { {0x443e008b,0x2cb80039,0x5b570009,0x64930fb5}},	//   mmt_, ārdu_, _איוב_, ržiš
  { {0x25a00572,0xbcfb000e,0x442c0851,0x80be0011}},	//   gfil_, _beép, lld_, शिशे
  { {0x644a000f,0x7c970012,0x443e045f,0x4421016d}},	// [24b0] _kifi, عشرا, omt_, toh_
  { {0x44380832,0xdc8b0009,0x67e20064,0x94390012}},	//   _chr_, לְבָ, _dôjs, ذكاء_
  { {0x8c1b0093,0xfc300003,0x67ef0058,0x141b000b}},	//   לומי, صحك_, _nøja, לומב
  { {0x7c3e005e,0x443e0032,0x225c0030,0x7ae5008e}},	//   ampr, hmt_, ívka_, ryht
  { {0xf1b90750,0x25ad0070,0x7ae5004a,0x7c380051}},	//   _vaš_, veel_, syht, _ohvr
  { {0x0058000b,0x9f450164,0x07a50001,0x7d000097}},	//   עשות_, _allá_, такн, _ýmsa
  { {0xa75c000b,0xf6b20003,0xdd910012,0x91ad0081}},	//   הדור, لموج, لوغ_, _chẽ_
  { {0x442c1210,0x24891211,0x6e2d1212,0x7a120035}},	//   eld_, oram_, nlab, vāto
  { {0x6e2d0036,0x8cc40037,0x44380032,0x25ad0834}},	//   ilab, रियो, _yhr_, reel_
  { {0xcf270012,0xa5bb0097,0x68e60073,0x6ca40012}},	//   _كراي, _skól, vykd, اصيل
  { {0x05e10037,0xe2850014,0x6e2d0028,0x0dcb0001}},	//   _नवंब, ълни, klab, _нуди_
  { {0xdd1d000d,0xe4d50003,0xa5670012,0x7a120035}},	//   _câţi, _لتتب, _أدان, rāto
  { {0x48fc0037,0x7c2100b6,0x61d60009,0x69d90227}},	//   _लेखो_, polr, דורף_, ijwe
  { {0xedca0011,0x20071213,0x8b940048,0x98880009}},	//   ाञ्छ, nini_, _бръч, עָרֵ
  { {0x91fd0039,0x7a381214,0x3ad20012,0xa2d20012}},	//   mpān, líte, _نيوز, _نيوت
  { {0x60c401b3,0xa6e90020,0x6e2d1215,0x24890028}},	//   _trim, _trươ, glab, fram_
  { {0x7a38000f,0x69650003,0x1d070103,0xe0210011}},	// [24c0] níte, _صديق, вети_, यवाद_
  { {0x7ae50051,0x74130012,0x6e2d1216,0x9359004c}},	//   _ühts, لوقا, alab, ерцу_
  { {0xd2590024,0xee3a1044,0x6e2d1217,0xeb970b12}},	//   еці_, _оно_, blab, тих_
  { {0x65690070,0x463a0024,0x99460012,0xe297004c}},	//   jbeh, _ічня_, نَاه, ђач_
  { {0xa3d20044,0x40960047,0xf993000b,0x443e0028}},	//   वाद_, трет, שרד_, ymt_
  { {0x65690029,0x44380052,0xc8650003,0x6b6300fa}},	//   ebeh, _uhr_, اطني, _вкра
  { {0x764b0101,0x644a00c1,0xdd900012,0x59b20011}},	//   _bigy, _rifi, موث_, ज़ार
  { {0x442c0070,0x7ae308b5,0x54b805c8,0x09e30189}},	//   wld_, änte, егия_, _косн
  { {0x41d60037,0x7a38000e,0x09e30048,0xc8080081}},	//   धानस, gíte, _тотн, hởi_
  { {0x442c0036,0x6e2d001e,0x52d8002d,0x2bd20011}},	//   uld_, zlab, емою_, ताधा
  { {0x291e000d,0x442c04db,0x7ec80061,0x764b000e}},	//   ştal_, rld_, _dépô, _figy
  { {0xc27b0093,0x627b0009,0x1ea90012,0x2d9200b0}},	//   ורטי, ונטנ, _سامي_, _øye_
  { {0xcdf7000b,0x2cb8001e,0xbbbc0011,0x7a150034}},	//   _במאי_, ārds_, ्फ़ॉक, kątn
  { {0xaa580012,0x629e1218,0xdb030478,0xa91d0e3d}},	//   _كلتا_, ktpo, _canó, _udže
  { {0xdbdc0028,0xd3780002,0xdceb001e,0x5c37000b}},	//   _ráðl, mać_, _iegā, _שרון_
  { {0xd3780002,0x24891219,0x6e2d0060,0x2007121a}},	//   lać_, tram_, ulab, zini_
  { {0x31790002,0x24f60009,0xdb030034,0x20070060}},	// [24d0] masz_, כֶ֑ם_, _fanó, yini_
  { {0xd3780002,0x4427001a,0x7a360028,0x31790540}},	//   nać_, ôn_, máta, lasz_
  { {0x16220037,0xf09f00c1,0xe28b0066,0x7a380031}},	//   मवार_, ltà_, _účtů_, zíte
  { {0x63bc002a,0xa01b0028,0x24860010,0xa5f9011d}},	//   _earn, fsög, šoma_, _чему_
  { {0xd378003e,0x2007121b,0x9d140024,0x3c390025}},	//   kać_, tini_, _вдяч, lève_
  { {0xe0d00003,0x7a38000e,0xf8070048,0xd3780034}},	//   تزم_, víte, ъчен, jać_
  { {0xed5900e3,0x200700a1,0xd378003e,0x9f510164}},	//   ной_, rini_, dać_, lizó_
  { {0x200700a2,0x26c50027,0xcb120009,0xa87b0012}},	//   sini_, _vrlo_, _הלל_, _يحذر_
  { {0x75f50013,0x2007121c,0x31790002,0xdd11003a}},	//   _náze, pini_, dasz_, _düşm
  { {0xd3780002,0x7a38000e,0xdb180030,0xf1bf068c}},	//   gać_, ríte, _zavé, edá_
  { {0x7a38000f,0x224d007a,0xf09f00c1,0x420a0210}},	//   síte, _kiek_, età_, енно_
  { {0x7a38000e,0xf1bf0017,0x75ea0066,0xc3320009}},	//   píte, gdá_, _výzk, מוי_
  { {0x22470013,0x7c25001b,0xdb010248,0xdb03121d}},	//   ínky_, kohr, delå, _panó
  { {0x25bf000d,0xd3780002,0xe8d60009,0x98160012}},	//   ldul_, cać_, אושר_, ابحا
  { {0x98a50039,0xa3d20037,0x539a000b,0x25bf121e}},	//   ālā_, वास_, _ניקו, odul_
  { {0x63bc0051,0x6609121f,0x229c1220,0x25bf1221}},	//   _sarn, niek, vík_, ndul_
  { {0xa3c80037,0x20ce0028,0xfbb70011,0x61e01110}},	// [24e0] _लोड_, iðið_, _असाम, _roml
  { {0x249f0028,0xb3850012,0x141a0012,0x61e00248}},	//   itum_, لجمه, ريضة_, _soml
  { {0xb05b0163,0x6b59000e,0x66091222,0x6441030f}},	//   nvän, _súgó, kiek, imli
  { {0xd3780002,0xbbe00037,0x4e1a0003,0xa3d20037}},	//   zać_, _पक्क, _ستجد_, वाह_
  { {0x44251223,0x66091224,0xd0d40048,0xdb1a0031}},	//   kol_, diek, ролъ, rdté
  { {0xceba0001,0xa01b0028,0xb4c20037,0x7a0b0002}},	//   ељи_, rsög, ्मी_, nętr
  { {0x66090070,0x386600b6,0x249f0028,0x44251225}},	//   fiek, spor_, etum_, dol_
  { {0xd3780656,0x200a003a,0xb05b006f,0x5d540014}},	//   wać_, hibi_, dvän, шкит
  { {0x7ddc000f,0xc7960003,0xd3780002,0x200a003a}},	//   _kész, _مشاب, tać_, kibi_
  { {0x3a260070,0x31790034,0x34b70009,0xd2860009}},	//   loop_, wasz_, נפים_, ְךָ֙_
  { {0xd378003e,0x16660001,0x0e66035c,0x9e6604fb}},	//   rać_, _свем, _скен, _свед
  { {0xf09f01a2,0x2ca00005,0xd378003e,0x91a00037}},	//   ttà_, ktid_, sać_, ग्लै
  { {0x1bd40048,0xd3780034,0xf1bf1226,0x7afa0031}},	//   _воля, pać_, kláv_, sztt
  { {0xc3560098,0x7a360570,0xf09f0850,0x4ae60012}},	//   _съдъ, ráta, rtà_, _مثبّ
  { {0xa36f0029,0xe7f60037,0xf09f10ac,0xd35b0009}},	//   äčši, ीफ़ा_, stà_, _אדול
  { {0xb4c20037,0x8d770012,0x2bd20011,0x9f5101e3}},	//   ्मू_, طارا, तावा, tizó_
  { {0xdbd20051,0x682d0029,0x7b040010,0x8c570012}},	// [24f0] _füüs, súdi, žutė, ائرا
  { {0x41c30044,0xdce00039,0x9f45004a,0x320b1227}},	//   षयवस, lamē, _yllä_, licy_
  { {0xddd0003a,0x41e7002d,0x4155035c,0x644e1228}},	//   _çeşi, ліда, авес, _dibi
  { {0x320b0002,0x249f0028,0xd6d80024,0x69d50011}},	//   nicy_, ytum_, _сть_, णाधी
  { {0x656d00c6,0x4425003a,0x7a3601bd,0x25190009}},	//   mbah, yol_, kátn, _יוֹא
  { {0xdceb007d,0x66090002,0xa265001a,0xba770012}},	//   _legă, wiek, _buộ, _مارت
  { {0xec360093,0x442503eb,0xa3d20044,0xa2650020}},	//   _כאשר_, vol_, वार_, _cuộ
  { {0x3ebe0028,0x249f0839,0x656d07a4,0xfbb70011}},	//   ætti_, ttum_, nbah, _असहम
  { {0x20ce0065,0x25bf09f6,0x44251229,0x6609122a}},	//   rðið_, rdul_, tol_, riek
  { {0x6609007a,0x7a120039,0x13e60015,0xa3ab0037}},	//   siek, māti, имый_, _कॉम_
  { {0x7a38000f,0xc5d5002d,0x249f05df,0xddc70010}},	//   líta, _віль, stum_, gpjū
  { {0xb05b006f,0x249f0028,0xdb24000e,0x7a88000b}},	//   rvän, ptum_, ásáv, נָתַ
  { {0x7a120039,0xb05b006f,0x91360024,0xa3d50011}},	//   nāti, svän, рхні, हाद_
  { {0x88bd0656,0xb4fa000b,0x34fa0009,0xacfa0009}},	//   _wyśw, _בפני, _בהנד, _שהסכ
  { {0x7ddc000f,0x645b02d1,0x245b001a,0xf746122b}},	//   _rész, lqui, _hêm_, рево
  { {0x8e55007c,0xdd920003,0x96550014,0x05660264}},	//   стрі, تور_, сърч, рван
  { {0x7a12001e,0x8cc80037,0xa3d20037,0x93bc000d}},	// [2500] jāti, ़ियो, वाल_, plăt
  { {0x307b0093,0xdb080066,0x63800066,0x27220029}},	//   _שאינ, ledá, dání, nčné_
  { {0xf1da0037,0xdb150017,0x78bb0269,0x9f5c021e}},	//   _बचान, _razã, _asuv, nivå_
  { {0x60c9122c,0x61e4004a,0xb17b01fb,0xc332000b}},	//   _brem, _joil, lkår, חוב_
  { {0xdb1c0061,0x27220029,0xf1bf000e,0x98a30048}},	//   _maré, kčné_, mlát_, жиче
  { {0x18670001,0x7a3d000e,0x2480001e,0x7644003a}},	//   шаљи_, méte, msim_, lmiy
  { {0xf773000b,0x7a3d122d,0x4444122e,0x69c10011}},	//   חקו_, léte, mm_, _रोकी
  { {0x8066007c,0x7866002d,0x61e4000d,0x7644003a}},	//   _вваж, _вказ, _noil, nmiy
  { {0x91830020,0x2bd20037,0xdceb000d,0x4444005b}},	//   _nếu_, ताला, _regă, om_
  { {0x69c2122f,0x320b0034,0xdb150031,0xdb1c01a0}},	//   ldoe, wicy_, _hazá, _parè
  { {0xec37000b,0xfeba0003,0x869a0021,0xcb570009}},	//   שאיר_, _جاءت_, _штат_, יסיה_
  { {0x44440052,0x2480088c,0xa3d20011,0x7d080035}},	//   hm_, ksim_, वाँ_, tīrī
  { {0x61e4000d,0xd5fb0009,0x98b80148,0xdb150030}},	//   _doil, _בפאר, алят_, _mazá
  { {0x7a31006f,0xbec70035,0xdce00035,0xdb181230}},	//   tåtk, stīš, samē, _haví
  { {0x0cb60044,0x34b60037,0x69c0000d,0x64b60037}},	//   _अनुम, _अनुद, _oame, _अनुश
  { {0xdb050163,0x5d55085b,0xb9990001,0xe5550001}},	//   nehå, скат, _свих_, скањ
  { {0x78a20027,0x656d1231,0xc5390024,0xbddb0025}},	// [2510] jtov, rbah, упах_, _bièr
  { {0x63800013,0xeb930003,0x1da60037,0x03d40024}},	//   vání, تظر_, क्तत, ожую
  { {0xcf920093,0x752f0002,0xd9550012,0x645b01e3}},	//   _צטט_, _wycz, مناخ, zqui
  { {0x9183001a,0xdb181232,0xc3330009,0x752f0034}},	//   _yếu_, _naví, קוף_, _tycz
  { {0xf1bf000e,0x7a3601e9,0x7c28119d,0xa01b0248}},	//   llás_, záto, kodr, bröt
  { {0xafe20015,0x68e40051,0x645d0164,0x60c91233}},	//   зошл, äida, ísim, _vrem
  { {0xc6680046,0x7a381234,0xe7ff0037,0x657b002c}},	//   ашње_, mítn, _उतना_, tauh
  { {0xff18000b,0x95990ec6,0x69c01235,0xc3320009}},	//   יקות_, утку_, _game, _זול_
  { {0x02440012,0x2bb90012,0xadd80009,0x78bb005e}},	//   _ذَكَ, هادة_, שוחח_, _usuv
  { {0x248d1236,0x69c01237,0x245b0018,0x7d090097}},	//   rrem_, _zame, _vêm_, _þesu
  { {0x645b05ab,0x7a150002,0x27220029,0x7bc10051}},	//   squi, jątk, rčné_, rdlu
  { {0x245b0017,0xcb12000b,0x69d80037,0xdb08000e}},	//   _têm_, ללי_, याधी, ülés
  { {0xfd56000b,0x70560003,0x61e40061,0x44440002}},	//   _השני_, إنسا, _voil, ym_
  { {0x7a3d000f,0xe9df0029,0x7bdc0248,0xdb080030}},	//   véte, ajú_, örut, sedá
  { {0xaa95000a,0x22950003,0x52850003,0x33760009}},	//   _العث, _العس, _البك, _העצם_
  { {0x5bb70037,0x7a3d000e,0x6a640003,0x6459002c}},	//   _असुव, téte, _بطول, _kuwi
  { {0x228300a2,0x7644003a,0x78a200f1,0x09f70009}},	// [2520] lık_, rmiy, xtov, _למקם_
  { {0x3ea90002,0x660d005e,0x69c01238,0x7a3d1239}},	//   łaty_, aiak, _same, réte
  { {0xcf57000b,0xdcef001e,0x660d0ff4,0xcb0a0012}},	//   _לבית_, _vecā, biak, ديان_
  { {0x88860003,0x7db60003,0xf1bf000e,0x3ebe0028}},	//   مؤتم, _اصدا, llár_, ættu_
  { {0x17540055,0x69c2123a,0xc19b0009,0x78a2123b}},	//   овля, rdoe, רשני, utov
  { {0xf3e6002d,0xdb010623,0x0eb40011,0x7a120035}},	//   _ужго, belø, ंबलड, mātu
  { {0xadd8123c,0x78a2123d,0x75f50030,0x69c0123e}},	//   имку_, stov, _sáza, _tame
  { {0x9b17000b,0x2283003a,0x21a30001,0x1317000b}},	//   _החלה_, dık_, _нисм, _החלל_
  { {0x7a38000f,0xe4e6002d,0x7a150002,0xb87b000e}},	//   líto, сійн, zątk, nyít
  { {0x8cbb0093,0xe0f70009,0x8fe50012,0x7c280073}},	//   נציק, _הצמח_, _وألم, uodr
  { {0x86c60003,0x02a300b3,0xfe720012,0xe1d90024}},	//   _ديان, прям, _ردا_, адні_
  { {0x1e57000b,0x7a120035,0x7a360031,0xa1940024}},	//   _השאר_, kātu, látj, паюч
  { {0x9f410029,0x628102a1,0x88170012,0x17fb0012}},	//   _dlhý_, aslo, مبسط, هرسة_
  { {0x7a38000e,0x8cb70011,0xf7700012,0xb05b008e}},	//   kíto, ्टरो, فاف_, lväk
  { {0xa3d50037,0xa3d20037,0xa6f8000b,0xa3cc0321}},	//   हार_, वाई_, בִּי, _शोध_
  { {0xbd890003,0x64630028,0x7a38000e,0xf1bf000e}},	//   شنطن_, _óvið, díto, rlás_
  { {0xf1d60037,0xc4b60037,0x94770012,0x4c780009}},	// [2530] धारन, _अनोख, إدرا, שָֽׁ
  { {0x660d11d7,0x18780009,0x41a50011,0xa01b0248}},	//   siak, _העזר_, ग्रस, rrös
  { {0x1dc40037,0x765a0010,0x7a380031,0xee3f0081}},	//   _लोकत, _nuty, gíto, _thý_
  { {0xd6e8000b,0x5ee8000b,0xa4d5002d,0xdb010262}},	//   _הַשָ, _הַשְ, _домі, relø
  { {0x7a380066,0xdb010260,0x28a7003c,0x22830060}},	//   mítl, selø, сшег, zık_
  { {0x907c000b,0xf7710012,0x6281123f,0x26cc001b}},	//   רטגי, ذات_, yslo, _brdo_
  { {0xa2940024,0xfe450055,0xa3dc0011,0xdc3a0009}},	//   _нарі, онко, डान_, _כעשר
  { {0x7d09014d,0xdb0a0052,0x26c7009b,0x387e0002}},	//   _þess, _dafü, rvno_, ątrz_
  { {0xa3d50044,0xada80003,0x1fa71240,0x3869016d}},	//   हाल_, صديق_, _грег, _ntar_
  { {0x228300a2,0x98170012,0x10170012,0xd2a9003c}},	//   tık_, _ابرا, _ابرد, акое_
  { {0x60cd00a1,0xbf15000a,0xe9ff001a,0x9f050003}},	//   _aram, _بواب, _nhẫn_, _بوضو
  { {0x6459002c,0x75f5014a,0xf7690009,0xd9f90011}},	//   _tuwi, _zázn, _יק_, ंसित_
  { {0x91bf0020,0x89360003,0x24190015,0x01360012}},	//   _chủ_, تعدا, _коды_, تعدد
  { {0xcb69002d,0x7a12001e,0xf7720003,0xdd010066}},	//   _таке_, vātu, باح_, štěv
  { {0x26cc084c,0x7bc3000d,0x65c60014,0x4e890009}},	//   ído_, _ianu, обва, יָּ֣
  { {0x7bd5008b,0x60cd1241,0xc1ba0012,0x61fd0032}},	//   _anzu, _fram, _ضابط_, chsl
  { {0x7bc30f5f,0x69d601e3,0x9f640060,0xdca31193}},	// [2540] _kanu, _inye, _ütçe_, мати
  { {0x6026007c,0x9f60004a,0x2d8b0034,0x7a381242}},	//   _єдна, ärät_, ócej_, títo
  { {0x0576000a,0x75f51243,0xda650003,0x34b60037}},	//   _واحد, _názo, كاني, _अन्द
  { {0xa3d50037,0xcb120009,0x69c61244,0xdb1a017a}},	//   हाँ_, ולב_, ndke, ndtá
  { {0x7a38000f,0x2db7000b,0x63660066,0x67d40001}},	//   síto, _ולכן_, nční, золу
  { {0x69c40154,0xbe8a022a,0x7a381245,0x03b60012}},	//   _laie, асие_, píto, _بإحد
  { {0xf1ca0044,0x59ca0037,0x38a40c60,0xa0070012}},	//   ियान, ियार, hör_, تقول_
  { {0x95ca0046,0x38a4012b,0xd6570009,0x7de60012}},	//   рука_, kör_, חיקת_, تستم
  { {0x75fc000f,0xa3d50037,0xe9ff001a,0x6fb60003}},	//   _néze, हां_, _hiến_, _ومرا
  { {0xe9ff0020,0x03f80001,0xe6c60012,0x3f9e0030}},	//   _kiến_, сној_, _وتضي, _uctu_
  { {0x80c20037,0x0bb70009,0xc43b0009,0x01d90012}},	//   लिके, חלים_, שתיי, مودع_
  { {0x91bf001a,0x38a4006f,0xe9ff001a,0x61e21246}},	//   _phủ_, för_, _miến_, njol
  { {0x38a4006f,0x32f5001a,0x7a3d0025,0x99a50031}},	//   gör_, áy_, géta, ítők_
  { {0xf0930009,0x7bc31247,0xe4e90012,0xe9ff0081}},	//   ונש_, _ganu, _دعمه_, _phẫn_
  { {0x22630029,0x98ac001e,0xe7300003,0xa6f80009}},	//   ľské_, ādā_, نصف_, זִּי
  { {0x02fb000b,0x91bf001a,0x2d5804b3,0x60cd0f88}},	//   _כלומ, _thủ_, жить_, _tram
  { {0x8ccd0044,0xa80200a2,0xe534002d,0x29020002}},	// [2550] तियो, şıyo, деть, czka_
  { {0x442c0101,0x69a70044,0xe9ff0020,0xd7f10003}},	//   nod_, ट्री, _biến_, _أكد_
  { {0x201100a2,0x77ba000b,0x67ba000b,0x6448003a}},	//   mizi_, _המתח, _המתק, imdi
  { {0x2486001c,0x5bb70796,0x7a38000f,0x2bb70037}},	//   _ovom_, _अस्व, lítj, _अस्थ
  { {0x8dda000b,0x4dda0009,0x442c1248,0x3cf40011}},	//   _הקרק, _החרו, kod_, इनों_
  { {0x201100a1,0xe808002d,0xcc76000b,0x7bd50052}},	//   nizi_, онід_, _מעשה_, _unzu
  { {0xfd4c0020,0xf1c60037,0x38a4000e,0x6e950012}},	//   _triể, _रोकन, zör_, ألعا
  { {0x3d070011,0x61e20034,0x9f470064,0x11d70012}},	//   िछले_, cjol, chný_, _بتسد
  { {0x5f0d0037,0x7a38000e,0x79c80012,0xfd110012}},	//   _डेस्_, kítj, _بوقف_, عجب_
  { {0x1c420015,0x7a361249,0x73050048,0x2011001b}},	//   нным, máti, зпоз, jizi_
  { {0x44390039,0x69c4124a,0xda65002d,0xf412000b}},	//   ēs_, _paie, явни, תפי_
  { {0xa3ab0044,0x38a4124b,0x657d124c,0x20110035}},	//   क्त_, tör_, _nesh, eizi_
  { {0x645d007a,0x455a0093,0x8d5a000b,0xa01b0052}},	//   _nusi, _הכנס, _הכני, rsön
  { {0x7fd5007c,0x764900a2,0xa3ab0037,0x7a3d08c5}},	//   місі, lmey, _कॉल_, réta
  { {0x61fb0005,0xdee6002d,0x38a4003a,0x661b0029}},	//   _olul, чови, sör_, onuk
  { {0x661b0006,0x764900a2,0x6455001e,0x645d1019}},	//   nnuk, nmey, _aizi, _busi
  { {0xdb0a0065,0x6564003a,0x6455003a,0x819b000b}},	// [2560] _hafð, rcih, _bizi, _הספצ
  { {0x60090010,0x1d190024,0xd40a0012,0x64550030}},	//   yžmi, іють_, حترم_, _cizi
  { {0xab69000a,0x7a38000e,0x7649003a,0x6455124d}},	//   تحقق_, sítm, kmey, _dizi
  { {0xdb1c0017,0xaa570003,0xa3cc0011,0xb0c70011}},	//   _parâ, سلها_, _शोर_, लिंग
  { {0x61e900bd,0x442c002c,0x64480028,0xf0f80011}},	//   _doel, yod_, ymdi, ्छेद_
  { {0xe9ff0020,0x6d3b000b,0x6d59002c,0xdb0e0066}},	//   _tiến_, _לתכנ, _agwa, _zabý
  { {0x24860027,0x27e5000e,0xe29700ac,0x8c430487}},	//   _svom_, ölni_, _нар_, _чере
  { {0xceb30093,0xfb1b0009,0x15e70011,0x225c0030}},	//   גיה_, _הולמ, टॉलर_, ívku_
  { {0xc059002d,0x29020248,0x89db0009,0x62830035}},	//   _діє_, _åka_, _פחמי, šnot
  { {0xa2f40511,0x70fb0009,0xbf650012,0x7d000097}},	//   дпоч, _ההמח, _قدمو, _ýmsu
  { {0xdfa50003,0x6448001e,0x67a50012,0x7a380031}},	//   _تحقي, rmdi, _تحقق, vítj
  { {0xbbc80037,0x442c124e,0xbef70009,0xd2570024}},	//   रयुक, sod_, _מצבו_, яць_
  { {0x442c001c,0x7a380031,0xf5ab0009,0x50670357}},	//   pod_, títj, _ה֑וּ, ятна
  { {0x14d7000b,0x7d04084b,0x1cbb0009,0xccf30009}},	//   _מודל_, dzis, _למדע, _רכס_
  { {0x645d039c,0xa3e00044,0xc43b000b,0x7bd80184}},	//   _susi, थान_, _התגי, _invu
  { {0x645500a2,0x7a38000f,0xa4d5002d,0x753d0002}},	//   _sizi, sítj, мобі, ższe
  { {0x7d040010,0x99450012,0x27180011,0x7a38124f}},	// [2570] gzis, _تَظه, धपुर_, míth
  { {0x78fc000b,0xc954000b,0x7a38000e,0xa87c000b}},	//   _לפחו, _אמפ_, líth, _האזר
  { {0xdb1c03eb,0x3f830027,0x64551250,0x63ba1251}},	//   _carà, maju_, _vizi, ietn
  { {0x7a38000f,0x7aea006f,0x63ba000e,0x39150021}},	//   níth, äfta, hetn, ммер
  { {0x645d083c,0xf3f30003,0x48ab05f0,0x61e90227}},	//   _uusi, _كأس_, стем_, _voel
  { {0x63ba00eb,0x2ca90248,0xaca30081,0x629a1252}},	//   jetn, mtad_, _liịc, kuto
  { {0x3e7a0039,0x7649003a,0x2fc50989,0x2ca911ec}},	//   gūt_, tmey, _valg_, ltad_
  { {0x9b440003,0x629a1253,0xceb4000b,0x201c01a0}},	//   _سنقو, duto, תיק_, anvi_
  { {0x764900a2,0xdb170061,0x3f830027,0x1c450024}},	//   rmey, dexé, kaju_, мним
  { {0x9f630006,0x3e7a0039,0xa3c20037,0x4374002d}},	//   ävät_, būt_, ्यय_, нуют
  { {0x3f830027,0x7a3d0107,0xfc460066,0x0cba0011}},	//   daju_, rétn, _říct_, _उन्म
  { {0xcf890093,0x7a3811e7,0x7a12001e,0x2ca91254}},	//   _כט_, gíth, gātp, ktad_
  { {0xb4bc0044,0x7a3d000e,0x850c0037,0xa3c20037}},	//   _आने_, métl, _सेंट_, ्यम_
  { {0xfd100003,0x1c44002d,0x63ba001b,0x344b06bd}},	//   _حجم_, _знім, cetn, _учен_
  { {0xe9ff001a,0x67ef0058,0xceb20009,0xa3d10011}},	//   _nhắn_, _højs, ֣ין_, वयन_
  { {0xa3ab0044,0xceb20093,0xee3a002d,0xda7a0009}},	//   क्स_, כיל_, іна_, _ונקר
  { {0x3f830027,0xbc6a0012,0x25ad0032,0x7a380030}},	// [2580] baju_, زمان_, ifel_, sítk
  { {0xeafa0003,0x60c4003a,0xdb1c0054,0x7b160003}},	//   يرات_, _isim, _parà, وظائ
  { {0xdb1c000f,0xe9ff001a,0xe7db000b,0x91e60686}},	//   _bará, _chắn_, _וקיש, може
  { {0x63ba1255,0xdb1c052e,0xf9920012,0x25ad02a2}},	//   zetn, _cará, ئبا_, jfel_
  { {0x3952004a,0x50ba0012,0x55bb0009,0xe8940198}},	//   äys_, تداد_, _ומכו, халь
  { {0x7a38000e,0x7a361007,0xbfaa0024,0xdce00035}},	//   zíth, mátu, ітле_, samī
  { {0xa3c80044,0xd6d00003,0x97c50012,0x1dda0011}},	//   _लोग_, اقب_, عتهم, भालत
  { {0xddea0003,0xef180035,0x25a01256,0x386d1257}},	//   ترته_, _ceļa_, ngil_, ţeri_
  { {0x7a12001e,0xfe370009,0x91fd0035,0x7a380031}},	//   vātp, ורקי_, kpār, víth
  { {0xb05b027e,0xdb1c1258,0x46b60012,0x2d9f0730}},	//   hwäc, _zará, _يحاس, ague_
  { {0x3f83001c,0x629a004a,0xe2150015,0x63ba1259}},	//   vaju_, uuto, емны, retn
  { {0xdde3000d,0x63ba081f,0x629a125a,0xc05b0024}},	//   ărţi, setn, ruto, жів_
  { {0xc5f30093,0xd1260003,0x7a38125b,0x3f830e6f}},	//   _בדף_, ام_, ríth, taju_
  { {0xbbc80044,0xa01b0163,0x67ef00c5,0x7a38000f}},	//   रयोक, msök, _højr, síth
  { {0x3f83001c,0x60c402bd,0xa01b006f,0x7a38000e}},	//   raju_, _esim, lsök, píth
  { {0x7c3a03ce,0x38600025,0xdcc80081,0x25a0020d}},	//   lltr, _fuir_, _kỉ_, ggil_
  { {0xe81f0037,0xb955002d,0xd847002d,0x2d840010}},	// [2590] _बदला_, _явищ, _охоп, iame_
  { {0x41dd0037,0x9f45000e,0x2c64006f,0xe8d6000b}},	//   यावस, óló_, _död_, _נותר_
  { {0x92590047,0xe298002d,0xa3ab0037,0x7bc70051}},	//   чает_, дає_, क्ष_, _vaju
  { {0x2d84007a,0xa01b006f,0x64580c63,0x09e40024}},	//   jame_, ksök, _livi, коєн
  { {0xb068000a,0xdb1c000e,0x58d90024,0x25ad0248}},	//   وصول_, _vará, яддя_, vfel_
  { {0x764d003a,0x07a20014,0x7a3601cf,0xd0f80009}},	//   lmay, гашн, látt, ומדת_
  { {0x25ad007d,0xa01b006f,0x9f450054,0x75f5000e}},	//   tfel_, esök, _allò_, _házi
  { {0xcf580093,0x764d00a2,0xa3ab0037,0x6b8500b6}},	//   ובות_, nmay, क्र_, lahg
  { {0x2489125c,0x25ad02f1,0xa01b0248,0x9e4c0009}},	//   nsam_, rfel_, gsök, חֲזִ
  { {0x3ec40006,0x7d1a000b,0x25ad006f,0x13090015}},	//   ästä_, לֵיה, sfel_, зной_
  { {0xe7e30037,0xa91d009b,0x764d003a,0x98140003}},	//   खाना_, _deže, kmay, _شبكا
  { {0xc7a90093,0x2d840036,0x69cb125d,0xa01b0248}},	//   _לב_, came_, ndge, bsök
  { {0xe9ff0020,0x7e6100bd,0xe8f70247,0xa01b0031}},	//   _nhận_, _hulp, еля_, csök
  { {0x291e000d,0x2c64006f,0x6458125e,0x6e3b0097}},	//   ăta_, _röd_, _givi, llub
  { {0xa3dc0037,0xabfa0009,0x24460025,0xa3c80011}},	//   डार_, _מהסר, nôme_, _लोट_
  { {0xa2c30044,0x91fd001e,0x7a38000e,0x64580052}},	//   रबन्, spār, lítv, _zivi
  { {0xdd8f0003,0x908a0003,0x28bf0011,0xf50a0048}},	// [25a0] صول_, _عندك_, _शैलि, чнал_
  { {0x61ed00bd,0x75fc000e,0x443a0070,0x7a380031}},	//   _zoal, _nézn, ulp_, nítv
  { {0xdb1c0017,0x877b0009,0x0f7b01b0,0x25f20011}},	//   _març, _מאיי, _מריל, ीसदी_
  { {0xeac9001a,0xdb0f0030,0x30a601c6,0xa5bb0097}},	//   _mẹ_, ádát, еркв, _hjón
  { {0xb05b006f,0x2d84125f,0x7a38000e,0x2be00011}},	//   lvär, vame_, kítv, नादा
  { {0xe7e30037,0x3c340248,0xd12f0012,0x69db1260}},	//   खाया_, rävs_, حمه_, _enue
  { {0x4df40037,0x2d841261,0x75f801bd,0xf7730009}},	//   _इकाई_, tame_, _nízk, נקה_
  { {0xb5aa000a,0xc1ca0037,0x69e20030,0x28c70011}},	//   سابك_, ियोग, áteč, लिखि
  { {0x60c4003a,0x28160012,0x7986016d,0x64bc0011}},	//   çimd, _كورس, dakw, ्टेश
  { {0xa01b0163,0xdb1a024a,0x61ed1118,0x2d8f1262}},	//   rsök, leté, _soal, _edge_
  { {0xa01b006f,0x7a36000e,0x764d003a,0xed5902a1}},	//   ssök, játs, ymay, veže_
  { {0x2d8209ea,0xdb1a000e,0xdcc8001a,0xe919002d}},	//   _neke_, neté, _tỉ_, домі_
  { {0xa3c20044,0x984b0014,0x4e170009,0xf1d60011}},	//   ्या_, зява_, _אחאב_, धाजन
  { {0x2bd70321,0xdb1c0f14,0xdb1a0025,0x629e1263}},	//   _भोपा, _garç, heté, kupo
  { {0x764d00a2,0xdb010032,0xed590412,0x22660034}},	//   tmay, gflä, reže_, ótką_
  { {0xe9ff001a,0x433b000b,0xbdd50014,0xbddb0061}},	//   _phận_, _מעוב, ъобщ, _thèm
  { {0xdbf9003e,0xdb1a000f,0x764d003a,0xe7870001}},	// [25b0] _głów, deté, rmay, _пуно
  { {0xb6030029,0x2418002d,0xd91c000b,0x1368004c}},	//   čšin, нією_, _מוחל, ешци_
  { {0x764d003a,0x91bf001a,0xa01b000e,0x24890c0b}},	//   pmay, _phù_, kröz, ssam_
  { {0xdb1a000f,0x6149001e,0xe9ff001a,0x66041264}},	//   geté, _tūlī, _thận_, chik
  { {0x28f8002d,0x91bf001a,0xa3cc0011,0x7a3d0031}},	//   нець_, _chú_, _शोक_, tétj
  { {0x7e611265,0xd8b80012,0x95160009,0xd942004c}},	//   _pulp, عدنا_, _יקרא_, јеши
  { {0xdb1a000e,0xcf880012,0xa01b0032,0x8e490012}},	//   beté, رضون_, rsöh, ولتك_
  { {0xed590015,0xb6060027,0x7ae3004a,0x9758000b}},	//   мой_, ješć, äntu, עיהו_
  { {0x5dd40015,0xdb1c003a,0x61f6003a,0xf1bf0029}},	//   ующу, _parç, öyle, deá_
  { {0x75f5022d,0x6e3b08a1,0x7e611266,0x44331267}},	//   _názv, slub, _tulp, nox_
  { {0x4421001a,0x49ba0003,0x3f870864,0xfbd20009}},	//   inh_, واحد_, manu_, בתי_
  { {0x7a38000f,0xa5bb0028,0xc332000b,0x3f850028}},	//   sítv, _sjón, שוט_, ðlun_
  { {0xdb01000e,0x7a38000e,0xe44e0048,0x6d5c0030}},	//   jelö, pítv, _вж_, ěrat
  { {0xdb1a0272,0x9d1a0009,0x35a70011,0x889a0009}},	//   zeté, _קוסט, _गाड़, ובשי
  { {0x0eb90015,0xb05b006f,0x2cad1268,0xf7720009}},	//   нуты_, tvär, lted_, שקל_
  { {0xc692000b,0xdb010052,0x7a360bb3,0xdd920012}},	//   יאל_, rflä, ráts, شوط_
  { {0xdb1a000f,0x2cad1269,0xd24f0003,0xb05b006f}},	// [25c0] veté, nted_, _بني_, rvär
  { {0x0e660146,0x395f00b6,0xb05b02fe,0x629e126a}},	//   _икон, _agus_, svär, tupo
  { {0x6b8300ec,0x9ad5002d,0xdb1a000e,0x2cad0051}},	//   _meng, люці, teté, hted_
  { {0x4421001a,0x2018126b,0xb05b0032,0x91bf0081}},	//   anh_, liri_, nwän, _phú_
  { {0xdb1a000f,0x186705fb,0x629e126c,0x8b660012}},	//   reté, вачи_, supo, _لازم
  { {0xe9ff0020,0xdfd00003,0x91030001,0x6d460238}},	//   _phản_, صيب_, рпље, _izka
  { {0xe7e30037,0x52990014,0xcac7011d,0xa2e3026d}},	//   खाता_, _пътя_, _игре_, _корд
  { {0x2cad002a,0x91bf0081,0xceb30009,0xb8960012}},	//   fted_, _thú_, ׁיו_, _للرع
  { {0x2018044f,0xe4e6002d,0x236700eb,0x645c126d}},	//   kiri_, тійн, žnje_, _kiri
  { {0x6b8311d3,0x99800073,0x7a3d004f,0x2249126e}},	//   _ceng, _okių_, méti, _shak_
  { {0x6b8300ec,0x2cad0036,0x201800b6,0xf2c30014}},	//   _deng, ated_, diri_, асян
  { {0xc333015a,0x2ca00051,0xee290012,0xdb150042}},	//   יות_, kuid_, _كأنه_, _nazý
  { {0x2cad0036,0x6b830065,0x7d090002,0x7a38000e}},	//   cted_, _feng, czes, líts
  { {0xf7700003,0xdb170017,0x2ca00070,0xc0510009}},	//   قاف_, nexã, duid_, ֶ֖ם_
  { {0x0d670014,0x7a38000e,0xbe880015,0x8bbb0009}},	//   възм, níts, ксте_, _חזות
  { {0xd357000b,0x645c03ab,0x443e126f,0x6b831270}},	//   _בשוק_, _airi, llt_, _zeng
  { {0x645c00a2,0x6abb0011,0xe4a70048,0x6e350031}},	// [25d0] _biri, ईब्र, ърво, _ízbe
  { {0x91a00020,0x93940003,0x33741271,0x2bbb0012}},	//   _thị_, لجما, игур, بارة_
  { {0x49750001,0x940b0009,0xfb150012,0x7d0900b8}},	//   глес, וּאֵ, دواج, zzes
  { {0xa294007c,0x443e008b,0x5efa000b,0x0a94002d}},	//   раці, hlt_, _נפרד, рацю
  { {0x5d9a000b,0x61fd0010,0xa91d0029,0x69cd0051}},	//   _אברה, iksl, _beža, _maae
  { {0x645c00a2,0x443e000e,0x66021272,0xe50c0011}},	//   _giri, jlt_, _alok, _सेटि_
  { {0x7a38000f,0xb659002d,0x8ea40012,0x099b0012}},	//   gíts, нших_, لصين, _يضرب_
  { {0x6b831273,0x7a3d1274,0x2cad1275,0x3f87001b}},	//   _seng, béti, tted_, sanu_
  { {0x6b831276,0x3f871277,0x89370012,0x2cad0132}},	//   _peng, panu_, _شعرا, uted_
  { {0x2cad0036,0xdce40039,0x6602004a,0x753d05a8}},	//   rted_, nciā, _elok, _mysz
  { {0x66020065,0x7d0910ff,0xddda000e,0x6b831278}},	//   _flok, szes, _ettő, _veng
  { {0x2cad002a,0x60d60034,0x60c90192,0x8a06004c}},	//   pted_, _prym, _ksem, узме
  { {0x25e00044,0x657b00c6,0x6ba40028,0x6b831279}},	//   कारी_, mbuh, útgá, _teng
  { {0x7c92000a,0x04920003,0x66020002,0xdc9a0009}},	//   _الوص, _الوح, _zlok, _ניצל
  { {0x7f19002d,0x44270070,0xa8560009,0x3f85005e}},	//   віту_, _ijn_, טישה_, _melu_
  { {0x2ca00051,0xd6cf002d,0xd7570012,0x7c3e0227}},	//   tuid_, стi_, طلقت_, wlpr
  { {0x765d0a60,0x7a380031,0x75f50031,0x271f0011}},	// [25e0] _disy, zíts, _házs, यपुर_
  { {0x69c9001e,0x1bfc0011,0x307b0009,0x6d460030}},	//   īmeņ, एसएल_, _ראינ, _vzka
  { {0xda65000a,0x657b002c,0x60c90954,0x1c390024}},	//   لاني, kbuh, _asem, тять_
  { {0x6e9b000b,0xd259002d,0x7a38000e,0x7e9b000b}},	//   _אבטח, вці_, víts, _אסטו
  { {0x7bc10df5,0xddc40034,0x248d0dac,0x2ca0127a}},	//   kelu, rmiń, jsem_, quid_
  { {0x3f850eb4,0x7a3d0061,0x3eca0001,0x31570009}},	//   _celu_, réti, ећим_, אינן_
  { {0x60c9127b,0xdcfd001e,0x3f85017b,0x25e00011}},	//   _esem, _iesā, _delu_, काली_
  { {0x443e0480,0x52b20037,0x7a3d0025,0x657b020d}},	//   wlt_, ीबीस, péti, gbuh
  { {0xa0c90003,0xa91d0d6c,0x7a38127c,0x248d000e}},	//   _لذلك_, _teža, síts, gsem_
  { {0x78a201a2,0x43940001,0x03f80001,0x20070eea}},	//   muov, јанс, тној_, chni_
  { {0x7bce0101,0x8c37000b,0x6b880058,0x3f850097}},	//   _mabu, רטיס_, radg, ðlum_
  { {0xccf90002,0xcb130009,0xeac70009,0x6b880040}},	//   byś_, מלת_, נִי֙_, sadg
  { {0x7bc10fb3,0x9f4b0031,0x61fd127d,0x2aae0064}},	//   belu, ülön_, rksl, hýb_
  { {0xb8ed0037,0x7bce127e,0x753d0034,0xdcfd0035}},	//   _रन_, _nabu, _rysz, _nesā
  { {0x7a28003a,0xf3f9000d,0x1bfb0009,0x68f90034}},	//   sıta, _îţi_, _אלגב, zywd
  { {0xe4e7002d,0x7bce002c,0xe6640434,0xd4e70055}},	//   лізн, _aabu, стро, люзи
  { {0xdbd10051,0x69c2038e,0x78270003,0x7c15002d}},	// [25f0] _tüüb, deoe, _معدل, адає
  { {0xa91d0029,0x3f15002d,0x59dd0011,0x26e40011}},	//   _bežn, _вдос, याकर, _कपूर_
  { {0x753d003e,0xdb150164,0xdce4001e,0xd7f1001a}},	//   _wysz, _razó, rciā, _rõ_
  { {0x95640014,0x2a980012,0xd3370009,0x3f85001b}},	//   _гърд, ائلة_, נראה_, _selu_
  { {0x417c0009,0x7bce127f,0x225906dd,0xc4c600ae}},	//   תנדב, _fabu, írky_, _بْ_
  { {0xb8cd0044,0xdfd10003,0xa6950001,0x60c9009b}},	//   _कम_, زيع_, ариј, _vsem
  { {0xc7f80009,0x7bc11280,0xdd2f0030,0x2c690064}},	//   רזות_, velu, věřo, _súd_
  { {0x8cb50083,0x8645004c,0xb5fb0031,0x7bce1281}},	//   асоч, јниж, _hiáb, _zabu
  { {0xb8820066,0xdb050052,0x55bc0009,0x4462003c}},	//   říze, gehö, תמחו, овыв
  { {0x68f6004a,0x248d1282,0xa01b008e,0x76401283}},	//   äyde, rsem_, isös, almy
  { {0x16050044,0xbb4500b3,0x248d1284,0x3a260109}},	//   रसार_, ренк, ssem_, имог
  { {0xa06a0046,0xc1060003,0x186a00be,0xf8a70003}},	//   кама_, لوجي, ками_, ية_
  { {0x3949003e,0x53d00011,0x3eb10032,0x95c40012}},	//   _czas_, _थोकश, etzt_, _دينه
  { {0x7d0d0002,0x661b03ec,0x7afa0192,0xbd440012}},	//   dzas, liuk, bytt, _انهي
  { {0x3f8a0027,0xe73a00f5,0x539a0009,0x7a3d0031}},	//   rabu_, тев_, _סיקו, vétv
  { {0x2aba0009,0x75f503a7,0x7bce1285,0x64411286}},	//   _ימצא, _zázr, _sabu, llli
  { {0xd4670098,0xa3d10037,0xddd5000e,0x9a3b0009}},	// [2600] иите_, वयं_, gszű, _שתפק
  { {0x9b850003,0x60c90060,0x9f4c0031,0x4f960357}},	//   مؤمن, çeme, ódó_, _триу
  { {0x4f9b000b,0xbf9b0009,0x9f9b0009,0xa79b0009}},	//   _בביצ, _בייש, _בסיפ, _בשיח
  { {0xdb18015b,0xe8fa096e,0xf3e90009,0xbcfb0031}},	//   _navý, кле_, וף_, _igén
  { {0x7d0d0002,0xdb1a000e,0x8d63002d,0x26c70034}},	//   czas, vetí, _євре, ewno_
  { {0x4813002d,0x66090051,0x7afa004a,0xd00f0012}},	//   оміс, ehek, yytt, ولن_
  { {0xddc4001e,0x29000029,0x42d50024,0x07a3004c}},	//   rmiņ, šia_, _літу, цајн
  { {0xa01b0163,0x644103d5,0x9757000b,0x66f70009}},	//   nsör, elli, סיקו_, ימצא_
  { {0x186a002d,0x4fa6002d,0xa06a0021,0xda5b0009}},	//   _рази_, _визв, _раза_, _יכלל
  { {0x34b70093,0xf3660046,0xe9ff0020,0x6908003a}},	//   ספים_, штин, _phần_, ırdı
  { {0x8aa300be,0x5a350014,0xa3c50037,0x32660001}},	//   оряд, йнот, उज़_, јтов
  { {0xc27b000b,0xc984035c,0x6df30012,0x4efb0009}},	//   כרטי, жури, _وكلا, _שהאו
  { {0x1bd40098,0x7afa004a,0x6b4f000e,0xdb1a000e}},	//   _голя, sytt, tógé, ldtü
  { {0xe9ff001a,0xfe730012,0xe3af0012,0xd918003c}},	//   _thần_, قدر_, _قرى_, рью_
  { {0x22940003,0xc6680001,0x3a260070,0xa3e00011}},	//   _البس, иште_, knop_, थाई_
  { {0x7a28003a,0xd35b0009,0x735b0009,0x6a140012}},	//   nıtl, _בדול, _בכוח, _وبير
  { {0xf3670014,0x24f80015,0xb4780009,0x7c8709f8}},	// [2610] атен, анты_, רָֽי, рубе
  { {0x60cd1287,0x201c013a,0x04c80012,0x7d0d0034}},	//   _isam, jivi_, ؤولي_, rzas
  { {0x93190003,0x8c3d003a,0xd4040024,0x9e350048}},	//   دقاء_, nuşa, цяти, _генч
  { {0xa2d70037,0x7a3d10b3,0x753d0031,0x442a1288}},	//   यित्, pétu, üszk, _ejb_
  { {0x83870047,0xe9ff0020,0x70190024,0x64411289}},	//   _выбе, _nhấn_, лікт_, ylli
  { {0xed560009,0xd0980012,0x25a9005e,0x8d5a0009}},	//   _לברר_, شئها_, lgal_, _תכשי
  { {0x386906db,0xa294002d,0xaa9406bd,0x67bc0009}},	//   _luar_, _марі, _мирч, דמוק
  { {0xc4851271,0x4c85057e,0xf1cf0011,0x7a280060}},	//   блик, блив, _सोचन, gıtl
  { {0x6609008e,0xe9ff0081,0x61ed008e,0xac960012}},	//   rhek, _chấn_, öalu, منيا_
  { {0xf7700003,0x321d0002,0xf09f10ac,0x9ff40012}},	//   _قام_, liwy_, drà_, _وألص
  { {0x7c220061,0xd7f806e6,0x3946001e,0xc5d50024}},	//   éori, _тут_, _šos_, _гіль
  { {0x4dd40012,0x8a390048,0xf7690009,0x60db128a}},	//   _وتنس, ияят_, _טק_, _krum
  { {0x2a600051,0x89da000b,0x89360012,0x80260012}},	//   _viib_, אחרי, إعجا, مرسم
  { {0x43850003,0x249f0058,0xa9360009,0xbb850012}},	//   _الثق, mrum_, מטרה_, _الثي
  { {0x2bb80003,0xd1380002,0x60cd128b,0xf09f128c}},	//   _خانة_, łą_, _esam, arà_
  { {0x05660014,0x629c001e,0xf09f0054,0x201c0604}},	//   сван, šroc, brà_, zivi_
  { {0x4d4a0001,0x7a3d0028,0x249f006f,0x61e40160}},	// [2620] упан_, rétt, nrum_, _inil
  { {0x69c6060f,0x25a9007b,0x249f0097,0xdb1a0482}},	//   leke, agal_, irum_, letá
  { {0x7a28003a,0x69c60070,0x8c1a000b,0x7ed50024}},	//   yıtl, oeke, נועי, _діяч
  { {0xdb07000e,0xc332000b,0x994a0012,0xb05b0032}},	//   émár, הוב_, هلال_, ewäh
  { {0x201c01a2,0x10a3128d,0x60db0bb5,0xadd70009}},	//   tivi_, зичн, _crum, _הוכח_
  { {0xdb1e000f,0x2bb70066,0x7644003a,0x7a3d122d}},	//   lepí, _věcí_, lliy, nétr
  { {0x2d800002,0xdb0e004a,0x201c0dce,0x1a780009}},	//   obie_, äjän, rivi_, _כְּמ
  { {0xe5c60015,0x69c6004a,0x443c0028,0x5c98010c}},	//   сско, jeke, _skv_, акия_
  { {0x8cdb0037,0x69c6128e,0xdce40034,0x4444128f}},	//   नियो, deke, bcią, ol_
  { {0x600b003a,0x7a28003a,0xf09f00c1,0xda7a118d}},	//   _küme, sıtl, vrà_, лям_
  { {0x76441147,0x61f61013,0xc43b0009,0x643b0009}},	//   kliy, _boyl, רתיי, רעינ
  { {0x4444008b,0xf09f1290,0x69c61291,0x44220031}},	//   hl_, trà_, geke, ők_
  { {0x63bc02a1,0x443a1292,0xf09f01a0,0xfe370009}},	//   _obrn, kop_, urà_, _פרדי_
  { {0x3e6e0013,0xf09f01a2,0xd6c60003,0xa8ab000b}},	//   _být_, rrà_, وق_, נֹכִ
  { {0x8c1b0093,0x2bb7000b,0x44440066,0x6298000e}},	//   _תווי, _הפוך_, dl_, ávol
  { {0x5eb4003c,0xdce40034,0x60cd016d,0x69c61293}},	//   яйст, zcią, _tsam, ceke
  { {0x60c400a2,0x7bc50359,0xa2d00011,0x94190048}},	// [2630] çiml, tehu, धिक्, ажат_
  { {0x4378000b,0x7644003a,0xbddb0061,0xf3670ba0}},	//   שְּׁ, aliy, _chèr, стан
  { {0x2ca00005,0x76440060,0x9fbd0034,0xb9950012}},	//   arid_, bliy, złów_, قلاب
  { {0xddc1007d,0x81a70003,0x314b0009,0x7c3a1294}},	//   _mulţ, إحال, ְתַּ, hotr
  { {0xb05b0029,0x75fc0031,0x378900b5,0xf9940009}},	//   dväz, _jézu, абло_, פרס_
  { {0xd0060014,0x69c6110c,0xbddb0025,0x7c3a001b}},	//   жеше_, zeke, _thès, jotr
  { {0x3209003a,0x69c6000e,0x57fc0009,0xb05b0032}},	//   _olay_, yeke, רלוו, rwäh
  { {0xb05b0052,0x7c281295,0xc3320009,0x72050012}},	//   swäh, endr, _חול_, _بورم
  { {0x69c6000e,0xdb1e000d,0xd8740012,0x37c50012}},	//   veke, cepâ, _فالب, _ويرف
  { {0x0c360003,0x32090115,0x24520012,0x61e41296}},	//   يكية_, _alay_, ونيس, _snil
  { {0xdcfb0010,0x2d800002,0x69c61297,0x8c1a0009}},	//   mbuč, ybie_, teke, שותי
  { {0x3ea70054,0xcad6000b,0x6f0b003a,0x2d8b0027}},	//   munt_, קורת_, ımcı, _nece_
  { {0xa06a0046,0x44440066,0x443a002c,0x7c460028}},	//   рага_, yl_, yop_, ðurö
  { {0x69c6000f,0x290c0002,0x515a000b,0xee3f0004}},	//   seke, ąda_, יכרו, _aký_
  { {0x998c000e,0x9a460012,0x69c61298,0xdb010032}},	//   ődő_, _وضعه, peke, nflü
  { {0x2fc70101,0x62980064,0xe57a019c,0x2ca01299}},	//   heng_, ávom, рза_, trid_
  { {0xee37002d,0x9f880028,0xbddb0061,0x4444129a}},	// [2640] іну_, kóði_, _chèq, tl_
  { {0xa3e70011,0x7656008e,0x244f0060,0xeaba0048}},	//   भाष_, smyy, yüme_, ийз_
  { {0x443a00bd,0x2fc7002c,0x2d8b00c1,0xf1bf000e}},	//   rop_, deng_, _fece_, knál_
  { {0xa3d5015f,0x660d0070,0x752f0002,0x2d8b003a}},	//   ाएँ_, chak, żczy, _gece_
  { {0x69bc0037,0xc5f30009,0xf8ca0011,0x6e3b129b}},	//   ष्यी, _חדר_, िबिय, doub
  { {0x2bae015f,0xd6d00003,0x98cb000b,0x2d8b000d}},	//   ज्ञा, فقت_, שֶׁ֥, _zece_
  { {0x23270098,0xa3e70037,0x6e940012,0x4667003c}},	//   _дори_, भार_, ألبا, орым_
  { {0x16370351,0x7ae1000f,0xdcba0014,0xd5b704b3}},	//   يسية_, _álta, ащо_, ось_
  { {0xf6530093,0xa3d50037,0x442a010b,0xddc90035}},	//   וצה_, ाएं_, ицом_, kmeņ
  { {0x2240000f,0x60cd0e23,0xc0d30003,0x7c3a0010}},	//   _akik_, çame, _زيمب, uotr
  { {0xe73a002d,0x3209129c,0x6604079b,0x79820034}},	//   _теж_, _play_, kkik, obow
  { {0x5ce60003,0x6010006f,0x8c3d003a,0x7c3a129d}},	//   _وكال, _jämf, luşl, sotr
  { {0xf993000b,0xddcd0002,0x1e570009,0x2d8b004b}},	//   ורר_, ymał, _ושאר_, _rece_
  { {0x6e200101,0x39450039,0x600b0051,0x7d0c0060}},	//   limb, āls_, _sümb, ılsı
  { {0x28d10044,0xed8b0046,0x65790061,0xde780009}},	//   _दैनि, исак_, _éché, מְּך
  { {0xdb1c0052,0x22460ff4,0xa5bb0028,0x6e2002a0}},	//   _darü, jlok_, _njót, nimb
  { {0x69c60028,0xa3e70011,0x31690031,0xb5fb0031}},	// [2650] _ókey, भाल_, _igaz_, _fián
  { {0x6e20007d,0x660d004a,0x9f580028,0x66040115}},	//   himb, shak, skrá_, akik
  { {0xc7b2000b,0xa91d09d2,0x99890034,0xdb080018}},	//   _אבי_, _težk, _okaż_, cedô
  { {0xdce90027,0x7bc80979,0xf1ab0012,0x3f91001b}},	//   zbeđ, hedu, شاؤه_, lazu_
  { {0xdb150017,0xd1410002,0xdb1a003a,0x2fc700b6}},	//   _razõ, knął_, betç, teng_
  { {0xf7710351,0x46f50014,0xb4fa0009,0xacfa0009}},	//   رات_, зчит, _הפשי, _ההשכ
  { {0x63b40042,0x60cd0411,0x7d000097,0xf1bf0031}},	//   žený, çamb, eyms, tnál_
  { {0x2fc7002c,0xc3320009,0x909b0012,0xdb1a008e}},	//   seng_, _נון_, _نضطر_, ietä
  { {0xdb1a004a,0xec760015,0xe5250024,0x6e3b129e}},	//   hetä, ппы_, ядип, roub
  { {0x4421102c,0x7bc80051,0x4374002d,0xf1bf000e}},	//   nih_, gedu, муют, snál_
  { {0xf8a9000b,0xed590035,0x3f9e0097,0x7bd5129f}},	//   _תש_, ieži_, ótum_, _mazu
  { {0xdeba000b,0xdb1c0002,0xdb1a004a,0xb6ba0009}},	//   _למעל, _zaró, detä, _לצעי
  { {0x2bac0037,0x257c0066,0xa5bb0028,0xad270003}},	//   _चाला, nálů_, _ljós, _براو
  { {0xd7f20003,0x4421048b,0xdb05000e,0x6cd20003}},	//   ركز_, jih_, eghí, _أقوا
  { {0x8c3d003a,0xa3c10037,0xc0520009,0x5b370012}},	//   nuşm, ्जन_, גזם_, _بعشر
  { {0x8afa0093,0xba9a0009,0x12fa0009,0x9f630030}},	//   _להצי, _הסקי, _להצב, ívám_
  { {0x66040006,0x7bd512a0,0x3e7112a1,0x98ac0035}},	// [2660] rkik, _bazu, _lát_, ādē_
  { {0x7bd5007d,0xa5bb0028,0x442112a2,0x21370009}},	//   _cazu, _bjós, gih_, _מטפל_
  { {0xdb1a00a2,0xa1c60001,0xb5fb000e,0x3f8c013a}},	//   retç, збед, _kiál, _redu_
  { {0x23720039,0xdb1a0060,0xdb1e01a0,0x7bc812a3}},	//   _šajā_, setç, repà, zedu
  { {0x442100ec,0x38b60065,0xdce40002,0x200e00b6}},	//   bih_, nær_, ycię, thfi_
  { {0x660b005e,0x69dd0097,0x25ad12a4,0x22460097}},	//   _algk, _ósen, egel_, slok_
  { {0xc05900bc,0xd2a7002d,0x6e2002a0,0x78a20030}},	//   ції_, _нкре_, timb, srov
  { {0x25ad000e,0xddcf000d,0xd29b000b,0x35b30048}},	//   ggel_, _micş, _לשלט, ебър
  { {0x0ee90011,0xb3ea0012,0x85730012,0x10a30024}},	//   _ऑप्स_, معدل_, رديئ, _питн
  { {0xb8650003,0xac18002d,0xd7760012,0x307b0009}},	//   _قالو, іону_, _رائع, _לאמנ
  { {0x9f7b000b,0x0bb7000b,0x60c40010,0x2d9d0002}},	//   _הנבח, הלים_, _apim, ówek_
  { {0x442102a1,0x60990012,0xd1410034,0x3206020d}},	//   zih_, ينجس_, snął_, nkoy_
  { {0x5c060098,0x3f9100d9,0xb5fb052e,0xfdf70009}},	//   _няка, tazu_, _diál, _מצאת_
  { {0xdb1a0006,0x5453007c,0xa3e30321,0x96050011}},	//   tetä, _звіт, _पोप_, रस्ट_
  { {0x3bbb0214,0x69c00026,0xb3bb000b,0x4421048b}},	//   _המוד, _obme, _המוכ, vih_
  { {0xc27b000b,0x443e12a5,0x77fa0011,0x442c0032}},	//   _פרחי, lot_, ्सुक_, lnd_
  { {0x42380093,0x1df80015,0x442c0070,0x2d580021}},	// [2670] _מנהל_, четы_, ond_, зить_
  { {0x443e0039,0xf0920093,0xb8830066,0xc8b40012}},	//   not_, _שני_, říst, _أصيب
  { {0x8c410052,0x77ba000b,0xe7f00037,0x2d920061}},	//   äßig, _ומתח, चाना_, baye_
  { {0x442112a6,0x661d0028,0xa2a40037,0x99a80012}},	//   sih_, _umsk, _किन्, كُمْ_
  { {0x3e710020,0xddc400a2,0x89370003,0xa5bb0028}},	//   _sát_, lmiş, أعضا, _fjór
  { {0xd366000a,0x443e0039,0xc4d2000b,0x7c3e00b8}},	//   _له_, jot_, _שגם_, copr
  { {0x66ff0037,0xddc4003a,0x629c000e,0x443e12a7}},	//   ैनिक_, nmiş, árol, dot_
  { {0xf2d20093,0x386d12a8,0x8c3d0060,0x644812a9}},	//   _בעל_, _tuer_, ruşm, eldi
  { {0xda340015,0x443e0a9d,0x69cb12aa,0x629800b8}},	//   _четы, fot_, mege, _avvo
  { {0x04560003,0x69d6003a,0x6e2d0032,0x93c2004b}},	//   ولية_, _saye, hnab, _ţăra
  { {0x69cb0070,0xff530003,0x61fb12ab,0x69d60573}},	//   oege, _أخذ_, _koul, _paye
  { {0x29020002,0x61fb004a,0x7ae3004a,0x69cb00c7}},	//   tyka_, _joul, änty, nege
  { {0x9f58000e,0x20040017,0x61fb0ebe,0xbbf50012}},	//   özök_, êmio_, _moul, _يستث
  { {0x9474000a,0x60c4003a,0x764912ac,0x29020504}},	//   _أدنا, çimi, lley, ryka_
  { {0x7f430047,0x6fbf0037,0xa3e70011,0xa3de0011}},	//   верж, ल्यू, भाई_, _दोष_
  { {0x6e2d0065,0x7649033b,0xdbcc0028,0x61fb000d}},	//   gnab, nley, lóðu, _noul
  { {0x75d3000a,0x89eb000b,0x3eaa000d,0xa99b0009}},	// [2680] ضيلا, _וַיֵ, subt_, _ובפר
  { {0x6faa0003,0x4a790009,0x61e912ad,0x27f70012}},	//   _بهدف_, ַרְב, _anel, _يفيد_
  { {0x764900a2,0x600b0051,0x6d460002,0x69cb0054}},	//   kley, _kümn, _wyka, fege
  { {0x61fb12ae,0x69cb0b3d,0x6f030002,0xb9260003}},	//   _coul, gege, dync, وفاي
  { {0x442c0065,0x61fb0061,0x644312af,0x7c3e0404}},	//   ynd_, _doul, _okni, popr
  { {0xdb1c0065,0xebf40009,0xdfd00012,0x33d50024}},	//   _farð, _אֶֽת_, ايث_, _піст
  { {0x7649003a,0x61fb03b1,0x7d040137,0xe7c00011}},	//   fley, _foul, lyis, श्यप
  { {0xceb30093,0x3ea012b0,0xf1bf000e,0xb05b0052}},	//   דיה_, čit_, rnák_, nwär
  { {0xdca30001,0x26c50051,0x443e12b1,0x7d0412b2}},	//   вањи, _eplo_, tot_, nyis
  { {0x442c0742,0x70fb0009,0x60fb0009,0xa2f4003c}},	//   und_, _והמח, _והמק, епоч
  { {0x442c0795,0x443e12b3,0x78a60159,0xd5af12b4}},	//   rnd_, rot_, erkv, _ис_
  { {0x7d040006,0x20ca0037,0x7de50024,0xdddc0030}},	//   kyis, िबंध, _піід, dprů
  { {0xc1050003,0x443e1150,0x9cb30012,0xdb1e005e}},	//   روسي, pot_, _لمنت, lepä
  { {0xa294002d,0xddc4003a,0xdb1e0018,0x7d160034}},	//   _закі, tmiş, cepç, dzys
  { {0x683f0066,0xd0100003,0x6295000e,0x501b0009}},	//   vádě, جلّ_, ázot, קולו
  { {0xc333000b,0xddc4003a,0x7c870001,0x600b0051}},	//   _שוק_, rmiş, дуже, _gümn
  { {0xde640014,0xdc550001,0x69cb0dcc,0x61fb12b5}},	// [2690] търп, евањ, vege, _roul
  { {0x61e90070,0x7649003a,0x69cb0832,0xa4b70009}},	//   _snel, zley, wege, ולמה_
  { {0x7649003a,0x65950024,0x764012b6,0x765b0060}},	//   yley, _пану, komy, ymuy
  { {0x76400002,0xdb1c0028,0x50b50015,0xdddd0034}},	//   jomy, _varð, еску, _wisł
  { {0x61fb0108,0x7d160002,0x4e16000b,0x6d7a0009}},	//   _voul, czys, _נחשב_, _מארח
  { {0x61fb0036,0xd0110003,0x78ab0070,0xf8070024}},	//   _woul, طلع_, rugv, ьчен
  { {0x7649003a,0x20070028,0xba740012,0x2d8f0040}},	//   tley, rkni_, _لاقت, _pege_
  { {0x61e912b7,0x63ad000d,0xd0d50048,0x31c4004c}},	//   _unel, şină, _побъ, _исув
  { {0x764900a2,0x3e75006f,0xe7e001c7,0x88c70012}},	//   rley, _låt_, _गोवा_, _تتأل
  { {0xaf070001,0x2d8f0052,0xdb1e005e,0x7f840012}},	//   _очек, _wege_, bepä, _للكن
  { {0xd9eb0011,0xda0a0012,0x7649020d,0x8c3d004b}},	//   टांत_, كيده_, pley, nuşi
  { {0xc332000b,0xc0490009,0x96350024,0x7afc0248}},	//   רוט_, _הז_, _янец, ärta
  { {0xa3b70037,0xa3c10037,0xe5070012,0x487a0048}},	//   _छाप_, ्जा_, _تباي, ясня_
  { {0x7bd80010,0x34fa0009,0xb4fa0009,0xa3de0011}},	//   _gavu, _מהנד, _מפני, _दों_
  { {0x96560001,0x84640014,0xe7f00011,0x92b50012}},	//   еђај, _ръце, चाता_, _أحتا
  { {0xee3a007c,0x7d040006,0x660912b8,0xfb1a0009}},	//   їна_, tyis, nkek, _מוצמ
  { {0x2cad002a,0x644100ff,0xa3b60011,0x64a305f7}},	// [26a0] nued_, ooli, ङ्क_, лата
  { {0x7d16003e,0xa3e70037,0x113b0009,0x6e24005e}},	//   rzys, भाग_, _מתפל, siib
  { {0x7d16003e,0xa3b70037,0xa3c10037,0x80250012}},	//   szys, _छान_, ्ज़_, _جريم
  { {0xf9920003,0x44250d8a,0xa2d50011,0xda100011}},	//   ابا_, hil_, णिज्, ासित_
  { {0x63ab0066,0x644112b9,0x00da0012,0xab630034}},	//   álné, koli, ثبات_, ążym
  { {0xf0930009,0xe8d9001a,0x889b0009,0xd7e7004c}},	//   ננו_, _ngờ_, לבני, емље_
  { {0xa2e300ac,0x69c412ba,0xa3b30011,0xc7b30009}},	//   _йорд, _obie, टलन_, אבו_
  { {0x7bd812bb,0xdb1e0051,0x387f12bc,0x629c0f27}},	//   _savu, repä, ţuri_, šrok
  { {0x2cad002a,0xddde0035,0xed57004c,0x5d540048}},	//   gued_, _atpū, ноћ_, ъкит
  { {0xdcef001e,0x442512bd,0xe0d70024,0x600b0060}},	//   _secī, gil_, _яву_, _cüml
  { {0xa3b60037,0xf413000b,0x645e12be,0xb05b0032}},	//   ङ्ग_, רפת_, impi, ltäg
  { {0xdc1200a2,0xc3330093,0xb87b0066,0x68e412bf}},	//   rşıl, טות_, jvíc, _brid
  { {0xc05b002d,0xb5fb000b,0x8dfb000b,0x68e40054}},	//   зів_, _מלאכ, _מהאת, _crid
  { {0x9cd70009,0x20d6001b,0xbd290012,0x442512c0}},	//   _נווה_, džić_, _تأمل_, cil_
  { {0x05870001,0x3d080011,0x9f340024,0x6f640012}},	//   еузм, िनके_, гері, ُهُم
  { {0xf6530012,0x9f450060,0x45d404a5,0xaa58003c}},	//   ائس_, _rolü_, лосс, _пищу_
  { {0x629a12c1,0x95c40003,0xa6340024,0xdb010032}},	// [26b0] lsto, طيله, унті, uflö
  { {0x69cf12c2,0x69c4083f,0x600b12c3,0xbca40012}},	//   lece, _zbie, _kümm, املي
  { {0x78bd0052,0x69c40034,0xe9d90034,0x90340012}},	//   ltsv, _ybie, _paź_, _حريص
  { {0xc27b000b,0xdbd701a3,0x629a12c4,0x69cf0cc4}},	//   פרדי, _sääs, isto, nece
  { {0xfd96000b,0x764d003a,0xdbd7015e,0x629a0032}},	//   _בדרך_, mlay, _pääs, hsto
  { {0x6008002d,0x25bf0132,0x63b50034,0x78bd0032}},	//   ннім_, wful_, _uczn, itsv
  { {0x764d003a,0x69cf0225,0x10140012,0x25bf0132}},	//   olay, kece, دبند, tful_
  { {0x78a4001c,0x764d0d33,0x64410034,0x7ceb0097}},	//   šiva, nlay, woli, jörð
  { {0x34b20003,0x25bf12c5,0xe7b20011,0x764d016d}},	//   لميز, rful_, _जालप, ilay
  { {0x13090015,0x23670027,0x2b9c0066,0xc60e0011}},	//   дной_, žnju_, mácí_, _सत्य_
  { {0x764d00a1,0x2cad002a,0x2bd00037,0x8bd60009}},	//   klay, sued_, तज़ा, דותו_
  { {0x412a00b3,0xa2c40011,0x82880009,0x644112c6}},	//   домо_, _रहस्, עְתֶ, soli
  { {0xc19a000b,0x6606000e,0x764d006f,0x69db0052}},	//   ושרי, ökke, dlay, _maue
  { {0x394c001e,0x2ca912c7,0xf0920009,0x764d12c8}},	//   āds_, drad_, שנם_, elay
  { {0x539a0093,0xa0670a25,0x69cf0164,0x78bd0ad2}},	//   _חיצו, тара_, bece, atsv
  { {0xe8df001a,0x3ea5000e,0x69c412c9,0x49c70048}},	//   _cuịa_, álta_, _ubie, _алън_
  { {0x8e55002d,0x3b960001,0x05660345,0x93bc004b}},	// [26c0] утрі, вјет, тван, mnăr
  { {0x61ed12ca,0x31570009,0x7bc112cb,0xf41f0064}},	//   _znal, _ביפן_, nflu, _zväz_
  { {0x69db0052,0xe73a0015,0xe2970ba0,0x93bc004b}},	//   _baue, _цен_, вах_, onăr
  { {0xd7b20037,0x2ca90051,0xcaa50003,0xa2a40011}},	//   _जाँच, brad_, اصلي, _किस्
  { {0x69db0052,0x8c3d003a,0x20d30012,0x21670681}},	//   _daue, luşu, لتوج, вици_
  { {0x9f650029,0xbcfb000e,0xdb210029,0x63830014}},	//   _štát_, _egés, štát, _вгра
  { {0x48ee015f,0x69cf00a2,0xf773000b,0x99860003}},	//   _आपको_, yece, סקה_, _للأو
  { {0x7bdc00c6,0x7f3b000b,0xade3002d,0xc6930009}},	//   _haru, ועצו, ацьк, באה_
  { {0x260302d1,0x7ceb0028,0xa3e70011,0xd7b20011}},	//   _años_, vörð, _मोड_, _जांच
  { {0x8af805fb,0x74140012,0xe3af0012,0x764d0060}},	//   енос_, اودا, يرٍ_, zlay
  { {0x764d003a,0x60140054,0x6d4f0030,0xb8820030}},	//   ylay, _càme, ýcar, říle
  { {0xba9b0009,0x7bdc12cc,0xdddc0034,0x444412cd}},	//   וסטי, _laru, żyłe, ho_
  { {0x63f60003,0x3e7812ce,0x69dd12cf,0xa3b30011}},	//   _لأغر, _hét_, rdse, _टाल_
  { {0x3e78000f,0xc953000b,0x444412d0,0x69cf12d1}},	//   _két_, שמש_, jo_, sece
  { {0x3e78000e,0xb4cb0037,0x764d039a,0x5f9412d2}},	//   _jét_, लब्_, tlay, рист
  { {0x3e78001a,0xa6340024,0x6edb0009,0x4e180012}},	//   _mét_, ансі, וחלפ, نتقد_
  { {0xe3900020,0xda100037,0x764d12d3,0x5d550b48}},	// [26d0] _điề, ासरत_, rlay, укат
  { {0x600b003a,0xf8bf0061,0x69db12d4,0x9b950012}},	//   _mümk, mté_, _saue, الات
  { {0xba740003,0x8c3d003a,0xf8bf0e90,0x764d12d5}},	//   لانت, muşt, lté_, play
  { {0xc3330093,0x8c3d003a,0x68e2001e,0x6010006f}},	//   בוע_, luşt, _šodi, _jämn
  { {0x444412d6,0xf8bf0706,0xbcfb000e,0xa9280066}},	//   bo_, nté_, _egér, vyžá
  { {0xf8bf0061,0x6010006f,0x8c3d003a,0x7bdc12d7}},	//   ité_, _lämn, nuşt, _garu
  { {0x8cdb0037,0x56920001,0x68e202a1,0xaa6711e0}},	//   निको, бајт, avod, _атак
  { {0xa3c10037,0xcf58000b,0x6010006f,0x64450312}},	//   ंभव_, כבות_, _nämn, lohi
  { {0x626c000d,0xb5fb0018,0x24590c04,0x865c0009}},	//   _uşoa, _fiáv, hème_, ודהי
  { {0xabd50001,0x87d70003,0x23d50867,0xe8550012}},	//   уциј, _جغرا, уцир, _صناد
  { {0x6d4b0002,0xcad50009,0xa22a0373,0xf8bf0025}},	//   _wyga, נוֹת_, ежна_, eté_
  { {0xd3360009,0x7bc1086a,0x624801e3,0x3f9812d8}},	//   טרתה_, sflu, eñor, waru_
  { {0x444412d9,0xc985004c,0x93bc004b,0x6d4b0060}},	//   yo_, јуџи, rnăr, _uyga
  { {0x3e710026,0x6e29008b,0x70560003,0xdd2f0066}},	//   _ešte_, lieb, انسا, měňo
  { {0x3e780020,0x1b49002d,0xdb1c0107,0x8c1a000b}},	//   _xét_, _язки_, _obrá, _רוצי
  { {0x660d0101,0x44440501,0x7bdc12da,0x2bc60011}},	//   gkak, wo_, _saru, र्ना
  { {0xee3708b0,0xf8bf0061,0xf1bf000e,0x7d1b0052}},	// [26e0] унт_, cté_, rnát_, nzus
  { {0xb05b004a,0x660d002c,0xd0f70009,0x6e290032}},	//   ttäe, akak, _עמית_, hieb
  { {0x2cbf0005,0x41aa0014,0x799612db,0x7d09008e}},	//   htud_, евен_, _keyw, hyes
  { {0x7bdc12dc,0xa2a50011,0x6abe0032,0xc9850012}},	//   _waru, _चटर्, rtpf, لشهي
  { {0x6736001e,0x79b7000b,0x3d0d0037,0x859b0009}},	//   šajā, רלנד_, िनों_, _אשכו
  { {0xc0e70012,0xd6d00012,0xf6b40012,0x8eb40012}},	//   افون_, ققت_, لمتج, لمتش
  { {0xf8b10037,0x394d002a,0x6d5d0028,0xc7d7000b}},	//   _जम्प, _eyes_, ýsan, רוצי_
  { {0x7c280032,0x7d1b0032,0xa5bd0073,0x3ce612dd}},	//   widr, fzus, liųj, _prov_
  { {0x27ef0013,0xc19b000b,0xb8820066,0xd3700012}},	//   ální_, _רשמי, říje, يهة_
  { {0xd12f000a,0x610a0039,0xc4d3000b,0x986a0003}},	//   _عمل_, _vēlā, צגת_, _أحرف_
  { {0x2bc60037,0xe9ff001a,0x23c60037,0x2bf70009}},	//   र्या, _chặn_, र्यद, אמין_
  { {0x9d9a0003,0x54e60003,0xe9df0029,0x9f5e08cf}},	//   _أنشئ_, _مستق, udú_, _noté_
  { {0xf8bf0061,0x75d30003,0xad8b000b,0x3d000037}},	//   uté_, _دينا, _נְאֻ, ोनों_
  { {0x2bc60044,0x75fc000f,0x1cb7000b,0xf8bf0061}},	//   र्मा, _nézz, _עלול_, rté_
  { {0xdce000a2,0x6b9a0054,0x8c3d003a,0xaed50024}},	//   mamı, matg, ruşt, шовш
  { {0x66020005,0xdce000a2,0xc1050003,0xf8bf0061}},	//   _jook, lamı, _نوعي, pté_
  { {0x20010051,0xcd340012,0x2bc60011,0x94770012}},	// [26f0] _tohi_, مركب, र्भा, ادرا
  { {0x6fb20037,0x60cd002c,0x6b9a0054,0x660212de}},	//   _जाएं, _ipam, natg, _look
  { {0x7c2f0025,0xbcfb0031,0x877a0009,0xdddc001b}},	//   écri, _egép, _באתי, sprš
  { {0xa294002d,0x5efa000b,0xfde90011,0xdb1a0034}},	//   саці, _ספרד, _ऑफिस_, letó
  { {0x759a000b,0xa9350015,0xdce0003a,0x71270012}},	//   _בסרג, шедш, kamı, درال
  { {0x2898000b,0x601008ec,0x7ed50012,0xdee50012}},	//   נדון_, _näml, لزبا, لأعي
  { {0xe5710003,0xf2e4002d,0x6e290070,0x6fb20012}},	//   يطة_, _люто, tieb, زميا
  { {0x7aea00c5,0x8237000a,0xc2c40003,0xdcf50012}},	//   æfte, _إرسا, _ديفي, لأخب
  { {0xc212000b,0xc7d90014,0x6e2912df,0xf1bf0042}},	//   _והן_, _имах_, rieb, riál_
  { {0x7d1b0052,0xe4c80003,0x89340012,0x60db020d}},	//   rzus, ابين_, _اعفا, _isum
  { {0x2cbf0051,0x7d1b00f7,0xfbd20009,0x6602005e}},	//   stud_, szus, חתי_, _fook
  { {0x0166022a,0x20050028,0x998f0073,0xe4d50012}},	//   икно, ölin_, mogų_, _نتتب
  { {0xe0d70098,0xc9560015,0x998f0010,0x5156003c}},	//   авя_, ртны, logų_, ртну
  { {0xf7720003,0xb8ee0037,0x7d06004a,0x8e86003c}},	//   تاح_, _रह_, äkse, игге
  { {0x9f5e12e0,0xa5960014,0x44d60002,0x92f60012}},	//   _poté_, иращ, _zł_, _نفوذ_
  { {0x78a9066e,0x645c002a,0x60db12e1,0x2cad08fd}},	//   ševa, _shri, _osum, ored_
  { {0x3ce80037,0x4c850003,0xdb1a12e2,0x0c26024d}},	// [2700] जिये_, مؤلف, zetü, аман
  { {0x515b0093,0x309b000b,0xb09b0009,0x83870024}},	//   _בכפו, _ששימ, _שייר, ибув_
  { {0xf1eb0037,0xb05b0248,0x93430934,0x60db12e3}},	//   _जोड़_, stäc, онфе, _asum
  { {0xda65000a,0xb05b0163,0x629e12e4,0x6e9b0009}},	//   ماني, ptäc, rspo, _בבטח
  { {0xdce0003a,0x7e6401a4,0xe0d20012,0x645c12e5}},	//   yamı, mmip, تزا_, _thri
  { {0xb8ce015f,0xa2e60047,0x4ea60063,0xf8b30009}},	//   _कि_, _когд, ариа, קשו_
  { {0x99990029,0x68e912e6,0x3e7c0066,0x0ff70003}},	//   losť_, _ered, _jít_, شعوب_
  { {0x3e7c0013,0x2d8012e7,0x2ca0005e,0xdb1a12e8}},	//   _mít_, ncie_, osid_, retü
  { {0x99990029,0xeb0e0037,0x6d590002,0x6b9a0054}},	//   nosť_, ान्त_, _czwa, tatg
  { {0x61e2000f,0xbea6002d,0xd00f0012,0x14180012}},	//   ldol, _важк, _قلق_, ايدة_
  { {0x3377000b,0x6b9a0054,0x2d800fae,0x2cad12e9}},	//   יעים_, ratg, kcie_, ared_
  { {0x2bc60044,0x2ca00005,0x6b9a0054,0xe4e6002d}},	//   र्ता, ksid_, satg, _вікн
  { {0x2cad12ea,0xdce00060,0x6b9a01a0,0x25a612eb}},	//   cred_, pamı, patg, _idol_
  { {0x61e20006,0x99990026,0xbb840003,0x2d800002}},	//   hdol, dosť_, _الغي, ecie_
  { {0xdb1a0149,0x93fb000b,0x442c12ec,0x6c5b0009}},	//   retó, _בלגי, mid_, _שדוח
  { {0xbafb000b,0xef190002,0x13170009,0x8afb0009}},	//   _יהוש, ąż_, _כחול_, _יהוי
  { {0x442c0070,0x04950003,0xbd780024,0x25d70009}},	// [2710] oid_, صلاح, рбує_, סומן_
  { {0x442c109a,0x3f9c0027,0xaada0037,0x4427001a}},	//   nid_, javu_, _बनाक, òn_
  { {0x2bc60044,0xb5fb0149,0x68e9048b,0x2ca0005e}},	//   र्धा, _diár, _sred, asid_
  { {0x68e912ed,0xaaa90011,0x442c12ee,0x27e112ef}},	//   _pred, _किसक, hid_, _hahn_
  { {0x84670098,0xddc20002,0x89a8002d,0xb9c40003}},	//   _въве, _okoł, рків_, تقني
  { {0x96950046,0xcc76000b,0x98f40003,0xdfd10003}},	//   бриш, _לגשת_, تثما, سيع_
  { {0x442c0005,0x56920001,0x6d590002,0x60c209bb}},	//   did_, пајт, _szwa, atom
  { {0xed590015,0xd738000b,0x0f38000b,0x1f380009}},	//   лой_, יטות_, ירוט_, ירור_
  { {0xa3ab015f,0x2d9900c1,0x7d0d003a,0x4c820015}},	//   _गया_, _mese_, nyas, плыв
  { {0x2cad0036,0x2d990119,0x6448080a,0x442c12f0}},	//   rred_, _lese_, godi, gid_
  { {0x249f0065,0x8c1a0093,0x2d800002,0xddc6001e}},	//   ssum_, רותי, ycie_, _likš
  { {0xc332000b,0x2cad12f1,0x36040012,0xc8790060}},	//   לוי_, pred_, _وولف, _kuş_
  { {0x6c850003,0x2005009b,0xdbf00066,0xeb8e12f2}},	//   _التم, _koli_, _zříd, _ни_
  { {0x99990029,0xaf360012,0xeb990048,0x200512f3}},	//   vosť_, مرأت, _сик_, _joli_
  { {0x61e2003a,0x6e2d03b5,0x539a0009,0xa8560009}},	//   ydol, fiab, _עסקא, מישה_
  { {0x2ca00051,0x99990029,0xddcd003a,0x291a0012}},	//   tsid_, tosť_, rmaş, _مقعد_
  { {0x7fd6002d,0x6e360010,0x05560048,0x2d8012f4}},	// [2720] _ліні, rnyb, ствя, rcie_
  { {0x68fb000b,0x2ca00051,0xe0fb000b,0x25e80011}},	//   _עליה, rsid_, _עליל, _चोरी_
  { {0xe80d0044,0x2ca00051,0x9f64003a,0xb6ab0024}},	//   _सकता_, ssid_, ütün_, _змiн
  { {0x60c20006,0x90a60003,0x753d0002,0x7afc0052}},	//   ttom, محتم, ższy, ärti
  { {0x20050026,0x91bb000b,0xdb1e000e,0x6448003a}},	//   _boli_, רמני, lepü, yodi
  { {0xf093000b,0x6ec60003,0x1eaa0012,0xdbf00030}},	//   לנד_, متبق, هابي_, _příd
  { {0x66060005,0x6ab60044,0x64480133,0x8fa30001}},	//   _kokk, _अमेर, vodi, чаје
  { {0xdb010065,0xf1bf000e,0x442c08bb,0x6b980060}},	//   uglý, riák_, wid_, _sevg
  { {0x8fa600be,0x644812f5,0x442c12f6,0x660612f7}},	//   _газе, todi, tid_, _रवैए_
  { {0xb5fb0020,0x3e41007a,0xf3f1000b,0xdbf00066}},	//   _khác, mėte_, ֵ֣י_, _tříd
  { {0x0dca007c,0x95ca007c,0xe9f9007c,0x51f9002d}},	//   _були_, _була_, анні_, анню_
  { {0x442c0005,0x66060065,0xf1ab0012,0xddc80034}},	//   sid_, _nokk, داده_, _ludź
  { {0xa3b80037,0xc5f3000b,0x2486006f,0x2d9900b8}},	//   छला_, _מדף_, _utom_, _rese_
  { {0xd9180015,0x20050028,0x46dc0037,0x94bb0009}},	//   сью_, ðli_, _मनाह, _עמות
  { {0x877b000b,0x53330001,0xb4250003,0xdb1e004a}},	//   ראלי, _нешт, _بعنو, ävän
  { {0x442a0663,0x3e410010,0x7e55002d,0x83370009}},	//   _amb_, kėte_, іває, _לאוס_
  { {0x26c3009b,0xc399002d,0x7c970003,0x53990015}},	// [2730] stjo_, икає_, إشرا, ивая_
  { {0x3e410010,0x7d0d003a,0xb3670015,0x224b10d9}},	//   dėte_, ryas, бъек, lock_
  { {0x7d0d00a2,0x68ed00d9,0x2bca0011,0x20050975}},	//   syas, _hrad, ़्या, _roli_
  { {0xd1310003,0x7d0d003a,0xb95500de,0x32b80012}},	//   وما_, pyas, овещ, صدمة_
  { {0x02440012,0x200512f8,0x3e410073,0x98c70842}},	//   أَنَ, _poli_, gėte_, ссел
  { {0xa295002d,0x6d5d001e,0x889c007e,0xba770012}},	//   _магі, _izsa, רבגי, _هارت
  { {0xb05b0006,0x8db50024,0x3619003c,0x6fac0011}},	//   ytän, оспі, ицию_, _जयसू
  { {0xc4850838,0x34a90001,0x7860006f,0xe7180009}},	//   олик, авио_, möve, מחור_
  { {0x2bc60044,0xe3b10003,0xe616002d,0x26de12f9}},	//   र्वा, ورد_, ідь_, _esto_
  { {0xeb990001,0x9f60000e,0x78a60040,0x5ac912fa}},	//   шио_, űrés_, _ækva, алом_
  { {0xb05b0006,0x68ed003a,0xd7f8001a,0xe2990001}},	//   ttän, _arad, _khăn_, јам_
  { {0xcf890093,0x04c90003,0xdd1e0066,0x90c6091c}},	//   _יט_, _نوصي_, _síťo, обме
  { {0x78600163,0x89da000b,0xb05b12fb,0x660612fc}},	//   höve, בחרי, rtän, _rokk
  { {0x7860012b,0xcb69046d,0xb05b12fd,0x69cd005e}},	//   köve, _кале_, stän, _ebae
  { {0xba3d0010,0x3f6a00f5,0x7bd71135,0x79820034}},	//   grįs, риво_, dexu, ycow
  { {0x2d9f0052,0xb90a0021,0xdb1e0031,0x224b12fe}},	//   naue_, _вниз_, repü, cock_
  { {0x6443009b,0x8f760024,0xad190009,0xd7760012}},	// [2740] čnin, _муні, בוּר, _وادع
  { {0x28b80011,0x6b560479,0xa5bb0034,0x79820034}},	//   उंसि, отех, _omów, wcow
  { {0x61e40101,0x442a0032,0x59c10011,0xfe460048}},	//   _kail, _vmb_, ष्कर, _мноо
  { {0x3e410010,0x6606004a,0x61e60070,0xdcfd0010}},	//   tėte_, _uokk, ndkl, _nesė
  { {0x95880010,0xe89400be,0x8d66002d,0x3e7112ff}},	//   grąž, чаль, _євге, _ašto_
  { {0x3e410010,0x6bd60003,0x799b0070,0xb5fb001a}},	//   rėte_, _بتحر, _eeuw, _thác
  { {0xa01b004a,0xa7140024,0x28da0011,0xdefa003c}},	//   mpöt, ямкі, _मैरि, рыл_
  { {0x78ad001c,0x2dd30014,0x2bc60037,0xf773000b}},	//   šava, джър, र्रा, וקו_
  { {0x6b9c0051,0xbc77003c,0x80da0011,0x7aee0159}},	//   _kerg, обых_, _पैले, _hrbt
  { {0x8c430046,0x9b6a0345,0xddc20002,0x136a0867}},	//   мење, ишна_, _skoń, ишни_
  { {0xb4e30044,0x6b9c1300,0xa5bb0018,0x637b0009}},	//   कटॉप_, _merg, _imóv, יניד
  { {0x68ed007a,0xba2b002d,0x61e41301,0xa2cd0011}},	//   _prad, ріод_, _cail, _सहस्
  { {0x7860000f,0x660f02f1,0xed5700ac,0x61e41302}},	//   zöve, öcke, _доц_, _dail
  { {0xb8670012,0x7c2a04ec,0x3eb81303,0x104b01c6}},	//   تاجو, _umfr, furt_, рями_
  { {0xdb4f002d,0x9e07002d,0x25a0005e,0x3ea50031}},	//   _цю_, очал, fail_, élt_
  { {0x7afc0005,0xddc20002,0x3ead00f1,0x68e00030}},	//   ärtu, _ukoń, čet_, _osmd
  { {0xc05b007c,0x1cb80003,0xb05b004a,0xd37b0c1e}},	// [2750] _він_, قالب_, ltäm, аче_
  { {0xddd60002,0x3eb80052,0xeb900012,0xa3d40148}},	//   omyś, burt_, نظم_, моуч
  { {0xb05b004a,0xd3710003,0x23c20037,0x6a940024}},	//   ntäm, ءها_, _शानद, дріє
  { {0x2bca0037,0x92590015,0xf1a70024,0x6b9c0227}},	//   ़्ता, щает_, ірен, _eerg
  { {0xc5fa0093,0x7860006f,0x5dfa0009,0xddcb0073}},	//   _הפרט, söve, _הפרנ, žiųj
  { {0xa6950001,0xc078002d,0x28080012,0x6d3a0009}},	//   приј, ісії_, يْنَ_, _הֲלו
  { {0xa195007c,0x82a40001,0x99d70012,0x160f0011}},	//   _навч, _оште, _وترا, _सवार_
  { {0x7c3a007d,0xd6ce000a,0xc6680001,0xc8ab0048}},	//   entr, اقي_, ошње_, _въже_
  { {0x6d430052,0x27f60066,0x61e404f2,0xa3e70011}},	//   ßnah, ádní_, _rail, मएल_
  { {0x4b25002d,0x94220015,0xd8740012,0x61e402d5}},	//   змов, емье, _قالب, _sail
  { {0xef20003e,0xddc40002,0x6b850052,0xc7c400b3}},	//   ążki_, gliś, ichg, _юсти
  { {0xb05b0163,0x7a360692,0x61460488,0x60100248}},	//   stäl, kšte, зема, _jämv
  { {0xf992000b,0x25a00573,0x7e691304,0x69d91305}},	//   ערך_, vail_, mmep, iewe
  { {0xb4d70037,0xdb1a1306,0xb05b008e,0x20c4008e}},	//   ाबी_, eetõ, ltäj, röi_
  { {0x63a11307,0xabfa0009,0x64430004,0x4e1f0011}},	//   maln, _להסר, čnil, _बताई_
  { {0xbc760003,0x6e3b0028,0xb05b008e,0x0dc90012}},	//   كهرب, nnub, ntäj, يبقى_
  { {0xee37002d,0x6b9c1308,0x69d900c7,0x5baa0015}},	// [2760] їну_, _perg, dewe, йкам_
  { {0xdce60039,0x26c7013a,0xe5720009,0x63a11309}},	//   _iekļ, ktno_, גַע_, naln
  { {0xb77b000b,0x9f97000b,0x518605fb,0x0f7b0009}},	//   _לאיש, _מדיה_, пула, _לאיב
  { {0xdb1a0051,0xe8fa0015,0xc9160009,0x91ba0012}},	//   petö, йле_, ּחַת_, إطار_
  { {0xb5fb001a,0x6b9c00b6,0x63a1130a,0x3a3f130b}},	//   _khán, _terg, kaln, _djup_
  { {0xb05b004a,0xddc40002,0xd12f0003,0x3e410010}},	//   ytäm, yliś, دمه_, mėta_
  { {0x8c1b000b,0xb7db000b,0x69d90347,0x66160073}},	//   _פולי, מקסי, bewe, okyk
  { {0xbb3b0093,0x6616007a,0xd5e20020,0x333b000b}},	//   _העלי, nkyk, _khỏ, _התלמ
  { {0x2ba606bc,0xd0260014,0xe6110009,0x3e410073}},	//   jící_, _емай, דִי_, nėta_
  { {0xb05b0006,0xb5fb001a,0x22810028,0x2ba60030}},	//   ttäm, _nhán, _bók_, dící_
  { {0xe1d9007c,0x7e7e0051,0x61d90048,0xbf130012}},	//   одні_, _nupp, омня_, _كوكب
  { {0xb05b004a,0x63a10051,0xe717000b,0xa194002d}},	//   rtäm, aaln, _מחבר_, наюч
  { {0xd625000a,0xa207000b,0xdb23000e,0xb05b03f5}},	//   _تعلي, לֶךְ_, _örök, stäm
  { {0x7a360026,0x3e410010,0xb5fb001a,0x36d5130c}},	//   všte, dėta_, _chán, могр
  { {0x3f9e007a,0x7bda130d,0xa857000b,0x628a021e}},	//   _metu_, metu, פילה_, _utfo
  { {0x6443012e,0x8b3b000b,0xc333000b,0x433b000b}},	//   čnim, _לתוצ, _רוק_, _לעוב
  { {0x70bb0011,0xd944004c,0xf9900012,0x7bda03bd}},	// [2770] _ईमेल, _пећи, _صبي_, oetu
  { {0x2bcf0037,0x3138000b,0x9c470024,0x9cd70009}},	//   त्पा, _מנחם_, їхал, הומה_
  { {0x6b850052,0xd7f8001a,0xc2c40012,0x8b670012}},	//   rchg, _chăm_, فيلي, سائم
  { {0x7bda08c0,0x69cb0052,0xeab00003,0x7a360027}},	//   hetu, ufge, اعل_, pšte
  { {0xddc80408,0xba740012,0x37e5003c,0x69d909bf}},	//   _budž, رامت, долг, rewe
  { {0x3cfa0009,0xe0d80024,0x9be40024,0xf8070198}},	//   _ולשנ, яві_, _піск, ячен
  { {0xb05b0006,0x7bda0005,0x63a1012e,0x6e3b002c}},	//   ttäj, detu, valn, tnub
  { {0x60100163,0x63a111f7,0xc3320009,0x67230159}},	//   _hämt, waln, _סון_, rznj
  { {0x63a10afa,0x26c7009b,0x7bda0284,0x443300b7}},	//   taln, stno_, fetu, oix_
  { {0x7bda007d,0x40e8000b,0xb05b004a,0x60100248}},	//   getu, _מַעֲ, stäj, _jämt
  { {0x56940046,0xa3cf0037,0x2bcf0037,0x64a2000d}},	//   _захт, व्य_, स्या, mţiţ
  { {0xc7a90093,0x63a100c6,0x2ba60030,0x74f90012}},	//   _כב_, saln, tící_, _وفاز_
  { {0xa5bd007a,0xe44e002d,0x3ea00027,0x64430027}},	//   siųs, _аж_, ćite_, čnij
  { {0x22810028,0xf8b6000b,0x3cf10011,0xe46b003c}},	//   _tók_, ופשי_, ँटने_, _ушел_
  { {0x41c60037,0xeab10012,0x8c42076b,0x9345130e}},	//   _वापस, _شعث_, _шеше, _юнке
  { {0x44330054,0x96550001,0x25bf130f,0x4a760012}},	//   eix_, еђуј, ngul_, _تُعر
  { {0xb5fb0020,0x66160010,0xf1bf017a,0xb5fd0159}},	// [2780] _thán, rkyk, riát_, emšk
  { {0x8d630047,0x4d63002d,0x660b0058,0x6616004a}},	//   твуе, ткув, _logk, skyk
  { {0x78a901a2,0xb9e6002d,0xb7fb0009,0x41e60024}},	//   _avev, діли, _ופית, діла
  { {0xc693000b,0x22400051,0xd5e2001a,0xfbc9000b}},	//   _שאר_, õik_, _thỏ, ית_
  { {0x00da0012,0xaa050012,0xb86a004c,0xd378001b}},	//   تبات_, عظمه, ојке_, leće_
  { {0xd7f80020,0xd010000a,0x368a002d,0xd0070001}},	//   _thăm_, طلب_, осин_, деље_
  { {0x8f9b0009,0xd5ba0024,0xa2e3003c,0xc0590024}},	//   קיקי, осп_, _иорд, чії_
  { {0x973c0027,0xdb010c56,0xb05b1310,0x78a911f9}},	//   _neće, palê, ttäk, ševi
  { {0x47c60046,0xed570046,0xd657000b,0xe3ce001a}},	//   _обав, моћ_, ויקת_, _dựng_
  { {0x6aba006f,0xa4fb0009,0x7c3e1311,0xbc670012}},	//   tutf, קליט, nnpr, ومين_
  { {0x0bb70093,0x83b70093,0xe2f8002d,0xfbb7000b}},	//   ולים_, ופיע_, чені_, ופית_
  { {0xd378001c,0x7bda03d5,0xdd900003,0x7c210032}},	//   deće_, setu, _صوت_, ahlr
  { {0xa3de0011,0x273c0064,0x7bda1312,0xb05b005e}},	//   ढ़ा_, yšné_, petu, ltäi
  { {0x8ca20037,0x6443017b,0x6aba0040,0xb8f70011}},	//   गठनो, čnik, putf, _सह_
  { {0x3bbb000b,0xf7700003,0xadd50001,0xb3bb0009}},	//   _ומוד, لاف_, новљ, _ומוכ
  { {0xf1d0001a,0x60100052,0x59c60037,0x3e45001e}},	//   _hạng_, _sämt, _वायर, pēte_
  { {0x69dd1313,0x2d58027f,0x189b0012,0x9cc8003c}},	// [2790] mese, дить_, _بضعة_, дыха_
  { {0x443e1314,0xc8670003,0x2bbb0003,0x7a360010}},	//   nnt_, _تطبي, تارة_, mšta
  { {0xddc8003e,0xf1d00020,0x387f0051,0x916d001a}},	//   _budż, _mạng_, _suur_, _hồi_
  { {0xa294007c,0x443e0052,0xf9900012,0xddcf004b}},	//   таці, hnt_, لبه_, _dicţ
  { {0x7a361315,0x69dd0052,0x1bbb0003,0x3e610028}},	//   nšta, iese, _واسع_, jóta_
  { {0x200c03eb,0x8574007c,0xb87b0065,0xb9070037}},	//   _codi_, _шлях, lvís, _बन_
  { {0x7ac4069b,0x69dd026e,0x63a51316,0x22b80012}},	//   _исте, kese, mahn, _يدفع_
  { {0x645a0065,0x63a500b6,0xb05b0051,0x7a360010}},	//   elti, lahn, stäh, kšta
  { {0x2bcf0044,0x629c003e,0xa954002d,0x79c80003}},	//   स्था, _zwro, _акті, _توقف_
  { {0x73050001,0xd3780027,0x2bca0011,0xbb850012}},	//   епоз, zeće_, ़्ला, ةلدي
  { {0xf1d00020,0x7afc0051,0xb87b0066,0x7a360cf9}},	//   _dạng_, ärtp, zvít, ešta
  { {0x2bcf0044,0x8ed80003,0x7afa000e,0xfb1a000b}},	//   स्ता, _تذكر_, _átte, פורמ
  { {0xa1550098,0xddc4003a,0x78bd0051,0x973c001b}},	//   върш, eliş, gusv, _veće
  { {0x66060028,0x201e0028,0x69c40034,0xfaa50bda}},	//   ökkv, óti_, _wcie, _зако
  { {0x8c1a000b,0x63a5051f,0x141a0009,0x20180097}},	//   _מוסי, dahn, _מוסב, rkri_
  { {0x85b50046,0x69c40002,0x64b5003a,0x69dd1317}},	//   кључ, _ucie, _eğiş, cese
  { {0xb4660083,0xfe4301d4,0xd378001b,0xdb010031}},	// [27a0] екал, унто, reće_, dalé
  { {0x6fd300a2,0xaf9a0047,0x24820029,0x61fb1318}},	//   nıcı, _этих_, íkmi_, _anul
  { {0x23c60037,0x479b000b,0xe8030037,0x3f980bd3}},	//   र्गद, _מייס, लाना_, mbru_
  { {0xda650003,0xe9e5002d,0x2bcf0037,0x22930012}},	//   ناني, кціо, त्ता, النس
  { {0xc237000b,0x443e1319,0x629c0031,0x63a5131a}},	//   ערנו_, ynt_, ároz, bahn
  { {0xb05b0006,0x993b0009,0x69dd0540,0x6e240031}},	//   ttäi, התנה, zese, lhib
  { {0x8c4306e6,0xd6d70015,0x7d16004a,0x916d001a}},	//   _сере, еты_, lyys, _mối_
  { {0xa737000a,0xa3d20037,0x443e002c,0xceb3000b}},	//   عثور_, ह्न_, wnt_, איה_
  { {0x59a70044,0x69dd131b,0xdb1c0018,0x25a20035}},	//   _ख़बर, vese, _ucrâ, _mekl_
  { {0xb05b0006,0xe8d7000b,0x69dd0052,0x916d131c}},	//   ltäv, _אומר_, wese, _nối_
  { {0xa1950015,0xfa6a0009,0xb4bd0011,0x6ec50012}},	//   канч, ּכָּ, _इम्_, _لتنق
  { {0x765b02d1,0xda670003,0x23c70037,0xb05b004a}},	//   cluy, عادي, _लाभद, ntäv
  { {0xf1d0001a,0x69a20037,0x66060028,0x63a5016d}},	//   _tạng_, _ख़री, ökku, yahn
  { {0xb05b0006,0xb8030037,0x69dd03ae,0xe8030037}},	//   htäv, लायम_, sese, लाया_
  { {0xc2210037,0x3e45001e,0x6af30012,0x69dd131d}},	//   _मतलब_, lēta_, _مثير, pese
  { {0xcf57000b,0x07080003,0x7e6d020d,0x63a5016d}},	//   גבלת_, ريقي_, umap, wahn
  { {0x32440003,0x9f470029,0xdb1c0002,0x3e45001e}},	// [27b0] _حنيف, rdné_, _obró, nēta_
  { {0x8d740012,0x113c0009,0x68e20034,0x6e240060}},	//   طاقا, _מתחל, dwod, ahib
  { {0xa858000b,0x2ca9006f,0x63a500b6,0xa3d20037}},	//   _איזה_, ssad_, rahn, ह्य_
  { {0xddc4004b,0x50b5003c,0x6fd30060,0xf2040472}},	//   rmiţ, вску, zıcı, лячо
  { {0x6fd300a2,0x601008ec,0xc0e500de,0xf8bf0025}},	//   yıcı, _kämp, толк, nué_
  { {0x7bde007d,0x7640004a,0x3e45001e,0x6d590034}},	//   cepu, enmy, dēta_, _rywa
  { {0xb9950012,0x225b0012,0x99850012,0x68e20034}},	//   _للأب, _فجرب_, _للزو, awod
  { {0xe8d90020,0xfe710003,0x60100da4,0x96fc0009}},	//   _ngữ_, جدت_, _lämp, ללות
  { {0x6fd3003a,0xe1ff0034,0x200c0031,0x36720012}},	//   tıcı, lmów_, ödik_, جهيز
  { {0xb3ca0037,0xea890001,0xb87b0030,0x765b0097}},	//   _सॉफ़्, мбол_, zvír, sluy
  { {0x5dd50003,0x2bb50011,0x23290b48,0x2bc60011}},	//   _لقائ, ूलबा, фони_, र्टा
  { {0x8d870014,0x8e960009,0xc0490009,0x7aea0040}},	//   _чужд, _ידעו_, _וז_, æfti
  { {0x3e45001e,0xf8bf131e,0xec6e091c,0xc2430842}},	//   cēta_, szén_, _вп_, рняк
  { {0xc0e30001,0x5fe10011,0x7d16008e,0x6609079f}},	//   јорк, फ़िल, vyys, ljek
  { {0x5e8c000b,0xada6002d,0xb05b004a,0x6da6072b}},	//   ּאמֶ, кавл, ytäv, кива
  { {0xceb2000b,0x7bd50052,0x82d6000b,0xf8bf0f14}},	//   ייל_, _abzu, _יוצג_, bué_
  { {0x916d0020,0x644100bd,0x59a70037,0x3ddf0070}},	// [27c0] _tối_, onli, _ख़तर, ieuw_
  { {0x6441131f,0x63a31025,0x6609008e,0xd378001b}},	//   nnli, _jenn, hjek, leća_
  { {0xb05b0006,0x3e45001e,0xc20f002d,0xa76601ef}},	//   ttäv, zēta_, ає_, _шкод
  { {0x64410052,0x2bc60037,0x68f60572,0x63a31320}},	//   hnli, र्जा, _kryd, _lenn
  { {0x69c208de,0xdb030040,0xb05b008e,0x2cbf005e}},	//   rgoe, _udnæ, rtäv, juud_
  { {0x64410070,0x63a30052,0x7a360010,0x91bf001a}},	//   jnli, _nenn, kšto, _phụ_
  { {0x2900007d,0x69d600b6,0xe2870012,0x9e340048}},	//   ţia_, _obye, _خذ_, лекч
  { {0x2bcf0037,0x661b002c,0xd3780027,0x6ced0037}},	//   त्सा, gkuk, jeća_, जिंग_
  { {0x916d0020,0xd3780027,0xa2da0037,0xb4be0037}},	//   _mỗi_, deća_, नबक्, ुझे_
  { {0x916d0020,0x3e450039,0x4fea0024,0x29550048}},	//   _lỗi_, rēta_, _імен_, _съср
  { {0x6d440026,0x0c73000a,0x6283007d,0x60100051}},	//   _žiad, جديد, _cuno, _rämp
  { {0xf8bf0061,0x5f370009,0x68f61321,0xd7370009}},	//   tué_, _בטבע_, _bryd, _בטבת_
  { {0xc05b007c,0xac0a0001,0x63a3000e,0x660f1322}},	//   дів_, _онда_, _fenn, _rock
  { {0x63a31323,0xd9180047,0xdfd80048,0x44251324}},	//   _genn, тью_, къс_, chl_
  { {0x6458001e,0xe8030011,0x5f740012,0xfe730012}},	//   _ikvi, लाता_, لافر, لدر_
  { {0x33770093,0xf365002d,0x62810061,0x6377000b}},	//   _בתוך_, _стін, _éloi, _בגוף_
  { {0xf8bf0108,0xde58002d,0x39490002,0x0ba7003c}},	// [27d0] qué_, таті_, żasz_, вшем
  { {0xa4d4002d,0x61ed0c42,0xe3b30012,0x8bb40012}},	//   рофі, _haal, شرط_, لإما
  { {0xe298002d,0xe7ec0037,0x41a70037,0x63a80029}},	//   ває_, _छोटा_, _ख़ास, iadn
  { {0xc333000b,0xeab00012,0x63a80042,0xa3d90011}},	//   סוף_, زعم_, hadn, _डॉन_
  { {0xa954002d,0x25a90643,0x39490017,0x66090027}},	//   акці, maal_, ças_, vjek
  { {0xab94007c,0x973c0027,0xd3780027,0xa6c9010c}},	//   _вирі, _seća, zeća_, елка_
  { {0xb05b004a,0x64410623,0x63a31325,0x7a260097}},	//   ltäs, vnli, _renn, _hóte
  { {0xff7c000b,0xdb030061,0x25a90562,0x24e900de}},	//   וטומ, _fenê, naal_, емии_
  { {0x66090051,0xb05b004a,0x69cc0042,0x34b20012}},	//   rjek, ntäs, ílež, مميز
  { {0xe3b1000a,0x661b0006,0x8d5c000b,0x63a80d27}},	//   حرة_, skuk, וכחי, gadn
  { {0xc5d5007c,0xc4d00037,0xbcfb000e,0x7cfd0028}},	//   _біль, _सङ्ख, _szél, færð
  { {0x26040037,0xa2c40011,0x3e450035,0xbcf50012}},	//   वाणी_, ांत्, mēto_, _مستغ
  { {0x3e45001e,0xbd280003,0x91f6000b,0xb05b008e}},	//   lēto_, _لأول_, אמרו_, ytät
  { {0x395e0039,0xc9520009,0xaa890012,0x2cad005e}},	//   āts_, צמם_, _كنتم_, msed_
  { {0x18670098,0xb05b0d4a,0x61ed003a,0x2cad1326}},	//   уари_, kräf, _faal, lsed_
  { {0xd5e20020,0x2bcf0037,0xc692000b,0x22920003}},	//   _khó, त्रा, מאל_, _اليس
  { {0x05661327,0xdd8f0012,0x26040011,0x2cad0912}},	// [27e0] уван, سول_, वाती_, nsed_
  { {0x309b0093,0x69c9000d,0x69c60070,0x53a60003}},	//   _רשימ, _acee, lgke, اماك
  { {0x3ce50044,0xdb010029,0xd2960024,0xdd120035}},	//   _जैसे_, kalí, урзь, _kļūt
  { {0x2cad0051,0x1d0a0014,0xb05b0aa0,0x69c600ed}},	//   ksed_, _земи_, stät, ngke
  { {0xd5e20020,0x3e4c0013,0xa8560009,0x09360012}},	//   _nhó, něte_, ְיֶה_, دراج
  { {0xcaa60003,0x6e221328,0xd0070014,0x3a261329}},	//   _مصري, _slob, лече_, shop_
  { {0x44440163,0x2cad012e,0xd5e2001a,0x63a80121}},	//   mn_, esed_, _phò, vadn
  { {0xe4e6007c,0xa2810002,0x4444132a,0x9e660012}},	//   гіон, łość_, ln_, داتن
  { {0x39460001,0xd5e2001a,0x2cad005e,0xb146004c}},	//   _снаг, _chó, gsed_, _снал
  { {0x69c6000e,0x4444132b,0xc94b0009,0xf7860012}},	//   egke, nn_, _אֲבֹ, _إلاَ
  { {0x26040037,0x2cad002a,0x61ed002c,0x501b000b}},	//   वादी_, ased_, _paal, _רובו
  { {0xc3330093,0x44440052,0x3377000b,0x443a132c}},	//   מות_, hn_, טעים_, hip_
  { {0x7e7d01a2,0xddc900a2,0x443a0827,0xdddb003a}},	//   _risp, lleş, kip_, lmuş
  { {0x3e41007a,0x44440377,0x43940489,0x8c43132d}},	//   mėti_, jn_, _такс, _лече
  { {0xddc900a2,0x25a90070,0x61ed0070,0x3e410010}},	//   nleş, taal_, _taal, lėti_
  { {0xb05b008e,0xa5070048,0x39150adc,0x4444132e}},	//   ttäs, лязл, _вмир, en_
  { {0x7e7d0039,0x44440028,0x3e410010,0x3e45001e}},	// [27f0] _visp, fn_, nėti_, zēto_
  { {0xddc900a2,0xb05b132f,0x8574002d,0x734b0345}},	//   kleş, dräg, слух, нчев_
  { {0xb05b1330,0xe8030011,0x9b440012,0x78bc0035}},	//   stäs, लासा_, منكو, _ārva
  { {0x443a007a,0x3e41007a,0x636f000e,0x32b80012}},	//   aip_, kėti_, lóné, ادلة_
  { {0x9f470066,0xda4c0009,0x28f80024,0x9df8003c}},	//   rdní_, עֲבָ, лець_, _снят_
  { {0x3e41007a,0x2cad0051,0x25a9009b,0x76b50001}},	//   dėti_, vsed_, _žal_, аљиц
  { {0xe6110012,0xb7fc0009,0xb05b0032,0x7ceb0248}},	//   قشة_, תפות, präf, _förå
  { {0xed59005c,0x2cad0051,0x3e45001e,0x6d5d0002}},	//   кой_, tsed_, rēto_, żsam
  { {0x10d80003,0x3e45001e,0x4c850001,0xa5f6004c}},	//   _مبلغ_, sēto_, јлов, рењу_
  { {0xf3f20009,0xa87b0012,0x660d0269,0x24520012}},	//   ַ֣ת_, _أحرر_, hjak, ينيس
  { {0x7f84000a,0x2cad0036,0x63bc0065,0x3169000e}},	//   _المن, ssed_, órna, _azaz_
  { {0x3e41007a,0xd57500be,0xa4d5002d,0x26c30164}},	//   bėti_, _куль, _воді, dujo_
  { {0x443a003a,0xeb8e1331,0xfc05003c,0x3d010011}},	//   yip_, _ми_, _впло, ोहों_
  { {0x63a70066,0xfaf8001e,0xa0680009,0xe3b90024}},	//   _nejn, _šīm_, ָׁלַ_, _рбк_
  { {0xbf650003,0x4444024c,0x4c3a0009,0x96b9004c}},	//   مدفو, vn_, _שתצב, луту_
  { {0xe8fa0046,0x44440742,0x644f0061,0x6abc0028}},	//   _али_, wn_, écif, árfe

  { {0x6fd6002d,0x62870061,0x4a5b000b,0x62730003}},	// [2800] _кінц, _aujo, _בדקו, _بهيئ
  { {0xd00f0003,0x44441332,0x26c301e3,0xf8bf0031}},	//   _يلي_, un_, bujo_, zzék_
  { {0x67bb000b,0x62870017,0xd7bb0009,0xfbb60009}},	//   _במיק, _cujo, _בציר, שפעת_
  { {0xb05b0052,0x79850012,0xdb0301a0,0x60c2008e}},	//   träg, مؤهل, _venè, tuom
  { {0xda65000a,0x854700b3,0x859b0009,0x26040011}},	//   حالي, _взяв_, _בשכו, वासी_
  { {0x60c2007a,0x6d4e003a,0x58f7000b,0xddc9003a}},	//   ruom, şbak, ימנע_, tleş
  { {0x2120048b,0x60c20010,0xc7b30009,0xfae70012}},	//   ših_, suom, קבה_, _بث_
  { {0xddc900a2,0xfe6f0003,0xe363002d,0x6b63002d}},	//   rleş, ودي_, _єкти, _єкта
  { {0x394d003e,0x7c280444,0x7bc30097,0x9c460bda}},	//   żesz_, thdr, ónug, ихол
  { {0x3e41007a,0x7ed6002d,0x6fb30012,0xf7e90012}},	//   rėti_, _відч, _ومقا, _مرمى_
  { {0x752d01a2,0x23380015,0x8c1b0009,0x3e410073}},	//   zzaz, упны_, דויי, sėti_
  { {0xd258002d,0x25dd0037,0x7f3b000b,0x3e410010}},	//   иця_, _कॉपी_, _בעבו, pėti_
  { {0x04940351,0x7c94000a,0x3ea90027,0x7c3a0c0c}},	//   _التح, _التص, ćate_, pitr
  { {0x34fb000b,0xd3a30048,0xe824003c,0x1b2a0012}},	//   _שהגד, _дръп, офсо, _لأبي_
  { {0xb5a70014,0xfda70001,0x63670014,0xbe8805c6}},	//   ирай, ијам, _кръг_, исте_
  { {0x6d5c00a2,0xe37b000b,0x6b7b000b,0xdd9806fd}},	//   ğraf, _ברור, _ברונ, ишу_
  { {0xcec40066,0xb05b006f,0x9f4500d9,0x660d1333}},	// [2810] teří_, träd, _malá_, rjak
  { {0x2bb80003,0x22460029,0x7bc81334,0xa3b80012}},	//   لامة_, enok_, ngdu, لامر_
  { {0x2d820029,0x5fdc0009,0xd37b003c,0x22470030}},	//   ľkej_, _יחזק, тча_, énko_
  { {0x9756000b,0xdb01000e,0xca840024,0x672d0035}},	//   _לשתף_, nalá, ігій, ģijā
  { {0x66ec0037,0x62801335,0x69cf0011,0x26de0c9d}},	//   झिझक_, _dimo, _थानी, _apto_
  { {0x1d16000b,0x3eb10002,0x7860008e,0x290b01a0}},	//   _הקשר_, oszt_, tövi, ixca_
  { {0x6dbb0034,0xdb0101e9,0x87d40012,0x6fb20012}},	//   ałał, kalá, تغنا, سميا
  { {0xf2d2000b,0xee320009,0x59c60011,0xf9900012}},	//   _מעל_, ּֽה_, _वाइर, _يبق_
  { {0xdb01000f,0xe4590014,0x6e290052,0x315b0012}},	//   dalá, лжи_, rheb, _شجرة_
  { {0x9f4c014a,0x98140012,0x10140012,0x4084034d}},	//   ždé_, _وبلا, _وبلد, _футб
  { {0xdce7003a,0x7a3605b1,0x68ed1336,0x8e850012}},	//   ımız, lšti, _asad, _الصه
  { {0xdb01000e,0xd1ba0012,0x2bd80011,0xa5bb0097}},	//   galá, دادا_, ब्बा, _blóm
  { {0xc9560047,0xf8bf0061,0x7a3600d9,0x26040011}},	//   стны, gré_, nšti, वारी_
  { {0x33950003,0xb4fa000b,0x765d1337,0xeb960024}},	//   _الغز, _תפסי, _aksy, _лиш_
  { {0xd7f10020,0x68ed00c1,0xc2e80012,0xd62a05f7}},	//   _mã_, _esad, _نعيم_, гове_
  { {0x7a360010,0xbbb70011,0xdb080025,0xb05b0032}},	//   kšti, _आयुक, xadé, gräb
  { {0xcc880020,0x61e61120,0xf8bf0061,0x62801338}},	// [2820] _lớn_, mekl, cré_, _rimo
  { {0x2137000b,0x442700b6,0xa3ba0012,0x69db01e3}},	//   _לטפל_, _jln_, طائر_, _abue
  { {0xfc3f0054,0x38170009,0xf0170009,0x63a70034}},	//   _avís_, _הקים_, _הקיץ_, ójny
  { {0x61e600a2,0xd259007c,0xb3460017,0xddcd0060}},	//   nekl, аці_, leçõ, mlaş
  { {0x25a000c6,0x656f0029,0xdb08000e,0xe5f70009}},	//   mbil_, ýchl, radé, _הזכר_
  { {0x5fdb0037,0x98a20034,0xd8d70009,0xe2aa0012}},	//   म्पल, czką_, מונט_, _مارن_
  { {0xddcd003a,0x7a360027,0x26040011,0x6dbb0034}},	//   nlaş, ašti, वाली_, słał
  { {0x7e9b0009,0xdee50012,0x9e140024,0x291d0034}},	//   נספו, تأهي, ідпі, bywa_
  { {0xa9260047,0x2bcf0037,0xc5f3000b,0x68fb1339}},	//   _удал, स्का, לדה_, _grud
  { {0xddcd003a,0x7c930003,0xe3b8003a,0x52d80024}},	//   klaş, أشيا, akın_, амою_
  { {0xdb01082b,0x2bf7000b,0x5f760003,0x57fb0009}},	//   talá, זמין_, _طائر, _תלבו
  { {0xad9b05ab,0x5d86000a,0xc0cb0046,0xcb13000b}},	//   _anún, _الإل, луге_, ללת_
  { {0xfdf7000b,0x661d004a,0xd2640035,0xe3b20012}},	//   _לצאת_, öske, ciņš_, _فرغ_
  { {0xdb01000e,0xf8bf133a,0xd7f10081,0xddcd0060}},	//   salá, rré_, _xã_, flaş
  { {0x501b000b,0x6fda0037,0x8bd7000b,0x291d0002}},	//   נולו, प्यू, _לוגו_, zywa_
  { {0x7e64002c,0x7e91001e,0x61e60c07,0x645a133b}},	//   glip, _jāpa, cekl, loti
  { {0x4238000b,0x68ed133c,0x443e133d,0x7c150024}},	// [2830] _לנהל_, _usad, oit_, одає
  { {0x442706f4,0x7a360013,0xf3f1001a,0x3ce00011}},	//   ón_, všti, họn_, _कहने_
  { {0xfa89001a,0x60080009,0x443e005e,0xd2640035}},	//   _lẫn_, _הִרְ, iit_, ziņš_
  { {0x443e0101,0x7e64000d,0x1df90015,0x92590015}},	//   hit_, clip, _темы_, шает_
  { {0x443e0cb4,0x89a80024,0x645a133e,0xc4c60012}},	//   kit_, сків_, koti, _تْ_
  { {0xa6950046,0xd5bf001e,0x3e45001e,0x96950001}},	//   ориј, žādu_, mēti_, ориш
  { {0xa3be0037,0x645a01ff,0x03090009,0x59c50012}},	//   ेलन_, doti, _דִּֽ, _ويسك
  { {0x7a360027,0x9d550003,0x6448133f,0xbb480012}},	//   pšti, ينغت, endi, _الفن_
  { {0x9f5e03eb,0x442700b6,0x3e45001e,0xde160012}},	//   _botó_, _pln_, nēti_, تقيت_
  { {0xfa890020,0xddcd00a2,0x8fa40001,0x3a29000e}},	//   _dẫn_, ylaş, _нађе, _alap_
  { {0x33650003,0x27e7081f,0xcb690426,0xc1690009}},	//   تهدف, menn_, ране_, _סח_
  { {0x443e1340,0x69cb1341,0x6b9c0060,0x24830227}},	//   ait_, ngge, ırga, _lijm_
  { {0xe3ae0094,0x9f5e000e,0x61e61342,0xa5670012}},	//   _об_, _fotó_, rekl, _ادان
  { {0xf0920093,0x63aa0028,0xa5bb0028,0xb97a0009}},	//   ונך_, _gefn, _flók, ינרי
  { {0xb3460018,0x98ab0035,0xdb070031,0x9f290009}},	//   reçõ, ājās_, _fejé, בֵּ֖
  { {0x22b50039,0x7649004a,0xb05b031d,0x0e660024}},	//   māk_, nney, träc, ікан
  { {0x22b50039,0x3ea00027,0x22a7000e,0x682b0052}},	// [2840] lāk_, ćiti_, lők_, _süde
  { {0x27e70033,0x37c60012,0x629800d9,0x9c820064}},	//   jenn_, _بيدف, _ytvo, _účta
  { {0x74130012,0x22b50035,0x69d90032,0xff0a004c}},	//   بولا, nāk_, ffwe, _тенк_
  { {0xddcd01b3,0x7c3e007a,0x20d2000d,0x443e1343}},	//   rmaţ, sipr, tâi_, zit_
  { {0x3ead001c,0x64480de9,0xe611000b,0x7d0b08ec}},	//   ćete_, yndi, _אִם_, ägst
  { {0x2fc00052,0x7649003a,0x443e1344,0xceba004c}},	//   ßig_, eney, _öt_, аљи_
  { {0xdcf6003a,0x26c70164,0x443e1345,0x9f4c00b8}},	//   mayı, guno_, vit_, _andò_
  { {0xdcf600a2,0x20050b4b,0x22a70031,0x22b50035}},	//   layı, _enli_, dők_, dāk_
  { {0x629e004a,0xa5070001,0x62981346,0xdb030066}},	//   lppo, жења_, _stvo, _dení
  { {0x186a0098,0xfa890020,0xbfc30001,0x47c3004d}},	//   _тази_, _vẫn_, _обук, _обув
  { {0x2bcf0037,0x63aa0028,0x7e91001e,0x3e45001e}},	//   स्टा, _vefn, _tāpa, zēti_
  { {0x2d9200a2,0x0dc7022a,0x2a720066,0xed5a010c}},	//   _üye_, _души_, _chyb_, _кое_
  { {0xda7b0093,0xf1b3000b,0x443e1347,0x3d040011}},	//   ינטר, וסר_, pit_, रमों_
  { {0x7640007a,0xc05b002d,0x22b5001e,0xb6020066}},	//   limy, рім_, bāk_, řádk
  { {0x539b000b,0x54570009,0x6e2d0e00,0x2a66020d}},	//   _דיוו, _וסגן_, thab, klob_
  { {0xd3780027,0x60c2014a,0xb5fb0042,0x5e450012}},	//   jeći_, krom, _cháp, أَرْ
  { {0xd378001c,0x6e2d004e,0x644b0025,0x98be004b}},	// [2850] deći_, rhab, égio, ătă_
  { {0x1c050037,0x3e45001e,0x93270012,0x04670024}},	//   राइल_, rēti_, يران, ітам
  { {0x7640113b,0x6e2d1348,0xde590024,0x3e450035}},	//   kimy, phab, _гані_, sēti_
  { {0x52150015,0xd1b80012,0x36190009,0x69d90032}},	//   ядет, قاها_, _הוֹד, ufwe
  { {0x22b5001e,0x22a7000e,0x26080037,0x85960009}},	//   zāk_, zők_, हारी_, _מדרג_
  { {0x389c000b,0xf8bf000e,0xf807048c,0x251a0009}},	//   סיונ, lzés_, ючен, _הושא
  { {0xd00e0003,0xdce6001e,0x224d0058,0xdb031349}},	//   الى_, _izkā, _tjek_, _pení
  { {0x06090731,0x3e610028,0xf8bf0a27,0x9258003c}},	//   сник_, jótt_, nzés_, _даст_
  { {0xe4d60003,0xdb0301e3,0x60c2134a,0x76490a0c}},	//   كويت_, _vení, crom, rney
  { {0x22a7000f,0x87070003,0x22b5001e,0x98a20034}},	//   tők_, _وبال, tāk_, czkę_
  { {0xa3dd0037,0x2bdd0037,0xa2c00037,0xdb0311f8}},	//   थ्य_, न्या, _विण्, _tení
  { {0x22b50039,0x26f90037,0x2c6d022d,0x38c20028}},	//   rāk_, ्मीर_, _vždy_, _nærð_
  { {0x48fe0011,0x78720040,0x22a70031,0x22b50035}},	//   लियो_, hæve, sők_, sāk_
  { {0x3ce00037,0xd848001a,0xb4fa000b,0xeab10012}},	//   _कहते_, họn_, _לפני, _كعب_
  { {0x0e6a0003,0x44ed0107,0x539a0009,0xdbc6005e}},	//   مصري_, _až_, _פיקו, töök
  { {0xb2ba000b,0xa2c00037,0xa2ba000b,0x69db0051}},	//   _המקר, _वित्, _המקט, õuet
  { {0x973c0027,0x6c860003,0x3cf60037,0x718b0009}},	// [2860] _veći, سلام, ँटें_, _לְיַ
  { {0x1bf30037,0x22420033,0x77ca0001,0x3e45001e}},	//   _असफल_, likk_, _улог_, mētu_
  { {0xdcf600a2,0x38c20065,0xd3780027,0xf8bf000e}},	//   rayı, _færð_, teći_, szét_
  { {0x7aba0093,0xcc88001a,0xdcf6003a,0xfe790066}},	//   מצעו, _sớm_, sayı, jmů_
  { {0xd3780027,0x3e45001e,0x6441134b,0xf9930009}},	//   reći_, nētu_, kili, גרד_
  { {0xb05b008b,0xf093000b,0xd3780027,0xf8b70009}},	//   hrän, ענו_, seći_, לפני_
  { {0xd7f1001a,0xe9a6002d,0xdb080837,0x7fd70009}},	//   ỗi_, _навп, tadí, פוקס_
  { {0xa3d90037,0x11da0003,0x682b003a,0x26c5001b}},	//   ड्स_, _دورة_, _müda, šlog_
  { {0xdced0029,0x786d0029,0x42530012,0x90a50012}},	//   zbaľ, súva, _أنقر, _يحكم
  { {0xa2c00037,0x3e45001e,0x988b000b,0x351b0009}},	//   _विद्, dētu_, _הָאֵ, צוינ
  { {0x644f0108,0x22420119,0xa5bb0002,0xdb080017}},	//   écia, fikk_, _glów, dadã
  { {0xb05b0163,0xdee50003,0x7ae10052,0xdb030018}},	//   grän, _تأكي, _älte, _senã
  { {0xe1ff134c,0x6441134d,0x2167027f,0xca370009}},	//   blón_, bili, ятог, לנטה_
  { {0xb8f5015f,0x629c134e,0x645e0027,0x60c0000e}},	//   _हम_, _otro, jopi, ámma
  { {0x33db000b,0xe2a3001a,0x7bdb0009,0x30340012}},	//   _החוד, _chứ_, _הקוו, رِّر
  { {0x7e9b0009,0x3e450035,0x2bd80011,0xba9b0009}},	//   מסלו, bētu_, ब्रा, _פסחי
  { {0x91bc0093,0xc1bc000b,0x629c134f,0xf8bf000e}},	// [2870] _המחי, _המחש, _atro, rzés_
  { {0xa3be0011,0xf8bf0031,0x753d0031,0x69dd02a2}},	//   ेलि_, szés_, úszi, lfse
  { {0x99890066,0xf1d40037,0x2bd40011,0x41d10011}},	//   íkům_, _थामन, _दाना, _हादस
  { {0x3a26002c,0x78720058,0x682f0058,0xceb20009}},	//   gkop_, ræve, _møde, _ביט_
  { {0xbcfb000f,0xe0ce0014,0xc5fa000b,0x44ed1350}},	//   _ezér, ъв_, _ופרט, _už_
  { {0x23c30108,0x9f4700f1,0x7a360029,0x92c2003a}},	//   _déjà_, lené_, nštr, üşün
  { {0x3e450039,0x320900a2,0xfe790030,0x3a260227}},	//   zētu_, _onay_, tmů_, bkop_
  { {0x9f470026,0xdb070066,0xc7440003,0xdb0301e9}},	//   nené_, _její, عضوي, _nená
  { {0x28080066,0x6292001e,0x81170012,0xf8b90012}},	//   átní_, ējoš, _عذرا, _ذهاب_
  { {0x4b25002d,0x60cb002c,0xd8740012,0xa2f50009}},	//   дмов, mugm, _كالب, ֵמָה_
  { {0x61f600a2,0x22420033,0xbb850003,0x28080066}},	//   _payl, tikk_, بلدي, štní_
  { {0xf8d10037,0x20d10037,0x923a002d,0x249f0028}},	//   _समाय, _समाध, ічну_, ppum_
  { {0x9f4700f1,0x64410175,0xd3780027,0x22420033}},	//   dené_, pili, deću_, rikk_
  { {0x3e450039,0xaac50037,0x26d800c1,0x7e620066}},	//   rētu_, _विपक, ttro_, _zkop
  { {0xcc56000b,0x26d81351,0x6fdf0011,0x2bcc0011}},	//   _קבצי_, utro_, प्यं, ालसा
  { {0x764d0101,0x3e4500cd,0x74a40011,0x290001a0}},	//   gnay, mēts_, चीकृ, _tria_
  { {0x3e45001e,0x629c1352,0xdb081007,0x645e1353}},	// [2880] lēts_, _stro, madá, topi
  { {0xe2a30020,0xf3ca0012,0x6c330012,0x682d0034}},	//   _thứ_, تبره_, نفقا, aźdz
  { {0x3e45001e,0x3e48000d,0x9f4701bd,0x2bdd0011}},	//   nēts_, eşte_, bené_, न्धा
  { {0xa2c00044,0xfaf80039,0xc332000b,0x9f470066}},	//   _विस्, _šīs_, כוב_, cené_
  { {0x08970003,0xc27b0009,0xdb080031,0x20d30012}},	//   وضوع_, קרני, iadá, نتوج
  { {0xb9370009,0x0ee20011,0x889b0009,0x2bdd0011}},	//   וננו_, _पहाड, קבצי, न्दा
  { {0xe7e00044,0xdee30001,0xdb01000e,0x63830511}},	//   ख्या_, воји, bblé, _агра
  { {0x4e770003,0xbb3b000b,0x61eb00c1,0x3e45001e}},	//   وحيد_, _ועלי, cegl, dēts_
  { {0x40930012,0x01d70012,0x83fc001b,0x01630aa2}},	//   _للقر, _توقع_, hođe, _акто
  { {0x83fc001c,0x2240000e,0x9f47022d,0xdb0305b1}},	//   kođe, _amik_, zené_, _sená
  { {0xcc880020,0xd6cf0003,0xac370012,0x97260012}},	//   _mới_, _نقل_, بسيط_, _تفاو
  { {0xdb08000f,0xd6260003,0xc7b80027,0x44441354}},	//   gadá, _تعطي, _dođe_, hi_
  { {0x9f47022d,0x69dd0028,0x99490012,0x7c2e1355}},	//   vené_, rfse, سلسل_, _olbr
  { {0x61eb003e,0x7e6000c6,0x9f430066,0x6bd70003}},	//   zegl, lomp, sejí_, _يونس_
  { {0x83fc0027,0x290d000d,0x3e45001e,0x9f471356}},	//   gođe, ţea_, cēts_, tené_
  { {0x41e7002d,0x98b90048,0x5c99003c,0xf1b90030}},	//   _ціка, _елит_, зкая_, _koše_
  { {0x9f470029,0x5c751357,0x49d60009,0x7bde0032}},	// [2890] rené_, елат, _אֵין_, ffpu
  { {0x68300051,0x78a200f1,0x83fc0027,0x9f4c01bd}},	//   _päde, dpov, bođe, ždá_
  { {0x64890010,0xf1b90027,0x7e6900d9,0xb5fd1358}},	//   _džia, _loše_, ylep, loše
  { {0x60cb002c,0x6830006f,0x7d02000e,0x05190003}},	//   tugm, _väde, _oros, _فيجب_
  { {0x5d850003,0x3e45001e,0xb5fd0027,0x759a0009}},	//   _سلسل, zēts_, noše, _מסרג
  { {0x61eb0d6c,0x46f500b3,0xcf250012,0x2c050011}},	//   segl, ечит, فرعي, राओं_
  { {0x661d0006,0x64450c2a,0x61eb1359,0xa2c00011}},	//   _kosk, mihi, pegl, _विष्
  { {0x6445002c,0x661d004a,0x7d02135a,0xfe710012}},	//   lihi, _josk, _bros, ددت_
  { {0xdfdb0014,0xca29000b,0xa8a7002d,0x74150003}},	//   _мъж_, _ִם_, _ірак, فوظا
  { {0xa2c00044,0x64450101,0x7e690051,0x7af50002}},	//   _विश्, nihi, slep, _kszt
  { {0x43740024,0x6445008e,0x24160009,0x5ed40012}},	//   куют, iihi, תחתן_, _لتنز
  { {0xc8690093,0x64450101,0x661d0039,0x83fc0027}},	//   _הן_, hihi, _nosk, vođe
  { {0x65941154,0x444400a2,0x64450101,0xfce5002d}},	//   _рачу, yi_, kihi, _чоло
  { {0x7bc30028,0x7af5000e,0x9d1a000b,0x4444135b}},	//   ónul, _oszt, _מונט, xi_
  { {0xbcfb000e,0xcf920009,0x26040011,0x9e76004c}},	//   _szép, רטל_, वाची_, ећај
  { {0x26120037,0x62890002,0x44440a87,0xceb20009}},	//   थायी_, _nieo, wi_, טיל_
  { {0x2bb60037,0x7af5000e,0x661d084b,0x6a440031}},	// [28a0] _आजमा, _aszt, _dosk, lőfo
  { {0x3ec500a2,0x4d63002d,0xdb030097,0xa7fc0060}},	//   üstü_, укув, _venæ, _akın
  { {0xdb0c000e,0x660b00b6,0x79fa0009,0xfeba0012}},	//   űköd, _ongk, ּלְח, _عادت_
  { {0xcc88008a,0xf1b20012,0x5e460012,0xdb060030}},	//   _với_, اءا_, _أَحْ, áméh
  { {0x64450101,0x67d40001,0x7af50031,0x26c7135c}},	//   bihi, волу, _eszt, erno_
  { {0xcc880020,0x3e4c0066,0xd6d00003,0x660b0a26}},	//   _tới_, měti_, لقت_, _angk
  { {0xdb0a00c5,0xad9b0028,0x67b70012,0x97a50024}},	//   _udfø, _snúi, راوح_, тріл
  { {0x89a50012,0x95d70048,0xdb240097,0x7d02135d}},	//   _لإكم, едът_, ðsíu, _pros
  { {0xfd120003,0xb17b006f,0x54540646,0xda650012}},	//   اجع_, neåt, квит, _شافي
  { {0xccf30093,0xe0860003,0x88bb0009,0x660b016d}},	//   רכז_, _أجري, _מזמי, _engk
  { {0x200c135e,0xf2e5000d,0xbd8a0012,0x2259003c}},	//   _indi_, ţând_, _فنان_, дины_
  { {0xd5d60012,0xb05b008e,0x7d02135f,0x7c281360}},	//   _ستؤث, rräm, _tros, skdr
  { {0xdca3002d,0x661d004a,0x6445004a,0x64a30024}},	//   _бачи, _rosk, yihi, _бача
  { {0xdb07000e,0xb5fd04d2,0xdb030248,0xf5370009}},	//   _lejá, roše, _benä, _אנדי_
  { {0xadf40037,0x63bc0028,0x3ca90011,0xabfb0009}},	//   _आसान_, órnu, _चौड़ा, _מהגר
  { {0xfe730012,0x29041361,0x5eeb0009,0xab2900ae}},	//   ادس_, _orma_, הַמְ, _تسهل_
  { {0xa5bb0028,0xebc70001,0xf1bf0066,0x64451362}},	// [28b0] _slós, ељен, nkám_, tihi
  { {0x93940003,0x7d06004a,0x69c008b9,0x201e1363}},	//   هجما, äksy, _adme, _noti_
  { {0x644500a2,0x61e80031,0x49d90024,0xdb070031}},	//   rihi, ődle, ддею_, _bejá
  { {0xa294002d,0xb6ba0009,0x200c1364,0x1dd00011}},	//   уаці, _קצרי, _andi_, _सफ़लत
  { {0x7e6d0039,0xe1f00003,0x68300a9d,0xdb0701e3}},	//   mlap, إسم_, _häda, _dejá
  { {0x7e6d1365,0x2898000b,0xab950001,0x7bd50002}},	//   llap, עדון_, _јављ, _uczu
  { {0x316c003e,0xe4540015,0xcc540014,0xf4560009}},	//   ędzi_, _скры, _свръ, _יישר_
  { {0x60c4007a,0x7e91001e,0x7e6d000e,0x682b0052}},	//   šima, _jāpi, nlap, _südl
  { {0x9f4a0054,0x6cd20003,0x9f471366,0x25dd0011}},	//   rebé_, لقيا, mení_, क्षी_
  { {0x9f470145,0xcce40003,0x61fb0824,0xe3b10012}},	//   lení_, اسيي, _haul, جرة_
  { {0x68300005,0xe1bf0037,0xe8d10037,0x26dc01e9}},	//   _näda, ्लंघ, _समुच, ctvo_
  { {0x9f470029,0x660b010a,0x6f480009,0xff160009}},	//   není_, _ungk, _אֲנַ, _בקעת_
  { {0x29040065,0x7e6d001e,0x91ba000b,0x60dd0040}},	//   íma_, dlap, ומרי, gtsm
  { {0x25dd0037,0xd0120003,0x69a20011,0x91a20011}},	//   क्री_, جلس_, _क्री, _क्रै
  { {0x998f0010,0x023a0003,0x23bc0030,0x60dd1367}},	//   nigų_, _يثبت_, hájí_, atsm
  { {0x9f470145,0xdb03004a,0xe8d10011,0xa7fc0060}},	//   jení_, _venä, _समूच, _akıl
  { {0x9f470042,0x44310227,0x0d860db7,0x6a781368}},	// [28c0] dení_, _blz_, тлан, nífe
  { {0xe0b70009,0x6faa0012,0xd9ba0011,0x2bdd0011}},	//   _שליט_, _تهدف_, उण्ट, न्ला
  { {0x3daa0015,0xe9da0015,0xb5fd0029,0xcb0a0003}},	//   _окно_, дке_, alši, بيان_
  { {0x7229002d,0x64890010,0x1e970009,0xdb030040}},	//   нців_, _užin, _שככל_, _genå
  { {0x6c860003,0xb7b5001a,0x314d0009,0x201e1369}},	//   _للحم, _vọn, ּתוּ, _poti_
  { {0x03a3007c,0x493b0009,0x69dd0248,0x913b0009}},	//   _виро, וגנו, _ösen, וענק
  { {0xddcd000d,0xf837000b,0x044300b3,0x9f4700d9}},	//   noaş, כנסת_, _терн, bení_
  { {0x9f470013,0xceb3000b,0x1af70009,0x69a20011}},	//   cení_, ביה_, _במלל_, _क्ली
  { {0x2904000d,0xb8e50012,0x71660012,0xba550048}},	//   _urma_, _مثله, _شارك, _стръ
  { {0xfa8a0020,0xa1050003,0xa84a0012,0x2d8f00b0}},	//   _mẫu_, _حذفه, _غلام_, _egge_
  { {0x0bb7000b,0xd7760003,0x83fc0027,0xfbd30009}},	//   כלים_, _شائع, gođa, בתת_
  { {0xda350015,0x61e20052,0xd7d20037,0xb2bb0009}},	//   уемы, nfol, _साँच, ומטר
  { {0x2e37000b,0xcc88001a,0x9f450042,0x7a260097}},	//   _בראש_, _bớt_, _malý_, _nótu
  { {0x9f4708cd,0xa4b70009,0xa3b60011,0xc7c4003c}},	//   zení_, _ילדה_, _ज़ि_, исси
  { {0xb5fd001e,0x80cc0011,0x6f240024,0x53330048}},	//   loša, _समझे, аєте, _вещт
  { {0xe654002d,0xb5a40015,0x64430002,0x2d8f0058}},	//   авсь, ируй, _zmni, øge_
  { {0x3d0d0044,0xb5fd0039,0x9f47014a,0x55750014}},	// [28d0] समें_, noša, vení_, угат
  { {0x7e6d039c,0xd0f8000b,0x8434002d,0xd7f10012}},	//   slap, _יצחק_, анує, _اكد_
  { {0x68e900c1,0x9f470004,0xa3c40011,0xfbd00012}},	//   _sped, tení_, _एयर_, غتك_
  { {0xb5fd001e,0xe1ff0bb6,0x6e3600d9,0x2c790025}},	//   koša, ndó_, chyb, mède_
  { {0x89a8002d,0xb5fd001e,0x9f470029,0xe0df00c1}},	//   тків_, joša, rení_, ntò_
  { {0xb5fd0039,0x29c3001a,0x3e5a01bd,0x9f4705b1}},	//   doša, ựa_, rďte_, sení_
  { {0x36690047,0x64480f68,0x2bb60037,0x61fb136a}},	//   нако_, didi, _आज़ा, _taul
  { {0xd5b10003,0x83fc0027,0xd9bf0011,0xc7b8001b}},	//   حفظ_, vođa, ्लोट, _vođa_
  { {0x7a260065,0x9f43004a,0xb5fd001e,0x229a001e}},	//   _mótt, lejä_, goša, _rīka_
  { {0x6e950048,0xb05b0032,0x78bd0097,0x6448136b}},	//   _бижу, bräi, dssv, gidi
  { {0x96fb0003,0x84580014,0x6e2d003a,0xdddd0064}},	//   _تعذر_, ърът_, kkab, _zisť
  { {0xb5fd001e,0x9f4701a0,0x98a00073,0x6448136c}},	//   boša, menà_, šią_, aidi
  { {0xfd100003,0x26c5000e,0x3c360058,0x4a430048}},	//   _وجه_, álon_, _hæve_, сняв
  { {0x9f430006,0x7a260017,0xc1bf0011,0xa6aa0012}},	//   kejä_, _rótu, ्लॉग, فارق_
  { {0x7529000e,0x3ebe0028,0xae170037,0xdb010051}},	//   lyez, étt_, थापन_, nalü
  { {0x661b00c6,0x6e2d002c,0x672102eb,0xb17b0262}},	//   njuk, gkab, älja, reår
  { {0x753b0052,0xddc40010,0x8c95002d,0xab64003a}},	// [28e0] nzuz, gliš, архі, zcüğ
  { {0x1c0e0037,0x661b0051,0x6e2d0376,0xbc6a0012}},	//   साइल_, hjuk, akab, رمان_
  { {0x49ca022a,0xd62a011d,0x73950024,0x316d0025}},	//   елен_, _зоне_, ршує, _ayez_
  { {0x32650024,0xb05b0248,0xddc40159,0x6448136d}},	//   атів, tsäg, bliš, zidi
  { {0x28f80800,0xad9b0029,0x9f470029,0x61e2136e}},	//   тель_, _vnút, rdný_, rfol
  { {0xe1ff0031,0xdb030411,0xb5fd136f,0x60c40073}},	//   rlói_, _denú, voša, šimo
  { {0xb7db000b,0x9e14002d,0x7ee30012,0xeaa70012}},	//   תקצי, идкі, مكون, _دع_
  { {0xb5fd0039,0xceb3000b,0xb87b0c56,0x9ed70048}},	//   toša, זיה_, otíc, умът_
  { {0x2fd60003,0xd83f009b,0x25b90028,0x7529000e}},	//   _متاح, ščih_, ðsla_, gyez
  { {0x2a66002c,0x09bf0037,0xb5fd013c,0x3e57004b}},	//   loob_, ्ल्य, roša, răta_
  { {0xd793000a,0x78a40149,0x7d040006,0x6f930003}},	//   _المخ, _ativ, hvis, _المض
  { {0xa2cc0037,0xd357000b,0xb5fd1370,0x5e9b0009}},	//   _हिन्, ריטי_, lošn, _נבדק
  { {0xc5f30093,0xa2c00037,0x9f47014a,0xd5bf0035}},	//   _לדף_, _विक्, mená_, žāku_
  { {0x3ebd004a,0x7a260028,0xe0df00c1,0x9f4701bd}},	//   _äytä_, _sótt, rtò_, lená_
  { {0xf8d10044,0x9f34002d,0xdb9b000b,0x682b0052}},	//   _सम्प, бері, _אסור, _jüdi
  { {0x9f470029,0x63b51371,0x7bca0028,0xadf90037}},	//   nená_, _sezn, ófun, ्ययन_
  { {0x5bcb0001,0x786d0029,0xdb0e0164,0x7c970012}},	// [28f0] ећег_, súvi, _debí, اشرا
  { {0x68ed0101,0x6e220051,0x212b0002,0x9f43004a}},	//   _ipad, _loob, mych_, tejä_
  { {0xe298002d,0x64890010,0xdd910012,0x8f9a0009}},	//   гає_, _užim, _وود_, _ביתי
  { {0xa4d5007c,0xd1310003,0xd6e80009,0x58b90012}},	//   _комі, يما_, _עַתָ, ناتج_
  { {0x212b1372,0x3ce0000d,0x629a0061,0xab95002d}},	//   nych_, ctiv_, _éton, _вигі
  { {0x41260015,0x63ba0027,0x9f43004a,0x389c0009}},	//   рошо_, jatn, pejä_, עיונ
  { {0xdb58002d,0xc7c40015,0xc7d80009,0xbfb80012}},	//   _бют_, ссчи, אווי_, اطها_
  { {0x212b0029,0x9f4a0769,0xd5ae0012,0x64580159}},	//   kych_, lebã_, وفى_, _ajvi
  { {0x680b0039,0x63ba1373,0xe616003c,0x67d5004c}},	//   _pēdē, fatn, рды_, _возу
  { {0x3ce50037,0x13090015,0x442300eb,0xa2cc0011}},	//   _कहीं_, вной_, _joj_, _हिम्
  { {0x9f45000f,0x9f4c0029,0xdb01000e,0x35f5027f}},	//   _való_, ždú_, való, _впер
  { {0xa2d60044,0x7d04004a,0x9f470066,0xcad60009}},	//   मंत्, yvis, cená_, סורת_
  { {0x67210163,0x63ba00b6,0x6d4b0028,0x23dd0011}},	//   äljn, batn, úgal, _मापद
  { {0x5d3a000b,0x645d0061,0x80cd0037,0x98a0001b}},	//   _בתנא, ésid, _सिने, šić_
  { {0xbb42002d,0x61e90027,0x683f0010,0xddc90029}},	//   _мешк, _obel, _išdė, tieň
  { {0x31260014,0x656f0066,0x78a400b8,0xb21b0040}},	//   _вдиг, _bych, _ttiv, lmæn
  { {0x212b003e,0xb21b0058,0x3b960001,0xcd270024}},	// [2900] cych_, omæn, ајет, ажте_
  { {0x69db0164,0x04460001,0x9f4701bd,0x629e052e}},	//   _acue, шезн, zená_, _époc
  { {0x23dd0037,0xb5fd001e,0xb87b1374,0x68fb005e}},	//   _मानद, jošo, stíc, _asud
  { {0x27ed001c,0xcc88001a,0xd356000b,0x2cbf0e0c}},	//   đene_, _lớp_, ביעי_, ksud_
  { {0x6fb60003,0x9f580054,0x9f4701e9,0x656f0032}},	//   لمشا, ldrà_, vená_, üchl
  { {0x2d980066,0xc953000b,0x3ec60021,0x6d3b0009}},	//   ěrem_, חמד_, асиб, _יתכנ
  { {0x212b003e,0x63ba1375,0x9f580054,0x6e22009b}},	//   zych_, vatn, ndrà_, _poob
  { {0x7bc30028,0x88c60003,0x27e90027,0x63ba11f7}},	//   ónuv, _نتطل, đana_, watn
  { {0x9f470029,0xadf70003,0x80a60003,0x10a3077e}},	//   rená_, شريط_, _ضمان, _митн
  { {0x3cf90037,0xddc00030,0xb05b0245,0x7c231376}},	//   _उनसे_, pomů, nrät, _conr
  { {0x212b0656,0x2905001e,0x3c770009,0xdfcf0012}},	//   wych_, ālam_, שתים_, _زين_
  { {0x212b084b,0xade20011,0xe9190024,0xfce602ab}},	//   tych_, क्शन_, гомі_, _водо
  { {0x984b0014,0x92580014,0x68e21377,0x9d1a0012}},	//   вява_, раят_, ntod, _جزاء_
  { {0x50670046,0x656f0145,0x212b0002,0x2bdd0037}},	//   ртма, _rych, rych_, _माया
  { {0xc058007c,0x67160037,0xe7300003,0xf8bf1378}},	//   рія_, थमिक_, وصف_, ssé_
  { {0x7a360010,0xbbaf0011,0x7147003c,0xaa44004c}},	//   kšty, टर्क, _вхож, _мејл
  { {0xd7e7002d,0xadf90037,0xe4d90012,0xfd100012}},	// [2910] _кіно, ्यतन_, طوات_, وجك_
  { {0x63b80033,0x656f00d9,0xb05b0810,0x9c38004c}},	//   _jevn, _vych, träu, апут_
  { {0xd7dc0044,0x656f0002,0x682b0052,0xb9950012}},	//   _बातच, _wych, _südw, ملاب
  { {0x44230002,0xdb05005e,0xed59001b,0x67280248}},	//   _woj_, mahü, laže_, ädje
  { {0x44230027,0xfe000037,0x81c8002d,0x3ce50011}},	//   _toj_, _लोटस_, ргів_, _कहें_
  { {0x73c50003,0xb5fd001e,0xfaa7002d,0x63b81379}},	//   _ديسم, tošo, _вшан, _nevn
  { {0x26c10382,0xf838000b,0x7bc30028,0xab04005e}},	//   ého_, שנות_, ónuu, _ööpä
  { {0xa2c0015f,0x7c2300a2,0xcf580093,0x9f580164}},	//   _विज्, _sonr, יבות_, ndrá_
  { {0x1c45002d,0xdb0705b1,0xed5902a1,0xf5320009}},	//   йним, _nejú, kaže_, ּ֥ח_
  { {0xc6e7007c,0x4ee7002d,0x1c110037,0x2d9f0802}},	//   _відп, _відз, ़ाइल_, scue_
  { {0xd6db0046,0xe36500b3,0xf9890009,0xdddb004b}},	//   _шта_, скни, _נר_, cluş
  { {0xf5950003,0x8d950003,0xe1f20003,0xb21b0040}},	//   _الإج, _الإش, أسد_, smæn
  { {0x6abc0028,0x659a0009,0x5fdc0011,0x5d850012}},	//   árfr, _עיסק, _बादल, _الشل
  { {0xf66a0065,0x07a30345,0x7c3a01e0,0xb4cb0011}},	//   phæð_, зарн, chtr, रूज़_
  { {0xf1d80037,0xfbb6000b,0x2001003a,0xdb1c01bd}},	//   _डालन, _הפצת_, _dahi_, _odrá
  { {0xb05b0032,0xe9da0867,0xc68f0012,0x9f47008e}},	//   tsäc, _ски_, ِّف_, menä_
  { {0x62980052,0xe3b20012,0xca370009,0xa3de0011}},	// [2920] _zuvo, كرا_, _לנקה_, _णाम_
  { {0x8ccf0044,0x05550024,0xddcd0034,0x9c290009}},	//   _दिनो, іття, gnał, נֵּ֥
  { {0x5f060047,0xadf90037,0xdb0a0052,0x5276002d}},	//   _узна, ्यान_, _gefä, буду
  { {0xd5b90015,0x91ba0003,0xb05b09d1,0x87170009}},	//   _всё_, اطار_, srät, _הקטע_
  { {0x660400a2,0xa3d70037,0xb05b006f,0x511800b3}},	//   mdik, िला_, prät, ролю_
  { {0x33d5007c,0xd6da002d,0xdfd00003,0xdfcf0003}},	//   _міст, гти_, ذيب_, فيه_
  { {0xe8190044,0x6604137a,0xfe1c0011,0x8f9b0009}},	//   दाता_, odik, _पचास_, ניקי
  { {0x91e30345,0x1d340048,0xb05b008e,0xf1bf0031}},	//   _носе, жния, isäa, nkát_
  { {0x27330020,0xed87002d,0xbd440003,0x6da30001}},	//   ạn_, йськ_, تنظي, чиња
  { {0x26c5000e,0xf4110009,0xa4fb0009,0x29370009}},	//   álok_, ֵ֤י_, נליט, _האמן_
  { {0x6e960003,0xe6960003,0xd5af137b,0x60c2137c}},	//   _الصا, _الصد, _нс_, lsom
  { {0xc333000b,0xe7170009,0x33770009,0xddcd0034}},	//   פור_, _לחבר_, מעים_, znał
  { {0x9e65000a,0xdb15000e,0x63be00b6,0x914b115e}},	//   _بالن, _vezé, kapn, учна_
  { {0xa055002d,0xf1db0037,0xc1570009,0x7afc0040}},	//   івві, _भावन, משכו_, ærts
  { {0x9f34002d,0xed5907a5,0x8f9b0009,0x2001005e}},	//   пері, raže_, רילי, _vahi_
  { {0x66020005,0x5b57000b,0xd3570009,0x44e20097}},	//   _jaok, _לשון_, _לשוק_, oð_
  { {0x5fc80044,0xe5730003,0x61ed002c,0x3cb80009}},	// [2930] रणाल, سطر_, _ibal, שֶֽׁ
  { {0x44e20065,0x7bda137d,0x7d1d137e,0xdb180025}},	//   ið_, ngtu, ässi, _revê
  { {0xaab50024,0xf2c40012,0xf1bf0031,0xf24b0009}},	//   ійді, كْلُ, bkát_, ְגְּ
  { {0xb05b0422,0x8f880009,0x3c2f0060,0xddc90035}},	//   präs, _לְרֵ, _sıvı_, kleš
  { {0x7bc30065,0x60e7002d,0x5c070048,0xa969004c}},	//   ónus, сцез, _лява, јила_
  { {0xbcfb0061,0x1ef90012,0x16a9016e,0x9ea9137f}},	//   _exéc, لعبة_, авки_, авка_
  { {0x44e20065,0x6298000e,0x2fd60012,0x6235003c}},	//   eð_, ívot, زويد_, _деву
  { {0xe7f50044,0x8237000a,0xf625002d,0x7bda0bb9}},	//   _इसका_, _ارسا, ідпо, egtu
  { {0x7e6900bd,0xee36002d,0xddc9009b,0x6e3b00b6}},	//   roep, інь_, gleš, rhub
  { {0x40e8000b,0x61ed1380,0x9f47008e,0xf1bf0031}},	//   _לַעֲ, _abal, tenä_, zkát_
  { {0xfbd20093,0x44e20028,0x60c40027,0xd8740012}},	//   ותי_, að_, _svim, _راكب
  { {0xc7a90093,0xa2cc0037,0x7bda020d,0x75150012}},	//   _יב_, _हिस्, agtu, _وواض
  { {0xdb0300a2,0x644f0061,0x9f47004a,0x6e440012}},	//   _henü, écis, senä_, _عنهم
  { {0xdb1a000f,0x2cad002a,0x389a0009,0xfc3f0030}},	//   zaté, mped_, יישנ, _stín_
  { {0x7d091381,0x2cad002a,0x02460012,0x44271047}},	//   lves, lped_, _وَتَ, _ion_
  { {0x78a90013,0x27ed001c,0x85050037,0x4427006f}},	//   _otev, đena_, रिंट_, _hon_
  { {0x44271382,0x9c260014,0xdb9a0001,0xec4a0593}},	// [2940] _kon_, одад, атељ_, азал_
  { {0x2aed0044,0xf2020011,0xb87b0018,0x1bba0012}},	//   _जहाँ_, _रोज़_, ntíl, شائع_
  { {0x44270108,0x290d1383,0x1ae30048,0x7c270034}},	//   _mon_, _area_, дохм, _dojr
  { {0x27f81384,0x72160012,0xd2590024,0xb05b0d4c}},	//   lern_, غذائ, бці_, nsän
  { {0x60c20010,0x7bda0010,0xa183003c,0xdb1a1385}},	//   usom, ygtu, мышл, raté
  { {0xb8f20044,0x44271386,0x27f80052,0x4ea600de}},	//   _वि_, _non_, nern_, ориа
  { {0xab2a0019,0xd6d00003,0x1ef70012,0x3e48004b}},	//   _това_, رقة_, قعية_, eşti_
  { {0x69d60037,0xd4b80015,0xcf93000b,0x60cd001e}},	//   _भागी, блиц_, וטו_, šama
  { {0xe4e6007c,0x7d540014,0x44271387,0x27f8031d}},	//   ційн, явих, _bon_, kern_
  { {0x44e20065,0xbc670003,0xe61f0029,0x44271388}},	//   rð_, يمين_, _zhôd_, _con_
  { {0xda7b0047,0xe2f8002d,0x78830066,0xdb030052}},	//   иям_, щені_, _důvě, _genü
  { {0x648906bc,0x63bc0052,0x7d09009b,0x92580015}},	//   _uživ, _lern, bves, жают_
  { {0xc218007c,0x27f80052,0x32040002,0xa6330024}},	//   ією_, fern_, _mamy_, _інші
  { {0xdb181389,0x27f808ec,0x9f4c0042,0xddcd0034}},	//   _levé, gern_, ždý_, znań
  { {0x629c007a,0xf7700003,0xba770003,0xa5c30002}},	//   _nuro, ناف_, _واعت, spół
  { {0x8b3b000b,0xdb18000e,0x26cd0027,0x7f3b0009}},	//   _כתוצ, _nevé, čeo_, בעלו
  { {0x98a20002,0x27f802f9,0xdb0306fe,0x629c138a}},	// [2950] tyką_, bern_, _fenó, _auro
  { {0xf1d80044,0x645a0993,0xddcd004b,0x69dd138b}},	//   _डाउन, nnti, flaţ, lgse
  { {0x63bc0108,0xdb18000f,0x2bb80003,0x645a138c}},	//   _dern, _bevé, زالة_, inti
  { {0xf9c7007c,0x290d007d,0xb5fd0470,0x7b640014}},	//   іщен, _prea_, rošk, фтуе
  { {0x361a000b,0xddc80002,0xe3d70012,0xf9900012}},	//   _הורד, łośc, _وتسع, نبه_
  { {0x629c00c1,0x290d000d,0x09340003,0xdfd10003}},	//   _furo, _vrea_, برمج, ريع_
  { {0x9f470029,0xc9f70012,0xa49b01a0,0x91f70012}},	//   lenú_, _وسرع, _eròt, _وأرا
  { {0xf1bf0065,0x56920001,0x4427138d,0x682f0989}},	//   _þá_, најт, _son_, _nødv
  { {0x7d090010,0xc6480003,0x98170012,0x27f8138e}},	//   uves, تجول_, _وبطا, yern_
  { {0x443e0274,0xfb960009,0x7d09138f,0xf7730012}},	//   ght_, ּ֣ית_, rves, _قاض_
  { {0x4427032b,0x63a5008b,0xdb0e0052,0xcb691390}},	//   _von_, ichn, _gebä, сане_
  { {0x98cf0044,0x2cad0666,0xf8cf0037,0x4427051c}},	//   _हटाए, pped_, _हटाय, _won_
  { {0x200506db,0xb5fd001e,0x44271391,0x263f0034}},	//   _kali_, joši, _ton_, głoś_
  { {0x443e02a4,0x27f80052,0x9f470029,0xec780024}},	//   cht_, uern_, denú_, _дпі_
  { {0x7bc11392,0xec36000b,0xa856000b,0x20051393}},	//   malu, _מאסר_, לישה_, _mali_
  { {0x7bc100c6,0x9f4b000f,0x629a0061,0x27f80052}},	//   lalu, áját_, _étoi, sern_
  { {0x229a001e,0x290000b6,0x4a57000b,0x63bc1394}},	// [2960] _rīki_, _usia_, _משקל_, _pern
  { {0xdb1e000e,0xe8f7003c,0x244a0012,0xdb0a0018}},	//   lapé, _эль_, حجري_, _refú
  { {0xb05b0006,0x4f9b000b,0xe7b7000b,0x7dd6003a}},	//   isäl, _לביצ, _מהיר_, nüsü
  { {0xd36f0003,0x11d70003,0x9f470064,0x62870030}},	//   دهم_, كومة_, benú_, ňkov
  { {0x645a0006,0xe572000a,0x200500c6,0x63bc1395}},	//   ynti, _سطح_, _bali_, _tern
  { {0x66060a73,0x7b01004a,0x7532001e,0xa1570009}},	//   _hakk, äytä, īdzī, הבנה_
  { {0x5f930046,0x644e0101,0xb17b0950,0x6e360010}},	//   ништ, _imbi, mgåe, okyb
  { {0x225a0003,0x6e360010,0x66061396,0x6d440032}},	//   _الرد_, nkyb, _jakk, ozia
  { {0x6d441397,0x361b000b,0xe62a001a,0x3cf80011}},	//   nzia, מוקד, _độ_, ्टें_
  { {0x2005007a,0x113b000b,0x644f0061,0x533404ad}},	//   _gali_, _התמל, écip, деот
  { {0xe41a04b4,0xddcd0013,0xe9f9002d,0xed5902a1}},	//   _kľúč, hlaš, онні_, raža_
  { {0x1e860047,0x0e9b000b,0x60c40010,0xb87b0028}},	//   _элем, _השאל, šimu, rtím
  { {0x58870047,0x6296003a,0x69dd1398,0x9f5e01a0}},	//   зыва, _diyo, rgse, _matí_
  { {0xc9530093,0x6d44003e,0x27ed001c,0xc05b002d}},	//   תמש_, dzia, đeno_, сім_
  { {0xb17b0058,0x86c50012,0x9f5a1399,0x7dd60060}},	//   dgåe, بيزن, _papá_, cüsü
  { {0x33770093,0xb5fd001e,0xa2d30011,0x735b0009}},	//   _מתוך_, toši, _डिब्, _לכוח
  { {0x63a50163,0x6a7d0164,0x7e6d000d,0xddcd0133}},	// [2970] tchn, léfo, roap, glaš
  { {0x00bc0009,0xb5fd139a,0x9f4d0064,0xcf270012}},	//   _המזמ, roši, čnúc_, _فرجي
  { {0x3cf90044,0xd5ed0020,0xc7b2000b,0x0af90003}},	//   _उनके_, hoả, _שבט_, تفاظ_
  { {0x63a5008b,0x66060028,0xddcd009b,0x7bce0002}},	//   schn, _gakk, blaš, óbuj
  { {0x8c3b008b,0x3cf80037,0x99840066,0x63a50034}},	//   _auße, ्टों_, _domů_, pchn
  { {0x8cbf0011,0x60cd0035,0x26c50030,0x20070031}},	//   लीफो, šamo, šlou_, udni_
  { {0x2005139b,0xca770003,0x7d0d139c,0x7d0202a0}},	//   _vali_, _فارغ, lvas, _asos
  { {0xff18000b,0x443c004a,0x200500b6,0xdb1a0fe1}},	//   לקות_, _alv_, _wali_, gatí
  { {0x2bb90003,0xd0d40014,0x2005139d,0x89340012}},	//   يادة_, _потъ, _tali_, _كعكا
  { {0xfc310003,0xa0c40003,0xcac9003c,0x7dd60060}},	//   ئحة_, _أيلو, огое_, tüsü
  { {0xb05b0163,0x3ce90051,0x6d4400c1,0x60c40010}},	//   rsäl, htav_, zzia, šimt
  { {0x7bc1139e,0xc7b8001b,0x05550048,0x7dd60060}},	//   salu, _dođu_, _отля, rüsü
  { {0xbd45000a,0x6609003a,0x95c80024,0xfc310012}},	//   _تنشي, mdek, _хліб_, _لحث_
  { {0x6d440029,0x4c9a0009,0x40950fa4,0xb8f60011}},	//   vzia, _ובסו, ерст, _हि_
  { {0xdee31128,0x28d30037,0xe73a00de,0x3d030037}},	//   кори, _तिथि, цев_, _वनडे_
  { {0x442a1211,0xcad60009,0x9e75004c,0x98a20034}},	//   _sob_, _חוקת_, ећуј, zykę_
  { {0x15fd0044,0x15e20037,0xfe790066,0xdd8f0012}},	// [2980] उज़र_, क्टर_, ilů_, لوف_
  { {0x6e2b00bd,0x6609004a,0xdb1a0030,0x6d44139f}},	//   _logb, hdek, zatí, rzia
  { {0xf093000b,0x98a20010,0x660613a0,0x06860223}},	//   _שנת_, vykę_, _takk, _огон
  { {0xa2d50037,0x7df90037,0xddcd001e,0x2a600051}},	//   _भिन्, ्योग_, plaš, õib_
  { {0x98a20002,0x08fa0012,0x8dfb0009,0xb5fd0035}},	//   tykę_, تراب_, _והכת, nošu
  { {0x6bd60012,0x645d0025,0x76aa0e5f,0x60c909df}},	//   _تتحر, ésil, отив_, _dvem
  { {0xe80f0044,0xd3720003,0x8c3b0052,0xdb1a01c2}},	//   ायता_, _شهر_, _fußb, tatí
  { {0xd5b00003,0x44250058,0x7c2a0c56,0x2498005e}},	//   دفة_, ejl_, _sofr, _hirm_
  { {0x69c00039,0xab5c0039,0x7d1b0054,0x34940048}},	//   _ieme, daļa, _àust, наир
  { {0x6fb30003,0x69c013a1,0xd467004c,0xddc90034}},	//   _لمكا, _heme, миње_, gieł
  { {0x69c000c6,0x03d7000b,0x2057000b,0xa08b000b}},	//   _keme, ווים_, _קיבל_, _וְאִ
  { {0x9f580029,0x682f0260,0x6fdc0011,0x6ec50012}},	//   ceré_, _føds, _बाउं, _أتلق
  { {0x229a0039,0x69c000c6,0x656f0052,0xcd360012}},	//   _rīku_, _meme, ücht, _تراب
  { {0x6441008b,0xd0840015,0x69c006ef,0xdb150031}},	//   chli, выси, _leme, _lezá
  { {0x7641007a,0x32670014,0xfe730012,0x7bdb0009}},	//   ūlym, _отив, ندر_, _וקוו
  { {0xe508001a,0xbddb0f4c,0xdb150042,0xc6900012}},	//   _kỷ_, _amèr, _nezá, لِّ_
  { {0xa2da0037,0xe80f0037,0x61fd13a2,0x6a760028}},	// [2990] पूर्, ायदा_, mesl, gáfu
  { {0x660900a2,0xb05b004a,0x5478000b,0xb5fd0d09}},	//   zdek, isäk, פְּנ, lošt
  { {0xdb15000e,0x60c913a3,0x7d0d13a4,0xde190012}},	//   _bezá, _svem, svas, _فقدت_
  { {0xdb1805b1,0x61fd13a5,0xdb050025,0xddc90034}},	//   _neví, nesl, nché, zieł
  { {0x249813a6,0xe8ee0015,0xadd6000b,0xf1940024}},	//   _firm_, ыл_, _אורח_, виць
  { {0x94ba000b,0x01380009,0xe3d40012,0xe8220011}},	//   _ממשת, ורדת_, _لتفع, माया_
  { {0x20d50065,0x9f580013,0x66090070,0x3ea10051}},	//   _búið_, teré_, tdek, _juht_
  { {0xb87b0017,0xfde60014,0x7bc5001f,0x69c013a7}},	//   luíd, едък_, lahu, _geme
  { {0x61fd13a8,0xfd110012,0xdb1813a9,0x660913aa}},	//   desl, اجب_, _deví, rdek
  { {0xe3b10003,0x60dd0051,0x26dc0010,0x42d5002d}},	//   درة_, dusm, buvo_, німу
  { {0x35b5007c,0x69cc0066,0xab5c001e,0x69c013ab}},	//   _збер, ůlež, taļa, _yeme
  { {0x61fd00bd,0xa96a0001,0xb5fd001e,0x68340054}},	//   gesl, зима_, tošu, _ràdi
  { {0x25b90065,0x7bc5002c,0xddc40066,0xb6340012}},	//   ðslu_, kahu, tliž, _جعلت
  { {0xf8b2000b,0x14d60009,0xd0120012,0x70190024}},	//   רשם_, _נוצל_, دلس_, міст_
  { {0x5e96000a,0x63050003,0xfbd2000b,0x3a3f003a}},	//   فلسط, _أوبل, _עתה_, _olup_
  { {0xdb030052,0xd6270001,0xa49b0054,0x34aa0001}},	//   _benö, носе_, _pròp, звао_
  { {0x8fa6002d,0xc692000b,0x05660014,0xd7e00011}},	// [29a0] _папе, ראן_, хван, _नालच
  { {0xdb1a000f,0x69c013ac,0xf1bf0031,0xec770560}},	//   latá, _seme, nján_, епу_
  { {0x69c000c6,0x67350002,0x4fbb000b,0x6aab000d}},	//   _peme, cyzj, _מציא, _înfă
  { {0xe64601d4,0xdb1a090e,0xda660012,0xfbc90009}},	//   _чемп, natá, راضي, מת_
  { {0xa3cf0037,0xb87b0017,0x26100037,0x33d60024}},	//   षणा_, buíd, _दोषी_, _півт
  { {0x69c606cb,0xe1650003,0xd037002d,0xdb1a000e}},	//   hake, خدمي, нзії_, hatá
  { {0x316c003e,0x141b000b,0xdb1a000e,0x69c613ad}},	//   ędzy_, _צולב, katá, kake
  { {0xb21b0040,0x644b0035,0xddd10073,0xdb1e0064}},	//   mlæg, īgie, _įgūd, napí
  { {0x8066002d,0x2d820033,0xe6110009,0xb21b0040}},	//   _зваж, åke_, בִי_, llæg
  { {0x4444008a,0xdb0a0028,0x9f47022d,0xb05b006f}},	//   nh_, _vefþ, lený_, rsäk
  { {0x229a001e,0xb21b0058,0x444413ae,0x224013af}},	//   _rīks_, nlæg, ih_, _blik_
  { {0x916d0020,0xb5fb000f,0xe5080020,0xdb1a000f}},	//   _nội_, _aján, _tỷ_, gatá
  { {0xdb050061,0xa1940024,0x3ea1005e,0xe5080081}},	//   rché, лаюч, _suht_, _uỷ_
  { {0x2c160044,0xad1b000b,0x79840002,0xc173000b}},	//   ताओं_, _מודר, _dziw, רחש_
  { {0xb87b13b0,0xddc40002,0x29040028,0xddc90002}},	//   ktív, bliż, æmar_, bień
  { {0xb21b0399,0x26080037,0x387f0061,0x9f4701bd}},	//   dlæg, ाएगी_, œur_, jený_
  { {0x3d1b0037,0x7bc513b1,0xb87b0017,0x9f4701bd}},	// [29b0] नमें_, tahu, tuíd, dený_
  { {0x444413b2,0xf3670760,0x5d840012,0xac190024}},	//   gh_, нтен, الكل, ьозу_
  { {0x93190003,0xb87b13b3,0x23e20011,0xfb190012}},	//   بقاء_, ruíd, _पारद, بقاع_
  { {0xd6d8002d,0x7bc50107,0xc6b60009,0x5ee80009}},	//   _ять_, sahu, _שהרי_, _אַשְ
  { {0x7c95000a,0x7bc5002c,0xb21b0058,0x660d003a}},	//   _للحص, pahu, lmæs, mdak
  { {0xdb1a000e,0xbddb0061,0xdb0a0052,0x46f5002d}},	//   zatá, _flèc, _befü, вчит
  { {0xe8220037,0xddcd0002,0x1c0a0037,0x9f470042}},	//   माता_, miał, _होटल_, bený_
  { {0x7c2e13b4,0x60cd0027,0xb05b004a,0x9f4713b5}},	//   _zobr, _ovam, ssäh, cený_
  { {0x98f40003,0xe1ff000e,0xfc310003,0x69c600e6}},	//   _مثلا, deó_, لحد_, vake
  { {0x7e7b0028,0xddcd0002,0x224013b6,0xddc90002}},	//   slup, niał, _slik_, wień
  { {0xdb1a0272,0x2240003e,0xf1c30020,0x2fc713b7}},	//   tatá, _plik_, _trở_, mang_
  { {0x2fc70f37,0xc869000b,0x6b9a0028,0x3eaa022d}},	//   lang_, _ון_, _útge, žité_
  { {0xf1bf000f,0xdd010066,0xdb1a13b8,0x41030048}},	//   pján_, čtět, ratá, азяв
  { {0x65940046,0x2fc713b9,0x6e29000e,0x9cd6000b}},	//   _сачу, nang_, ljeb, _יונה_
  { {0x6c560009,0xf4560009,0xdb1a0031,0x83f6004c}},	//   _שיצא_, _שיצר_, patá, _рејс_
  { {0x2fc713ba,0xb17b006f,0xadf90037,0x8d760012}},	//   hang_, mgån, ्यटन_, ناءا
  { {0x660b0101,0x69c4001e,0x444413bb,0x2fc70160}},	// [29c0] _magk, _ieie, th_, kang_
  { {0xb5fb0065,0x65930001,0x2fc7054c,0x661d13bc}},	//   _hjál, рађу, jang_, _ensk
  { {0x2fc700c6,0x7bc313bd,0x9f48004a,0x9f470029}},	//   dang_, _menu, ähän_, tený_
  { {0xb21b0065,0x660b002c,0x78a40269,0x6e290031}},	//   rlæg, _nagk, _kuiv, jjeb
  { {0x69c40051,0x9f470029,0xb21b0058,0xd946004d}},	//   _meie, rený_, slæg, ъеди
  { {0x9873002d,0xddcd0002,0x9f5c0061,0xb87b11df}},	//   аліц, ciał, levé_, stív
  { {0x44200020,0x2d8013be,0x9f4713bf,0xb87b13c0}},	//   _đi_, _šie_, denó_, quíe
  { {0x27ed001c,0x69c40039,0xfe6f0003,0x628913c1}},	//   đeni_, _neie, يدي_, _gheo
  { {0xf6530093,0x7bc3008b,0x2fc70160,0x867b000b}},	//   יצה_, _benu, bang_, ורקו
  { {0x660d0fc6,0x2fc700b6,0x9f5c0025,0x2175004c}},	//   zdak, cang_, hevé_, _суср
  { {0xdb18000e,0x201e00b6,0x7bdb0009,0xd4370009}},	//   _bevá, _inti_, וקיו, דריק_
  { {0xddcd0002,0xb21b0eeb,0x7bc3005e,0x7e0c0011}},	//   ział, emær, _eenu, हयोग_
  { {0xa4d4002d,0x6a7d13c2,0xa9bb0009,0x91bb0009}},	//   _солі, néfi, וזכר, ומכי
  { {0x200c00c6,0xb21b0eeb,0xe10b0009,0x78a40227}},	//   _jadi_, gmær, וּלָ, _duiv
  { {0xf8c8001a,0xf1bf01e9,0x69c40a46,0x925b0012}},	//   hứ_, áška_, _feie, _يشعر_
  { {0x6397000b,0xf644002d,0x27ed0066,0xddcd0002}},	//   _בדוא_, ахун, řen_, wiał
  { {0xebc70046,0x2d5808b0,0x2fc70175,0xb21b0058}},	// [29d0] вљен, вить_, yang_, smæs
  { {0x5fb70011,0x2e380025,0x6a7d0025,0x2c340009}},	//   _अभिल, _défi_, défi, נָּם_
  { {0xd3710003,0xddcd0002,0xe3b00012,0xf1c90012}},	//   حها_, riał, ترق_, فوضى_
  { {0x2fc70175,0x629e0061,0xddcd0002,0x225913c3}},	//   wang_, _épou, siał, nisk_
  { {0x4dda0093,0xbd6b0001,0x2fc713b9,0x403502ad}},	//   _אחרו, _црне_, tang_, ледс
  { {0x7bc80005,0x2fc70a60,0x07090012,0xab5c0035}},	//   jadu, uang_, فيتي_, taļl
  { {0x660b0101,0x64540001,0x2fc713c4,0x9ef50012}},	//   _pagk, _тврђ, rang_, استش
  { {0x60d6007a,0x2fc70160,0x7bc80051,0x4431000e}},	//   šyma, sang_, eadu, _hoz_
  { {0x7bc300c6,0x2fc70160,0x614a0025,0x6cd20012}},	//   _penu, pang_, _mêlé, مقيا
  { {0xb5fb0065,0x69c413c5,0x2c1c0011,0x9cd60009}},	//   _sjál, _seie, नाएं_, נותה_
  { {0x78a40108,0x7d0413c6,0x8fa40012,0xb05b0032}},	//   _suiv, zwis, _ضمنه, nsäu
  { {0x7d040002,0xcf560009,0xb17b0248,0x41b6003c}},	//   ywis, _גבעת_, rgån, ысот
  { {0xed59048b,0x7bc8026e,0x69c413c7,0xfe700012}},	//   kaži_, badu, _veie, _بدل_
  { {0xdb1c0164,0x7aec000e,0xd8380604,0x5b350012}},	//   _serí, öltö, _tiče_, _معبر
  { {0x69c40051,0xdb1c0201,0xe8190011,0xf7860012}},	//   _teie, _perí, दाजा_, الأَ
  { {0x3ea5007d,0x2259003e,0xdb18014f,0x25ad13c8}},	//   _mult_, cisk_, _bevæ, ncel_
  { {0xdb0a0028,0xddc9001e,0x98f60003,0x448a046d}},	// [29e0] _hefð, pieņ, _إثبا, ебан_
  { {0x629e0054,0x4806002d,0x61e903c8,0x7d0413c9}},	//   _èpoc, _спов, _acel, rwis
  { {0xb0c60037,0x7ae111c9,0xe9da096e,0xddc900eb}},	//   रीनग, nult, еке_, dlež
  { {0xb87b0042,0x539a0009,0xe9e50024,0x61e610fc}},	//   stít, גיעו, иціо, ngkl
  { {0x200c00b6,0x7ae113ca,0x27150081,0x91bb0009}},	//   _padi_, hult, _h́nh_, גמני
  { {0xdcfd0039,0x40940003,0xe8940024,0xf5390030}},	//   _uzsā, جلتر, шаль, dyť_
  { {0xf1ba0020,0xeab40093,0xab610051,0x9f5813cb}},	//   _đơn_, _כִּי_, öüle, nerà_
  { {0x7e641326,0xfb1b0009,0x2dda0012,0x5efb0009}},	//   nnip, _אולמ, ربعة_, תפקד
  { {0x21670046,0x25d7000b,0x200c00b6,0x7bc813cc}},	//   _бити_, אופן_, _tadi_, tadu
  { {0x54540014,0x62980066,0x61e90066,0x3ace0002}},	//   рвот, ůvod, _zcel, tęp_
  { {0xd5e20020,0xb05b004a,0x3c77000b,0xb8930003}},	//   _chọ, isät, רתים_, _اللع
  { {0x3eb8009b,0x9f5813cd,0xaa590024,0x6f4b0009}},	//   dprt_, derà_, тиму_, _אֲדַ
  { {0xf1bf000e,0x3ea50070,0x2715001a,0xd7fb0055}},	//   lják_, _zult_, _ánh_, нув_
  { {0xb5fb0042,0xd40a0012,0xb8fd0011,0x7ae113ce}},	//   _ukáz, _ستتم_, _डि_, bult
  { {0x501b000b,0x33170003,0xdb0a0028,0xf1bf1356}},	//   עולו, _مزيد_, _gefð, ššia_
  { {0x442c006f,0x97570009,0xc3330009,0x68e20073}},	//   ljd_, אילו_, _לוצ_, kuod
  { {0xdc550046,0x26c1000f,0xa3e90037,0x6448004a}},	// [29f0] авањ, ához_, _याद_, ohdi
  { {0x61e900c1,0x68e20010,0xa3d5002d,0x40ec0009}},	//   _scel, duod, рожч, _נַחֲ
  { {0xcb550001,0xe8220037,0x443e13cf,0x442c0070}},	//   јвећ, मारा_, ikt_, ijd_
  { {0xdb1c0149,0x27ed0027,0xf1bf000e,0x99a80003}},	//   _serã, đenu_, dják_, هُمْ_
  { {0x443e0028,0x645a13d0,0x89a8002d,0x68e20073}},	//   kkt_, kiti, уків_, guod
  { {0x443e0070,0xccf2000b,0xd8b80012,0xdb18008e}},	//   jkt_, _וכך_, ادنا_, _kevä
  { {0x2fc50119,0xaa95002d,0xfc3f0164,0xf1bf000e}},	//   _velg_, _вивч, _guía_, gják_
  { {0xe6c40003,0x7ae1004a,0xceb4000b,0xa2a20037}},	//   حتوي, vult, זיק_, गदर्
  { {0x1c450803,0xdb1c0017,0x7bc700b6,0xdcef001e}},	//   иним, _terã, _keju, _izcē
  { {0x1c1f0037,0xf5390029,0xdb95002d,0x660f02c3}},	//   बाइल_, ryť_, ишнь, _lack
  { {0x9f580054,0xff530012,0xcb69038f,0x9f4b008e}},	//   xerà_, _اخذ_, тане_, älän_
  { {0x7bc70039,0x443e0070,0x38ab0058,0x9f5800c1}},	//   _leju, akt_, _kør_, verà_
  { {0xfe70000a,0x9f5813d1,0xe8220011,0xe3ae0173}},	//   _عدم_, derá_, माला_, _мб_
  { {0x443e13d2,0xd116000b,0x76490028,0x9f5813cd}},	//   ckt_, בקשה_, lhey, terà_
  { {0x94740003,0x68e20010,0x66d90021,0xe5160011}},	//   _ادنا, zuod, льтр_, तिथि_
  { {0x29560014,0x7aee022d,0x75d60012,0x9f5800b8}},	//   _въор, žití, شيطا, rerà_
  { {0x527b000b,0xb05b006f,0x290c001e,0xfbd20003}},	// [2a00] _בנקא, tsät, ādas_, قتا_
  { {0xb05b0032,0x9c23004c,0xbab60012,0x27150081}},	//   usät, одуд, لمطب, _t́nh_
  { {0x49ca0015,0xe7db000b,0x660f02f1,0x23ba0037}},	//   влен_, _בקיש, _fack, ेरबद
  { {0x38ab0989,0xb05b00e5,0x9f58052e,0x11d70012}},	//   _bør_, ssät, cerá_, لومة_
  { {0x03a6002d,0xb05b006f,0x55bb0009,0x6448008e}},	//   _виго, psät, _במכו, yhdi
  { {0x66040065,0xc0760046,0xf1bf000f,0x7641007a}},	//   leik, шћењ, tják_, ūlyt
  { {0xe7ee0037,0x68e2004a,0x39400010,0x69cb0058}},	//   _जाना_, suod, šis_, bage
  { {0x38ab091a,0x96b70003,0xd6260003,0xddc90002}},	//   _før_, جاوز_, شعبي, mieś
  { {0x38ab00c5,0xfe6f0003,0x37e60015,0xafe60015}},	//   _gør_, بدو_, _возг, _возл
  { {0x9f580064,0x443e0641,0xf1bf0031,0xdb1a0064}},	//   zerá_, ukt_, pják_, matú
  { {0xddc90002,0x2417000b,0x628200ca,0x443e13d3}},	//   nieś, בחין_, oloo, rkt_
  { {0x443e13d4,0xa75b0009,0xd2460012,0x625101bd}},	//   skt_, _בדבר, سن_, sťov
  { {0xc05b007c,0x9f580017,0xdcef001e,0xdb1e019a}},	//   вів_, verá_, ādīs, lapä
  { {0xc05b002d,0xdd3b000b,0xdb1e0054,0x02a60829}},	//   тім_, _בעדכ, capç, _крим
  { {0xdb1e0051,0x44f00007,0x9f5813d5,0x660f13d6}},	//   napä, là_, terá_, _pack
  { {0x7bc700c6,0x9f5c0066,0xe61f001a,0x6a68003a}},	//   _seju, jeví_, _khôi_, nıfl
  { {0x629f0061,0x2ba70001,0xdb1e0051,0xdb0501e9}},	// [2a10] _époq, ајев, hapä, dchá
  { {0x44f001a2,0xdb1c0164,0xe7ee0037,0x6d4d0070}},	//   ià_, _será, _जाया_, rzaa
  { {0x2bb90037,0xb05b004a,0x44f0001a,0x38ab13d7}},	//   इडबा, ssäs, hà_, _sør_
  { {0x80db0011,0x1af70009,0xc2120009,0xd1b80012}},	//   _निदे, שמאל_, ּ֔א_, لاها_
  { {0xdb1c06fe,0xe7ee0011,0xa2d30011,0x11080012}},	//   _verá, _जामा_, _डिक्, لغوي_
  { {0xfd960009,0x65360009,0x1bb80012,0x44f001a0}},	//   _לדרך_, _האשף_, _نافع_, dà_
  { {0xb9e7002d,0x62820070,0x7bc70028,0x69cb13d8}},	//   _візи, bloo, ðjum, page
  { {0x683d0054,0xf99f0054,0x62560010,0x11d40003}},	//   _mèdi, ndès_, ršok, _وتقد
  { {0x64860065,0xf807002d,0xadf80011,0x49040012}},	//   rðin, _вчен, ्ज़न_, _ووفق
  { {0x30850003,0x1c4500fa,0x20850012,0x0445004c}},	//   _الطف, сном, _الطّ, сеон
  { {0x9f580054,0xddcd05dd,0xe0df10ac,0x78a901e3}},	//   merç_, dlaž, erò_, _huev
  { {0xdef6000b,0xd3560009,0x44f001a0,0x78a113d9}},	//   _למעט_, מיתי_, bà_, _hilv
  { {0x660401ff,0xf6740003,0x8e740003,0x78a911f8}},	//   veik, _بالخ, _بالض, _juev
  { {0x78a901e3,0xf3f10012,0xf9920009,0x7d7a00af}},	//   _muev, _رأت_, פרם_, _גננו
  { {0x66040b3f,0x7ae50051,0x61ed13da,0xf1bf000e}},	//   teik, juht, ällö, bbá_
  { {0x60db0010,0xdb360009,0x6ca60012,0x25bf13db}},	//   šuma, _לנצח_, مصطل, nbul_
  { {0x78a902d1,0x6441001e,0xddc90002,0xd4c60012}},	// [2a20] _nuev, okli, wieś, إغري
  { {0xdd8f0012,0x31570009,0x17fa0012,0x660413dc}},	//   رول_, _ליפן_, _صرخة_, seik
  { {0xb09b0009,0x7d09041d,0xa5bb01e3,0x6a680060}},	//   _תייר, hwes, _inón, yıfl
  { {0xb87b0164,0x0dba0003,0xdb1e0051,0x64900051}},	//   críb, _حادث_, vapä, käig
  { {0xc05a002d,0x3af1001a,0x62820644,0x867b0009}},	//   лік_, háp_, rloo, _תרכו
  { {0x78a10039,0xb9000037,0xdb1a0029,0x62820b8c}},	//   _cilv, _थि_, ratú, sloo
  { {0x645e13dd,0xbbc40011,0xb5fb0097,0x61b80011}},	//   mipi, षरीक, _sjái, _आभूष
  { {0x44f001a2,0x44b4007c,0x64860028,0xc8e00037}},	//   tà_, обис, aðil, _निपट
  { {0xfe6f0003,0xa49b0054,0xb4260012,0x68e60248}},	//   عدى_, _pròx, معدو, jukd
  { {0x25bf003a,0x44f013de,0x6441002c,0x9f5a0054}},	//   abul_, rà_, gkli, _japó_
  { {0x7f86000a,0x547b0093,0xe2f8002d,0x4dda0012}},	//   _الان, רטיו, шені_, _موضح_
  { {0xc333015a,0xe61f001a,0xfce60015,0x3ea20002}},	//   לות_, _thôi_, _годо, _nikt_
  { {0x6da30003,0xf5960012,0x7d960012,0xdb1c008e}},	//   _عموم, _الشج, _الشؤ, _herä
  { {0xdb1c13df,0x5c73002d,0x644113e0,0x6490005e}},	//   _gerç, _еліт, ckli, näid
  { {0xc058002d,0xc6d8000b,0xb3f70009,0x2bf70009}},	//   сія_, יַּר, _המוח_, _המון_
  { {0x7bca014d,0x74bf0011,0x6d9c0064,0x2d8d0034}},	//   _hefu, लीकृ, aťaž, śleń_
  { {0x7c350026,0x69cf0c90,0xdb0300b7,0xb87b0018}},	// [2a30] _pozr, mace, _agnè, luím
  { {0x734b0014,0x4d980015,0x645e005e,0x3ea20035}},	//   лчев_, скую_, gipi, _eikt_
  { {0xe7ee0044,0xe9f90020,0xfbd00003,0x29d50003}},	//   _जाता_, _giả_, عتك_, قياس
  { {0x6441001e,0x7bca0031,0xdd2b0031,0x7ae513e1}},	//   zkli, _lefu, sőűr, ruht
  { {0xbcfb0017,0x7ae500e6,0x69cf13e2,0x7c8704d6}},	//   _exér, suht, iace, _гуве
  { {0xdb1c0163,0xdff5002d,0xdd310002,0x8aa713e3}},	//   _berä, іяль, zęśc, _град
  { {0xd1bb000a,0x80db0037,0x201313e4,0x985d0034}},	//   _ماذا_, _निवे, _maxi_, _głąb_
  { {0xee390e0f,0xa3e90011,0xe8920064,0x5692004c}},	//   рни_, _याँ_, ĺňať_, мајт
  { {0x78a10065,0x6aaa0052,0x82340003,0xe9d90002}},	//   _tilv, _auff, _عرفا, _idź_
  { {0x99480003,0xf9900003,0xa988000b,0xac39002d}},	//   _الكل_, _سبق_, _הָעִ, рчих_
  { {0xdb1c0052,0xc5d5002d,0xb21b0058,0x69cf0830}},	//   _gerä, _діль, rlæn, face
  { {0x60c4004b,0x625a003c,0xadbd0024,0xb51c0011}},	//   ţime, ррор_, _радi, निमय_
  { {0xfe42002d,0xdb1c0017,0x99f60009,0xa3e90011}},	//   _іншо, _terç, חזרה_, _यां_
  { {0xbb450015,0x7bca10c7,0xf8b20009,0x07ba0012}},	//   _мелк, _gefu, ושך_, شهرة_
  { {0x0325002d,0x2bbf0037,0x82860012,0x9b950012}},	//   _єдин, _श्या, _وجعل, _بلغت
  { {0x38af032b,0x3f840333,0x0686002d,0xdcf70037}},	//   _für_, āmu_, іган, ुबंध_
  { {0x62730003,0x75d30003,0x3ea2006f,0x88c60012}},	// [2a40] _تهيئ, بيقا, _vikt_, _بتعل
  { {0xe45f0028,0xf8b3000b,0x628613e5,0x20070c81}},	//   _svör_, _קשת_, llko, jeni_
  { {0x6da6034c,0x41aa0014,0x3ea2001e,0x27e50002}},	//   _мина, авен_, _tikt_, ólne_
  { {0xdb1a0722,0x81460012,0xaac50012,0x66fc0035}},	//   ratø, ينان, ستمن, nākš
  { {0x645e002c,0x73c60012,0xf1bf0031,0xa3e90011}},	//   pipi, _ويحم, mját_, यला_
  { {0xd91b000b,0xdfd00003,0x66160010,0xdb1c004a}},	//   יונל, ريب_, ldyk, _perä
  { {0x44f40006,0x27e000a2,0x4444009b,0x66160073}},	//   lä_, ğin_, mk_, odyk
  { {0x66160915,0xe357000b,0xdb1c0052,0xe2a60028}},	//   ndyk, _ושלח_, _verä, óðum_
  { {0xc693000b,0x44f4004a,0x69cf0029,0x80660015}},	//   ואה_, nä_, vace, _дваж
  { {0xb35401b6,0x6616004a,0xdb1c008e,0x6abe00b0}},	//   зкош, hdyk, _terä, oppf
  { {0x22490070,0x7bca0028,0xf1bf000e,0x66160010}},	//   _plak_, _vefu, kját_, kdyk
  { {0x4438007d,0xb5fb02d1,0xb87b0164,0x2bac0037}},	//   _lor_, _imág, dría, _फ़्रा
  { {0x44f40006,0x7e6000c6,0x2beb01e1,0xba9b000b}},	//   jä_, mimp, _चालू_, יסטי
  { {0x444400bd,0x4438002a,0x44f4004a,0x290b0002}},	//   jk_, _nor_, dä_, rwca_
  { {0xd838009b,0x9057000b,0x6fbf0011,0x6490005e}},	//   _moč_, קבלו_, ्रबं, käib
  { {0xfa340003,0x38af004e,0xf1bf000e,0x68e20b86}},	//   _يريد, _tür_, gját_, krod
  { {0x5d550014,0xa3ae0037,0xfbab027f,0xdfa70012}},	// [2a50] чкат, _कला_, атей_, _وحدي
  { {0xf1bf000e,0x7d0203a2,0x443813e6,0xb87b01e3}},	//   aját_, _mpos, _cor_, bría
  { {0xf7700003,0x661613e7,0xb5fd13e8,0x443813e9}},	//   _لاَ_, bdyk, liše, _dor_
  { {0x6d40007a,0x5a350014,0x69c20070,0x539b01b0}},	//   kyma, янет, gboe, ביבו
  { {0x2ca300bd,0x200713ea,0x68e20002,0x443813eb}},	//   _tijd_, teni_, grod, _for_
  { {0x6d40007a,0x759a000b,0x7c3800b6,0x443813ec}},	//   dyma, _לסרג, _novr, _gor_
  { {0x44290020,0x7e7b0066,0xe73900de,0x7d0d0ad2}},	//   _đa_, toup, сей_, lwas
  { {0x28dc0044,0x7bce0065,0x67f40028,0x8d550014}},	//   _बिलि, ðbun, tþjó, зточ
  { {0xdb05008b,0xb5fb000e,0xab5c0035,0x66fc0035}},	//   schä, _imád, kaļs, vākš
  { {0xbebc0039,0x67f40028,0xc1040012,0xcf270012}},	//   _brīd, rþjó, _توكي, _وراي
  { {0x67f40028,0x7c3813ed,0x59cf0011,0xdc3c0009}},	//   sþjó, _dovr, _हजार, יעזר
  { {0xdb12000f,0x83fc001b,0x41e50012,0x6d3513ee}},	//   égév, viđe, وسُف, _нееф
  { {0x271c0020,0xd24f0012,0x2bbd0011,0xf2210011}},	//   _ảnh_, انُ_, ोरदा, याज़_
  { {0x44f4004a,0x29dc001a,0x66fc001e,0xdb150052}},	//   vä_, ửa_, sākš, _bezü
  { {0x442713ef,0xa2d20012,0xf1bf0031,0xcb6613f0}},	//   _inn_, _كيوت, tját_, _наше_
  { {0x44f403fc,0x4438000e,0xdd920003,0xe7ee0011}},	//   tä_, _sor_, فوز_, _जावा_
  { {0x443813f1,0x7644003a,0xe51c0011,0x59cf05f3}},	// [2a60] _por_, rkiy, निधि_, _हज़र
  { {0x7d1b0006,0x660913f2,0xc9530009,0xac830695}},	//   ivus, heek, _רמז_, егул
  { {0x6d40003e,0x7d1b0005,0x103b000b,0xf6260014}},	//   zyma, hvus, _הגיע, _едно
  { {0xdca609f0,0xd259002d,0x200a003a,0x64a60d60}},	//   _нами, оці_, lebi_, _нама
  { {0xb05b0051,0x69c20070,0x68e20010,0xa1330012}},	//   späe, rboe, urod, فروش
  { {0xb17b0033,0xf8b3000b,0x7d1b0051,0x70540012}},	//   mgåt, עשו_, dvus, بنتا
  { {0x2018001e,0xa91d00f1,0x7d0213f3,0xd6560009}},	//   idri_, _vyža, _spos, ּיִת_
  { {0x171b000b,0x6d4013f4,0x54b8022a,0x7c3813f5}},	//   מוצע, tyma, огия_, _sovr
  { {0x7bce00c6,0x48e3011f,0x7c3813f6,0x88c50012}},	//   _kebu, _потв, _povr, _يتكل
  { {0x88bb0009,0x986a0012,0x80630024,0x200a001b}},	//   _לזמי, _احرف_, _звуж, jebi_
  { {0x4fbb000b,0x67bb000b,0x7e6000b6,0x6d400d30}},	//   _הצבא, _המבק, pimp, syma
  { {0x7d0d0002,0x2246000e,0x442713f7,0x200a005e}},	//   ywas, nkok_, _enn_, eebi_
  { {0x2e37000b,0x9d9a0012,0xbd290012,0x7c380159}},	//   _מראש_, _انشئ_, _وأهل_, _tovr
  { {0x859b000b,0xb5fd02a1,0xd59b0009,0xe44f0012}},	//   _השדו, riše, _הבדל, _مضى_
  { {0xabfb007e,0x33fb0009,0xa3e90011,0x93fb0009}},	//   _ההור, _להגנ, यलर_, _הלוי
  { {0xf8bf0061,0x7d0d002c,0xb5fd02a1,0xf3130012}},	//   ppé_, twas, piše, _أبوظ
  { {0x62560010,0x200a003a,0xa697000b,0xb5fb0028}},	// [2a70] ršot, bebi_, לכלה_, _sjás
  { {0x7c14002d,0x6f0d0034,0xdb070031,0xdb1a067a}},	//   ндує, łaci, _ifjú, katü
  { {0x2bb80003,0x3a290058,0x6235002d,0x4427003a}},	//   سالة_, _knap_, межу, ın_
  { {0xdb1a13f8,0xa3dc0044,0xfd1f001a,0x2cb90012}},	//   lató, तृत_, _trì_, _وُجد_
  { {0xe1f0000a,0xb5fb0065,0x9f510164,0xe0d80024}},	//   اسم_, _fjár, pezó_, зві_
  { {0xc918000b,0xe7bf0037,0x7bce0480,0x3ea6004a}},	//   פחות_, ्रिप, _gebu, _aiot_
  { {0xe7360014,0x6d400051,0xd00e0012,0xae1e0011}},	//   дещ_, _ümar, شلي_, _मोहन_
  { {0x7d1b0051,0xdb1a0123,0x7e6d13f9,0x7bdc13fa}},	//   tvus, ható, nnap, _zdru
  { {0x6fbf0037,0xe7bf0037,0x66090070,0x7cde000d}},	//   ्रां, ्राप, reek, părţ
  { {0x61fd0028,0x39420010,0x7e6d04ec,0xe3b10012}},	//   efsl, vyks_, hnap, خرة_
  { {0x420a00a6,0x93b60009,0xfbd20009,0x8c1c0009}},	//   онно_, ולתו_, כתי_, מוזי
  { {0x1fc6015f,0xd9ff0037,0xc0490009,0x6e890012}},	//   वर्ड, ोजित_, _דז_, _بنصف_
  { {0xd4350003,0xdb0a02f1,0x8e560009,0x71d60009}},	//   _يعتب, _affä, _קינג_, וורד_
  { {0xdb1a13fb,0xe8000011,0x2bb20011,0x7e6d114d}},	//   gató, ल्पा_, _जलधा, enap
  { {0x7bce0185,0xbbd60009,0xa28a0012,0x92660012}},	//   _rebu, _חוצץ_, _وضعك_, _يدعم
  { {0x7bce00c6,0x2ca7001f,0x7bdc0066,0x3eb8000e}},	//   _sebu, _hind_, _sdru, _érte_
  { {0x2ca713fc,0x1be10011,0x33f60223,0x6aae13fd}},	// [2a80] _kind_, _खयाल_, дчес, _subf
  { {0x94060012,0x7e6d020d,0xdb1a13fe,0x22a80060}},	//   ظواه, anap, matò, _aşka_
  { {0x38b401ab,0xc7b3000b,0xeb93000b,0x65c601b8}},	//   _här_, _בבת_, תָּ_, _обна
  { {0x1bf00011,0x38b40248,0x51860451,0xdb1806dd}},	//   _चावल_, _kär_, мула, _nevý
  { {0x644f001e,0x7c490031,0x3ea6053f,0xd8b70012}},	//   īcij, ásró, _riot_, ودوا_
  { {0x7bdc0027,0xceba0001,0x46d20011,0xd0100012}},	//   _udru, ољи_, _तबाह, الث_
  { {0x38b4006f,0xba0a0012,0x62840073,0x2bc40610}},	//   _lär_, _وترك_, _okio, _ल्या
  { {0x442001b3,0x15140048,0x8c3b0032,0x9d140868}},	//   _şi_, едия, _wußt, едич
  { {0x38b401ab,0x6d4400b6,0x2167002d,0x7c3c13ff}},	//   _när_, nyia, _жити_, _korr
  { {0x03f80001,0xdb1c0192,0x113b0009,0x9f5c008e}},	//   чној_, _berø, _ותמל, tevä_
  { {0xf413000b,0x60c2004a,0x9e3c00d9,0x7c3c1400}},	//   דפת_, lpom, _buďt, _morr
  { {0x68ed039c,0x2ca70070,0x75460014,0x60d60010}},	//   žodž, _eind_, _онез, šymu
  { {0xdb1a1401,0x2ca706a3,0xfe9b000b,0x58870015}},	//   tató, _find_, _ויאמ, дыва
  { {0x38b40163,0x9c570003,0x3c440012,0x7c3c1402}},	//   _där_, _يجوز_, _سَعِ, _norr
  { {0x9f5f003a,0xe3b8003a,0xe80e0037,0x442d1403}},	//   _ürün_, mcı_, ाज़ा_, _đe_
  { {0x56940400,0xd7170009,0xdb1a0034,0xb5fb0097}},	//   васт, וחלט_, sató, _smáb
  { {0x7c3c02d1,0xc7c70001,0x28e00037,0x74f80021}},	// [2a90] _borr, _осни, _निषि, метр_
  { {0xe3b8003a,0xe8d8000b,0x69db0028,0x2ca703c2}},	//   ncı_, _חוזר_, ðuef, önd_
  { {0x30780012,0x224d0227,0xdb180031,0x28cb0011}},	//   _تحية_, _plek_, _nevü, ़ीरि
  { {0xddc4000d,0x60cd0070,0xd6d80024,0xe1ff0031}},	//   rniţ, _kwam, _ють_, nfó_
  { {0xb90b0003,0xa803003a,0xc0e5002d,0x3af8001a}},	//   تزام_, _çıkt, холк, hép_
  { {0x91690020,0x68eb06e7,0x443c1404,0x41740012}},	//   _cửa_, rugd, _nov_, خامس
  { {0x9f500065,0xddc4009b,0x39490113,0x98bf003a}},	//   ðaðu_, lniš, šas_, ırım_
  { {0x43940047,0x7c2a008b,0x2ca71405,0xf7700003}},	//   _расс, _anfr, _sind_, جاه_
  { {0xc8f40014,0x6e920012,0x99820034,0x660d0034}},	//   _изтъ, دليا, zekł_, ieak
  { {0xfc31000a,0x6490008e,0xe1ff0034,0x628b1406}},	//   احة_, häin, onów_, llgo
  { {0x3af8000e,0x63ad0b71,0x539a0009,0x0ff80012}},	//   gép_, _şans, ּירו, _تعقب_
  { {0xf089000b,0x23bf0011,0x28c60011,0xdb1a01a0}},	//   _הנ_, _श्रद, रीकि, tatò
  { {0xed4e0047,0xadd60009,0xc56b0012,0x321e0030}},	//   _со_, _נוסח_, _بحال_, ěty_
  { {0x26de0027,0x661b1407,0x6aa90347,0xddc4017b}},	//   štom_, lduk, _lief, dniš
  { {0xe73a0373,0x75221408,0xc2c80012,0x38b40032}},	//   чев_, _zroz, _قبيل_, _wär_
  { {0x661b046c,0xb05b008e,0x60c20034,0xddcd004b}},	//   nduk, isäy, ypom, riaş
  { {0x999e0010,0x33f9000b,0xad660012,0xb05b008e}},	// [2aa0] ėtų_, ּהֲנ, راره, mpän
  { {0x78fb0093,0x3957000b,0xe0fb000b,0x29570009}},	//   _צפיו, _נשים_, _צליל, _נסיך_
  { {0xb8f30037,0x7c3c092b,0x47f70009,0x91690081}},	//   ही_, _vorr, _אציל_, _rửa_
  { {0x91690020,0xddc4012e,0x6a160003,0x78a8006f}},	//   _sửa_, bniš, عبار, _sidv
  { {0x7d1c001e,0xc6930009,0x3af80031,0xe3b80060}},	//   ārsk, _תאר_, zép_, ycı_
  { {0x60c200c1,0xd8d7000b,0xf993000b,0xa9670003}},	//   rpom, גוסט_, ארד_, عموم_
  { {0x09e6007c,0xfae70012,0xda660012,0x865a0009}},	//   _повн, _حث_, _كاري, ּדִי
  { {0xceb3000b,0x7f470012,0x8afb0009,0x9df70048}},	//   ניח_, عليق_, _מהלי, енът_
  { {0x7d1b0018,0xe474004c,0x78a80675,0x28dc1409}},	//   _áust, клињ, _tidv, _बिगि
  { {0x201a000f,0x07a6007c,0x78250003,0x46e10037}},	//   _napi_, _зазн, _لعمل, _फिलह
  { {0x60cd0132,0x93fb0009,0x1c0f0011,0xddc4090a}},	//   _swam, הליי, ़ज़ल_, zniš
  { {0xb5fd140a,0x3af80031,0x75220aef,0xe606008e}},	//   lišn, rép_, _troz, äsää
  { {0x865b0009,0x6490008e,0x44f901a0,0x26190011}},	//   _צדדי, väin, cè_, _मोटी_
  { {0xc5690003,0x20cd0604,0xddc400eb,0xe1ff0034}},	//   _تحمل_, rži_, vniš, ynów_
  { {0x141b000b,0x8c1b0009,0xbc1b0009,0xb87b0097}},	//   _מוגב, _זווי, _מוגש, lrík
  { {0xddc404d2,0x6d1c0011,0xbb770009,0x9f600031}},	//   tniš, निंग_, _רעהו_, árát_
  { {0x6490004a,0xdb200028,0xca7c0009,0xda7c0009}},	// [2ab0] räin, ðtæk, _מנהט, _מנהר
  { {0x6490004a,0x14190003,0xddc404d2,0x660d005e}},	//   säin, بيئة_, rniš, seak
  { {0xf6990046,0xb5fd140b,0xcfb6000b,0x28b70037}},	//   _овој_, dišn, _בלתי_, _इंडि
  { {0xee210024,0xe1ff0034,0x7bc5005e,0xddc4090a}},	//   _темi_, rnów_, _õhuv, pniš
  { {0x25d60009,0x62640031,0x9dd60009,0x9be70024}},	//   _שושן_, dőol, _בורק_, _півк
  { {0x6bd40003,0x7ae20035,0xab87028b,0x66e50fe3}},	//   _متفر, ņota, _зубк, вока
  { {0x6aa90052,0x79c90003,0x3946002c,0xcc760009}},	//   _tief, _يوسف_, ayos_, _יעשה_
  { {0xcf240012,0xa2950024,0x4ada05f3,0x68fd140c}},	//   اروي, _рабі, _भिजव, ktsd
  { {0x44f90054,0xc0150048,0xb87b01e3,0x661b140d}},	//   uè_, _имащ, rríj, rduk
  { {0x76490a58,0x26de000e,0x1c450055,0xe5040012}},	//   skey, átok_, тном, ابيي
  { {0x95d9003c,0x9f040012,0xb87b0064,0x201a016d}},	//   _ждет_, _مولو, príj, _rapi_
  { {0x201a00b6,0x216a00ac,0xcb120009,0xe1f20012}},	//   _sapi_, дими_, בלט_, جسد_
  { {0x89da0009,0x6fd60024,0xe5350048,0x7ae80227}},	//   וחרי, ківц, _шедь, ardt
  { {0xed560046,0xfd56000b,0x1d060345,0x3a3f0d29}},	//   _још_, _בשני_, _реши_, _loup_
  { {0xb5fb0028,0x7b670024,0x17790223,0xfc3f0c8b}},	//   _smáa, _ятде, есть_, _luís_
  { {0x3376000b,0x6028001e,0xceb2000b,0xe5f3000d}},	//   _בעצם_, _zīmē, שין_, văţă
  { {0x201a00c6,0x70560012,0x84ac0009,0xbea307e8}},	// [2ac0] _tapi_, _لنظا, ִיאִ, ратк
  { {0xe1ff0164,0xe5720009,0xf7720012,0x2ed10011}},	//   nión_, בַע_, _ناج_, _सबूत
  { {0x539a0009,0xb5fd001b,0x3e7a0035,0xc32a00ae}},	//   ֵינו, višn, līte_, بكان_
  { {0xc3320093,0x3a3f0573,0xaae50012,0xc6b70009}},	//   יוב_, _coup_, اسلو, _שהכי_
  { {0x24440028,0xdb1e0028,0xf8bf0031,0x60dc0035}},	//   _sömu_, tapó, rvég_, _ārms
  { {0xdb1c000f,0xb7d80003,0x515b000b,0xdcf50066}},	//   _kerü, روبا_, וכנו, ůběh
  { {0xe8e00020,0x8c1b000b,0x200e0028,0xc7b30009}},	//   _ước_, _קולי, refi_, סבה_
  { {0xdb1c000e,0xf773000b,0x13170009,0xeb970a2c}},	//   _merü, יקו_, _בחלל_, _рис_
  { {0x5ea30012,0xb5fd00eb,0x22920097,0xdb1a140e}},	//   جميل, mišl, tákn_, natö
  { {0xe1ff140f,0xcf260012,0xbd9b0009,0xb87b0097}},	//   gión_, _لرصي, וספת, rrík
  { {0x9f580066,0x3d170011,0x07a6004c,0xdb1a005e}},	//   terý_, _बैठे_, _ражн, hatö
  { {0xb87b0026,0xacbb0061,0x28b70011,0xd3370009}},	//   prík, _brûl, _इंदि, דרטה_
  { {0x1e570009,0xdb1a005e,0xc5f30009,0x8e6b0009}},	//   _בשאר_, jatö, _כדף_, _קֳבֵ
  { {0xe1ff06f4,0x5453007c,0xdb1c1410,0x64860028}},	//   ción_, _квіт, _berü, rðis
  { {0x44d0003e,0x386d001c,0xeeab002d,0xc0580024}},	//   eń_, đer_, дтак_, тія_
  { {0x645d001e,0x7c2e1411,0x04c90012,0x02a4003c}},	//   īsie, _anbr, فوري_, _крым
  { {0x9a680012,0x35b40686,0xa5c20034,0xcc99004c}},	// [2ad0] _جميل_, рбур, łówk, евац_
  { {0x7bc50051,0x3ea01412,0xd78b0012,0x54540198}},	//   _õhut, amit_, _يخدم_, авут
  { {0x12b40003,0x3ea01413,0xd3a7137b,0xc7b20009}},	//   لإنج, bmit_, трап, _לבי_
  { {0xe45f006f,0x3ce9009b,0xd7f8000d,0xb21b0040}},	//   _stöd_, prav_, _acă_, mlæs
  { {0x910501ec,0x8bb70012,0x4a5c0009,0x09e40024}},	//   упле, _لإزا, ודאו, роін
  { {0xe1ff0164,0x201106c0,0xdb1a005e,0x46f5003c}},	//   xión_, nezi_, latõ, гчит
  { {0xef12000b,0x27e9003a,0x6490005e,0xaed2004c}},	//   ֶּה_, ğan_, käij, бојш
  { {0x7658007a,0x27e9003a,0x2011004b,0xe8e00081}},	//   _įvyk, şan_, hezi_, âịn_
  { {0x2a640098,0x06960003,0x4c85003c,0x20110060}},	//   _търг, دنية_, ллив, kezi_
  { {0x69d900b6,0x661d1414,0x98a4004c,0x291a0035}},	//   lawe, _lask, _виђе, āpat_
  { {0x44fd001a,0x3ea0004a,0x7bd51415,0x20111416}},	//   hì_, ymit_, _mezu, dezi_
  { {0xceb20093,0xe1ff02d1,0x69d90070,0x63bb003a}},	//   _היא_, sión_, nawe, _şunl
  { {0x64860028,0xfce50ba0,0x4a5a0009,0x69cb0032}},	//   rðir, _соло, תדרו, ibge
  { {0x7e690010,0x6e3b0470,0x44fd00b8,0xb8960012}},	//   liep, ljub, dì_, السع
  { {0x2d8f0052,0x26de00d9,0x63050012,0x661d1417}},	//   ügen_, éto_, _إوبل, _bask
  { {0x2299000e,0xdb1a0028,0x9655004c,0x78690073}},	//   téke_, tatö, ађуј, ržva
  { {0x7bc50051,0x7bd51418,0x79960034,0xb21b0097}},	// [2ae0] _õhus, _bezu, _uzyw, rlæt
  { {0xdb1c000f,0x09cc0037,0xb8f80037,0xdb1a1419}},	//   _terü, ार्य, ाठ_, ratö
  { {0x272300a2,0x5f460003,0x37750015,0xf8bf0061}},	//   _nın_, _إنجل, _выяс, rvée_
  { {0x2485141a,0xdb1a141b,0x9f4101e3,0x6286141c}},	//   holm_, patö, _echó_, noko
  { {0x91e31103,0x9f58097c,0xb5fd0f23,0x1ae00011}},	//   соче, peró_, rišl, _पटकथ
  { {0xd9430046,0x69d60164,0xddcd0002,0x61430001}},	//   сељи, _leye, chał, сеља
  { {0x7524000e,0xe51c0037,0xc8e00011,0xa6340024}},	//   lviz, निकि_, _निकट, инкі
  { {0x60c40149,0x2011004b,0x58d60012,0xe8040011}},	//   _otim, zezi_, _ميرذ, श्ता_
  { {0xacb40046,0x29560014,0xad260012,0x79b70009}},	//   јбољ, _съвр, اربو, _תלמד_
  { {0xb7b5001a,0x06f60037,0xebd60009,0xf1b90aae}},	//   _hạn, ुझाव_, נֵ֥י_, _vaše_
  { {0x2259003c,0x3394003c,0x60c40073,0x5c3701b0}},	//   вины_, ранё, _atim, אטיב_
  { {0xc3330093,0x201e0e9e,0x7524141d,0xed5a0048}},	//   צור_, _hati_, kviz, _пое_
  { {0xb7b50020,0xc2130009,0x8cb00011,0x9a84003c}},	//   _mạn, זהר_, _अंगो, суэл
  { {0x61e400a2,0x661d0039,0xf5930003,0x7afd004b}},	//   _edil, _sask, _الهج, ăstr
  { {0xa91d0029,0x7bda141e,0x661d141f,0x201e1420}},	//   _vyži, matu, _pask, _mati_
  { {0xdb180052,0x02fb0009,0x24490097,0x1c020011}},	//   _bevö, _נלחמ, _rúmi_, र्सल_
  { {0xdb050052,0x7524000e,0xdddb0066,0xb3eb0012}},	// [2af0] schü, gviz, nouš, فعال_
  { {0x7d1d0058,0x6bd40003,0x66040051,0x2bb80003}},	//   æssi, متمر, afik, هامة_
  { {0x5695002d,0xd5b10012,0xc2c40012,0x9f350024}},	//   _вант, _وفد_, ميلي, _тені
  { {0x7bda0cf4,0xb7b5001a,0x5fbf0037,0xdddb0066}},	//   hatu, _cạn, ्रकल, kouš
  { {0xb7b50020,0x26de0029,0xb604119d,0x7bda1421}},	//   _dạn, átov_, íšet, katu
  { {0xb346003a,0xd0090a15,0xe8000037,0xd2d70012}},	//   _kaçı, теке_, ल्ला_, _مغرب
  { {0x7e690070,0xe73900be,0x9169001a,0x201e1422}},	//   tiep, тей_, _lừa_, _dati_
  { {0xa2670098,0xddc20002,0x8aa41423,0xb5fd10dc}},	//   _съгл, _iloś, _груд, mišk
  { {0xf1c80066,0xb5fd1424,0xfbd10012,0xee36003c}},	//   ndář_, lišk, يتد_, рны_
  { {0xeb100037,0x40870015,0x7e690227,0x7bda1425}},	//   ़बूत_, _субб, siep, gatu
  { {0x6604003e,0xe29a0001,0x212900b6,0x8c1a000b}},	//   yfik, као_, _arah_, דותי
  { {0x6926003c,0x8f44003c,0xf7700012,0xf9870012}},	//   амма, _ухуд, _عال_, قب_
  { {0x7bda0005,0x8e840003,0x8a16000b,0x2d8f0052}},	//   batu, _النه, בחרו_, ügel_
  { {0x9f580065,0x7019002d,0x7d1c001e,0x8d5a0009}},	//   ferð_, ліст_, ārst, _בכני
  { {0x9f580065,0x45d6029b,0x76a60003,0xb5fd1426}},	//   gerð_, ицат, لحرك, višj
  { {0x25bf00c6,0x201e0010,0xb5fd078d,0xc4c60012}},	//   ncul_, žti_, dišk, لتطو
  { {0x3e7a001e,0xb21b0033,0x75d30012,0x64431427}},	// [2b00] nīta_, plær, زيلا, _koni
  { {0x752401a2,0xb5a90003,0x3eaf0ad2,0xb5fd1424}},	//   rviz, طاقك_, _ligt_, fišk
  { {0x3a20039c,0xa6ca0003,0xe9da072b,0x201e001b}},	//   _kaip_, _جوجل_, вке_, _rati_
  { {0x2902004a,0x201e0027,0x7bda0102,0x539a0009}},	//   otka_, _sati_, zatu, דיעו
  { {0xb5fd007a,0xb87b0018,0xd378001b,0x7bda016d}},	//   aišk, rrív, maće_, yatu
  { {0x3e7a0039,0x7ee60015,0xdb1c0028,0x26de0042}},	//   dīta_, ацие, _ferð, štou_
  { {0xdb1c0065,0xd6d70047,0x7bda05ef,0xa0890009}},	//   _gerð, аты_, vatu, נְנִ
  { {0xddcd1428,0x96341429,0x95880034,0x7ae3004b}},	//   mnaţ, сниц, aląż, ânte
  { {0x7bda142a,0xdd970015,0xe51c0011,0x99090012}},	//   tatu, ишь_, निटि_, _مغلق_
  { {0xddcd000d,0xe571000b,0x70fb0009,0xc34a0048}},	//   onaţ, לַי_, _בהמח, вяме_
  { {0x0bb70093,0x6f09003e,0xfee90003,0x8433002d}},	//   ילים_, łecz, _معنى_, інює
  { {0xdddb0066,0xe7170009,0x7bda142b,0x9f580097}},	//   pouš, _כחבר_, satu, verð_
  { {0xdfdb0098,0xc693000b,0x7bda142c,0x50f40024}},	//   къв_, _ואף_, patu, озят
  { {0x27ed008b,0xd48f002d,0x9169001a,0x9203001e}},	//   ßen_, _єр_, _vừa_, _šādo
  { {0x749b000b,0xb05b142d,0xe0df13cd,0xb4170012}},	//   _שיופ, npäi, ssò_, _ضغوط_
  { {0xe654007c,0x27ed003a,0x433b0009,0x97570009}},	//   овсь, şen_, _יעוב, בילו_
  { {0x8bb70003,0xdbd10028,0x656d0029,0x26c50010}},	// [2b10] لإضا, _býðu, _ľahk, ūlo_
  { {0xb5fd007a,0x8434002d,0x69dd0f2e,0x57f5013b}},	//   tišk, онує, lase, _упот
  { {0xbebc001e,0xa6ab0003,0x2d870002,0x41b50012}},	//   _drīk, _لاحق_, łne_, ممار
  { {0xdb1c014d,0xb5fd0a05,0x69dd142e,0xd9990012}},	//   _verð, rišk, nase, هنات_
  { {0xb5fd0010,0xfe360009,0xf1cc0011,0xd1090012}},	//   sišk, _הארך_, ारजन, اقته_
  { {0x8934000a,0x69dd00c8,0xd0110012,0x26110081}},	//   تعما, hase, سلع_, _ạo_
  { {0xe1ff000e,0xd7f80594,0xc7aa0009,0x2a69005e}},	//   giók_, руч_, ְׁפָ, _omab_
  { {0x3e7a0039,0x645a00ff,0xdddb13f6,0x7e6d142f}},	//   tīta_, ehti, služ, niap
  { {0x64431430,0xd5490015,0x6d4d00b6,0x69dd0688}},	//   _poni, уппе_, nyaa, dase
  { {0x2d91001e,0x645a0444,0xd378001b,0x79960034}},	//   āze_, ghti, zaće_, żywc
  { {0xd795000a,0x5f95000a,0x6f950003,0x3b090001}},	//   _الاخ, _الائ, _الاض, ћемо_
  { {0xc049000b,0x69dd1184,0x7bce0097,0x6f7a0009}},	//   _אז_, gase, ðbur, _גְדו
  { {0xa3d70037,0x53a70037,0x7e7e000e,0xcdb60009}},	//   सरा_, केतश, éppe, _הפנה_
  { {0x645a0518,0x29020b37,0x7bd80227,0x10a6123c}},	//   chti, rtka_, _gevu, сигн
  { {0x3a20007a,0x8c3b0032,0x7d0f0031,0x290202d0}},	//   _taip_, _fußz, _apcs, stka_
  { {0x69c10030,0x7bc102a2,0x92650012,0xaac40012}},	//   ělec, lclu, _وديم, _بتون
  { {0x291e001e,0x3ae3003a,0xe1ff0031,0xe5a303d4}},	// [2b20] ātas_, lıp_, ziók_, зити
  { {0xb3e90003,0xdceb0073,0x7bc11431,0xe73a004c}},	//   لعمل_, _lygį, nclu, _бео_
  { {0x68e40058,0x3ae3003a,0x60a50003,0x6d4d02a0}},	//   _hvid, nıp_, _بإيق, ayaa
  { {0xeb970800,0xddcd000d,0x90e60003,0x20070028}},	//   щих_, rnaţ, مستن, efni_
  { {0x2d840061,0x645a004a,0xdd920012,0x5fbf0011}},	//   _âme_, yhti, _روس_, ्रचल
  { {0x69dd08b2,0x3ae30060,0xf1b91432,0x8f340048}},	//   zase, kıp_, _vaša_, жекц
  { {0x7646007a,0x39520010,0x69dd0c6e,0x7bdb0009}},	//   _koky, šys_, yase, _תקלו
  { {0xceb3000b,0xdb1c006f,0x03770009,0x1ed70012}},	//   היה_, _berö, _התלת_, حبوب_
  { {0xb05b0006,0x7646007a,0xb5fb0028,0x645d001e}},	//   späi, _moky, _smák, īsin
  { {0x4096000a,0x14b7000a,0xb05b004a,0xb8960003}},	//   _الطر, حديث_, ppäi, _الطع
  { {0x5398002d,0x9f45003a,0xc43b0009,0xe215003c}},	//   рвня_, ülü_, אתיי, омны
  { {0x68e2009b,0x9169001a,0x7bde1433,0x7ae301e3}},	//   osod, _nữa_, hapu, ánti
  { {0xc05b002d,0x68e20b0d,0x3e7a0035,0x69dd1434}},	//   гів_, nsod, līto_, rase
  { {0x69dd03d5,0xd3ba002d,0x3cfb0009,0xdb1c0097}},	//   sase, _суді_, _עלונ, _afrí
  { {0x7ac60001,0xf7730003,0x3e7a0035,0x91690081}},	//   _усле, ساس_, nīto_, _bữa_
  { {0x8afc003e,0x3377000b,0x63770009,0x6f4b0009}},	//   rzęd, _לתוך_, _לגוף_, אֲמַ
  { {0x1dc40012,0x7d040031,0x95c81435,0xfe700012}},	// [2b30] سْلِ, gtis, суса_, ردف_
  { {0x7e6d00b6,0x859b0009,0xa3940030,0xa3a7004c}},	//   siap, רשמו, _důžé_, бјек
  { {0xfb150012,0xfa6b0009,0xe4500012,0x68e406dd}},	//   تواج, ְכְּ, رضك_, _zvid
  { {0x3e7a001e,0xe1f00003,0xb87b0029,0xb5fd017b}},	//   dīto_, فسه_, prís, piši
  { {0x64580164,0xab62003a,0x2c6f0034,0x3ae30060}},	//   _olvi, _çünk, ażda_, zıp_
  { {0x3ae3003a,0x6829000e,0x40ec0009,0xe9d90034}},	//   yıp_, ködő, אַהֲ, _weź_
  { {0x70b50037,0xdc9a0009,0xcee80012,0xf7420048}},	//   ंदुल, _כישל, مرين_, дещо
  { {0x245b0108,0x79960002,0x917a001a,0x17580009}},	//   _même_, żywa, hấp_, מסור_
  { {0x4423012e,0x6447001c,0x628b0e68,0xe1ff1436}},	//   _kaj_, _koji, mogo, ciói_
  { {0xdb1c0052,0x3d090037,0x31780003,0x3ae3003a}},	//   _verö, _वहीं_, _احفظ_, tıp_
  { {0x6490004a,0x68e4001b,0xe1ff0034,0x37c40012}},	//   päiv, _svid, niów_, _رينف
  { {0x7de6000f,0xdb1c003a,0x628b0604,0xc9aa02e3}},	//   _késő, _terö, nogo, ивне_
  { {0xec6e0014,0x229c1437,0xef1f0034,0x6616008e}},	//   _жп_, níka_, óżne_, veyk
  { {0x4423012e,0x9f580061,0x64900051,0x6ca70014}},	//   _naj_, lgré_, näit, _уреж
  { {0xe29a1438,0xf1b9009b,0x3b06002d,0x6616004a}},	//   _как_, _našo_, _дещо_, teyk
  { {0x69db008b,0x7d041439,0x752902a1,0x6df60012}},	//   _neue, ttis, ovez, تكرا
  { {0xe0d20003,0x628b143a,0x64900574,0x0eb60011}},	// [2b40] _غزة_, dogo, käit, _आंकड
  { {0x61e9143b,0xe3b80060,0x8b9608d1,0x5d670148}},	//   _adel, ydım_, ореч, циум_
  { {0xda66002d,0x3bd50015,0x9f060003,0x26050321}},	//   овжи, яютс, _بوجو, _हॉकी_
  { {0x201800a1,0x7afd003e,0xd62a0001,0xa79b0009}},	//   leri_, ństw, _томе_, _כשיח
  { {0xcaa50003,0xfe790066,0x7bde010a,0xc5f30009}},	//   أصلي, dnů_, papu, _קדש_
  { {0xe9f90020,0x61e9143c,0xc953000b,0x6e220027}},	//   _khả_, _edel, ומד_, _saob
  { {0xf8bf143d,0x69db0052,0xcf260003,0xc7af0012}},	//   _één_, _feue, ترشي, نّه_
  { {0xe3b800a2,0x7bdc1144,0xc7b3000b,0x00ca0048}},	//   rdım_, _heru, ובו_, _влак_
  { {0x3e7a001e,0x7bdc00b6,0x99800066,0x2018143e}},	//   sīto_, _keru, _aniž_, keri_
  { {0x94760003,0xb05b004a,0x718b0009,0xdb500012}},	//   تدعا, npät, _דְבַ, َّد_
  { {0x7bdc00c6,0x6490004a,0x42550003,0xdb050052}},	//   _meru, läis, كندر, schö
  { {0xf1b10037,0xbebc001e,0x752904d2,0xbddb0061}},	//   ुँचन, _brīv, bvez, _poèm
  { {0x2906004a,0x6490004a,0xe3b8003a,0x85760012}},	//   ntoa_, näis, ndık_, _بدائ
  { {0x201806b0,0x8afc0034,0x6fd90034,0x3a24143f}},	//   geri_, rzęb, dźcó, _lamp_
  { {0xf647002d,0xff040015,0xcddb0001,0x1bf70009}},	//   охан, мятн, иња_, _וצור_
  { {0x4423012e,0x6490008e,0x7bdc1440,0x16340306}},	//   _saj_, käis, _aeru, меся
  { {0x7bdc1441,0x64470066,0xe4d90012,0xb5fd001b}},	// [2b50] _beru, _poji, صوات_, mišt
  { {0x8afc0002,0x7bdc000d,0x2018000d,0xb5fd0580}},	//   częc, _ceru, ceri_, lišt
  { {0x8c1b000b,0x7bdc1442,0x6f0d0034,0x2906008e}},	//   שובי, _deru, łacz, etoa_
  { {0xf1b9012e,0xe1ff0002,0x3a241443,0xb5fd013a}},	//   _vašo_, riów_, _camp_, ništ
  { {0x4423001c,0x64900051,0x3ea903d5,0x69db0054}},	//   _taj_, täit, mmat_, _veue
  { {0x94ba000b,0x1beb0037,0x44b40014,0xd8220015}},	//   _למשת, _फ़ाइल_, _обяс, едши
  { {0xf6510003,0x13590012,0xe1f30012,0x7d190060}},	//   فئة_, _الأخ_, _يسر_, şası
  { {0xe9df014d,0xa77c000b,0x212d009b,0x52140001}},	//   _þú_, ירופ, _treh_, _одст
  { {0x5fcf0037,0x19580015,0x28b70037,0xb5fd0580}},	//   _स्थल, _даты_, _इंगि, dišt
  { {0x7529000f,0x7188000b,0xf8bf0028,0x3ea900b6}},	//   rvez, _וְעַ, rvél_, hmat_
  { {0x69c10066,0x7bc50052,0xa4480012,0x260c0011}},	//   ělen, ichu, تشيك_, ड्डी_
  { {0xdce7003a,0x69c10002,0x8f9a000b,0xc869000b}},	//   şlık, ślen, _היעי, _גן_
  { {0x55ba000b,0x7c23003a,0x5e440012,0xd378001b}},	//   _המנו, _tanr, _تَنْ, raća_
  { {0x3940004a,0x649000e6,0xd00a004c,0xccf90034}},	//   äisi_, häir, љеве_, muś_
  { {0xa0670001,0x602f0010,0x1867046d,0x07a3004c}},	//   чара_, dėmė, чари_, еарн
  { {0x6b9c0052,0x7bdc041e,0x75f60060,0x7e7b1444}},	//   ürge, _seru, müzü, nnup
  { {0x05660098,0xdd920003,0x7bdc1445,0x51fb000b}},	// [2b60] чван, روط_, _peru, _ההפצ
  { {0xe9f9001a,0x8fa60695,0x6490008e,0xee3f0064}},	//   _thả_, _напе, väis, _chýb_
  { {0x67bb000b,0xddc40002,0x68ed000e,0xc7bb0009}},	//   _למיק, oniż, áadn, _לציט
  { {0xf126002d,0x6490004a,0x2906004a,0xda650003}},	//   зько, täis, ttoa_, واني
  { {0xc5f3000b,0x7bdc1446,0xba290012,0xb05b008e}},	//   _אדר_, _teru, تسلم_, mpär
  { {0x6e260101,0x7c5a0003,0x6490004a,0x2906004a}},	//   _hakb, _السر_, räis, rtoa_
  { {0x29060006,0x6490004a,0x63830177,0xc66a003c}},	//   stoa_, säis, _згра, йшие_
  { {0xe663002d,0x6e260002,0x4b7b000b,0x64901447}},	//   етьо, _jakb, _האלו, päis
  { {0xc7b60012,0x6e3b0009,0x6e261448,0xa7b6004c}},	//   _فصاع, מתקד, _makb, _есеј
  { {0x44441449,0x515b000b,0x69c602f1,0x3b540024}},	//   nj_, _הכמו, ecke, дкор
  { {0x444400bd,0xb5fd024e,0x4f660012,0xe9ff0081}},	//   ij_, tišt, _عاطف, _hoạn_
  { {0x7f3b000b,0x76bb000b,0x6aa40061,0xee290003}},	//   _לעבו, _המאפ, _chif, _وأنه_
  { {0xb5fd001c,0x5a340048,0x3219144a,0x61fd144b}},	//   rišt, хнят, resy_, rgsl
  { {0x7b05004a,0xb97b0009,0x8c43034d,0x69c6144c}},	//   öttö, מרכז, _пече, acke
  { {0x9f34002d,0xb5fd0066,0xe9ff001a,0x3ebe0051}},	//   нері, pišt, _loạn_, _jutt_
  { {0x4444003e,0x61e20051,0x5f940447,0x4b7b0009}},	//   ej_, jaol, хист, _לאוו
  { {0x628f0026,0x61e20051,0x7afa144d,0xb87b0097}},	// [2b70] moco, daol, lutt, lsím
  { {0xf1b90027,0xe2f90024,0xd49b003c,0xe5530031}},	//   _sgš_, жежі_, ёра_, éséé
  { {0xe7a50039,0x93190003,0x7afa144e,0x7c280097}},	//   ādīš, تقاء_, nutt, iddr
  { {0xe1ff144f,0x7bc50732,0x68ed000e,0xe2980024}},	//   ciót_, schu, áado, пає_
  { {0xa954007c,0x3ebe0097,0x08c40024,0x9a880012}},	//   нкці, _autt_, ебін, أَنْ_
  { {0x7afa0006,0xe0d00012,0x75f60060,0x5d3a0009}},	//   kutt, ازن_, yüzü, _ותשא
  { {0xab95002d,0x69c6006f,0xef19002d,0x57240003}},	//   _циві, ycke, іми_, فريق
  { {0xa294007c,0xd738000b,0x7afa0a17,0x60cd004a}},	//   _засі, לטות_, dutt, _otam
  { {0xc212000b,0xd5e80012,0x2b490034,0xee360024}},	//   _בהן_, سعين_, _łac_, єнь_
  { {0x61ed00ec,0xd9280009,0xe53c0009,0x8b070030}},	//   _adal, _מֵעָ, מתחר, _naří
  { {0x60cd003a,0x28b70011,0x1c020011,0x6721001b}},	//   _atam, _इंजि, र्टल_, _uslj
  { {0x442b0034,0xd7f8004b,0x621900af,0x721900af}},	//   śc_, _umăr_, חוֹק, חוֹח
  { {0x98a4000d,0x7afa004a,0x2bfe0011,0xb1430198}},	//   _urmă_, autt, _लालू_, внял
  { {0x1cba000b,0x94ba0009,0xa7da0012,0x5b250012}},	//   _ומסע, _ומסת, توسط_, _يفشل
  { {0x92e8000a,0x66e6002d,0xcec40066,0xdee60024}},	//   _فريق_, ьова, daří_, ьови
  { {0x93240012,0xa695004c,0x6e291450,0xed5a0472}},	//   _أرون, еруј, ndeb, ооб_
  { {0xc986000a,0xfce30047,0x3cf50037,0x44271451}},	// [2b80] _تشغي, кото, एंगे_, _kan_
  { {0x58f7000b,0xb05b0a50,0x44440250,0xa3ba0012}},	//   _קצין_, spär, uj_, زائر_
  { {0x7d090005,0x661b004a,0xe9ff001a,0xe1ff06be}},	//   htes, keuk, _soạn_, ciós_
  { {0x44270020,0x8b070066,0xe1ff0002,0xdb24000e}},	//   _lan_, _zaří, chód_, ésév
  { {0x51830046,0x09360012,0xa0c40012,0x09e30542}},	//   куша, براج, ريغو, точн
  { {0xdfcf0003,0x2056027f,0x7afa1452,0xd943004c}},	//   ليه_, ьтер, yutt, тељи
  { {0x3e7a001e,0xc7b00012,0x90870012,0xe737004c}},	//   līti_, دّث_, بنوك_, деј_
  { {0x442701e4,0x7afa004a,0x7c270034,0xddc9004b}},	//   _aan_, vutt, _zajr, vieţ
  { {0x7eb5007a,0xd7cf0037,0x3e7a001e,0xc0060014}},	//   _išpl, _स्वच, nīti_, _опак
  { {0x442703f2,0x6026002d,0x61e00e26,0x3ebe00b8}},	//   _can_, _ідеа, _heml, _tutt_
  { {0x44271453,0x93f7000b,0x7afa004a,0x69c10002}},	//   _dan_, וציא_, uutt, ślem
  { {0xb87b0065,0xddc9007d,0x7afa1454,0x92580015}},	//   rsím, rieţ, rutt, дают_
  { {0x84460003,0x8b070066,0x44271455,0xbebc0035}},	//   _يختل, _paří, _fan_, _trīs
  { {0xa3df0044,0x44270039,0x3e7a001e,0xd4c50012}},	//   तरण_, _gan_, dīti_, _أغني
  { {0x764b00b6,0xabfb000b,0x626b0066,0xc7b10009}},	//   _yogy, _והור, dřov, ָ֑ם_
  { {0x61ed0b9c,0x7a870012,0xd91b0048,0x69c80030}},	//   _udal, _تشتم, _дьо_, ědec
  { {0x60cd00c6,0xce940014,0xddc9001e,0xb5fb0028}},	// [2b90] _utam, татъ, nieš, _smás
  { {0x201c0027,0x752d00c1,0xd49b0024,0xfdbb0011}},	//   jevi_, rvaz, іра_, _उल्फ
  { {0xa3a90044,0xd371000a,0xc7d6000b,0x201c1456}},	//   खें_, دها_, _אותי_, devi_
  { {0xa4d5002d,0xd3a40014,0xdb0e000e,0x7d09004a}},	//   _помі, труп, áján, ytes
  { {0xcce7000a,0xe6ed0026,0xb5fb014a,0x61e40028}},	//   _تسجي, _väčš, _vlád, ðila
  { {0xa158000b,0xd0110003,0x07a50146,0x8fa5077e}},	//   ובדה_, الغ_, налн, нале
  { {0x44271457,0x2bae0011,0xd00e0012,0x69c10030}},	//   _ran_, झेदा, صلي_, ělej
  { {0x6d250083,0x74d60011,0x87b80009,0x5a340530}},	//   едиз, मीकृ, ולוס_, _инст
  { {0xe5790015,0x6fca0037,0x44271458,0x68e91459}},	//   язи_, _स्कू, _pan_, _uved
  { {0x61e0080a,0x201c00c1,0x3eb9145a,0xc014022a}},	//   _zeml, cevi_, _list_, _имущ
  { {0x4427145b,0xddc9007a,0xdbdc0028,0xe29a013b}},	//   _van_, aieš, ráði, зан_
  { {0xdddb0030,0xc3320009,0x23780031,0x7d09145c}},	//   louž, אוט_, úrja_, ptes
  { {0xddc90039,0xdb1c006f,0x4427145d,0xc19a0024}},	//   cieš, _ifrå, _tan_, ятої_
  { {0x3ead145e,0x32040034,0xf8a70012,0x442701a0}},	//   lmet_, żmy_, طة_, _uan_
  { {0x6a96002d,0xa30e0037,0x6013003a,0x68ed000e}},	//   _приє, _सहेज_, mımı, áadj
  { {0xb5fb145f,0x3e7a001e,0x6013003a,0xe61f0029}},	//   _aláb, tīti_, lımı, _skôr_
  { {0xd5b20003,0xceb2000b,0x626b0066,0x3ead11c9}},	// [2ba0] افذ_, רין_, třov, imet_
  { {0x4f26002d,0x8726002d,0x6013003a,0x61e01460}},	//   _здоб, _змож, nımı, _seml
  { {0x5fdb000b,0x80890003,0x224d0070,0x3e7a001e}},	//   _מחיק, _تضيف_, _boek_, sīti_
  { {0x2cb8032b,0xc332000b,0xb3460017,0x27e10052}},	//   _wird_, טוב_, laçõ, _zehn_
  { {0x645b000f,0xa3df0037,0x6013003a,0xc05a0024}},	//   áció, तरा_, kımı, зій_
  { {0x3ea6002a,0x20c6001a,0xddc9001e,0xb3460017}},	//   _shot_, _môi_, vieš, naçõ
  { {0x5f930538,0xf0930009,0x8ba3003c,0xd7930048}},	//   лишт, אנג_, _бирж, лишъ
  { {0xddc9001e,0x95ca0472,0x9634034d,0x97a90009}},	//   tieš, чука_, тниц, וֹפֵ
  { {0x644e0002,0x442a00b6,0xd406002d,0x61e6013d}},	//   _kobi, _kab_, няни, dakl
  { {0x54540098,0x224d0070,0x2cb8006f,0xfc320003}},	//   твот, _zoek_, örd_, احظ_
  { {0x8afc0002,0x59f900ac,0xd7060024,0xdfa60012}},	//   częl, меня_, _їзди, _أحذي
  { {0x24560065,0xa75b000b,0x375b0009,0x20c60081}},	//   _dæmi_, _מדבר, _מכבד, _bôi_
  { {0x2bd10044,0xf1bf000e,0xf1b9001e,0x8e470012}},	//   _द्वा, ldák_, _paši_, _سلوك_
  { {0xb3460017,0x853b000b,0x6013003a,0xdd3b000b}},	//   gaçõ, _מגדי, cımı, _מעדכ
  { {0xf1b91461,0xdb210060,0xddcd0034,0x61f40248}},	//   _vaši_, ötür, ykań, ådlö
  { {0x61e6003a,0xdb9b000b,0xddcd000d,0x639b0009}},	//   cakl, _מסור, diaţ, _מסונ
  { {0x3eb9045d,0x59d40003,0x3f9e0028,0xc7cb0015}},	// [2bb0] _vist_, _صغير, ýtur_, _ныне_
  { {0x3ead00a2,0xb3460149,0x2bbb0003,0x3eb90070}},	//   zmet_, caçõ, ساطة_, _wist_
  { {0x644e0082,0x442c0028,0x73a90009,0xae210011}},	//   _dobi, idd_, ֵינֵ, _मसलन_
  { {0x41b50012,0xd0d50048,0xe0d5004c,0x60130060}},	//   نمار, водъ, водњ, zımı
  { {0x6e3d0052,0x3e7a001e,0x88c8002d,0x7afe02dc}},	//   _insb, nītu_, елів_, aupt
  { {0xa3bc0044,0x644e02d1,0x442a0052,0xd576000b}},	//   _अलग_, _gobi, _gab_, _יתרה_
  { {0xddcd000d,0xf838000b,0xba770012,0x7d0d1462}},	//   ciaţ, תנות_, _كارت, ltas
  { {0xb3460017,0x99d70012,0xa2be0011,0x7c2a005e}},	//   zaçõ, _سترا, षदर्, _aafr
  { {0x6013003a,0x2d990058,0xc4850055,0xdddb01bd}},	//   tımı, æse_, клик, použ
  { {0x3e7a001e,0x7d0d1463,0x69d90032,0x629d1464}},	//   dītu_, itas, lbwe, elso
  { {0x601300a2,0xb9040037,0x68ed0db3,0x7d0d1465}},	//   rımı, भी_, _avad, htas
  { {0x16110037,0x45d500de,0x645a1466,0x80d80011}},	//   _डॉलर_, _родс, akti, नीके
  { {0xb3460017,0x320c0002,0xb7e60037,0x68ed000e}},	//   taçõ, ędy_, _क़दम_, áadh
  { {0x7d0d00c5,0xdfd20003,0x38a4006f,0xc7ce001a}},	//   dtas, شير_, föra_, hống_
  { {0xb3460149,0xf092000b,0x24960003,0x38a4006f}},	//   raçõ, ינך_, _جنود_, göra_
  { {0x20c6008a,0xdbc90051,0xb3460017,0x644e1467}},	//   _tôi_, _mõõd, saçõ, _sobi
  { {0x6e2b0101,0x27e70028,0xf1bf000e,0x644e1468}},	// [2bc0] _magb, kann_, zdák_, _pobi
  { {0x42d6002d,0x78fb000b,0x7e64002a,0x61e41469}},	//   віду, _קליפ, ship, _heil
  { {0xe3b8003a,0xbddb0007,0x09e60063,0x78ba0097}},	//   ldır_, _poèt, воен, _ritv
  { {0x6e2b0101,0xd259002d,0x6da60003,0xddcd000d}},	//   _nagb, нці_, _لمجم, riaţ
  { {0xe3b8003a,0x442c146a,0x61e4146b,0x644e0edf}},	//   ndır_, ydd_, _meil, _tobi
  { {0x644e0027,0xddcd000d,0xa2d60003,0x27e702dc}},	//   _uobi, piaţ, _ليست, gann_
  { {0xa7fc003a,0x9183001a,0x3e7a001e,0x8a060909}},	//   _alıc, iếp_, zītu_, _изве
  { {0xfaa605cc,0x6604146c,0x61e41326,0xb7bc0035}},	//   _рабо, ngik, _neil, _maģi
  { {0x09060001,0x60c40010,0xd0260014,0x6e2b146d}},	//   _шпан, _nuim, _имай, _dagb
  { {0x78ba00bd,0xdb1c0061,0xe56f0012,0xd467004c}},	//   _uitv, _agré, غطي_, киње_
  { {0x7c2a0065,0x6fd801e1,0x7d0d000e,0x93fb000b}},	//   _vafr, _न्यू, ztas, וליי
  { {0xfee9000a,0x3e7a0039,0xd3780027,0x7d0d146e}},	//   _أعلى_, tītu_, naći_, ytas
  { {0x6e200390,0x61e40028,0xd8770003,0xfdf70009}},	//   memb, _deil, ناسب, _יצאת_
  { {0x2bfe0044,0x1d17000b,0x3e7a001e,0xf1b3000b}},	//   _लागू_, _סקור_, rītu_, יסר_
  { {0x61e40119,0x8c1b000b,0x3e7a001e,0x260f0011}},	//   _feil, _חווי, sītu_, थ्वी_
  { {0xb5950015,0x61e40028,0x01650012,0x68ed001b}},	//   гибш, ðill, _مُعَ, šadi
  { {0xa50700e3,0x55070014,0x3944006f,0x7d0d146f}},	// [2bd0] ъявл, ъчва, ämst_, utas
  { {0x7d0d0f92,0x63f40003,0x648b001e,0xd37b0014}},	//   rtas, لأمر, kļie, мче_
  { {0x3e7a0039,0x7ea50065,0xddc60002,0x6e201470}},	//   nīts_, hópa, _dokł, kemb
  { {0x62820051,0x27e70052,0x7d0d0f84,0x99d40012}},	//   gnoo, wann_, ptas, لتها
  { {0xee3f0029,0xd1b80003,0xe4e4002d,0x7d001471}},	//   _iný_, ناها_, _вісн, jums
  { {0x7eb50073,0x6282020d,0xf8b50011,0xc2c50012}},	//   _išpi, anoo, ूदिय, _ميسي
  { {0x6e2b01e5,0xd8740003,0xe3b8003a,0xd7ee0003}},	//   _pagb, جانب, zdır_, سكي_
  { {0x442100c6,0xddcd0039,0x3e7a0039,0xe3b8003a}},	//   leh_, skaņ, dīts_, ydır_
  { {0xf1b9001e,0x27e70028,0xe616003c,0x7d000035}},	//   _pašu_, pann_, уды_, gums
  { {0x4421012e,0xe9f90020,0x60c40070,0xcf270012}},	//   neh_, _thẻ_, _ruim, _لرؤي
  { {0xf1b91472,0x6569000e,0xf8bf0031,0xbbe10011}},	//   _vašu_, szeh, kvés_, _फ़ैक
  { {0xcd350003,0x75240034,0xeb920009,0x52860012}},	//   _مرتب, ywiz, מָר_, الحك
  { {0x4a5a0093,0x4421016d,0x7afa1473,0x61e41474}},	//   גדרו, keh_, artt, _veil
  { {0xe3b800a2,0x44210027,0x04590012,0x7e62001b}},	//   rdır_, jeh_, _سلعة_, _zlop
  { {0x61e41475,0x99750002,0x3e7a001e,0xc29a003c}},	//   _teil, nęło_, lūta_, _птиц_
  { {0xa2060306,0xd627003c,0xd3560009,0x6fd40011}},	//   _спид, лосе_, _תיקי_, _ब्रू
  { {0x66c7003a,0x0eb90015,0xe9f9001a,0xa1130003}},	// [2be0] _sıkl, туры_, _nhẹ_, _هويت
  { {0x290200b6,0xb4e40011,0xdde30035,0x6e201476}},	//   muka_, _नबी_, ārša, zemb
  { {0x6e200101,0xb17d0029,0x66e60024,0x29021477}},	//   yemb, _reťa, _щона, luka_
  { {0x2cb00010,0x6f79000b,0x3ce80321,0xfbc90009}},	//   _žodį_, _יְרו, _चौथे_, לת_
  { {0xf9920003,0x29020029,0x3e7a001e,0x7a3b008e}},	//   حبا_, nuka_, zīts_, _hätä
  { {0x66c700a1,0x3cf90044,0xb87b0149,0xed590066}},	//   _tıkl, ोंने_, ssív, dyž_
  { {0x77ba0009,0x3c630024,0xe8160011,0x27e7005e}},	//   ׂמְח, _укрг, द्या_, _õnne_
  { {0x7c2e07ca,0x44f41478,0xe3c10060,0x26c5020d}},	//   _habr, апис, ğış_, _dulo_
  { {0x3e7f004a,0x38a40028,0x61ed0028,0xf6530009}},	//   lätä_, vörn_, ðale, מצה_
  { {0x3e7a0039,0x2452000d,0xa98b000b,0x7ea5000e}},	//   tīts_, _câmp_, _אָבִ, rópa
  { {0x36060003,0x68ed000e,0x8fa6010b,0x04970009}},	//   _مواف, áadv, _саже, רכיך_
  { {0x21b5007c,0x0bb7000b,0xa295002d,0x3e7a00cd}},	//   ийня, טלים_, рамі, rīts_
  { {0x6e93000a,0x5e93000a,0xd5ed001a,0x3e7a001e}},	//   _النا, _النط, hoạ, sīts_
  { {0x3e670051,0x6d46004a,0x3e7f008e,0x21580012}},	//   _mõte_, äkau, kätä_, اجَع_
  { {0xab270001,0x395f0259,0x316b0002,0xfc2f0012}},	//   _боја_, šus_, szcz_, _رحو_
  { {0x290200b6,0x7ea50028,0xbb3b000b,0xb5d50001}},	//   buka_, hópn, _טעוי, ржај
  { {0x3cee0044,0x9f430066,0xdbdf0028,0x62830061}},	// [2bf0] ेंगे_, mají_, _bíðu, énom
  { {0xe3b30003,0x9f430066,0x8c440001,0x3ea0008e}},	//   مرض_, lají_, беђе, alit_
  { {0xbb840003,0xb9c50012,0xfbd00012,0x3ea01479}},	//   ملكي, لقضي, ستل_, blit_
  { {0x9f430066,0x82f80012,0xda670012,0x4421147a}},	//   nají_, ارلز_, دائي, seh_
  { {0x7bc60066,0x41af0011,0x2d800064,0x442102a1}},	//   ěkuj, जेंस, _žien_, peh_
  { {0x0084002d,0x9f430066,0x3cfa0009,0xfd960009}},	//   бліо, hají_, _בלשנ, _כדרך_
  { {0xf7710003,0x9f430066,0x0058000b,0x656d0052}},	//   غات_, kají_, רשות_, lzah
  { {0xbb84000a,0x43840003,0x7ae3000d,0xee39147b}},	//   _الفي, _الفق, ântu, тни_
  { {0x9f430066,0x656d0052,0x7c21012b,0xfd460048}},	//   dají_, nzah, telr, изък_
  { {0x9f6b0098,0x99540001,0x26c5004a,0xf8b90012}},	//   _през_, _укуц, _tulo_, _شهاب_
  { {0xba760003,0x3e7a001e,0xc949000b,0x3b090001}},	//   لاحت, sūta_, _קמ_, њемо_
  { {0x6dc7000a,0x67b80003,0xdef6000b,0xcb12000b}},	//   _إزال, _صالح_, _כמעט_, חלט_
  { {0x9f47022d,0x6f03013d,0xfce507a7,0xb5fb147c}},	//   dané_, lunc, _толо, _plán
  { {0x2902001c,0x05a8002d,0xb4fa000b,0x442e147d}},	//   ruka_, _свій_, _יפני, _gaf_
  { {0xfaa60047,0x6f03147e,0x3f9e0028,0xdee60dc2}},	//   _како, nunc, ætu_, роби
  { {0xdbdf0065,0xfaf8001e,0x21290029,0x6e2f0081}},	//   _síðu, rzīt_, ťahy_, _cacb

  { {0x3ea00065,0x7c2e147f,0x6bd60012,0x9cb60012}},	// [2c00] rlit_, _pabr, لتار, لمرت
  { {0xa7fc00a2,0xa4430001,0x33d60024,0xb87b01bd}},	//   _alın, онуд, ріат, usít
  { {0xb7fb0009,0x130a003c,0xb87b0031,0xddc00031}},	//   _בפית, тней_, rsít, zimű
  { {0xb87b000f,0x3e7f004a,0x52760012,0xeb971480}},	//   ssít, rätä_, جائز, ших_
  { {0x3e7f0006,0x93bc000d,0x7bc300c1,0xa3e80011}},	//   sätä_, ndăr, _ognu, बरम_
  { {0xa073007c,0x7d040006,0xb937000b,0x6e241481}},	//   огіч, muis, יננו_, leib
  { {0x8c1b000b,0xe0b7000b,0x7d040feb,0xd6cf0024}},	//   _שולי, בלסט_, luis, ют_
  { {0xa2cb0037,0x95d70014,0x89d70012,0xb0fa0012}},	//   _तंत्, адът_, _نوفر_, _لفرض_
  { {0x9f430066,0xe611000b,0x78b10028,0x68ed000e}},	//   vají_, הִי_, ákvæ, áadt
  { {0xb7960001,0x6e240052,0x9f4701bd,0x8d730012}},	//   _крећ, heib, zané_, غايا
  { {0xe9f90020,0x9f430066,0x439405f7,0x1c0b0011}},	//   _chế_, tají_, санс, स्टल_
  { {0xc3330093,0xa2f70009,0x9f7b0009,0x877b0009}},	//   קור_, סמכה_, _בנבח, _באבי
  { {0xdd92000a,0x9f4700f1,0x4fc7010c,0x7d0413f2}},	//   _بوش_, vané_, исва, juis
  { {0xdc080039,0x78620026,0x611a001e,0x7d041482}},	//   _rēķi, _dôvo, mālā, duis
  { {0xf0b4002d,0x1754002d,0x9f470004,0x4fd70009}},	//   ійсь, овря, tané_, שולב_
  { {0x3bbb000b,0x8f1b000b,0x2c64006f,0xdce6003a}},	//   _במוד, כולת, _röda_, _aykı
  { {0xe4e7002d,0xa2ca0037,0xebc70001,0x611a001e}},	// [2c10] рібн, _सूत्, аљен, nālā
  { {0x6f03003a,0xe8160037,0x656d0052,0xea00001a}},	//   yunc, द्दा_, rzah, _trải_
  { {0xeb090003,0xbebc001e,0x75360010,0x656d0052}},	//   اقصى_, _drīz, avyz, szah
  { {0xe8f5000a,0x80f50012,0x3a980024,0x7d041483}},	//   مستخ, مستض, атію_, buis
  { {0x3cfe015f,0x98da0037,0x361a0009,0xf8da0011}},	//   _लिये_, _बढ़ाए, _גורד, _बढ़ाय
  { {0x61eb1484,0x6f03004b,0xf1bf0031,0xed560009}},	//   sagl, tunc, ldás_, _הבשר_
  { {0x61eb002c,0xe7080003,0xda35003c,0x62860034}},	//   pagl, لتين_, _левы, ynko
  { {0xcb12000b,0x44310164,0x52850003,0x7c251485}},	//   _מלל_, _haz_, _الرك, lehr
  { {0x95550003,0x95990015,0xee36003c,0x64551486}},	//   إخبا, ытку_, сны_, _kozi
  { {0xb4650047,0x3c650803,0xac18002d,0x4431009b}},	//   скол, ског, ацює_, _jaz_
  { {0x61e90005,0x4431001e,0xd259001e,0x8c1a0009}},	//   _keel, _maz_, _ziņa_, אותי
  { {0x99800026,0x78620026,0x64550027,0xddc2009b}},	//   žiť_, _pôvo, _lozi, _zmož
  { {0x61e90005,0xf652000b,0x7c250052,0xfe700012}},	//   _meel, _מצא_, kehr, _تدل_
  { {0xe9f90020,0x7d04004a,0x200c0051,0x66090154}},	//   _thế_, vuis, üdi_, lgek
  { {0x64430065,0x78a3001e,0x74120012,0x2d9200b0}},	//   _inni, ilnv, _رويا, _øyer_
  { {0x9f4500d9,0x22f60009,0xc4c60012,0xa3df0011}},	//   _celé_, _הזקן_, متطو, तरक_
  { {0xceb20093,0x6e240052,0x75290070,0x62990002}},	// [2c20] ליל_, reib, nwez, dowo
  { {0x4806002d,0x3137000b,0x4431000d,0xb9370009}},	//   _упов, _פנים_, _caz_, _פניו_
  { {0x61e90070,0xddcb0002,0x291f004a,0x9f45000e}},	//   _beel, _mogł, _apua_, _felé_
  { {0xa2ca0044,0x44250005,0x2018006f,0xfaf6000b}},	//   _संस्, hel_, lfri_, מצעי_
  { {0x64430006,0x2baa0037,0x61e90070,0x44310017}},	//   _onni, _करवा, _deel, _faz_
  { {0xd259001e,0xbb46027f,0xeb9a0867,0x8459004c}},	//   _viņa_, _легк, _биг_, _крст_
  { {0xf1bf1356,0x61e91487,0x1ef70012,0x8ad80009}},	//   ndár_, _feel, معية_, _כַּפ
  { {0x62990002,0xa6c70003,0x44251488,0x14f8004c}},	//   cowo, حويل_, eel_, анић_
  { {0x89660047,0x64690010,0x4431003a,0xe9f9001a}},	//   _укаж, šsių, _yaz_, _chẽ_
  { {0xe8d7000b,0xddc20107,0x26c210dc,0xe0860012}},	//   _לומר_, _umož, _liko_, _اجري
  { {0xb4db0054,0xd3d70003,0x4c9b0009,0xd7960012}},	//   _gràf, حبًا_, רביו, _الضخ
  { {0x4669002d,0x645c0051,0xfe720003,0x26c20027}},	//   _крім_, örib, _عدا_, _niko_
  { {0x2e370009,0x1dac0011,0xf4d70012,0xc27b0009}},	//   _לראש_, _चरित, _هونغ_, ררכי
  { {0x27ee0065,0x20181489,0xe81b0011,0x2fc5036e}},	//   nafn_, gfri_, प्पा_, ølg_
  { {0x447b000b,0xd6f8000b,0x44310fae,0x9c17000b}},	//   _תנוע, יִּש, _raz_, _החוק_
  { {0xf1ba0037,0xea00001a,0x7c250052,0x6455148a}},	//   ेशान, _trại_, wehr, _sozi
  { {0xdc550046,0xcbc70003,0x545503e2,0xd0110012}},	// [2c30] овањ, مزاي, оват, _قلة_
  { {0xe787002d,0x628a01e3,0xba3d0030,0x61e9148b}},	//   _гумо, éfon, _lhůt, _seel
  { {0x94a80098,0x8c1b000b,0x8afc0002,0x11d70003}},	//   стта_, רובי, częt, متشد
  { {0x4425148c,0x19eb0012,0xe81b0011,0x60c1148d}},	//   zel_, اراً_, प्ना_, _silm
  { {0x4acf0037,0x4425059b,0x61e90114,0x60c901e3}},	//   _संभव, yel_, _veel, _quem
  { {0x212d012e,0x859a0009,0xb17c0009,0x37090012}},	//   _vseh_, _כשרו, נטגר, لْتُ_
  { {0x786b00a2,0xb8d00037,0x62990002,0x2bdf0037}},	//   _güve, _टी_, powo, _प्या
  { {0x44250777,0xa77c0009,0x0f7c0009,0x5eec0009}},	//   wel_, טרופ, טרול, רַגְ
  { {0x60c100c5,0x60c90051,0xddcb0034,0x260a0011}},	//   _tilm, _uuem, _pogł, िलती_
  { {0x75290070,0xb4db0054,0xac960003,0x9f47119d}},	//   rwez, _tràf, ينيا_, laní_
  { {0x2dd50511,0xb7670048,0x224a0048,0x4425148e}},	//   _джер, _утай, апни_, rel_
  { {0x753d000f,0xd6ab0003,0x4425148f,0x6ffb001e}},	//   _orsz, _صدام_, sel_, sācē
  { {0xc5e80009,0x14750012,0x38a4005e,0x8aa80009}},	//   _הַצֹ, _واتج, löri_, מֹשֶ
  { {0x64430028,0x73c40012,0x2a69005e,0x316c0034}},	//   _unni, _فيهم, _elab_, ądz_
  { {0x1fb50232,0x7aa60012,0xe81b0011,0xae7a0024}},	//   зстр, _وإعل, प्या_, асах_
  { {0xcb12000b,0x00ca03e2,0x8afc0034,0x20180841}},	//   _חלה_, _клик_, rzęt, sfri_
  { {0x9f470004,0x80e60012,0x15ba003c,0x786b04e7}},	// [2c40] daní_, _بأعل, рывы_, _süve
  { {0x63a30065,0x3e670051,0x0c230015,0xf1b90066}},	//   _kynn, _võta_, ммун, ýše_
  { {0xeac9001a,0x49ca0104,0xd1380002,0x7a0d000e}},	//   _mẹo_, ален_, łąd_, zőtő
  { {0x7e6d00bd,0xe8160037,0xb1cd0009,0x63a30245}},	//   chap, द्रा_, ְמוֹ, _mynn
  { {0xf6530009,0xbba60011,0xe80e0011,0xd0100012}},	//   _חצר_, _ऑर्क, _सादा_, ّلت_
  { {0x6e360010,0x88c50012,0xaff70012,0xb5fb0031}},	//   ldyb, ستهل, قفها_, _aláh
  { {0x787b000b,0x42d60024,0x3e6a0024,0xb5fb0030}},	//   יָהו, _фігу, ишин_, _bláh
  { {0x2000000d,0xbe8a0001,0x27ee0028,0x42d50024}},	//   şii_, јске_, safn_, _хіру
  { {0xd00a0046,0xceb30093,0xddc2003e,0x61e40028}},	//   _везе_, ויה_, _umoż, ðilu
  { {0x0bf30047,0xc8660003,0xaff70003,0x7d7b0009}},	//   мпью, _بطري, _وفقا_, ינפו
  { {0x61e20027,0x20d0001a,0xe3b8003a,0xfbd30009}},	//   obol, _hài_, ldız_, ותת_
  { {0xb5fb05b1,0x539b0009,0x5ce60048,0x63b500d9}},	//   _vlák, שיטו, _дюка, ýzna
  { {0xa2ca0011,0xb2bb0009,0x26cc0159,0x61ef1490}},	//   _सूर्, ימטר, _hudo_, racl
  { {0x74130012,0x14180012,0x54970012,0x60dd1491}},	//   _يونا, _طيبة_, _وضوح_, rpsm
  { {0x9f34002d,0xa7fc003a,0x8f340129,0xb6d80009}},	//   мері, _alık, мерц, מַּט
  { {0x9757000b,0x61e2048b,0xa195002d,0x19950024}},	//   חילו_, jbol, _найч, _найя
  { {0x9f47015d,0x7e6d1492,0x61e20058,0x6eca0034}},	// [2c50] vaní_, rhap, dbol, _dębi
  { {0xa3a70046,0x61ed002a,0x2ba70001,0x7e64002c}},	//   ојек, _heal, ојев, akip
  { {0xd498002d,0xf429004a,0x58b80003,0x9f470029}},	//   іру_, lmää_, _بايج_, taní_
  { {0x20d00020,0x75220c82,0xe5030011,0x61ed0132}},	//   _bài_, _opoz, _लिपि_, _jeal
  { {0xdd860351,0x20d00020,0x71270003,0xd92b0048}},	//   _أو_, _cài_, ترال, рцел_
  { {0x55ba000b,0x20d0001a,0x660d005e,0x60dc0009}},	//   _למרו, _dài_, lgak, סקונ
  { {0x915e001a,0xb5fd001e,0xf429004a,0xdb03014a}},	//   oặc_, ekša, hmää_, _ozná
  { {0xdb1c000e,0xb5fb0028,0x11d40012,0x38a4005e}},	//   _ugrá, _blái, _يتقد, röri_
  { {0x6447048b,0xa9240010,0x1d22003c,0xc1040012}},	//   _knji, įžki, емым, _يوفي
  { {0x7c2804a3,0xb9240012,0x33d40024,0x1309003c}},	//   gedr, _تفكي, міют, бной_
  { {0x7ea50028,0x07080003,0xbb450695,0x6b560009}},	//   hópi, _ويكي_, ченк, ִישׁ_
  { {0xce380003,0x7d16004a,0xacf50012,0xd5750024}},	//   _وأنا_, ytys, _فستت, _нуль
  { {0xf8cb0037,0x8d770012,0x61ed1493,0x74b906bd}},	//   ादिय, _باضا, _deal, _лукс_
  { {0x5d3a000b,0xfd56000b,0xc9520009,0xfaf10012}},	//   _לתנא, _משני_, תמך_, _كثب_
  { {0x7d09004a,0x6c320003,0x61e20361,0xfbd20009}},	//   lues, _سفيا, ybol, _אתו_
  { {0xee3a0001,0x6446001e,0x644700b6,0x61ed1494}},	//   љна_, ēkie, _anji, ðall
  { {0x2bd20011,0xd00a004c,0xc6920009,0xb4db01a0}},	// [2c60] _सलमा, _лепе_, גאן_, _aràb
  { {0xd7f1001a,0x7e641495,0x628b139d,0xd5af0012}},	//   ữa_, skip, engo, افك_
  { {0xf8b30093,0x8b26002d,0x53a60003,0x7d16004a}},	//   _רשת_, ядже, أماك, stys
  { {0x7659003e,0x2ab2000f,0x0ae90003,0x316a002d}},	//   _nowy, lább_, تركي_, йшло_
  { {0x40340014,0x90560009,0x3034003c,0x6e29005e}},	//   делс, ּסֶף_, делё, deeb
  { {0x20d00020,0x7e880066,0x26cc0164,0xe0430001}},	//   _vài_, měpi, _pudo_, енљи
  { {0xe1ff0002,0x61e40028,0x91e61496,0xd9b90011}},	//   chów_, ðils, _нове, _इण्ट
  { {0x20d0008a,0xfaa3007c,0x7d040027,0xdceb003a}},	//   _tài_, _засо, oris, _aygı
  { {0x2ab2000e,0x628200e6,0xb5fd0035,0x90e50012}},	//   kább_, mioo, ukša, _يسكن
  { {0x26cc0149,0xd4d70003,0x61ed1497,0xf3f10081}},	//   _tudo_, أبيض_, _seal, _ột_
  { {0x61ed0005,0xa3b60037,0x60cd00b6,0xe61a1498}},	//   _peal, चें_, _suam, _где_
  { {0xaf49000a,0xcf250003,0x6fd80011,0x7d041499}},	//   _بشكل_, _تركي, नुरू, kris
  { {0x7d090164,0xe5340015,0xb5fb0042,0x1e570009}},	//   cues, _цель, _kláv, _משאר_
  { {0x61e000a2,0x55bb000b,0x629d004a,0x61ed002a}},	//   ımla, _המדו, soso, _weal
  { {0x8c1b007e,0xda0d0037,0xf429004a,0x7c35017b}},	//   _הווי, _हालत_, smää_, _razr
  { {0x443f00a2,0xdb0300d9,0xe0df00b8,0x9f47009e}},	//   _şu_, _uzná, ppò_, naná_
  { {0x81fc000b,0xaffd002d,0x22490029,0x82340012}},	// [2c70] _ההחז, _копi, _inak_, _سريا
  { {0xdfd10003,0xfbd00012,0x734b0048,0x68f80030}},	//   _جيد_, هتم_, йчев_, řadí
  { {0xde59002d,0xaac70003,0x68e9149a,0xd3710012}},	//   _дані_, ستان, _swed, خها_
  { {0xe3b0000a,0x62820051,0x68e9002c,0x7d040082}},	//   ارك_, gioo, _pwed, bris
  { {0x9179008a,0xdddb0002,0x9f4701bd,0xf6560009}},	//   _bấm_, ykuł, daná_, _חסרי_
  { {0x0138000b,0xc7a5002d,0x07a5011f,0x8fa502ac}},	//   פרות_, милк, малн, мале
  { {0x76590002,0x6626000e,0xc7d8000b,0xddc90002}},	//   _powy, _ütkö, לוגי_, pież
  { {0xb4db03eb,0x645c0163,0x56920001,0xb5fd009b}},	//   _gràc, örin, кајт, akšn
  { {0x58050012,0xa5250024,0xdb1c0248,0xb815004c}},	//   _يورك, ємод, _egrä, _одај
  { {0x22490535,0x7870008e,0xab650024,0x38350024}},	//   _anak_, _käve, двол, _інер
  { {0x6ee7000a,0x2ab2000e,0x1a2a0014,0x29190c25}},	//   _رسال, vább_, ожни_, etsa_
  { {0x7d0902d1,0x1dbf0037,0xc869000b,0x4a43002d}},	//   pues, ्शात, _דן_, внюв
  { {0x7d09149b,0x9f64008e,0x66c70060,0x91f60009}},	//   ques, ätön_, _fıkr, ומרו_
  { {0x63851154,0x22490f49,0xcb690dd8,0x55ba0009}},	//   _огла, _enak_, _мале_, _ומנו
  { {0xe29f0065,0x75450002,0x82860012,0x2bf60009}},	//   boð_, łrzę, _يجعل, _חמצן_
  { {0x39400010,0xd9f20011,0x38a40097,0x7af50031}},	//   _tris_, _अजित_, vöru_, áztu
  { {0x32d30020,0x6fa40011,0x38a40248,0x51fb0009}},	// [2c80] _hãy_, _चुनू, fört_, _והפצ
  { {0x88c60003,0xa2e60015,0x26cc0056,0x7d04149c}},	//   _تتعل, дожд, ídos_, rris
  { {0xb4db0054,0x6282149d,0x3ea9149e,0x7d04149f}},	//   _pràc, tioo, blat_, sris
  { {0x41aa0014,0x2a88000e,0x3ea90054,0xf1260024}},	//   овен_, lőbb_, clat_, дько
  { {0x62820005,0x9f4700f1,0xb5fb14a0,0x20d40269}},	//   rioo, vaná_, _cláu, _jäi_
  { {0x6282035f,0xd6da14a1,0xa3c80011,0x3ea014a2}},	//   sioo, оти_, _उलट_, loit_
  { {0x4438007d,0x7ea50065,0x6564008e,0x3ea00227}},	//   _iar_, hópu, lyih, ooit_
  { {0xa3c30037,0x1d3405cc,0x9f450061,0xc7b30009}},	//   ्शन_, ения, _delà_, כבו_
  { {0x645c14a3,0x44380660,0x64c80011,0x5c060148}},	//   _kori, _kar_, रदेश, мяна
  { {0x986a0012,0x515b0009,0xac26003c,0x3b540469}},	//   _بحرف_, _וכמו, ффик, екор
  { {0xd37a022e,0x2a88000e,0xe29f0097,0x88c50012}},	//   ючи_, zőbe_, toð_, _ستكل
  { {0xaacf0037,0x32d3001a,0x443814a4,0x7ea50031}},	//   _संरक, _dãy_, _lar_, fópu
  { {0xa2ca0037,0xd1260003,0x76bb000b,0x394d0018}},	//   _संक्, دم_, _ומאפ, ães_
  { {0x645c039c,0x104b002d,0x9f430029,0x291914a5}},	//   _nori, цями_, majú_, rtsa_
  { {0xc058002d,0x61ed0028,0x67d4002d,0x9f430029}},	//   фія_, ðalk, тосу, lajú_
  { {0xe4e7002d,0x92580003,0x38a4006f,0x5afb000b}},	//   діжн, _يشير_, förs_, _ולהצ
  { {0xdfd50047,0x865b000b,0x7c38003a,0x9f430029}},	// [2c90] _попы, קדמי, _kavr, najú_
  { {0xb5fd0039,0x443814a6,0x442c14a7,0x3ea914a8}},	//   ekšl, _car_, ned_, slat_
  { {0x645c007d,0xf2d00003,0x3e7a001e,0x443814a9}},	//   _dori, لآن_, lūtu_, _dar_
  { {0x23df015f,0x2bdf015f,0x53df0044,0xfbdf0044}},	//   _प्रद, _प्रा, _प्रश, _प्रम
  { {0x81f60003,0x6d440010,0x26de00c1,0x4dda000b}},	//   رفور_, _šian, _atto_, _מחרו
  { {0x9f430029,0x3e7100f1,0x443814aa,0x442c14ab}},	//   dajú_, _máte_, _gar_, jed_
  { {0x442c0b7b,0xa2ca0037,0x8fa20a1a,0x60c80010}},	//   ded_, _संग्, лаше, _didm
  { {0xee32000b,0x2ab2000e,0x38b60260,0x9f450042}},	//   ָֽה_, kába_, mære_, _celá_
  { {0xd14b000a,0x2ab2000f,0x79a70001,0x6606000e}},	//   _بشأن_, jába_, _црве, ókka
  { {0xa2ca0044,0xe451000a,0x6aa414ac,0x442c14ad}},	//   _संख्, اضة_, _skif, ged_
  { {0x6d420352,0x6a860014,0x7c38003a,0xae0f0037}},	//   _eroa, елна, _davr, िलान_
  { {0xdb1e0066,0x644a0c4d,0x5ee80009,0x7d0d14ae}},	//   áván, _enfi, _חַסְ, kuas
  { {0x3e7a0039,0x7e690028,0x3e6e0028,0x442c0087}},	//   gūtu_, mkep, _nýta_, bed_
  { {0x442c0036,0x7ea50028,0xa2ca0321,0x8d5a0009}},	//   ced_, rópu, _सूक्, _מכני
  { {0xd5b70020,0x7f190024,0x443814af,0x3ea014b0}},	//   ếng_, міту_, _rar_, toit_
  { {0x2a88000f,0x26de001e,0x3e7a001e,0x7c3814b1}},	//   sőbb_, īto_, būtu_, _zavr
  { {0xeb1f0044,0x765d00a2,0x443814b2,0x3ea00ca7}},	// [2ca0] _बहुत_, _dosy, _par_, roit_
  { {0x7d1b0006,0xc19b000b,0xf9770009,0xe3b20012}},	//   itus, _משפי, _נגיש_, هرا_
  { {0x7d1b0051,0x9f430029,0x09ba0037,0x961d001e}},	//   htus, zajú_, ेश्य, ziņa
  { {0x443814b3,0x442c14b4,0xe1f20003,0xd259002d}},	//   _war_, zed_, اسا_, мці_
  { {0x442c0036,0x21670e0f,0x7ea50028,0x443814b5}},	//   yed_, ници_, hóps, _tar_
  { {0x9f430026,0x442c002a,0x628614b6,0x81430012}},	//   vajú_, xed_, hiko, انون
  { {0x442c0036,0xe6660001,0xab090003,0x7d1b00ff}},	//   ved_, етпо, _يتفق_, etus
  { {0x442c0036,0x9f47003a,0x7c380027,0x9f430029}},	//   wed_, zanç_, _savr, tajú_
  { {0x2dd70003,0xb5fb0028,0x3cf90037,0x442c14b7}},	//   ربية_, _klár, ोंगे_, ted_
  { {0x9980007a,0x7d7b000b,0x60fb000b,0x9f430029}},	//   žių_, פניו, _מהמק, rajú_
  { {0x7d1b0051,0x442c14b8,0xaf490003,0xdf490012}},	//   atus, red_, _يشمل_, _يؤمن_
  { {0x62860005,0x99890029,0x442c14b9,0x58d50024}},	//   giko, žať_, sed_, комт
  { {0x765d0002,0x61ed0028,0x60f80015,0x442c14ba}},	//   _rosy, ðali, нняя_, ped_
  { {0xd259001e,0x765d14bb,0x62860079,0xc0580024}},	//   _viņi_, _sosy, aiko, ніс_
  { {0x6e2d14bc,0x02a714bd,0x36d5020e,0x8bd70009}},	//   teab, _прим, тобр, _טוגו_
  { {0x99850012,0x7d0d14be,0x25dc0011,0xb21b0506}},	//   _للعو, tuas, गुली_, rnæs
  { {0x68ed0002,0xa3d5003c,0x2439004c,0x8d740012}},	// [2cb0] _uwad, возч, мпањ_, هاكا
  { {0xb4ab0037,0xf8b8001a,0x9c38004c,0x6e2d14bf}},	//   खते_, _nhĩ_, нпут_, seab
  { {0x3944002a,0x72190109,0x749b0009,0x307c0009}},	//   _arms_, джер_, לימפ, _מאזנ
  { {0xd7f1008a,0x61cb0037,0x636b000e,0xa9350012}},	//   _sẽ_, िशेष, lönö, َّاب
  { {0xe0d8002d,0x229c0066,0x865a0009,0x26da03a7}},	//   еві_, níky_, _חדרי, ípon_
  { {0x99920002,0x717c0009,0xc0c8004c,0x628614c0}},	//   _abyś_, הנדס, нује_, ziko
  { {0x201a0054,0xd00e0003,0xa6950001,0xf8380009}},	//   òpia_, زلي_, криј, גנות_
  { {0x7bda000d,0x8aa40024,0x99d40012,0xc1050012}},	//   ectu, _бруд, _متكا, _لوري
  { {0x7d1b14c1,0x58d5002d,0x7a42000e,0x7e6906d2}},	//   utus, _розт, nítő, rkep
  { {0x44ef0002,0x446504f0,0x58d414c2,0x290f005e}},	//   iż_, твов, _софт, muga_
  { {0xfbd2000b,0x7d1b14c3,0xe29a0751,0x290f14c4}},	//   יתי_, stus, дан_, luga_
  { {0x7de70003,0x7ea514c5,0xc3320009,0xf9870012}},	//   _أسام, róps, בוט_, لب_
  { {0xa5640003,0x290f0051,0x6fd80011,0x2d640012}},	//   _مدون, nuga_, नुकू, _مطوّ
  { {0x3ea014b1,0x628614c6,0x291d0034,0x88e30024}},	//   čite_, siko, itwa_, ржре
  { {0x44ef003e,0x8fa60014,0x290f03c2,0x07a602e3}},	//   eż_, таве, huga_, тавн
  { {0x290f0051,0x7aed0002,0x7bdc00c1,0xf2d20009}},	//   kuga_, _łatw, _sfru, _דעה_
  { {0xc5f20009,0x290f005e,0x62840034,0x7e23004c}},	// [2cc0] ידן_, juga_, _imio, јдуж
  { {0xb4db0054,0x20040010,0xad650003,0x6aca0011}},	//   _tràn, ėmis_, دافه, िद्र
  { {0x7d090052,0x753c001e,0x3ead14c7,0x26cb14c8}},	//   hres, ārzi, klet_, _fico_
  { {0x6d44007a,0x290f14c9,0x7d0914ca,0xf98a0012}},	//   _šiam, fuga_, kres, وناي_
  { {0xc05a002d,0x01330003,0xd98d0009,0x290f005e}},	//   дій_, لعود, ּנוֹ, guga_
  { {0xdc080039,0xc013002d,0x7afc0027,0xa7fc003a}},	//   _mēģi, иміщ, _tvrt, _alır
  { {0x7d09000f,0xceba0001,0xba0a0012,0x291d14cb}},	//   eres, мљи_, _يترك_, atwa_
  { {0x539b000b,0x3ead14cc,0xcf930009,0x6e440012}},	//   _חילו, glet_, יטו_, انظم
  { {0x291d0002,0xdd110060,0x27f80159,0x7d0914cd}},	//   ctwa_, _müşe, karn_, gres
  { {0xccf30009,0xa3b90011,0x3ead04e2,0x3e67005e}},	//   סכת_, _चरम_, alet_, _võti_
  { {0x1877000b,0x961d001e,0x7c3c14ce,0xc3340009}},	//   _שעבר_, ciņo, _marr, נוֹ_
  { {0x87170009,0x2179003c,0x55e6004c,0x9e6614cf}},	//   _יקבע_, еймы_, _родб, _швед
  { {0x58870015,0x2ab9000e,0x644e0060,0x5e570009}},	//   выва, jébe_, _onbi, _שידע_
  { {0x3e750119,0x5c73002d,0x8cd60011,0xa3d30048}},	//   _måte_, _кліт, _बढ़ो, _кошч
  { {0x59a5015f,0x6d4600a2,0x54330003,0xd259001e}},	//   _ऐडवर, _arka, _ضرور, _ziņu_
  { {0x644e0052,0x3cfe0037,0x7f3b0009,0x443e14d0}},	//   _anbi, _लिखे_, ועלו, ldt_
  { {0x961d0039,0x44ef0002,0xdd11003a,0x65150012}},	// [2cd0] ziņo, uż_, _düşe, طوائ
  { {0x291e000d,0x3e710028,0x443c08dd,0x443e14d1}},	//   ătat_, _máta_, _jav_, ndt_
  { {0x44e20020,0x3e710065,0x7c3c14d2,0x6d460052}},	//   hư_, _láta_, _darr, _erka
  { {0x69dd000f,0x99840010,0x290f0688,0xf5e40024}},	//   ncse, _namų_, tuga_, _вірм
  { {0x3ead003a,0xc27c000b,0xe8df0081,0x764f0034}},	//   vlet_, וראי, _trọn_, _incy
  { {0x443c0333,0xad1a000b,0xfc640014,0x443e0070}},	//   _nav_, _אושר, _късн, jdt_
  { {0x290f0051,0x291d0002,0x28da0037,0x7e770227}},	//   suga_, stwa_, _यूनि, ëxpo
  { {0x443e0070,0xc1e30321,0x72190009,0x7d0914d3}},	//   edt_, _क्लब_, _רוּח, tres
  { {0x3ead14d4,0x7e6d07cc,0xc0ab0012,0x61ed0097}},	//   rlet_, ikap, _قائل_, ðalu
  { {0x40e8000b,0xd259001e,0x649d0054,0x3e710029}},	//   _יַעֲ, _viņu_, nèix, _dáta_
  { {0x46150012,0xbe150012,0x7c2e005e,0x7e6d12fb}},	//   _موار, _مواع, õbra, kkap
  { {0x32ba0003,0x99160024,0x6e3d0030,0x6d030011}},	//   عددة_, льгі, _nasb, _लिंग_
  { {0xf9920003,0x321e0002,0x9dd6000b,0x7e6d0040}},	//   صبح_, ęty_, _עוסק_, dkap
  { {0x38b60028,0xdfd20003,0x9be7002d,0xe73a0015}},	//   færa_, صير_, _рідк, нег_
  { {0xdc9a000b,0xdbd10051,0x4c9a0009,0xbc1a0009}},	//   _איסל, _müük, _אבסו, _נוקש
  { {0xd7f10020,0x9e750001,0x93bc004b,0x69dd0031}},	//   _dõi_, аћуј, sfăc, ccse
  { {0x261b0037,0xbda50003,0x12a90012,0x657b0032}},	// [2ce0] _यानी_, لحكو, _جدوى_, nzuh
  { {0x3157000b,0x7e6d14d5,0x7e7614d6,0x2ab90031}},	//   _עיין_, akap, shyp, rébe_
  { {0x645c0005,0xa3b90037,0x8e860014,0x629d0025}},	//   örii, _चरण_, _бгне, érog
  { {0x7c3c0614,0x998d0034,0x26da0064,0x20d30011}},	//   _warr, _oceń_, ípom_, _धूँध
  { {0x64430017,0x6a660097,0x0d8304a5,0x7c3c14d7}},	//   ônic, _hófs, _глян, _tarr
  { {0x8d4b000b,0x3e7114d8,0x10a303b0,0x20f20035}},	//   _אֲלֵ, _ráta_, бичн, iņi_
  { {0x87260012,0x7fd70009,0xcf260012,0x2bc30011}},	//   اعتم, נוקס_, ارتي, वेदा
  { {0x9b930003,0x61ed0028,0x443c0027,0xfaa60dd8}},	//   _الفت, ðalt, _sav_, _сабо
  { {0xa2a10044,0x6d4414d9,0x10160003,0x443c0010}},	//   गकर्, nvia, _مباد, _pav_
  { {0xd5c00044,0x1dc00037,0xe8d7000b,0x74140012}},	//   शेषज, शेषत, _עובר_, جودا
  { {0x443e01e4,0x68e4007a,0xfeea0012,0x7e6d020d}},	//   rdt_, _atid, _أعطى_, ykap
  { {0x8f9b0009,0x6f790009,0xdd000060,0x673a001b}},	//   _איבי, _בְנו, ştık, _istj
  { {0x786b0051,0x6d440029,0x9f5100d9,0x1dc00011}},	//   _hüvi, jvia, razí_, शेशत
  { {0x6d3b0093,0x9182001a,0x9f470029,0x60d6003a}},	//   _נתונ, _mềm_, vanú_, _duym
  { {0x9999000f,0xb4c20037,0xb4c00037,0xcebb0001}},	//   reső_, ्दी_, ंगी_, еља_
  { {0x58d50098,0xe80e0037,0x539b0009,0x9f470064}},	//   _коит, _साझा_, _ריהו, tanú_
  { {0x5d550014,0xd7fb004c,0xb4db01a0,0xa5bb0034}},	// [2cf0] шкат, _пун_, _tràm, _zbój
  { {0xd0110003,0x9ed90014,0x673a0051,0x7e6214da}},	//   _بلد_, _имот_, _ostj, _loop
  { {0x649d0054,0xca150048,0x998d0034,0x988c0009}},	//   rèix, иджъ, żeń_, _רָחֵ
  { {0xeb91000b,0xe3c40012,0x8bc4003c,0xbddb01a0}},	//   חָד_, حْمَ, ссуд, _enèr
  { {0xc5fa000b,0x8dfa000b,0x61f914db,0x95670048}},	//   _בפרט, _שהשת, rawl, _сънд
  { {0x21660001,0xd0060048,0x1bd404ac,0xa3d40217}},	//   риши_, аеше_, _горя, _горч
  { {0x61ed0028,0xdc9a0009,0xcee80012,0x4c9a0009}},	//   ðals, _יישל, هرين_, _יבשו
  { {0x39490101,0x0f58000b,0xa2950024,0xfde60048}},	//   _oras_, ריהם_, _табі, адък_
  { {0xd455002d,0x7ae4058a,0x7d0d004e,0xb4c20011}},	//   атнь, _čita, nras, ्दू_
  { {0xddc40073,0x4c6900b5,0x69a90011,0x4b250d7c}},	//   nkiš, тион_, _घड़ी, амов
  { {0xe1ff003e,0x96550014,0x3a3f14dc,0xa0c40012}},	//   nków_, _вълч, _kaup_, _ايلو
  { {0xa96a0046,0x216a002d,0x39490061,0x7d0d0755}},	//   вима_, вими_, _bras_, kras
  { {0xe2970075,0xee780003,0xec6e01b6,0x9975004c}},	//   рая_, _حصلت_, _дп_, бурш
  { {0xd4660046,0xb4fa0093,0x6d4400c1,0xd00f0003}},	//   _више_, _ספצי, vvia, ولُ_
  { {0xe8170037,0x8c1a0009,0x6ec60012,0xe7e50011}},	//   _तारा_, _יוסי, لترق, कड़ा_
  { {0x539a0214,0xcce60003,0xe1ff0002,0x7afa0028}},	//   _ביצו, لسطي, dków_, _ætti
  { {0xf652000b,0x9f450029,0xd4da002d,0x628b0d85}},	// [2d00] חצן_, _celú_, тьбі_, digo
  { {0xe0fb0093,0x628b0010,0x78fb0009,0xec7714dd}},	//   _שליל, eigo, _שליפ, апу_
  { {0xdddd000f,0x0ca90003,0x2bab0037,0x2abc01e3}},	//   _első, اطقي_, _घुमा, híbe_
  { {0x6da6002d,0xd36f0003,0x8b650003,0x9f4c01e9}},	//   _вима, بهم_, حاكم, _nedá_
  { {0x29000017,0x90c6035c,0x9f4301e3,0x7a460031}},	//   éia_, абде, bajó_, jétő
  { {0x201814de,0x201a0051,0xf1a90003,0x3eb2004a}},	//   ngri_, üpi_, دامه_, llyt_
  { {0xa067004c,0x628b14df,0x26cf020d,0x644114e0}},	//   раја_, bigo, _bigo_, ddli
  { {0xeb97007c,0x224000c6,0x64410052,0x290c0002}},	//   _тис_, _naik_, edli, ądaj_
  { {0xdcba002d,0xd5b7064f,0x61ed0164,0xb9290012}},	//   кщо_, ись_, ñale, _مثلك_
  { {0xb4c00044,0xceea002d,0x9169001a,0xb4c20037}},	//   ंगे_, _адже_, _lựa_, ्दे_
  { {0x224000c6,0xf8bf0061,0x36060003,0x3e75006f}},	//   _baik_, ntée_, _نواف, _låta_
  { {0x1bf20037,0xf8bf0025,0xfe790030,0x6fb30012}},	//   _आजकल_, itée_, chů_, _بمما
  { {0x867b0009,0x265b0009,0x50670048,0x78700248}},	//   _בראו, _שכדא, атва, _tävl
  { {0x5d7b000b,0x27fc038e,0x4d7b000b,0x39460017}},	//   _שָׁנ, navn_, _שָׁא, ivos_
  { {0x06fd0066,0x94bb0009,0x1cbb0009,0xa8570009}},	//   žívá_, _שמות, _שמוע, סילה_
  { {0x394902d1,0x8f9b0009,0xaa2d008e,0xf7770009}},	//   _tras_, דילי, ämää_, בעלי_
  { {0x9169001a,0x6ac40003,0xb2bc0009,0x05a70011}},	// [2d10] _dựa_, _بقيم, _במהר, _कुशब
  { {0xc3cb0003,0xe1ff0002,0xeaca001a,0x25bd0060}},	//   نظام_, tków_, _hẹp_, _ızlı_
  { {0x628b0149,0x309a000b,0x99d50012,0x389c0009}},	//   tigo, _תשתמ, مقات, _ביזנ
  { {0xde59002d,0x7d0d14e1,0x8f360009,0xda080012}},	//   _самі_, pras, _פארו_, ليمه_
  { {0x394902d1,0xe1ff0002,0x95cb0001,0x6441100c}},	//   ías_, sków_, _јуна_, ydli
  { {0x753d000e,0xb4c00011,0xd7f10081,0x22920159}},	//   _issz, ंगो_, ữu_, mške_
  { {0xf8bf0025,0xb21b0097,0x6d400097,0x83340012}},	//   ctée_, mhæf, _ámar, _ورفض
  { {0x2f98000b,0x2a64000e,0x7c2a0052,0x1798000b}},	//   יכון_, _gomb_, _abfr, ידול_
  { {0xc212000b,0x88070003,0x61fd0060,0x99850012}},	//   _מהן_, _نظام, dasl, _الذو
  { {0x3e710026,0x7d020604,0x98170012,0xd5780009}},	//   _táto_, _dvos, _خبرا, יתחה_
  { {0x69cb0037,0x7c640012,0x5f740012,0x9f580025}},	//   _तृती, تايل, _وامر, paré_
  { {0x6f1502d1,0xc869000b,0x272114e2,0x2d7f0034}},	//   duzc, _אן_, món_, _płeć_
  { {0xeaca0081,0x2c690064,0x272114e3,0xa3d70011}},	//   _dẹp_, _súdu_, lón_, ाखा_
  { {0x6ca40012,0xec780024,0x05a80024,0x9f430097}},	//   _وصول, _кпі_, _твій_, _þjó_
  { {0xb21b0058,0x66e609cc,0x753d0031,0x84560009}},	//   dhæf, соба, _assz, _לבסס_
  { {0xbda60003,0xaad00011,0xd1320012,0x39460073}},	//   محذو, _सूचक, _فمع_, yvos_
  { {0x442a00b6,0xee370001,0xed5704ac,0xba170009}},	// [2d20] _pbb_, љну_, бот_, _החפץ_
  { {0x98a90010,0xa3ab0011,0x290214e4,0x74160012}},	//   _ypač_, कअप_, mska_, صوصا
  { {0x272114e5,0x5f460012,0xf8bf0025,0x7fd70009}},	//   jón_, _انجل, utée_, _לויס_
  { {0xfad60093,0xf1fa000a,0xd7bb000b,0xd9fa0037}},	//   צונך_, اعات_, _תצטר, ्णित_
  { {0x186a0dc2,0x290214e6,0x61140024,0xf8bf0025}},	//   лади_, nska_, ідку, stée_
  { {0xf8bf0061,0x2721134c,0x76440060,0xa967004c}},	//   ptée_, fón_, ldiy, сиља_
  { {0x5f43000a,0x444400c7,0x290f01eb,0x272114e7}},	//   كنول, md_, arga_, gón_
  { {0x2296000a,0x32960003,0x3ea000eb,0x76440060}},	//   _الرس, _الرأ, čito_, ndiy
  { {0x61fd000f,0x99920002,0xb5fd001e,0x752414e8}},	//   vasl, żył_, ekšs, ntiz
  { {0xd6d2000a,0xb8650003,0x61e206b5,0xe56f0012}},	//   _فقط_, _والو, lcol, عطي_
  { {0x444414e9,0xaf9a0024,0xd00f0012,0x7e2a0024}},	//   id_, _стах_, _ألم_, _біла_
  { {0x6d440010,0x0bb7000b,0x539b000b,0xb5fd0010}},	//   _šiau, מלים_, ריטו, ukšt
  { {0xd5a70037,0x61fd017b,0x05a70011,0x76440060}},	//   _कुंज, rasl, _कुंब, ddiy
  { {0x444400bd,0x2d8004fa,0x69d6000e,0x8cd30011}},	//   jd_, dzie_, _egye, _भूगो
  { {0x7e66006f,0x1bfb000b,0x4fc400ac,0xaae60003}},	//   _bokp, _גלוב, зста, _استو
  { {0x6397000b,0xd6d801d4,0xa1950048,0x5f9414ea}},	//   _לדוא_, стр_, _майч, чист
  { {0x27210164,0x44440070,0x2d580055,0x9f4701bd}},	// [2d30] zón_, fd_, бить_, daný_
  { {0x444414eb,0xaae70003,0x80dc0037,0xebc70001}},	//   gd_, مسؤو, _पढ़े, бљен
  { {0xb21b0028,0xb5fd04d2,0x57fa0009,0xdb510012}},	//   rhæf, ljše, _דלתו, بَا_
  { {0xdb1f0028,0x656d002c,0x73c40003,0xf1bd0037}},	//   _ávís, pyah, سينم, _ईरान
  { {0xb5fd09d2,0x89370012,0x290f14ec,0x444414ed}},	//   njše, إعصا, urga_, bd_
  { {0x272102d1,0x07390003,0xcee90015,0x61e200b8}},	//   tón_, لسبب_, адке_, acol
  { {0x6d47001e,0xe7080012,0xcf240012,0x645514ee}},	//   ājam, متين_, كريي, _inzi
  { {0x61e201a2,0xb5fd001e,0x272114ef,0xc1050012}},	//   ccol, ekšr, rón_, _ووزي
  { {0x628f14f0,0x272101e3,0xec7914f1,0xb5fb14f2}},	//   dico, són_, ипи_, _bláz
  { {0x7305007c,0x917a001a,0x3209003a,0x272114f3}},	//   опоз, hập_, _aday_, pón_
  { {0xf412000b,0x29020002,0x8c1a000b,0xe3b10003}},	//   ופי_, wska_, בותי, برة_
  { {0x5cf5002d,0xd57501d4,0x290211f9,0xc2c60012}},	//   _дяку, _муль, tska_, تيجي
  { {0xd5480003,0xddc20029,0x29040bb3,0x787001a3}},	//   _هجوم_, _zlož, éma_, _hävi
  { {0x38b600c5,0x78700006,0x9f4701e9,0xd0120012}},	//   mærk_, _kävi, zaný_, بلس_
  { {0x44440348,0xe73a025c,0x6d4914f4,0xe81c0011}},	//   vd_, шев_, lvea, _नासा_
  { {0xee3a0001,0x661b0289,0x44440644,0x645514f5}},	//   јна_, nguk, wd_, _anzi
  { {0x7fd6007c,0x64430101,0x9f4700f1,0xa3c30037}},	// [2d40] _міні, _kani, vaný_, ्शक_
  { {0x2d800026,0x752414f6,0x44440b6a,0x93260012}},	//   rzie_, rtiz, ud_, قرصن
  { {0xe2860047,0x673e001c,0x6a860015,0xd2aa0015}},	//   олжи, _uspj, олжа, акже_
  { {0x9c870066,0x539a000b,0xe5670012,0x72290024}},	//   _počá, ביעו, _قط_, йців_
  { {0x01360003,0xa50a0001,0xdb070066,0xddc212b0}},	//   تعاد, _њега_, _vyjá, _slož
  { {0xc173000b,0x1df20037,0xb87b0066,0x644314f7}},	//   וחד_, घर्ष_, spív, _nani
  { {0x8b230046,0xd6d70015,0xea5a0001,0xdfcf0003}},	//   _одре, оты_, _крај_, نيه_
  { {0x3e78000e,0xddc214f8,0x9e660012,0xba1a0012}},	//   _béta_, _vlož, تاتن, _خيرا_
  { {0x3eb8001e,0x9f580029,0x91030001,0xe4c6003c}},	//   ērt_, darí_, _опте, жённ
  { {0xf8780009,0x67560012,0xdca3004c,0x628f0034}},	//   _פְּל, _وخار, мањи, wico
  { {0xee3a0015,0xddc214f9,0x33db0009,0x7bdb0009}},	//   _вне_, _ulož, יחיד, יקיו
  { {0x7d0414fa,0xdb21000e,0x9f4c004a,0x7f3b000b}},	//   ksis, étét, _vedä_, _כעבו
  { {0x212600c6,0x66d50010,0x22460002,0x394d01e3}},	//   ntoh_, _iška, idok_, íes_
  { {0x64430101,0x3ea90d6c,0x8c430001,0xdfd80014}},	//   _gani, čate_, _жеље, жът_
  { {0x64430017,0x628f0e0a,0x4e8b0048,0xfe730012}},	//   ônim, pico, ащам_, ودر_
  { {0xcb130093,0x6609001e,0x66000a12,0x6b7b0009}},	//   _חלק_, _ķeks, namk, _כרונ
  { {0x7d040101,0x95cb0014,0xdddd0002,0x9d15002d}},	// [2d50] gsis, рува_, _posł, ядач
  { {0x61fb0108,0xfc330003,0x18680001,0xa0680001}},	//   _seul, بحر_, _мањи_, _мања_
  { {0x2c180011,0x44e00081,0x68e914fb,0x6600016d}},	//   _दाईं_, _lò_, _sted, kamk
  { {0x05870046,0xa4d5002d,0xc175000b,0x9f4501bd}},	//   _дугм, _номі, ּחַ_, _celý_
  { {0x9e5a000b,0xd2b8000b,0xd13b066f,0x865a0009}},	//   _הכרט, קלדת_, рхе_, _הדרי
  { {0x68e90029,0xe042002d,0x3e7c0066,0x21580003}},	//   _vted, енши, _víte_, تجمع_
  { {0xf771000a,0xa08c000b,0x68e90002,0x644314fc}},	//   عات_, יְהִ, _wted, _rani
  { {0xe1ff0065,0x394d14fd,0x05650594,0x4f9c0009}},	//   _þó_, _tres_, звин, יבוצ
  { {0x79820656,0xfd110003,0xceb4000b,0x644314fe}},	//   czow, رجة_, ויק_, _pani
  { {0xe8200037,0x3b850001,0x44e0001a,0x03d50009}},	//   _बाधा_, злог, _dò_, ּוֹם_
  { {0x2292007a,0xcf780012,0x11d60024,0x3b09004c}},	//   eška_, _وإما_, зігр, љемо_
  { {0x67ba000b,0x644300b6,0x5fba0009,0x7d0414ff}},	//   _המעק, _wani, _הצענ, ysis
  { {0x2bb80037,0xcdf6000b,0xa7fc003a,0x4dda0009}},	//   _अर्थ, _זמני_, _alıy, _החנו
  { {0xb87b0029,0x7ae9024e,0xdd940012,0xb7da0012}},	//   dpís, _četn, _تجمع, صورا_
  { {0x6e2f0017,0x9bfa0009,0x7bfa0009,0xeb9603b0}},	//   _bbcb, _ההצט, _הפצצ, _ниш_
  { {0x3e6e0065,0xc7b2000b,0xb9060014,0xe9a6002d}},	//   _nýtt_, גבל_, _език, _найп
  { {0xceb2000b,0x3ae10028,0x621b0009,0x721b0009}},	// [2d60] תין_, _hóp_, _הופק, _הופח
  { {0x14d60009,0xf507003c,0xb5640009,0x7d041500}},	//   פועל_, янул_, וֹעַ_, rsis
  { {0xe7db000b,0xb7db0009,0x3fdb0009,0x6fdb0009}},	//   _לקיש, _לקיי, _לקיב, _לקיס
  { {0x8289002d,0xf8bf000e,0xfaa300b3,0xf09f01a0}},	//   осіб_, ntén_, нахо, bràs_
  { {0x25d7000b,0x2246000e,0xda650012,0x3ead0227}},	//   _מוכן_, rdok_, بالي, doet_
  { {0x91bb000b,0x38b60028,0xf7720003,0x55bb000b}},	//   זמני, færi_, فاع_, _למכו
  { {0xa3ab0044,0x9f580054,0x79820002,0x90290012}},	//   _कुल_, narà_, szow, تأنف_
  { {0x3ead0058,0x8b9b000b,0x139b0009,0xe39b0009}},	//   goet_, _הבלת, _הבלע, _השלכ
  { {0xa3c90037,0xfaa30a32,0x66001501,0x89eb00af}},	//   लेस_, _чато, ramk, _הַבֵ
  { {0x95880002,0x66000052,0x1ab70037,0xb1170003}},	//   ciąż, samk, ृष्ठ, _رقما_
  { {0x59a50037,0x4adc0037,0xe215003c,0x443a0227}},	//   _गुजर, यदिव, ммны, iep_
  { {0x9f580054,0x11d90003,0xa75b0009,0x2919139a}},	//   darà_, توحة_, _לדבר, tusa_
  { {0x3d130044,0xc05b002d,0x1ea90012,0x443a016d}},	//   _दिये_, бів_, _بالي_, kep_
  { {0xdd3b000b,0xc19b0009,0x4ee70024,0xa3cd0011}},	//   _לעדכ, משכי, зіаз, शेड_
  { {0x3ae1001a,0x57a40001,0xb5fd048b,0x9f580054}},	//   _góp_, ешта, ljša, garà_
  { {0x2919000e,0xfbb7000b,0x2906004a,0x539b0009}},	//   pusa_, _מפות_, ksoa_, _ליוו
  { {0xb5fd009b,0x2d580109,0xe5340024,0x98cc0011}},	// [2d70] njša, пить_, неть, ाषाए
  { {0xebc70001,0x9f5801a0,0x7c970012,0x19b80012}},	//   пљен, barà_, أشرا, _عطية_
  { {0x9f580054,0x04c80012,0x69c01502,0x99820073}},	//   carà_, أولي_, _azme, bekų_
  { {0x63b50042,0x629d00b0,0x2003008e,0x8b3b00af}},	//   _vyzn, nnso, laji_, מתבצ
  { {0x63b50002,0x443a003a,0x26de1503,0xc1040012}},	//   _wyzn, bep_, _auto_, فوني
  { {0x9f580b45,0x89a80024,0x8d5a0009,0x2d840064}},	//   lará_, чків_, _וכשי, dzme_
  { {0x61e6006f,0x22950048,0x6d4d0d78,0x9f4a0031}},	//   yckl, _живя, lvaa, obbá_
  { {0x95880002,0x9f580d85,0xece91504,0xa3c20011}},	//   siąż, nará_, одил_, ्धन_
  { {0x644700b6,0x200300b6,0xf2d20009,0x3ead13af}},	//   _kaji, kaji_, _יעל_, roet_
  { {0xeb990001,0xc1040012,0xcc890024,0x1309003c}},	//   жио_, _أولي, ібне_, оной_
  { {0x2909004a,0x3e7c0028,0x9f580054,0xe8170037}},	//   _avaa_, _líta_, xarà_, _ताजा_
  { {0x6447004a,0x9f581505,0x6d4d005e,0x6ee70060}},	//   _laji, varà_, kvaa, _tıbb
  { {0xda1f0044,0x764600c6,0x5d690294,0xe8f7027f}},	//   _भारत_, _raky, _филм_, мля_
  { {0x9f580054,0xe5880009,0x76460073,0x61e90031}},	//   tarà_, _מָצָ, _saky, _lfel
  { {0xa0880009,0xe7270012,0x8b940048,0xd00f0012}},	//   פְשִ, خص_, _пръч, ؤلف_
  { {0x9f581506,0xfbd20009,0x8afa0009,0x76490060}},	//   rarà_, _בתו_, _והקי, ndey
  { {0xdb0e0066,0xb2290003,0x9f580054,0xc6920009}},	// [2d80] _vybí, _رأيك_, sarà_, דאן_
  { {0xe73a0046,0x28e10037,0x61e900c1,0x3ea00082}},	//   _део_, _पढ़ि, _afel, čiti_
  { {0xab270867,0x0ae90012,0x6d4d008e,0xb87b0097}},	//   доха_, كرني_, avaa, ppír
  { {0x99dd022d,0x7d1b019a,0x9f58052e,0x2906008e}},	//   _daňo, kuus, cará_, tsoa_
  { {0xa2b50037,0xa967035c,0xd1300012,0xda650012}},	//   ेषज्, мица_, امت_, عامي
  { {0x66041507,0xd6ea0103,0x3ead0c82,0xd7ef0012}},	//   laik, офил_, čete_, لكه_
  { {0xdfd0000a,0x57fb000b,0x29060017,0x8a060001}},	//   ديث_, קלקו, ssoa_, _озве
  { {0x64470013,0x941e0037,0xc9560015,0x66041508}},	//   _zaji, _पाँच_, _отзы, naik
  { {0xceb30009,0xf1a80011,0x69c0013c,0x66d50073}},	//   כיה_, _छँटन, _uzme, _iškl
  { {0x3e780013,0x26de0145,0xb4b80037,0xf55b000b}},	//   _této_, _tuto_, चते_, קדימ
  { {0x6e47006f,0x6d5d1509,0xd62a150a,0x24170009}},	//   örbä, äsar, _може_, וחין_
  { {0x6f1c008b,0xed5a0063,0x6604150b,0x6282150c}},	//   durc, _мое_, jaik, nhoo
  { {0x984b0014,0x7529000d,0x1ea90012,0x941e0011}},	//   оява_, ctez, _عامي_, _पांच_
  { {0x656f0052,0x55bb0009,0x27170081,0x7bdc016d}},	//   äche, _ומדו, ũng_, _ngru
  { {0xf413000b,0xd0d40014,0xe2ab0003,0x9f58052e}},	//   _ספק_, торъ, _وابن_, tará_
  { {0x4ea40014,0x9f5c0029,0x6d4d0070,0x644700b6}},	//   вруа, javí_, tvaa, _saji
  { {0x9f580d85,0x81fc0009,0xdd94003c,0x9e080012}},	// [2d90] rará_, _והחז, ваты, بيقك_
  { {0x31560093,0x3e710065,0x9f5801c5,0x76490060}},	//   _ניתן_, _hátt_, sará_, zdey
  { {0xf8bf0017,0x6604055c,0xdee70012,0x82150012}},	//   ntém_, baik, _تأخي, فواص
  { {0x644700b6,0x44e4006f,0xfd5e001a,0x8f1a0009}},	//   _waji, _fö_, _quyể, _צורת
  { {0xc6160093,0xeab00003,0x22490070,0x3e710028}},	//   _אחרי_, جعل_, _maak_, _mátt_
  { {0x7d1b004a,0x91780009,0xc0c8004c,0x34fa00af}},	//   vuus, ועדף_, мује_, _מהשד
  { {0xfd5e001a,0x20010051,0x38b60192,0xcb690012}},	//   _tuyể, _mehi_, mært_, _عمره_
  { {0x752900c1,0x7d1b004a,0x060903e2,0x38b60262}},	//   ttez, tuus, чник_, lært_
  { {0xf5480020,0x8c95002d,0x78f80012,0x41770012}},	//   _cụ_, ерні, _يعكس_, _غارس
  { {0xf5480020,0x2db8000b,0x00d80003,0x7529150d}},	//   _dụ_, ולחן_, _قبلت_, rtez
  { {0xa3c90044,0x7d1b004a,0xe667010c,0xe8d60009}},	//   लें_, suus, _отдо, _נוער_
  { {0x26d9012e,0xbbdc0037,0x6e450012,0x9f580097}},	//   _niso_, _बल्क, _سنتم, _þrá_
  { {0x6119000b,0xceb20009,0xfe790030,0x6604150e}},	//   הוָה, _גיא_, mků_, vaik
  { {0x2d940002,0xfe790030,0x38a90064,0x2a6d0b5e}},	//   ódeł_, lků_, túry_, _loeb_
  { {0x2baf0044,0x6604069c,0x9be4002d,0x7e56013b}},	//   _जुला, taik, _річк, нтац
  { {0x9f5c014d,0x683300a2,0x9f9b005e,0xfe790030}},	//   _því_, lıdı, määr_, nků_
  { {0x7d09150f,0x38b60028,0x5a9b0009,0xd10a0012}},	// [2da0] nses, fært_, _משקא, _عقده_
  { {0xe72a0014,0x69c4001e,0x7d09015e,0x6833003a}},	//   _еоод_, _izie, ises, nıdı
  { {0x6bd70003,0xbfa3001a,0x7aeb004b,0x66041510}},	//   فوكس_, uyế, _întă, paik
  { {0x7d0903fc,0x23660027,0xdceb003a,0xb906003c}},	//   kses, ćoj_, _çiğn, ездк
  { {0xfe790013,0x9f5c00d9,0x62820be9,0x75d60012}},	//   dků_, raví_, rhoo, _سيسا
  { {0x6d46102b,0x9fe60012,0x3b0a0426,0x3ea01511}},	//   _iska, رسته, _него_, lnit_
  { {0x501b000b,0x645c02f1,0x64a31003,0xbcb70009}},	//   לוסו, _inri, _сара, _נפלו_
  { {0x1d340014,0x3ea01512,0x02d60012,0x9f5e0025}},	//   вния, nnit_, _ستأخ, _jeté_
  { {0x62800006,0xfe37000b,0xb21b0058,0xd6220024}},	//   _ilmo, גרפי_, fhæn, _фiна
  { {0xf5480020,0x3e710097,0xa9230073,0xa3d40048}},	//   _vụ_, _sátt_, ėžta, копч
  { {0x69c400c1,0x7c3e0f62,0xfe790030,0x9c0b00af}},	//   _azie, iepr, bků_, הִכִ
  { {0xd62a0015,0xc333000b,0xf548001a,0xa2950024}},	//   _ходе_, נור_, _tụ_, тамі
  { {0xc05b002d,0x63860061,0x22490070,0xf8bf00f1}},	//   пів_, _béné, _vaak_, stém_
  { {0x69c4003e,0xf7730012,0x3ea01513,0xba3b0025}},	//   _dzie, هاز_, čitu_, roïq
  { {0x60da0005,0x270c0066,0xf8bf000e,0x9f34002d}},	//   _mitm, něn_, lték_, лері
  { {0x62670003,0x644a1514,0x3bbb000b,0x03bb0009}},	//   _سابق, _hafi, _ממוד, _מצול
  { {0x443e0070,0x5ff50014,0x644a1515,0x26d91516}},	// [2db0] oet_, _изпу, _kafi, _viso_
  { {0x44210036,0x63860108,0xad9d0002,0xfe790066}},	//   ugh_, _géné, kaźn, zků_
  { {0x443e00bd,0x57670003,0xa3c20037,0xe4a40560}},	//   iet_, _أدخِ, ्धि_, урто
  { {0xa3cd0044,0xd9990003,0x25b90003,0x7afc000e}},	//   शेष_, ونات_, _يهدد_, árty
  { {0xfe790066,0xd9450146,0x443e1517,0x7c3e0010}},	//   vků_, тели, ket_, bepr
  { {0x22490027,0x1d16000b,0x443e1518,0xa3c20011}},	//   žak_, _בקשר_, jet_, ्धा_
  { {0xfe790066,0x8aa70024,0x6bd70012,0xb4bd0011}},	//   tků_, _зрад, _ستسر, आती_
  { {0x7d090005,0x443e1519,0x57de0011,0x752d151a}},	//   tses, eet_, _मल्ह, otaz
  { {0x752d01a2,0x290b0002,0xe5710003,0x443e151b}},	//   ntaz, jsca_, شطة_, fet_
  { {0x60da003a,0x3ea00066,0x5d480009,0xfe790030}},	//   _gitm, znit_, תָהּ_, sků_
  { {0x8c3c00a2,0x6ee70003,0x6833003a,0xb35f0024}},	//   toğr, _أسئل, rıdı, имiщ
  { {0x7c3e151c,0x6833003a,0x8bd60009,0xaf340012}},	//   zepr, sıdı, כותו_, _حركت
  { {0x63860061,0x3ea00066,0x443e151d,0xb1430a32}},	//   _péné, vnit_, bet_, анял
  { {0xd7f20003,0x6143004c,0x62880073,0xd943004c}},	//   شكر_, јера, _įdom, јери
  { {0xc0030001,0x66e605f7,0x2919151e,0x63860025}},	//   рпск, тоба, arsa_, _véné
  { {0x2007151f,0xd3360009,0x6d4603d3,0xb9960012}},	//   hani_, _ירצה_, _pska, _للعب
  { {0x7ae31520,0x7c3e1521,0x1d070662,0xe4e50024}},	// [2dc0] _hunt, tepr, кети_, гієн
  { {0x9177000b,0x3ea01522,0x3e7c0029,0x764b002c}},	//   _סעיף_, snit_, _títo_, _lagy
  { {0x6d46003e,0x290d007d,0x68e400bd,0x73360003}},	//   _wska, _avea_, _huid, ضرائ
  { {0x68e40005,0x443e1523,0x35fa0012,0xa1f70012}},	//   _kuid, zet_, _تردد_, نّما_
  { {0x443e1524,0x99340012,0x7e6913c3,0x7ae31525}},	//   yet_, افتت, djep, _lunt
  { {0x443e1526,0x68e40038,0x3cfb0011,0xd00f0012}},	//   _út_, _muid, _लौटे_, قله_
  { {0x68e40227,0x443e1527,0x81fa0012,0x6602005e}},	//   _luid, vet_, _يفسر_, _peok
  { {0xf8bf000e,0xad9d0002,0x6d440002,0x443e1528}},	//   tték_, raźn, owia, wet_
  { {0x48e6007c,0xc6930093,0xc0e6002d,0x7ae90027}},	//   _розв, יאה_, _розк, _četi
  { {0xa0c90003,0x54530015,0xf8bf000e,0x60da0070}},	//   _كذلك_, авьт, rték_, _uitm
  { {0x66020006,0x8c1b000b,0x57fb0009,0x443e1529}},	//   _teok, וויי, _חלבו, ret_
  { {0x92580015,0x443e152a,0x68e40685,0xbb93003c}},	//   вают_, set_, _buid, рающ
  { {0xc0970012,0x3e750248,0x644a0097,0x443e152b}},	//   نجست, _mått_, _tafi, pet_
  { {0x8438000a,0xa8a40146,0x68e40070,0xcb540012}},	//   _أكثر_, арск, _duid, _منتظ
  { {0x66c5000e,0x138a0012,0xa7d40012,0x7ae300b1}},	//   lóka, _تخشى_, لتفص, _gunt
  { {0x0bb70093,0x645d0039,0xa3d60037,0x2ebf0037}},	//   _שלהם_, ēsie, ाइन_, ्षेत
  { {0x5187002d,0x764d00b6,0x2007010a,0xd7fb0198}},	// [2dd0] _шука, rday, yani_, _оун_
  { {0x1acb0037,0x4427003a,0x752d152c,0xfdc30011}},	//   िष्ठ, ün_, rtaz, _शरीफ
  { {0x752d01a2,0x68e40070,0xf4130009,0xa3cd0011}},	//   staz, _zuid, שפע_, शें_
  { {0xc333000b,0xdcf70003,0x20070bca,0xcf560009}},	//   יוע_, _لأسب, wani_, _עברת_
  { {0x95640014,0x2007152d,0xae1a0009,0x361a0009}},	//   _кърд, tani_, _אורכ, _אורד
  { {0x66d50010,0x34950001,0xb97c0009,0xbae50012}},	//   _iški, _сагр, ונדי, _مكسي
  { {0x2007152e,0x9f51000e,0xe7080003,0x3e75152f}},	//   rani_, mazó_, نتين_, _fått_
  { {0x39490051,0xc1050003,0xdb25000e,0x78b5000e}},	//   _osas_, _موري, épít, hozv
  { {0xdd1200a2,0x7ae3007d,0x7e690cb1,0x95550012}},	//   _müşt, _sunt, rjep, اخبا
  { {0x62990002,0x9b150009,0x1abe0011,0x7ae31530}},	//   liwo, ְחָה_, ोष्ठ, _punt
  { {0x6d440034,0x6d460097,0xc7590035,0x8b640012}},	//   zwia, ækar, šībā, لاَم
  { {0x95550003,0xc049000b,0x8f88000b,0xcb360009}},	//   _مختا, _מז_, _בְנֵ, נארי_
  { {0x20050b86,0x72b60009,0x44270081,0x9f580025}},	//   _keli_, רִיב_, _tcn_, mbré_
  { {0xad1a000b,0x3ebf1531,0xd3780002,0xc4840024}},	//   _נוצר, llut_, być_, _клік
  { {0xe29a09f0,0xa3c90037,0x39491532,0x8cb90011}},	//   _пак_, लेख_, _esas_, ्तनो
  { {0x539a0009,0xdd920012,0x6d440034,0x26dd016d}},	//   _ריקו, موز_, twia, _jiwo_
  { {0x7d0d0101,0xee5c0028,0x6c1a0012,0x98c30011}},	// [2de0] gsas, æðið_, فتاح_, षताए
  { {0x76400002,0x20050051,0x6d440034,0x5046004c}},	//   zemy, _neli_, rwia, _сеоб
  { {0x61e9009b,0x9bc90009,0x6e2e0031,0xaae50012}},	//   žele, תֶּ֖, őbbi, لسنو
  { {0xa3ab0044,0x644107f6,0x479b0009,0xd67a0012}},	//   _कुछ_, heli, _טייס, _أحدا_
  { {0x44e90065,0xd378003e,0xf2d30009,0xa9960012}},	//   _nú_, zyć_, צעד_, دشات
  { {0x7ae90027,0xc3060003,0x200a002c,0x64411533}},	//   _četv, _مبرو, nabi_, jeli
  { {0xeef6000b,0x31790002,0xd6da1534,0x7d1b1535}},	//   אמֶר_, zysz_, нти_, erus
  { {0x66c5000e,0x9b930012,0x224200b0,0xb5fb0420}},	//   tóka, _طلقت, jekk_, _inác
  { {0x49ca0046,0xd24f0003,0xe29b000b,0x44e9001a}},	//   _члан_, _عنك_, _נשמר, _cú_
  { {0x27f70145,0xb8ea0037,0x64411536,0x66061537}},	//   čení_, ोष_, geli, _lekk
  { {0x644e0101,0xa4b7000b,0xa857000b,0x26c00010}},	//   _mabi, רליה_, _תיבה_, klio_
  { {0x66c5000e,0xf127002d,0x35fa0003,0x7d0d004a}},	//   lókn, льго, _أراد_, ysas
  { {0xa3d60037,0x443800d9,0x85760012,0xd3780034}},	//   ाइड_, _obr_, _حدائ, syć_
  { {0xac181128,0x64411538,0xf1b30009,0x230a0012}},	//   _року_, celi, מסר_, _كتبي_
  { {0xdfd50015,0xbca30012,0x66190034,0x78b50482}},	//   ровы, _دموي, ówko, rozv
  { {0x26c001a2,0x7d0d00ff,0x758b0024,0x20050034}},	//   glio_, tsas, нсзв_, źli_
  { {0xe2140003,0x65150003,0x66061124,0x320b0132}},	// [2df0] _طبيع, شوائ, _dekk, macy_
  { {0x45b80015,0x7d0d1539,0x2dd80012,0x320b0034}},	//   угую_, rsas, طبقة_, lacy_
  { {0x7d0d0006,0x6284004a,0x66d50010,0x8c1b0009}},	//   ssas, _ylio, _iškv, תובי
  { {0xd357000b,0x41550109,0x01d90012,0x32b80012}},	//   טיבי_, ивес, نواع_, هدنة_
  { {0x6441003a,0xa1580024,0x98a20034,0x9f5e0064}},	//   yeli, лацу_, stką_, _detí_
  { {0x7e6d0051,0xfc670014,0xdc1e0037,0x8f150e8a}},	//   ljap, _съмн, पलोड_, афич
  { {0x44e9153a,0xb5fd009b,0xfe710003,0x18780009}},	//   _sú_, ljši, قدة_, רעור_
  { {0x64410070,0x7be3003a,0xfe710012,0xcee80012}},	//   weli, ştuğ, تدت_, درون_
  { {0x26c30039,0x78270003,0xc4850001,0xc68e0003}},	//   ējo_, _معال, илик, بِي_
  { {0x9984000a,0x98db0003,0x3ebf153b,0xec76003c}},	//   _الكو, _أبرز_, slut_, ипы_
  { {0xc169000b,0x200a009b,0x626602ad,0xebd70009}},	//   _קח_, vabi_, авна, נֵ֖י_
  { {0xc5d5007c,0xeb960015,0xa5f90001,0x93b60009}},	//   _кіль, рию_, _реду_, ילתו_
  { {0x2731008a,0x66060033,0x200a002c,0xa3c90037}},	//   _hơn_, _rekk, tabi_, लेज_
  { {0x66060269,0x960e0011,0x6d59016d,0x224212e8}},	//   _sekk, िण्ट_, _irwa, sekk_
  { {0x672300c6,0xd0070a15,0x200a0d6c,0xb4c30037}},	//   nunj, ресе_, rabi_, ्षी_
  { {0x66c501c4,0x200a14d5,0x320b0132,0x6d590034}},	//   ióko, sabi_, cacy_, _krwa
  { {0xb2bb000b,0xa2bb0009,0x6cd60012,0x98a60024}},	// [2e00] _במקר, _במקט, لقرا, _випе
  { {0x4463007c,0xf8bf0061,0x26c0001b,0x6723016d}},	//   овув, tuée_, slio_, kunj
  { {0x66060005,0x644e012e,0x57fb000b,0x0b46077e}},	//   _tekk, _vabi, _שלטו, рнен
  { {0xb4c10037,0xc217002d,0xba170012,0xd2590024}},	//   ंतु_, аєш_, ليما_, лці_
  { {0xa06a0001,0x656f0052,0x66c5000e,0x11540055}},	//   када_, ächl, tókn, склю
  { {0x57f30001,0xf7720012,0x3e780097,0x2baf0011}},	//   општ, قاع_, _létt_, _जँचा
  { {0x61e40163,0xa7b80047,0xf8bf0061,0x2731001a}},	//   _ogil, ылку_, quée_, _cơn_
  { {0x66c50028,0x2baf0011,0x9df70048,0xfaa600f4}},	//   sókn, _जुटा, анът_, _табо
  { {0xf5360009,0x42530012,0xd5b00012,0x54b80048}},	//   ׁנֵי_, _بنقر, ثفة_, лгия_
  { {0x14180003,0x6723001b,0x44380097,0x84330024}},	//   ديدة_, bunj, ýr_, оньє
  { {0xe47b000b,0x6d590347,0x94730012,0x88bb0009}},	//   דריכ, _erwa, تديا, _יזמי
  { {0x4444153c,0x1eda0012,0x9f610025,0xbf9b0009}},	//   he_, _شباب_, _épée_, _ביבש
  { {0x8cf40003,0x320b0ee7,0x2e370009,0xb8b70012}},	//   _اكتش, racy_, _כראש_, لإست
  { {0x653b0009,0xdfa7004c,0x4035004c,0x04430198}},	//   _סעוד, ајбо, љевс, _мечн
  { {0xddc40039,0xcebb0001,0xddc60002,0x7e620ad2}},	//   ndiņ, вља_, _nakł, _knop
  { {0x33db000b,0x9f5e00c1,0x7bdb0009,0x6e640024}},	//   _בחוד, _metà_, _בקוו, отуж
  { {0x4444153d,0x66c50031,0x629d153e,0x7e6d0e7b}},	// [2e10] fe_, zóko, miso, rjap
  { {0xfd4d008a,0xc1bc000b,0x3ea90d6c,0x91bc000b}},	//   _khoả, _במחש, čati_, _במחי
  { {0xf3670046,0x7e620227,0xf09200af,0x9b4400ae}},	//   штан, _onop, _זני_, ينكو
  { {0x4b370093,0x6a940024,0x6d4b0097,0xa3ab0011}},	//   שראל_, оріє, ægas, कॅट_
  { {0x660d00bd,0x2731001a,0x27ec0029,0xaa560012}},	//   maak, _sơn_, ždne_, صلوا_
  { {0x6c85000a,0x672302b7,0xd0f80009,0x4dda0009}},	//   _السم, tunj, סמות_, _תחשו
  { {0x3e7c0066,0xf8bf0156,0xd7ee0012,0x46150012}},	//   _síti_, ltés_, ركي_, موغر
  { {0xc332000b,0x7ae00010,0x2bba0037,0xc668004c}},	//   _מול_, _gimt, _उड़ा, ишње_
  { {0x3e780065,0xddc6003e,0xf8bf153f,0xddc40030}},	//   _rétt_, _zakł, ntés_, ojiš
  { {0xd874000a,0x70740003,0x67230027,0xf8bf0061}},	//   _والب, _والذ, punj, ités_
  { {0x5f790003,0xbb4500b3,0x09e60511,0xe3b10012}},	//   _حماس_, щенк, йонн, ثرة_
  { {0x6d590002,0x44441540,0xa5c20097,0x216a0842}},	//   _trwa, ze_, þókn, гими_
  { {0x44441541,0x6d4b0052,0x68e10623,0x64450845}},	//   ye_, _usga, _kild, kehi
  { {0xfd56000b,0x6e2904a3,0xa4d40024,0xd4660048}},	//   _לשני_, lgeb, _дочі, _гише_
  { {0xcaf50003,0x177906e6,0x9a6a0003,0xf1bf000e}},	//   _استب, асть_, _ممثل_, lgál_
  { {0x681b0039,0x07a3007c,0x44441542,0x673c004a}},	//   lādē, часн, we_, _ärje
  { {0x7ae00010,0x7afb004b,0x22920030,0xe1ff0034}},	// [2e20] _rimt, _ăuta, ušku_, ejów_
  { {0xcb6a0001,0x2292001b,0xad250012,0xa3ea0148}},	//   лазе_, ršku_, ترفو, уджа_
  { {0x18770093,0x60db000b,0xb5fd009b,0xfcb50024}},	//   _העיר_, _תקינ, ljšu, іщую
  { {0x366a1543,0x41d90011,0xf8bf0031,0xacea0012}},	//   _само_, _बृहस, stét_, _مرسل_
  { {0x3913002d,0xdd8f0024,0xf8bf0025,0x1e570009}},	//   змір, _ншi_, ctés_, _השכר_
  { {0xbcfb0065,0x69c001e9,0xe1650012,0x629d1544}},	//   _bréf, _vyme, تدمي, ziso
  { {0xd6d0000a,0x4386000a,0xbb860003,0xb21b0058}},	//   وقت_, _الأق, _الأي, mhæv
  { {0xdd0804b4,0x994c0026,0x5678010c,0x8cf40b05}},	//   _môže, môže_, рбия_, озиц
  { {0xf653000b,0xa3d60011,0xb9960012,0xd5ba003c}},	//   לצה_, ाइव_, _الذب, ыск_
  { {0x68e10065,0x0577000b,0x5b1405f7,0xf8bf0031}},	//   _gild, צגים_, омот, mrég_
  { {0x66c5000e,0xcff70009,0x62821545,0x2d821546}},	//   iókj, _הצבה_, okoo, ške_
  { {0x5eeb000b,0x628213f2,0xc879004b,0xe1d90024}},	//   _עַבְ, nkoo, _ruşi_, идні_
  { {0x1e570009,0xc50a0012,0x25ab0064,0x6e2e0031}},	//   _לשאר_, _إتصل_, čilú_, őbbs
  { {0xd9180047,0xfd4d001a,0x7dc50003,0xcff40048}},	//   щью_, _thoả, _بتمك, зпръ
  { {0x5c37000b,0xe7f00037,0x66d50010,0xe437000b}},	//   _הטוב_, _चलना_, _iškr, _הרוח_
  { {0xf96b0098,0xe6940015,0x6e940339,0xfaa4004c}},	//   _брой_, писы, пису, _најо
  { {0xe29f0065,0xcc990001,0xf8bf0061,0x62820647}},	// [2e30] mið_, авац_, utés_, dkoo
  { {0xe29f0065,0xf8070001,0xdd7b0009,0x6bd70012}},	//   lið_, _учин, אטמל, متضر
  { {0xa036000b,0xda7b002d,0xe80c0037,0x644514d5}},	//   _ואתה_, ляд_, _सज़ा_, rehi
  { {0x68e906f4,0x66f10039,0xaac90037,0xe29f0028}},	//   _pued, _nāka, रतिक, nið_
  { {0x68e11547,0x8e560009,0xd2d40012,0xa9250024}},	//   _pild, _וירג_, أغلب, ідкл
  { {0xbcfb0108,0x7bc6003e,0x0138000b,0x11d40012}},	//   _préf, ękuj, צרות_, ستند
  { {0xe29f0065,0xf7710003,0x3ea91548,0x20c90028}},	//   kið_, ظات_, onat_, búin_
  { {0x3ea91512,0xb4c30011,0x62340400,0xdee20048}},	//   nnat_, ्ष्_, _несу, мощи
  { {0x6e290732,0x4d65002d,0x394d002a,0x7aea0052}},	//   rgeb, іков, _uses_, _auft
  { {0x9f63000e,0xf5360009,0xa4d6004c,0x9f880097}},	//   ívót_, קנתי_, одњу_, kóða_
  { {0xe29f0065,0x3b090001,0x37ab0447,0x39400404}},	//   fið_, јемо_, _стан_, _spis_
  { {0xe29f0065,0xc8690093,0x6d5d006f,0x66c5000e}},	//   gið_, _בן_, _orsa, iókk
  { {0x6dc70003,0x3ea91549,0xbbc60011,0x74290012}},	//   _ازال, dnat_, _वर्क, _نكشف_
  { {0xcfaa0003,0x3940154a,0x74f60012,0x7bc70097}},	//   لازم_, _vpis_, _بفوز_, ýjus
  { {0xf8bf000e,0x39400002,0xe4d20012,0xc7b20012}},	//   ttér_, _wpis_, _تقود, ذّر_
  { {0x3ea90054,0x9586003c,0x6aad0097,0xd1320012}},	//   gnat_, олбе, _gjaf, _قمع_
  { {0x660b000f,0x3ce30070,0x61f6006f,0xe6c50012}},	// [2e40] _megk, _bijv_, _ifyl, ستفي
  { {0xa3d60044,0x85210037,0xa7fc003a,0x660b000e}},	//   ाइल_, _मिनट_, _anın, _legk
  { {0x7ae403d5,0x9b460012,0x6d5d08ec,0xc1ea0048}},	//   _kiit, تناو, _ersa, адеж_
  { {0xe2460003,0x84e30011,0x26c401e3,0x6289154b}},	//   تخطي, कआउट_, _ómo_, _cleo
  { {0x200e0028,0x3ea00574,0x95e60011,0x6282154c}},	//   tafi_, miit_, कशीट_, rkoo
  { {0x3ea005cf,0x7ae402bd,0x67210133,0x66f1001e}},	//   liit_, _liit, šlje, _sāka
  { {0x8cb90011,0x865a0009,0xa3de0011,0x4e8a0024}},	//   ्तरो, ֹדִי, _दृढ_, ищим_
  { {0x7ae40006,0x877b000b,0xa9f40037,0x8e20002d}},	//   _niit, יאצי, ंडोज़_, _вiн_
  { {0x95d70048,0x0dca0024,0x66190034,0x66c50031}},	//   одът_, шуки_, ówki, iókh
  { {0x7d1d000e,0x3ead013a,0x3ea9154d,0x60860012}},	//   ássa, četi_, znat_, _بشرك
  { {0xe29f0065,0x5c5b0009,0xadfc0011,0xa3cf0011}},	//   tið_, בדיק, ौरान_, _शरण_
  { {0xe8d90020,0xfce6154e,0x200c016d,0x314a00af}},	//   _trị_, _додо, _hedi_, ֑תָּ
  { {0xe29f014d,0x3ea00051,0x3ea90dd1,0xc2130009}},	//   rið_, diit_, vnat_, והר_
  { {0xe29f0028,0xdfc60003,0xf8ca0037,0xc4c60012}},	//   sið_, في_, ितिय, _بتصو
  { {0xc058007c,0x3f850042,0xa6f80009,0xd6f80009}},	//   ція_, álu_, מִּי, מִּש
  { {0xe2980001,0x442c0070,0xce68002d,0x6448154f}},	//   _мај_, lgd_, оруд_, ledi
  { {0x442c0070,0xe534027f,0x6fbb0011,0xd7e70024}},	// [2e50] ogd_, меть, _शुरू, _міно
  { {0xebc70001,0x26cc0054,0x442c1550,0x645a0097}},	//   ољен, ïdor_, ngd_, _ótil
  { {0xaa4b0024,0xf8bf0025,0x442c0227,0x8c3c0060}},	//   иїде_, grée_, igd_, ciğe
  { {0x2011001c,0x7ae40017,0x77ba0009,0x67ba0009}},	//   lazi_, _xiit, _למתח, _למתק
  { {0xca740003,0x6d5d1551,0x4a5c0009,0xd5a60012}},	//   بالغ, _ursa, ידאו, _أف_
  { {0xbcfb0108,0x6448001c,0x4dda0009,0x8dda0009}},	//   _crée, jedi, _לחרו, _לקרק
  { {0x6d4d0070,0x644812d3,0x200c045b,0xf8bf0025}},	//   lwaa, dedi, _dedi_, crée_
  { {0x64551552,0x7a160034,0x915e0081,0xe29f0097}},	//   _hazi, rętó, hắc_, _öð_
  { {0x20110470,0x7ae4004a,0x6e2d0052,0xa0c50003}},	//   kazi_, _riit, igab, _فيرو
  { {0x7ae40006,0xe3b10012,0xa3cf0011,0x442c0248}},	//   _siit, فرج_, _शरद_, ggd_
  { {0xe7f00037,0x64551553,0x9cd80009,0x9ee90012}},	//   _चलता_, _mazi, חוזה_, _افصل_
  { {0x442c0070,0x539a000b,0x8d770012,0x68e5008e}},	//   agd_, מיתו, _واشا, _aihd
  { {0x6f15003e,0x68ed02d1,0x6464000d,0x20d60024}},	//   eszc, _cuad, _ştiţ, зівс
  { {0xb4fa000b,0xacfa000b,0x8d5a000b,0x64551554}},	//   _הפסי, _ההסכ, _לכני, _nazi
  { {0x6e2d0052,0x366a0014,0x2aa4000e,0x7ae4005e}},	//   fgab, баво_, rűbb_, _tiit
  { {0xfb1a000b,0xc3320009,0x531a0009,0xa206003c}},	//   _הוקמ, _נוח_, _הוקצ, _эпид
  { {0xb4d70037,0xceb20009,0x6d4d0227,0x1d260adc}},	// [2e60] ागू_, גין_, gwaa, ямам
  { {0x31370093,0xf8bf0061,0x66f1001e,0xa84a0003}},	//   _צריך_, trée_, _nāko, _الدم_
  { {0x307b0093,0xa87b0009,0x395f00b6,0x987b007e}},	//   _האינ, _האיר, _arus_, _האיט
  { {0x3d1c0037,0x01da0003,0x25ad0027,0x28c40011}},	//   _मिले_, موضع_, _žele_, _लीजि
  { {0xb9e3002d,0x6286008e,0x7bce0034,0x9f5801e3}},	//   ніши, ikko, _wzbu, paró_
  { {0x61e91555,0x6604005e,0xaf060198,0x91e301c6}},	//   _egel, lbik, пчик, хоче
  { {0x43430800,0xa7370003,0x200c00c1,0xddcb0002}},	//   _перв, كثير_, _vedi_, _nagł
  { {0xcb370009,0x2e4a0048,0x98ac0060,0x64551556}},	//   _מאלי_, сяко_, ılıp_, _zazi
  { {0x644800a2,0xc1060003,0x7d160e45,0xe6110009}},	//   tedi, _رواي, nsys, כִי_
  { {0x7ce90010,0x7c3a0052,0xdc980024,0x0d970009}},	//   _užre, uftr, івні_, פכים_
  { {0x442c0227,0x6d4d0227,0x57fb0009,0x64481557}},	//   rgd_, zwaa, _הלבו, redi
  { {0x64481558,0xa25b0025,0x02d90012,0x75d60012}},	//   sedi, plôm, توجب_, _فيضا
  { {0xc4be0044,0xd627002d,0xac180014,0x68ed1559}},	//   ्ताओ, _хоче_, _долу_, _quad
  { {0xf9930009,0x6286155a,0x26c20919,0xe8d90b24}},	//   גרש_, akko, _akko_, _trọ_
  { {0x6af30003,0x2fc50058,0xddc90027,0x643b000b}},	//   _كثير, ælg_, mješ, _העונ
  { {0x6455155b,0xddc90027,0x6ee7003a,0x6d4d0227}},	//   _sazi, lješ, _kıbr, twaa
  { {0xdddb0027,0x95cb0014,0xddcb0002,0xc86705fb}},	// [2e70] okuš, сува_, _zagł, _етни
  { {0x6d4d00bd,0x6e2d0052,0x89340012,0x787d0025}},	//   rwaa, sgab, _أعيا, _lèvr
  { {0x92590015,0x2900000d,0x6455155c,0x6d4d0c3b}},	//   жает_, ţial_, _vazi, swaa
  { {0xfbd0000a,0x6723012e,0x66f10039,0x7aee0054}},	//   اتك_, vrnj, _sāko, _dubt
  { {0xdb180006,0x752400c1,0x9e5a0009,0x865a0009}},	//   _hyvä, criz, _וכרט, _ודרי
  { {0xccf2000b,0xe7310012,0x1df70011,0xf9580009}},	//   _בכך_, نصب_, ीर्ष_, פסות_
  { {0xe7390021,0xdb18008e,0xd00e0012,0xe7fe05f3}},	//   цей_, _jyvä, جلى_, _उभरा_
  { {0x61e900eb,0x69ce0011,0x0565003c,0x7d1d0031}},	//   želj, _सरली, двин, ásso
  { {0xb3450149,0x9fe70003,0x06960003,0x067c0009}},	//   _opçã, _فساه, بنية_, מנהל
  { {0x628d0872,0xfce50024,0x3b85155d,0x212b155e}},	//   _alao, ьопо, длог, duch_
  { {0xf8bf0017,0x8c1a0009,0xa3d60011,0x96070012}},	//   guém_, חותי, ाइए_, _فبإم
  { {0xedd50003,0xd29a002d,0x78a3004a,0x11d6002d}},	//   _قياد, ітні_, linv, дігр
  { {0x62860006,0x3ead0163,0x6480005e,0x2240005e}},	//   rkko, mnet_, _köit, õiki_
  { {0x62860005,0x661d03ee,0x71880009,0xc0e30024}},	//   skko, _adsk, פְרַ, кояк
  { {0xae7a0015,0x93fa0009,0x9bfa0009,0x33920012}},	//   осах_, _ולצי, _והצט, _للوز
  { {0x3ebf0013,0x92b6000a,0x25f50037,0x6721000e}},	//   nout_, _تحتا, एँगी_, álja
  { {0xe5a3024d,0xcad70009,0x98a20035,0xc2370009}},	// [2e80] вити, _קופת_, aukā_, _חאפז_
  { {0x3ead0052,0x672100eb,0x70770012,0x3ebf155f}},	//   hnet_, šlja, _يميز_, hout_
  { {0xbcfb0108,0x93c3000d,0xa5bb000e,0x63030012}},	//   _préc, _ţări, _adód, َوْل
  { {0x8b65000a,0xd1ca0015,0xdddb009b,0x49ca0083}},	//   عالم, олее_, zkuš, олен_
  { {0x8f000024,0x7d030048,0x3ead1560,0x28ca05f3}},	//   цiю_, _изяж, dnet_, ितलि
  { {0x74e7002d,0x660f0032,0x89970009,0x787d1561}},	//   _одяг_, _zeck, וכנס_, _sèvr
  { {0xddc9001c,0x3ead0052,0x3ebf0070,0x93bc004b}},	//   vješ, fnet_, fout_, ngăt
  { {0xdb0e0002,0x8f1b0009,0x8b9b0009,0x3ead1562}},	//   _wybó, קופת, _ובלת, gnet_
  { {0xfaa30001,0x320601a6,0xbc4a0595,0x61e91563}},	//   _рато, mboy_, очне_, želk
  { {0xd1970009,0xe97b0009,0x27f70012,0xb21b0040}},	//   _חכמי_, _ונמש, _يفقد_, rkæm
  { {0xd2510003,0x3ebf1564,0x7d0b0031,0xda35003c}},	//   هند_, bout_, ágsz, нены
  { {0xbd460003,0x6d460058,0xcfa90003,0xdddb09d2}},	//   _يناي, _opka, _عالم_, skuš
  { {0xddc90027,0x656f0052,0x93bc000d,0x224b1565}},	//   pješ, ächt, egăt, reck_
  { {0x212b0052,0x68e81566,0x000000c4,0x000000c4}},	//   ruch_, _jidd,   ,
  { {0x212b0052,0x6d460708,0x889b0009,0xd4330012}},	//   such_, _apka, קבלי, _شعوب
  { {0x85050003,0x68e80f50,0xcf570009,0xe8d90081}},	//   فورن, _lidd, ובלת_, _trỏ_
  { {0x660f0163,0x61ed0051,0x7bca0052,0xb4d50063}},	// [2e90] _veck, _igal, üfun, ежащ
  { {0xbcfb0108,0xdb180163,0x443e0052,0x61fa0066}},	//   _créa, _tyvä, nft_, ětle
  { {0x660f0163,0x661d007a,0x443e1567,0x78a3008e}},	//   _teck, ųski, ift_, vinv
  { {0xe298007c,0x661d0058,0x29191568,0x80ad0011}},	//   має_, _udsk, ossa_, ँचवे
  { {0x29190006,0xe1670003,0x1e96000b,0x3ead038e}},	//   nssa_, بداي, _נכשל_, vnet_
  { {0x29191330,0xf536000b,0x443e0070,0x8f00002d}},	//   issa_, _אנשי_, jft_, цiя_
  { {0xf0940093,0xa295002d,0x5f770003,0xdbd60038}},	//   כנס_, _заві, باشر, _jääk
  { {0x443e0644,0xca24003c,0x61ed020d,0xddc405be}},	//   eft_, _аффи, _ngal, ndiş
  { {0xc0cb1128,0x443e0052,0x6e26000e,0xdbd6004a}},	//   _дуже_, fft_, ókba, _lääk
  { {0xe1fa0044,0xeb990001,0x65620052,0x61ed1569}},	//   ूर्ण_, зио_, _droh, _agal
  { {0x53c9002d,0x7ae90010,0xcb690345,0x2919156a}},	//   ягом_, _kiet, чане_, essa_
  { {0x7e7d001e,0x656f0052,0x2f5a0009,0x7afa0031}},	//   _nosp, ächs, _מדענ, _étte
  { {0x8d870012,0xe5690048,0x7ae9156b,0xdce70030}},	//   _تشان, _хилд_, _miet, áměs
  { {0x7ae9156c,0x6c350003,0x6458156d,0x61ed156e}},	//   _liet, _أفغا, _gavi, _egal
  { {0xb4cb0037,0x2ca50028,0x2bc60037,0xb2220028}},	//   लती_, mild_, _रुपा, _þægi
  { {0x139a000b,0x539a0009,0xc6a5004c,0x69c00060}},	//   _מבצע, _מיצו, врђи, ümes
  { {0xbcfb0061,0xdc390009,0x753b156f,0x79660012}},	// [2ea0] _préa, ּעֲר, ntuz, _أطعم
  { {0xe0d20003,0x6ab80037,0x7659002a,0x8f760024}},	//   _حزب_, इक्र, _lawy, _зумі
  { {0x7ae90052,0xcb09002d,0x10370009,0xda5a0009}},	//   _biet, дхід_, _אטים_, ּכְל
  { {0xc332000b,0xe9da00bb,0x7ae90035,0x22820097}},	//   רוא_, пке_, _ciet, _tóku_
  { {0xc1e70015,0x64430002,0xaa570003,0x443e0028}},	//   ньше_, _obni, علها_, yft_
  { {0x673c0159,0x7d041570,0x7e6b020d,0x03a60a36}},	//   otrj, mpis, _angp, _зиго
  { {0xce940014,0x7ce90010,0x64581571,0x56940048}},	//   какъ, _užra, _ravi, какт
  { {0xd6d70047,0x95080003,0xddcd0027,0x65621572}},	//   нты_, وقعك_, ljaš, _proh
  { {0x7ae30070,0xe5720003,0xa90a0012,0xb4cb0011}},	//   ïnte, اطع_, _ريال_, लतू_
  { {0xd91b0093,0x4f96057b,0x859b000b,0x64a30001}},	//   _מומל, _преу, פשיו, лања
  { {0xa3d60044,0x443e00a7,0xa295002d,0x3d100321}},	//   ाइट_, rft_, вані, _दौरे_
  { {0xda100044,0xdbd60051,0xaf490003,0x92100011}},	//   ारित_, _rääk, _تشكل_, ारिज_
  { {0x2919004a,0xd7f1001a,0xba9b000b,0x443e0052}},	//   ussa_, _mãn_, לסטי, pft_
  { {0x3a20003a,0x6721000e,0xb4fb000b,0x7e7d1573}},	//   _edip_, áljo, _צפוי, _sosp
  { {0x6e671574,0x2bf70009,0x4fe8003c,0x00e4003c}},	//   нтаж, _אמון_, емён_, ужён
  { {0x752d00c1,0x66c50031,0x44f60097,0xf8bf0031}},	//   tuaz, lókr, _bæ_, ntéz_
  { {0xac270469,0x7ae91575,0xdd94003c,0xdd910012}},	// [2eb0] ефек, _riet, гаты, جوء_
  { {0xd1400002,0x22b6001e,0x7ae90fb7,0xa6f5004c}},	//   żący_, māka_, _siet, _изош
  { {0x22b6001e,0x7ae91576,0x7d041577,0xf1bf0031}},	//   lāka_, _piet, apis, agát_
  { {0x44f60028,0x78a70227,0xe9f80024,0xc33300af}},	//   _fæ_, lijv, енці_, טוע_
  { {0xe8f8002d,0x273a0070,0x69da0002,0x7ae91578}},	//   елі_, eën_, ęteg, _viet
  { {0x07a5011f,0x27ab0009,0x7ae90034,0x6ce40024}},	//   калн, ּסֵּ, _wiet, _бісе
  { {0x7ae91579,0x648d0028,0x6b83006f,0xb8820066}},	//   _tiet, _búin, ängd, _říka
  { {0xdddd0039,0x0f58000b,0x22b6001e,0x61fb0262}},	//   _nosū, תיהם_, kāka_, _uful
  { {0x2d8b0042,0x765b00e8,0x6d3200ae,0xf5050b2b}},	//   áce_, rduy, لفيض, ъзпо
  { {0xb4cb0037,0x4c85002d,0x23750012,0x99d40012}},	//   लते_, тлов, ناجح, _إتفا
  { {0x907a000b,0xe4520009,0xb7670024,0xdc880009}},	//   _קטעי, בֶר_, _ятай, גְרָ
  { {0xfeb8000a,0x780a0037,0x0f180012,0x7afc0031}},	//   _كانت_, वर्क_, _أغلب_, írta
  { {0xe2970063,0x6aa60248,0x22b60035,0x6609157a}},	//   тая_, rikf, gāka_, mbek
  { {0xbcfb0061,0x934509ca,0x7d1b005e,0xdb080031}},	//   _prén, _анке, msus, őlép
  { {0x7d1b0051,0x12aa0003,0x3f8c00d9,0x8cca0011}},	//   lsus, _يدعى_, ádu_, _सीटो
  { {0x7d040027,0xcf92000b,0x601f0060,0xbcfb0025}},	//   tpis, בטל_, _açmı, _créo
  { {0xa8060014,0x1ea90003,0x7d1b0051,0x95830055}},	// [2ec0] _изпл, رافي_, nsus, алте
  { {0x0cbe0044,0x7d0400b6,0xe403002d,0xdbcc0028}},	//   ्तेम, rpis, изуп, _kóði
  { {0xe2a3001a,0x91f60011,0x2018157b,0xddc2001b}},	//   _trừ_, _इलाज_, mari_, _mnoš
  { {0xd36f000a,0x7d1b00b9,0xfa89002d,0xba290003}},	//   تهم_, ksus, нсій_, فسهم_
  { {0xdb0e006f,0x98a20073,0xf1bf0031,0x60c308aa}},	//   _nybö, auką_, lgár_, fonm
  { {0x66d50010,0xa3df0037,0x7d1b08ab,0xfc030695}},	//   _išky, देह_, dsus, _впро
  { {0xf093000b,0x22b6001e,0xd6da0001,0x20180054}},	//   שנו_, zāka_, мти_, iari_
  { {0x201800c6,0x7d780003,0x3eb2004a,0xc7b3000b}},	//   hari_, فمبر_, nnyt_, יבו_
  { {0xd9460046,0x20180065,0xdd900003,0x7d1b05cf}},	//   _јези, kari_, صود_, gsus
  { {0x0137000b,0x3eb2004a,0x645c157c,0x9f980042}},	//   _ברמת_, hnyt_, _jari, lším_
  { {0x2018157d,0x61480097,0x66090031,0x6280157e}},	//   dari_, _félö, bbek, _komo
  { {0xc333000b,0x558a0014,0x22b6001e,0x268a0012}},	//   סור_, _обем_, tāka_, _تخطي_
  { {0x9d9a0003,0xfd380012,0xf9890012,0x24990035}},	//   _تنشئ_, _أكتب_, رنسي_, ūsma_
  { {0x9f35002d,0x645c157f,0xf36605fb,0xcb340048}},	//   легі, _nari, _атин, _бекъ
  { {0x9cd7000b,0x78a70070,0x8e20002d,0xf7700012}},	//   _שווה_, rijv, _вiд_, ياف_
  { {0x628000b6,0x645c002c,0x20180532,0x9f980042}},	//   _nomo, _aari, aari_, jším_
  { {0xd2b80009,0xb5d5004c,0x3f9e0097,0x3f870034}},	// [2ed0] _שלחת_, ужај, útur_, zynu_
  { {0x1477000a,0xa8550a25,0x98a20010,0x645c1580}},	//   خارج, _скоч, tuką_, _cari
  { {0x8bd80009,0x6e22043a,0xe3b00012,0x645c1581}},	//   תַּח, _odob, يرم_, _dari
  { {0x3e040014,0xddcd0066,0xc333000b,0x6e950012}},	//   _вярв, zdař, שוף_, _إلحا
  { {0x7aed000f,0x645c1582,0x62340024,0xe29c0009}},	//   _miat, _fari, речу, ושאר
  { {0x99d40003,0x08c4002d,0x7c870345,0x765d00b6}},	//   جتما, абін, _руме, _hasy
  { {0xa3df0044,0xf6510003,0x46a50014,0x32bb0003}},	//   देश_, مئة_, лакв, _قدرة_
  { {0x7d1b0005,0x7529012e,0x72040003,0x645c0029}},	//   tsus, trez, _نوفم, _zari
  { {0xd4150047,0x20180101,0x765d0a26,0x5c150015}},	//   льны, yari_, _masy, льну
  { {0x13090047,0x752900c1,0x478b0014,0xb5fb0066}},	//   нной_, rrez, _осем_, _znát
  { {0x3eb20006,0xf9890009,0xe4c80012,0xb6350012}},	//   ynyt_, _צר_, خبين_, _مفاع
  { {0x7d1b0051,0xbcfb0061,0xfbd2000b,0x69c10060}},	//   psus, _prél, מתי_, ğlen
  { {0xe56e0046,0xe8f7002d,0x7aed00b6,0x3ea91583}},	//   _уз_, лля_, _diat, diat_
  { {0x6e220b32,0xddc20027,0x03190012,0x291d016d}},	//   _zdob, _unoš, _كتبت_, iswa_
  { {0x765d00b6,0x73c50012,0x20181584,0x4c3a0009}},	//   _basy, _حيثم, rari_, _נתקב
  { {0x645c0101,0xc3320009,0xa695004c,0x22b60035}},	//   _sari, _הוה_, аруј, māko_
  { {0x8d660047,0x9f980066,0x05660015,0xc5f2000b}},	// [2ee0] ывае, vším_, ыван, מדן_
  { {0x399b000b,0x62800b45,0x219b0009,0x59aa0011}},	//   _נייד, _somo, _נביא, _चेयर
  { {0x0c370003,0x22b6001e,0x883b000b,0xabd60001}},	//   اكمة_, nāko_, _אתיו, уцај
  { {0x6d4b0f00,0x3ea91585,0xf2c50024,0x99990073}},	//   _opga, ciat_, асін, cesų_
  { {0xa1580447,0x645c1586,0x22920030,0xa967038f}},	//   талу_, _tari, ušky_, лица_
  { {0x7e7b001e,0x61d7000b,0xe8d9001a,0xd91b0009}},	//   ejup, נוסף_, _trễ_, גוסל
  { {0x7d02003e,0xb4e00037,0x6d4b134f,0x9f9801e9}},	//   _stos, दगी_, _apga, pším_
  { {0x1ef70003,0x44441587,0x212000eb,0x91e60b4e}},	//   دعوة_, lf_, _ovih_, _бобе
  { {0x7aed00c1,0x0caa00f5,0xe297035c,0x18360012}},	//   _riat, етни_, _сат_, _مراح
  { {0x4438008b,0xb9930003,0xb80a0003,0x51930012}},	//   ür_, _الكب, _أيام_, _الكذ
  { {0x1bd4002d,0x6564004a,0xf8b30009,0x0463003c}},	//   роня, hvih, _פשע_, стым
  { {0x92580015,0xbb930015,0x7ae21588,0x6e221589}},	//   гают_, сающ, nmot, _udob
  { {0xa80200a2,0x3ea903eb,0x984b0014,0x212b0052}},	//   ğınd, viat_, нява_, urch_
  { {0x444400bd,0xa80200a2,0x22b6001e,0x68f6003a}},	//   jf_, şınd, bāko_, _duyd
  { {0x7ae2006f,0x6d40158a,0xd6db12f2,0xd7b80009}},	//   kmot, ltma, ета_, דֶּך
  { {0x5e58007c,0x4444158b,0x7bd8001b,0x6db50198}},	//   лися_, ef_, _izvu, айбу
  { {0x99990010,0xf1a40037,0x4444158c,0x3ea9158d}},	// [2ef0] resų_, _खेलन, ff_, riat_
  { {0xb8820030,0x78a50097,0xdce209df,0x6e360031}},	//   říjm, _umhv, _oroč, agyb
  { {0x75eb000e,0x8c1b0009,0xa3df0011,0xef670048}},	//   _közü, גובי, दें_, _съпо
  { {0xeaae002d,0x4444158e,0xfb1b0009,0x628f0227}},	//   ій_, af_, תואמ, nkco
  { {0xd9440003,0x224900b6,0x660d158f,0xe1f00012}},	//   مئوي, _mbak_, mbak, أسم_
  { {0x660d0f33,0xf7710003,0xbf650012,0xc9180009}},	//   lbak, قاب_, لدعو, נחות_
  { {0x8fa2003c,0xa695004c,0xdd0e0060,0xd00e0012}},	//   жаще, ириј, _kışl, ذلي_
  { {0x3169003e,0xa3de0066,0x22b6001e,0xc1050012}},	//   _oraz_, _běží_, vāko_, _نوري
  { {0x9875002d,0x212b001a,0xef190034,0x7e7b1590}},	//   _клац, _ích_, ąży_, rjup
  { {0x66f10039,0x3ea60163,0x2613001a,0x22b6001e}},	//   _sāku, _emot_, ảo_, tāko_
  { {0x2120001c,0xbb4500c0,0xe3b10003,0x752d0066}},	//   _svih_, шенк, ترة_, hraz
  { {0xfc3f0013,0x09e605cc,0x91e6010c,0xb3820024}},	//   ří_, ионн, ионе, ілял
  { {0x660d0058,0x661b004a,0x88c60012,0xa96a004c}},	//   dbak, mauk, لتسل, њига_
  { {0x859a000b,0x661b0757,0x7ae20b37,0x00f60009}},	//   _בשנו, lauk, zmot, ימשך_
  { {0x66e60012,0x7d091591,0xafe60198,0xa7a70048}},	//   لأرق, lpes, ровл, акра_
  { {0x44fb0020,0x75eb003a,0xcf920009,0x6bb40024}},	//   _kê_, _gözü, קטן_, _усіє
  { {0xa3e80044,0x752d00c1,0xdd0e003a,0x20d60024}},	// [2f00] मेन_, graz, _dışl, _вінс
  { {0x4444008b,0xc7a60024,0x61db0009,0x89db0009}},	//   uf_, _виок, _בקפד, _בחפי
  { {0x907b000b,0x66f1001e,0x44fb1592,0x752d1593}},	//   _סטטי, _māks, _lê_, araz
  { {0xd7bb0093,0x752d13b4,0x4fbb000b,0xe2460003}},	//   _יציר, braz, _יציא, شخصي
  { {0x28db0044,0xc05a002d,0x7bce0002,0x09b00037}},	//   _मीडि, вій_, _wybu, जपेय
  { {0xdce20580,0x7e0e0011,0x66f10035,0x394d0060}},	//   _proč, सर्ग_, _nāks, çesi_
  { {0xd3720003,0x7c47000e,0xa09b0009,0xc8290009}},	//   _ظهر_, ésrő, כיסט, אֵפֹ
  { {0x44fb1594,0x3546024d,0xe8d90081,0x661b1595}},	//   _bê_, ахов, _trệ_, gauk
  { {0x8c3c00a2,0x66f1001e,0x245b0010,0xddc90060}},	//   liği, _sākt, kšmė_, rdeş
  { {0x6721012e,0xf3f1000b,0x113b000b,0x44fb1596}},	//   šlji, ּ֣י_, _בתמל, _dê_
  { {0x8c1b000b,0x2bf7000b,0xcaa70012,0x9cd70009}},	//   כויי, ימין_, لصحي, שויה_
  { {0x69c1003a,0x66fc0066,0xa802003a,0x7f3b000b}},	//   şlem, _ačko, şıld, _יעבו
  { {0xf8bf000e,0x0e9b000b,0x628f0070,0x7a410031}},	//   nség_, _בשאל, rkco, látó
  { {0x8c430001,0xd918003c,0xd59b0009,0xe1ff10f9}},	//   _деље, шью_, _שֹׁכ, scó_
  { {0x31690002,0xe3af0003,0x60c70029,0x23a50037}},	//   _wraz_, _يرى_, rojm, _गेंद
  { {0x8c3c00a2,0xeb97000b,0x752d1597,0xf8bf0e90}},	//   diği, _כדור_, traz, tués_
  { {0x36040012,0x7c070012,0x95cb0048,0xd6570009}},	// [2f10] توقف, لباك, тува_, סימת_
  { {0xcc740046,0x8c3c003a,0xb0350001,0x201c017b}},	//   огућ, fiği, _унош, javi_
  { {0xa856000b,0x660a000e,0x290b009b,0x6ec70012}},	//   _היתה_, ímké, lpca_, _نتحق
  { {0x62350001,0xf8bf0164,0x0bb70009,0x99d90012}},	//   седу, pués_, סלאם_, هواء_
  { {0xf8bf0e90,0x661b1598,0x644a0034,0xcad800af}},	//   qués_, vauk, _obfi, בואת_
  { {0x88c8007c,0x3861008b,0xfc670014,0x97250003}},	//   алів_, _jahr_, _тъмн, مفتو
  { {0x33950003,0xbb850003,0xab950003,0x661b004a}},	//   _الأز, _الزي, _الأغ, tauk
  { {0x57b8000b,0x66f1001e,0xdc010037,0xcfb8000b}},	//   ילוב_, _sāks, ोर्ड_, ילוי_
  { {0x201c0027,0x661b1599,0xe84b0012,0xa3e40011}},	//   bavi_, rauk, _لجان_, पेस_
  { {0x661b0039,0x0dc80046,0x8855000b,0xc8240003}},	//   sauk, јући_, _לֹ֣א_, _وفقً
  { {0x661b004a,0xa0c40012,0xe6430060,0x46150012}},	//   pauk, _بيلو, şmış, _هوار
  { {0xc7b2000b,0x2a9a0003,0xdb1e0658,0xcf920009}},	//   _צבא_, ائدة_, íván, _מטב_
  { {0x3ead159a,0xddc90027,0x30760024,0xf505003c}},	//   miet_, ljež, бувс, _узло
  { {0xdd8e0003,0xb97a000b,0xa06a0001,0x40950264}},	//   _سوى_, אנשי, ћава_, орст
  { {0xdfd20003,0x141a000b,0xd62a00db,0xf8bf0031}},	//   سير_, _עוקב, лове_, zség_
  { {0x3ead0333,0x201c009b,0xb21b0058,0xa3cb0011}},	//   niet_, zavi_, skær, _लड़_
  { {0x6cd60003,0x0c2604ba,0x98a60223,0xa2c50011}},	// [2f20] مقرا, йман, _гипе, रवर्
  { {0xb97b0093,0x8c3c00a2,0x8db5002d,0xcc290012}},	//   _עניי, tiği, істі, لأمم_
  { {0x6d5d0a80,0x8c1a000b,0xa2c40037,0x0b460ed4}},	//   _essa, רועי, िकल्, снен
  { {0x3ead0333,0xf8bf000f,0x8c3c00a2,0xc332000b}},	//   jiet_, tség_, riği, לוב_
  { {0xda65000a,0x3ead121f,0x644301a0,0xe297004c}},	//   تالي, diet_, ònic, љач_
  { {0x04960003,0x6c860003,0x3cf10029,0x2eb20037}},	//   _السح, _الآم, ľovú_, ुक्त
  { {0xf8bf000f,0x3378000b,0x23780009,0xb8ff0011}},	//   sség_, _דְּב, _דָּמ, _धी_
  { {0x93b7000b,0xf773000b,0xddcd003a,0x25ad00eb}},	//   _הללו_, לקו_, ndaş, _želi_
  { {0x7a410031,0x25a00e00,0x661d0097,0xa5bb0031}},	//   sátó, nzil_, ðska, _adój
  { {0x3ead0035,0x7f1a0557,0x3202159b,0x000000c4}},	//   aiet_, _біду_, ecky_,
  { {0xe47b000b,0xf8bf0061,0x3ead0bb2,0xdfa60012}},	//   אריכ, nsée_, biet_, _احذي
  { {0x3ead159c,0x59aa0011,0xf8bf0025,0x6d4414ec}},	//   ciet_, _चेहर, isée_, ktia
  { {0xa3e80011,0xd7f10081,0xe10b0009,0x6ec50012}},	//   मेत_, _rãi_, ְּךָ, _بتلق
  { {0xb0ba0037,0x98ab000d,0x321d0002,0x67350034}},	//   ेविग, ducă_, zawy_, tuzj
  { {0x6d44016d,0xfebb0012,0x48a80367,0x9ca50012}},	//   etia, هارت_, стям_, _بإنن
  { {0x38610052,0xb3b70009,0xbd450012,0x15150148}},	//   _wahr_, _לפוג_, ينزي, ждая
  { {0x94190048,0x84e90012,0x98ba0011,0x44f4159d}},	// [2f30] ижат_, لفرق_, ेवाए, зпус
  { {0x3ead0039,0x3c780009,0x7c3a159e,0xcc7800af}},	//   ziet_, סָּב, ngtr, סְּר
  { {0xd3710003,0x321d0002,0x9b590148,0xd9f90357}},	//   بها_, tawy_, риет_, анец_
  { {0x6721000e,0x7a44000e,0xddc90027,0x7e6200d9}},	//   álju, mító, vjež, _naop
  { {0xa924002d,0x2bcf159f,0x321d0002,0x3ead0a5c}},	//   зділ, _सुना, rawy_, viet_
  { {0x2003003e,0xa0691003,0xd7090df8,0xd0060048}},	//   ncji_, рака_, анке_, оеше_
  { {0x3ead0039,0x0309000b,0x7d0d038e,0x9b090009}},	//   tiet_, _כִּֽ, lpas, _כִּ֥
  { {0x7d0d15a0,0x2f540024,0xdd090064,0x442715a1}},	//   opas, ятіс, _môžt, _sdn_
  { {0x2003003e,0x8d55002d,0x361c000b,0x0c790015}},	//   kcji_, ітич, אוחד, асны_
  { {0x3ead0039,0x8d5c000b,0x4b250129,0x22b60035}},	//   siet_, רכזי, омов, māki_
  { {0xfbd10003,0x2909008e,0x22b60035,0x3ead0035}},	//   بتة_, _ataa_, lāki_, piet_
  { {0x28d20011,0xaac90011,0x68fb00e6,0x7d0d016d}},	//   _दीजि, िकिक, _kuud, kpas
  { {0x2d820033,0x6abd01e3,0x28a60011,0x68fb079f}},	//   øket_, érfa, कोवि, _juud
  { {0x68fb0005,0xfc460066,0xc5f20009,0x64b80011}},	//   _muud, čích_, _חדד_, _आदेश
  { {0x6b830c60,0x6457041d,0x7d0d15a2,0x9aa60012}},	//   ängl, dexi, epas, _ومتو
  { {0x2733001a,0x61f6024c,0x6e3b00b6,0x6d4415a3}},	//   ạng_, _ugyl, ngub, ttia
  { {0x7d0d0101,0x6496000d,0x34aa0001,0x201a016d}},	// [2f40] gpas, _mâin, авао_, _tepi_
  { {0xe3b20003,0xd00a0001,0x1426002d,0x0c260024}},	//   ورا_, _њене_, ідем, імен
  { {0xe1fa096e,0x395f005e,0x5f460012,0xf8bf0025}},	//   аге_, _asus_, _بنجل, usée_
  { {0x316d012e,0x366a0001,0xe7db0009,0x5aca003c}},	//   _brez_, _тамо_, _כקיש, шлем_
  { {0x1874007c,0xf8bf0061,0xc9830015,0xacea0003}},	//   згля, ssée_, дущи, _نرسل_
  { {0x2bcf01e1,0xf993000b,0xf72a0015,0xe571000b}},	//   _सुभा, ורד_, аций_, _אַל_
  { {0xab270046,0x7bdc001e,0x66040064,0x907b0009}},	//   _мора_, _uzru, ocik, יטסי
  { {0x6496004b,0x22b60035,0x660415a4,0x01da0012}},	//   _câin, bāki_, ncik, _نوزع_
  { {0x20030002,0x7afc024c,0x60260048,0xdcba0048}},	//   ycji_, _hurt, _мдаа, ищо_
  { {0x6282004a,0x7afc15a5,0x752400b8,0xbcfb15a6}},	//   ljoo, _kurt, isiz, _trév
  { {0xa3e40044,0x93fb000b,0x1bfb0009,0x4bfb0009}},	//   पें_, יליי, יליב, יליס
  { {0xa75b0009,0x75241448,0x2d8200b0,0x394615a7}},	//   _כדבר, ksiz, økes_, otos_
  { {0xfee90003,0xa2b20037,0x50670014,0x6ef50010}},	//   _اعلى_, _आगन्, отва, _išba
  { {0x394615a8,0x2733001a,0xf8ca0011,0x6e2015a9}},	//   itos_, ụng_, ाकिय, lamb
  { {0xeeab0001,0x20030034,0xe4370009,0x5c370009}},	//   атак_, rcji_, _ורוח_, _וטוב_
  { {0x6e2000c6,0xc333000b,0x539b000b,0x644e15aa}},	//   namb, _חוק_, _כיוו, _abbi
  { {0x7a44000e,0x3ebe0028,0x20030002,0x55070014}},	// [2f50] sító, étta_, pcji_, ючва
  { {0xd5b8002d,0xc058002d,0x68fb019a,0x7afc15ab}},	//   іст_, _дію_, _ruud, _burt
  { {0xd4980001,0x68fb0b4b,0x32550021,0xaa55004c}},	//   црт_, _suud, звер, звеш
  { {0x68fb0005,0x7d0d15ac,0x6738001b,0xc2c40012}},	//   _puud, ppas, duvj, ويلي
  { {0x661d001e,0x4e7a000b,0xc6170037,0xcad8000b}},	//   _iesk, _הארצ, तरीय_, קודת_
  { {0x80a8002d,0x22b6001e,0x7afc15ad,0x1d160009}},	//   овів_, rāki_, _furt, _מקשר_
  { {0x44210db2,0x661d15ae,0x389c0009,0x8cba0011}},	//   mah_, _kesk, שיונ, ्वरो
  { {0x442100ec,0xba77000a,0xbcfb0065,0x5fbc000b}},	//   lah_, _باست, _frét, יצונ
  { {0x661d00c6,0x2d8b0108,0x39460844,0x7d09004c}},	//   _mesk, âce_, ctos_, љног_
  { {0xd0110003,0x442112a6,0x1c4500b3,0xddd90034}},	//   _ألا_, nah_, чном, _pawł
  { {0x2d820033,0x764f0034,0x0bb50048,0x69c600b0}},	//   øker_, _obcy, ящия, _øker
  { {0xf8a9000b,0x661d15af,0x3a9a04a5,0x442115b0}},	//   _גש_, _nesk, стою_, hah_
  { {0x442115b1,0xed58002d,0xc5fa0009,0x15fa0009}},	//   kah_, _мої_, _הפנט, _ההנע
  { {0x20cb0044,0x2bc60037,0xd0070015,0x442115b2}},	//   िविध, _रुका, зере_, jah_
  { {0x442115b3,0x66e615b4,0x8c1a000b,0x96960593}},	//   dah_, зова, _הוצי, праш
  { {0xe7370046,0x39460010,0x7524003a,0xe2a90012}},	//   џет_, ytos_, tsiz, _واين_
  { {0xf5390029,0xba9b000b,0x9a3b000b,0xa2b7000b}},	// [2f60] nuť_, _לסקי, _התפק, _מפקד_
  { {0x661d0051,0x752415b5,0x442115b6,0x7afc0ce4}},	//   _eesk, rsiz, gah_, _purt
  { {0xbcfb0061,0x6ffb0009,0xb7fb0009,0xd7fb0009}},	//   _brés, _להיפ, _לפית, _להיל
  { {0xbcfb0061,0xdcb1001a,0x254e0035,0xdb230030}},	//   _prét, hỉ_, tēlā_, írán
  { {0x4421046c,0x2bac0011,0xf8bf0025,0x22b809df}},	//   bah_, _टेरा, crés_, nčki_
  { {0x442115b7,0x4ddb0009,0xcfb60009,0x661d0034}},	//   cah_, _לחכו, ּלֵי_, _zesk
  { {0x7c21000f,0xfbc3002d,0xb4d80037,0x7ae4004a}},	//   dalr, _збро, ाती_, _ohit
  { {0x3da6007c,0x2bcf0044,0xb3bb000b,0xdb1c0002}},	//   зроб, _सुधा, _המלכ, _wyró
  { {0xc9860003,0xc27b0009,0xd6570009,0xa3e80011}},	//   _عشري, _פרמי, ליקת_, मेर_
  { {0xc19b000b,0x6e2015b8,0x219b0009,0x50650012}},	//   _השמי, samb, _הבמא, _يطلق
  { {0x623505f7,0xba190012,0x547b00af,0x000000c4}},	//   мену, ييدا_, צטטו,
  { {0xc3330093,0x0bb7000b,0x22b6001e,0x201e11c9}},	//   עור_, ללים_, kāku_, _heti_
  { {0x44210755,0x5bb90037,0xa6e20097,0x661d15b9}},	//   yah_, _आश्व, æðuh, _resk
  { {0x212d0013,0x7ae40005,0xa3b4007c,0x661d0066}},	//   šeho_, _ehit, _облі, _sesk
  { {0x442115ba,0x4fc41390,0xa9230073,0xc7c405d4}},	//   vah_, еста, ėžia, ести
  { {0x3bbb0093,0x442100c6,0x645a15bb,0x201e04d2}},	//   _למוד, wah_, leti, _leti_
  { {0x98dc0037,0x443e0227,0x22b60035,0x32220034}},	// [2f70] यताए, ogt_, gāku_, óryś_
  { {0x6728001c,0xa2c50037,0x3ea0002c,0xd37b0014}},	//   _ovdj, रवक्, ahit_, йче_
  { {0x442100ec,0xd6d1000a,0xbcfb0108,0xa3e80044}},	//   rah_, _لقد_, _prés, मेल_
  { {0xd9990003,0xf8bf15bc,0x6abd0033,0x22b6001e}},	//   ينات_, prés_, nnsf, bāku_
  { {0xf194002d,0x645a15bd,0x61140934,0x442115be}},	//   ниць, keti, едчу, pah_
  { {0x443e0070,0xddcd0034,0x645a15bf,0x69cb0aaa}},	//   jgt_, reań, jeti, _øgeu
  { {0x201e0029,0x7c21002a,0xe8480012,0xbcfb0025}},	//   _deti_, valr, سجون_, _trés
  { {0x22b6001e,0x443e15c0,0xf5090337,0x645a15c1}},	//   nākt_, egt_, онил_, eeti
  { {0xdddd003e,0x6298001e,0x02440012,0x69c600b0}},	//   _hasł, īvot, _سَلَ, _økep
  { {0x201e0028,0x443e03ce,0x51f40012,0x27e00030}},	//   _geti_, ggt_, _أسفر, řina_
  { {0x9c870066,0x22b6001e,0xe1ff01e3,0x656d005e}},	//   _začá, zāku_, rdón_, hvah
  { {0xe5690012,0x443e15c2,0xf8c60011,0xe2970367}},	//   _ومضى_, agt_, लक्प, даю_
  { {0x36340012,0xf4290223,0x7c29003c,0xd1830223}},	//   _أرمس, _долл_, _долг_, вляй
  { {0x17fa0003,0x7ae415c3,0xacfa0009,0x01360009}},	//   ترحة_, _whit, _והסכ, ורשת_
  { {0x7e66002c,0x5c140012,0x7ae40132,0x6d4915c4}},	//   _pakp, _أظهر, _thit, ltea
  { {0xe8d90020,0x22b6001e,0xbae60012,0x53360009}},	//   _trở_, tāku_, _تكبي, _חנקן_
  { {0x75d3000a,0xceb20009,0x448a004c,0x24990035}},	// [2f80] نيفا, דין_, обан_, ūsmu_
  { {0xb4d80044,0x22b6001e,0x045a0003,0xeb9a0012}},	//   ाते_, rāku_, تلطة_, يضات_
  { {0xa3e80044,0x307b000b,0x69c1003a,0xa87b000b}},	//   में_, _ואינ, şlet, _ואיר
  { {0x22b6001e,0xeb97003c,0xe9da0a41,0x201e15c5}},	//   māks_, ьих_, оке_, _seti_
  { {0xba48007a,0xbcfb0061,0x645a003a,0x22b6001e}},	//   _grįž, _fréq, yeti, lāks_
  { {0xd00f0003,0x2bc60011,0xf2bb0011,0x6e240031}},	//   لله_, _रुझा, _उद्घ, laib
  { {0x22b6001e,0x9f980109,0xe29a00b3,0x645a15c6}},	//   nāks_, явку_, _дав_, veti
  { {0x98a60034,0xebe30223,0x7bc10073,0xb5fb0030}},	//   kroć_, _росп, _žlug, _snáz
  { {0xdddd0002,0xe4c6003c,0xbed70009,0x63ae0073}},	//   _zasł, дённ, ווקז_, žinė
  { {0x7d7b0009,0x28130012,0x2bcf0011,0x84e70012}},	//   קניו, _لوكس, _सुहा, وفيق_
  { {0x764d00a2,0x40eb000b,0xb21b0058,0x6e24002c}},	//   yfay, _וַאֲ, bjæl, kaib
  { {0xbb930015,0x6b8300a8,0xdddd0029,0x07b70012}},	//   тающ, ängi, _hosť, _تهمة_
  { {0x65960003,0x6d49000d,0x20f90037,0x7c2e0027}},	//   _تجار, ctea, ंदेश_, _odbr
  { {0xf993000b,0xddc20034,0x69c50032,0xe50500ae}},	//   דרש_, _mnoż, ßhei, _أبني
  { {0xdfd80014,0x22b6001e,0x7c3b0009,0xdc3b0009}},	//   дът_, gāks_, _ותוס, _ועור
  { {0xd5e20011,0x656d07a5,0x6e24068e,0x000000c4}},	//   _पराज, _šahi, gaib,
  { {0x290001d7,0x99840012,0x88c70012,0x95390048}},	// [2f90] _guia_, _لليو, _يتخل, язат_
  { {0x22b600cd,0x61e0003a,0xfc300012,0x40950012}},	//   sākt_, ümle, لحم_, _ألدر
  { {0x656d0005,0x5a350103,0x9f45008e,0x290d004b}},	//   svah, енет, älä_, _stea_
  { {0xdb0e0031,0x9dab0048,0x6e2415c7,0xda6700ae}},	//   ádáb, _дъга_, caib, بائي
  { {0x7e690026,0x78b5009b,0xd1b80012,0xd5a60012}},	//   vdep, oizv, واها_, _إف_
  { {0x2bbe0011,0x78b50035,0xd6220024,0x3f6915c8}},	//   ्थशा, nizv, _цiка, зико_
  { {0x46f50109,0xe739027f,0x8a370012,0x87240012}},	//   нчит, чей_, _يعرض, نعيم
  { {0x05650001,0x4d650001,0xc7f8000b,0x32c4003a}},	//   евин, екив, וזות_, kıya_
  { {0x22b6001e,0x7e6915c9,0x5eec0009,0x80da0011}},	//   zāks_, rdep, חַזְ, _पीके
  { {0x31780012,0xd8740012,0x6d4915ca,0xa3b40011}},	//   _تحفظ_, _لامب, rtea, _जेड_
  { {0x889a000b,0xc4d20009,0x8c1a0009,0x7a6a15cb}},	//   _צבעי, רגי_, הותי, пинг_
  { {0xc049000b,0x539a0009,0x9b920012,0x22b60035}},	//   _לז_, פירו, الَت, vāks_
  { {0xbddb0061,0xbd450012,0x2bcf0011,0xaa3a0009}},	//   _scèn, _أنتي, _सुरा, התרח
  { {0x6f010272,0x22b6001e,0xdce909d2,0x7c250032}},	//   _kulc, tāks_, oveč, jahr
  { {0xe29a0472,0xdfd20012,0x7bd80073,0x6e240031}},	//   _нак_, ايز_, _gyvu, taib
  { {0xbcfb0061,0x3ebf15cc,0xcb12000b,0xdce20027}},	//   _prép, nnut_, _גלה_, _proć
  { {0x7c25008b,0x75d60003,0x69c1003a,0x32c4003a}},	// [2fa0] fahr, ريطا, şler, cıya_
  { {0x62990070,0x05770003,0xa5bb000e,0x6e24000e}},	//   ekwo, عملة_, _adós, saib
  { {0xdce9012e,0x644115cd,0x69cb0040,0x3ebf15ce}},	//   jveč, igli, _øger, knut_
  { {0x442515cf,0x599a0009,0x2ebd0011,0xa3e40011}},	//   hal_, ּשַׁ, ्कृत, पेट_
  { {0x8dfb0009,0x4dd60012,0x26d20963,0x50660012}},	//   _מהכת, _ستحس, moyo_, ّابِ
  { {0x7c2e0058,0x6cd60003,0xa02a0003,0x6ac90011}},	//   _udbr, _أقسا, سستك_, िकॉर
  { {0xf093000b,0x82a6002d,0x59dc0037,0x645e0029}},	//   רנו_, _завж, _बरकर, mepi
  { {0x7b06001e,0x5d540014,0x2f5b0009,0x26c000b8}},	//   ēstā, вкит, פדפנ, nnio_
  { {0xfaa300b5,0x95d70048,0x35b30048,0x442e15d0}},	//   _сато, ндът_, лбър, _pdf_
  { {0x2a690005,0x645e0122,0xc3340009,0x644115d1}},	//   _saab_, nepi, ֣וֹ_, ggli
  { {0x34b7000b,0x3d170011,0xdc9b0009,0x645e15d2}},	//   תפים_, _पढ़ने_, פיטל, iepi
  { {0x3bbb000b,0x3dc60034,0x6ee515d3,0x7c250030}},	//   למיד, żowy_, tóbe, zahr
  { {0x26c0003e,0xdee31271,0x1ea90012,0x78b50035}},	//   dnio_, _соци, _تالي_, tizv
  { {0x32c4003a,0x442515d4,0x645e0944,0x26c015d5}},	//   rıya_, cal_, jepi, enio_
  { {0x7ea30005,0xdfd50015,0xd4330003,0xd4670001}},	//   _lõpe, товы, _صعوب, _чије_
  { {0x2ebd0044,0x7bdb0093,0x7c250052,0x33db000b}},	//   ्केत, _מקוו, wahr, _מחוד
  { {0x661d014d,0x2d580047,0x7d02007a,0xa2ce0037}},	// [2fb0] ðski, нить_, _juos, सवर्
  { {0x64a40046,0x6ac90037,0xe787002d,0x52c90011}},	//   гађа, िक्र, _зумо, िक्स
  { {0x212b03de,0x8c1b0009,0x7d1d0031,0x3cf10011}},	//   lsch_, פואי, ássz, ँगते_
  { {0xc333000b,0x46a50037,0xc5fe001e,0x21f50012}},	//   רוף_, _ऐतिह, šējo_, نكاس
  { {0x7d02007a,0x212b15d6,0xdd000030,0x01650337}},	//   _nuos, nsch_, čtěj, ткло
  { {0x212b0052,0x6d4d002c,0x859a0009,0xe1f00012}},	//   isch_, mtaa, _חששו, حسم_
  { {0x2bb80003,0x6e220052,0x46a5029b,0x23cf0037}},	//   _كافة_, _beob, какв, _सुंद
  { {0x7e6d00c6,0xcb120093,0x442315d7,0x442515d8}},	//   ndap, _כלל_, _hej_, wal_
  { {0x6441008b,0xc05b002d,0x6ee5000e,0x66090ff4}},	//   tgli, _ніж_, tóbb, rcek
  { {0x1fa70e0f,0x13090015,0x442315d9,0xeb99013b}},	//   _прег, мной_, _jej_, дио_
  { {0x6d4d004a,0xfaa6062c,0x644115da,0x291a0034}},	//   htaa, вано, rgli, ązań_
  { {0xddc4007d,0x645e0002,0x2ecc0037,0xe6bd0037}},	//   ndiţ, zepi, ावृत, ्कोज
  { {0x7afb000f,0x64550604,0xc9630048,0xa6960009}},	//   _miut, _obzi, авяй, _שכנה_
  { {0xe3b915db,0x442315dc,0x43850012,0x7e7d15dd}},	//   _обл_, _nej_, _للتق, _ansp
  { {0x03a2002d,0x26c00002,0x80480009,0x26d2016d}},	//   _вищо, tnio_, עֲשֶ, toyo_
  { {0x41b60003,0xcf250003,0x645512a3,0xc6c3042a}},	//   _لمعر, طرفي, _abzi, айск
  { {0x7e6b0101,0x6cd6000a,0xa4460001,0x6d4d002c}},	// [2fc0] _magp, نقرا, кнад, gtaa
  { {0x7afb01a2,0x97da0003,0x7e6b15de,0x26c015df}},	//   _aiut, _يبدأ_, _lagp, snio_
  { {0xc7a6007c,0xbfa5001a,0x8fa60063,0x109b0009}},	//   _ринк, uyệ, _ране, _חביב
  { {0x7e6b0101,0x7afb03eb,0x78a1006f,0xe2970ed4}},	//   _nagp, _ciut, _allv, ках_
  { {0xd954000a,0x7ceb0052,0xa8ea0012,0x5a330024}},	//   انتخ, dürf, وعتك_, рніт
  { {0xf7720003,0x7644003a,0x212d009b,0x5dcb0009}},	//   لاع_, lgiy, _dveh_, _חֶלְ
  { {0x7d020006,0xb17d0029,0x6b830c60,0xee86003c}},	//   _suos, _vzťa, ängt, выпо
  { {0xe6cc0037,0x3ce60011,0x1eaa0012,0x44440fa0}},	//   ावेज, _जीते_, باتي_, lg_
  { {0xceb30093,0xade3007c,0xa2cf0011,0xbd430012}},	//   ייה_, ицьк, धकर्, لنيي
  { {0x7d02004a,0x68fa0070,0xb4cc0011,0x5c7304a5}},	//   _vuos, _uitd, लवे_, альт
  { {0xdeef00e3,0xa295007c,0xc43b000b,0x83fc0027}},	//   _вы_, гані, ותיי, jeđe
  { {0x26c00010,0xfbd30009,0x98a60159,0x212b15e0}},	//   čios_, יתת_, isoč_, tsch_
  { {0xe5340015,0x3d1b0011,0x212b0032,0x6d4d0097}},	//   _сель, पीआइ_, usch_, xtaa
  { {0x8bb60003,0x2ebd0037,0x03b60003,0x444415e1}},	//   _لإعا, ्क्त, _لإعد, jg_
  { {0x87041103,0x7c2800c1,0x9f050003,0x48a8002d}},	//   ияте, madr, اورو, ттям_
  { {0x6d4d0006,0x7c2815e2,0x7e600df5,0x97570009}},	//   ttaa, ladr, nemp, כילו_
  { {0x29040017,0x7e6d00b6,0x7e6015e3,0x7afb15e4}},	// [2fd0] _numa_, rdap, iemp, _riut
  { {0x6d4d15e5,0x444415e6,0x34bf0011,0xb4bf0011}},	//   rtaa, gg_, ्वेद, ुके_
  { {0x50b8000a,0x6d4d15e7,0x7a390024,0x501a0009}},	//   _جديد_, staa, епер_, _אותו
  { {0x75d50003,0x1de20011,0x444415e8,0xf2e40024}},	//   _ميجا, _परंत, ag_, аючо
  { {0xdd86000a,0x6d400039,0x442315e9,0x2904013d}},	//   _او_, juma, _tej_, _cuma_
  { {0xe8f8002d,0x98e50003,0x7ae9002a,0x7c280029}},	//   влі_, دكتو, _whet, jadr
  { {0x7e6b01e5,0x0058000b,0x2249003a,0xa3e70037}},	//   _pagp, דשות_, _ocak_, _परि_
  { {0x660d029a,0x629d0227,0x387e0025,0xc3320009}},	//   ncak, jkso, _entr_, _לול_
  { {0x752d00c1,0x6d4015ea,0x59b70011,0x41b70011}},	//   nsaz, guma, _अधिर, _अधिस
  { {0x2001001a,0xb5fd0027,0x644515eb,0xa87b0012}},	//   _nghi_, deše, nghi, _تحرر_
  { {0x2d8202f1,0xe1ff0034,0x98af004b,0x6d4015ec}},	//   äker_, ndów_, argă_, auma
  { {0xc8690093,0x6d400914,0xcad50009,0x7c28005e}},	//   _מן_, buma, רוֹת_, aadr
  { {0x661b00c6,0xf2d2000b,0x7c2815ed,0xed590024}},	//   mbuk, מעט_, badr, _чол_
  { {0x91ba0093,0x55ba000b,0x9103016e,0x7c2815ee}},	//   תמשי, _אמנו, спре, cadr
  { {0xf8b20093,0xb4c10037,0xb8dc0037,0xe1ff0002}},	//   משך_, ्की_, _आग_, jdów_
  { {0x6b9c03ee,0x07a30024,0x7ee30012,0xe6c50012}},	//   ørge, щасн, مكّن, لتقي
  { {0x83fc001c,0x343a0003,0x764415ef,0x3f9e15f0}},	// [2fe0] ređe, فساد_, rgiy, štu_
  { {0x74160003,0xa9b20037,0xf0660a41,0x3942005e}},	//   اوضا, ीपीए, _скоп, muks_
  { {0xd62a0014,0x6d40000d,0x1ec60003,0xc3050012}},	//   _поне_, zuma, _مقدّ, لبنو
  { {0x7524003a,0x644515f1,0xba450024,0x9c7c0030}},	//   _çizg, aghi, ихій, mlče
  { {0x38a20065,0x39420051,0x7bdc0034,0x6b830248}},	//   _aðra_, nuks_, _wyru, ängr
  { {0x4b260003,0xc953000b,0x141a0012,0x3b260012}},	//   _معرف, צמו_, _سيرة_, _معرّ
  { {0x3a2415f2,0x3942005e,0x8cdb0009,0x7e6015f3}},	//   _temp_, huks_, _נחלת, temp
  { {0x39420005,0x1d340104,0x6b83006f,0x661b15f4}},	//   kuks_, ания, ånge, gbuk
  { {0xc0b30020,0x22930003,0x91e3002d,0x7e600947}},	//   gười_, _القس, _готе, remp
  { {0xd5630098,0xfc460066,0xd4980024,0x3942005e}},	//   стъп, _číst_, ткої_, duks_
  { {0x2ee0003a,0x9cd70009,0xf8bf0031,0x389b0009}},	//   klif_, רויה_, ssék_, _ריבנ
  { {0x52a70003,0x2bf70009,0x6aa41235,0xd1310012}},	//   اصدق, טמין_, _clif, يمج_
  { {0xc05b007c,0x629d024c,0x8d730012,0xd9f60011}},	//   нів_, rkso, _هاوا, ेशित_
  { {0x2a6d0066,0xd71b0012,0xe58b0009,0x2ee00060}},	//   žeb_, فترض_, _רָאָ, elif_
  { {0xa3b40037,0xe7840511,0x1cb70009,0x93770012}},	//   _जेल_, буто, _גלגל_, _مصير_
  { {0x7d06002c,0x6beb0009,0x8d870024,0x6e20005e}},	//   _buks, _אַחַ, лузд, _õmbl
  { {0xb5fd0159,0x660d016d,0x29040030,0x9df90048}},	// [2ff0] peše, rcak, ímat_, тнат_
  { {0x628000c5,0x752d00c1,0x95d80015,0xadf4004c}},	//   _anmo, rsaz, удут_, спуш
  { {0x60fa000b,0x04c80003,0x70fa000b,0x7ae3004b}},	//   _שהתק, دولي_, _שהתח, înto
  { {0x7ceb07a4,0xc3330009,0xe9190024,0xe2980024}},	//   würd, מוע_, воді_, лає_
  { {0xe1ff0002,0xe969003c,0x216915f5,0xca380009}},	//   rdów_, талл_, тили_, רנדה_
  { {0xf487002d,0x3ea9000e,0xe53a0009,0xc9b80009}},	//   _сумн, lhat_, _בתשר, נהגת_
  { {0x07a5010c,0x28980009,0xafe50024,0xc7a50048}},	//   райн, רדון_, шокл, рийк
  { {0x753b00c1,0x661b002c,0x8d550021,0xdd910012}},	//   truz, ubuk, аточ, قوع_
  { {0x661b00c6,0x31580003,0xc0470003,0xd5b10003}},	//   rbuk, _مجلة_, _مخاو, تفظ_
  { {0xb4c10037,0x753b15f6,0xb9940012,0x929d0034}},	//   ्के_, rruz, _الْب, _biłg
  { {0x6a860098,0xe2860ac5,0x4c820024,0xf9890009}},	//   ална, ални, ілюв, _קר_
  { {0x39420005,0x7f4300c1,0x8bd6000b,0x03d60009}},	//   tuks_, munq, יותו_, יותם_
  { {0xcad6000b,0x3ea9000e,0x7f4300c1,0xfad60009}},	//   שורת_, dhat_, lunq, שורך_
  { {0x8f00002d,0x7c270066,0x3ea900b6,0xa06a0001}},	//   цiї_, _nejr, ehat_, њава_
  { {0x4cba000b,0x1cba000b,0x39420051,0x6d5d050d}},	//   _במסג, _במסע, suks_, _apsa
  { {0x39420051,0xed5a004c,0x7d06005e,0xb5c60024}},	//   puks_, коб_, _puks, айбл

  { {0x94260015,0x1d070014,0xbe130012,0xa5070048}},	// [3000] имае, иети_, توقع, иета_
  { {0x44270013,0x7524003a,0x3ea9002c,0xa99b0009}},	//   _jen_, _çize, ahat_, _סביר
  { {0xa3d30044,0xe9df02d1,0x5b360003,0x73360012}},	//   _हुआ_, ngún_, شعار, شرائ
  { {0x44270026,0x3ea915f7,0xbbe90012,0xfaa6004c}},	//   _len_, chat_, اركم_, јадо
  { {0x61e90002,0x3ebe0028,0xfe370009,0x2d8f0040}},	//   _czel, éttu_, _דרכי_, øget_
  { {0xd7f10020,0xddcd000d,0x61e9001e,0x7ceb030f}},	//   _hãy_, leaş, _dzel, türe
  { {0x8fa30001,0x61e915f8,0x6d44004b,0x56940024}},	//   жаје, _ezel, luia, йакт
  { {0x2733001a,0x3ea00137,0x7ed30012,0xe2970024}},	//   ịnh_, nkit_, يزيا, _кас_
  { {0x74c60014,0x35f30048,0xe9df01e3,0xaa3b0009}},	//   ищож, опър, egún_, _שתמח
  { {0x3ea9000f,0xed57000b,0xd91b0009,0x661d0097}},	//   zhat_, סביר_, _סובל, ðskr
  { {0x9e6604b3,0xcc770009,0xdc890009,0xc4f70012}},	//   _введ, בעיה_, רְפָ, جعيا_
  { {0x442701e4,0x96fa0003,0x96070015,0xf79b0009}},	//   _een_, _شعار_, _кэша_, _שבאמ
  { {0xa3d30044,0x1e570009,0x20d70012,0x3ea90031}},	//   _हुई_, _כשאר_, لتسج, vhat_
  { {0x3be60037,0xdfc60003,0x7aed002a,0x98b9000d}},	//   _करूँ_, كي_, _what, dusă_
  { {0x3ea9000f,0x442c093d,0xd6db0014,0x787c006f}},	//   that_, mad_, вта_, _såvä
  { {0xabfb0009,0x03c50024,0x9bfb0009,0x92b40012}},	//   _בהור, _усім, _בהוט, _وحيا
  { {0x04c90012,0x8d770012,0xfd130012,0xbc070198}},	// [3010] هوري_, جازا, تجز_, ачей
  { {0x6abd0065,0xe5c4002d,0xb5fd0692,0x442715f9}},	//   lisf, істо, neša, ún_
  { {0x7c270058,0x25ad000e,0xcb550001,0xd3710003}},	//   _vejr, zzel_, свећ, ثها_
  { {0xddc9000d,0xbad8002d,0x7ceb0052,0xbb840012}},	//   ndeţ, афії_, fürc, تلمي
  { {0xe1670001,0x6d44004b,0x63700031,0xe2900012}},	//   рђен, cuia, tóná, بذل_
  { {0x2bcf0044,0x442c0005,0xe0d8002d,0x41740003}},	//   _सुझा, jad_, аві_, غانس
  { {0x442c15fa,0xccf2000b,0x3ea60058,0xb5fd0027}},	//   dad_, _מכך_, _blot_, deša
  { {0xa3d30044,0x44270006,0x6ee50002,0x1e8505c6}},	//   _हुए_, _sen_, róbo, слим
  { {0xddc6012e,0x17e40011,0x442c0032,0xdb240097}},	//   _kakš, _गर्व_, fad_, ásöl
  { {0xddc9000d,0x442c15fb,0xd469004c,0x395f01a0}},	//   edeţ, gad_, ћине_, _ipus_
  { {0xa22a0015,0x6e2d0532,0x17fb0012,0x442715fc}},	//   лжна_, kaab, _شرطة_, _ven_
  { {0xddc60027,0x442c00ca,0xe8b20011,0x8e740012}},	//   _lakš, aad_, ुच्च, _وانض
  { {0x442715fd,0xceb20009,0x76490060,0x83fc001b}},	//   _ten_, _ציד_, mgey, ređa
  { {0x7cf00005,0x7649003a,0x6abd0028,0x7e200011}},	//   märg, lgey, érfr, बर्ग_
  { {0x31ae000e,0x3be60011,0x2bcf0011,0x78bc15fe}},	//   _közé_, _करेँ_, _सुचा, rirv
  { {0x539a000b,0x5986002d,0x42260063,0xf743004c}},	//   _תיקו, _глиб, _удив, џето
  { {0x7e640010,0x3ea015ff,0xf5ea003c,0x6e9300ae}},	// [3020] reip, rkit_, умал_, ألقا
  { {0x7ae20034,0x141a0012,0x3ea0079f,0x98b9004b}},	//   wlot, ايضة_, skit_, rusă_
  { {0x2897000b,0x2d8f0058,0xf8c8001a,0xe1ff01a0}},	//   _הדין_, øger_, hức_, bdós_
  { {0x200501a2,0x98b9000d,0x6b83006f,0x442c1600}},	//   _agli_, pusă_, ånga, zad_
  { {0x442c0101,0xb9560046,0x7cf00051,0xc05a002d}},	//   yad_, стећ, järg, гій_
  { {0x7ae200bd,0x7ea30051,0xa1570009,0x2c570030}},	//   slot, _lõpl, מבנה_, _vědí_
  { {0x442c03fb,0x3ea61601,0x2ef40024,0x07370012}},	//   vad_, _plot_, озкр, مسيب_
  { {0x442a0070,0x200500c1,0x66f80037,0x539b000b}},	//   _heb_, _egli_, ंगिक_, _גילו
  { {0x442c1602,0x142a0024,0x7c3c01e3,0x3a291603}},	//   tad_, ліно_, órro, _reap_
  { {0x442a001e,0xd12f0012,0xdce2001b,0x62841604}},	//   _jeb_, _أمل_, _prođ, _anio
  { {0xef1a029b,0x442c1605,0x38ab0260,0x7cf00032}},	//   _сме_, rad_, _sørg_, märd
  { {0xe8d9001a,0xe9f9002d,0xa7850012,0xd62706bd}},	//   _trừ_, инні_, _بشكو, _гоце_
  { {0x58870015,0xb5fd0584,0xa3b80011,0x62840034}},	//   быва, lešn, _घेर_, _dnio
  { {0xac180a25,0x6da30001,0x224d0002,0x9cf60001}},	//   _току_, _хиља, żek_, _учеш
  { {0xdbf10013,0xc7b10009,0xa2950024,0x6611008e}},	//   _přím, ֵ֑ל_, _макі, _ähkö
  { {0x59da0011,0x645c1606,0x39460073,0xf8140034}},	//   _युवर, _abri, kuos_, ężyć_
  { {0xe6940015,0xd4b90001,0xca380009,0xce940048}},	// [3030] читы, алац_, _הנחה_, чатъ
  { {0xa3cc0037,0x38ab0058,0x8c590012,0x9874003c}},	//   _रखा_, _køre_, ؤلاء_, _ельц
  { {0xce950098,0x395f000d,0xb5fd0027,0x7ae70024}},	//   _данъ, _spus_, ješn, бюдж
  { {0xdb08000e,0x7cef0058,0x77ba0009,0x645c1607}},	//   álás, pørg, _כמתח, _ebri
  { {0xc7b80027,0xddc6009b,0x7cf0006f,0x39460164}},	//   _među_, _takš, färd, guos_
  { {0x7cf01608,0xb608022d,0x58d40593,0x88c80024}},	//   gärd, _vyšš, почт, блів_
  { {0x389c000b,0x889c0009,0x02450012,0xd00e0012}},	//   ריונ, רבוי, _وَسَ, خلى_
  { {0x645c012e,0xf99f0054,0x66f20001,0xdce90027}},	//   _zbri, ncès_, мпју, oveć
  { {0xf993000a,0xa2d60037,0x5fdb0037,0xa5bb000e}},	//   _عبر_, यकर्, _मुसल, _adóz
  { {0xe58c0009,0x3c65003c,0xf8bf0025,0x65690032}},	//   רָהָ, цког, isés_, rweh
  { {0x61ed003a,0xda660a76,0x7cef0033,0x6266010c}},	//   _azal, овни, jøre, овна
  { {0xc3320093,0x6f0200c1,0xe7300003,0x7d1b1609}},	//   ווט_, _gioc, _أصل_, ppus
  { {0xdce9001c,0xc1b70037,0x3ead021e,0x62960025}},	//   jveć, _अधोग, mhet_, _voyo
  { {0x62840002,0x2ee20037,0x7188000b,0x38ab0623}},	//   _wnio, पत्त, צְרַ, _føre_
  { {0x38ab00c5,0xdfd20003,0x7d0b0028,0x2bd90037}},	//   _gøre_, ذير_, _hugs, _बुला
  { {0x7d0302dc,0x442a068b,0x4438016d,0xe61a0578}},	//   _hins, _seb_, _sdr_, рда_
  { {0x6e2b000e,0x64360003,0x54360012,0x216a0024}},	// [3040] _megb, قراء, قرار, _типи_
  { {0x61e4003a,0x27ed0066,0x98b90010,0xfe790066}},	//   _iyil, řena_, tusą_, dlům_
  { {0xbcfb0108,0x7cf00c16,0x8b6a00de,0x33660012}},	//   _spéc, värd, риев_, تهاف
  { {0xf99f0061,0x442a160a,0xd2590024,0x71660012}},	//   ccès_, _web_, йці_, قاتك
  { {0x64430d85,0xbcfb0031,0x3ead160b,0x7cf00aa0}},	//   ónic, _csés, dhet_, tärd
  { {0x3ead000e,0x2d540051,0xbefa001e,0x0f56000b}},	//   ehet_, mäe_, žģīt, ַיִם_
  { {0x7d0b0039,0xe72f0003,0xf093000b,0xb8650003}},	//   _augs, نصي_, ונג_, ثانو
  { {0x7d03160c,0x60dc00b6,0x3ead1204,0xc6f8004c}},	//   _ains, horm, ghet_, љних_
  { {0x9df70014,0x6fda01c7,0xe60f0012,0x24980031}},	//   онът_, _पुरू, خشى_, _korm_
  { {0x7cf002f1,0xd49a0015,0x26c90027,0x7d03160d}},	//   lärb, рри_, znao_, _cins
  { {0xf413000b,0xe043002d,0x6c7b0009,0x64b30012}},	//   ופת_, _інци, בריד, بحير
  { {0x7d0306f0,0x2bbd0037,0xddcd000d,0x5187004c}},	//   _eins, ्पता, ndaţ, оуга
  { {0x59c50012,0xad9b0031,0x60dc160e,0x7d03160f}},	//   سيسك, _egúj, form, _fins
  { {0x6ab70321,0x7cef0722,0xbce60012,0xf7730012}},	//   _आग्र, tøre, _بأصو, واز_
  { {0x09b70037,0xcebb0001,0x78800064,0x8c1b0009}},	//   _अध्य, аља_, _závä, _דווי
  { {0x7d0304a3,0x69da004b,0xab830198,0x02940012}},	//   _zins, ştea, _цушк, _يؤيد
  { {0x5fdb0011,0xf8bc0011,0x261a0011,0x5a9c0009}},	// [3050] _मुरल, ्चाय, बड़ी_, _כשהא
  { {0x3ead000e,0x44f4002d,0x645a0052,0xe571000b}},	//   zhet_, дпус, nfti, עַן_
  { {0xf8bf0061,0x656f0002,0xdce90027,0xc0520009}},	//   ssés_, _wsch, sveć, _אזי_
  { {0x656f0e56,0x8f880009,0x6ee50034,0x13080024}},	//   _tsch, _וְשֵ, róbk, іній_
  { {0xde8f0020,0xa924007c,0x24981610,0xaa560012}},	//   _lịch_, дділ, _form_, سلوا_
  { {0xc5fa000b,0xccf80066,0x7d0b1611,0x2795077e}},	//   _לפרט, jmě_, _rugs, зшир
  { {0x3ead0af2,0x44240024,0xbea50048,0xbf680012}},	//   thet_, _ієра, зайк, قصيم_
  { {0x32090020,0xfbd2000b,0xccf80066,0x764d01ea}},	//   _ngay_, _נתן_, emě_, ngay
  { {0x656d0032,0x645a086a,0xf5560012,0x23a00035}},	//   nwah, ffti, كليب_, _vājš_
  { {0x9980003a,0x34960009,0x6e2b0529,0x2ca91612}},	//   _afiş_, ִ֣ים_, _wegb, скоп_
  { {0x7d03014d,0x3a2d002a,0xcb690014,0x64980014}},	//   _vins, _keep_, щане_, ютър_
  { {0xde8f0020,0xa96a035c,0xe1e70012,0x216a0048}},	//   _dịch_, бима_, فس_, бими_
  { {0xb7bc0039,0x49990015,0x6ed3000d,0x290f0061}},	//   _reģi, отря_, răbd, _égal_
  { {0x23bd0044,0xf992000b,0xad1a000b,0x2d540051}},	//   ्पाद, תרך_, _הוסר, väe_
  { {0x17790047,0xd00f0003,0xfaa603ff,0x86ea0012}},	//   ость_, الف_, _нако, معرف_
  { {0x539a0093,0x8b3a0093,0x60dc0061,0x784e000e}},	//   _ליצו, _התקצ, sorm, _bőví
  { {0x60dc01e5,0x2f110028,0xa1130012,0xdb0d0064}},	// [3060] porm, _lág_, _كويت, ľkým
  { {0x3157000b,0x2905002c,0xb17b0009,0xb97b0009}},	//   _ציין_, _nila_, _פטיר, _פניי
  { {0x309b0093,0xda0a0003,0x389b000b,0x24980114}},	//   _השימ, مياه_, _היינ, _vorm_
  { {0x8717000b,0x7ceb1613,0xaae60012,0xed5a09e8}},	//   _מקטע_, büro, أسطو, _лом_
  { {0x3a37000b,0xc219002d,0x3a2d002a,0xb8660012}},	//   פרסם_, ієї_, _deep_, كاثو
  { {0x7ceb003a,0x63a10248,0x71090024,0x6e241614}},	//   nürl, kyln, іхів_, lbib
  { {0xa857000b,0xc6b60009,0x96f81615,0x7c2e0035}},	//   פיקה_, ּהִי_, оект_, _iebr
  { {0x333b0009,0xbb3b0009,0xf7730009,0x8cb60011}},	//   _לתלמ, _לעלי, תקה_, ोचको
  { {0x9c83009b,0x6143035c,0x29051616,0x50460024}},	//   ščet, _пета, _fila_, _неаб
  { {0xd00f0003,0x7338035c,0x6d44011c,0x718b0009}},	//   _ملك_, озор_, iria, _לְבַ
  { {0x9956001e,0xccf80066,0xe2f9002d,0xe8d70009}},	//   kļūt_, rmě_, жені_, _צובר_
  { {0x6d440010,0xa3bd0011,0x6b7b0009,0xdcfc0060}},	//   kria, _इधर_, צרכנ, ıyıc
  { {0xc50a000a,0x867b0093,0x51870046,0xa2ae0037}},	//   _اتصل_, _לראו, чуна, ुफ़्
  { {0x7dc50003,0xde8f001a,0x7ceb030f,0x45fb0009}},	//   _تتمك, _tịch_, gürl, _ההדג
  { {0x7b060013,0x6c5b000b,0x44770009,0x5c5b0009}},	//   ístě, _הדוח, _מעגל_, _הדוק
  { {0x6e240101,0xdce40027,0xe8d9001a,0x27ed0066}},	//   gbib, dviđ, _trữ_, řeno_
  { {0xcc990001,0x1df80015,0xa5f809cc,0x764d11d3}},	// [3070] овац_, зеты_, зету_, rgay
  { {0x656d0032,0xe827003c,0xd0110012,0x7eaa06dd}},	//   rwah, _эфио, _جلد_, _výpa
  { {0xf092000b,0xdced0027,0x98ab000d,0x656d0052}},	//   _סנט_, hvać, ască_, swah
  { {0x29051617,0x05190003,0x8f3600af,0x6d441618}},	//   _sila_, _ويجب_, _קארו_, bria
  { {0x4e7a0009,0x6d441030,0x8e960009,0x7e69005e}},	//   _וארצ, cria, _חדרו_, veep
  { {0x7c2e1619,0x2178000b,0x26f70011,0x20540048}},	//   _gebr, פתור_, ुद्र_, етър
  { {0xb4d90044,0xf7710003,0x6b830058,0x3f570061}},	//   ावी_, ئات_, ængd, nçu_
  { {0xaa580046,0x0d850015,0x7c2e161a,0x753d0031}},	//   _нису_, длин, _zebr, ászo
  { {0x29050cce,0xdb080004,0xa85506bd,0x6e2f0060}},	//   _tila_, vzdá, _окач, _mecb
  { {0x6aad0051,0xb5fd0604,0x03a5003c,0x0b59003c}},	//   _alaf, lešk, диоо, ормы_
  { {0xa91d0584,0x657b005e,0xd6db0560,0x442e161b}},	//   _drže, svuh, _лтд_, _def_
  { {0x7d0700bd,0x1fc90044,0x929d0002,0x60c30089}},	//   _lijs, िपीड, _miło, linm
  { {0x27e0003a,0x3ea2006f,0x7ceb07a4,0x6d4901c5}},	//   ğine_, ökte_, türl, quea
  { {0x1dd80044,0x6d440190,0x23290024,0x4c840024}},	//   _भुगत, vria, _доки_, _плів
  { {0x7c2e03eb,0x7ceb003a,0xdee6161c,0x9103046d}},	//   _rebr, rürl, дови, тпре
  { {0xfe790030,0x64430097,0x21a60012,0xb5fd001b}},	//   ndů_, ónin, _يمثّ, ješk
  { {0x38af00a2,0x60c3003a,0xe5720003,0x7d070070}},	// [3080] _süre_, kinm, خطأ_, _bijs
  { {0x03a60001,0x6d4402ec,0x60970012,0xf8d20011}},	//   мизо, rria, _ينيس_, _सदिय
  { {0x7cf00163,0xf6261480,0x660b00b0,0x833a0048}},	//   gära, _одно, _oggk, ючат_
  { {0x2d80001e,0x9c7c009b,0xcf930009,0xb9c60012}},	//   _šiem_, moče, _סטר_, وقاي
  { {0x9c7c02e7,0xe7c30037,0x7c2e003a,0x5fc30011}},	//   loče, _वेबप, _tebr, _वेबल
  { {0xab2a0014,0x1de10037,0x60c30028,0xfbd90011}},	//   _мога_, _पड़त, ginm, _बुकम
  { {0xb4ea0011,0x8c43004c,0x7ae4029c,0xd007004c}},	//   मती_, _јесе, _okit, меље_
  { {0x6b8300c5,0x1ef70003,0x20070029,0x3da6048c}},	//   ænge, وعية_, _únie_, дроб
  { {0xfcaa0009,0x7d6a0024,0x9c7c0030,0x8ed700ae}},	//   ַיֹּ, ішив_, hoče, بذور_
  { {0xe0860003,0xc19b0009,0xa99b0009,0x75240060}},	//   _تجري, _ושמי, _ובמר, _çizm
  { {0xf7720003,0x7eb10033,0x442e0028,0x9c7c009b}},	//   _جاء_, _håpe, _vef_, joče
  { {0xa2a10037,0xe5c6096e,0x57b70009,0x4b370009}},	//   कॉप्, _осло, _קלאב_, ורטל_
  { {0xb9e4002d,0xa91d009b,0x4efb0009,0x7e620018}},	//   віри, _trže, _והאו, _ibop
  { {0x39460149,0x26c4080a,0x3d1c0037,0x8f0d0011}},	//   iros_, limo_, _पढ़ें_, _ढूँढ़_
  { {0x9c7c012e,0x248d001a,0x4fc40055,0x7d070227}},	//   goče, _đem_, вста, _rijs
  { {0x3f570061,0x8f9b000b,0x39460010,0x60c3003a}},	//   rçu_, חילי, kros_, zinm
  { {0x2fdf003e,0xf1a7002d,0xb5fd09d2,0x72340012}},	// [3090] ług_, _ірин, vešk, _شريط
  { {0x9c7c161d,0xa7750339,0xebc70001,0x3f8101bd}},	//   ločb, _злоч, мљен, _trhu_
  { {0x26c4007a,0xeb090003,0x38ab0058,0x20100029}},	//   kimo_, أقصى_, _børn_, áliť_
  { {0xd627000a,0x26c4007a,0x6ffa0009,0x99d70012}},	//   _تعدي, jimo_, _מהתפ, وتشا
  { {0xae1a000b,0xe1ff000e,0xe9ce0014,0xb2360012}},	//   _מורכ, deók_, ук_, ركوا_
  { {0x7cf0161e,0x7b670014,0xe1f00003,0x28a7003c}},	//   pära, _отбе, جسم_, ьшег
  { {0x9aa50012,0xa5bb0018,0xc8780060,0x6d4d079b}},	//   _كمسو, _geór, _dağ_, luaa
  { {0x39460844,0x4431000e,0x26c40010,0xee390146}},	//   bros_, _hez_, gimo_, чни_
  { {0xc05b007c,0x4431003a,0x2f1511bf,0x98ef0037}},	//   _між_, _kez_, _låg_, छताछ_
  { {0xd011000a,0xb5fd007a,0x16010037,0x7afd0227}},	//   _إلا_, neši, लेयर_, emst
  { {0xc2c6000a,0x3ea9003a,0xf1c50037,0x13e90015}},	//   فيدي, kkat_, _लेबन, ямой_
  { {0xeab20003,0xc5d5002d,0x7cf0006f,0xff7a000b}},	//   اعد_, _піль, järn, _מטעמ
  { {0xbda70003,0x3eaf001e,0x7e6d004b,0xeab20009}},	//   _تحاو, _ilgt_, deap, רֹת_
  { {0x6ee5003e,0x0ef80037,0x6d4d0051,0x26fa0037}},	//   róbu, ंग्स_, duaa, ्द्र_
  { {0x7ea30005,0x645c0054,0xf7670012,0xfc560009}},	//   _lõpu, òrie, دا_, _נבקש_
  { {0x9c7c080f,0x7e7b00b6,0x3ea90a60,0x7eaa0042}},	//   roče, ndup, gkat_, _výpo
  { {0xceb2000b,0x9c7c0159,0x61e9016d,0x4431086f}},	// [30a0] אין_, soče, _nyel, _bez_
  { {0x39460149,0xb9db000b,0x44310029,0x2d800010}},	//   vros_, _מחפש, _cez_, _šiek_
  { {0x90570009,0x44310017,0x7b09003a,0xc5e9000b}},	//   _אביו_, _dez_, _üstü, צד_
  { {0xe8d90020,0x3ea90163,0xa50a0731,0x39460583}},	//   _trợ_, ckat_, _нема_, tros_
  { {0xf5390026,0x44310017,0x83fc0027,0x26c4161f}},	//   jsť_, _fez_, ređi, vimo_
  { {0x20070054,0xd00f0003,0xfce60024,0xf8bf0025}},	//   _únic_, مله_, _чого, ppée_
  { {0xf5390029,0xde8f001a,0x232a06bd,0x25fc0011}},	//   esť_, _vịnh_, _хоби_, लेरी_
  { {0x38b4006f,0x2b470066,0xcf930009,0x17570009}},	//   _färg_, ánce_, רטה_, גסקר_
  { {0xceb3000b,0x2d800017,0xa3bc0011,0x7ae20dcf}},	//   טיה_, nvie_, इज़र_, moot
  { {0x26c41620,0xed57000b,0x387a0029,0xe0850003}},	//   simo_, עביר_, _napr_, _لجمي
  { {0xa4b7000b,0xe7e00037,0xcf890003,0x26c404cf}},	//   גליה_, _खुला_, _يضمن_, pimo_
  { {0x67ce000e,0xd337000b,0x9e730012,0x2912016d}},	//   zőjé, ערכה_, _مهمت, _buya_
  { {0x29120164,0x245800b3,0x2f15130b,0x0e9b0009}},	//   _cuya_, _жаль_, _såg_, _משאל
  { {0x916d0020,0x9b940003,0xdfc60003,0x251b0009}},	//   _hộp_, _للتت, لي_, _צווא
  { {0xe7db0044,0x30a40014,0x7e6d000d,0x64430d85}},	//   _मुखप, уряв, teap, ónim
  { {0x6d4d0269,0x9f470030,0x3ea91621,0x63a50ca4}},	//   tuaa, _ání_, ukat_, vyhn
  { {0x99840003,0xdce40002,0x6c550015,0x67ce000e}},	// [30b0] _مليو, zwią, ккау, tőjé
  { {0x8c440001,0x3ea91622,0x2f150248,0x47d500ae}},	//   леђе, skat_, _tåg_, _ليخر
  { {0x6e360101,0x92590015,0x4431060e,0x50d40003}},	//   bayb, дает_, _vez_, _حزير
  { {0x916d001a,0x9f96000b,0xd337000b,0x67ce000e}},	//   _nộp_, _סדרה_, תראה_, sőjé
  { {0xa3de0066,0x7e9a0009,0x8e360009,0x6d5b1623}},	//   _věří_, _חסרו, _שנשא_, xtua
  { {0xf7710012,0x67550012,0x91bc0009,0x3f690934}},	//   لاب_, نخبر, המדי, дико_
  { {0xa91d048b,0x2c160011,0x61e90034,0xc0520009}},	//   _drža, दुओं_, _wyel, ׁ֖ה_
  { {0x6d5b1624,0x6a140012,0xee090b2b,0x056503d2}},	//   ttua, _مبكر, мейл_, ввин
  { {0x6b9c0051,0xc212000b,0x98e10037,0x3ea2006f}},	//   ärgn, _כהן_, पकाए, ökta_
  { {0xb4bd0037,0xfc310003,0x27e0004b,0x69da0060}},	//   ीचे_, جحة_, şina_, ştek
  { {0xf412000b,0x2b1400b3,0x8c1a0009,0x29121625}},	//   יפי_, льяр, וותי, _suya_
  { {0xa6c90012,0x5d850012,0x83fc001b,0x752f0034}},	//   _توصل_, _للصل, jeđu, _owcz
  { {0x6a3a000b,0x6e2900b6,0xe3b8003a,0x645c0054}},	//   וגרפ, mbeb, azı_, òric
  { {0x6b650047,0x64a20098,0x68e31626,0x6d5c004b}},	//   _акка, _ваша, nond, ărat
  { {0xc052000b,0xafe60055,0xe73a003c,0x2aa20034}},	//   יזם_, товл, ьев_, _dóbr_
  { {0xd0070001,0x7984016d,0x291201e3,0x661b016d}},	//   ђете_, _triw, _tuya_, ncuk
  { {0xe0da0001,0x9c7c009b,0x68e31627,0xf50a0048}},	// [30c0] _ови_, loča, kond, днал_
  { {0x31370093,0x2937000b,0x7ebe0010,0x2d801628}},	//   _שנים_, _שאין_, rūpi, rvie_
  { {0x8c42003a,0x38b4006f,0x7ae209de,0xaac60011}},	//   _öğen, _värd_, toot, _लगाक
  { {0x0a670001,0xbb430015,0x20070064,0x232706bd}},	//   врши_, рецк, _únia_, тоци_
  { {0xb1cd0009,0x39130012,0x7ae21629,0x6e290032}},	//   ּמוֹ, لونز, root, dbeb
  { {0x91bb000b,0xc1730009,0xf8630024,0x75240060}},	//   ומני, יחד_, ивчо, _çizi
  { {0xb8ea0037,0x98a30001,0x547b0009,0xa9070012}},	//   _लग_, рије, _קטלו, خيول_
  { {0x63a303f3,0x8e840012,0x7ceb0032,0x9c7c001b}},	//   änne, الظه, fürw, doča
  { {0x26d20101,0x6ee50029,0x71650012,0xa26a0034}},	//   inyo_, tóbr, _مالك, zęść_
  { {0x8ffa0003,0xcb98002d,0xc1570009,0x9ffa0012}},	//   _قرار_, евої_, _בשמו_, _قراء_
  { {0xdce2009b,0x9c7c009b,0xda35003c,0xdb54003c}},	//   _upoč, goča, лены, ывны
  { {0x66e3002d,0xc6a30001,0xd7ef0012,0xa91d001b}},	//   _коха, _врши, _بكم_, _mržn
  { {0xc05b002d,0x61f60002,0x6d49162a,0xe9470048}},	//   мів_, _czyl, crea, ъхно
  { {0x929d0002,0xa3b20011,0xdce60035,0x38d400af}},	//   _piłk, टना_, īmēj, אֵֽל_
  { {0x290c162b,0x40340015,0x92b70012,0xcfa4004c}},	//   _mida_, ресс, _لحظا, ашти
  { {0x2f18000f,0x68e30070,0xa3e60037,0x877b000b}},	//   _még_, zond, _पड़_, ואלי
  { {0x83fc0027,0x15180012,0xd684004c,0xbdf5004c}},	// [30d0] ređu, نزلة_, јусп, упај
  { {0x6adb0044,0xb5fd0027,0x1bbb0012,0xd3a70063}},	//   यक्र, mešt, واضع_, креп
  { {0x68e300bd,0xfbd00003,0xddc40010,0x3ed50012}},	//   vond, يتم_, reiš, _مقدر
  { {0xe298002d,0x25de0037,0x02440012,0x68e30227}},	//   кає_, _कुकी_, لَمَ, wond
  { {0x7abc0093,0x4a44002d,0x38b40052,0xb5fd0010}},	//   וצאו, рнів, _wäre_, nešt
  { {0x69da0052,0xab2b0012,0x63a80040,0x4f790048}},	//   ßtei, _يسأل_, kydn, ещия_
  { {0x68e3162c,0xfe710003,0xdce40002,0x57a40001}},	//   rond, مدة_, jwię, ишћа
  { {0x68e30732,0x7cf003d5,0xe57907e8,0x0f580009}},	//   sond, järj, ези_, דיהם_
  { {0xb5fd0027,0x64680028,0x68e3162d,0xceb40009}},	//   ješt, _þrið, pond, ייק_
  { {0xdb0a0030,0xd9280009,0x753b0060,0x38ab162e}},	//   ěním, _יֵעָ, rsuz, _mørk_
  { {0x7e550012,0x2d8600b8,0x645c01a0,0x7e7d004b}},	//   _مناص, _eroe_, òria, _oasp
  { {0x9c7c012e,0x6d5c000d,0x92b60012,0x7e7d162f}},	//   roča, ărar, احدا, _nasp
  { {0x45450003,0xa2b50011,0xc956003c,0x7cf00032}},	//   _إنتق, ॉफ़्, ытны, wärm
  { {0x9c7c1630,0xdddd003e,0x290c0051,0xdd8e0012}},	//   ločn, _obsł, öda_, _روى_
  { {0xaa7b014d,0x6446007a,0x9cda000b,0x7afb0051}},	//   glýs, ėkit, _אקספ, _ohut
  { {0xa3d70044,0x7ea30051,0xeab20012,0x3ead1631}},	//   ापन_, _sõpr, _دعت_, nket_
  { {0x9586003c,0xdb020031,0x6e930012,0x7c351632}},	// [30e0] ылае, szló, حلقا, _bezr
  { {0xddc60107,0x7cf01633,0x71bb0009,0xa9bb0009}},	//   _takž, märk, _נציג, _נזיר
  { {0x3940045d,0x290c0051,0x0b46002d,0xe5050003}},	//   _hvis_, _rida_, унен, شبكي
  { {0xbae5007c,0x290c1634,0xe9da0838,0x8f9b0009}},	//   ацій, _sida_, нке_, _ניכי
  { {0x5a33002d,0xc1e7064f,0x64430404,0xb5fd001e}},	//   сніт, льше_, _odni, iešs
  { {0xf7720003,0xa91d03ca,0xf9870012,0xe9f90081}},	//   ماع_, _tržn, انوي_, _hoả_
  { {0x69dc003e,0xab78007e,0xdb78000b,0x3378000b}},	//   _śred, _בְּי, _בְּש, _בְּב
  { {0x6b9c0051,0x6443000e,0x2f18000e,0x1ab80011}},	//   ärgm, _adni, _vég_, _आतिथ
  { {0x45d40001,0x7ae61635,0xe0560012,0x7e640097}},	//   ропс, dokt, _مخاب, ifip
  { {0xb5fd001c,0x443a1636,0x7ea30005,0x5b260109}},	//   vešt, nap_, _lõpp, льма
  { {0x3b630047,0x8f450024,0x44f70012,0xdfcf0012}},	//   бъяв, _вхід, دريج_, _فيك_
  { {0x690b0002,0x3ead1637,0x171b0009,0x2e160012}},	//   _eżel, cket_, _נודע, _إباح
  { {0x7e7d1638,0xc8f50048,0x63ba0031,0x6e3d0097}},	//   _rasp, измъ, sztn, ðsbe
  { {0xed57015a,0x6b9c00c5,0xfd57000b,0xdc180035}},	//   _עבור_, ørgs, _עשוי_, nāļi
  { {0x7e7d039c,0x443a00c6,0x8c1b000b,0x9f350024}},	//   _pasp, dap_, _אווי, ребі
  { {0x4ea40046,0xc333000b,0xaa7b0028,0x7c3a1639}},	//   бруа, _פופ_, rlýs, latr
  { {0xdd940015,0xf4870001,0xc5170012,0x84350024}},	// [30f0] баты, лужн, ابرت, инає
  { {0xaa7b014d,0x443a0160,0x25a90115,0x27e00030}},	//   plýs, gap_, ryal_, řiny_
  { {0xd371000a,0x5215010c,0x25a90be2,0xf0920009}},	//   تها_, адет, syal_, _וני_
  { {0xf53f0163,0xa3c30066,0x7c3a05cd,0xc1750009}},	//   _två_, náší_, hatr, ֹחַ_
  { {0x210f0037,0x9c7c0159,0xae010011,0x463a0009}},	//   ादेश_, vočn, लेशन_, _בערע
  { {0x07a50098,0xa0690046,0x8fa50014,0x6b83006f}},	//   иалн, така_, иале, ångs
  { {0x78a102d1,0xc4d2000b,0x9c7c163a,0x00580009}},	//   _volv, _וגם_, točn, אשות_
  { {0x46a500de,0x0f7c0009,0x7c3a163b,0x78a1163c}},	//   раив, תאהב, eatr, _wolv
  { {0x38b4006f,0x6d46163d,0x8c950024,0xe9190024}},	//   _lära_, škan, арні, _розі_
  { {0xa2a10037,0x98f70003,0x99d40003,0x629d0066}},	//   कॉर्, _إثرا, _اتفا, ejso
  { {0x9c7c0027,0x38b4006f,0x2d820033,0x9aa60012}},	//   počn, _nära_, åker_, لمدو
  { {0x8b080066,0x7cf0031d,0x6d4d0269,0xeab20012}},	//   mořá, tärk, kraa, زعج_
  { {0x80e60012,0x7ceb0060,0x99820073,0x443a016d}},	//   لأسل, nürs, vakų_, yap_
  { {0x6e3b0052,0x6d4d13f2,0x55ba0009,0x91f60009}},	//   laub, draa, _במנו, שמשו_
  { {0x443a003a,0x7cef0033,0xe7370345,0x87060012}},	//   vap_, jøri, иер_, لبرل
  { {0x6e2d0101,0xddc6003e,0x7a0c0035,0xd6260012}},	//   gbab, _takż, _pētī, شعري
  { {0x80d60044,0x3da70014,0xe6170538,0x6d4d0b8c}},	// [3100] _बदले, акто_, рду_, graa
  { {0xe3b20003,0x25fc0037,0x7cef0989,0xb5a90003}},	//   يرا_, लेगी_, føri, دافك_
  { {0x6e3b001f,0x1ec60012,0x443a163e,0x6ecc0060}},	//   kaub, _نقدّ, rap_, aşba
  { {0x8b23002d,0x443a0827,0x63a3006f,0x7c3a0ebc}},	//   ідче, sap_, änna, zatr
  { {0x7989036c,0x7c3a15ef,0xa1ba0012,0x7cf00032}},	//   _crew, yatr, خطاء_, häri
  { {0x045a0003,0xe8d9001a,0x79890002,0xc9530009}},	//   _جلسة_, _trụ_, _drew, קמו_
  { {0xd6da0c4b,0xbb4300a6,0xdfcf0012,0x6a960024}},	//   кти_, _мерк, ويه_, _крає
  { {0xa534002d,0x2f1c000e,0xa92600b3,0x4b7b0009}},	//   бнич, _míg_, _вдал, _באלו
  { {0x4438012e,0xdddb000d,0xdd900012,0xe51c0011}},	//   _ker_, reuş, سود_, _भूमि_
  { {0x4438001c,0x62820070,0x515b000b,0xd40602ad}},	//   _jer_, ldoo, _בכמו, ияни
  { {0x44380241,0x6f040027,0xdddd001e,0x6280163f}},	//   _mer_, kmic, _pasū, _kamo
  { {0x20cd007a,0x44381640,0xdfcf0012,0x6aa40025}},	//   džia_, _ler_, _تيم_, _coif
  { {0xdd8f000a,0x094b0014,0x6f041346,0x6f0f1641}},	//   _يوم_, ъчни_, dmic, _ricc
  { {0x44380163,0x6d4d0070,0xc0510009,0x3d1a0011}},	//   _ner_, vraa, ּ֖ם_, _बढ़े_
  { {0x6f0f00c1,0x1b770003,0xacfb000b,0x34fb0009}},	//   _picc, _نصية_, _שהוכ, _שהוד
  { {0x5eb4005c,0x0bb7000b,0x4438004b,0x3acf0034}},	//   ойст, _כלום_, _aer_, tępu_
  { {0xe7ed0037,0x7aed1642,0xf5590012,0x44381643}},	// [3110] _चुना_, _ikat, طلاب_, _ber_
  { {0x7c380027,0x44381644,0xb9560009,0xa3cb0011}},	//   _jevr, _cer_, _פיתח_, _रेड_
  { {0x44381645,0x82150003,0x6d4d0647,0x7c380227}},	//   _der_, مواص, sraa, _mevr
  { {0x6e95000a,0xe695000a,0x38b90061,0x44380070}},	//   _الحا, _الحد, _mère_, _eer_
  { {0x44381646,0x7ebc000e,0x7eb50042,0xa6960009}},	//   _fer_, _képf, _nápa, _הכרה_
  { {0x44380163,0x1d16000b,0x7ceb003a,0xa3b60011}},	//   _ger_, _לקשר_, rürs, छना_
  { {0xc058002d,0x7cfd0025,0xc0d20012,0x9c7c0159}},	//   річ_, nère, ثيوب, ročl
  { {0xc7d80009,0x44211647,0x6ee40012,0x62801648}},	//   יווי_, lch_, يسيل, _gamo
  { {0x443800a2,0x9c7c012e,0xe5710003,0x44210480}},	//   _yer_, močj, سطة_, och_
  { {0x8b080066,0x44211649,0x7cf0074f,0x6280164a}},	//   pořá, nch_, täri, _zamo
  { {0x130a0015,0x7529164b,0x4421164c,0xc2090009}},	//   лной_, spez, ich_, _נה_
  { {0xcff6000b,0xfbd2000b,0xf8a9000b,0x7e770012}},	//   _הצעה_, לתי_, _אש_, _خاطئ
  { {0xd4690001,0x86c40012,0x6b8a0227,0xdce70030}},	//   _биле_, _بينن, _erfg, íměs
  { {0x7c380070,0xd7f1001a,0x7cf0084a,0x7cfd0025}},	//   _gevr, _kỹ_, päri, fère
  { {0xf412000b,0x7cfd0061,0xd7f20003,0x7eb50042}},	//   _צפה_, gère, سكر_, _zápa
  { {0x9695002d,0x16040037,0xd7f1001a,0x4438164d}},	//   оруш, शेवर_, _mỹ_, _ser_
  { {0xbea3007c,0xd257000b,0x4438164e,0xa3cb0011}},	// [3120] чатк, _השפה_, _per_, _रेत_
  { {0x99920013,0xa99b000b,0xdd8f0003,0xb4650012}},	//   _když_, _עביר, عول_, قدمه
  { {0x7f86000a,0xd838001c,0x9f5e004a,0x4438164f}},	//   _الجن, _reč_, ätä_, _ver_
  { {0xd259007c,0x6b9c0005,0x44380052,0xd8380066}},	//   иці_, ärgi, _wer_, _seč_
  { {0x628200bd,0x673b0027,0xc0ca0001,0x628001c5}},	//   rdoo, ćuje, луке_, _vamo
  { {0xdb1a0272,0x3ea7007d,0x48e30014,0x6d40006f}},	//   szté, _într_, почв, vsma
  { {0xd838066e,0xf1bf000f,0x07a30001,0x20c90012}},	//   _več_, zzá_, зајн, جبني_
  { {0xa6aa0003,0xc6f80001,0x6d461187,0xcf930009}},	//   طابق_, јних_, škam, לטו_
  { {0x54b80048,0x65641650,0xe8fa091c,0x6d401651}},	//   игия_, ntih, _бла_, usma
  { {0x38b90061,0x9c7c009b,0xd8a50012,0xdd7b0009}},	//   _père_, močk, _وإلي, נטיל
  { {0xd2510012,0x25bf004b,0xc49b0009,0x4c9b0009}},	//   وند_, azul_, אשית, אביו
  { {0x6d560101,0x38af003a,0x3f850028,0xbe850003}},	//   kuya, _türk_, ælum_, _وجنو
  { {0x9c83012e,0x44211372,0x984b0014,0x2d99004a}},	//   ščit, ych_, лява_, äset_
  { {0x7cfd0007,0x9a290081,0x661d0064,0x55770009}},	//   tère, _mươi_, ľske, _לעדן_
  { {0xbcfb0108,0xaab80037,0x38af1652,0x501b0009}},	//   _opér, _आतंक, _jüri_, רולו
  { {0xff07002d,0x7cfd0061,0xa3d70011,0xa3ec0011}},	//   сягн, rère, ापस_, _झड़प_
  { {0x69da097f,0xa5d80012,0x7cfd0025,0x9c39004c}},	// [3130] şter, مبكر_, sère, ипат_
  { {0x9d1b0093,0x6ef3003a,0x44211653,0x6f1a0daa}},	//   טומט, içbi, uch_, _outc
  { {0x443e000d,0x645a0040,0x27ed0032,0x61fb1654}},	//   iat_, igti, ßend_, _szul
  { {0x44210518,0x443e1655,0x60080009,0x798d010f}},	//   sch_, hat_, _לִרְ, _kraw
  { {0xd9450015,0x443e1656,0x9c7c0159,0xddcd0034}},	//   цели, kat_, ročj, ndaż
  { {0x0f8b0009,0x2418003c,0xdcb10081,0x929d0034}},	//   ָאֵ֑, _горы_, _ổ_, _piłs
  { {0xf3f30003,0x3eb90028,0xccf2000b,0x104801ec}},	//   _رأس_, _klst_, _חכם_, сячи_
  { {0x6f1a1657,0x9c7c01bd,0x443e0945,0x2249016d}},	//   _dutc, bočk, eat_, _ndak_
  { {0x2d8b0013,0x443e1658,0x52b50011,0x1c890012}},	//   íce_, fat_, ंसीस, لَةٌ_
  { {0xe4c5007c,0x20cd007a,0x25ad003a,0x985d001e}},	//   ійни, džio_, ryel_, gāļu_
  { {0xf989000b,0x7cf0004a,0xf3f10003,0x3ea60503}},	//   _שר_, märt, بأة_, _foot_
  { {0xef0e007c,0x6ee70003,0xae090037,0xf7700012}},	//   _ім_, _اسئل, वधान_, _سام_
  { {0x06980003,0x443e1659,0x798d165a,0x7cef0623}},	//   _دخلت_, bat_, _craw, ført
  { {0xbf020037,0x798d0bf8,0x6b6c001e,0x443e165b}},	//   लग्न_, _draw, lēgš, cat_
  { {0x752d001e,0xf0920009,0xc2c60012,0xbe3a0024}},	//   epaz, ונם_, _ويتي, ичаї_
  { {0x93bc000d,0xd7570012,0x6abd0032,0x3ad60035}},	//   rbăt, تلفت_, chsf, kāpi_
  { {0x629601e5,0x27e000a2,0x284a0024,0x98160012}},	// [3140] _inyo, ğini_, _кзпп_, _وبدا
  { {0x93bc007d,0x62860005,0x27e0160d,0x6d560060}},	//   mbăr, ldko, şini_, ruya
  { {0x3e4c0010,0x7eb50145,0x33d60024,0x14170012}},	//   lėtų_, _nápo, ціат, زينة_
  { {0x7ebc000f,0xfbd20009,0xed5a0469,0x6d560025}},	//   _képe, ותב_, _ком_, puya
  { {0x62840149,0x7c3e0010,0x88e602ad,0xddcd004b}},	//   _maio, papr, ожде, reaţ
  { {0xed43002d,0xf1b3000b,0xc866002d,0x443e1585}},	//   _інсп, וסד_, ітли, xat_
  { {0x501b0093,0x6d44165c,0x99490002,0x7ebc000e}},	//   בוצו, lsia, góły_, _lépe
  { {0x3393000a,0x443e0160,0xbe8a0001,0x7cef0058}},	//   _تلفز, wat_, рске_, kørs
  { {0x9c7c012e,0x7c3c165d,0xeeb7002d,0x443e165e}},	//   loči, _kerr, ільш_, tat_
  { {0x3e4c0010,0x62960bad,0x0caa02ad,0x38af005e}},	//   dėtų_, _anyo, ртии_, _türi_
  { {0x7cf40054,0x5f1a0011,0x43940dd8,0x3c770009}},	//   nàri, _मूल्_, чанс, חתים_
  { {0x798d003e,0x6d440179,0x6b830058,0x672d0027}},	//   _praw, ksia, ængi, ćajt
  { {0x2bb50020,0x99920002,0x443e165f,0xadb70012}},	//   ác_, _gdyż_, pat_, _وهما_
  { {0x6da30046,0x8438000a,0x7ebc0061,0x6e240164}},	//   _циља, _اكثر_, _dépe, ecib
  { {0x9c7c009b,0x69da000d,0x8bc30014,0x9a87096e}},	//   joči, ştep, _осъд, _дупл
  { {0x3f45001e,0x3704002d,0x3bbb000b,0x6ac40012}},	//   rķu_, дчув, _כמוד, _يقوم
  { {0x7ebc01c4,0xa91d00eb,0x54fe0011,0x8d770012}},	// [3150] _gépe, _trži, _उठाए_, غارا
  { {0x443c095d,0x7c3c0b45,0x44980021,0x80a40012}},	//   _jev_, _cerr, овую_, _يمين
  { {0x9c7c012e,0xa87a000b,0x69c20070,0xd2510003}},	//   goči, _האתר, ezoe, فنا_
  { {0x7cf0066d,0x539b0009,0x7bdb0009,0x877a0009}},	//   färs, ייבו, סקאו, _פארי
  { {0x7c3c1660,0xd1b80012,0x6b8e0032,0x39591661}},	//   _ferr, ياها_, _erbg, nuss_
  { {0x88c8002d,0x017c000b,0xb97c0009,0x917c0009}},	//   олів_, שָׁל, ינדי, שְׁח
  { {0xe7390047,0xf838000b,0x7cf40054,0x2ca71662}},	//   щей_, חנות_, càri, _rond_
  { {0x3eb90028,0xcee80003,0x7c3c0032,0x66de0035}},	//   óst_, يرين_, _zerr, tīka
  { {0x7cf0004a,0xa43d002d,0x628c0042,0x765b0060}},	//   märr, льнi, álož, rguy
  { {0x7ebc0061,0x6aa90070,0x7d1d1663,0x20cd0030}},	//   _répe, _hoef, _muss, užil_
  { {0xa3b90003,0x2ca70070,0x2bb50081,0xec360009}},	//   صادر_, _vond_, úc_, האתר_
  { {0x539a000b,0xd7fa0009,0x6ffa0009,0x09e6004c}},	//   צירו, _ההעל, _ההעפ, зомн
  { {0x361a0009,0xf9920012,0xa5f8004c,0x34950dc2}},	//   _הונד, ربح_, _децу_, _надр
  { {0x3e4c0010,0x71880009,0xd5d40012,0xed590030}},	//   rėtų_, קְרַ, _تتمث, muž_
  { {0xdfd2000a,0x7d1d0c7a,0xc7a60014,0x4c9a000b}},	//   رير_, _auss, чивк, _לבסו
  { {0x6d440005,0x7d150039,0x7b030051,0xd00f0003}},	//   tsia, _aizs, nõud, طلق_
  { {0xcb130093,0x6d44007a,0xb2bb0009,0xa2bb0009}},	// [3160] _אלה_, usia, _למקר, _למקט
  { {0x7cf40054,0xfb1a0012,0xf8e00011,0x6d441664}},	//   tàri, مقطع_, _नदिय, rsia
  { {0x7c3c1665,0x7d1d0025,0xb07b0009,0xd838001b}},	//   _verr, _euss, _פנטז, _uoči_
  { {0x9c7c066e,0x64411666,0x7cf40054,0x7b030051}},	//   roči, hali, ràri, jõud
  { {0x7d1d0e00,0xa1580024,0x7ebc0031,0x78a81667}},	//   _guss, іаку_, _lépc, _podv
  { {0x69c200bd,0x64411668,0x6f1e0653,0x6f090064}},	//   rzoe, jali, _kupc, emec
  { {0xf0930093,0xdfd00003,0xa3cb0037,0x69c20070}},	//   תנו_, ضية_, _रेल_, szoe
  { {0x6d55003e,0x44270028,0x26080011,0x7bdb0009}},	//   ązan, _afn_, ाइली_, _הקלו
  { {0x4d980024,0x38af0060,0x7ae31669,0x6441166a}},	//   ікою_, _kürt_, énte, fali
  { {0x31bb0093,0xc1bb000b,0x6441166b,0xe56f0003}},	//   _הזמנ, _הממש, gali, اطي_
  { {0x99840010,0xa2790001,0x7cef0260,0xa08b0009}},	//   _temų_, обну_, tørr, _לְאִ
  { {0x39590039,0x32670015,0x6441019a,0x93fb0009}},	//   tuss_, чтов, aali, מליי
  { {0x6ec50003,0x443c001e,0x6441166c,0x26d2020d}},	//   _تتلق, _tev_, bali, diyo_
  { {0xf1b00012,0x20cd0030,0x6b9c054e,0x7d7b0009}},	//   اءَ_, mžik_, ärgs, _לנדו
  { {0x34fb000b,0x6c830003,0xb4fb0009,0xd36f0024}},	//   _ההגד, _سليم, _הפגי, _яч_
  { {0x33db000b,0x2bf70009,0xc6f90024,0x1bf70009}},	//   _לחוד, _ממון_, інах_, _מצור_
  { {0x7b030051,0x27ed0034,0x9d150024,0x76930034}},	// [3170] nõue, łen_, ддач, _użył
  { {0x91bc000b,0xc1bc000b,0x19bc0009,0xad9b01e3}},	//   _למחי, _למחש, _למחב, _azúc
  { {0x23790003,0x7d15000e,0xab950012,0x7d1d0032}},	//   تماد_, _vizs, بلاغ, _wuss
  { {0x7d1d00bd,0xc333000b,0x7c250518,0x645e002c}},	//   _tuss, תוף_, schr, agpi
  { {0x69340024,0x7b03005e,0x6441166d,0xa9240024}},	//   енчу, jõue, yali, еділ
  { {0xf4840014,0x7e62166e,0xec290012,0x4dd40012}},	//   _пусн, _acop, _ذكرى_, _ستُس
  { {0x238c0066,0x6441166f,0xfe710012,0x98a20148}},	//   _něj_, vali, ندة_, тище
  { {0x67bc0009,0x64411670,0xcd290306,0xd7bc0009}},	//   ממוק, wali, ожие_, מצור
  { {0xc6480003,0x26c30010,0x15090012,0xa5f6004c}},	//   سجيل_, ėjo_, يْبٍ_, мећу_
  { {0x98db0012,0xf3490048,0x38b4005e,0xc0d50012}},	//   _ابرز_, опол_, _värk_, _غياب
  { {0x61f6008e,0x3ebf016d,0x3949108d,0x3b0a1671}},	//   _syyl, phut_, _avas_, жено_
  { {0xc0490093,0x216a0015,0xe29a0015,0x9f040003}},	//   _כז_, оими_, цам_, _كولو
  { {0xf652000b,0x21a30015,0x64411672,0x291f005e}},	//   _יצא_, виям, pali, _juua_
  { {0x3cf90037,0x9d1a0009,0xdc3c0064,0xa3bd0011}},	//   ्गों_, _ווסט, _záľu, इना_
  { {0x291f0051,0x93bc004b,0x656912e8,0x7ebc0025}},	//   _luua_, ncăl, lteh, _hépa
  { {0x61f6004a,0x8b3a0009,0x7ebc0031,0xb4b60011}},	//   _tyyl, _ותקצ, _képa, जस्_
  { {0x34aa0001,0xdd920012,0xddc20034,0xb4aa00ab}},	// [3180] овао_, خوذ_, _zdoł, оказ_
  { {0x26d20101,0x19570009,0x39570009,0xa50a004c}},	//   siyo_, _קביל_, _קשים_, цеза_
  { {0x309b000b,0xa09b000b,0x389b0009,0xb09b0009}},	//   _ושימ, _וייט, _ויינ, _וייר
  { {0xe1fa011d,0x38af1673,0xa3d405f3,0x2b47099e}},	//   оге_, _fürs_, _सेफ_, ânca_
  { {0x397a000a,0x39460010,0xa3d40011,0xdce4001b}},	//   تصاد_, usos_, _सेन_, ltič
  { {0x7e621674,0xf7720012,0xcf260012,0x7f5c0025}},	//   _scop, ناع_, وربي, ourq
  { {0x39460327,0xd7ef0021,0xdce400eb,0x63831271}},	//   ssos_, ту_, ntič, _игра
  { {0xf8bb0044,0x2f170015,0x66de001e,0x2d800bb2}},	//   _उत्प, мощь_, rīko, owie_
  { {0xe5c60015,0xe4e6002d,0x6569000e,0x786602ad}},	//   ьско, дінн, gteh, _оказ
  { {0x7ebc1675,0xdce400eb,0x80d00011,0x1fb60198}},	//   _dépa, ktič, डोमे, _осер
  { {0x4033007c,0x54570009,0x3ea20248,0x2ca7005e}},	//   _реєс, וסין_, ökts_, öndi_
  { {0x6d5b0101,0xe6930003,0x6e930012,0x5e930012}},	//   buua, _للمد, _للما, _للمط
  { {0x54a60003,0xf1b901bd,0x644e0f15,0xc2370009}},	//   _يحتف, áš_, _odbi, ורכו_
  { {0xfd4f001a,0x2d800002,0x45fb0009,0x9c7c001b}},	//   _triế, dwie_, _והדג, toču
  { {0xd7f80047,0xc588001a,0x3c77000b,0x5bc30012}},	//   дут_, _hồ_, _חתום_, _لقول
  { {0x442a08de,0xaae70012,0x44441676,0x70db0011}},	//   _afb_, _تستو, ea_, _बद्ल
  { {0x44441677,0x06a40012,0x7cf00d4c,0x2d801678}},	// [3190] fa_, خصَّ, tärp, gwie_
  { {0x59960009,0x9c7c0064,0xc5880081,0x44441679}},	//   _נכתב_, poču, _mồ_, ga_
  { {0xf429004a,0x50d40003,0x66de001e,0xc588001a}},	//   lkää_, _جزير, tīkl, _lồ_
  { {0x4444019a,0x53340024,0x95cb004c,0xa2b40011}},	//   aa_, тецт, _дуга_, _आवण्
  { {0xda010037,0x7c2a167a,0x5e560009,0xf1ab0012}},	//   ोधित_, _offr, _אירע_, غاؤه_
  { {0xc1040003,0x7ebc0061,0x80a20037,0xd1b80003}},	//   نوني, _répa, खाये, باما_
  { {0x6602000f,0x7ebc0061,0x64450c25,0x7ceb0032}},	//   _azok, _sépa, mahi, kürz
  { {0x38b4004a,0x291f0051,0xe7080003,0xc588001a}},	//   _väri_, _tuua_, وتين_, _bồ_
  { {0x61da0037,0xcee80012,0xa3d70011,0xe576003c}},	//   बपृष, برون_, ापक_, езы_
  { {0x64450101,0xb16e0013,0x6f0d0052,0x79580021}},	//   nahi, ížeč, hmac, _цифр_
  { {0xccf2000b,0x2d800002,0xde950001,0x6f0d167b}},	//   רכי_, zwie_, _пажњ, kmac
  { {0x7c2a0061,0xff500012,0x127a0012,0xc8690009}},	//   _effr, _ضخم_, أحدث_, _לן_
  { {0xed4e00bc,0x64450101,0x3076002d,0x4444167c}},	//   _що_, kahi, нувс, ya_
  { {0xdb1a000f,0x73e50098,0x30750015,0x4444167d}},	//   sztá, _полз, кусс, xa_
  { {0xd7f20003,0xf8ad001a,0x69c6000e,0xf8520029}},	//   اكز_, _đợi_, szke, ížiť_
  { {0x2d800002,0x64430028,0x7ebc000e,0x67210051}},	//   twie_, ðnin, _lépn, _mulj
  { {0xaadb000b,0x9c7c01bd,0xdce413f6,0xe4660097}},	// [31a0] _מחקר, počt, stič, _þökk_
  { {0x6c86000a,0x9f860447,0x6445002c,0xef860148}},	//   علام, _згод, gahi, _злоп
  { {0x7c2400a2,0x103b000b,0x929d0002,0x26df001b}},	//   _şirk, _מגיע, _chło, knuo_
  { {0xaa7b015d,0x6da606bd,0x6d49005e,0xca0a0048}},	//   mnýc, _зима, ksea, пнеж_
  { {0xaa7b0042,0x7ae301e3,0x291a167e,0x6445167f}},	//   lnýc, énta, _kipa_, bahi
  { {0x98a3048c,0x6e290018,0xfaf90035,0x10a3046e}},	//   личе, eceb, ltīt_, личн
  { {0x6602000e,0xf8b3000b,0x7eb50042,0xaa7b01bd}},	//   _szok, רשו_, _zápi, nnýc
  { {0x67210027,0x3da601b6,0xaa7b0030,0xeb970009}},	//   _dulj, ероб, inýc, _אדלר_
  { {0x91e30014,0xfaf9001e,0x301a0012,0x6d49005e}},	//   _боте, itīt_, _فتاة_, gsea
  { {0x6d4b000e,0x8fa606bd,0x7ceb0032,0x7ae41680}},	//   ágai, _пазе, würz, _ajit
  { {0xf3890020,0xaa7b00d9,0x7ceb0032,0x2259003c}},	//   _cả_, jnýc, türz, мины_
  { {0xf773000b,0xaa7b022d,0x34dd0011,0x9f5e0064}},	//   _תקף_, dnýc, _मद्द, ätý_
  { {0x6445002c,0x3d1f0011,0x69090097,0xc1b80842}},	//   yahi, _बढें_, nþeg, елях_
  { {0x26f90037,0x13f40014,0x7eb5052e,0x645c0018}},	//   ंत्र_, _изля, _rápi, órid
  { {0xcebb004c,0xaf07004c,0x291a016d,0x6f0d1681}},	//   пља_, ечак, _dipa_, tmac
  { {0xabfb0009,0x7bfb0009,0x7cf41682,0x79820034}},	//   _מהור, _מפוצ, càrr, kwow
  { {0x64450101,0x98830029,0xaa54003c,0x75220073}},	// [31b0] tahi, víľu_, _свыш, _juoz
  { {0xa8a40014,0xaa7b015d,0xa3bd0011,0x658f0031}},	//   _брюк, bnýc, इनल_, lőhö
  { {0x64450167,0xf09f001a,0xd6d10012,0x1cb80012}},	//   rahi, _đà_, _نقد_, راكب_
  { {0x64450101,0xe3b00003,0xf8bf0025,0x7bc80073}},	//   sahi, حرك_, ppés_, izdu
  { {0x64450167,0xb224002d,0x4224002d,0x6721004a}},	//   pahi, уміл, удів, _sulj
  { {0x9dd6000b,0x7afd1683,0x3ea91684,0xed5600af}},	//   _יורק_, hlst, ljat_, _בבשר_
  { {0xfecb000b,0x07090012,0xc7a50048,0x2ca70097}},	//   ּמִּ, ويتي_, тийк, öndu_
  { {0x7ebc0061,0x6d490051,0x3ea91685,0xf79c000b}},	//   _dépo, tsea, njat_, לבומ
  { {0x26b6000b,0x656d050a,0xaa7b00d9,0x6e290c56}},	//   דִים_, ntah, znýc, rceb
  { {0x27ed0066,0x62860031,0x66e80030,0x3ea9008e}},	//   řeny_, _ókor, věke, hjat_
  { {0xa3cb0037,0xa3ba0011,0x6d491686,0x38b4005e}},	//   _रेख_, आईए_, ssea, _märt_
  { {0xaa7b015d,0xe61f001a,0x656d01ea,0x38b40248}},	//   vnýc, _ngô_, ktah, _lärt_
  { {0x20d6007c,0x98d6002d,0x6d460ecf,0x7c950012}},	//   вівс, вівщ, škar, _للإص
  { {0xf3890020,0xaa7b022d,0xec790538,0x7afd0f31}},	//   _tả_, tnýc, _цпк_, alst
  { {0xddca0002,0x46f600b3,0x98a30695,0x16660012}},	//   łoży, вчат, шире, َارَ
  { {0x321f001a,0x20cd0010,0x79820002,0x61f60002}},	//   _nguy_, džiu_, ywow, żyli
  { {0xceb2000b,0xfc320003,0xaa7b01bd,0x656d020d}},	// [31c0] בין_, لحا_, snýc, gtah
  { {0x644300c6,0xfaf9001e,0x3ea9004a,0xaa7b01bd}},	//   _jeni, stīt_, ajat_, pnýc
  { {0x2d8f0058,0x61e902dd,0x64431687,0x7eb50097}},	//   åger_, _axel, _meni, _hápu
  { {0x7ebc0108,0x79820002,0x60c11688,0x62490009}},	//   _répo, twow, _allm, ֲנוּ_
  { {0x7ebc0061,0x3eab01bd,0x66db008e,0xa2d30012}},	//   _dépl, žitá_, säkä, جينت
  { {0x79820002,0x658f000e,0x3cfd0011,0xbf660012}},	//   rwow, zőhö, ॉगों_, ندبو
  { {0x7ee6003c,0xcc770009,0xd46707b9,0xb226004c}},	//   кцие, _שעלה_, _шире_, _амбл
  { {0xd6d70015,0x99990029,0x8fa30001,0xc7b3000b}},	//   кты_, lasť_, раће, שבה_
  { {0xd2570009,0x7c2d0060,0xa96a0012,0x7e64005e}},	//   _ששמה_, _şara, _زمام_, igip
  { {0xe7ed0037,0x7ae20002,0x7afd0070,0x98b90073}},	//   _चुका_, lnot, wlst, vusį_
  { {0x34b7000b,0x9f4f003a,0xc4d3000b,0xead9002d}},	//   דפים_, ünüz_, שגת_, емні_
  { {0x41e7002d,0x64430227,0x7afd0040,0x28d50011}},	//   віга, _eeni, ulst, डोनि
  { {0x394d02b5,0x1e570009,0x7afd1689,0x7ae2168a}},	//   ées_, _ישאר_, rlst, inot
  { {0x6bd60003,0x33940003,0x6443168b,0x3cec0011}},	//   _لتعر, _ملتز, _geni, जकों_
  { {0x3ea9081c,0xbff80055,0xe9180024,0x351b0009}},	//   tjat_, верх_, торі_, _קוונ
  { {0x9c17000b,0xff07002d,0xe6540024,0xaa890012}},	//   _בחוק_, тягн, ивсь, _أنظم_
  { {0x644300a2,0x7ae200f1,0x7d1c0028,0xfaf9001e}},	// [31d0] _yeni, dnot, _birs, stīs_
  { {0x3e53001a,0xdcf90003,0x656d0807,0xf992000b}},	//   ệt_, رفات_, rtah, _פרי_
  { {0xa2b40044,0x656d0101,0xfc300003,0xaa95002d}},	//   _आवश्, stah, تحق_, лижч
  { {0x656d055d,0x644812c8,0x628f0184,0x33980012}},	//   ptah, hadi, ndco, ضخمة_
  { {0x7d1c0036,0x79a70014,0x865a000b,0x442e168c}},	//   _firs, ърже, _אדרי, _off_
  { {0x7ae20006,0x644800c6,0x7c3400be,0x961d001e}},	//   anot, jadi, _верх, ieņe
  { {0xccf2000b,0x3d060037,0xa4d40024,0x98480024}},	//   _לכך_, _सीधे_, _торі, тяча_
  { {0xb5fd001e,0x645d0010,0x7cfd0054,0x6d4d008e}},	//   egša, ėsim, mèri, osaa
  { {0x6d4d004a,0x40350d60,0x6443168d,0x4d15091c}},	//   nsaa, _безс, _peni, льот
  { {0x609b0012,0xa7870012,0x24810032,0xaba90451}},	//   _تخرج_, _لشؤو, nehm_, евоз_
  { {0x7f59002d,0x6443168e,0x7cfd01a0,0x628f0227}},	//   _чаес_, _veni, nèri, fdco
  { {0x6443008b,0x7ebc000f,0x7996003e,0x6d4d0c55}},	//   _weni, _lépj, _pryw, ksaa
  { {0x645c0aa1,0x6e3b00b6,0x6443168f,0x99d60012}},	//   óric, mbub, _teni, اتجا
  { {0xd6d90002,0x99d50024,0xa3d40011,0x11da0009}},	//   lił_, рююч, _सेव_, תחשב
  { {0xd36e0003,0x6f1d1690,0xc5f80035,0x68e31691}},	//   _فهو_, _bisc, _ņē_, innd
  { {0xdfcf0003,0xd6d90002,0x1eaa0012,0xceb20009}},	//   سيق_, nił_, رازي_, ֖ין_
  { {0xceb20093,0xe5a300ac,0x91db0011,0xd83e0073}},	// [31e0] זין_, бити, _पेपै, ščia_
  { {0x20cd0066,0x621b0009,0xcc8a0012,0x9c7c0159}},	//   užit_, _אופק, عناه_, onča
  { {0xfaf90039,0x9cd6000b,0x7d1c134f,0x6d4d00b6}},	//   brīd_, נועה_, _virs, asaa
  { {0x7ae21692,0x6d260012,0xeafa0012,0x7d1c0032}},	//   unot, _معسك, ررات_, _wirs
  { {0x99dd0029,0x7ae20028,0x2d840025,0x60d81693}},	//   _peňa, rnot, _ème_, tivm
  { {0xc1730009,0x2b590034,0x7cfd01a0,0x7ae21694}},	//   צחו_, ńscy_, bèri, snot
  { {0x9cd7000b,0x644813be,0xf76f0012,0xb21b0623}},	//   _עולה_, vadi, كاي_, ndær
  { {0x7d540014,0x65aa0001,0x6e3b1695,0xe66600fa}},	//   авих, етог_, gbub, утко
  { {0xceb3000b,0xad260012,0x64481696,0x7b060035}},	//   מיה_, دربو, tadi, ārtē
  { {0x7ebc000e,0xbb74004c,0xddcb004b,0xefea0012}},	//   _képk, агој, ţişt, _كعضو_
  { {0xd6d90002,0x6d5b0051,0x442e0032,0xf7720012}},	//   bił_, arua, _vff_, _داء_
  { {0xd6d90002,0xfbd30009,0xe215003c,0x7b03005e}},	//   cił_, מתת_, имны, jõul
  { {0x59c40037,0xd1260003,0x291e1697,0x16770009}},	//   वनिर, تم_, _kita_, _תגדל_
  { {0x43940048,0x645801e3,0xf1c20159,0x361b0009}},	//   _вакс, óvil, dišč_, _נוגד
  { {0x14d70093,0x3cfb007e,0x226a008e,0xd6b50048}},	//   _גוגל_, _רפוב, ätkö_, айвъ
  { {0x79a70048,0xc7d70009,0xf1a71193,0x963510eb}},	//   _брое, אולי_, _брон, рнац
  { {0xe9050020,0x2d580021,0x63ba0058,0xe78a0030}},	// [31f0] _lượ, лить_, lytn, _míří
  { {0xd6d90002,0x7cfd0054,0xdce90066,0xc1740009}},	//   ził_, tèri, yteč, _החץ_
  { {0xc7ab000a,0x711a000b,0x6f1d0052,0x6d4d0038}},	//   _أدخل_, _שותפ, _tisc, ssaa
  { {0x7b740003,0x4fd6000b,0xdb120028,0x69cb0d89}},	//   إطلا, _כותב_, ægðu, tzge
  { {0xdd860012,0xa0691698,0x18691698,0xc2440024}},	//   _بو_, вала_, вали_, снік
  { {0xd6d90002,0x63ba01bd,0x4dda0009,0xdb460012}},	//   wił_, kytn, _יחרו, _وَ_
  { {0x256f0b51,0x64550002,0xa3d40011,0xd4980048}},	//   lül_, _idzi, _सेल_, _сря_
  { {0x47d20003,0x2b5c0066,0xe9050081,0x291e0097}},	//   غيير, ávce_, _dượ, _eita_
  { {0x256f000f,0x7afb00b6,0xdce905b1,0xd6ce0012}},	//   nül_, _ikut, steč, بقي_
  { {0x64470013,0xd6d90002,0xeb990001,0xa5090001}},	//   _jeji, sił_, вио_, ђена_
  { {0xd6d90002,0x645c0017,0x109a0009,0x889a0009}},	//   pił_, ória, _שבעב, _שבעי
  { {0x8c1a000b,0x95d90015,0x256f09c5,0x5e270012}},	//   כותי, _идет_, kül_, _إعاق
  { {0x26110037,0xddc20066,0x66ba0009,0x75440024}},	//   देशी_, _zbož, _שמנה, _гніз
  { {0x7ae90027,0x65750029,0xe8f70109,0x455a0009}},	//   _ljet, ľahč, иля_, _יכנס
  { {0x29040039,0x9c7c009b,0xf74614cf,0x75260032}},	//   ēma_, ončn, ребо, _sukz
  { {0xf1c2009b,0xd5e60014,0x5de60014,0xcf250012}},	//   tišč_, ажби, ажба, صرفي
  { {0xf8c50037,0xbafb000b,0x256f034f,0xfe430024}},	// [3200] वसाय, _בהקש, gül_, інфо
  { {0xc19b000b,0x3b960001,0xe50b0011,0x8b960472}},	//   _ישפי, ијет, _सीमि_, иреч
  { {0x0b1a0012,0x2d8b00b8,0x6282005e,0x7b33004b}},	//   نقطة_, _esce_, teoo, _dăug
  { {0xd4090012,0xd2500012,0x64470035,0x60dc0060}},	//   اتكم_, سنت_, _eeji, lirm
  { {0x69000006,0xed570014,0x3ead0027,0xf19401d4}},	//   töeh, _коя_, djet_, силь
  { {0xd8f7007c,0x6455003e,0x8997000b,0x60f7002d}},	//   анії_, _gdzi, יכנס_, анія_
  { {0x6564004a,0x291e1699,0x57560009,0x201a008e}},	//   luih, _vita_, ׁבַע_, äpi_
  { {0x7eb8000f,0xe905001a,0x60dc0052,0xdd900012}},	//   _típu, _vượ, hirm, كوب_
  { {0x5d830003,0x96b70001,0x7c2904fe,0x7b33004b}},	//   قليل, рују_, _şeri, _lăud
  { {0xe905001a,0x9c7c009b,0x6e3d0028,0x291e004b}},	//   _tượ, ančn, ðsbr, _uita_
  { {0x224b002a,0x256f000e,0x60dc169a,0x15170012}},	//   tack_, zül_, dirm, جزية_
  { {0x81c3001e,0x5693002d,0xb7db000b,0x6564008e}},	//   ņēmi, _маєт, _בקבי, kuih
  { {0x20b40011,0xe8b40011,0xfce6169b,0xddcd004b}},	//   ुसंध, ुसूच, _кодо, ifaţ
  { {0x256f000e,0x55bb000b,0xd59b000b,0x33980012}},	//   vül_, _במדו, _שבגל, _منتج_
  { {0x23271154,0xab270046,0x6114002d,0xa0370009}},	//   _који_, _која_, ідсу, שאלה_
  { {0x256f000f,0x8c1b000b,0xcf57000b,0xbc1b0009}},	//   tül_, _בווי, יבלת_, _בווש
  { {0x32090060,0xaa7b06dd,0xbd6b0b2b,0xd9440a36}},	// [3210] _uzay_, nným, ърве_, _дењи
  { {0x256f000f,0xf5370009,0x7ebc0025,0x81fc0009}},	//   rül_, ינמי_, _dépi, _בהחז
  { {0x443e008b,0x6447009b,0xb3670014,0x2d91001e}},	//   ibt_, _veji, ръзк, āzei_
  { {0xb69b0061,0x8f9a000b,0x43680024,0x64550034}},	//   _chât, _עירי, раїн_, _wdzi
  { {0xe9f8002d,0x7d010028,0x816b01b6,0x644701e3}},	//   анці_, ylls, треб_, _teji
  { {0xe8f8007c,0x67280006,0x64550002,0x31580009}},	//   алі_, _budj, _udzi, שיגן_
  { {0xe7680003,0xa2670014,0x3ebf004a,0x7b030051}},	//   لحين_, _възл, tkut_, nõuk
  { {0x764d002c,0x443e04a3,0x645c0097,0x212b0025}},	//   naay, ebt_, órin, _écho_
  { {0xf1fb0012,0x25a90012,0x99840012,0x313402ab}},	//   _شعرت_, ادعي_, _ولفو, _метр
  { {0x7d01013e,0x3ebf008e,0xddc2004b,0x44230040}},	//   ulls, skut_, _scoţ, øj_
  { {0x798d002c,0xdc88000b,0x2cb8006f,0x60dc003a}},	//   _asaw, בְרָ, örda_, virm
  { {0x212900b6,0x8bd60009,0xaa7b01e9,0xcaca004c}},	//   _buah_, מותו_, bným, угме_
  { {0x443e006f,0x60dc169c,0x5a9a000b,0x8f1a0009}},	//   bbt_, tirm, אשרא, _עונת
  { {0x6564004a,0x6c350003,0xf5560012,0x25c90060}},	//   vuih, _افغا, _الوب_, ıtlı_
  { {0x5b350003,0x60dc0028,0xf4d40012,0xe29a0365}},	//   _اعتر, rirm, _بتنظ, _бай_
  { {0x75d6000a,0x7e69169d,0x6564008e,0x6b9c0040}},	//   ميزا, ngep, tuih, ærge
  { {0x29030470,0x60dc169e,0x05850024,0x93bc004b}},	// [3220] blja_, pirm, жуєм, scăt
  { {0x3086000a,0x07fa0012,0x088a003c,0x0ffa0012}},	//   _الدف, _مرجع_, _сбой_, _معجب_
  { {0x62860070,0x20290029,0xa2e6004d,0xaa7b05b1}},	//   oeko, átiť_, божд, zným
  { {0xda660012,0x0a160012,0xc3320009,0x6ab60132}},	//   صاصي, موضح, פוד_, _joyf
  { {0xf1d20044,0x6f040052,0x93bc000d,0x67280027}},	//   _देखन, mlic, ncăr, _sudj
  { {0xf993000b,0xaa7b01e9,0x628600ff,0x99470012}},	//   פרו_, vným, heko, حلول_
  { {0xa09b000b,0x35d00037,0x4f570003,0x6286169f}},	//   טיסט, _तेज़, مجيد_, keko
  { {0x1dd90044,0x6f04008b,0xa5bb003e,0x628616a0}},	//   _बेहत, nlic, _ogól, jeko
  { {0xc693000b,0x61430001,0x7abb0009,0x44a60012}},	//   לאה_, _нета, _עצמו, محدّ
  { {0x6728000f,0x6f040052,0xb5b7000b,0xa4d4002d}},	//   _tudj, hlic, צליח_, іоні
  { {0x29030082,0x443e0052,0x22490802,0x6f0416a1}},	//   vlja_, rbt_, _peak_, klic
  { {0x8c1b000b,0x635c000d,0xe2f9002d,0x66de001e}},	//   טויי, mănă, ремі_, rīks
  { {0xc05b007c,0x6f0400f7,0x7ae301e3,0x497409e8}},	//   лів_, dlic, énti, пляс
  { {0xf6170093,0x66e5007a,0x2249002a,0x44f30024}},	//   _החדש_, mėki, _weak_, _епіс
  { {0x66e5007a,0x9cdb0093,0xc1040003,0xcfa40001}},	//   lėki, _תקופ, سوفي, пшти
  { {0x6f0416a2,0x644a0097,0xeab70009,0x8f370009}},	//   glic, _hefi, _לִ֖י_, מאלו_
  { {0x58d50014,0xe4e7002d,0x66e50010,0x29030604}},	// [3230] _моит, біжн, nėki, plja_
  { {0x764d002c,0xf5370009,0x7aed008e,0xddd0004b}},	//   saay, צטבר_, _hjat, ţeşt
  { {0x7c2d003a,0xbab5003c,0x764d020d,0xfa370012}},	//   _şark, жёлы, paay, مرشد
  { {0x220b0009,0x26d90032,0x2b5c0064,0x66e50073}},	//   ְפַּ, _umso_, ávca_, kėki
  { {0x645802a1,0xd82516a3,0xda780223,0xeab20009}},	//   _odvi, одли, сях_, וֹג_
  { {0x47590098,0x66e50010,0x98a20014,0x62860002}},	//   ария_, dėki, дише, zeko
  { {0xe7390047,0xaa7b0028,0x7af90002,0x98f40012}},	//   шей_, rnýj, powt, أثنا
  { {0xb9e7002d,0xc2c50012,0x645816a4,0x8d550db7}},	//   _лізи, _بيري, _advi, оточ
  { {0xb8830029,0xfe38000b,0x644a16a5,0x785b0035}},	//   _príč, זרחי_, _befi, tāvē
  { {0xcd28000a,0xcce50003,0x7e690052,0x7aed0038}},	//   حسين_, تسعي, sgep, _ajat
  { {0xc209000b,0x6a860014,0xdce40027,0xdc880009}},	//   _סה_, олна, stić, זְרָ
  { {0x66e50010,0x93fa0009,0x644a0031,0x7e7d14df}},	//   bėki, ילתי, ófiz, _nbsp
  { {0x272e0028,0x412a0686,0xe4d50012,0x0f180012}},	//   _sýn_, рого_, _وتتب, _اغلب_
  { {0x8afd0656,0x52b60037,0x7ebc0061,0x93bc000d}},	//   stęp, _अक्स, _dépu, rcăr
  { {0x6f04008b,0x93bc007d,0xd7f20003,0x6286005e}},	//   tlic, scăr, ذكر_, peko
  { {0x7523008b,0x78a516a6,0xcf92000b,0xee3a16a7}},	//   _hinz, _enhv, וטל_, рна_
  { {0x6f04008b,0x2bc10037,0x0b170003,0x5d6a0055}},	// [3240] rlic, शनका, _بقية_, ризм_
  { {0x7c650003,0xdb9a0001,0x2ee90070,0x4aa80011}},	//   كامل, итељ_, anaf_, गावव
  { {0xda6f0015,0x7ebc000e,0x6d4601bd,0x98a90034}},	//   мя_, _képt, ákaz, _stać_
  { {0x68fc0033,0x4256002d,0xe5a60345,0xf1db0037}},	//   lord, ітет, _дими, _मेहन
  { {0x68fc16a8,0x2d8f0040,0xa25b0025,0x8d760012}},	//   oord, æget_, mhôt, _باجا
  { {0x68fc0d4a,0xd0d70024,0x58d70024,0xdce90030}},	//   nord, одії_, одія_, čněn
  { {0x9c7c001c,0x764b024c,0xf8b3000b,0xc6900012}},	//   niče, _begy, ושג_, ِّب_
  { {0x1ef70003,0x3860003a,0x35b416a9,0xbdb4004c}},	//   يعية_, şir_, збир, збиј
  { {0x2cb80005,0xb05a0003,0x68fc16aa,0x0caa0103}},	//   _kord_, _نشاط_, kord, атни_
  { {0x7ebc0061,0x66e50010,0x79b70009,0x75230018}},	//   _répu, rėki, _ולמד_, _cinz
  { {0xa295002d,0x644a0028,0x442700b6,0x2fe60012}},	//   пані, _vefi, _dgn_, _بكاف
  { {0x7523008b,0x8afd0002,0x2cb816ab,0xb8820064}},	//   _einz, dręc, _lord_, _šípo
  { {0x644101a2,0x867b000b,0x66de001e,0xfd380003}},	//   bbli, _כראו, lūko, _اكتب_
  { {0x645800c5,0x2cb816ac,0x2bca0011,0x9c7c0159}},	//   _udvi, _nord_, ानदा, fiče
  { {0xd6db16ad,0xcb670001,0x645d0010,0x0f1b0012}},	//   ата_, _даје_, ėsit, لغرب_
  { {0xd357000b,0xa53502c4,0xd4090012,0x1d350048}},	//   _ויהי_, знач, _اتهم_, зная
  { {0x61550003,0x2cb816ae,0xdb170034,0x68fc16af}},	// [3250] _عندئ, _bord_, ńców, bord
  { {0x7afd16b0,0x9c7c09df,0x2cb816b1,0x2001005e}},	//   lost, biče, _cord_, ühik_
  { {0x7afd00ff,0x23ca0011,0xd0f80011,0x83ab03d2}},	//   oost, ानिद, ंकरण_, штаб_
  { {0x6ffa000b,0x8c1b0009,0x39490034,0xd7fa0009}},	//   _להתפ, בובי, _kwas_, _להתל
  { {0xd9450345,0xe9a80012,0xdbfa0011,0xe29c0009}},	//   чели, قدون_, _ऍडॅड_, ישאר
  { {0xe0d8007c,0x55ba000b,0xd12e0012,0xfbca0011}},	//   ові_, _המשו, دمو_, ानाम
  { {0x12e7002d,0x7ebc000e,0x8ae7002d,0x387c006f}},	//   _діаг, _néps, _діал, _övre_
  { {0x0ea90047,0xee390014,0x7e6d16b2,0xc98716a7}},	//   ский_, щни_, ngap, _музи
  { {0x9555000a,0x3f9e0065,0x26df007a,0x3eb916b3}},	//   أخبا, _ertu_, riuo_, _most_
  { {0x3eb9002a,0x3ea6009b,0xe7330012,0x7ebc01e3}},	//   _lost_, _enot_, _قصص_, _sépt
  { {0xf7700003,0x93e90003,0x3eb90070,0xfaaa0003}},	//   _لان_, صفحك_, _oost_, مهدي_
  { {0x7afd16b4,0xef0e002d,0x9c7c03ca,0xf7700012}},	//   gost, _їм_, viče, _جاك_
  { {0x2d91001e,0x59bd0037,0x2731001a,0x64560031}},	//   āzes_, ्निर, _hán_, égió
  { {0x859a0093,0x97420027,0xa3bd0037,0xf8a70003}},	//   _לשנו, šćen, ेना_, رة_
  { {0x6569004a,0x2731068c,0x07a30bda,0xdbf70012}},	//   lueh, _ján_, нарн, _بأشع
  { {0xa3d40037,0x7e6d060b,0x27310097,0x9c7c0412}},	//   _सेट_, ggap, _mán_, riče
  { {0x05660098,0xc5660014,0x38b40052,0xa2bf0037}},	// [3260] яван, якак, _märz_, _वक़्
  { {0xdd8f0003,0x7e6d002c,0x629601ea,0x550305fb}},	//   طوم_, agap, _hayo, епуб
  { {0x3eb901b3,0x62960101,0x7ebc0061,0x00bb0009}},	//   _fost_, _kayo, _mépr, _המימ
  { {0x6569004a,0xc7b3000b,0x2fc50260,0x2cb816b5}},	//   kueh, _טבת_, ølge_, _word_
  { {0x7e9b000b,0xd24f0003,0xe89400b3,0x28b00037}},	//   _הסכו, انه_, даль, ञापि
  { {0x27310020,0x7afd04fa,0x29070028,0xddc40002}},	//   _bán_, zost, glna_, raiń
  { {0xd6da04b3,0x44440185,0x2731001a,0xf0930009}},	//   йти_, mb_, _cán_, גנו_
  { {0x4444008b,0x9878009b,0x6d56003a,0x273116b6}},	//   lb_, _išči_, osya, _dán_
  { {0x644e00c6,0xa4d40024,0x6d561642,0x7ae216b7}},	//   _kebi, допі, nsya, miot
  { {0xdb1b000f,0x2957000b,0xa4d8002d,0x6296002c}},	//   sztü, _מסמך_, ідну_, _aayo
  { {0xb80a0003,0x28b00037,0x78a80399,0x54770009}},	//   _ايام_, ञानि, _indv, הגיע_
  { {0x644e00ec,0xddc40039,0x7afd03ec,0x67260159}},	//   _lebi, maiņ, uost, _nikj
  { {0x64a61104,0x0e9b000b,0x3c460003,0x645c0864}},	//   _нада, _לשאל, _فَإِ, _odri
  { {0xc8be0011,0x8cf40012,0xdfc60012,0xdcb80011}},	//   ्सिट, _تكتش, ني_, ोसोफ़
  { {0x6280012e,0x6c7b007e,0x747b000b,0xd497000b}},	//   _obmo, _האופ, _הנוג, _זכות_
  { {0xb6030029,0x3704002d,0x96d80037,0x629616b8}},	//   úšob, ечув, नोलॉ, _gayo
  { {0xa2aa0037,0xc42b0003,0xdb1b0053,0x4a5c0009}},	// [3270] टार्, مثال_, sztó, _הדחו
  { {0x224d002a,0xc9520009,0x66ca03a7,0xb0350357}},	//   _seek_, _שמי_, _výka, _юнош
  { {0x316c0002,0xa87a000b,0x6564003a,0x6d56010a}},	//   ądze_, _ואתר, arih, asya
  { {0xbb840003,0x66ca01bd,0x444416b9,0xc3330009}},	//   علني, _týka, ab_, גוף_
  { {0x444416ba,0x9c7c0010,0x6e9a00af,0x569a00af}},	//   bb_, anči, _וברח, _וירצ
  { {0x224d0eaf,0x4879002d,0x644e16bb,0x273101e9}},	//   _week_, ісля_, _gebi, _pán_
  { {0x261a0037,0xb6060029,0xf8380009,0x7ebc0025}},	//   मेसी_, _vráť, הנות_, _répr
  { {0xe5590001,0x3eb90028,0x29070028,0x27310081}},	//   ојој_, ðst_, slna_, _ván_
  { {0x78270003,0xfaff001e,0x629616bc,0x628b16bd}},	//   _فعال, ļūda_, _rayo, mego
  { {0x2731001a,0x61e20028,0x6023000e,0x9c7c0030}},	//   _tán_, _þoli, _címü, vičc
  { {0x2ca70052,0x6d40003a,0x765d0034,0xd8740012}},	//   _vnnd_, apma, _odsy, _سالب
  { {0xbe150003,0xd7fa000b,0x539a0009,0x57fa0009}},	//   _قواع, _והעל, קירו, _ולעו
  { {0xed4e002d,0xba560009,0x6e440012,0xdc0a0011}},	//   _шо_, וסרו_, _أنهم, _वर्ड_
  { {0xf992000b,0x361a0009,0x6f0916be,0x628b0420}},	//   דרך_, _וונד, llec, hego
  { {0xd706002d,0xa3dd0037,0x7b030051,0xc43a0009}},	//   дзви, _तेल_, nõus, _ותצי
  { {0x628b013a,0xcaf60012,0x68e316bf,0x9c7c16c0}},	//   jego, _تستب, hind, miča
  { {0x764f0002,0x75270070,0xcb130009,0x9c7c00eb}},	// [3280] _decy, _bijz, _בלה_, liča
  { {0x3cfa0044,0x4444151c,0xdd8f0003,0x6f090052}},	//   ्तें_, ub_, ؤول_, hlec
  { {0xa08b000b,0xcdc90009,0x6abb0025,0x9c7c16c1}},	//   _וְכִ, סך_, _bouf, unči
  { {0xc332000b,0xfbd2000b,0x644e16c2,0xfbb60009}},	//   דוא_, כתב_, _webi, ופעת_
  { {0x6abb0066,0x68e316c3,0x6f090729,0xdce0004b}},	//   _douf, find, dlec, numă
  { {0x6f020002,0xb0a70011,0xaa7b0097,0xe1ff0034}},	//   _skoc, खाएग, lnýt, agów_
  { {0xdfd00003,0xf76f0012,0x7ae2008e,0xa0890009}},	//   طية_, لاي_, piot, לְקִ
  { {0xf7730009,0x6f0916c4,0x249816c5,0xddc40035}},	//   דקה_, glec, _harm_, raiņ
  { {0x224616c6,0x048a004c,0x6d400097,0x8c8a004c}},	//   mbok_, ољни_, upma, ољна_
  { {0xa2da0044,0x78a8006f,0xc1bb0009,0x68e316c7}},	//   पोर्, _undv, _וממש, cind
  { {0x6f0902d1,0x7d08006f,0x8cd40011,0x97c60012}},	//   blec, rlds, योगो, _تقاو
  { {0x7c2d00a2,0xeb91000b,0x6587006f,0xddc6003c}},	//   _şart, נָי_, örhå, _обеи
  { {0x4dd30012,0x05d30012,0x764f16c8,0x59c500ae}},	//   _لتوس, _لزوج, _recy, ريسك
  { {0x3cfa0044,0x660f0052,0x9c7c00eb,0x64c40012}},	//   ्तों_, ücke, biča, _سيعل
  { {0x67d5002d,0xd7e4002d,0x34fb000b,0xcebb0001}},	//   хову, віто, _והגד, оља_
  { {0x290a0010,0xef110009,0x99d70012,0xa2d50012}},	//   alba_, ָּל_, _يتظا, _سيخت
  { {0x68e3003a,0x99480003,0x33180012,0x082b0012}},	// [3290] yind, _قليل_, _تزود_, _وأدى_
  { {0x6abb0061,0xee3f0029,0x7f950024,0x2bbb0012}},	//   _souf, _iným_, _заох, ياضة_
  { {0xdce9001c,0x6f09003a,0x7aef0061,0xa2d60037}},	//   steć, ylec, onct, मोक्
  { {0x752700bd,0x2175002d,0x68e306f6,0xd25b0024}},	//   _wijz, еукр, wind, іце_
  { {0x6f09009b,0x24980bf8,0xcad80009,0xe63a0009}},	//   vlec, _farm_, וואת_, _מתרכ
  { {0x3cf80011,0x7b03005e,0x68e316c9,0x2795004c}},	//   ँवों_, tõus, uind, ешир
  { {0xfe710003,0x98a4000d,0x68e316ca,0x6abb0025}},	//   هدة_, _sumă_, rind, _touf
  { {0x2735006f,0x68e316cb,0x6d5d0073,0x9c7c16cc}},	//   _mån_, sind, šsam, viča
  { {0x99800002,0x22680030,0x68e316cd,0x2735063a}},	//   _dziś_, ítků_, pind, _lån_
  { {0x91e40046,0x9c7c0027,0x97420027,0x6f090066}},	//   _рође, tiča, šćan, slec
  { {0x28ac0037,0xf8680003,0xb8d30011,0x20ac0011}},	//   चारि, _زمني_, टा_, चारध
  { {0xdce4003a,0x59c40011,0x63bc0248,0x5f740012}},	//   ktiğ, वनचर, ärna, _جاكر
  { {0xf2170037,0x9c7c04d2,0x26cf0073,0xe9df0097}},	//   _तरफ़_, mičn, _ilgo_, tbúa_
  { {0xb5fd001e,0x55ba0009,0x317a0009,0x25f30011}},	//   ugšu, _ממנו, הרשמ, ंपनी_
  { {0x9cd60093,0xac160001,0xe4c80003,0x97c60012}},	//   _רוצה_, _пољу_, _زبون_, رتسم
  { {0x7bda000b,0x66ca022d,0x23760012,0x394d0132}},	//   _מקצו, _výko, _أميد_, _owes_
  { {0x27ff003a,0x7c3b003a,0x657b16ce,0xaa7b0097}},	// [32a0] ğuna_, _şura, ntuh, rnýt
  { {0x27ff003a,0x7ae616cf,0x98a40035,0xe0da004c}},	//   şuna_, likt, īmē_, _хво_
  { {0x929d003e,0x22460033,0x0b46052c,0xaa9a0009}},	//   _skła, tbok_, хнен, ּבְכ
  { {0x657b002c,0x7f3b0009,0x7ae616d0,0x29050060}},	//   ktuh, _מעטו, nikt, _akla_
  { {0x3265002d,0x27f2001e,0x28ac0011,0xc05a0024}},	//   ттєв, šanā_, चालि, пій_
  { {0x26cf052e,0x7ae60227,0x224616d1,0xc9530009}},	//   _algo_, hikt, sbok_, נמו_
  { {0x9c7c080a,0x929d0034,0x569411e0,0x7f180012}},	//   fičn, _wkła, вайт, ويتز_
  { {0xd6d70047,0xdd900003,0xc7b3000b,0x42530012}},	//   еть_, لوب_, רבה_, _منفر
  { {0x929d0002,0x16370012,0x888600f5,0x7ae616d2}},	//   _ukła, رسية_, _плаж, dikt
  { {0x6d440010,0x2367013a,0x7ae609d4,0x20d4005e}},	//   ipia, šnje_, eikt, _jäid_
  { {0xdeef0047,0xe2f9002d,0xc4d3000b,0x02cc0037}},	//   _бы_, дені_, רגת_, ासंभ
  { {0x2735006f,0x7bcb0009,0x7ec60025,0xcfd20060}},	//   _rån_, לֶכֶ, _dépê, ışır_
  { {0x6ce60024,0x6eba0011,0xc2180024,0x66ca03a7}},	//   _піке, _एकजु, еєр_, _výkl
  { {0x2ec90044,0xd7e60003,0x52bd0037,0xe58b0009}},	//   रस्त, لك_, _ऍक्स, _זָהָ
  { {0xf53f0a3b,0x5c370009,0x3940016d,0x5bc30012}},	//   _stå_, _ארון_, _etis_, _مقول
  { {0xf1c60020,0xdce4003a,0x7ae6072c,0x7c2500d9}},	//   _đánh_, ttiğ, cikt, _úhra
  { {0x8d770003,0xdce9000d,0x60f90048,0x6c75004c}},	// [32b0] عارا, _înăl, _ония_, клађ
  { {0x62840002,0x473506fd,0x0cbd0011,0x9c7c16d3}},	//   _zbio, _инос, ोसेम, zičn
  { {0x2903004a,0xdce40060,0xa2950024,0x7656016d}},	//   moja_, stiğ, кажі, bayy
  { {0xd6db007c,0x2903004a,0xddc9000d,0x7b2c003a}},	//   _хто_, loja_, ngeţ, _ağus
  { {0xd6560009,0xca380009,0x629d0227,0xcad80009}},	//   _בירת_, גנדה_, idso, עודת_
  { {0x29030006,0x3138000b,0x0138000b,0x91050048}},	//   noja_, ערוך_, ערות_, ъпле
  { {0x6aad0070,0x9c7c0133,0x883c01b0,0x7d0116d4}},	//   _onaf, tičn, הגות, vols
  { {0x2d4f0002,0x7fe80012,0x95850048,0x2903008e}},	//   oże_, عروف_, влие, hoja_
  { {0x98a40010,0x213f00b6,0xdd8e0012,0x9c7c16cc}},	//   _sumą_, _utuh_, قوي_, ričn
  { {0x6f0d0052,0x35b80011,0x290316d5,0xe8df0081}},	//   hlac, ेनज़, joja_, _meịo_
  { {0x657b0101,0x29030cac,0x7ae616d6,0x9c7c00eb}},	//   stuh, doja_, tikt, pičn
  { {0x2d4f003e,0x6e190012,0x9ee90012,0x64480035}},	//   kże_, _قياس_, _تفصل_, abdi
  { {0x1dd90011,0x4a5a0009,0x7d0116d7,0x7ae616d8}},	//   _बेचत, ודרו, pols, rikt
  { {0x80b90037,0x442e0032,0x7ae616d9,0x00860048}},	//   ्सटे, _ggf_, sikt, ълго
  { {0xb4bf0037,0x66e60686,0xd7060012,0xb4cd0011}},	//   ीसी_, вова, نظري, रसी_
  { {0x24640039,0x673c000e,0x4374004c,0x62840034}},	//   zīmē_, _érje, _сушт, _ubio
  { {0x531b000b,0x6d5b16da,0x6d44016d,0x290316db}},	// [32c0] _קופצ, nsua, upia, boja_
  { {0xa3c80011,0x8c4609cc,0x6606005e,0xdce00035}},	//   लैक_, теже, ükki, ormā
  { {0x6f0d0962,0xd838001b,0x961d0035,0x7ae416dc}},	//   blac, _jače_, meņu, _kmit
  { {0x25ad009b,0x6d4408be,0x0ba90012,0x0ea90011}},	//   _šele_, ppia, عالى_, _चोपड
  { {0xda650003,0x28a70011,0xa9ed0009,0xc2370009}},	//   طاني, खाचि, ּחוֹ, דרנו_
  { {0x7b2c000d,0x044316dd,0x8c430511,0x89db0009}},	//   _eşua, _верн, _вере, וחני
  { {0x20d40051,0x6d5b00b6,0x5f730012,0xdfcf0012}},	//   _käib_, esua, لاير, ييه_
  { {0x3da60024,0x93fb0009,0x0cca0011,0x68e70227}},	//   вроб, _חללי, िस्म, zijd
  { {0x628f001e,0x656916de,0xceb30009,0x5bca0011}},	//   veco, greh, שיח_, ान्व
  { {0x4c940046,0xe6110009,0x394616df,0xdce416e0}},	//   ћинс, מִי_, mpos_, krič
  { {0xd4970047,0x6569002c,0xe8d70009,0x8e860012}},	//   тры_, areh, _שובר_, _للاه
  { {0xdb140065,0x68e70070,0x29030002,0x6f040132}},	//   ðaða, wijd, woja_, joic
  { {0x29030006,0xddc9007d,0xf5770003,0x68e70070}},	//   toja_, rgeţ, _لمنع_, tijd
  { {0x39460164,0xa2c70011,0x290316e1,0x9f580031}},	//   ipos_, ासङ्, uoja_, _áró_
  { {0x68e70070,0x27380031,0x628f016a,0x37070198}},	//   rijd, _jén_, peco, вчав
  { {0x9bb7000b,0xb2750015,0xb3b70009,0x86c50012}},	//   _יהוה_, _слиш, _יפוג_, ديرن
  { {0x2bca0037,0x273816e2,0xa2f80009,0xa6150339}},	// [32d0] ानका, _lén_, _שמחה_, умач
  { {0x6d5d000e,0xe5700003,0x6f0d16e3,0x26050011}},	//   ásai, تطف_, slac, _हँसी_
  { {0x44271512,0xde590024,0x27380081,0x2fd90012}},	//   än_, _пані_, _nén_, _أوجد_
  { {0x69d9008b,0x6d5d0039,0xe8e1001a,0xbcfb0031}},	//   tzwe, šsai, _đột_, _svéd
  { {0xff16000b,0x99850012,0x20890148,0xaa58004c}},	//   _תקרת_, التو, ейли_, тичу_
  { {0x4104002d,0x69d90052,0xaf99035c,0x2d9916e4}},	//   азів, rzwe, етих_, _isse_
  { {0xeafb0003,0x6fb50012,0x69d90032,0x38690060}},	//   _قررت_, امعا, szwe, ğar_
  { {0x6569000f,0xdd910003,0x02a40148,0x386905be}},	//   treh, موع_, _крум, şar_
  { {0x79890002,0x27380070,0x26b60009,0x28a40011}},	//   _upew, _eén_, אִים_, _गोवि
  { {0xdced0029,0x6e3b0d85,0x645516e5,0xb4cd0011}},	//   hvaľ, scub, _jezi, रसे_
  { {0xd0110003,0x64550dd1,0x4b2605fb,0xa3d60011}},	//   _الا_, _mezi, лмов, िनय_
  { {0x216a007c,0xd94609f0,0x6d41048b,0xa96a16e6}},	//   ними_, леми, _član, нима_
  { {0x60c107f6,0xdbc90051,0x20d60024,0x6f0416e7}},	//   _kolm, _rõõm, гівс, voic
  { {0x19b6000b,0x8d5a000b,0x6f040002,0xe5880009}},	//   אפשר_, _טכני, woic, _יָצָ
  { {0x2d9900c1,0x7bc80002,0x70530003,0xf4560009}},	//   _asse_, cydu, إنفا, _עיקר_
  { {0xdb040025,0x66d109bc,0x000000c4,0x000000c4}},	//   _orné, _påka,   ,
  { {0x64550832,0xcad70009,0xb6090035,0x6f0416e8}},	// [32e0] _bezi, _תופת_, _nošķ, roic
  { {0xdce40470,0x89db0009,0x94a90012,0x394d004b}},	//   prič, _נחיי, َالِ_, ţesc_
  { {0x2d9916e9,0x287b000b,0x645516ea,0xada30030}},	//   _esse_, _אנימ, _dezi, ejúč
  { {0xf8be0037,0xdd12001e,0x2367000e,0xcf930009}},	//   ्स्प, _kļūs, ánja_, _פטר_
  { {0xa054002d,0xaa570003,0x08540198,0xa03600af}},	//   авлі, الها_, авлю, ְאֵה_
  { {0xa50a0001,0xcf9a0001,0x2367013a,0xddab0009}},	//   _чега_, еји_, šnja_, _אֱלָ
  { {0x26c20006,0x7f830012,0x60c116eb,0xada30064}},	//   _koko_, ملون, _dolm, ajúč
  { {0xe29f0028,0x96340345,0x26c211d7,0xaa570012}},	//   koða_, шниц, _joko_, _ملفا_
  { {0x2d8000bd,0x3d26002d,0x7ebc000e,0x504605f7}},	//   ntie_, льов, _képz, _безб
  { {0xcd970009,0xa1c3004c,0xd454004c,0x66d50031}},	//   נדית_, _убуд, шкоћ, _ráke
  { {0xfaf9001e,0xb8f80037,0xdb1b004a,0xa9230042}},	//   krīt_, ास_, yytä, ížen
  { {0xbda6000a,0x57fb000b,0xdfcf0003,0xdc3c0791}},	//   _محتو, _אלבו, _عين_, mšči
  { {0xdc3c009b,0x9c7c0580,0x7bda0540,0xc6930009}},	//   lšči, ničk, sztu, _לאף_
  { {0xd0060003,0x4ddb0009,0x659b0009,0x759b0009}},	//   قل_, _אחדו, _ניוק, _נסוג
  { {0xdc3c012e,0xde590024,0xdfd80048,0x9c7c001b}},	//   nšči, каві_, гът_, hičk
  { {0x645501a2,0x501b0009,0xf3f10081,0xdc3c0159}},	//   _sezi, תולו, oạn_, išči
  { {0xdc550046,0x7d250003,0x54550170,0xa3dd0011}},	// [32f0] ивањ, لفرن, иват, _तेज_
  { {0xf53f01ab,0xdc3c007a,0x28a40011,0x3ea00030}},	//   _från_, kšči, _गोलि, adit_
  { {0x92590047,0xdc3c009b,0x5a35107b,0x40ec0009}},	//   вает_, jšči, анет, _רַחֲ
  { {0x9c7c0027,0x60c1008e,0xdc3c0159,0x645a16ec}},	//   fičk, _solm, dšči, hati
  { {0x2d8000bd,0x9e5a000b,0x865a000b,0x764d02a0}},	//   ctie_, _בכרט, _בדרי, mbay
  { {0xf958000b,0x31580009,0x3d140011,0x20d4005e}},	//   נסות_, ניון_, _नीले_, _käia_
  { {0x9854002d,0x7b220025,0x60c11171,0x9c7c0159}},	//   стіш, _mœur, _volm, pičj
  { {0x16a90047,0x443e000d,0x8d650083,0x645a16ed}},	//   твии_, ect_, авие, eati
  { {0x63410039,0x05760003,0xba190003,0xdc3c009b}},	//   _mēne, لمية_, _شيئا_, ašči
  { {0xc4820047,0x660f0163,0x2ed20037,0x63a20002}},	//   ольк, _myck, _सत्त, łone
  { {0x2316002d,0x660f006f,0xc2c60003,0x290716ee}},	//   иємс, _lyck, ليدي, mona_
  { {0x7aeb03de,0x2d990058,0x645a019a,0x67ba0009}},	//   nigt, æses_, aati, _במעק
  { {0x660f006f,0x98a50035,0xa91d0073,0x26c20c71}},	//   _nyck, _zilā_, _apži, _roko_
  { {0x03a5007c,0x7c940014,0x99060001,0x4dda0009}},	//   _вико, _гръц, ртмa, _בחנו
  { {0xb21b0058,0xf6560021,0x9c7c013a,0x8fa6004c}},	//   lfæl, итаю, zičk, јабе
  { {0xe5190044,0x764d0101,0x6d5d0010,0x9bfa0009}},	//   _नीति_, gbay, šsau, _בהצט
  { {0x656d0005,0xceb2000b,0xee370ec6,0x7afd1007}},	// [3300] grah, חין_, рну_, érte
  { {0x2d8016ef,0xfbd20012,0x515b0009,0x764d1642}},	//   rtie_, يتا_, _שכיו, abay
  { {0xa7fc00a2,0xb4db0054,0x26c200b6,0x66ec003a}},	//   _adın, _itàl, _toko_, aşka
  { {0x9c7c001c,0x645a16f0,0xdc3c009b,0x2d8004d1}},	//   tičk, zati, všči, ptie_
  { {0x660f0052,0x645a0b70,0xcb130009,0x70560012}},	//   ückl, yati, קלד_, لنشا
  { {0x9c7c001c,0x3f660001,0x7aeb0010,0xc1730009}},	//   ričk, атиб, aigt, קחו_
  { {0x03060011,0xdc3c0073,0x2f010064,0x2b060011}},	//   रवाह_, ušči, lógy_, रवाँ_
  { {0x273c0065,0xbe8a0001,0xdc3c009b,0x6566000e}},	//   _mín_, тске_, ršči, ákho
  { {0x9c7c080a,0xcdf60009,0x614315f5,0x6724008e}},	//   liči, ימֵי_, _мета, imij
  { {0xccb8002d,0xdc3c009b,0xe7ff0011,0x4cb80024}},	//   угої_, pšči, _ऊँचा_, улою_
  { {0x764d0101,0xbe660003,0xdce9003a,0x9f45003a}},	//   ybay, _نهاي, steğ, çlü_
  { {0x6d460027,0xf5ea0015,0x7b220025,0x79820034}},	//   _otka, _имел_, _sœur, otow
  { {0xc05b007c,0x7982003e,0x7ae301a0,0x81c40306}},	//   ків_, ntow, ènti, ощре
  { {0x386d0052,0xa3d60011,0x2ddb0009,0x10540009}},	//   ßer_, िना_, _שַׁב, מֹֽר_
  { {0x386d00a2,0x64580039,0x6d460039,0x66ca0028}},	//   ğer_, _ievi, _atka, _lýku
  { {0x7982003e,0x764d002c,0x96f80001,0x290716f1}},	//   ktow, ubay, аест_, zona_
  { {0xbafc000b,0x8afc0009,0xa6970009,0x8d740012}},	// [3310] _שהחש, _שהחי, סכמה_, قالا
  { {0x4095000a,0xb895000a,0x67241277,0x2ba70001}},	//   _الدر, _الدع, amij, ијев
  { {0xbca40003,0x7aeb0052,0xd2510003,0x656d00ff}},	//   تملي, tigt, كنا_, srah
  { {0x69cb0163,0x2367009b,0x660f006f,0x290c002c}},	//   tyge, šnjo_, _tyck, _akda_
  { {0x471a000b,0xceb6000b,0xe1f00012,0x8f1a0009}},	//   _תורג, _הפרק_, وسه_, _תורת
  { {0xa3c80037,0x645816f2,0x6f650012,0x65360009}},	//   ोना_, _nevi, مهتم, _לאשף_
  { {0x79820002,0x290716f3,0x225b0012,0xdb210031}},	//   atow, rona_, _لجذب_, ítós
  { {0x20d40006,0x77f8000b,0x47f80009,0xbbb50011}},	//   _näin_, ימוד_, יצול_, ूहीक
  { {0x50670003,0x799b0002,0x2738001a,0x7ae90859}},	//   _نطاق, _usuw, _lĩnh_, _imet
  { {0x2ba50039,0xa91d0010,0x04b50015,0xe0d30012}},	//   _pēc_, _apžv, ссия, _بزر_
  { {0xd4c4000a,0xd6db0001,0xc1040003,0x7ae904d2}},	//   تغيي, _итд_, _بولي, _kmet
  { {0x9bb60009,0x98a5004b,0x6d4916f4,0x9595004c}},	//   צהרה_, _filă_, ppea, _гркљ
  { {0x4545000a,0x273c0028,0xb60700b3,0xdca503d4}},	//   _انتق, _sín_, _тяжк, _гали
  { {0xdddd0002,0x66de001e,0xf8b8001a,0x0ef20011}},	//   _odsł, lūkp, _khĩa_, ॅक्स_
  { {0x7b3301b3,0x66d500f1,0xb8f00011,0x9d1a0009}},	//   _căut, _záka, _शव_, _גוסט
  { {0x7982003e,0x3ebf00b6,0x6eb00011,0x9c7c16f5}},	//   ytow, njut_, झाएँ, viči
  { {0xb5fb0066,0x99860003,0x672416f6,0x54360012}},	// [3320] _udál, _الخو, rmij, مرار
  { {0x7ae90005,0x273c0020,0x7afb043c,0x76590034}},	//   _amet, _tín_, _ajut, _lewy
  { {0x61200028,0x2fd0000d,0xe4520009,0x889b0009}},	//   tölf, ângă_, לֶף_, _גביי
  { {0xdbd0015d,0xbae50024,0x71660012,0xcb090024}},	//   _užív, оцій, ماتك, ахід_
  { {0x6d46079d,0x52830012,0x98c60024,0x644316f7}},	//   _utka, سلوك, йскл, _ofni
  { {0x7982003e,0x66d5000e,0xc9530009,0xa7860012}},	//   rtow, _ráka, למד_, مشبو
  { {0xf093000b,0x798216f8,0x60c10097,0xb3410060}},	//   פנה_, stow, ölmi, üçle
  { {0xe81e0044,0x7982003e,0xd6d70047,0x645e16f9}},	//   येगा_, ptow, йты_, lapi
  { {0x7ae30070,0x3ea207c7,0x290a07a5,0x35b40024}},	//   ënte, _makt_, koba_, ібор
  { {0x645e0101,0x78a10708,0xd49a0829,0xf36a0009}},	//   napi, _galv, ури_, ְדָּ
  { {0xa6860146,0x2418003c,0xac1809cc,0x20d4008e}},	//   _глед, роны_, рону_, _päin_
  { {0x64430028,0x3f9e0027,0xee3a002d,0xf8d10011}},	//   _efni, _istu_, _снд_, हस्प
  { {0xeab1000b,0x64410227,0x645e16fa,0x2e160012}},	//   וֹם_, bcli, kapi, _اباح
  { {0x27380020,0x61200065,0x64a316fb,0x9f350024}},	//   _cũng_, jöld, _нача, жеві
  { {0x2d84003a,0xccf80066,0x2738001a,0x67d402e3}},	//   ltme_, mně_, _dũng_, пору
  { {0xccf80013,0xbdd50015,0x5d550014,0x2738001a}},	//   lně_, ообщ, жкат, _vĩnh_
  { {0x6345007a,0x09e4004c,0x95570012,0x67280025}},	// [3330] _mėne, _ноћн, إخرا, ïdja
  { {0xa7fc00a2,0x645e0101,0xa3570003,0xccf80066}},	//   _adım, gapi, مخصص, nně_
  { {0x16350015,0x8cbf0011,0x69c4005e,0xe4c4003c}},	//   _меня, लॉगो, äien, чётн
  { {0x99d50012,0x7aef16fc,0x7b180097,0x660f0032}},	//   يقات, nict, síun, ückk
  { {0x78a10006,0x416b0001,0x4a9c0009,0xa5bb0031}},	//   _palv, ујем_, טיאג, _szóf
  { {0x661d0039,0x6d4d0176,0xccf80066,0x9fc9011d}},	//   _izsk, mpaa, jně_, игла_
  { {0xccf80013,0x2eed00bd,0x78a1078a,0x6d4d0ead}},	//   dně_, tief_, _valv, lpaa
  { {0x7ae9013a,0xb21b0097,0xee39038f,0x7afb11a7}},	//   _umet, mgæf, шни_, _ujut
  { {0x66d10033,0x64c50012,0x6da516fd,0x27210081}},	//   _påkj, قيةل, ципа, hóng_
  { {0x336500be,0xe79b0003,0x2eed0070,0xdce90470}},	//   овог, _مخصص_, sief_, preč
  { {0x2ca3000f,0x394900c6,0x66d80028,0xf1a90009}},	//   _majd_, _atas_, _líka, _שס_
  { {0xeb960047,0xc0490093,0xc5d5002d,0x3b0a002d}},	//   цию_, _יז_, _міль, ремо_
  { {0xccf80066,0x4426001a,0x3ea20248,0x06380012}},	//   bně_, ̀o_, _rakt_, _اسمع_
  { {0x26d902ef,0x6efe001e,0xccf80066,0x73c50012}},	//   _also_, mība, cně_, _ويشم
  { {0x6efe001e,0xf8b2000b,0xae5a0024,0x645e00e6}},	//   lība, ושם_, ирає_, vapi
  { {0xa3e20037,0x7e7b15c9,0xee3f0097,0x464a019c}},	//   _नेट_, ngup, _snýr_, рзан_
  { {0x0566007c,0x6efe001e,0xe45a0345,0xc6920009}},	// [3340] юван, nība, ижа_, ואן_
  { {0xdb21004a,0xa3d50011,0xd46a003c,0x20000060}},	//   ätök, ाईं_, риже_, şiii_
  { {0xeb9a022a,0x23b30012,0xfa760009,0x6d4d16fe}},	//   рие_, ومكس, ַעַת_, apaa
  { {0xccf80066,0x673a000e,0x41aa07e8,0xb4d60011}},	//   zně_, ítju, ивен_, _सत्_
  { {0xccf80066,0x76430034,0x41530024,0x398416ff}},	//   yně_, śnyc, двіс, nös_
  { {0x3d030037,0x765d0028,0x3cf50037,0x25ff0037}},	//   रकों_, ðsyn, ीकों_, _रखती_
  { {0xccf80013,0xd6da1700,0xdb830024,0xa8570009}},	//   vně_, ити_, _огри, קיקה_
  { {0x83fc001c,0xeeb81701,0x5d540048,0x758a00a6}},	//   nađe, слиш_, пкит, асов_
  { {0xccf80013,0x66d50028,0x7c39000e,0x645c0190}},	//   tně_, _tákn, _ábrá, _keri
  { {0xa5b7000b,0x7d230012,0x44441702,0x4fb60012}},	//   קליק_, وفين, nc_, _وصار
  { {0xccf80066,0xc43b0009,0xdc8b0009,0x2d84005e}},	//   rně_, יתיי, בְכָ, stme_
  { {0xccf80013,0x6efe001e,0x9c7c009b,0xda350015}},	//   sně_, bība, viču, яемы
  { {0x6efe001e,0xccf80066,0x66d5014a,0x7e60060b}},	//   cība, pně_, _záko, mamp
  { {0x645c1703,0x7e601704,0x5a340024,0xdd3d0034}},	//   _neri, lamp, ьнят, rąży
  { {0x7aef0611,0xb4c80011,0xf0340009,0x92590365}},	//   pict, ैसी_, לָֽי_, _лайт_
  { {0xf7700003,0x66d5022d,0xceb80001,0x7e601433}},	//   ضاف_, _nákl, ољу_, namp
  { {0xdce6003a,0x3f9e0028,0xc3280012,0x645c1705}},	// [3350] _askı, ætur_, _بكين_, _beri
  { {0xc9520009,0xe4500012,0x94770012,0x8afd0073}},	//   _רמי_, نضم_, تدرا, pręs
  { {0x309a0093,0xb09a000b,0x6efe001e,0x6d400061}},	//   _השתמ, _היתר, zība, _éman
  { {0xb5fd066e,0x6d4d004a,0x479a000b,0x44441706}},	//   laše, ppaa, _פירס, ac_
  { {0x27ff00a2,0x661d0039,0x78a505a2,0xb6ba0009}},	//   ğunu_, _uzsk, _kahv, _הצרי
  { {0x9d180014,0x27ff003a,0x08c4002d,0xcf590014}},	//   _моят_, şunu_, мбін, брич_
  { {0xe0d00012,0x00580009,0x39840031,0x753d0031}},	//   خزن_, חשות_, zös_, _husz
  { {0x92b70003,0x3984004a,0x6efe001e,0x31790a8e}},	//   _بحسا, yös_, tība, kusz_
  { {0x645c00a2,0xe5710003,0x7ce00032,0x31790034}},	//   _yeri, رطة_, _dörf, jusz_
  { {0x753d0002,0x6efe001e,0xdced00f1,0x66d50107}},	//   _musz, rība, krač, _zákl
  { {0x7ce00163,0x6efe0039,0xf3f1001a,0x33f50024}},	//   _förf, sība, oại_, ячис
  { {0x6efe0039,0x8bd60009,0x27210064,0x61200031}},	//   lībn, פורו_, fóne_, kölc
  { {0xe2970015,0xb5a71707,0xa63a0009,0xdc180011}},	//   чая_, _фрей, _הגנר, _थर्ड_
  { {0x17fa0003,0x61200032,0x39841460,0x75351708}},	//   مرأة_, wölb, rös_, _nizz
  { {0x2467000e,0x1cba000b,0x753d1088,0x3f87001b}},	//   _című_, _למסע, _ausz, ntnu_
  { {0x3b070098,0x64451709,0x62990034,0x660f0032}},	//   _нещо_, echi, jewo, ückw
  { {0x83fc0027,0xdced009b,0x66d80028,0xda7b0009}},	// [3360] rađe, arač, _fíkn, _הנפר
  { {0x7ce00028,0x753d0002,0x656400b6,0x6f160248}},	//   _mörg, _dusz, rsih, slyc
  { {0x73360003,0x2bae0037,0x2057000b,0x351a000b}},	//   سرائ, टिया, _מייל_, צוענ
  { {0xd7bb000b,0x4444170a,0x78a5013a,0x6445170b}},	//   _הצטר, sc_, _zahv, achi
  { {0xa9280010,0x60c8170c,0xe8380024,0xd3780034}},	//   pažį, _podm, оплі_, zuć_
  { {0x644501a2,0x3f680060,0xa91b0097,0xc0e304a5}},	//   cchi, oğu_, etþj, ночк
  { {0x61e2000f,0xb8f40037,0x6d4b0071,0x1be70048}},	//   szol, _हक_, _atga, _едри_
  { {0xb8d3015f,0xd6d00012,0xbdb4004c,0x33fb0009}},	//   _जो_, ئقة_, дбиј, _ההלנ
  { {0x7e60170d,0xa1160012,0xa06a0686,0xdced170e}},	//   ramp, _فورت, _газа_, zrač
  { {0xa0c9000a,0x7aed001c,0xb4d60037,0xb4c80037}},	//   _وذلك_, _smat, ससे_, ैसे_
  { {0x78a50005,0x5f06003c,0xdc8b00af,0x6921099e}},	//   _rahv, _езжа, זְכָ, nţeş
  { {0x2f3b000b,0xd7ef0003,0xdced009b,0x67bb0009}},	//   _הגאד, _حكم_, vrač, _למבק
  { {0xbcfb0066,0xa596002d,0x2d96002d,0xdee50012}},	//   _svém, _хрещ, _хрес, _تألي
  { {0x3d140044,0x62990002,0x753d170f,0x2367013a}},	//   _नीचे_, zewo, _rusz, šnji_
  { {0x78a50006,0x0f1b0003,0xf8b8001a,0x351b0009}},	//   _vahv, مغرب_, _nhĩm_, _הוגנ
  { {0xabfb000b,0x4b7b0009,0x9c170009,0x753d0540}},	//   _להור, _האהו, _מחוק_, _pusz
  { {0xdd910012,0x64451710,0xa535004c,0x98a50073}},	// [3370] ضوا_, tchi, днач, _eilę_
  { {0x7ce01711,0xa1150012,0x3ea6020d,0xb0ab0011}},	//   _nörd, _زوجت, _laot_, _टोंग
  { {0x6ce4002d,0xdc8b0009,0xaa7b01e9,0x6729008e}},	//   хіте, מְאָ, chýc, ymej
  { {0x7afd1712,0x21f50003,0x64451713,0xe3b00012}},	//   nnst, وكاس, schi, درك_
  { {0x6ec00011,0x62990132,0x3ea90227,0x2169004c}},	//   वानु, rewo, mdat_, цили_
  { {0x66d80028,0x55ba0009,0x25d60009,0xe8f80024}},	//   _líkl, _ומשו, _חושן_, плі_
  { {0x917a001a,0xdb24000e,0x3ea91714,0x9be40024}},	//   _mất_, őség, odat_, _зітк
  { {0xe7dc000b,0xdd910003,0xd5490048,0xdce20159}},	//   מקוש, نوع_, опие_, _dvoč
  { {0x6729019a,0x7ce0066d,0xfce50511,0x3f871715}},	//   rmej, _förd, допо, stnu_
  { {0x3ea9004a,0xa91b0028,0x7ce0059b,0x91640012}},	//   hdat_, stþj, _görd, _أهله
  { {0xb7d50012,0x47d50012,0xf7700012,0xdced0ca4}},	//   _تقاب, _تيار, _مان_, hraď
  { {0xc8690093,0xdb1b0034,0x26f90011,0x25a90ea4}},	//   _כן_, dytó, ्कोर_, _šalu_
  { {0x917a0020,0xdce2009b,0x6d4b0348,0x7ce0031d}},	//   _bất_, _zvoč, _utga, _höre
  { {0x80d80037,0xbbe90012,0x85050012,0x225f0227}},	//   डसें, _ورغم_, _توتن, _leuk_
  { {0x25ad005e,0xaa7b0030,0x000000c4,0x000000c4}},	//   lvel_, uhýc,   ,
  { {0xf412000b,0xef1a002d,0x2ca71716,0x9c080009}},	//   _שפה_, іма_, _hand_, _מִפִ
  { {0xacca002d,0x0906002d,0x6cd60012,0x25ad1717}},	// [3380] огаз_, _опин, وقرا, nvel_
  { {0xa5bb000f,0x25ad000e,0x3ea6001e,0x3ea91718}},	//   _szóc, ivel_, žot_, adat_
  { {0x66dc0066,0x39400070,0x2ca7014f,0x4f260da9}},	//   _léka, _huis_, _mand_, _одоб
  { {0x1efa0009,0x657b008e,0x39401719,0x2ca7171a}},	//   _וּ֝מ, kuuh, _kuis_, _land_
  { {0xddc20029,0x614300bb,0xe8940055,0xa158003c}},	//   _odoš, веча, еаль, чалу_
  { {0xa3dd0011,0x39400227,0x7e640073,0xddc00073}},	//   णना_, _muis_, laip, samū
  { {0xf0930009,0xa3e60011,0x3940171b,0xdce00035}},	//   דנו_, _बेच_, _luis_, zumē
  { {0xbd6a0015,0x356a0223,0x8fa3004c,0xddc207ee}},	//   орое_, орон_, таће, _adoš
  { {0xa5340109,0x1d340048,0xdb1b0034,0x2ca7171c}},	//   ннич, нния, zytó, _band_
  { {0x7ce0171d,0x62840017,0x2918000e,0x2ca7000d}},	//   _före, _acio, _óra_, _cand_
  { {0x7ce0171e,0x3c77000b,0xc477000b,0xdfa60003}},	//   _göre, ותים_, ותיו_, _تحذي
  { {0x83fc001c,0x2bac0066,0x9f980097,0x78a80031}},	//   gađa, _věc_, _ráða_, _hadv
  { {0x2ca70052,0x41e70024,0x5887003c,0x660f0032}},	//   _fand_, фіна, мыва, ückt
  { {0xa803003a,0xdfc60003,0x6e2202a1,0x0ef90011}},	//   _çıkm, هي_, _izob, ्क्स_
  { {0x7ed70003,0x3ea90070,0xd47b000b,0x6c7b01b0}},	//   وزرا, tdat_, _ואול, _ואופ
  { {0xb5fd001c,0x37040024,0x22490060,0x66d50031}},	//   laša, вчув, _ufak_, _rákk
  { {0x78ba00bd,0x917a0020,0x3ea9171f,0xcb140009}},	// [3390] _ontv, _tất_, rdat_, _בלק_
  { {0xd1380002,0xdb040052,0x98550024,0x78a8140a}},	//   _nią_, _ernä, _якої, _nadv
  { {0x68f5003a,0x8ba90009,0xa8560009,0x04c80012}},	//   mizd, ּׁנִ, _איתה_, بولي_
  { {0xdbdc0028,0xaa580001,0x7ce0006f,0x629d1720}},	//   ráða, дицу_, _röre, neso
  { {0x27210028,0xc3340009,0xfb1c0009,0x99150024}},	//   jóna_, דוף_, קודמ, нькі
  { {0x68f500a2,0xf7710003,0xf3f1001a,0xb17c000b}},	//   nizd, هاب_, oạt_, קטור
  { {0x3861008b,0x7ce00163,0x7ae21721,0x2ca71722}},	//   _mehr_, _förb, bhot, _rand_
  { {0xf8380093,0xbcfb0013,0x7fe80003,0x644a1723}},	//   ונות_, _svéh, ظروف_, _affi
  { {0xe7080003,0xc0ab0012,0x2ca71724,0x6f0301e3}},	//   بتون_, _وائل_, _pand_, _íncu
  { {0x23670027,0x62841725,0x81c20035,0x7ce01726}},	//   šnju_, _scio, ķēta, _töre
  { {0x39400061,0xa3d50011,0x02f30011,0x28c30011}},	//   _suis_, ाईट_, _आगाह_, शानि
  { {0x39400108,0x660f0052,0x63ba000e,0x68f50035}},	//   _puis_, ücks, _átne, eizd
  { {0xa4d5007c,0x394007d9,0xb143003c,0x94d506bd}},	//   _поді, _quis_, лнял, _подц
  { {0x628b006f,0x91f6000b,0xf9920009,0x3cfb0011}},	//   _ögon, תמשו_, ארך_, ्वों_
  { {0x7a36003a,0x39890028,0x629d0032,0x25a0016d}},	//   _kütü, hús_, beso, wwil_
  { {0x63a2003e,0xab270014,0x68f50010,0xbea311ed}},	//   łonk, _поща_, aizd, ласк
  { {0x7e64007a,0xb9c60003,0xe6e00037,0x12fb000b}},	// [33a0] raip, _ستظه, _नतीज, _מהקב
  { {0x6f1b0032,0xb5fb0031,0x31570009,0x672d1727}},	//   hluc, _adás, _ריין_, amaj
  { {0x65760006,0x6f1b003e,0xda6f064f,0x305b000b}},	//   sryh, kluc, ля_, _מדיד
  { {0xc7b3000b,0xb21b02d2,0x0166028b,0xca261728}},	//   _עבר_, mfær, екдо, нфли
  { {0xf98f0012,0xb21b0040,0x7ae20385,0x7b160c9d}},	//   مبو_, lfær, rhot, láus
  { {0x24560003,0xd0d70024,0xd1300012,0x60180048}},	//   _سنرس, ндії_, جمت_, моля_
  { {0x7a3600a2,0xdfd00003,0x66d80028,0x6e22000e}},	//   _bütü, شية_, _ríkj, _szob
  { {0x23890066,0x8f9b0009,0x65690032,0x2fc5005e}},	//   žují_, פיפי, fseh, älgi_
  { {0xfe6f0003,0xceb30009,0x74c40011,0xd7370009}},	//   حدى_, ריח_, रापृ, עטפת_
  { {0x2dd70012,0xa5d70012,0xc0ea0012,0xb21b0097}},	//   عبية_, عبير_, _عفان_, kfær
  { {0x3e7a003a,0xa3d60011,0xb5fd1729,0x6f020248}},	//   gütü_, िनट_, raša, _tjoc
  { {0x3861008b,0xb7db000b,0x92580015,0x93fb0009}},	//   _sehr_, _מקבי, нают_, לליי
  { {0x4dd30003,0x6120000e,0xba3b0054,0x211b0012}},	//   _متوس, röln, veïd, كتسب_
  { {0x2705001e,0x644a172a,0x7c2b0097,0xb21b172b}},	//   mēna_, _uffi, ámrö, ffær
  { {0xb21b0028,0xb5fd013a,0x0cdc0011,0x69c012fb}},	//   gfær, našn, यसीम, ämer
  { {0x539b0093,0xf5e7002d,0x6120004a,0x398901e3}},	//   _זיהו, нізм, löll, yús_
  { {0xb2740015,0xe5980024,0xd61b0012,0x672d172c}},	// [33b0] _слыш, нкті_, سترا_, rmaj
  { {0x6120004a,0x99640014,0xb5fd001b,0x27210097}},	//   nöll, _стъл, kašn, jónn_
  { {0xd2510003,0xb5fd0027,0x28b00037,0xf0920009}},	//   لنا_, jašn, फ़ारि, _דני_
  { {0xfbd00003,0xb5fd0027,0x7b740003,0x91f90012}},	//   حتك_, dašn, اطلا, وفاء_
  { {0xc2440024,0x6d4f0031,0x6f1b172d,0x6d5d0035}},	//   унік, _utca, vluc, šsaz
  { {0x2be10044,0x66d50028,0xfdf6000b,0x61200097}},	//   पनदा, _jákv, _יצרת_, jöll
  { {0xa8ac000b,0xbea50014,0xc4d20009,0x3f47005e}},	//   לֹהִ, вайк, _דגם_, _jõu_
  { {0x65690574,0x26c9001b,0x533411b0,0x291c172e}},	//   tseh, njao_, _бест, alva_
  { {0xd6ce0003,0xd3780002,0x06090055,0x7ce00248}},	//   تقي_, erć_, ьник_, _höra
  { {0x66d50065,0x8cc40037,0x65690052,0x7b2c000d}},	//   _nákv, रायो, rseh, _uşur
  { {0x2d98007d,0x3f470051,0x6569172f,0xe6950012}},	//   ărea_, _nõu_, sseh, _للاد
  { {0xf412000b,0xdce90027,0xa96a0001,0x7e621730}},	//   שפט_, kreć, мима_, _geop
  { {0x4e780003,0xdbde0097,0xc3320009,0xe4d50012}},	//   _أحمد_, síða, יוט_, _لتثب
  { {0x63a20002,0x3ead1731,0xb97a0009,0x20d4005e}},	//   łoni, ldet_, ונשי, _näit_
  { {0xb90a0037,0x26cf0034,0xdce9001b,0x3ead1545}},	//   _मत_, _kogo_, ereć, odet_
  { {0x26cf0017,0xb21b1732,0xf7720009,0x3ead1733}},	//   _jogo_, rfær, יקל_, ndet_
  { {0xb21b1734,0x04460001,0x66d10192,0x8c460400}},	// [33c0] lgæn, везн, _påkr, везе
  { {0xb21b0065,0xb97b000b,0x3ead004a,0xe8f70109}},	//   pfær, _קניי, hdet_, _аль_
  { {0x316d0108,0x1877000b,0x3eab002a,0xa857000b}},	//   _avez_, _בעיר_, _fact_, _שיטה_
  { {0x3ead0058,0x2bc20011,0xdc290012,0x26cf0159}},	//   jdet_, षमता, رسله_, _nogo_
  { {0x64430010,0xc3050003,0x7e620132,0x3ea00b89}},	//   žnia, دبلو, _reop, meit_
  { {0xc953000b,0x224d00b6,0x3ea00fc4,0xbb560012}},	//   סמו_, _efek_, leit_, _لنسب
  { {0x7e620036,0xf093000b,0xa3e30037,0x7ce0006f}},	//   _peop, ינג_, पैम_, _göra
  { {0xeb0d0037,0x6d5614bb,0x20d4005e,0x2000004b}},	//   िकृत_, opya, _käis_, ăii_
  { {0x66d501bd,0x96b7004c,0x80c20011,0xd9461390}},	//   _náku, тују_, लादे, _рези
  { {0x3ea0008b,0x80d10037,0x8f76002d,0xb5fd001e}},	//   heit_, _सकें, _ауді, pašn
  { {0x3ea0008b,0x26cf0017,0x316d009b,0xd10f0037}},	//   keit_, _fogo_, _zvez_, िवरण_
  { {0xf413000b,0xbe850003,0xc2b8002d,0x3ea00031}},	//   יפת_, _مجهو, влює_, jeit_
  { {0xdb21000f,0x39441735,0x316d0108,0xbecb001a}},	//   ítés, _jums_, éez_, _nhâị
  { {0x0d97000b,0x39440113,0x6120000e,0xb9250003}},	//   _סכום_, _mums_, lölj, افسي
  { {0xd8380039,0x6018022a,0x73c30012,0xd7f80189}},	//   _taču_, воря_, _نيوم, вут_
  { {0xdce0007a,0x3ea0000e,0xef110009,0xe4370009}},	//   tumė, geit_, ֶּן_, _ברוח_
  { {0x1df80015,0x9f340024,0xa5f811a2,0xbd680a36}},	// [33d0] веты_, реті, вету_, врхе_
  { {0x94740012,0x54540024,0x659404a5,0x912b0012}},	//   لدما, ивут, рафу, _تسبق_
  { {0x3ae20028,0x3ead13df,0x3ea003c0,0xdce90027}},	//   _hópa_, ydet_, beit_, sreć
  { {0x2d80007d,0xe2ab0003,0x93fb0009,0x02f00060}},	//   buie_, بائن_, ולבי, _üçlü_
  { {0xddcd0034,0xd84e0081,0x667a0009,0x26de0035}},	//   ngaż, rọng_, _אטרק, ītot_
  { {0x89dc0093,0x66d80028,0x9b450012,0x0efd0011}},	//   וחדי, _ríki, _منسو, ॉक्स_
  { {0x0b880001,0x6120006f,0xc7950012,0x38580024}},	//   _исти_, följ, اشتب, трію_
  { {0x2d8d002a,0x05a9002d,0xbb840003,0x3ead08b5}},	//   ttee_, евий_, _خلفي, udet_
  { {0x656d01e5,0xb5fd007a,0x3ead1736,0x41790012}},	//   nsah, rašo, rdet_, _سماح_
  { {0x645e0051,0x3ea00052,0x33750009,0xdca5004c}},	//   _õpil, zeit_, ְעָם_, ћани
  { {0xa5bb000e,0x29030133,0xdce40035,0x0b42003c}},	//   _szól, dnja_, nsiā, йнэн
  { {0xdb960009,0x73e20109,0xe1e70012,0xf8a90009}},	//   נדרט_, союз, مس_, _מש_
  { {0xbebd001e,0x6dc40012,0xcb120009,0x3ea003d1}},	//   elūg, _نزول, מלט_, veit_
  { {0x3ea00480,0x8a160009,0x645c0097,0xe3b10012}},	//   weit_, רחשו_, ðrit, _هرب_
  { {0x3ea0060c,0x1cb80003,0x37e300fa,0x66e60237}},	//   teit_, _جانب_, борг, гова
  { {0xdb9a000b,0x2d80000d,0x75d60012,0x9e660012}},	//   _נספר, tuie_, هيزا, طارن
  { {0xd7070015,0x2bcb0011,0xad650012,0x3ea01737}},	// [33e0] унте_, ाहका, لاله, reit_
  { {0x661d003e,0x3ea0000f,0x7afd000e,0x6120000e}},	//   _dysk, seit_, értv, zölj
  { {0x2b4f007d,0x42d6002d,0x753c001e,0x7ce0006f}},	//   _încă_, ліду, _virz, _förn
  { {0xf1c50020,0x26de001e,0x20d40051,0x62861738}},	//   _trợ_, ītos_, _täis_, ngko
  { {0xf5480020,0x6b810154,0x6f041739,0x9f4b0030}},	//   _mục_, hulg, mnic, ělým_
  { {0xf993000b,0xf548001a,0xc2370009,0x657b0030}},	//   צרו_, _lục_, ארנו_, druh
  { {0xe7f90037,0xfbc70003,0xebe60015,0x661d0002}},	//   ृपया_, _ات_, _совп, _zysk
  { {0x6d46173a,0x8f9b0009,0xa3c90011,0xa6db0097}},	//   _kuka, תיקי, ोहन_, _viðg
  { {0x6120000e,0xa20608e0,0x1a06112d,0x2bdc0011}},	//   rölj, _спад, _спам, मन्थ
  { {0x6d460006,0x90d50020,0x44f4002d,0x6f04173b}},	//   _muka, _hìn, рпос, hnic
  { {0x44380163,0x7ae4173c,0xd4970015,0x27ea0058}},	//   är_, _blit, уры_, _åbn_
  { {0xb5fb0272,0xc9870014,0xf548001a,0x877b0009}},	//   _beál, луги, _cục_, _טאבי
  { {0x90d5001a,0xf548001a,0x79820034,0x290307a5}},	//   _mìn, _dục_, nuow, tnja_
  { {0x661d006f,0xee290012,0x672d0064,0x7ae4173d}},	//   _rysk, _شأنه_, ňajt, _elit
  { {0x6d460028,0xc4f7000b,0x66d80028,0x29030604}},	//   _auka, _תמוז_, _líku, rnja_
  { {0x6d460807,0x2f18002d,0xdce0001e,0x79820034}},	//   _buka, гось_, kumī, kuow
  { {0x644f0002,0x764d046c,0x9f470029,0x6d4600b6}},	// [33f0] ście, rcay, rzné_, _cuka
  { {0xeb0d0044,0x764d0922,0x661d173e,0xf9940009}},	//   िक्त_, scay, _vysk, _הרץ_
  { {0x90d50020,0x7ae4004a,0x661d0002,0xd497000b}},	//   _bìn, _ylit, _wysk, רכבת_
  { {0x5155002d,0x1b780003,0xa295002d,0x7ce00248}},	//   атку, اصلة_, раді, _föro
  { {0x3f83001b,0x6935020f,0xf865173f,0xfaa20557}},	//   luju_, анду, авло, іашо
  { {0x6ae20037,0x61200052,0x02e20037,0x66dc0028}},	//   _पत्र, völk, _पत्न, _fékk
  { {0x3f830a12,0x8cc80011,0x6d460a89,0x61200032}},	//   nuju_, ़ानो, _zuka, wölk
  { {0x6d4600a2,0x2d95111e,0xdddb001e,0x7c3a00d9}},	//   _yuka, арос, eguš, _útra
  { {0x60870003,0x51870001,0xc9870001,0xbcfb0066}},	//   _مشاك, _љуба, _љуби, _uvés
  { {0x3f8316a0,0xb5fb01bd,0xeb000011,0x6f040e76}},	//   kuju_, _reál, ोक्त_, znic
  { {0x3f830027,0x78a30ad2,0x98a7004b,0x66d80097}},	//   juju_, menv, amnă_, _kíkt
  { {0xa3b60037,0xde59002d,0x4e190015,0xdced0027}},	//   जित_, _раді_, _июля_, brać
  { {0xd94600de,0x6f041740,0x62860a9d,0x9ae80009}},	//   реги, vnic, rgko, רַתִ
  { {0x6f04003e,0x412a00be,0x271e0011,0x6d461741}},	//   wnic, того_, पत्र_, _ruka
  { {0xf5480020,0xa2e60015,0x366a01b6,0x201e0028}},	//   _tục_, _войд, каво_, æti_
  { {0x539a000b,0xfd4c001a,0x7ae4002c,0xb5fd04d2}},	//   _ייצו, _nhiễ, _ulit, jašk

  { {0x7ce0006f,0xee3a102d,0x78a30227,0x3eaf1742}},	// [3400] _förl, тна_, kenv, _magt_
  { {0xccc30015,0x6f041743,0x3eaf1744,0x6c560024}},	//   обуй, snic, _lagt_, ртає
  { {0x307b000b,0xa87b007e,0x287b000b,0x987b0009}},	//   _באינ, _באיר, _בנימ, _באיט
  { {0x96960046,0x9183001a,0x6d4615b2,0xc4c9000b}},	//   _трош, _hết_, _tuka, וג_
  { {0x91830020,0x64431745,0xaa7b0066,0x19f6004c}},	//   _kết_, _ogni, lkýc, јџер
  { {0xa6db0065,0x79b7000b,0xdced0027,0xfce60472}},	//   _viðe, ילנד_, vrać, _того
  { {0x90d50020,0x6120000e,0x4ea6002d,0xe3a70012}},	//   _tìn, rölh, арпа, _بر_
  { {0x213e0274,0xd6d70015,0x68fc034f,0xe72f0012}},	//   _with_, иты_, hird, وصي_
  { {0x3f83001c,0xbd870003,0x645e0051,0x68fc0060}},	//   zuju_, لنين_, _õpik, kird
  { {0x63b80013,0x02af0037,0x0d97000b,0x3eb2004a}},	//   _prvn, _जोड़न, סכים_, hdyt_
  { {0x26c2004a,0x68fc003a,0x66e6025c,0xa1130012}},	//   _onko_, dird, _кожа, _بولت
  { {0x83fc0027,0x32670ec6,0x96ba0012,0x7bda0914}},	//   nađi, штов, _جائز_, rytu
  { {0xe4e6002d,0xf8da0037,0x28c30037,0xbddb0054}},	//   _війн, _बकाय, शालि, _agèn
  { {0xd0060003,0x3f83051f,0xc5130012,0x3d100011}},	//   كل_, tuju_, _وبوت, ़कों_
  { {0x9f05000a,0x43840003,0xbb840003,0x644f0002}},	//   موسو, _العق, _العي, ścic
  { {0x8f9b000b,0x2fcd0027,0x643b000b,0x92f40003}},	//   כילי, ćeg_, _בעונ, _وأيض
  { {0x7ce0000f,0xb9950003,0x7afd02bd,0x3f830027}},	// [3410] _törl, _الخب, mist, suju_
  { {0x291801a2,0x3e65001a,0x7ce002f1,0xfd100012}},	//   cora_, ặt_, _förm, وجل_
  { {0x7ce000a2,0x7afd0006,0xa6db0065,0x92590015}},	//   _görm, oist, _viðb, гает_
  { {0x2d840051,0x92580012,0x63540024,0x7b1d01e3}},	//   kume_, لشهر_, івчу, céut
  { {0xe9a80003,0xd2b80009,0x19eb0012,0xdcb10081}},	//   لدون_, ילאת_, خراً_, hỏa_
  { {0x61200006,0x3158000b,0xf9580009,0x71720012}},	//   töli, סיון_, ססות_, أهوا
  { {0x394900c6,0x4878002d,0x3a870015,0xc078002d}},	//   _luas_, рсія_, _вызв, рсії_
  { {0xb5fd1746,0x69dd004a,0x29180027,0xba740003}},	//   laši, kyse, zora_, _واقت
  { {0x7afd1747,0x28c70011,0xee39003c,0xaa7b0030}},	//   dist, लादि, ыни_, zkýc
  { {0x50db0037,0x6120000e,0xb5fd0cf9,0x64440060}},	//   _भविष, lölv, naši, _şiir
  { {0x7ce00163,0x7f840003,0xc2c60003,0xc1d00037}},	//   _börj, _ولكن, ميدي, सङ्ग
  { {0x47350046,0xc0490093,0xab190024,0x3949016d}},	//   _унес, _טז_, ицях_, _buas_
  { {0x68fc003a,0x27210028,0xb5fd0fb5,0x3f73001b}},	//   tird, jóni_, kaši, eću_
  { {0x6d5b00c6,0xaa7b0026,0x39490149,0xcdb6000b}},	//   mpua, tkýc, _duas_, _לפנה_
  { {0xa3550003,0x2731001a,0xe8f5001a,0x2ca51748}},	//   _اختص, _cơng_, _đức_, meld_
  { {0x98790039,0xdfcf0003,0xe9ff001a,0x5b7a0009}},	//   kšķu_, ريق_, _ngắn_, _ערפא
  { {0x270c0066,0x63450010,0xe0da0014,0xaa7b00d9}},	// [3420] něna_, _mėnu, _бвп_, skýc
  { {0xee370ec6,0x8d850012,0xbc6a0012,0xdcb10081}},	//   сну_, تشفن, امان_, _ửa_
  { {0xf7720003,0x32460003,0x493b0009,0x16040011}},	//   _عاد_, مناف, _תגיו, _रखकर_
  { {0xa294002d,0x0c370012,0x2ca51749,0x2b910081}},	//   іалі, حكمة_, held_, iác_
  { {0x2ca500bd,0x2b91001a,0xdce40002,0x83fc0027}},	//   keld_, hác_, esią, rađi
  { {0x3d110037,0x9fa20028,0x67240114,0xa9c50012}},	//   ठकों_, _bíða_, llij, تزمو
  { {0x22490027,0x7afd174a,0x8f3404ba,0xddd00034}},	//   žaka_, yist, оекц, żeńs
  { {0xf10501e1,0x6724174b,0x973c0027,0x2d800347}},	//   _रद्द_, nlij, _opće, orie_
  { {0x6d5b0101,0xceb3000b,0x2ca5174c,0xad660012}},	//   gpua, ליה_, feld_, حابه
  { {0xa6db0065,0x25d7000b,0x7ae2174d,0x3949174e}},	//   _miða, צוין_, lkot, _ruas_
  { {0x39490149,0x2a690005,0x74c90037,0x0057000b}},	//   _suas_, _peab_, रातः, _השבת_
  { {0x7ae20010,0xbb930015,0x7afd0575,0xfbd30009}},	//   nkot, чающ, uist, לתת_
  { {0x644f0002,0x63480066,0x41e40024,0xc56a0012}},	//   ścia, _měni, піра, _إحصل_
  { {0xa3e80037,0x05770009,0x7ae20fa1,0x6724174f}},	//   यना_, _פגום_, hkot, elij
  { {0x7ae2004a,0x644302e7,0x2a690051,0x3cfb000b}},	//   kkot, žnik, _teab_, _תלונ
  { {0x7ce0006f,0x0dcb0001,0x387f003a,0x25a9002c}},	//   _förk, лузи_, şur_, twal_
  { {0x3c470003,0x2907146e,0x84470012,0x9e4b0009}},	// [3430] مضاف, ynna_, مخال, אֲבִ
  { {0xf9900003,0xfaff0070,0x6115002d,0xa50b0009}},	//   _أبي_, lië_, _єдну, ָּמִ
  { {0x7d080058,0x28c70011,0xb5fd1750,0xfb84003c}},	//   inds, लासि, raši, зычн
  { {0x326b0003,0xfaff0070,0x2d80000d,0xcb340048}},	//   احاً_, nië_, brie_, пехъ
  { {0x6120000f,0x9f470066,0xcec00066,0x9fa20028}},	//   rölv, rzní_, ářet_, _síða_
  { {0x6eea0029,0x7bc50028,0x4f790014,0x2f550594}},	//   _výbe, _áhug, ащия_, отис
  { {0xa6c904ad,0xef190034,0x2ca51751,0xddc40073}},	//   илка_, toż_, veld_, maiš
  { {0x96b90046,0x612007cc,0xa2940024,0x57fc0009}},	//   руку_, lölt, _насі, טלוו
  { {0x7ae900a2,0xceb4000b,0x2ca51752,0x27210011}},	//   _ilet, פיץ_, teld_, मतौर_
  { {0x03950048,0x6d5b016d,0x59b80011,0xe5050012}},	//   ормя, rpua, इटसर, تبعي
  { {0x130a0015,0x2ca50070,0x33f5002d,0xca290009}},	//   иной_, reld_, ючис, _סם_
  { {0xdb1c0061,0x3f87003a,0x92f6002d,0x8c1a000b}},	//   _arrê, munu_, ічні, יותי
  { {0x7ce00163,0x6353000d,0x6120000e,0x7d1a07c9}},	//   _förh, _bănc, költ, bots
  { {0x7ae90054,0xc9520009,0x18670681,0x859a0009}},	//   _llet, ומך_, жари_, _כשנו
  { {0x67240070,0x3f87003a,0x7ae902bd,0x6c560009}},	//   tlij, nunu_, _olet, _ויצא_
  { {0xc7b2000b,0xfb170003,0x7c3e00f1,0x6d431753}},	//   ובל_, _وقوع_, _úpra, _hina
  { {0x6d430101,0x672400bd,0x7e6b000e,0x2d801754}},	// [3440] _kina, rlij, _megp, urie_
  { {0x67240049,0x6d431755,0x61201756,0xdd8f0012}},	//   slij, _jina, tölu, ئول_
  { {0xa09b0009,0x037a0012,0xb5fd001b,0x6d4b0843}},	//   _דייט, شحات_, mašu, _luga
  { {0xdcfb001c,0x3f87003a,0x6d590002,0x63bc006f}},	//   druč, dunu_, _otwa, årni
  { {0xdb21000f,0x6f1b0013,0x4a9b0009,0xd3370009}},	//   ítás, douc, שינג, קרנה_
  { {0x91bb000b,0xd8f7002d,0x7ae9101e,0xb5fd0010}},	//   ימני, онії_, _elet, našu
  { {0xa6db0028,0xb6ba0009,0x6d4b1757,0xba3b01a0}},	//   _miðn, ֹצִי, _auga, veïm
  { {0x7c2e048b,0xdce90027,0xb7db000b,0x6d431758}},	//   _izbr, dređ, יקצי, _aina
  { {0x3f87001e,0x29000017,0x6d431759,0xddc9004b}},	//   aunu_, éias_, _bina, rbeş
  { {0xb4e40037,0x07a60014,0x3f8705b6,0x7d080422}},	//   नसे_, _мазн, bunu_, unds
  { {0x7d1a0051,0x6d590052,0xdb1d000e,0xdee60012}},	//   rots, _etwa, őzít, _وأصي
  { {0xfc460066,0x7d1a0269,0x8c1b0009,0x79820034}},	//   šího_, sots, שוטי, orow
  { {0xdd8f0003,0x61200028,0x6d4b08e2,0xfaff0227}},	//   _لون_, jöls, _guga, rië_
  { {0x6d430101,0xf3f1001a,0x7c2e05b1,0x5efd0011}},	//   _gina, hạy_, _ozbr, रोन्_
  { {0x270c0066,0x6d4b0052,0x466b00f5,0xcf3b0012}},	//   něno_, _zuga, ирам_, لأرض_
  { {0x9f050003,0x877b000b,0xa3c90011,0x7d550048}},	//   أورو, יאלי, ोहर_, звах
  { {0x6120000f,0x291c09ea,0x83fc0027,0x291a0028}},	// [3450] tölt, kova_, rađu, ófað_
  { {0x61320058,0x7ae9038e,0x79820002,0x3d150011}},	//   gæld, _slet, drow, तकें_
  { {0xf0920093,0x14190003,0x79820002,0xddc40010}},	//   _אני_, حياة_, erow, raiš
  { {0xdcc40037,0x539b0009,0x79820034,0xddd30034}},	//   राउज़, שיאו, frow, ągły
  { {0x81a70003,0xc9640024,0x7e560009,0x0ab80012}},	//   تحال, двій, _מסרב_, تطلب_
  { {0xe8f8002d,0x4dda000b,0xf548001a,0x3f87003a}},	//   олі_, _החשו, _cụm_, tunu_
  { {0xf7710003,0xceb90066,0x98a20055,0xc4d20009}},	//   ءات_, hoře_, хище, _אגם_
  { {0xdce40002,0xf1cb0037,0x6d43175a,0x3f87175b}},	//   dsię, ामान, _sina, runu_
  { {0x6d4301e5,0xddcb0039,0x6f09175c,0xdce40002}},	//   _pina, _iegū, rnec, esię
  { {0xa3df0044,0x224900b6,0x21a40003,0xfd110012}},	//   _तथा_, _agak_, _تمكّ, عجة_
  { {0x8b260015,0x644f0002,0x3ae20028,0x8ccd0037}},	//   здне, ścio, _hópi_, ताबो
  { {0x6d4b00c6,0x8bd60009,0xe29a05c8,0x03d60009}},	//   _tuga, לותו_, щам_, לותם_
  { {0xdc3c0333,0x6d430101,0x4426001a,0xc956003c}},	//   kšķi, _tina, ́o_, ятны
  { {0x55ba000b,0xadd6000b,0x3d150037,0xdce90027}},	//   _למנו, _מונח_, तकों_, pređ
  { {0xa3cc0037,0x5fbd0037,0x3ea9002a,0x8cc80037}},	//   रमण_, ्मिल, feat_, ़ारो
  { {0x3f51001a,0x9c7c01bd,0x4b7a0009,0x2bb00011}},	//   _máu_, nkčn, _האקו, _जनता
  { {0xb5fd0035,0x05850024,0x25ad0227,0xdb080031}},	// [3460] pašu, дуєм, nwel_, ülír
  { {0x6d230001,0x2705001e,0xdb1c0061,0x41bb0009}},	//   едуз, mēnu_, _irré, _פציע
  { {0x7ac60014,0x50db000b,0x61320058,0xe7760012}},	//   зсле, _החיצ, ræld, _عادة
  { {0xa3be0037,0x798211f7,0x74130012,0xec130012}},	//   ीमत_, trow, رونا, روند
  { {0xa6db0028,0xf1940015,0x25ad0070,0xdebb0009}},	//   _miðl, филь, jwel_, _המכל
  { {0x7982002a,0xdb070028,0x394d09ec,0x291c00b8}},	//   rrow, _brjó, _dues_, uova_
  { {0x3f9801b3,0x7c2e0826,0xf8b30009,0x27210097}},	//   ntru_, _uzbr, גשו_, jóns_
  { {0x7982003e,0x6beb000b,0xdd900003,0x64620002}},	//   prow, _הַמַ, نوب_, świę
  { {0x39450061,0x21670001,0x291c175d,0x994a0012}},	//   _fils_, _нити_, pova_, _طلال_
  { {0xa177000b,0xfdf70009,0x515b0009,0x71730012}},	//   _מעמד_, פצית_, _לכמו, _أهلا
  { {0x7ce0006f,0xf8b30009,0xa6db0097,0x3f77004b}},	//   _förv, _רשע_, _biðl, cău_
  { {0x52a70003,0x6b88175e,0xdce40073,0xdc3c0035}},	//   أصدق, rudg, priė, zšķi
  { {0x7d010039,0xa3b30011,0x76bb0009,0x61e2175f}},	//   bils, _जैन_, _למאפ, nyol
  { {0xa63b0093,0x7d57000b,0xd7e60003,0xb5fd04cf}},	//   _הגדר, _ציוד_, نك_, rašt
  { {0xc49b000b,0xdc9b000b,0x26d900b6,0x649b0009}},	//   _השות, _היול, _poso_, _הסוד
  { {0xf709001a,0xf7700012,0x9f510031,0xd4090012}},	//   hần_, طاف_, nzzé_, _بتهم_
  { {0xf6500003,0x4a7c000b,0x7aed01ea,0x3ea91760}},	// [3470] ائف_, _הרחב, _ilat, reat_
  { {0xc1720009,0x394d0025,0x7d1e0227,0x61ef0060}},	//   _שחי_, _rues_, gops, ınlı
  { {0x7b640109,0xdb1f000e,0xb09a0009,0x889a0009}},	//   етче, ővít, _ויתר, _ובתי
  { {0x60c80005,0x394d0164,0x629e000e,0xe299002d}},	//   _andm, _pues_, őpon, іал_
  { {0x20d5002d,0x3f511761,0x2a6d0051,0xb6ba0009}},	//   дійс, _sáu_, _veeb_, _וצרי
  { {0xa3be0037,0x7aed0054,0x4759004d,0x98a200f5}},	//   ीमा_, _llat, ория_, више
  { {0x7ae60065,0x2a6d0051,0xe7390223,0xa8580009}},	//   ykkt, _teeb_, оек_, ליגה_
  { {0x64580da6,0x657d000e,0x6d470cfc,0x6d4f1762}},	//   _afvi, ásho, _hija, _kuca
  { {0x394d0051,0xdd8e0012,0x6d4f004b,0x6aab0031}},	//   _uues_, لوي_, _juca, megf
  { {0x6ab600a1,0x7ce00b11,0xfbd10012,0x5efd0011}},	//   _sayf, _föru, نتج_, रोत्_
  { {0xa3b60037,0x30780012,0x7aed1763,0xcc560009}},	//   जिए_, _رحلة_, _blat, ובתי_
  { {0xe1e70012,0x7ce00032,0x6d5d0269,0xdced0060}},	//   نس_, _hört, _otsa, yrağ
  { {0x80b40037,0x7aed0002,0x23600027,0xaa7b01bd}},	//   _इसमे, _dlat, _čije_, ckým
  { {0x69b00037,0x67291764,0xdcfb0035,0xddc40034}},	//   _आईसी, llej, bruā, aciś
  { {0x6d5d0259,0x321e0034,0x67291765,0xcaf60012}},	//   _atsa, łty_, olej, _يسبب
  { {0x3f8a003a,0xbfc30014,0x2705001e,0x6f0d1766}},	//   rubu_, ъбск, mēns_, gnac
  { {0xcb130093,0xc692000b,0xddcd003a,0xa5bb000e}},	// [3480] _שלח_, כאן_, rbaş, _szór
  { {0x3e6c0020,0x6e2b0052,0xb4e80037,0x4c830024}},	//   ết_, ügba, बसे_, клув
  { {0xdced0027,0x6d470db2,0xa6db0028,0xeb97077e}},	//   građ, _dija, _miðj, дих_
  { {0x673b003e,0xbae5002d,0x60da0054,0x3f980035}},	//   jmuj, нцій, _sotm, _īru_
  { {0x7bd50029,0x6d470164,0x2d840031,0x7ce00031}},	//   äzuj, _fija, _íme_, _bört
  { {0xd1300003,0x644f0002,0x91f70009,0x3c460012}},	//   دمت_, ścij, ומנו_, _يَحِ
  { {0x98be001e,0x67290164,0x7ce00060,0xb8d60011}},	//   _citā_, flej, _dört, _जस_
  { {0xd6d0000a,0x7ce00065,0x6729012e,0x3f800010}},	//   اقة_, _vöru, glej, čiu_
  { {0x64590656,0xa6db0065,0x69c0000d,0xa3b60037}},	//   świe, _biðj, _urme, जिक_
  { {0x6f0d003e,0x7aed1767,0x89db0009,0x6729008e}},	//   znac, _slat, _וחמי, alej
  { {0x6f0d0002,0x6ef10058,0xd4970015,0x44f70012}},	//   ynac, _håbe, фры_, بريج_
  { {0x8c3c00a2,0x92580015,0x69c20011,0x3eb80035}},	//   neği, мают_, लिपी, ērts_
  { {0x8d930012,0x44270032,0xf5930012,0xdced001b}},	//   _للنش, _eyn_, _للنج, zrađ
  { {0xa6db0028,0x3cf70003,0x4cb70024,0x2ea70011}},	//   _viðm, _يعود_, _олію_, ख़्त
  { {0x25ec0011,0x6d47017b,0xe8df0081,0xd6db0588}},	//   आईवी_, _rija, _cuộn_, ота_
  { {0x6d470006,0x7aed0051,0x98a4001e,0xf5e70024}},	//   _sija, _ulat, ēmā_, мізм
  { {0x50670014,0x9df90014,0xdd910012,0x44270227}},	// [3490] _отна, чнат_, طوا_, _zyn_
  { {0x2cb81768,0xcd97000b,0xf5480081,0xb5fb0031}},	//   _card_, ודמת_, _bụi_, _beár
  { {0x673b0002,0x67200027,0x2c340009,0xf1bf0018}},	//   ymuj, komj, תָּם_, lvá_
  { {0x160e0037,0xdbd10051,0xf1bf1038,0x200c0064}},	//   ापार_, müüg, ová_, údie_
  { {0x865a000b,0x81ab0012,0xb65a0009,0xfaf80009}},	//   _מדרי, تطاف_, _מדרש, וצאי_
  { {0xa7b50001,0x98ba0010,0x3eb902c3,0xa3be0011}},	//   есиј, _tipą_, _hast_, ँटा_
  { {0x67290005,0xddc6001e,0xab62003a,0xf1b90042}},	//   tlej, _iekš, çütl, _myši_
  { {0x7ce01769,0x8c3c00a2,0xe9ff0081,0x680e0031}},	//   _förs, ceği, _ngần_, lődé
  { {0x7ce0176a,0xc1050003,0x7cf20058,0x9967002d}},	//   _tört, _كوري, _færd, _італ
  { {0xdb0b0052,0x67bb0003,0x3eb9176b,0x0d82003c}},	//   _erfü, _واضح_, _last_, ыльн
  { {0xc209000b,0xab2a132d,0x6729176c,0x232a176d}},	//   _פה_, зона_, plej, зони_
  { {0x7af9003a,0xcf560009,0x63b80040,0x660a0030}},	//   _çatı, _טבעת_, ævni, ámká
  { {0x2cac006f,0xc3320009,0x35a50048,0xdcb10081}},	//   bedd_, טוט_, _чалг, hỏi_
  { {0x4dda0009,0xade80012,0xd1320012,0xdce9001b}},	//   _מחנו, _تفهم_, امس_, dseć
  { {0x07a30001,0x68e10028,0x70530003,0xc0520009}},	//   ларн, ölda, انفا, רזל_
  { {0x3ead0006,0x6eea0042,0x3eb9064a,0x05760012}},	//   neet_, _výbo, _cast_, فائد
  { {0xd6cf0003,0x3f87015b,0xa2ad0011,0x7cf20262}},	// [34a0] حقق_, hrnu_, ज़र्, _lære
  { {0x3eb90036,0xe29f0028,0x721b0009,0xdd8f0012}},	//   _east_, miða_, _מופח, صوم_
  { {0x8c3c00a2,0xd11d0037,0x9a6a0003,0xe29f0028}},	//   teği, पकरण_, كمال_, liða_
  { {0x3ead004a,0x69c4176e,0x2fc50058,0x26dd0002}},	//   jeet_, _krie, ælge_, _nowo_
  { {0xe89400b3,0x3ae20028,0x2cb80c23,0xcb130009}},	//   валь, _hóps_, _tard_, נלד_
  { {0xc1040012,0x6ef10040,0x224d0031,0x7cf20474}},	//   ضوعي, _våbe, _egek_, _bære
  { {0x7cf200c5,0xf093000b,0x7ce0006f,0xe29f0028}},	//   _værd, אנו_, _förr, yfð_
  { {0x539b015a,0x8f9b000b,0x61e60010,0xda660012}},	//   _מילו, ליצי, kykl, _ساري
  { {0x67200027,0x56570012,0xe8fa0148,0x270c0030}},	//   romj, رشيح_, _ела_, něni_
  { {0xdb150052,0x61e60010,0xcd970009,0x60660012}},	//   _erzä, dykl, עדית_, _أهال
  { {0xccf30093,0x9e66002d,0xe29f0097,0x2b490031}},	//   רכת_, _звед, eiða_, _piac_
  { {0xa6db0028,0x7c3a0028,0x2cac006f,0xf4130009}},	//   _viðk, _útru, sedd_, טפת_
  { {0x2b490026,0x66d30012,0xfce616fb,0x61e60073}},	//   _viac_, _حينئ, _подо, gykl
  { {0x752101a0,0x69c4176f,0x31350bda,0x7ced0031}},	//   colz, _drie, тегр, _túra
  { {0x3ea00e67,0x3eb9051c,0x54570009,0x8ccd0011}},	//   ffit_, _past_, _אסון_, तारो
  { {0xb0630029,0x69c413fc,0x8cc80011,0xdb230031}},	//   _zväč, _frie, ़ाको, érün
  { {0x97240012,0x70c90011,0x3eb91770,0x39521771}},	// [34b0] افقو, िफ़ॉल, _vast_, _guys_
  { {0x6abd0192,0xddc001e9,0x6b880227,0xdbd1005e}},	//   ldsf, kamž, ordg, püüg
  { {0xa6db0028,0x9d1b000b,0x69c40029,0x7cf20262}},	//   _liði, לומט, _zrie, _bærb
  { {0xbebd0039,0x9980003a,0xc01c001a,0x8c1b0009}},	//   rlūk, çiş_, _lược_, הובי
  { {0x442b0020,0x9aec0009,0xa2f80009,0xc3340009}},	//   ́c_, הַגִ, עמדה_, אוף_
  { {0x3158000b,0x3d1a0037,0x09e20024,0xc9540009}},	//   עיון_, नकों_, рошн, אמס_
  { {0x6fb2000a,0x3ead03d5,0xac18002d,0xd8b80003}},	//   لموا, teet_, _зору_, عدها_
  { {0x78a4001c,0x7cf20192,0x645a1772,0xd00e0012}},	//   điva, _være, ecti, تلى_
  { {0x7ce00052,0x6d4a000d,0xa6db0028,0x7bdc0052}},	//   _körp, _bifa, _viðh, ärun
  { {0x2d830133,0x78ba0010,0x80270012,0x61e61773}},	//   čje_, _gatv, _كرام, vykl
  { {0xc6e7007c,0x399b0017,0x28d50037,0x4ee7002d}},	//   _підп, lês_, दानि, _підз
  { {0x78ba1774,0x29111775,0x5dd50012,0xe1ff01e3}},	//   _zatv, enza_, _لتتأ, rbón_
  { {0x399b0149,0xcad6000b,0xc27a0009,0x2d8d01e3}},	//   nês_, דורת_, וררי, quee_
  { {0x69c400bd,0x6abb0052,0xf992000b,0xe1ff000e}},	//   _vrie, _lauf, ברך_, mból_
  { {0x61e6007a,0xf092000b,0xa6960001,0xe1ff0031}},	//   sykl, ינם_, крај, lból_
  { {0x290701e5,0xe1f20003,0x2416000b,0xdb190066}},	//   hina_, _نسخ_, _שחקן_, _trvá
  { {0x9aeb0009,0x6da60012,0xb91a0012,0x7a490035}},	// [34c0] _חַיִ, ضمام, _يتخذ_, _cītī
  { {0x98be007a,0xe5a30001,0x656400b6,0xee370ec6}},	//   _kitą_, рифи, rpih, тну_
  { {0x644f003e,0x6abb0032,0x29071776,0xd24f003c}},	//   ściw, _bauf, dina_, иц_
  { {0xe1ff000e,0x7017000b,0x6d4600d9,0x42d50024}},	//   kból_, _יחיד_, íkaz, лічу
  { {0x78ba007a,0x64590002,0x6724004a,0xc333000b}},	//   _patv, świa, moij, בוא_
  { {0xf1b3000b,0x28d50011,0xc5ee0011,0xe1ff0031}},	//   יסד_, दायि, छनीय_, dból_
  { {0xdfd0000a,0xc29a0001,0x27e700b0,0xd7ef0012}},	//   صية_, _отац_, gynn_, يكه_
  { {0x7c3e0029,0x6d4a00b6,0x8c1b000b,0xf7730009}},	//   _úpri, _sifa, _חולי, בקה_
  { {0x399b0017,0x29071777,0x81a50012,0xe1ff0031}},	//   cês_, bina_, _محلل, gból_
  { {0x6abb0002,0xb9c50012,0x99330012,0x20050031}},	//   _zauf, _حتفه, _نفقت, úlik_
  { {0x9c7c0010,0x2b9c0064,0x5ea60012,0x69c20227}},	//   nkči, níc_, _لمال, lvoe
  { {0xb69b075e,0x57fb0009,0x5b7b0009,0xfeea0012}},	//   _amân, _קלאו, ורטא, _تعطى_
  { {0x69c20070,0x6abd153b,0x7ae30018,0x394c1778}},	//   nvoe, rdsf, ênti, _kids_
  { {0xc50a0003,0xac180001,0xc9530009,0xf5480081}},	//   _تتصل_, _полу_, ימש_, _cụt_
  { {0xcebb0001,0x13b30012,0xa6db0097,0xf5370009}},	//   мља_, _نصيح, _miðv, _שנוי_
  { {0xbd6b0001,0x66090028,0x672d000e,0x4ea70048}},	//   држе_, _þekk, ulaj, ърга
  { {0x67020011,0x7cf6004b,0x69c20227,0x8d740012}},	// [34d0] रोधक_, _vârf, jvoe, لالا
  { {0x2c7c0066,0x657d000e,0x270c0030,0x62800064}},	//   vádí_, áshi, měnu_, ómov
  { {0xb4ac0037,0xd2510003,0xd4980014,0x69c20227}},	//   कड़े_, منا_, ърт_, evoe
  { {0x3f91003a,0x6008000b,0x9f47000e,0x7ae01387}},	//   muzu_, _יִרְ, sznú_, _comt
  { {0xa1580538,0xca840024,0x4aa50011,0x394c1779}},	//   вачу_, ргій, ग्यव, _bids_
  { {0x3ea6002c,0xd59a0009,0x399b0018,0x7c22004b}},	//   _abot_, _אבשל, rês_, şora
  { {0x3f9100a2,0x3f580017,0x63b80058,0x97c50012}},	//   nuzu_, _céu_, ævnt, اقبو
  { {0xf838000b,0xe1ff000e,0x3f580054,0xddc00010}},	//   כנות_, tból_, _déu_, jamų
  { {0xad650012,0x5215003c,0x2907177a,0x3dc6177b}},	//   داعه, _сдат, pina_, _crow_
  { {0xd1b80003,0x394c0070,0xe1ff000e,0x04b50048}},	//   _جافا_, _gids_, rból_, усия
  { {0x2905003a,0xe1ff000e,0x657b00e6,0xa2f50009}},	//   _imla_, sból_, ssuh, ָמָה_
  { {0xcad5000b,0x6f7a0009,0xb4e00011,0xe1ff0031}},	//   אוֹת_, _נְבו, _तव्_, pból_
  { {0x6f090002,0x3dc6002a,0x667a0009,0xddeb0012}},	//   miec, _grow_, _נטסק, _تراه_
  { {0xa6db0065,0x6f09001e,0x394c006f,0xf8b30011}},	//   _miðu, liec, öds_, ंजिय
  { {0x9d1a000b,0x68e1177c,0xb4bf0011,0xad1a0009}},	//   _אוסט, _mold, ँयी_, _אוסר
  { {0x6ee30005,0xd00f0003,0x2b9c0066,0x5276002d}},	//   _sõbr, ألف_, víc_, _суку
  { {0xa6db0065,0x3ebf004a,0xf5480081,0x644f0034}},	// [34e0] _niðu, idut_, _tụt_, ściu
  { {0x01fb0009,0xf9930009,0x61200032,0x68e1177d}},	//   _נפיל, _פרת_, hölz, _nold
  { {0x389b0009,0xb09b0009,0xa2d80011,0x6f090034}},	//   _איינ, _אייר, याप्, kiec
  { {0x69c200bd,0xa6db0028,0xe2920003,0xdcb1001a}},	//   tvoe, _biðu, إذا_, hẻ_
  { {0xc05a007c,0x3f580065,0xddc4001e,0x2b9c014a}},	//   ній_, _séu_, laiž, síc_
  { {0x69c20070,0xdd9f0066,0xe5a30001,0x5dcb0009}},	//   rvoe, ěňte_, _ћири, _אֶלְ
  { {0xdfa60003,0xa857000b,0xa6db0028,0x7ae00107}},	//   احتي, ניקה_, _viðv, _tomt
  { {0x2d8203ca,0x6d4e177e,0xf7730009,0xeb1f0011}},	//   škem_, _hiba, זקה_, यकृत_
  { {0xa2d80037,0x61320040,0x58960012,0x68e1177f}},	//   यान्, tæll, _مجاز, _fold
  { {0x8f76007c,0xdce90029,0x114a0012,0xd9460048}},	//   _буді, ateľ, _أجرى_, _сези
  { {0x6f090c6b,0x69ba0011,0x5b150048,0xe2f90024}},	//   biec, _एनडी, имот, вені_
  { {0x973c0027,0x3f91003a,0x93fb0009,0x6f090034}},	//   _opći, vuzu_, תלטי, ciec
  { {0x68e1003a,0x2d9f0c4d,0xa2d50011,0x5887003c}},	//   _yold, ctue_, णात्, лыва
  { {0x5d83000a,0xac97000a,0x25a00058,0xcd970009}},	//   _الول, _منها_, dtil_, _עדות_
  { {0xd7f80047,0xe44f0003,0x73c30012,0x07090012}},	//   гут_, _عضو_, _هيوم, نيسي_
  { {0xa4ff0037,0x7c380416,0x290a0018,0xdb0b0248}},	//   ोच्च_, _izvr, aiba_, _arfö
  { {0x5c750662,0x6353004b,0x65950c7b,0x60120031}},	// [34f0] илат, _răni, разу, tűmé
  { {0x7c2e006f,0x753c0002,0x290a0164,0x2d871780}},	//   _bybr, _chrz, ciba_, čne_
  { {0x6d4e00c6,0xaa550046,0x29d80029,0xb0840024}},	//   _diba, авеш, ržať_, _свiд
  { {0xd6db00e3,0xab2b0003,0xb7da000b,0xbc380012}},	//   _что_, رسال_, _סקרי, اسكا_
  { {0x067a000b,0x2a980003,0x4e7a000b,0xe9870001}},	//   _שנשל, ائمة_, _בארצ, ућен
  { {0xc05b002d,0x6f090002,0xa6db0028,0x1b770012}},	//   хід_, wiec, _viðu, _مدرج
  { {0x6f09121f,0xf6510003,0x68e11781,0x6e950012}},	//   tiec, يئة_, _vold, للغا
  { {0x3ebf004a,0x4585003c,0x2d9f0025,0x0d85112d}},	//   udut_, агив, ttue_, алин
  { {0xe5760015,0x29ce0028,0xa15900b3,0xee390048}},	//   азы_, rðað_, _разу_, ъни_
  { {0xb3a9003a,0x6d4100b6,0xada80003,0xe5720009}},	//   _çıkı, umla, اديق_, קַח_
  { {0x6f091782,0xd0110003,0xeb990001,0x6d411783}},	//   piec, _بلا_, њим_, rmla
  { {0x69c90562,0x69090030,0xf1bf0031,0xa6db0097}},	//   _kree, užen, _áás_, _miðs
  { {0x7f570061,0x6909124c,0x9567010c,0x0d67003c}},	//   _auxq, ržen, _съед, _съем
  { {0x7e7b00b6,0xa96700f5,0x8dfa0009,0x96a10011}},	//   laup, рира_, _שהסת, क्रॉ
  { {0x61eb0028,0xc7460012,0xd079003c,0x2f1a0035}},	//   hygl, لضري, ысяч_, līga_
  { {0xe8df0020,0x539a000b,0x2d920164,0x25a00033}},	//   _muốn_, _סיפו, tuye_, ttil_
  { {0xd1320003,0xad650003,0x2f1a0035,0x6d5b1784}},	// [3500] _ومع_, ماله, nīga_, nqua
  { {0x9a3b000b,0x25a00058,0xb97b000b,0x7e7b0052}},	//   _בתפק, rtil_, _שניי, haup
  { {0x1d19007c,0xeb9a05cc,0x8b2600b3,0x6d5b0132}},	//   ують_, тие_, адже, hqua
  { {0x7ae40006,0xe57a0014,0x25a00033,0x7c2e0107}},	//   _joit, _изм_, ptil_, _vybr
  { {0xc3330093,0x7c2e003e,0x4426003e,0xa6db0028}},	//   קוד_, _wybr, ło_, _viðt
  { {0x6f1604fa,0x6d5b002a,0xf993000b,0x753c0052}},	//   lnyc, dqua, קרו_, _uhrz
  { {0xd00f0003,0xe8df001a,0x6f160002,0x4fb30012}},	//   وله_, _cuốn_, onyc, قصير
  { {0x6b83000d,0x7ae40318,0x6f16047f,0x69c91785}},	//   ânge, _noit, nnyc, _free
  { {0x50b6002d,0xbce60003,0x69c91786,0x2d8d1787}},	//   _всеу, لأدو, _gree, gree_
  { {0xc19b0009,0x29d30012,0xe6110009,0xfd120012}},	//   _בשמי, _بيكس, לִי_, تجع_
  { {0x6ab20037,0x60fb0009,0xbc7b0009,0x4438037d}},	//   ज़ूर, _שהבק, כנית, år_
  { {0x6da6007c,0x6f16003e,0x3f850028,0xe5c60015}},	//   _вида, jnyc, álum_, _вско
  { {0xd9f80037,0x6f1604fa,0x26db0009,0x59b00011}},	//   ्छित_, dnyc, _שקדמ, फ़िगर
  { {0xa6db0028,0xddcf000d,0x15fb000b,0xdca3004c}},	//   _niðr, _lecţ, _שִׁמ, _даљи
  { {0x853b000b,0x7d1d000e,0x75280002,0x5d3b0009}},	//   _שגוי, ésse, modz, _שתוא
  { {0x3014002d,0x501b000b,0x33db0009,0x27210064}},	//   ідтр, דולו, _יחוד, fóny_
  { {0xc639002d,0xa6db0097,0x831c0009,0x9b440012}},	// [3510] упає_, _biðr, _שוחז, _بنيو
  { {0x629b00c1,0xeb1f0037,0xebc70001,0x6f160002}},	//   _scuo, यक्त_, иљен, anyc
  { {0xd6d1000a,0x6136000d,0x6f160002,0xba770003}},	//   _فقد_, tâln, bnyc, لاشت
  { {0xa6db1788,0x7528084b,0x6f1604f3,0x9a880012}},	//   _viðs, hodz, cnyc, لَمْ_
  { {0x68e50006,0xe1ff0164,0x7f3a0009,0xcb140009}},	//   _kohd, nzó_, _תערו, חלף_
  { {0x68e5004a,0x69c90070,0xed560009,0xe4c7003c}},	//   _johd, _vree, _לבשר_, _тёмн
  { {0x9203001e,0xd0f8000b,0x13b40003,0xa3bb0011}},	//   _šādu, שמות_, _وصفح, _अनि_
  { {0x38180093,0x7018000b,0x660d0028,0x6f0d04f4}},	//   יקום_, יחוד_, _þakk, niac
  { {0x78b5000e,0x6b5e0035,0x4d65004c,0x7bda1789}},	//   kezv, _rīga, љков, extu
  { {0x7ae4004a,0x2f1a001e,0x6f0d00c1,0x6f160512}},	//   _soit, rīga_, hiac, znyc
  { {0xb4fa000b,0x7ae4083e,0xf8b30011,0x0cb70011}},	//   רפתי, _poit, ंजीप, _असीम
  { {0xdce0001e,0xf412000b,0x60c1012b,0x61320028}},	//   rpmā, לפי_, _halm, mæli
  { {0xe2970015,0x6f160029,0x7ae4104b,0x0656000b}},	//   щая_, vnyc, _voit, _הינך_
  { {0xd466007c,0x6f160002,0x61460014,0x78b50031}},	//   _лише_, wnyc, сега, gezv
  { {0xbb85000a,0x6d590101,0xc2ea0003,0x33950003}},	//   _البي, _huwa, _معظم_, _العز
  { {0xaa7b0065,0x6d59178a,0x83640012,0xcc140012}},	//   skýr, _kuwa, _بدول, _بذهب
  { {0x8297000b,0xf2970009,0x6f16178b,0xee3a068f}},	// [3520] _הדפס_, _הכפר_, rnyc, уна_
  { {0xddcf007d,0x2d80178c,0x6f16178d,0x45830024}},	//   _secţ, rsie_, snyc, ягув
  { {0xb5fd007a,0x8ca90037,0x59b80037,0xc5e9000b}},	//   rašy, ज्यो, ेटवर, עד_
  { {0x9186000a,0x645504cf,0x9696004c,0x60c1178e}},	//   مجتم, _egzi, _урош, _aalm
  { {0x0854002d,0x26c20027,0x2918003a,0x4a9b0009}},	//   овлю, _iako_, onra_, רינג
  { {0xa50a0098,0x86370009,0xa3b30011,0x9f470064}},	//   _сега_, _לרכב_, _जैक_, rzný_
  { {0x26c20750,0x6ef501c5,0x3706022a,0xf8b30009}},	//   _kako_, _sába, йчив, פשה_
  { {0x6d590101,0x26c20756,0x9c17000b,0x75280002}},	//   _buwa, _jako_, _החלק_, wodz
  { {0x2dda0003,0x7bc6001e,0xbd870003,0xa2d50037}},	//   ابعة_, ākum, منين_, णार्
  { {0x26c20027,0x2d8a009b,0xe29f0028,0x6d59020d}},	//   _lako_, čbe_, miði_, _duwa
  { {0x63a50052,0xe29f0028,0x4789002d,0x28130012}},	//   _ähnl, liði_, _всім_, _فوكس
  { {0x41e7002d,0xe61a002d,0x7cf20260,0x6ec50012}},	//   біга, _йде_, _særl, _وتنق
  { {0xa1590046,0x7982003e,0x26c3001e,0x2f1a001e}},	//   рагу_, nsow, ējot_, līgo_
  { {0xe1ff06ef,0xe3b20012,0x2b460064,0x79820034}},	//   rzó_, _فرع_, ňoch_, isow
  { {0xe1ff000f,0x6f0d087d,0xd47b0009,0x41b50011}},	//   szó_, tiac, _גאול, _आईऍस
  { {0x7982003e,0xdce00039,0xceb90066,0x9c17000b}},	//   ksow, ksmī, toři_, _לחוק_
  { {0x28b90044,0x26c70013,0xfdf10011,0x4ad60011}},	// [3530] _इसलि, ěno_, आईएस_, धारव
  { {0x6f0d0026,0x89dc0009,0xf9920009,0x4aa50011}},	//   siac, _תחזי, _קרי_, ग्रव
  { {0xb609001e,0xabb50012,0xaadd0011,0x23b50012}},	//   _sašķ, تماث, यापक, تماس
  { {0x539b000b,0x9f350024,0xfaa50024,0xf9890012}},	//   ריאו, _фемі, іало, لنصي_
  { {0x018b0015,0xe9a80012,0xe1ff0034,0xe5c7178f}},	//   ущей_, مدون_, rbów_, _усно
  { {0x297c0009,0x656d016d,0x0b7b0012,0x397c0009}},	//   נטוא, mpah, _مصرع_, נטונ
  { {0xfe710003,0xf745002d,0x0a6b0001,0xf8b90011}},	//   ودة_, оеко, _брзи_, _इसीप
  { {0x3b640014,0xc99b0012,0xe2f80024,0x6d59020d}},	//   _хърв, _مخطط_, _лесі_, _puwa
  { {0xceb40093,0xa5db0009,0x6ef10248,0x26b60009}},	//   ליק_, רַ֔י, _påbj, חִים_
  { {0xff08004a,0x7d090001,0xf5050024,0xa2a70011}},	//   äärä_, рног_, ізно, ट्स्
  { {0x2815000a,0x59c70037,0x2f1a001e,0x03d50009}},	//   _بواس, लिवर, cīgo_, קוֹם_
  { {0x4acf0037,0x26c3001e,0xc8690009,0x5dd50012}},	//   _सोमव, ējos_, _ין_, _وقائ
  { {0x82360003,0x6ef5000e,0x9f4c0066,0x98a70034}},	//   تردا, _hábo, ádí_, alną_
  { {0x672f0002,0x6eea0030,0xbd450012,0x26c21790}},	//   _akcj, _nýbr, _بنتي, _sako_
  { {0x7ce0000e,0x4fac0009,0x69cd005e,0x8cd60011}},	//   _törz, ְׁמְ, _erae, बारो
  { {0x7afd008b,0x9f59000e,0x7cf200b0,0x79820034}},	//   chst, ázás_, _værm, ysow
  { {0xceb2000b,0x23600027,0x656d002c,0xc4e60198}},	// [3540] וין_, _čiji_, gpah, ожай
  { {0xe57700b3,0xe29f0097,0xe1260024,0x6d880009}},	//   юзу_, viði_, _ємни, מָעְ
  { {0x26c2048b,0xe3ba0001,0xaf0a0003,0x656d15ff}},	//   _tako_, рбе_, _نقدم_, apah
  { {0x3f980039,0x8c1a000b,0x49ca036f,0xa25b0064}},	//   muru_, בועי, илен_, jdôl
  { {0x2ee61791,0xf2040011,0xba170012,0x3a200060}},	//   _roof_, _शेख़_, ييما_, çip_
  { {0xc5f30093,0xf7720003,0x7cf20058,0xe29f0028}},	//   _חדש_, واع_, _mærk, riði_
  { {0x31a4000e,0xaff70012,0xa88b0009,0x2d8b0030}},	//   höz_, يفها_, שָׂ֥, ácen_
  { {0x31a4000e,0x2f1a001e,0x78ad001b,0x27e0001b}},	//   köz_, rīgo_, đava, ćin_
  { {0x26c20026,0x71650012,0x75d40012,0x867b0009}},	//   ľko_, _فالك, سيدا, ברפו
  { {0xa3ae0044,0x69c0000f,0x32020029,0xbc4a02e3}},	//   _कहा_, _isme, dzky_, ичне_
  { {0x28de0011,0xe0850012,0x7afd0132,0xab0b0012}},	//   मानि, _رجلي, thst, لتحق_
  { {0xeb07007c,0x69cd1792,0x46d10011,0xe5ca003c}},	//   ічно, _prae, _दोपह, _выкл_
  { {0xad5a0015,0xae160012,0x471b0009,0xb9e70024}},	//   _трех_, _بذات, _דואג, ціни
  { {0xf993000b,0x3f910034,0x6ef50031,0xfe370009}},	//   ורש_, trzu_, _lábl, _ורדי_
  { {0x88540009,0x3f850025,0xbd430012,0x74970009}},	//   לֹֽא_, élu_, _تنوي, _ודוד_
  { {0x8b240001,0x33fb000b,0x64580073,0x926b004c}},	//   _одје, _כהונ, žvil, _трка_
  { {0xa2d80011,0x61e4008e,0x9d550012,0xa25b10b3}},	// [3550] यार्, äill, سنات, ndôm
  { {0x629d0058,0xd3710012,0x67360073,0x7d1a0032}},	//   lgso, ّها_, alyj, nnts
  { {0xa3cd0044,0x69c0007a,0x00ba000b,0x68e10028}},	//   रिय_, _asme, _המתמ, öldu
  { {0x2d84098f,0x629d1793,0xae0c0011,0xb4e70011}},	//   ksme_, ngso, _सेवन_, _यक्_
  { {0x7e7d0333,0x41b50037,0x2d840066,0xc2c40012}},	//   _iesp, _आईओस, jsme_, بيني
  { {0x91bc0009,0x7cf20623,0xd1480012,0xa3cd0011}},	//   ימדי, _nærh, يشون_, रिम_
  { {0x8bd90024,0xaab70012,0xf7710012,0x20030034}},	//   _умвс_, _وإرش, راث_, nzji_
  { {0x1ab4002d,0x2d950210,0x6d550060,0x7d1a1032}},	//   _обся, прос, _hiza, ents
  { {0xf429004a,0xe8d90081,0x69090073,0x19950472}},	//   keää_, _cuị_, ažei, _хазя
  { {0x7afb0065,0xeb990001,0xdb26004a,0x9f43004a}},	//   _hlut, био_, öpöy, lyjä_
  { {0xca29015a,0xd91a000b,0xc1040003,0xb4450024}},	//   _עם_, _פועל, _تولي, омiч
  { {0x92b6000a,0xdb040058,0x883a007e,0x6d5d0018}},	//   أحدا, _opnå, _התעו, _ousa
  { {0x7ae900bd,0x37080003,0x7cf3003a,0x6d5d055c}},	//   _moet, _بْنُ_, _kırı, _nusa
  { {0x7cf200c5,0x7ae90005,0xccc4002d,0x18670867}},	//   _værk, _loet, _обій, зари_
  { {0xd9b80037,0x6f1b003a,0xf7460024,0x64430097}},	//   _इन्ट, onuc, зево, ýnil
  { {0x9f56000e,0x0566076c,0x6d5d1794,0xbf160012}},	//   ógép_, зван, _busa, أورب
  { {0xba9b000b,0x12eb000b,0x8afb000b,0x69c0003a}},	// [3560] _הספי, _הַיּ, _להקי, çmed
  { {0xdd8f000a,0x38af003a,0x7e7d005e,0x7cf20097}},	//   اول_, nırı_, _eesp, _kæri
  { {0xdb050061,0x7afb0052,0x18770009,0xd7ca0012}},	//   othè, _blut, _מעיר_, _اوجه_
  { {0x68e800c1,0x7e7d0358,0xe9da0015,0xdb050061}},	//   _sodd, _gesp, йке_, nthè
  { {0x7ae2004a,0x6382000e,0x6d480028,0x98aa0010}},	//   rjot, _kíná, ymda, albą_
  { {0x7e7d003e,0x7afb10e9,0x7bce001b,0x000000c4}},	//   _zesp, _elut, _trbu,
  { {0x6d5d008b,0x6ef5000f,0xd0100003,0xf76f0012}},	//   _zusa, _tábl, ضلة_, هاي_
  { {0x8f9b000b,0x24530003,0x8c1b0009,0xc7b30009}},	//   ציפי, _أنفس, _הולי, גבה_
  { {0x69c00008,0x27f10034,0x9c7c0030,0x7d1a0031}},	//   _usme, zyzn_, ejča, tnts
  { {0xb8650012,0x49060012,0x7ae91795,0xe8d90081}},	//   _قامو, _عواق, _zoet, _vuị_
  { {0xa295002d,0x0a950024,0x60c51796,0x6d480f1f}},	//   мані, маню, _rahm, rmda
  { {0x23be0013,0xb7db000b,0x24170009,0x883b0009}},	//   _můj_, _לקבי, לחין_, _פתאו
  { {0x6b650010,0xd7050012,0xdd8f0012,0x5f000011}},	//   _mėga, _تظلي, _مون_, रसन्_
  { {0x7bdc0005,0x7cf20028,0xa3c10037,0xf7730003}},	//   ärus, _færi, ्टम_, فار_
  { {0x443a0020,0x8ca10044,0xbb830012,0xdfd80048}},	//   _áp_, _खातो, _كلوي, път_
  { {0x8c1b0093,0x6d5d00c6,0x539b000b,0x70b90037}},	//   _לווי, _pusa, _היהו, _इस्ल
  { {0x60c500a2,0x88c40066,0xdce900f1,0xdddd001e}},	// [3570] _tahm, _změň, zpeč, _iesū
  { {0x81fc000b,0x9df80015,0x7ae90cb1,0x7afb1797}},	//   _להחז, чнут_, _soet, _slut
  { {0xf0920093,0xc7ab0003,0x7e7d003a,0xa3be0037}},	//   _בני_, _ادخل_, _tesp, ुटि_
  { {0xa3cd0044,0xd251000a,0xfbd00003,0xbcfb0025}},	//   रित_, ننا_, دتك_, _suéd
  { {0x6d5d0101,0x7ae90070,0x2d910002,0xdd860012}},	//   _uusa, _voet, ązek_, _جو_
  { {0xc244007c,0x25a913bc,0x4dda0009,0x68470025}},	//   хнік, mtal_, _וחשו, cédé
  { {0x7ae907fc,0xdce90030,0x25a91798,0x7cf6099e}},	//   _toet, upeč, ltal_, _cârm
  { {0xd6ce0003,0x8cdb0037,0xdb190029,0xd5b10012}},	//   لقى_, नावो, _prvý, نفع_
  { {0x917a0020,0x38af003a,0xdbd7008e,0x74b90148}},	//   _mật_, tırı_, sääv, оунс_
  { {0xb114002d,0x83890055,0xab650434,0xe1ff0034}},	//   _змуш, обов_, мвол, ybór_
  { {0xccf2000b,0x1c450055,0xebd50024,0xa4450024}},	//   דכי_, ьном, звiл_, ьнод
  { {0x395f0051,0xc878003a,0xe29f0028,0xf0890009}},	//   _kuus_, _doğu_, ggð_, _כנ_
  { {0xe60e0148,0xdca500b5,0xf5480b24,0x000000c4}},	//   _рд_, _жали, _lụy_,
  { {0x395f0051,0x7bda0031,0x46bd0011,0xa91b0097}},	//   _muus_, _átug, ्यवह, lsþj
  { {0x917a001a,0x07a30dc2,0x8b640012,0x25a91799}},	//   _bật_, карн, _كايم, etal_
  { {0x68e1000e,0xba560048,0x25a90227,0xf743003c}},	//   öldr, _отпъ, ftal_, весо
  { {0x3126004c,0xe1ff01e3,0x68f90031,0x385a0012}},	// [3580] _одиг, lcón_, áadó, _وشدد_
  { {0x448a0024,0x96dc004b,0xf53f0248,0x7e7d0097}},	//   ібен_, ăşiţ, _spår_, ðspj
  { {0x6c4a0003,0xc9530009,0x80db0009,0xe1ff0478}},	//   آلاف_, _שמת_, _וחיז, ncón_
  { {0x7cf203ee,0xf7730009,0x200c0064,0xbec30035}},	//   _nærv, _שקר_, údiu_, _šūna
  { {0x09ba0003,0x31600017,0x7bda179a,0x387e179b}},	//   تطاع_, _juiz_, _štud, _petr_
  { {0x2f1a001e,0x7bc309d2,0x11d70012,0xe4da0012}},	//   mīgi_, _osnu, بوهة_, _بوست_
  { {0x2f1a001e,0xb9060011,0xf8b30009,0x8f34004c}},	//   līgi_, _बच_, דשו_, некц
  { {0x78a90027,0x758a072b,0x69c4179c,0x8c4300b5}},	//   đevi, осов_, _osie, _ресе
  { {0xddcd000d,0x69090027,0x2f1a001e,0x5d540014}},	//   mbaţ, ožet, nīgi_, нкит
  { {0x628002d1,0x1c220037,0x6efc0061,0x6b9a00b0}},	//   _hemo, _मशाल_, _déba, tutg
  { {0xd4970009,0x25a90031,0x8c490009,0x6280179d}},	//   וכית_, ztal_, ּׂרִ, _kemo
  { {0x6b9a00ad,0x60c80031,0x0cbb0011,0x7d0b0031}},	//   rutg, _hadm, _उस्म, égsz
  { {0x54e60012,0x55730024,0xe29f0097,0x0d830148}},	//   _يستق, _агіт, rgð_, _алчн
  { {0x672d0604,0x25a9006f,0x04580012,0x2f1a0035}},	//   čaje, vtal_, _علبة_, dīgi_
  { {0xe1f90010,0x69c4001e,0xd5c8001a,0x6909179e}},	//   šų_, _esie, _hề_, džet
  { {0x6d58000f,0xceb80001,0xf7700003,0xe7840001}},	//   _hiva, мљу_, شاف_, ђусо
  { {0xe4e7002d,0x9f34002d,0x60da0070,0xc05b002d}},	// [3590] міжн, теті, _ontm, _мін_
  { {0x14740003,0x25a9179f,0xe97e0024,0x60c817a0}},	//   نامج, rtal_, _свiт_, _nadm
  { {0xe4a40048,0xd5c80081,0x316d0159,0x22950012}},	//   ърто, _lề_, _stez_, فلاس
  { {0xbcfb0061,0x25a917a1,0x1ae40024,0x6faf0011}},	//   _québ, ptal_, коєм, ूबसू
  { {0x2f1a001e,0x7d080010,0x38c40010,0xd5c80081}},	//   cīgi_, _kūrė, kūrė_, _nề_
  { {0x270c0066,0x6d880009,0xf9900012,0xe5880009}},	//   měny_, _קָרְ, شبه_, _קָרָ
  { {0x6efc00b7,0x38c40073,0xa2950024,0x6ef50a19}},	//   _séba, dūrė_, _паві, _hábi
  { {0xa3cd0037,0xd5c8001a,0x00580009,0xf7480012}},	//   रिस_, _bề_, ושות_, وجيه_
  { {0xc8ab0014,0x270c0066,0xe6190187,0x6abd0032}},	//   _мъже_, něny_, яди_, desf
  { {0x6201003a,0x61320058,0x3ead0054,0xeb99046d}},	//   ızlı, jælp, sfet_, пио_
  { {0xa3c10037,0x7aed17a2,0x28de0011,0x41c70011}},	//   ्टि_, _boat, मासि, लिकस
  { {0x4439001e,0x4e350012,0x8a06003c,0x3e350012}},	//   ās_, _كفاء, езме, _كفار
  { {0x6d470006,0xbbac0011,0x38c40073,0x6e920012}},	//   _ohja, _टङ्क, būrė_, _صلوا
  { {0x64a50014,0xa3c10037,0xdc120060,0x2f1a0035}},	//   _чака, ्टा_, aşım, vīgi_
  { {0xfc640014,0xacfa0009,0xb4fa0009,0x6d4b0073}},	//   _ръчн, _מהסכ, _מפסי, įgal
  { {0xdbd70b38,0x2f1a001e,0xd00f0012,0x33920012}},	//   _määr, tīgi_, حلف_, _إليز
  { {0xdce60039,0x443e17a3,0x98a30002,0xf98a0003}},	// [35a0] _atkā, _št_, woją_, _عندي_
  { {0x3d1d0037,0x2f1a001e,0x98a30010,0x628000b6}},	//   _पदों_, rīgi_, toją_, _semo
  { {0x628000b6,0x7e6917a4,0xa87b0009,0xeb97003c}},	//   _pemo, kcep, _מאיר, еих_
  { {0x869a0047,0xfe720003,0xd736002d,0x2f1a001e}},	//   _этот_, _حدد_, _їхнь, pīgi_
  { {0xddcd004b,0x645c0035,0xddcb0060,0x44380032}},	//   rbaţ, _tgri, _ğişi, _wyr_
  { {0xc213000b,0xc7c60014,0x6f040018,0xb8660012}},	//   נהג_, есии, lhic, راتو
  { {0x443e000f,0x8c4300be,0xa09b000b,0x629a0010}},	//   _át_, _бере, ליסט, ėtoj
  { {0x03d7000b,0xa6aa0003,0x1eaa0012,0xcf930009}},	//   _אולם_, سابق_, سابي_, אטה_
  { {0x628617a5,0xa9260024,0x865b0009,0x3e5b0009}},	//   dako, _здал, הדפי, הדפס
  { {0xd5c8008a,0x03f80001,0xc42a06e5,0xafe60451}},	//   _về_, дној_, зюме_, _позл
  { {0x7aed007d,0x20180051,0x04580012,0x20070034}},	//   _poat, _äri_, بلدة_, czni_
  { {0x78a50107,0x8c1b0009,0x76760012,0x57fb0009}},	//   _schv, לויי, _أداء, _מלבו
  { {0x961d001e,0x6d5817a6,0x690917a7,0xdc120060}},	//   paņa, _tiva, džer, rşım
  { {0xa3cd0037,0x80cb0011,0xc4c60012,0x6f0417a8}},	//   रिश_, ायें, _ستتو, ehic
  { {0x7aed007d,0x7a490039,0xa2d80037,0x6ef50018}},	//   _toat, _sūtī, याख्, _sábi
  { {0x643b000b,0xdc3b000b,0x9f60000e,0xb7db0009}},	//   _מעונ, _מעור, árás_, הקלי
  { {0x3d940063,0x395a0132,0xdd910012,0x99d70012}},	// [35b0] литр, _fips_, شوا_, _أتعا
  { {0xa3e20037,0x2f1a001e,0x57f5004c,0x621c0009}},	//   _गपशप_, mīgu_, _апот, _מוחק
  { {0x29010017,0xdc8b0009,0x28de0011,0x2f1a0035}},	//   _ilha_, לְאָ, मारि, līgu_
  { {0x9e15007c,0x6f0417a9,0xf7760009,0xea000081}},	//   _адмі, chic, _שערי_, uyết_
  { {0x2f1a0035,0xab640034,0xdb1c0031,0xdbd703bd}},	//   nīgu_, ężar, _arró, _säär
  { {0xb97c000b,0xdddb001e,0x93960060,0x628609aa}},	//   לנדי, jauš, üşür, zako
  { {0x7cf20058,0xbfa8004c,0x628617aa,0x1dc90011}},	//   _vært, етње_, yako, रिकत
  { {0x7cf20065,0xdbd700b9,0x98b6001e,0xe7390015}},	//   _færs, _väär, īgās_, ьей_
  { {0xe7f30037,0x7c990048,0xdb1c01e3,0x29010018}},	//   _अथवा_, мънс_, _erró, _olha_
  { {0x7cf20065,0x6b5e001e,0xfc3f0066,0x9d45004c}},	//   _hærr, _līgu, řím_, ђенд
  { {0xaadd0037,0x5f940014,0x2c370009,0xdbce0060}},	//   यांक, _бихт, עָ֖ם_, rıça
  { {0x64430042,0x67b800ae,0x000000c4,0x000000c4}},	//   _vzni, _سامح_,   ,
  { {0xed4e0047,0x9ae8000b,0x64430002,0xc2120009}},	//   _во_, תַתִ, _wzni, ֹ֔ר_
  { {0x7c8700a6,0xd946132d,0x86440024,0x6146047a}},	//   _чуде, теги, _сніж, тега
  { {0x6443001e,0x25ad17ab,0xe73a0545,0x628617ac}},	//   _uzni, ltel_, дев_, pako
  { {0x3ebf0052,0x8fa30001,0xcf920009,0x7cf20097}},	//   neut_, јате, יטל_, _nærr
  { {0xc2c90003,0x2f1a001e,0x9ea70048,0xe8120011}},	// [35c0] _سبيل_, cīgu_, ъвта_, _डेरा_
  { {0x09f7000b,0xc19b0009,0xbcfb0025,0x7bd50034}},	//   _סמים_, _קשיי, _stér, _brzu
  { {0x961d001e,0x7cf2014f,0x6f0417ad,0x78fb0009}},	//   kaņo, _særs, phic, _חליפ
  { {0x4e7a0003,0x291817ae,0xdb1c01a0,0x5276004c}},	//   _تحدد_, lira_, _arrò, тужу
  { {0xe894007c,0xe7310009,0xa2a50011,0xa96717af}},	//   галь, _הֵם_, _कास्, вича_
  { {0x66090039,0xc05a0024,0x291817b0,0x69c20227}},	//   dzek, мій_, nira_, rwoe
  { {0x711b000b,0xf093000b,0x73e30a41,0xf8b30009}},	//   ווספ, בנו_, _корз, ישג_
  { {0xa3c10037,0xda650003,0x3e860010,0xdb1c01a0}},	//   ्टर_, _ماكي, būtų_, _errò
  { {0x28e20044,0x6f03007d,0x1d340014,0xe357000b}},	//   पादि, _înce, лния, _ישלח_
  { {0x64430002,0x7c3c0028,0x672d0027,0x6fb60012}},	//   żnie, _kyrr, čaja, _لمطا
  { {0x69c0003a,0x4c9b0009,0xd91b0009,0x03c30048}},	//   çmen, וביו, _קובל, асям
  { {0x291817b1,0xc3340009,0x69d617b2,0x2f1a0035}},	//   eira_, רוֹ_, _brye, tīgu_
  { {0xc3330093,0x66090002,0xd2460003,0x4a7b0009}},	//   שור_, czek, إن_, ורכב
  { {0xd5bf0039,0x2f1a001e,0xd0060012,0xcdf70009}},	//   šāku_, rīgu_, مل_, _במדי_
  { {0xa438007c,0xb4be0037,0x6f0217b3,0xf55b0009}},	//   _язку_, ँजी_, _kloc, _קדומ
  { {0xd7740003,0x21670015,0x1b2b0003,0x2f1a00cd}},	//   شافع, _итог, _تأتي_, mīgs_
  { {0xf99f0054,0x291802a1,0x6d5c17b4,0xfdfb0011}},	// [35d0] què_, bira_, _bira, एनएस_
  { {0x6f0203eb,0xa3c10037,0x7c940003,0xfd390012}},	//   _lloc, ्टल_, لشما, ركاب_
  { {0x9f45000e,0x7d1d0054,0x6d5c17b5,0xaaaa0011}},	//   áló_, éssi, _dira, _कामक
  { {0x7afd17b6,0xba740012,0x3ffa0009,0x6d5c17b7}},	//   nkst, لاهت, _נפרע, _eira
  { {0x9915007c,0xf62b002d,0x7e2b002d,0xf1a70a41}},	//   лькі, _ціни_, _ціна_, трен
  { {0x7c3c0065,0x6f020397,0x80cd0011,0x88c80024}},	//   _fyrr, _aloc, _धोखे, клів_
  { {0xdfce0012,0x7afd17b8,0xa382005e,0x6f0217b9}},	//   كيو_, kkst, õõtm, _bloc
  { {0xfe71000a,0x7e6d00c6,0xb7f60037,0x7afd0070}},	//   حدث_, ncap, ीनतम_, jkst
  { {0x25ad0070,0x05760012,0xd5ae0012,0x76c40012}},	//   utel_, همية_, كفي_, شغيل
  { {0x13e90015,0x69c90051,0x2ed00037,0x98a70010}},	//   емой_, _isee, _हफ्त, foną_
  { {0x6609000e,0x25ad17ba,0xdfd10012,0x2bb90012}},	//   szek, stel_, _ديا_, رادة_
  { {0x539a0009,0x60080009,0x6f0217bb,0x9bb60009}},	//   עירו, _בִנְ, _gloc, נהרה_
  { {0xa2a5015f,0xfad60009,0x7f580024,0xc3320009}},	//   _कार्, אורך_, _рацс_, מוט_
  { {0xa2d40037,0xf5920003,0x759a000b,0x7afd0fd8}},	//   _बोर्, _الوج, _ניצח, akst
  { {0x60260014,0x9bc90012,0x291817bc,0x98a70034}},	//   удва, _أوبك_, rira_, coną_
  { {0x291817bd,0xbcfb17be,0xef190034,0x1ddf0011}},	//   sira_, _stép, niż_, नमंत
  { {0xd7f8001a,0xb5aa0003,0x7f5d17bf,0x715a004c}},	// [35e0] _ngăn_, عارك_, _disq, _прос_
  { {0xee370538,0xe5a30086,0x2d8d008e,0x29070159}},	//   уну_, сифи, isee_, jhna_
  { {0x69c90269,0x78fb0009,0x63a10031,0x6d5c17c0}},	//   _asee, _נפטו, nuln, _vira
  { {0xab770003,0x6d5c00b6,0x8f9b0009,0xdb020040}},	//   امنا_, _wira, _איטי, stlæ
  { {0x2f1a0035,0x6724071e,0x98a717c1,0x25a017c2}},	//   zīgs_, mnij, zoną_, quil_
  { {0xba170012,0x6f0217c3,0xd0d40048,0x672417c4}},	//   ديها_, _sloc, рокъ, lnij
  { {0xdfd0000a,0xf5030001,0x7afd0010,0x672d0133}},	//   زية_, _узро, ykst, čajn
  { {0xb6f40046,0x64430002,0xa2d40011,0x7fd70009}},	//   рзиј, żnic, _बोल्, רוקס_
  { {0xe9da007c,0x69c0003a,0xfaf7000b,0x443c0262}},	//   _яка_, çmel, _עצמי_, _syv_
  { {0x29070066,0x65660a60,0x63a10132,0x78ad0064}},	//   chna_, _mukh, fuln, ľový
  { {0x07b70012,0x7b160073,0x5ea60012,0xdb0217c5}},	//   _مهلة_, ašum, _ممال, ktlä
  { {0x2f1a0039,0x67240027,0x98a70002,0xbb93003c}},	//   rīgs_, jnij, roną_, щающ
  { {0x7f5d0061,0x67240027,0x9258003c,0x2f1a0035}},	//   _risq, dnij, лают_, sīgs_
  { {0xc2370009,0x98a70073,0xbd0208ca,0x672417c6}},	//   טרכו_, poną_, _šéfr, enij
  { {0x395e0070,0xd7e40024,0xd6db11e0,0x63a1016d}},	//   _mits_, біто, нта_, culn
  { {0x7d1a02bd,0xc878003a,0xf5e7002d,0x3e350012}},	//   lits, ığa_, лізм, لفأر
  { {0xb4c20037,0x2d8f000e,0x7e6d1074,0x8d740012}},	// [35f0] ्यू_, ége_, rcap, مالا
  { {0x98aa000d,0x6566002c,0xfd130012,0x30a70048}},	//   robă_, _dukh, حجر_, _срив
  { {0x515a000b,0xa3cd0037,0x1cb80003,0x67240027}},	//   _שכתו, रिए_, طالب_, bnij
  { {0x877a0009,0x7d1a005e,0x6724001b,0x33980012}},	//   _שארי, hits, cnij, اخلة_
  { {0xdd0100a2,0x7cdb001e,0x6b650010,0xaa880012}},	//   ştır, _pārē, _mėgi, انهم_
  { {0x6ce7002d,0x69c9009b,0x395e001e,0x361a0009}},	//   _сіме, _vsee, _cits_, _יורד
  { {0x80ad0044,0x7d1a0051,0xd0f80009,0xf8dc0009}},	//   _जाने, dits, רמות_, תחומ
  { {0xb8fc015f,0x2d8d004a,0xfb580003,0x6463003a}},	//   _तो_, tsee_, _مؤقت_, ştiğ
  { {0x7bd80005,0x7d1a0051,0x8d750003,0xdceb001e}},	//   _arvu, fits, جابا, _atgā
  { {0x5f950014,0xa3bc0037,0x67240604,0xe9d80012}},	//   _вижт, _अहम_, znij, _حذفت_
  { {0x3b0a09f0,0x04450094,0xb9090037,0xd8740003}},	//   вено_, ренн, या_, _طالب
  { {0x60c300a2,0x2569000e,0x216a01d4,0x63a117c7}},	//   lenm, _túl_, кими_, ruln
  { {0x61460098,0xfce506e6,0xe2970015,0x67240027}},	//   иема, _воло, шая_, vnij
  { {0x84670014,0x395e006f,0x63a1000e,0x660d17c8}},	//   _съде, öts_, puln, dzak
  { {0x67240027,0x351a000b,0x60c3001e,0x9d1a0009}},	//   tnij, _בוסנ, ienm, _בוסט
  { {0x6f090149,0xaad40011,0x60c30032,0x67240764}},	//   nhec, _ठोंक, henm, unij
  { {0x433b000b,0xa3cd0037,0x290502bd,0x6c760003}},	// [3600] _בעקב, रिक_, _olla_, لطائ
  { {0x80ad0044,0x672409ea,0x6d410054,0x79fb000b}},	//   _जाये, snij, nlla, _סליח
  { {0x309b000b,0x6cd30003,0x8ca70037,0x845a0a2c}},	//   _בשימ, تقلا, _चारो, трат_
  { {0xa3d60037,0x98a70010,0x6c550024,0x395e0132}},	//   सित_, monę_, стує, _sits_
  { {0x6f03000d,0x867b000b,0xddc40010,0x82890009}},	//   _înca, _ברכו, rbių, רְעֶ
  { {0x3913002d,0x64430002,0xb1130024,0xb4650012}},	//   омір, żnia, оміш, _هدفه
  { {0xb8ce015f,0x26cf0101,0x628b0101,0xf093000b}},	//   _का_, _bago_, bago, קנה_
  { {0xd6d700e3,0xf773000b,0xb8820066,0xa857000b}},	//   ать_, חקה_, _řídi, סיקה_
  { {0x10a6007c,0xa0a60001,0x6eb70011,0xe29b0009}},	//   _визн, _вазд, ्ज़ु, _ששמר
  { {0x6208003a,0x0466004c,0x80b00011,0x7d1a17c9}},	//   ırlı, штим, _आउटे, uits
  { {0xb8dc0011,0xe8d90081,0xf366004c,0xe2f90024}},	//   ेज_, _huệ_, јтон, гені_
  { {0x7d1a0051,0xd6cf0003,0x291c064b,0x8f8b0009}},	//   sits, _يقل_, liva_, _יְדֵ
  { {0x50670014,0xa4d4002d,0x26c402a1,0xd3570009}},	//   итва, _голі, memo_, ייטי_
  { {0x7cf6000d,0x290517ca,0x45fb0009,0xf7730012}},	//   _vârs, óla_, _בהדג, قار_
  { {0xdb0b0058,0x9b940003,0xab940012,0x88770009}},	//   _opfø, _البت, _البغ, שתלב_
  { {0x27ed0027,0x2fcd0002,0x6c5b000b,0xc43b000b}},	//   ćen_, łego_, _בדוח, _שתהי
  { {0xe7580024,0x22491448,0x629a0073,0x628b0031}},	// [3610] риті_, _uzak_, ėtot, vago
  { {0xd6570093,0xe1ff003e,0x660d009a,0x291c017b}},	//   שימת_, wców_, rzak, jiva_
  { {0x660d000e,0x9f350024,0x41d50011,0x61fd008e}},	//   szak, _гені, दिवस, lysl
  { {0x26c4048b,0x3cdd0011,0xf21c0011,0x6e320030}},	//   jemo_, _कोने_, _पेड़_, _žebř
  { {0xe1ff0002,0x66e50037,0x60c317cb,0xd1c80012}},	//   rców_, कासक_, tenm, لبوم_
  { {0x80a8002d,0x628b17cc,0x7e560009,0x7c28001b}},	//   ивів_, sago, _לסרב_, _ždre
  { {0x60c3003a,0xa1560001,0x26cf0844,0xa098000b}},	//   renm, љају_, _pago_, בדוק_
  { {0x3ea90807,0x06c9002d,0x3eb90028,0x656f00d9}},	//   ngat_, угий_, ýst_, ícho
  { {0x20c70047,0x6d410054,0x291c17cd,0x7b240031}},	//   _всег, tlla, biva_, lőug
  { {0xdb1c0108,0x6d4100a2,0x5fc20037,0xdca50001}},	//   _aprè, ulla, _वैकल, љани
  { {0x2bda0037,0x63a500b6,0xcad50009,0x47d50012}},	//   णिया, nuhn, ֖וֹת_, _ديار
  { {0x6d410054,0xc6d40012,0xb69b0025,0x5ed40012}},	//   slla, _وتنت, _blâm, _وتنز
  { {0x71260003,0xd9f90011,0xab630034,0xdb0217ce}},	//   مرسل, ्नित_, ężyc, nulé
  { {0xcd76000b,0xed44002d,0x6c850003,0x673d17cf}},	//   _העסק_, _дніп, _الثم, _aksj
  { {0xab990003,0xdee60339,0xd0070313,0xf3c80012}},	//   _إختر_, бови, бере_, _نبيه_
  { {0x98a7003e,0x52aa0001,0x96660015,0xdb050052}},	//   ronę_, _свим_, скае, nthä
  { {0xc27b000b,0x10a6002d,0x98a600b3,0x09ba0012}},	// [3620] _גרפי, _липн, _липе, _إطبع_
  { {0x88ca0800,0x7ae40028,0x26c4001b,0xdb05005e}},	//   _слов_, _hnit, zemo_, hthä
  { {0x63a500b6,0xa3ca0011,0x1fb6004c,0xa7b6004c}},	//   guhn, रौप_, _успр, _успј
  { {0xfaa6026d,0x82a60024,0xddc90064,0xb283003c}},	//   садо, садж, dbež, пышк
  { {0xda65000a,0x91b70003,0xd9460751,0xdce2001b}},	//   زاني, مطور_, беди, _suoč
  { {0x63a500b6,0xa2d80011,0x7f4417d0,0xdf780024}},	//   buhn, _नोर्, lliq, абкі_
  { {0x291c17d1,0x33780009,0xc8db0009,0x03a30024}},	//   riva_, _כְּב, טקסט, _ниро
  { {0xc6f80339,0x3da60447,0xc3060012,0xe8d90081}},	//   рних_, броб, _ابسو, _tuệ_
  { {0x26c417d2,0x291c17d3,0xfe6f0012,0x9df70048}},	//   remo_, piva_, ردي_, йнът_
  { {0xd3b80024,0x15140024,0xbf050011,0x26c4001b}},	//   алої_, ідня, _रत्न_, semo_
  { {0x1877000b,0x66e50011,0x853b0009,0x3d3b0009}},	//   _העבר_, काशक_, רגיי, רגיס
  { {0xa3cd0037,0x61fd08b5,0x8fe50012,0x7d1e0060}},	//   रिज_, tysl, _بأكم, hips
  { {0xaaaa0037,0x5ebb0009,0xcb370009,0x4aaa0011}},	//   _कारक, _תזדק, מאטי_, _कारव
  { {0xf1270055,0x6b73000d,0x7ae415ff,0x5e570009}},	//   сьмо, _săge, _enit, _הידע_
  { {0x24b7007e,0x28de0037,0xd7e40024,0x251b00af}},	//   _להגן_, माजि, піто, _תווא
  { {0x69c000bd,0x3f910002,0x501b000b,0x07090012}},	//   _opme, rszu_, אולו, جيري_
  { {0xd0d50098,0x644f0002,0xfc3f0030,0x8cf50024}},	// [3630] _допъ, ęcie, řít_, озац
  { {0x4c78000b,0x63a5016d,0x8c670488,0x04670a01}},	//   שָּׁ, tuhn, стад, стам
  { {0x69c00039,0xbc4b0047,0xd0f80037,0x6f03000d}},	//   _apme, учае_, ुसरण_, _înco
  { {0xa294007c,0x69db02d1,0xe8120037,0x672d0027}},	//   заці, _prue, _डेटा_, čajk
  { {0x7bdc0032,0xe1ff01a0,0x208909e8,0xa889056f}},	//   _erru, nyó_, айли_, айла_
  { {0xf7710003,0x60c70030,0x29030031,0xaf9905f7}},	//   واب_, nejm, nkja_, атих_
  { {0xd0110003,0x37860014,0x29030028,0xd6e20034}},	//   بلغ_, общо_, ikja_, kołę_
  { {0xdcfb001e,0x6d4517d4,0x627e0034,0x4ed50024}},	//   stuļ, llha, ołoż, іюйт
  { {0xdd8e0003,0x29030028,0x51740012,0x41740012}},	//   نوي_, kkja_, _فالأ, _فالس
  { {0x26d90029,0x14250015,0xe3b10012,0x9d520012}},	//   ôsob_, ждом, ورج_, ونيت
  { {0x28ad0037,0x02c6085b,0x60c70002,0xddc20002}},	//   ञ्छि, ойно, dejm, _czoł
  { {0x8bd60009,0x03d60009,0x6d450032,0xcae40011}},	//   קורו_, קורם_, hlha, गाइड_
  { {0x7ae40066,0x320401e9,0xa96a0048,0x216a0048}},	//   _vnit, ámy_, рига_, риги_
  { {0x6efc0108,0xddc9000d,0x55ba000b,0x320c0002}},	//   _débu, aceţ, _כמנו, ądy_
  { {0x46f6002d,0x6b650010,0x8b460012,0x99190024}},	//   очат, _mėgs, _وضعن, сіях_
  { {0x6d45000f,0x67290029,0xa3d60011,0x6f630012}},	//   elha, nnej, सिर_, ِهِم
  { {0x60c70034,0xca970009,0x6e930012,0xae0c0011}},	// [3640] bejm, _ודפי_, بلقا, ाईयन_
  { {0x7a1c001e,0xd7760012,0x61fb0032,0x7f4417d5}},	//   rātī, _واجع, äule, sliq
  { {0x65630149,0x5bc60003,0x7f4401f2,0x6729009b}},	//   _minh, تقال, pliq, knej
  { {0x65630149,0xe9da069b,0x656b002a,0x8ae30024}},	//   _linh, ике_, _ough, дішл
  { {0x5db60003,0xb2d30012,0x224d0034,0xcb130009}},	//   _بإجر, بينغ, _czek_, ולא_
  { {0x6f040002,0xcf9a0001,0xf80601ec,0x1d0a0109}},	//   lkic, аји_, жчин, _теги_
  { {0x28b20044,0x224d000f,0x7f3c0009,0xeb97169b}},	//   _जानि, _ezek_, ְע֖ו, _мир_
  { {0xa857000b,0x644e0470,0x9c17000b,0x63b40002}},	//   חיצה_, _izbi, _וחלק_, ągnę
  { {0x628f0029,0xaf330003,0xb5c70012,0x80e60012}},	//   vaco, بروت, قويم_, _وأطل
  { {0xa3d60037,0x32d7001a,0xa9060003,0x2b4617d6}},	//   सिल_, _ủy_, _ببرن, lloc_
  { {0x656317d7,0x6729025e,0x3cf70012,0xb8ce0011}},	//   _dinh, bnej, تعيد_, कल_
  { {0x656310c7,0x539b000b,0x67290064,0x61e20159}},	//   _einh, סיכו, cnej, _šola
  { {0xddc9000d,0x2a640048,0x628f17d8,0x6f040034}},	//   rceţ, дърг, raco, dkic
  { {0x644e0027,0x6f040060,0x636a004c,0x62820e00}},	//   _ozbi, ekic, _криг_, hboo
  { {0x29030065,0x60c7012e,0xf3ef0003,0x368b0578}},	//   rkja_, rejm, _لأي_, исан_
  { {0x442d077d,0xe7f20044,0x3eaf0052,0x8f9b000b}},	//   _će_, _अपना_, ügt_, יילי
  { {0xbf380024,0x6c6b004c,0x645c0097,0x29280097}},	// [3650] ізує_, ашег_, ýrif, ðvað_
  { {0x61e00028,0x67290a45,0x628d0051,0x6f0d0e2f}},	//   æmle, znej, _heao, shac
  { {0x63a8009b,0xe53b0009,0xdbd6005e,0x7b160073}},	//   nudn, סתבר, jääg, ršuv
  { {0x6f040002,0x2ae40011,0xa3db0011,0x2d4b00b0}},	//   ckic, गाएँ_, ठित_, jøen_
  { {0xda78002d,0x49cb0337,0x21690a32,0xdb020474}},	//   цях_, руем_, щили_, rtlø
  { {0xb17c0093,0x98aa0066,0x9e5a0009,0x8dfa0009}},	//   סטור, době_, _לכרט, _ההשת
  { {0x07a50695,0x6729179a,0xa3b40024,0xa09c0009}},	//   чайн, tnej, _обрі, ביוט
  { {0x80bb0011,0x6b8d0034,0xb6a30081,0x8aa40223}},	//   श्ते, _łago, _giầ, _оруд
  { {0xb3640014,0x26b6000b,0x9e090012,0x3b640048}},	//   _църк, הִים_, صيدك_, _църв
  { {0x672902e7,0x7d090001,0x53f90012,0xe616003c}},	//   snej, сног_, مرجح_, яды_
  { {0x65630017,0x6f1d0070,0xeb99004c,0x2f19003c}},	//   _vinh, _omsc, љим_, _ложь_
  { {0x67ba000b,0xd7ba000b,0x8c1a0009,0x32ba0012}},	//   _למעק, _לצער, מותי, حددة_
  { {0x6443003e,0x65630149,0x25a900b6,0x9f5e0066}},	//   _wyni, _tinh, jual_, átí_
  { {0x63a80029,0x7b240027,0xcdf60009,0x4dda0009}},	//   budn, eđut, _ממני_, _לחנו
  { {0x6f040002,0x7d06001e,0x9f5e0066,0xdee609e3}},	//   tkic, īkst, ští_, пови
  { {0x9bfa000b,0xa3df0037,0x539a0009,0xa3da0011}},	//   _להצט, तिन_, _היקו, ़िस_
  { {0xdcf00030,0x25a917d9,0xf2d300af,0x3ead0522}},	// [3660] řečt, gual_, _טעה_, iget_
  { {0x6f0417da,0x45360024,0xada90012,0x644e005e}},	//   skic, їхат, تدفق_, übig
  { {0xc953000b,0xe0fb000b,0x7f46011d,0x78fb01b0}},	//   _רמת_, _הליל, _неож, _הפיו
  { {0x05bd0011,0xd4910081,0x3f9a0097,0xe29717db}},	//   ्बाब, hà_, ápum_, зац_
  { {0xd9460751,0x7cf30031,0x237f001b,0x023a0012}},	//   педи, _sűrű, _čuje_, حثات_
  { {0x7bc30097,0xed570223,0x3ead0040,0x673b17dc}},	//   _opnu, _ноя_, eget_, čuje
  { {0xdfda0014,0x2ca701e3,0xab640032,0xf7720012}},	//   съл_, ónde_, grüß, راغ_
  { {0x69c417dd,0x9ed70048,0x7646008e,0x8b9b0009}},	//   _opie, змът_, _kyky, _לבלת
  { {0x5d540014,0x96340055,0xceb30009,0x6720001b}},	//   мкит, ьниц, גיח_, rimj
  { {0xcb98007c,0xa617000b,0x6b510248,0x98aa0030}},	//   ової_, פקיד_, råge, robě_
  { {0xc059002d,0x987b000b,0x6efc0061,0xccf30009}},	//   _дії_, _האבט, _débr, תכת_
  { {0x63a80002,0xddcd004b,0xcb0b17de,0x977300ae}},	//   rudn, ncaţ, сход_, _أُنش
  { {0x76460006,0xc56a0003,0x644f0002,0xbef70009}},	//   _nyky, _احصل_, ęcia, _מצאו_
  { {0xa3df0037,0xd6250012,0x865b0009,0xdb050ca4}},	//   तिम_, _تعمي, _הדדי, ruhé
  { {0x1cbb0093,0x94bb000b,0x4cbb007e,0x8c410052}},	//   _המוע, _המות, _המוג, ößte
  { {0x877b000b,0x6d4817df,0x64430034,0xada50064}},	//   מאלי, llda, żnik, spúš
  { {0xa634002d,0x7b160010,0x99490012,0xbab80012}},	// [3670] енті, ršut, _ولعل_, _رديء_
  { {0x2f25001e,0xf9920009,0xdb0e0031,0x4d9817e0}},	//   lēgt_, _שרי_, óköt, якую_
  { {0xe3b800a2,0x3ead006f,0x9f550024,0x00ba0009}},	//   ntı_, yget_, _овоч, _ומתמ
  { {0x6f1d0052,0xa3d40011,0x3e7c0030,0x27fe0064}},	//   _umsc, _हनन_, tátů_, ätne_
  { {0xeab00003,0x7abc0009,0xa3d30011,0x25a917e1}},	//   اعم_, מצאו, _सैन_, qual_
  { {0x69dd0051,0x3e7c0066,0xe3b8003a,0xa7790001}},	//   ivse, rátů_, ktı_, ољих_
  { {0xdfce0003,0x320201bd,0x389c0009,0xb8d50011}},	//   ليو_, zyky_, זיונ, _झा_
  { {0xa3da0037,0x0ea90015,0xfbd20009,0xbae50012}},	//   ़िर_, цкий_, _בתל_, _تكري
  { {0x51870014,0xfde9002d,0x3ead17e2,0xeaf80012}},	//   _хуба, ідок_, rget_, _عرفت_
  { {0x656f02d1,0x69dd009b,0x59c40012,0x7afb17e3}},	//   _much, dvse, _سيمك, _hout
  { {0x69c417e4,0x89340012,0xbcfb01e3,0xcaca0488}},	//   _spie, _أعقا, _hués, огне_
  { {0x6f03007d,0x7afb17e5,0x7f490012,0x23780031}},	//   _înch, _jout, _بلصق_, írja_
  { {0xd706002d,0xbcf50003,0x7afb03b5,0x26d80035}},	//   _інше_, _يستغ, _mout, ērot_
  { {0xdce20026,0xa5b20037,0xa3c20037,0x66060033}},	//   _zvoľ, _आमतौ, ्बम_, økke
  { {0xdb1c0029,0x04590012,0x29070097,0x7ae90244}},	//   _sprí, _بلغة_, ikna_, _onet
  { {0x6207000e,0x69c0003a,0x5b360003,0x656f0206}},	//   örlé, çmes, _تعتر, _buch
  { {0x9aeb0093,0x2bd50037,0xceb2000b,0x65670070}},	// [3680] _וַיִ, धिका, כין_, _bijh
  { {0xef1f0051,0xe5a3070f,0xc4c60012,0x80bf0011}},	//   _emü_, тифи, بترو, ल्मे
  { {0x7afb0108,0x3eb3004a,0x2d8017e6,0xd38a0024}},	//   _bout, äntö_, spie_, ійде_
  { {0xfe720003,0x4e0d0011,0xaac10011,0x0aea0055}},	//   _جدد_, िनाई_, ष्पक, юдей_
  { {0xddcd007d,0xb17b0058,0x6d480028,0xed5a0001}},	//   rcaţ, rvåg, ylda, _мом_
  { {0x6d460030,0x7ae917e7,0xe3b80060,0xa98900af}},	//   ůkaz, _enet, ytı_, פָנִ
  { {0x7afb00bd,0xa0670001,0xd0100003,0x60c1005e}},	//   _fout, маља_, طلة_, õlmi
  { {0xd757000a,0x6d430051,0x079b0009,0x8f9b0009}},	//   وجيا_, _akna, קספל, קיפי
  { {0x88c60003,0x660400b6,0x6da30001,0x68fa17e8}},	//   _يتطل, nyik, виња, _totd
  { {0xe3b8003a,0x2907006f,0x79fb000b,0xa50b0009}},	//   ttı_, ckna_, _ולמח, ַּיִ
  { {0x672d0002,0x7afb17e9,0x8ca60011,0x291700ae}},	//   ynaj, _yout, _चयनो, _تقلد_
  { {0xa3df0044,0x3863000f,0xe3b800a2,0xdce20064}},	//   तित_, _újra_, rtı_, _uvoľ
  { {0x672d17ea,0x6abd0028,0x7db30012,0xda670012}},	//   čajt, rfsf, _لمنص, بادي
  { {0x656f0002,0xab940001,0x7dd8000e,0x61e4004a}},	//   _ruch, _закљ, zúsá, äily
  { {0x656f032b,0xb8820029,0xdc8b0009,0xd0d40048}},	//   _such, _číta, _וְחָ, ъоръ
  { {0xba6b0003,0xe7300003,0x63a501e9,0x656f17eb}},	//   _بحثك_, لصق_, vrhn, _puch
  { {0xa3d60037,0x05740012,0x79820034,0x672d17ec}},	// [3690] सिक_, نالد, jpow, rnaj
  { {0x88c40002,0x79820002,0x7afb17ed,0x63a5015b}},	//   ęści, dpow, _sout, trhn
  { {0x656f0052,0x661601e9,0x7afb17ee,0x56950373}},	//   _wuch, azyk, _pout, _пант
  { {0xd6d90002,0x80bb0037,0xe9df0029,0xd2510012}},	//   koła_, श्रे, ovú_, هنا_
  { {0x90c50063,0xa2940024,0x4e7a0009,0x66160034}},	//   ебле, тачі, _מארצ, czyk
  { {0xe9d8007c,0xe8f8002d,0x6b5601e3,0xc984046e}},	//   ькі_, млі_, máge, туци
  { {0x26d9002c,0x62860002,0x7afb17ef,0x9b740012}},	//   _kaso_, ybko, _tout, _لاقص
  { {0xbcfb0061,0x7ae917f0,0xd1bb0012,0xdb0217f1}},	//   _guér, _unet, _واذا_, kulá
  { {0x2d990272,0xa2d80037,0x2d8b0061,0xb9c70012}},	//   ése_, _नोट्, èce_, _تتأه
  { {0xe0d30003,0xf8070015,0x10d80003,0xdb0217f2}},	//   _جزر_, _очен, _يبلغ_, dulá
  { {0x8b26035b,0x7bda000e,0x8cc10037,0x644f0002}},	//   едне, _átut, र्यो, ęcio
  { {0x7b160039,0x0bb6000b,0x28b20011,0xd9f30011}},	//   gšup, עִיר_, _जाहि, _आपात_
  { {0xfe790066,0xdca50829,0x0f180012,0x13030024}},	//   mců_, _зали, _تغلب_, узям
  { {0x80bb0037,0x91ba000b,0x7bd50002,0x26180011}},	//   श्ले, המשי, _oszu, _बेटी_
  { {0x3b0a0001,0x79820002,0x6fb60012,0x9756004c}},	//   _неко_, zpow, عمرا, етаљ
  { {0xfe790066,0x8c1a000b,0x6d41029a,0xdb1c0042}},	//   nců_, _מוצי, lola, _oprá
  { {0xc2e90003,0x99d60003,0xd266002d,0x7bc70692}},	// [36a0] _زعيم_, _أتبا, _який, _apju
  { {0x9a3b000b,0x66160002,0xaac10037,0x02c10037}},	//   _מתפק, rzyk, ष्ठक, ष्ठभ
  { {0xe3b20003,0x66160120,0xda7a0048,0x04b50048}},	//   طرا_, szyk, пял_, ъстя
  { {0xe292000a,0x6b56000e,0x61e400eb,0xe73a06bd}},	//   اذا_, lágb, _kril, _хем_
  { {0x2fe80002,0x6d4117f3,0xf5b60024,0xfe790030}},	//   ługę_, kola, _ясню, dců_
  { {0x6b510163,0x999b0009,0x63ba0248,0x6d41016d}},	//   råga, לבנט, yttn, jola
  { {0x7cf6000d,0xe3a70012,0xf8b30009,0xb7660357}},	//   _târz, _حر_, אשו_, нтий
  { {0xb3bb000b,0x97c30003,0x61e401e3,0xba1a0012}},	//   _ממלכ, اقيو, _oril, _فيزا_
  { {0xe2a60028,0x34bd0011,0xd3570009,0x31ca0011}},	//   æðum_, ौजूद, _טילי_, िबोध
  { {0xe9d7002d,0xf19b000b,0x6b5f001e,0x6d4117f4}},	//   _яку_, _משמש, _lūgt, gola
  { {0xdb1c0013,0x66e6035b,0x673c000e,0xf8b30009}},	//   _zprá, _пожа, _írjo, _תשע_
  { {0xdb02000e,0xe6c50012,0xe6c60012,0x61e417f5}},	//   tulá, _لتهي, _ستصي, _bril
  { {0x69060065,0xc333000b,0x4efb0009,0x8cc10011}},	//   _aðei, רור_, _מהאו, र्डो
  { {0x98b8001e,0xfd380003,0xa3c20037,0xf6290003}},	//   torā_, _تكتب_, ्बा_, _تسمى_
  { {0x26d90164,0xe9ff001a,0x61e4015e,0x3cf70003}},	//   _paso_, _khảo_, _eril, _سعود_
  { {0xd4090012,0xf7700012,0x0bb70009,0xd6d80bd8}},	//   _تتهم_, صاف_, _נלחם_, нту_
  { {0x0708000a,0x6ca717f6,0xe5730003,0x271e0037}},	// [36b0] ريكي_, ереж, اطر_, _बगैर_
  { {0xce37000b,0xdb0203ee,0x63a817f7,0xfe790030}},	//   תאמת_, gulæ, ordn, zců_
  { {0xdb1c00f1,0xab6b0012,0x26d9008e,0x3ec40030}},	//   _sprá, سحاق_, _taso_, ístí_
  { {0x43840003,0xdc3b0009,0x8f9a0009,0xa5a10011}},	//   النق, העבר, _קירי, _खिलौ
  { {0xe4a70046,0xfe790066,0x25ad0025,0xbebd0035}},	//   _прво, vců_, xuel_, inūt
  { {0xbb850003,0x4fa50014,0xf9900012,0x61dc0009}},	//   _للسي, викв, صبه_, פקוד
  { {0xe5340015,0xdc880009,0x6d4117f8,0x3c450012}},	//   _серь, _רְשָ, vola, _شَرِ
  { {0x6b56000e,0x25ad17f9,0x6d5804e7,0xf5e90048}},	//   zágb, tuel_, _ahva, дмил_
  { {0x20090039,0x6f03000d,0x6b6c003a,0x6b9a0052}},	//   ņai_, _încu, _işga, estg
  { {0x270e0037,0xdbcc0028,0x25a9002c,0xd0d9002d}},	//   _सत्र_, _kóða, iral_, _ідеї_
  { {0xa3da0037,0xac390024,0xfe790030,0x25a90064}},	//   ़िए_, ьчих_, pců_, hral_
  { {0x6d41000f,0xf3f2000b,0x61e417fa,0x25a9016d}},	//   sola, ׁ֣ר_, _pril, kral_
  { {0xdb08000e,0x471a000b,0x25ad17fb,0xba9a0009}},	//   élés, _קונג, quel_, וסרי
  { {0xb1430021,0x7e7d17fc,0x20d50024,0x28c40011}},	//   инял, _afsp, лісс, ल्पि
  { {0xf8b20009,0xa9670373,0x60230578,0x200c1544}},	//   ישם_, тира_, адра, ádi_
  { {0x84640014,0x6b56000e,0x61e417fd,0x3d090011}},	//   _съче, ságb, _tril, िसके_
  { {0x61e4007d,0xc692000b,0xb13a0003,0xad9d0034}},	// [36c0] _uril, יאן_, _يأخذ_, zyźn
  { {0xd257000b,0x7aed0604,0xdd8f0012,0xd6d90034}},	//   _בשפה_, _znat, توك_, koło_
  { {0xeb9717fe,0xb8e80037,0x6b51006f,0xd379002d}},	//   вих_, ोज_, rågn, ечі_
  { {0x2aeb0037,0x60da003a,0x2ba90011,0x93fa0009}},	//   टाएँ_, _satm, _किना, ולעי
  { {0x6a160003,0x99d30003,0xdb0217ff,0xe2970538}},	//   خبار, لتوا, pulæ, тач_
  { {0x8cc10011,0x64a6003c,0xa7b8003c,0x1154003c}},	//   र्दो, _шага, елку_, ыклю
  { {0xdbcc0028,0xd00f0003,0xc010001a,0x443e004b}},	//   _góða, يله_, _đuổi_, _ât_
  { {0x6d580027,0xe737004c,0xdb1c07c2,0x63a8001b}},	//   _shva, кеј_, _spræ, vrdn
  { {0x1ef70012,0x60da0f1f,0xaa460bda,0x6603004c}},	//   ضعية_, _tatm, _реал, ипћа
  { {0x645a0028,0x03f80001,0x44f401de,0xb4ac0011}},	//   _útis, еној_, упос, गले_
  { {0xe9ff001a,0xdb050028,0x61e21800,0x3fa50012}},	//   _thảo_, luhá, lvol, _مصنف
  { {0x501b000b,0xdb9b000b,0xbb930015,0x644a0004}},	//   _קואו, וסטר, шающ, _vyfi
  { {0x79a70014,0x61e21801,0x9258003c,0x88c40034}},	//   ърне, nvol, кают_, ęśni
  { {0x34940dd8,0x2bba0012,0x6d58001b,0xa8a41003}},	//   _сакр, _قاعة_, _uhva, ирск
  { {0xd9180015,0xe7e50011,0xed570009,0x39430035}},	//   тья_, किया_, _שבור_, rojs_
  { {0x6d470028,0xdb020052,0x93f70009,0x1bf70009}},	//   _skja, gulä, _יצוא_, _יצור_
  { {0x7e55002d,0x2d8f0061,0x20070929,0x64460060}},	// [36d0] уває, ège_, zyni_, şkid
  { {0x58d50047,0x15f50037,0x25a9025a,0x61e201bd}},	//   _соот, ेहतर_, rral_, dvol
  { {0xb8820066,0xa4d40024,0x69c91802,0x2f110097}},	//   číte, рохі, _spee, _lága_
  { {0x6b510163,0xee840015,0x394e0227,0xef1f0034}},	//   rågo, _выро, elfs_, ężko_
  { {0x29010051,0xdd860003,0x28c00037,0xe8ee0472}},	//   _koha_, _دو_, श्वि, бл_
  { {0x95820002,0xe1f00012,0xf1bf0018,0xe0d80024}},	//   żące, تسم_, itá_, кві_
  { {0xf771000a,0x64550039,0xb4c10037,0xf3670345}},	//   حات_, _uzzi, ्जी_, _атан
  { {0x6f0d0fae,0xa3c20037,0xcb690012,0x75280035}},	//   nkac, ्बर_, _أمره_, eidz
  { {0xdb050028,0x645c0028,0x66050015,0xde050015}},	//   sthó, ýrin, уппа, уппи
  { {0xe6160055,0xdb020032,0x3f9e0073,0xf8b20011}},	//   удь_, zulä, štui_, _जाइय
  { {0xc209000b,0x853c000b,0xd6d70003,0x236d0034}},	//   _צה_, וגזי, _لتشغ, _kiej_
  { {0x2a690035,0x6d4503fe,0x62991803,0x6f0d1804}},	//   žabu_, hoha, nawo, jkac
  { {0x6d450005,0x6f0d0002,0xed4e06e0,0x672909bb}},	//   koha, dkac, _го_, miej
  { {0x1c030037,0x67290010,0x6be50012,0xdce30035}},	//   लहाल_, liej, _مكتم, _finā
  { {0xab2a0047,0x232a002d,0x61e21805,0x6609000e}},	//   _пока_, _поки_, zvol, lyek
  { {0x6729003e,0x236d0002,0x25bf004b,0xb0c40011}},	//   niej, _niej_, otul_, _लॉरग
  { {0x25bf01b3,0xe7370047,0xdce30039,0xee3a02ac}},	// [36e0] ntul_, ует_, _zinā, хна_
  { {0x98a70010,0xdd8f0003,0x09f70009,0x28070031}},	//   monė_, سوم_, _עמים_, ívná_
  { {0xdb020c60,0x67290034,0x25bf005e,0x6296020d}},	//   pulä, kiej, htul_, _keyo
  { {0xa3e40044,0x41a80011,0x24870060,0x28c00011}},	//   नित_, _कटास, ınma_, श्रि
  { {0xe81c0037,0xf126002d,0xcb070012,0x7e9b0009}},	//   _भेजा_, лько, طيون_, _אסכו
  { {0xbebd007a,0x61e209a0,0xdfd00003,0x6f03000d}},	//   siūl, rvol, قيت_, _încr
  { {0xf8b20037,0xc04f002d,0x8bd8000b,0x6d5c003a}},	//   _जाईय, сі_, _בַּח, _ihra
  { {0x75280002,0x758a022a,0x61e20227,0x75d40012}},	//   widz, нсов_, pvol, ليبا
  { {0x1634010c,0x8cc10011,0xc8b60012,0x8703003c}},	//   репя, र्वो, _مصاب, сяще
  { {0x88bc06bc,0x98c10035,0x020306bd,0x6f0d06bf}},	//   _změn, ēsīs_, _узун, zkac
  { {0x6f0d0002,0x88c40002,0x62960a5f,0x25bf004b}},	//   ykac, ęśli, _beyo, atul_
  { {0x66760003,0x2901000e,0x7de60003,0x6b650010}},	//   _إدار, _soha_, _مستم, _bėgy
  { {0x25bf000d,0xcf570009,0xa2270012,0xff570009}},	//   ctul_, _עבדת_, ارجه, _עבדך_
  { {0x8637000b,0x6f0d0002,0x2db70009,0xf1bf0018}},	//   _גאדג_, wkac, _עלון_, rtá_
  { {0x2d54004a,0xe47b000b,0x74970009,0xc9530009}},	//   täen_, _ארוכ, _גדוד_, ממש_
  { {0x2ba90037,0xfe730003,0xf3ef0003,0x64580949}},	//   _किता, صدر_, _رأى_, _izvi
  { {0x6d450312,0x6f0d0bca,0x95d90048,0xcec00030}},	// [36f0] toha, rkac, ъдат_, ířat_
  { {0xb0b20044,0x7afd013a,0x6f0d0504,0xf6570009}},	//   _जाएग, ljst, skac, רסמי_
  { {0xa2bc0044,0xa87a0093,0x8c190003,0x62990002}},	//   ष्क्, _באתר, خيار_, tawo
  { {0xdb021806,0x539b0009,0x8d770012,0x98a9001b}},	//   orlá, תיאו, _ماسا, đač_
  { {0x60de00a2,0x25bf007d,0xfe9a0009,0xe9a80012}},	//   _yapm, xtul_, _שישמ, هدون_
  { {0x28f80015,0x8fe50012,0x67290034,0xe97c0009}},	//   лечь_, لأعم, wiej, תנגש
  { {0xfe71000a,0xd0980003,0xdb1c1204,0x9f5c004a}},	//   يدة_, ائها_, _språ, kyvä_
  { {0x88bc0066,0x3eb91807,0xf99300ae,0x7fe800ae}},	//   _uměn, üst_, _هبط_, اروف_
  { {0x67290010,0x9e620048,0x98a70034,0x453511e0}},	//   riej, овъд, enną_, ихот
  { {0x25bf007d,0x7d090001,0x6729044c,0xc5f20009}},	//   rtul_, тног_, siej, קדי_
  { {0x661b0656,0x47d5000a,0x25bf007d,0xfc310012}},	//   szuk, _خيار, stul_, تحة_
  { {0x25bf007d,0x39471808,0xb17b0248,0x62660229}},	//   ptul_, lons_, rvån, ивна
  { {0x4a430014,0x82d6000b,0xcad60009,0xfad60009}},	//   жняв, בורג_, בורת_, בורך_
  { {0x39471809,0xfc310012,0x25ad0064,0x6606079b}},	//   nons_, _وحث_, mrel_, äkke
  { {0xa6960046,0xdfd20003,0x5f060de1,0xbbe80012}},	//   ирај, غير_, азва, _مريم_
  { {0x6d5c012e,0x4c3a000b,0xf1c50037,0xc43a0009}},	//   _shra, _שתקב, लझान, _שתקי
  { {0xa1560014,0x78bb0027,0x6b56000e,0x1d260538}},	// [3700] _външ, đuvr, lágo, амам
  { {0xdca60046,0x2fdf0002,0xb19b000b,0x7bc10051}},	//   ражи, ługa_, _שייכ, otlu
  { {0x60c3000e,0x161d0011,0x7d0316be,0x61e60248}},	//   _önma, _बेघर_, _mons, lvkl
  { {0x083b000b,0x103b000b,0x61e90028,0xa79b0009}},	//   _יעיל, _יגיע, _brel, _בשטח
  { {0x644e003e,0x7bc10051,0xc27b000b,0x6b5d000e}},	//   _wybi, htlu, דרני, ségg
  { {0xb21b0028,0x25a0003a,0x3947180a,0xda650012}},	//   mbæt, msil_, gons_, حامي
  { {0xdfd0000a,0xf0930093,0xb9230003,0x98a3001e}},	//   سية_, חנו_, تفوي, nijā_
  { {0x7bdb000b,0xa3e40037,0x3ec30015,0x9b070048}},	//   _בקלו, निस_, осьб, _кнсб_
  { {0xc6f70015,0x9df70014,0xe5060012,0xe0da019c}},	//   рных_, инът_, لبدي, _ива_
  { {0xdceb01b3,0xbd430003,0xc1bb000b,0x31bb0009}},	//   _rugă, ينيي, _בממש, _בזמנ
  { {0x6c34000a,0x3c77000b,0x6fb30012,0x44770009}},	//   صفحا, יתים_, _ومكا, יעיל_
  { {0x268a0003,0x320b0034,0x864600b5,0x98a30035}},	//   _شخصي_, tycy_, _кнеж, dijā_
  { {0x69c2091a,0x7ae2001e,0x4efb0009,0x1efb0009}},	//   ntoe, idot, _שהדו, _שלדע
  { {0x7ae2004a,0x29c2001a,0x3e330012,0x6c840012}},	//   hdot, _mưa_, _بفهر, _الغم
  { {0x69c20006,0x753d000f,0x34fb000b,0x6d48180b}},	//   htoe, észe, _בהגד, moda
  { {0x6d48180c,0x07090012,0x33fb0009,0x2f380012}},	//   loda, ديري_, _יהונ, لثقة_
  { {0xdcfd001e,0x39470061,0x629d180d,0xa4870012}},	// [3710] _atsā, yons_, maso, لجان
  { {0x629d066e,0x30a7002d,0xdce70035,0x7ae2180e}},	//   laso, _трив, _bijā, edot
  { {0x39470061,0x9cd7000b,0x98a3001e,0x25a000b6}},	//   vons_, שובה_, cijā_, asil_
  { {0x629d002c,0x2ba90037,0xe3b00012,0xc7fa0009}},	//   naso, _किसा, برك_, _עִיר
  { {0xa2bc0044,0x69c20070,0x6b56000e,0xc2c40003}},	//   ष्ट्, gtoe, zágo, تيني
  { {0xa924002d,0xc1040003,0x88bc0066,0x629d000e}},	//   оділ, يوني, _uměl, haso
  { {0x6d48180f,0x39471810,0x49180009,0xe3d40012}},	//   doda, rons_, שקול_, _وتفع
  { {0xf8380093,0x2838000b,0x9838000b,0xfc460029}},	//   ינות_, ינוך_, ירוף_, číta_
  { {0x660d00c6,0xcf240003,0xa3df0037,0x52150001}},	//   nyak, تروي, तिक_, _удат
  { {0xeb100037,0x629d002a,0x672d0051,0x7bc11811}},	//   ास्त_, easo, hiaj, ttlu
  { {0x351a000b,0x04450a2c,0x3b0a004c,0x8c4505d8}},	//   רותנ, сенн, гено_, сене
  { {0xa3e80037,0x2b160014,0x29050a04,0x68e11812}},	//   बित_, сьор, _hola_, _hald
  { {0x7bc10005,0xfce500be,0x5d850003,0x9e76000b}},	//   stlu, _голо, _التل, _הגנה_
  { {0x7d1a0518,0x2f18000e,0x6b5d000e,0xa3e40037}},	//   chts, _vége_, vége, निश_
  { {0x09d40044,0x8cca0037,0xb4b30011,0x660d016d}},	//   _धन्य, स्फो, टली_, eyak
  { {0x98a3001e,0x6b5d0061,0x93250012,0x69cd005e}},	//   rijā_, tége, _ورين, äleõ
  { {0x660d00b6,0x8d760003,0xdce9001e,0x98a30035}},	// [3720] gyak, صاءا, kseļ, sijā_
  { {0x2ed40037,0xb21b0028,0x67360010,0xaa7b00d9}},	//   _दस्त, rbæt, snyj, ndýn
  { {0x6b5d000f,0x1877000b,0x7ae00027,0x25a01813}},	//   sége, _לעיר_, _pamt, ssil_
  { {0x7349007c,0x9b25007c,0x1db70037,0xbb760009}},	//   ачів_, офіл, _आमंत, צענו_
  { {0x29050c78,0xc333000b,0x1874002d,0x59f80063}},	//   _bola_, הוא_, огля, реля_
  { {0xdd8f000a,0xc05a002d,0x69c20c42,0x629d0053}},	//   _سوف_, лій_, rtoe, zaso
  { {0x487b000b,0x6d480042,0x9fe60012,0xb7ca0012}},	//   נטקס, voda, إسته, ابتك_
  { {0xf773000b,0x6d480034,0x98bc0073,0x645c1814}},	//   הקה_, woda, dovą_, _izri
  { {0x6ce6007c,0x629d000f,0xc27b0009,0x68e11815}},	//   біне, vaso, _תרמי, _fald
  { {0xd24f0003,0x4ddb000b,0x9179001a,0x6d480606}},	//   _أنك_, נחיו, hận_, uoda
  { {0xb4fb000b,0x629d004a,0x8cca0037,0x6d481816}},	//   אפיי, taso, स्यो, roda
  { {0x2ba90037,0x6f66010b,0x23a90011,0x6e930012}},	//   _किरा, _увез, _किरद, _فلما
  { {0x63ab0002,0xdcef000d,0x7d0303ce,0x29050060}},	//   ągni, _jucă, önsk, _yola_
  { {0x672d003e,0xf7730003,0x29050028,0x25bb0009}},	//   wiaj, كار_, ðla_, _עצומ
  { {0x4ac80044,0x907b0093,0x629d1817,0xa8180009}},	//   रभाव, רטלי, paso, בֵּי
  { {0xec37000b,0x6b5d000e,0xef110009,0x9f550024}},	//   _לאור_, ségb, ֵּן_, івач
  { {0xad670012,0x673c0031,0xa5f807a7,0x29c80012}},	// [3730] مائه, _írju, бету_, _هِيَ_
  { {0xe29f0028,0xe6c0001b,0x394a1818,0x660d09b8}},	//   lað_, čišć, cobs_, ryak
  { {0x3e6f003a,0xab9b0012,0x672d1819,0x8bd9019c}},	//   _kötü_, اخطر_, piaj, рмес_
  { {0xe29f0065,0xeab00003,0x61ed181a,0x60080009}},	//   nað_, فعه_, _kral, _הִשְ
  { {0x99d70003,0x68e1181b,0x28c00037,0x76550002}},	//   إتصا, _pald, श्कि, ęzyk
  { {0x64400002,0xc5f20009,0xa99c0009,0x88c80024}},	//   _śmie, _קדם_, נבור, йлів_
  { {0xe29f0065,0x6b950002,0xdbf10066,0x229d0010}},	//   kað_, _uwzg, _přít, eškų_
  { {0x3818000b,0xe29f0028,0x05a90198,0x0d8500db}},	//   מקום_, jað_, авий_, олин
  { {0x68e111e3,0xe576003c,0xa5f6004c,0xa6e20097}},	//   _tald, озы_, жењу_, öðin
  { {0xf0b80012,0x929d0034,0x690b0060,0x53c9181c}},	//   _هامش_, _koło, _mües, агом_
  { {0x28c40037,0xeb990001,0xe29f0028,0x61ed0de5}},	//   _लॉगि, јим_, fað_, _aral
  { {0xe29f0028,0x3a9a002d,0x61ed0328,0xcad50009}},	//   gað_, штою_, _bral, חוֹת_
  { {0x4e780003,0xdb090031,0x6b560031,0x2005008e}},	//   _احمد_, áláz, lágk, älin_
  { {0xe3b10003,0x317a0009,0x3ce30159,0x7796004c}},	//   _قرب_, ירשמ, _najv_, жјац
  { {0x61ed0005,0x869a0867,0xa7a90009,0x186a0147}},	//   _eral, итат_, יֹּ֥, рави_
  { {0xd6d20012,0x91790081,0xb21b1691,0x61ed181d}},	//   بقر_, uận_, rbær, _fral
  { {0xd7f8000d,0xae190009,0x452a004c,0x6e290030}},	// [3740] ţă_, בוּכ, ажан_, _žebr
  { {0x4d630024,0x2f180025,0xfc320012,0x7ae4181e}},	//   дкув, _méga_, وحا_, _hait
  { {0x8b26007c,0x5ba5002d,0x7b2b0066,0x6b5d0061}},	//   одже, зріз, dřuj, léga
  { {0x7b3c0133,0x74130012,0xa8020060,0x929d0034}},	//   ačun, بوما, şıkl, _doło
  { {0x69c6000f,0xd9460015,0xf1940024,0x6b5d0025}},	//   ntke, оеди, чиль, néga
  { {0x7ae40006,0xda650003,0xf1bf000e,0x3ea0181f}},	//   _lait, ساني, szág_, lait_
  { {0xfbc30447,0xea010081,0x86c40012,0xbab600ae}},	//   _обро, _đậu_, كيغن, _ومسب
  { {0x3ea00061,0x3da6002d,0x7ae4002c,0xd6d90002}},	//   nait_, ороб, _nait, kołu_
  { {0x50ca0037,0xb17b0033,0xe29f0028,0x8cc10011}},	//   िभाष, rvåk, vað_, र्को
  { {0x7af6002a,0x6b56000e,0x6aa90002,0xad260012}},	//   _anyt, lágh, _zdef, تربو
  { {0xe29f0065,0x98a3007a,0x547b000b,0x69c600e6}},	//   tað_, niją_, יטיו, etke
  { {0x74ca0044,0x3ea0000e,0x8cca0037,0x61ed05e1}},	//   स्तृ, jait_, स्तो, _pral
  { {0xe29f0028,0x41e40024,0x3ea00025,0x9f450030}},	//   rað_, міра, dait_, ílí_
  { {0xe29f0028,0x66570009,0x5e570009,0xa3e40011}},	//   sað_, _ובדף_, _וידע_, निआ_
  { {0x78fb000b,0xe29f0028,0x7d07009b,0x7ae40440}},	//   ספלו, pað_, _rojs, _fait
  { {0xab280001,0x23280001,0x501b000b,0x7ae41820}},	//   _моја_, _моји_, בולו, _gait
  { {0x690b0054,0xdb0200d9,0xaded0011,0x61ed1821}},	// [3750] _qües, nulý, जियन_, _ural
  { {0x929d0002,0x6abd0058,0xa1280012,0x98a30073}},	//   _poło, lgsf, _وكيل_, fiją_
  { {0x7ae400c6,0x98a30010,0x4427001a,0x60da0051}},	//   _yait, giją_, àn_, õtme
  { {0xfaa7002d,0x7d070002,0xa2940024,0xd8380064}},	//   ішен, _wojs, даці, úče_
  { {0x68e5004a,0x5efa0009,0xcb140009,0xd3580009}},	//   _kahd, _הפרד, ולף_, קידי_
  { {0x673b001c,0x39780024,0x09040024,0xd6d90034}},	//   čuju, ісію_, мпін, hołt_
  { {0x68e50006,0x98a3007a,0xa295007c,0xd9a80011}},	//   _mahd, ciją_, _наві, _कट्ट
  { {0x97d80003,0xe29f0028,0xe70b0009,0xbf640012}},	//   تظهر_, _þð_, יהֶֽ, وديو
  { {0x644600a2,0xd8380864,0x49b80012,0x6b560031}},	//   şkil, _reče_, _واكد_, ságk
  { {0x6e200005,0x58bb0003,0x361c000b,0x80b40538}},	//   _ümbe, _خارج_, יוחד, _обух
  { {0x6d890026,0x3ea00061,0xdb0e000e,0x7ae4004a}},	//   _hľad, yait_, űkít, _pait
  { {0x6281003e,0xdc3e000d,0x2d8b0030,0x6abd00b0}},	//   ślon, lţăm, _otce_, ggsf
  { {0x4e7a0093,0x21a30015,0x3ea01822,0x2bd20321}},	//   _האנצ, ниям, vait_, _सहभा
  { {0x7ae40daa,0xeb180011,0xeb080011,0x6b5d0025}},	//   _wait, _दत्त_, _वक्त_, réga
  { {0x3ea00bd6,0xacfa000b,0x7ae41823,0xc1720009}},	//   tait_, _להסכ, _tait, תחם_
  { {0xdd920003,0x23d20037,0x69100051,0xab290012}},	//   فور_, _सहबद, _näev, _وسيل_
  { {0x3ea00f52,0xb2bb000b,0x7abb000b,0xc333000b}},	// [3760] rait_, _המפר, _הצפו, _רוח_
  { {0x98a30010,0x3ea01824,0xd5af0012,0x8d760009}},	//   tiją_, sait_, افل_, פגעו_
  { {0xa3e40044,0x307b000b,0xa87b000b,0x807b0009}},	//   निए_, _לאינ, _לאיר, _לניצ
  { {0x98a3007a,0x63be0033,0x2b811825,0xf1aa0012}},	//   riją_, _åpne, _móc_, ماته_
  { {0xc693000b,0xa6e20028,0x98a30010,0xc2e90012}},	//   _ראש_, öðun, siją_, تعلم_
  { {0x28c00044,0x98a30010,0x2d820066,0xf806002d}},	//   श्चि, piją_, íkem_, зчин
  { {0xb4b80037,0x351b000b,0x044300b3,0x6abd006f}},	//   छली_, _פולנ, _зерн, ygsf
  { {0x543b0093,0x671c0011,0x1ae3112d,0x753d0031}},	//   _העלא, नसिक_, _посм, észn
  { {0xe1260046,0xdb02000e,0xcad70009,0xe4e60024}},	//   _емаи, cslé, _צומת_, пінн
  { {0x6e24004b,0x2b810081,0x628602dd,0x6910005e}},	//   izib, _bóc_, ecko, _käeu
  { {0xdbf10013,0x8cc10037,0xdfcf0003,0x40eb0009}},	//   _přát, र्टो, _ميل_, _לַאֲ
  { {0xf6e5007c,0x1dac0037,0x7c42001e,0xf0170009}},	//   _оцін, _चिंत, _ātrā, _מקבץ_
  { {0x87250012,0x7af6008e,0xdddb099e,0x6abd1027}},	//   _تعلم, öyty, rcuţ, rgsf
  { {0xb4ab0044,0xdddb000d,0x27e90002,0x98bc0010}},	//   _गये_, scuţ, łane_, tovę_
  { {0x3d000037,0xf55b000b,0x4f5b0003,0xd7f80001}},	//   राने_, _הדגמ, مجرد_, пут_
  { {0x443f0027,0x8cca0037,0x3bbb0009,0xdc3b0009}},	//   _ću_, स्सो, _המהד, _לעור
  { {0xa3e40044,0xa2a20037,0x68e5008e,0x6b5d0025}},	// [3770] निक_, _ख़त्, _tahd, légo
  { {0xf1b20037,0xdb1c0002,0x0467011f,0xca380009}},	//   _जितन, _opró, птем, _מנחה_
  { {0x69100005,0x63ba048b,0x7c670012,0xa0880009}},	//   _päev, nutn, سائل, _מְרִ
  { {0x5a350048,0x6363005e,0x6b560018,0x6f160064}},	//   мнет, kõne, tági, ckyc
  { {0xf9880003,0xf984002d,0x89a80024,0x98a7004b}},	//   كنني_, егіо, зків_, jină_
  { {0xe9d8002d,0xe4e4002d,0x8dfa000b,0x63ba120d}},	//   які_, _пісн, _והשת, kutn
  { {0x1bd400be,0x20540014,0xd0060014,0x98bc0030}},	//   _поря, нтър, деще_, lově_
  { {0xdb1b0006,0x77f8000b,0xe6190264,0xa3bb0011}},	//   nttä, למוד_, жди_, इंस_
  { {0x98a7007d,0x2d990061,0xe9810024,0xc2c40012}},	//   gină_, èse_, _разi_, _سيلي
  { {0x69100051,0xd6d90002,0xee360015,0xf9920009}},	//   _jäet, seł_, ьны_, _סרב_
  { {0x3c65007c,0x2d540005,0xd8740012,0x98bc0030}},	//   ьког, päev_, _كامب, hově_
  { {0x57270003,0x6b5d000e,0x60080009,0x11d60024}},	//   _عراق, ségn, _מִנְ, мігр
  { {0x28c40037,0x98a7000d,0xddcb0034,0xbebd0073}},	//   ल्कि, cină_, _wygł, siūs
  { {0x3ebf0054,0x45450003,0x6da2000d,0x19b60009}},	//   lgut_, _تنتق, nţaţ, ופשר_
  { {0x93a80012,0x3ebf01a0,0x6f160064,0x3b0a0681}},	//   _فايف_, ogut_, tkyc, _меко_
  { {0x3ebf1826,0xdbd90017,0x9f550001,0x93b60009}},	//   ngut_, nçõe, ењуј, _חלקו_
  { {0x307a0003,0xdbd90017,0xaefb001a,0x3f8c09d4}},	// [3780] _وحدة_, içõe, _thùn, ūdu_
  { {0xb4b80044,0xad5a0024,0x70860048,0x6f160064}},	//   छले_, ірах_, _югоз, skyc
  { {0xb6a30020,0xd7ca0012,0x8ae60024,0xe0fb0009}},	//   _phầ, _بوجه_, ділл, _וליל
  { {0xeab20012,0xc4c90009,0x60dc1827,0xcf9300af}},	//   ئعا_, יג_, lerm, _שטר_
  { {0xdb1c003e,0xa2c10044,0xcb130009,0x98bc0030}},	//   _spró, _वास्, כלא_, cově_
  { {0x753d000e,0x7d03006f,0x478a0593,0x98a7000d}},	//   észl, önst, осим_, vină_
  { {0xd7f00003,0x2bdd0037,0xec160012,0xb6a30081}},	//   اكب_, _फैला, _غورد, _thầ
  { {0x69100005,0x8cca0037,0x98a7000d,0x940b0009}},	//   _käes, स्रो, tină_, _וּמֵ
  { {0x29180028,0xbebd0010,0x17570009,0xfaa3054b}},	//   kkra_, tiūr, וסקר_, _шато
  { {0x2fdf003e,0x60dc0119,0x97c60003,0x6b5d0061}},	//   ługi_, jerm, _يتضم, tégo
  { {0xdb1b03fc,0x34b7000b,0x798d0002,0xccf80066}},	//   yttä, ופים_, _staw, dmět_
  { {0xef690003,0xc334000b,0x68e81828,0x7bc80070}},	//   _فإنه_, תוֹ_, _hadd, rtdu
  { {0xd2460003,0x61e4000e,0xc21b002d,0xf50600b3}},	//   ان_, _csil, ієм_, _оздо
  { {0x637e001e,0x660f02f1,0xd0060012,0x7b3c1829}},	//   _līni, äcke, هل_, učuj
  { {0x9be6002d,0x68e81013,0x36d502ad,0x61e4182a}},	//   _цілк, _madd, новр, _esil
  { {0xc328000a,0x26c001a2,0x8cca0044,0x68e80163}},	//   _يكون_, ggio_, त्रो, _ladd
  { {0x64580006,0x68fa0070,0x8d790003,0xf6500012}},	// [3790] _hyvi, _ontd, سماء_, لئك_
  { {0x29180248,0x98bc0030,0x60dc182b,0xe1670012}},	//   ckra_, rově_, cerm, _تدبي
  { {0x3dc90002,0xa7750294,0x6910005e,0x98bc0030}},	//   staw_, _плоч, _väet, sově_
  { {0xfe0e0044,0xab94002d,0x5c370009,0x160e0011}},	//   िहास_, тиці, ורבן_, िहार_
  { {0x78a3182c,0xa6960009,0xa15913f0,0x290c0aef}},	//   tanv, _רכשה_, паду_, _boda_
  { {0x41b20037,0x3f810051,0x2f110028,0x41bc000b}},	//   _जिसस, _kuhu_, _lágt_, קצוע
  { {0xa927001e,0x92c7002d,0x78a30245,0x3f81182d}},	//   _režī, _ощад, ranv, _juhu_
  { {0xc7b4000b,0x68fa0052,0x291e0028,0x78a3153b}},	//   דבק_, _entd, _elta_, sanv
  { {0x98a3007a,0x99840003,0xee39077e,0x3a54003c}},	//   siję_, _للقو, яни_, _актё
  { {0x7ae9004a,0x290c182e,0xa91d0073,0x69cb0032}},	//   _haet, _goda_, _atžv, mtge
  { {0x56950014,0xdbd90017,0x7ae90051,0xe4a80009}},	//   _зает, pçõe, _kaet, וֹרָ
  { {0x441a000b,0x7ae9004a,0x8c1a000b,0x60c500ed}},	//   פורס, _jaet, פורי, _achm
  { {0xa2c10044,0x78a1004a,0x20d6002d,0x29c9182f}},	//   _वार्, _kelv, нівс, núa_
  { {0x61e4009b,0x69cb0ad2,0xdcf90012,0x06380012}},	//   _vsil, itge, _رفعت_, _تسمع_
  { {0x29180028,0xad1a0009,0x05740012,0xdcee0081}},	//   rkra_, _מוסר, _شاهد, _libă
  { {0xdee30511,0xeab20012,0x29181830,0x3f811831}},	//   лоси, _صعب_, skra_, _duhu_
  { {0xea010020,0xce470014,0x8d660015,0x05661832}},	// [37a0] _đầu_, езте_, евае, еван
  { {0x5997000b,0x6910004a,0x69cb0032,0x6b560018}},	//   _רכיב_, _väes, dtge, rágu
  { {0x309b000b,0x6b8b004b,0xa09b0009,0x69cb0227}},	//   _משימ, _îngă, _מייט, etge
  { {0x2ca50065,0xbae5002d,0x61220029,0x539a0009}},	//   hald_, кцій, _dôle, פינו
  { {0x2ca50058,0x2bd20037,0x6b56000e,0x6d5a0248}},	//   kald_, _सहवा, lágs, ylta
  { {0x2ca50028,0xe1660012,0x7afb0032,0x07e6004c}},	//   jald_, ردشي, _enut, ецим
  { {0xb9080044,0xf093000b,0xe29a0024,0xd0100012}},	//   _बस_, ננה_, _нав_, شلة_
  { {0x78a10051,0x29c90028,0xc7b30009,0x7ff30012}},	//   _eelv, búa_, אבה_, اسوا
  { {0xa3dc0037,0x78a1000e,0xa3e80037,0x61e4003a}},	//   तौर_, _felv, बिक_, çild
  { {0x98a70010,0x71d70009,0xc0d60012,0xeb190011}},	//   tiną_, _אומד_, _سيصب, दस्त_
  { {0xf36a0009,0x20c90012,0x351b0009,0x97c50012}},	//   ּדָּ, _تبقي_, פוטנ, _لتنم
  { {0xa4fd0037,0x4e960012,0xfbd30009,0xc43b0009}},	//   _उच्च_, _أشار, נתר_, לתיי
  { {0x6e3b0029,0x2ca503c0,0x298b010c,0x3f810190}},	//   _ľubo, bald_, ясно_, _suhu_
  { {0x4bda0012,0x63be1833,0x3f8112fb,0xab5d0035}},	//   _فبعد_, kupn, _puhu_, itļi
  { {0xdfd80014,0x98480014,0xbf1c0011,0xe4480012}},	//   нът_, еята_, नसून_, _تلغى_
  { {0xa857000b,0x9f470029,0x63be00b6,0x61220025}},	//   גילה_, yvní_, dupn, _rôle
  { {0x5d550014,0xf6530003,0xe7e20037,0x29070034}},	// [37b0] вкат, ائز_, _कैसा_, yjna_
  { {0x7d1a0005,0xe6dd0037,0xdb1e0051,0x2d821834}},	//   nkts, _मस्ज, htpä, _duke_
  { {0x78a11835,0x25a91836,0x9bc80012,0x7d080227}},	//   _relv, ssal_, فولك_, ijds
  { {0x672400bd,0x62750003,0x25a90066,0x29c901e3}},	//   chij, نهائ, psal_, túa_
  { {0x66640098,0x333c0009,0xaad30011,0x6910005e}},	//   _бърз, התאמ, ध्यक, _käep
  { {0x88bc0066,0x9f470066,0xccf80030,0x78a7001b}},	//   _směr, rvní_, změr_, najv
  { {0xa4d4002d,0x22950003,0x69cb1837,0x2d540032}},	//   _щорі, _للأس, stge, päer_
  { {0xf7710003,0x25660061,0x7afb1838,0x63b80029}},	//   جات_, rôle_, _unut, ávne
  { {0x91820020,0x9fb60066,0x850c0011,0x2ca50248}},	//   iện_, vřít_, ाउंट_, tald_
  { {0xe9750003,0x61e4003a,0x8d750003,0x601c12fb}},	//   _شهاد, çile, خابا, nämö
  { {0xd0f60009,0x03950048,0xa91d001b,0xa8020060}},	//   _שמעת_, ърпя, _tužb, şırl
  { {0xde950046,0x2b160014,0xc9490009,0x39860018}},	//   _радњ, тьор, _ומ_, _pôs_
  { {0xb5fb000e,0xd24f0012,0x0b430024,0xe3b80060}},	//   _szán, ْنُ_, рнян, arı_
  { {0x9e64007c,0x6fd80011,0xcdb60009,0x91ba0009}},	//   _свід, _महमू, _יפנה_, ומשי
  { {0x10a31839,0x61e2003e,0xea010020,0xa78c0009}},	//   рисн, zwol, _đấu_, ּאמֹ
  { {0xc7b2000b,0x2b030011,0x3eda0012,0x6b830032}},	//   יבל_, षाणु_, بورج_, _iung
  { {0x0357000b,0x80e10037,0xe5a6022a,0x6724183a}},	// [37c0] _ביקש_, फ़ाइ, тизи, rhij
  { {0x6b83183b,0x6d41183c,0x31bb0009,0x63be0c51}},	//   _kung, nnla, _קזינ, tupn
  { {0xa7fc003a,0x8afa0009,0x106a0012,0xe3b20012}},	//   _azın, ֽהְי, _تحظى_, شرا_
  { {0x98a7007a,0xf529000b,0x6b830a26,0x9c7c0030}},	//   minę_, חץ_, _mung, meče
  { {0xc333000b,0xf1fa0003,0x98a70914,0x9c7c117c}},	//   סוד_, بعات_, linę_, leče
  { {0x2eed003a,0xf993000b,0x8a170009,0x6aa4183d}},	//   edef_, סרו_, כחנו_, _leif
  { {0x63630005,0xb8da0037,0x98a70911,0xd7e60024}},	//   sõna, _आए_, ninę_, тіло
  { {0xdb1b0061,0x6b560031,0xe3b80060,0xff4f0012}},	//   puté, zágr, vrı_, يخي_
  { {0x6b5d000f,0x5d540014,0xbb770009,0xcf770012}},	//   ségk, лкит, _יעלו_, خصوص_
  { {0xe29a0020,0x6b830e9e,0x660f0248,0x98a70073}},	//   _đưa_, _bung, äcka, kinę_
  { {0xa3e80037,0x3eb90010,0x9182001a,0x6f09183e}},	//   बिट_, ųsta_, yện_, bjec
  { {0x98a70010,0x63b500d9,0x7b3c001b,0xe61a004c}},	//   dinę_, ázna, ačuv, _оде_
  { {0x2b460029,0x6f0f1725,0x64de0011,0xa4d40024}},	//   čoch_, _rocc, _नक़्श, _болі
  { {0x98a70010,0x2f15130b,0xc1710009,0x6d5e0227}},	//   finę_, _lågt_, ֶ֗ם_, jlpa
  { {0xf7730003,0xb4be0037,0x443a0051,0x28d20037}},	//   لار_, इली_, _äp_, द्धि
  { {0x27fe006f,0x6d5e006e,0x5eb4004d,0x3c770009}},	//   åtna_, elpa, ийст, _בתום_
  { {0x6ca700de,0xad670012,0x6b830032,0x291c0097}},	// [37d0] вреж, نائه, _zung, kkva_
  { {0x01fa0009,0xe5c4004c,0xdb020097,0x45d404a5}},	//   _נפתל, јсто, mslá, рофс
  { {0x389a000b,0x1bfb0037,0xb2270028,0x98a70010}},	//   _איתנ, एमएल_, _fræð, cinę_
  { {0xdc3b0009,0xc43b0009,0xeab00012,0x501a0009}},	//   ועבר, ותבי, قعه_, _נורו
  { {0x6eba000b,0x78a514dc,0x271f0037,0xdb020028}},	//   _אזרח, ðhvo, _बतौर_, nslá
  { {0x645c014d,0x1bf40044,0x7aed06cb,0xeb930003}},	//   _fyri, ेमाल_, _laat, _نظر_
  { {0x98a20015,0x6f090027,0xc7a80012,0x97c40012}},	//   щище, tjec, نديل_, لتيم
  { {0x765d0006,0x929d0002,0x287c000b,0xa87c000b}},	//   _kysy, _połu, ונומ, ואור
  { {0x6b8300c6,0x74ca0037,0x6aa40886,0xc3320009}},	//   _sung, स्कृ, _reif, _הון_
  { {0x61e91277,0x6e290002,0x6d4114bb,0xeb990863}},	//   _isel, rzeb, unla, нио_
  { {0x91b00020,0xb5fb000e,0x9cd6000b,0x3ea900e6}},	//   _đảm_, _szál, אותה_, kaat_
  { {0xe452000b,0x15f50003,0xdb020028,0x8bba0009}},	//   מֶר_, _مستح, fslá, עזרת
  { {0xba3d0066,0x3f85016d,0x2727005e,0xfb1a0009}},	//   _zdůr, _hulu_, _mõnd_, גורמ
  { {0x98a70010,0x2f18000e,0x6b83183f,0x3f8500ff}},	//   tinę_, _régi_, _tung, _kulu_
  { {0xc815007c,0xd1410002,0x3f85001b,0x201e1840}},	//   аєть, czął_, _julu_, áti_
  { {0xd7f7008a,0x2fd80051,0x28da0037,0x7bc11841}},	//   ững_, _ärge_, _मॉनि, mulu
  { {0x7bc11842,0xc68f0012,0x99d60012,0x16660681}},	// [37e0] lulu, سِل_, _إتبا, увам
  { {0xdb0a0066,0x645c0258,0x319b0009,0xb4de0011}},	//   ěnít, _pyri, _רבינ, ढ़े_
  { {0x657c0006,0x25e50037,0x62810066,0x7bc11843}},	//   _virh, _जैसी_, ělov, nulu
  { {0x3ea90070,0x25ad0225,0x7bc1000d,0x645c1844}},	//   caat_, ksel_, iulu, _vyri
  { {0x61e9000e,0x99d30003,0x7bc11845,0x7a360012}},	//   _csel, متوا, hulu, دعائ
  { {0xdce30039,0x645c0010,0xa2d40321,0xe9730012}},	//   _minē, _tyri, _यॉर्, مهند
  { {0xd5470014,0x7bc100e7,0xdce60073,0x660f0248}},	//   _спре_, julu, _sukė, äckn
  { {0x3f8500c6,0x7f440061,0x7bc1000d,0xc6f81846}},	//   _dulu_, nniq, dulu, тних_
  { {0x25ad1847,0x8f670003,0xba490030,0x69360035}},	//   gsel_, دميك_, omůž, eņem
  { {0x29560098,0x2dd70003,0x1dd70003,0x80d60037}},	//   _събр, ابية_, ابيع_, म्मे
  { {0x986a0012,0x71730012,0x78a5005e,0x86c60012}},	//   _أحذف_, _اهلا, _rehv, _ميان
  { {0xb5fb0272,0xf1bf000e,0x27270051,0x93270012}},	//   _szám, szám_, _kõne_, اردن
  { {0xa5960098,0x7aed00b9,0x6936001e,0xf7730009}},	//   _срещ, _vaat, aņem, _הקף_
  { {0x8cd30044,0xa2c10037,0x27270051,0x6d58009b}},	//   ब्दो, _वाक्, _mõne_, _ukva
  { {0x753a03eb,0x7bc11848,0x351b0009,0x7aed019a}},	//   mitz, culu, _אוגנ, _taat
  { {0x753a0663,0x3e070014,0x765d004a,0x753d000e}},	//   litz, лязв, _pysy, észv
  { {0xdb1e0108,0x3ea91849,0x7bdc184a,0xdb1b01bd}},	// [37f0] cupé, raat_, _apru, nutí
  { {0x753a03eb,0xd7f8000d,0x3ea900b6,0x4c4b042a}},	//   nitz, _oră_, saat_, няем_
  { {0x765d003e,0xb97a000b,0x9cd70009,0x29010018}},	//   _wysy, _שנתי, רובה_, _inha_
  { {0x92eb000a,0x4f9a0093,0x8f9a000b,0x7f440054}},	//   عراق_, _שברצ, _שירי, cniq
  { {0x6936001e,0xa91d0027,0x28d20037,0x05790012}},	//   zņem, _dužn, द्वि, _لمحة_
  { {0xf77f003a,0x1fb50103,0xbca50012,0xe8f80024}},	//   _hiç_, асир, _خمسي, ллі_
  { {0xd705004d,0xd92c0009,0x7e0d0011,0xc9180009}},	//   изки, עֵדָ, ाङ्ग_, רחות_
  { {0x7bc1000d,0xf8380009,0x47590048,0xc2c50012}},	//   vulu, טנות_, ърля_, _خيري
  { {0xd7060015,0x6d45004a,0x1d2502e3,0x80cd0011}},	//   рные_, onha, имим, _सापे
  { {0x3f850051,0x62880066,0x7bc1184b,0x9d520012}},	//   _tulu_, ědom, tulu, ينيت
  { {0x3084000a,0xc1040003,0x53350009,0x78fa0009}},	//   _المف, _دولي, ֹאָב_, _שפעו
  { {0x249800a2,0xf7700003,0x7bc1184c,0xed590027}},	//   ırma_, _فان_, rulu, drže_
  { {0xfe9a0093,0x8f1a000b,0xd3560009,0xa2ba0011}},	//   _סיסמ, _שונת, שירי_, ्लब्
  { {0x98a70066,0xf4870055,0x628f172a,0x7bc1184d}},	//   vině_, _судн, acco, pulu
  { {0x2bb1003e,0xbd680001,0xd53a0009,0x3d090011}},	//   jąc_, _срце_, _שתצט, साने_
  { {0x273f004a,0x4424001e,0x6fd80037,0x8cd80037}},	//   vänä_, _ām_, _महसू, न्नो

  { {0x6e930003,0xed5a0001,0x661b00b6,0x25760012}},	// [3800] تلقا, воа_, nyuk, لهرس
  { {0x33f60406,0xf1bf000e,0x26cb00c1,0x0c7a0012}},	//   ичес, zzák_, _ecco_, نصاب_
  { {0xa3bb0011,0x889b0009,0xbcb60009,0x60bb0009}},	//   इंट_, _שבטי, שפעו_, _בציד
  { {0x28d20037,0x6f0d0002,0x98a70066,0x6b5d000e}},	//   द्रि, cjac, pině_, ségv
  { {0x7e9b000b,0xf8aa0037,0x272a001a,0xb2d30012}},	//   _בסכו, _क़ाय, _hùng_, تينغ
  { {0xc05a007c,0xc1560001,0xe7b40012,0x6fb40012}},	//   кій_, шњењ, ممتد, ممتا
  { {0xf8b30093,0x98b1000d,0x2bb10034,0x8c430f80}},	//   קשה_, liză_, cąc_, _дере
  { {0x6d5c009b,0x9c7c0027,0x3958184e,0xdb0202f1}},	//   _hkra, ječa, hors_, nslä
  { {0x753a0054,0x60ea00f5,0x3abb0009,0x1d340048}},	//   titz, _имам_, _שממנ, йния
  { {0x6443003e,0x7fd6002d,0x6259002d,0xf5360009}},	//   źnie, _віді, _срср_, ינִי_
  { {0x395803eb,0x753a184f,0x6e2d00c1,0x6f0d0002}},	//   dors_, ritz, zzab, yjac
  { {0x753a0052,0xd6d90002,0x612b0051,0x26c2000e}},	//   sitz, koły_, _külg, ókod_
  { {0xf594000a,0x8d94000a,0x78a8000f,0x224d003a}},	//   _التج, _التش, _kedv, çek_
  { {0x361b000b,0x15fb0009,0x6ca30048,0x272a0081}},	//   _בודד, _שהגע, _дръж, _bùng_
  { {0x272a0020,0xdb09000e,0x74670014,0xe3b80060}},	//   _cùng_, álóz, _кръв_, azır_
  { {0x6c7b000b,0x272a0020,0xe47b0093,0x747b000b}},	//   _באופ, _dùng_, _ברוכ, _בנוג
  { {0x68e30164,0x8754002d,0x8cc20037,0x69c001a0}},	// [3810] yend, ікує, _लाखो, àmet
  { {0xe58a000e,0x3f85000e,0x61ed05de,0x03b70012}},	//   óváí, ílus_, _isal, لإصد
  { {0xa2c10037,0x6e2d000e,0xd259001e,0xee870015}},	//   _वाञ्, szab, ļņu_, _выго
  { {0x68e3008b,0x256f0051,0x2b59000d,0x19b50012}},	//   wend, külg_, nosc_, محتج
  { {0xe919002d,0x49cb0015,0x6ce70024,0xdb050097}},	//   лоді_, туем_, _ківе, gshá
  { {0x68e30154,0x49b80012,0x70e10011,0x88c80024}},	//   uend, شاهد_, फ़ेल, илів_
  { {0x60da0051,0x2ca70156,0x6458005e,0x63be001b}},	//   õtmi, _rend_, üvit, crpn
  { {0x2489007a,0x61ed00b9,0xf1bf0028,0x6d5c0066}},	//   šimą_, _osal, krá_, _zkra
  { {0x612b000f,0x9c7c0d6c,0xcee80003,0xa194027f}},	//   _küld, veča, شرين_, _матч
  { {0x6aa901e4,0x0d82007c,0xf1bf1850,0xd1310003}},	//   _heef, яльн, drá_, _عما_
  { {0x7f850003,0xf7850003,0x7bc5002c,0x3958019e}},	//   _الصن, _الصَ, nuhu, vors_
  { {0xbef40012,0x91e601c6,0x98ae0073,0x06f40012}},	//   _وأنت, боме, rifą_, _وسنج
  { {0xd838001c,0x61ed000f,0xe7300003,0xc332000b}},	//   _reči_, _csal, _تصل_, לוט_
  { {0x6aa90070,0xba560009,0x8a39003c,0x9c7c1851}},	//   _leef, מסרו_, ряют_, mečn
  { {0x9c7c1852,0x7d031712,0x3947006f,0xc7a30014}},	//   lečn, _inns, inns_, зиск
  { {0x272a0020,0x2416000b,0x8407000e,0xfbb60009}},	//   _vùng_, _לחצן_, _előí, _הפקת_
  { {0x7ae600a2,0x11d70003,0x2fdf000d,0xdb020248}},	// [3820] mekt, _هوية_, ăuga_, gslå
  { {0x6b80003a,0xdca60695,0x7fd60024,0xd2a60024}},	//   _simg, сажи, _лімі, _бiль
  { {0x80b30037,0x7ae60227,0x52860012,0xdb1b0031}},	//   ीलैं, oekt, ملاك, lutá
  { {0x9a6a0012,0x7ae61853,0x6b5d0fc0,0x6d5c0034}},	//   همال_, nekt, légr, _wkra
  { {0x28c90037,0x61260028,0x9c7c0580,0x023a0012}},	//   _राशि, _aðla, ječn, دثات_
  { {0x25bf007d,0x201c0010,0xdb1b000e,0x71d70009}},	//   drul_, tyvi_, iutá, מונד_
  { {0xdfd00003,0x93bc000d,0x25bf004b,0x8f540012}},	//   ذية_, nzăt, erul_, ينتش
  { {0x6aa900bd,0xa3ab0037,0x69c6004a,0xa714002d}},	//   _geef, गठन_, kuke, імпі
  { {0xe9a30001,0xc6f70015,0xa91d001b,0x98b10034}},	//   _натп, сных_, _mužj, lizą_
  { {0x1d34002d,0xdce30073,0x5046004c,0x69c6138b}},	//   іння, _minė, _лезб, duke
  { {0xa097000b,0x62850066,0x155b0009,0x78250012}},	//   _הדבק_, ěhov, רכיב, _وعمل
  { {0x2bb5001a,0xdcf8001e,0xf4130009,0x8e860012}},	//   ích_, _divā, לפת_, _الإه
  { {0xc333015a,0x25bf000d,0xf1bf0018,0x05d300ae}},	//   פוש_, crul_, urá_, _فزوج
  { {0x1677000b,0xa2d90011,0x200d0034,0x9e770009}},	//   _הגדל_, _फॉर्, ślił_, _הגדה_
  { {0x0d3b000b,0xd52d001a,0x69c60010,0xd6db00f5}},	//   _תגוב, hữn, auke, лта_
  { {0x7ae600a2,0xf770000a,0xe6990048,0xdb1b1854}},	//   cekt, فاق_, рваш_, butá
  { {0x9f60000f,0xb5050037,0x61ed0051,0xa4870003}},	// [3830] írás_, रालय_, _usal, مجان
  { {0x256f0032,0x6aa90032,0x30a70024,0x3ea01415}},	//   küle_, _seef, _урив, abit_
  { {0x8cd80011,0x68e7004b,0x6d481855,0xe46b0337}},	//   न्धो, mejd, inda, ушал_
  { {0xc2c40003,0x61fb0070,0x321d0034,0x70e10011}},	//   كيمي, _prul, tywy_, फ़्ल
  { {0xdaa8002d,0x2bb5001a,0x6d5a0010,0xbddb0054}},	//   свід_, ách_, kota, _exèr
  { {0x2d99004a,0x612b000e,0x77950001,0x27950538}},	//   _itse_, _füle, ојиц, ошир
  { {0xdfce0003,0x3d0c0037,0x69c60032,0xa069004c}},	//   نيو_, ़ाने_, zuke, шака_
  { {0xf3890020,0x9c7c0013,0x25bf000d,0x6d481856}},	//   _bản_, tečn, trul_, enda
  { {0x6b8a008b,0xe6160015,0xf389001a,0x2efa0009}},	//   _aufg, жды_, _cản_, בִיב
  { {0x02440003,0xc588001a,0x4519010c,0x1c4500b3}},	//   _عَلَ, _tồn_, рция_, жном
  { {0x5fdd0044,0x63710163,0xab5d001e,0x9c7c080a}},	//   _महिल, gång, guļo, sečn
  { {0x2d990051,0x2fc70052,0xcf920009,0xe1e70012}},	//   _otse_, mung_, _חטא_, وس_
  { {0x2fc71857,0x6b5d0061,0x6d890029,0x10f6010c}},	//   lung_, tégr, _uľah, оявя
  { {0xf9920093,0x2d83001c,0x69c60119,0xa8060055}},	//   ורך_, _nije_, ruke, озгл
  { {0x27270051,0x2fc71858,0xe2080002,0xd546001a}},	//   _sõna_, nung_, wróć_, _lện
  { {0x291e0051,0x6b5d000e,0x672d000e,0xf6260593}},	//   ötab_, ségr, ghaj, одбо
  { {0x68e700c5,0xf09f0020,0x2fc71859,0xe7e90037}},	// [3840] bejd, _đàn_, hung_, झौता_
  { {0x91b0001a,0x61e4003a,0x2fc711ba,0x2d8b053a}},	//   _đàm_, çilm, kung_, _duce_
  { {0xc6160037,0x0bb6003c,0x2d8301e3,0x98780064}},	//   _तथ्य_, ющая, _dije_, _páči_
  { {0xe1fa020e,0x2fc70bc7,0xe28d0009,0xc7b30009}},	//   иге_, dung_, ְרוֹ, _קבר_
  { {0x93bc000d,0x6d480028,0xe89401d4,0xe9cf0012}},	//   nzăr, ynda, паль, نغو_
  { {0x6b840005,0x2fc70052,0xa3e50037,0x256f003a}},	//   _liig, fung_, _बैक_, tüle_
  { {0xf3890020,0x2fc7185a,0xf72a0015,0xb8f20011}},	//   _sản_, gung_, иций_, _वा_
  { {0x68e70002,0x3f820028,0x670d0011,0x6724185b}},	//   zejd, öku_, हायक_, nkij
  { {0xf3890020,0xf773000b,0x7afd0028,0x6d5a185c}},	//   _bảo_, וקה_, _ósta, tota
  { {0x2fc71858,0x9987000d,0x613008ec,0x6b9e00b0}},	//   bung_, şiţi_, _hälf, oppg
  { {0xe61f0020,0xd7ef000a,0x6d480028,0x7fd60024}},	//   _ngôn_, _لكل_, rnda, _фізі
  { {0x5187002d,0x8ae7002d,0xf1b10011,0x7f170012}},	//   жува, ціол, ुंचन, _ويلز_
  { {0x5a340055,0xbf130012,0xf3890081,0x69c2185d}},	//   днят, _تونب, _uản_, nroe
  { {0x67240c39,0x2d8b0030,0x98bc0073,0x3eab185e}},	//   ekij, _ruce_, rovė_, _sect_
  { {0x28d20037,0xd0d40048,0x656f0025,0xd6d90034}},	//   _सानि, ьоръ, îche, liła_
  { {0x6344000e,0xa3e50011,0x9d9b0012,0x9f4e01a0}},	//   tőne, _बैग_, لخطأ_, ïnès_
  { {0xa802003a,0x2fc70052,0x3eb90028,0x7bc80e86}},	// [3850] ğıyl, zung_, ósti_, ludu
  { {0x85050037,0xf09f001a,0xc8c90011,0xbd9b0009}},	//   राइट_, _đào_, _राइट, יסמת
  { {0x3eb9007a,0x80c40011,0xb8e10011,0x63440031}},	//   ųsti_, _राजे, ुल_, sőne
  { {0xad9b0029,0xf4130009,0x7bdb0009,0x539b0009}},	//   _prúd, ופע_, שקאו, ׁיבו
  { {0x8cd80037,0xa2cc0037,0x69c208de,0x96fa0009}},	//   न्हो, _हार्, groe, _פלשת
  { {0x2fc71858,0x3f8c03d0,0xf1bf000e,0x4e7a0009}},	//   tung_, _budu_, lzás_, _לארצ
  { {0xe8d9001a,0xc4d2000b,0x2fc70052,0x6371006f}},	//   _quỹ_, _רגל_, uung_, tånd
  { {0x2fc7185f,0xa3bb0037,0x7bc81860,0xf9890012}},	//   rung_, ेंस_, dudu, _هنري_
  { {0x6b840005,0x2fc71441,0xdb050248,0xad9b0064}},	//   _riig, sung_, rshä, _hrúb
  { {0xc5880020,0xa8a70695,0xee36003c,0x799b020d}},	//   _gồm_, _фрак, яны_, _ituw
  { {0xb4650014,0x7bc80051,0x0ecb0011,0xcad50009}},	//   якол, gudu, िलाड, ֔וֹת_
  { {0x91e60001,0x1bec0037,0x09e6004d,0xd6d90034}},	//   поме, _जनरल_, помн, biła_
  { {0xb0d20044,0x61300005,0x6d890029,0x42230014}},	//   _सामग, _jälg, _zľav, едяв
  { {0x867a0093,0x25e00037,0x2d9f0025,0x6d4b0025}},	//   _פרסו, _कहती_, mpue_, égal
  { {0xab99000a,0xdfd2000a,0x645c005e,0x6b84005e}},	//   _اختر_, عير_, ürit, _tiig
  { {0x3bba000b,0xa91d0027,0x612f038e,0x91cc0011}},	//   _המקד, _duži, _følg, _समलै
  { {0x5bdb0037,0x09ba0012,0x6ead0011,0x13db0011}},	// [3860] _बहुव, _اطبع_, _ज़रु, _बहुभ
  { {0x6d4113b9,0x9a3b000b,0xe8ca003c,0x69fb0009}},	//   nila, _לתפק, _угол_, _פליק
  { {0xa7fc003a,0x5ba5002d,0x28d20037,0x6b9e006f}},	//   _ayın, дріз, _साबि, uppg
  { {0x6d410160,0xdcb1001a,0x69c21861,0xc8c905f3}},	//   hila, hả_, troe, _राउट
  { {0xc333000b,0x291a001e,0x4efb0009,0x96fb0009}},	//   עוד_, _kopa_, _ההכו, _הלכת
  { {0x612b0005,0x291a004a,0x25a000b6,0x672b0097}},	//   _küla, _jopa_, mpil_, _algj
  { {0x6d411862,0xd6d90002,0x97c60012,0x61e4020d}},	//   dila, wiła_, ستثم, _lpil
  { {0x96ea007c,0xf3890020,0x0eea002d,0x9f49003a}},	//   ська_, _cảm_, ськи_, ıkça_
  { {0x9f63000e,0xa2d30003,0x96b70001,0x290f0097}},	//   ívás_, _سيلت, чују_, ýjað_
  { {0xd24f0003,0xc19b000b,0xa98b0009,0x79b70009}},	//   _إنك_, _לשמי, _הָאִ, _מלמד_
  { {0x6db500a2,0x7bc80051,0xd6d90002,0x9c7c0066}},	//   _aşağ, uudu, siła_, mečk
  { {0x6d41002c,0xd6d90034,0x9c7c0030,0xcf260012}},	//   aila, piła_, lečk, _عرضي
  { {0xa91d1863,0xc3330093,0x6d5e1864,0x637f0035}},	//   _suži, תור_, kopa, _jūni
  { {0xf67b000b,0x256f005e,0xd5cb0009,0x28df0011}},	//   _האדמ, küla_, _הֶהָ, प्पि
  { {0x36d5002d,0xd7e4002d,0x04db000b,0xd148001a}},	//   мовр, ніто, _הקול, yễn_
  { {0xf09f001a,0x8f9b000b,0x649109df,0x7ae4005e}},	//   _đàm_, מילי, zžič, õitl
  { {0x7883000e,0x2abc000b,0xbf1d0321,0x3abc0009}},	// [3870] _kívü, _המחא, _नवीन_, _המחנ
  { {0xf994000b,0x628e001e,0x9c7c1865,0xfc46119d}},	//   _ארץ_, ānoš, večj, čína_
  { {0xa0220051,0x29380009,0x03940024,0x7b940024}},	//   ööta, _מאזן_, ерія, ерії
  { {0xaabf0037,0x99990002,0x673d0028,0xa2940024}},	//   ्लिक, mysł_, _umsj, еаці
  { {0xa2c00037,0xd49b0001,0x4efa0009,0xe9ce0048}},	//   _वयस्, _грб_, _והרו, ък_
  { {0x3cf80037,0x4427001a,0x9c7c009b,0x26c20031}},	//   ्ञों_, ơn_, rečj, ókon_
  { {0x6e200051,0x7fd50024,0xe7390842,0x4abf0011}},	//   _ümbr, філі, жей_, ्लाव
  { {0xbf350003,0x28d20011,0x25660064,0xa6fb0009}},	//   برتغ, _साथि, vôli_, מִ֖י
  { {0x0609002d,0x80ce0037,0x6d411866,0x27311867}},	//   інок_, _ताले, tila, _láng_
  { {0x05760003,0x7aeb0052,0xa3b90003,0xfe4201b6}},	//   ومية_, legt, ياجر_, тньо
  { {0xac39002d,0xdcb1001a,0x69d91868,0x6363005e}},	//   ючих_, rả_, ltwe, sõnu
  { {0xf1d10044,0x61300051,0x59d10037,0xe29701d4}},	//   _समान, _mäle, _समार, маю_
  { {0xdb1b03fc,0x7bc5008b,0xe7300003,0xd6d90034}},	//   yttö, hrhu, _حصل_, liło_
  { {0x612f0192,0x61e40060,0x3860004b,0x27310081}},	//   _føle, çili, şire_, _báng_
  { {0x2d8f002a,0x4c9a0009,0xdd0b0034,0x25740032}},	//   _huge_, _ובצו, półd, näle_
  { {0xf4120009,0xeb0c0011,0xdbc6005e,0x27310081}},	//   _יפו_, _सचेत_, _köög, _dáng_
  { {0xb5fb000e,0x36670001,0x2d8f0061,0xdb1b0028}},	// [3880] _szár, дато_, _juge_, tttö
  { {0x186a0046,0xa06a02e3,0x3eaf0347,0x8c950024}},	//   _мапи_, _мапа_, _legt_, ерці
  { {0x61300d64,0x69d9051c,0x25a000d2,0xdbc6005e}},	//   _väld, etwe, spil_, _löög
  { {0xdb1b057f,0x2bc50011,0x23250024,0x2d871869}},	//   ortá, _विना, нфіг, _line_
  { {0xceb3007e,0x62490009,0x44260035,0x44a60012}},	//   _שיש_, ּנוּ_, ņo_, _يحسّ
  { {0xcf9a0046,0xfbc6002d,0x2d87002a,0xb7d80003}},	//   оји_, _обго, _nine_, كوتا_
  { {0x39940163,0xe29a002d,0x99920002,0x46b20011}},	//   _läs_, _мав_, ódła_, _ज़ाह
  { {0xc5880020,0x7d1c186a,0x2d87186b,0x6376186c}},	//   _hồi_, _hors, _aine_, nánd
  { {0x2d87007d,0x69d90002,0xbb430001,0x9c7c186d}},	//   _bine_, ctwe, _ретк, meči
  { {0x2b400054,0x2d87186e,0x2d8f001b,0x21a3003c}},	//   _amic_, _cine_, _duge_, _рифм
  { {0x2d87186f,0xd6cf0345,0xd6d90034,0xccf80030}},	//   _dine_, _ит_, ciło_, rdě_
  { {0x2d87032b,0x3d050044,0x7d1c0108,0x80da0044}},	//   _eine_, _होने_, _lors, प्रे
  { {0x27310020,0xa2640014,0x7d1c0070,0x660f006f}},	//   _sáng_, върл, _oors, äckt
  { {0x3eaf0070,0x46130012,0x7d1c1870,0xdb1e079b}},	//   _zegt_, _جوهر, _nors, lupä
  { {0xe571000b,0xdfd80014,0x2bad0037,0x69cb0052}},	//   _עַד_, мът_, झीदा, zuge
  { {0x33180003,0xdce9001e,0x9c7c013a,0xb5ab0012}},	//   _يزيد_, zpeļ, ječi, قائك_
  { {0x2d87003a,0x7bda004a,0x93780012,0xe3b80060}},	// [3890] _yine_, lttu, _تصور_, zyıl_
  { {0x2bc50037,0x7d1c1871,0xc588001a,0xe46b003c}},	//   _विमा, _cors, _bồi_, ошел_
  { {0xe3b8003a,0xdb1e1872,0xd0110012,0xe1ff01e3}},	//   nsı_, kupä, _صلح_, lvó_
  { {0x0f27007c,0xa87a000b,0x63760164,0x2b080037}},	//   _цьом, _מאתר, cánd, षाएँ_
  { {0xdddd003e,0xa1eb000a,0x2bc501e1,0x89a8002d}},	//   _wysł, تراك_, _विभा, дків_
  { {0x69cb1873,0x7d1c1874,0xf652000b,0x63a100d9}},	//   ruge, örsl, _עצם_, ypln
  { {0x6d450175,0xa8480012,0x60960012,0xdbc6005e}},	//   miha, ولهم_, رنيس_, _söög
  { {0xf771000a,0x6d450807,0x66020077,0xc2c40012}},	//   دات_, liha, _brok, _ليفي
  { {0xf1a70024,0xd6d90034,0x2cb10031,0x9f5e0031}},	//   _іран, siło_, _kezd_, íté_
  { {0x6d450065,0xfd110003,0xf389001a,0xf992000b}},	//   niha, اجة_, _hải_, _ערב_
  { {0x6b89000e,0xcb6a05fb,0x2d871875,0x93460189}},	//   _kieg, зане_, _vine_, енне
  { {0xdbc60051,0x2d87002a,0xd7fa000b,0x659505c6}},	//   _töög, _wine_, _מהעל, _заду
  { {0xed4e002d,0x2d87000d,0x6d4c0028,0x6d450312}},	//   _бо_, _tine_, ðlað, kiha
  { {0x412a007c,0x6b891876,0x2bd00037,0x361a0009}},	//   чого_, _lieg, _हमला, _מונד
  { {0x63760164,0xb8930012,0xdee60f10,0x929d0034}},	//   tánd, الفع, нови, _woły
  { {0xc5880020,0x3f9e0039,0x6729004a,0x6b891336}},	//   _rồi_, ītu_, nkej, _nieg
  { {0x3f9e001e,0x612b1652,0xdcf40027,0x7d1c1877}},	// [38a0] ūtu_, _küll, šačk, _pors
  { {0x98a70010,0x6371006f,0x6d4512bd,0x2ba60011}},	//   minė_, våna, giha, कीका
  { {0x7d1c03e4,0x20c90037,0x98a70010,0x8afa007e}},	//   _vors, _राजध, linė_, ּהְי
  { {0xeab20003,0x7d1c0087,0xb605009b,0x298a0001}},	//   اعا_, _wors, _košč, пско_
  { {0xf38a0020,0x98a70010,0x26c2000e,0xef21001e}},	//   _cải_, ninė_, ókom_, _daļā_
  { {0xf1b3000b,0x7bda0028,0xdfd00012,0x80bc0011}},	//   נסו_, yttu, ليت_, ैलें
  { {0xfce3002d,0x7ae41878,0x50b70012,0x30a50024}},	//   _щоро, _obit, ردود_, трів
  { {0x66020013,0x20d20037,0xdb1e0051,0x75d40012}},	//   _prok, _सावध, uupä, نيبا
  { {0x0206007c,0xdb020061,0x657e0061,0xde7a0024}},	//   _язан, mplè, omph, орiї_
  { {0x98a70010,0x7ae41879,0x2e3b0009,0x80a60012}},	//   dinė_, _abit, פגינ, _أمان
  { {0x38610052,0x7d370009,0x645d0060,0x6c5404a5}},	//   ührt_, גניב_, şsin, ткну
  { {0xf09f001a,0x600b0009,0x7bda008e,0x67290064}},	//   _đài_, _מִדְ, rttu, ckej
  { {0x291e046c,0xa5f80001,0x612b0052,0xda030011}},	//   _kota_, _целу_, _füll, लियत_
  { {0x65610149,0xdb020065,0x291e0006,0x44250066}},	//   colh, fsló, _jota_, byl_
  { {0xc6a70046,0x272e0065,0xed620010,0x34fb0009}},	//   ерзи, _sýna_, _mažą_, _מהגד
  { {0x64430002,0x98a70010,0xa7fc0060,0x201e0064}},	//   źnik, binė_, _ayık, ätia_
  { {0x2735006f,0x98a70010,0x61260028,0x290c187a}},	// [38b0] _lång_, cinė_, _eðli, _onda_
  { {0x6376014a,0x48ab0015,0x27270051,0x612b0051}},	//   ráne, _этим_, _mõni_, _külm
  { {0x98c40047,0x6b890039,0x3204002a,0x8cd80037}},	//   _ссыл, _pieg, _army_, _मानो
  { {0xe8d9001a,0x7afd187b,0x290c187c,0xe9d10012}},	//   _tuỳ_, ndst, _anda_, لغت_
  { {0x69dd00b4,0x7aef000d,0x6b89001e,0xceb6000b}},	//   ntse, iect, _vieg, _בפרק_
  { {0xe61f001a,0xa0690400,0x63ba187d,0x01650048}},	//   _ngôi_, мала_, kstn, ъкло
  { {0x629600a2,0x2bc50037,0x7d540001,0x63ba009b}},	//   ıyor, _विधा, _сврх, jstn
  { {0xf38a0020,0x3d0501e1,0xc7b4000b,0x7afd187e}},	//   _tải_, _होते_, אבק_, jdst
  { {0x63ba0026,0xa1950014,0xdb02000e,0x60f50001}},	//   estn, _разч, zsló, _изађ
  { {0xdb020061,0x67290066,0x69cf187f,0x27350262}},	//   mplé, skej, duce, _hånd_
  { {0x27350163,0x7afb1880,0x7afd0070,0x6561000e}},	//   _gång_, _kaut, fdst, rolh
  { {0x7afb0039,0x98a7007a,0x6561000e,0xe627001a}},	//   _jaut, tinė_, solh, _phổ_
  { {0xfeb80003,0x63ba009b,0x39470ca7,0x7aba0009}},	//   _سانت_, astn, oins_, וצרו
  { {0x66060058,0x98a70010,0x7afb1881,0xa021005e}},	//   ække, rinė_, _laut, _ööse
  { {0x290c003a,0xd059002d,0x98a70914,0x69dd1882}},	//   ıda_, ерті_, sinė_, atse
  { {0xed590416,0xc6c30406,0xdb020028,0xe627001a}},	//   drži_, ийск, rsló, _thổ_
  { {0xceb20093,0xb15a0012,0x4d660048,0xb0d20011}},	// [38c0] יין_, _يؤخذ_, вкав, _सालग
  { {0xd5af0003,0xed570001,0x79b7000b,0x19b70009}},	//   تفك_, воу_, _שליד_, _שפיר_
  { {0x69db0663,0x26c2000e,0x80d70037,0x6b5d000e}},	//   _aque, ókok_, _बाते, végz
  { {0x7afb007d,0x291e1883,0xa3d30024,0xab270048}},	//   _caut, _sota_, роїч, коха_
  { {0x7fe20044,0x8c96002d,0x51f30012,0x27350248}},	//   _पहुँ, _арбі, لسور, _sång_
  { {0x394704a4,0x63ba0034,0xdca3070f,0x07e6004c}},	//   gins_, ystn, _вари, вцим
  { {0xd010000a,0x7aef02d1,0x7afb0061,0xb9370009}},	//   صلة_, yect, _faut, כנסו_
  { {0x7afb007a,0xd0070001,0x2ef40001,0xc053000b}},	//   _gaut, ђење_, узир, יזו_
  { {0xe0da0046,0x28d30044,0xc6f70015,0x629e0066}},	//   _ова_, _तालि, тных_, ěpod
  { {0xb4be0037,0x05780012,0x7bde001b,0x21761884}},	//   ेले_, عمدة_, otpu, _рубр
  { {0x3cfa0037,0x7bc8003a,0x5c730015,0xe4ab0009}},	//   _उसने_, urdu, ильт, וֹכָ
  { {0x46a60014,0xfbd30009,0x4dda0012,0xbea60148}},	//   _радв, סתר_, _يوضح_, _радк
  { {0x69dd1885,0x3f800034,0x7bde1886,0x9c7c0159}},	//   utse, dmiu_, htpu, veču
  { {0x69dd0c28,0xf9930009,0xc1050012,0x27310031}},	//   rtse, ירש_, دوسي, _tánc_
  { {0x5577000b,0xe8240024,0x6606008e,0x6d481887}},	//   _שעון_, афто, _arkk, mida
  { {0x63760013,0xa857000b,0x394700c7,0x6d481888}},	//   ránc, דילה_, zins_, lida
  { {0x6d48004a,0x629d000e,0x7db40012,0xd5b10012}},	// [38d0] oida, mcso, لصلا, صفا_
  { {0x9cb50003,0x612b003a,0x7afb0b66,0x63760f9b}},	//   امات, _mülk, _saut, mána
  { {0xe3b00003,0x6376000e,0x6378000e,0x6606019a}},	//   قرن_, lána, zíne, _erkk
  { {0xe3b00003,0xc2c40003,0x92590015,0x629d000e}},	//   ترك_, ليمي, нает_, ncso
  { {0x333c000b,0x6d480bec,0x63760031,0x672d0159}},	//   ותאמ, kida, nána, mkaj
  { {0x30750047,0xe8f80024,0x4dda0009,0x6d4801e3}},	//   луйс, клі_, _אחשו, jida
  { {0x99820066,0xcfa4004c,0xf7450147,0x7afb1889}},	//   zyků_, ашњи, леко, _taut
  { {0x98bc007d,0x39470325,0xdb020061,0x6abf0037}},	//   tivă_, sins_, pplé, ्लोर
  { {0x6376000f,0x4a55002d,0x6d4800c1,0x90e70012}},	//   jána, _скас, fida, _لسان
  { {0x9990000d,0x2369009b,0xacf5004c,0x6ab90132}},	//   şaţi_, _akaj_, учиј, lawf
  { {0x98bc000d,0x3ed50003,0x6b950164,0xb6d50012}},	//   sivă_, _مقار, _juzg, _مقاع
  { {0x25790061,0xf9890009,0x11d60024,0xf8df0011}},	//   dèle_, _זר_, лігр, प्रय
  { {0x2bc50037,0x33200061,0x6376000e,0x0b43002d}},	//   _विवा, _voix_, gána, снян
  { {0xb6020066,0x6d48060e,0x6f1b0027,0xa2ba0037}},	//   čátk, cida, ljuc, ्लङ्
  { {0x3d170037,0xf4840001,0x67170037,0x69cb0052}},	//   नाने_, _кућн, थापक_, hrge
  { {0xd0070046,0x69c40037,0x6f1d0052,0x80cd0011}},	//   ћете_, _रिली, ösch, _साझे
  { {0x6e2900c6,0x635c012e,0xc6920009,0xa3b60011}},	// [38e0] nyeb, nčne, מאן_, चीन_
  { {0xc8d20044,0xdff30321,0xfca90012,0x2a3b0009}},	//   _साइट, _आनंद_, نامو_, _נעימ
  { {0xa3bb0037,0x5aca0109,0x6ab6126b,0xceb90030}},	//   ेंट_, елем_, _keyf, kař_
  { {0x2ca700a2,0xe73a0047,0xda7a0593,0xfa760009}},	//   ında_, _чем_, нял_, ְעַת_
  { {0x59f8005c,0x4e270365,0x82d70009,0x7c280034}},	//   теля_, _боян_, רונג_, zydr
  { {0x6ab60065,0x39990061,0x28df0037,0x6d4b0025}},	//   _leyf, _dès_, प्लि, égat
  { {0x9fe6000a,0x6d480583,0x660403c2,0x8b95027f}},	//   استه, vida, lvik, _вруч
  { {0xb8cb0037,0x48f00011,0x24530012,0x6e3b0032}},	//   _क्_, _इसको_, _انفس, fzub
  { {0x61340054,0x10a60de1,0xc8d60012,0x50d60012}},	//   _càlc, _бизн, _مزاع, _مزار
  { {0x59830015,0x6376000e,0x6d48188a,0x46a40011}},	//   _глуб, vána, uida, _ग्रह
  { {0xb8930351,0x4093000a,0x2458007c,0x3b5501ef}},	//   _المع, _المر, тань_, икор
  { {0xee3a0046,0x8433002d,0x2bc50037,0x4e960003}},	//   _пне_, снює, _विरा, _إشار
  { {0x7c3a000f,0x96b9002d,0xdc27003a,0x6d48188b}},	//   sztr, _руху_, köğr, pida
  { {0x629d000f,0x25790061,0x68fe0054,0x6604188c}},	//   scso, tèle_, _capd, dvik
  { {0x629d0272,0x6376000f,0xf7730003,0xc8d20011}},	//   pcso, sána, مار_, _साईट
  { {0x3d0c0011,0x63760097,0x96f8188d,0x6130188e}},	//   ़ाके_, lánn, лест_, _häll
  { {0x61300163,0x612b0051,0x256f000e,0x6d5d0025}},	// [38f0] _käll, _lüli, lüli_, ésag
  { {0x627c000b,0x3cff0037,0x02e10037,0x61ed002c}},	//   _אנחנ, ईयें_, ग्रह_, _ipal
  { {0xa9260039,0x53a40003,0x768b003a,0x69c00033}},	//   _dažā, مملك, _köyü, _avme
  { {0x2d8e0036,0x637808bf,0xeeab0024,0x929d0034}},	//   _life_, vínc, _яток_, _małg
  { {0x99d7000a,0x62860066,0x69cb0998,0x23160012}},	//   اتصا, _úkol, urge, شيوخ_
  { {0xc0c80046,0xa99c0009,0xfbc50011,0xf9900012}},	//   гуће_, עבור, _विलम, سبه_
  { {0xd8b80003,0x98b1001e,0x47590048,0xaff60012}},	//   ادها_, lizē_, крия_, لفوا_
  { {0x2904001e,0xcf250003,0x99d70012,0x2727005e}},	//   ēmai_, شرعي, _متطا, _tõnu_
  { {0xed590098,0xef160015,0x7d12000e,0xd6e80009}},	//   кои_, рмы_, _újsá, אַתָ
  { {0xd1670098,0xed45002d,0x66060028,0x61fb188f}},	//   _съби, рноп, ækka, _isul
  { {0x61ed00c6,0x99840003,0x610b001e,0x9cd60009}},	//   _apal, _اللو, _vēlē, בותה_
  { {0x8f9a000b,0xe2860103,0x6a860048,0x92a60034}},	//   _סיני, илни, илна, _gałę
  { {0x99800026,0x85c80003,0x61ed0017,0x85a70001}},	//   šiť_, _مِنْ_, çalh, _сјед
  { {0x61300163,0xdb050061,0x03950048,0xdca50ee6}},	//   _gäll, sphè, _крия, _таки
  { {0xa7860003,0xa06a011f,0xdb1b000e,0x29040066}},	//   لشرو, тава_, gutó, ěma_
  { {0x6800000f,0xb6a605cc,0xdb1b01bd,0xd6d20012}},	//   lájá, риал, ysté, تقر_
  { {0x6376048a,0x59760015,0x25bf1890,0x1f630024}},	// [3900] láno, _выну, nsul_, ікум
  { {0x3ead003a,0xda7b000b,0xfc320003,0xc1bb0009}},	//   hbet_, _בנפר, يحا_, _שמיש
  { {0xc5f20044,0x3cdd0037,0x66e611ed,0xd6a50024}},	//   _अन्य_, _खाने_, _кона, _сiчн
  { {0x78bc0005,0x25bf0005,0x7413000a,0x8877000b}},	//   larv, ksul_, توما, _כתיב_
  { {0x6800000e,0x6b820758,0x929b0009,0xd3570009}},	//   kájá, rmog, דינת, סיני_
  { {0x67220051,0xd0d7002d,0x78bc1891,0x58d70024}},	//   _sooj, идії_, narv, идія_
  { {0xc9170009,0x42d60024,0xf8b30009,0x637d0031}},	//   יחסת_, _візу, חשו_, léne
  { {0x6130006f,0x0eea002d,0x96ea0198,0x15d8004c}},	//   _säll, тьки_, тька_, гмић_
  { {0xb5fb000f,0x66e20037,0x99e90012,0x0caa00f5}},	//   _száz, क्षक_, _معلق_, ктни_
  { {0x3f8f1892,0x96a60011,0x89db0009,0x612b005e}},	//   _eigu_, _ट्रॉ, _בחמי, _tüli
  { {0x3ead000f,0x7bc70010,0x63760672,0x0577000b}},	//   bbet_, šjun, ránn, שגים_
  { {0x2d8e002a,0x32090132,0x3dcd1893,0x256f0031}},	//   _wife_, _pray_, brew_, rüli_
  { {0x61300006,0x9da70014,0x2574006f,0x6d400010}},	//   _täll, _къща_, täll_, _įman
  { {0x3869000d,0x2703001a,0x3a24006f,0x59c90011}},	//   şare_, _ổn_, ämpa_, _रिसर
  { {0xed570001,0xad1b0009,0xc57b0009,0xd6db0de1}},	//   _њој_, _בוגר, _שרות, кта_
  { {0x3f8f0065,0x6130019a,0x78bc0cc6,0x20110064}},	//   ögu_, _jälj, aarv, _ázie_
  { {0x637d1007,0xdd910003,0xe3b8003a,0xfdf80011}},	// [3910] géne, سوا_, ayıt_, ्टिस_
  { {0x929d0002,0x52e30011,0xbc070048,0xeca7004c}},	//   _małe, ट्रॉ_, ичей, рјан
  { {0x4427001a,0x443e1894,0x515a0009,0x75880109}},	//   ân_, nzt_, _תכתו, рств_
  { {0x6376000f,0x25a9000e,0x6352001e,0x52150021}},	//   jánl, ppal_, tāni, йдет
  { {0x877a0093,0x2cb80033,0x10a5011f,0xd5b80048}},	//   _תארי, _ferd_, билн, _всс_
  { {0x09f80093,0xe0d8002d,0x29031381,0x63a401bd}},	//   שֶׁר_, иві_, ndja_, _činn
  { {0x01380093,0x2901002b,0x63f40012,0x59c90011}},	//   שרות_, _maha_, _وأفر, _रिवर
  { {0x3eb90656,0x0058000b,0xc7a80003,0xaf020014}},	//   _jest_, ישות_, جدول_, зпъл
  { {0xb882014d,0x929d0002,0x68f5000e,0xd7060015}},	//   _þínu, _całe, kezd, сные_
  { {0xf990000a,0xd7e7007c,0xa0c40003,0x25bf000d}},	//   _قبل_, _відо, _ويقو, rsul_
  { {0x3cfa0037,0xdfa70003,0x3eb90054,0x98a70010}},	//   _उससे_, _ضحاي, _oest_, linį_
  { {0x63760026,0xe6950003,0x5e950003,0x26c2000e}},	//   ráno, _الإد, _الإط, ókot_
  { {0x8e85000a,0x98a70010,0xa6960009,0x78bc1895}},	//   _الشه, ninį_, _הכנה_, tarv
  { {0x7d1c006f,0x6263002d,0xa0a30014,0x753a0480}},	//   örst, ївра, зард, chtz
  { {0x290100a1,0x251a0093,0x1dda0044,0xf1d10037}},	//   _daha_, _תוצא, यूनत, _समझन
  { {0x637d000f,0x6e930003,0xdd920003,0x78bc00e6}},	//   téne, كلفا, كور_, sarv
  { {0x61300006,0x2d9100a2,0x75d60003,0x7bc103ee}},	// [3920] _jälk, _bize_, إيطا, lslu
  { {0x3eb90005,0x98a70010,0x637d000e,0x27e90002}},	//   _eest_, dinį_, réne, łany_
  { {0x0577000a,0x637d000f,0x04570003,0x69c40029}},	//   حملة_, séne, ملكة_, _hvie
  { {0x2cb800bd,0x69c4007a,0x59af0037,0xbaba0003}},	//   _werd_, _kvie, जीकर, اداء_
  { {0xd36f0012,0x98a70073,0x660d0073,0xcec40030}},	//   رهه_, ginį_, _šakn, atří_
  { {0x61300163,0x7bc10010,0x20d60024,0x8b961896}},	//   _sälj, kslu, сідс, _грач
  { {0xb9000044,0x443e0163,0xa7fc003a,0x61e21897}},	//   _था_, _åt_, _ayır, stol
  { {0xc6920009,0x3f840035,0xaac50012,0x98a70073}},	//   ּא֙_, ummu_, _وتقن, binį_
  { {0x61301898,0x8e14002d,0x160b0037,0x612b02f7}},	//   _välj, ідоц, _हज़ार_, _kült
  { {0x443e008b,0xccfa0046,0x6aa400b6,0x45fb0009}},	//   tzt_, ући_, _afif, נהיג
  { {0x29010005,0x78ba0039,0x3f9a0051,0xd7960012}},	//   _raha_, _ietv, _nupu_, _الصخ
  { {0x442c1899,0x3c770009,0xa3e00011,0x443e0032}},	//   ryd_, מתים_, _दमन_, rzt_
  { {0x4f65000a,0x66760003,0x78ba0010,0x443e189a}},	//   _بالف, _ادار, _ketv, szt_
  { {0x3eb90005,0x69c40010,0xcdf70009,0xa9550024}},	//   _sest_, _dvie, _למדי_, ікві
  { {0x3cdd015f,0x7c93000a,0xdbf10013,0x5d470009}},	//   _खाते_, _عشوا, _příj, _לָהּ_
  { {0x2d91189b,0xfc570009,0x7f750024,0x54570009}},	//   _size_, _לבוש_, ігає, _לבוב_
  { {0x29010051,0x612b003a,0x69c001e3,0xd4b9004c}},	// [3930] _taha_, _bült, ámet, илац_
  { {0x78ba00c5,0xdb1e0002,0x3eb91587,0xa2b10011}},	//   _netv, kupó, _west_, ंरक्
  { {0x28d20011,0x69c00035,0x69c4189c,0xf3f90365}},	//   _साजि, šmet, _zvie, рнеш_
  { {0x98a7007a,0xd2510003,0x79c90012,0xa08800af}},	//   tinį_, ونا_, لوصف_, _לְרִ
  { {0x7ccb001e,0x9cb50012,0xe4a7004c,0x9aec0009}},	//   tērē, _ومحت, _грбо, רַבִ
  { {0x612b0052,0x98a70010,0x7bc1189d,0xb9250012}},	//   _gült, rinį_, yslu, تفتي
  { {0x91620020,0xe8090037,0x69a00037,0x272e0028}},	//   _xử_, विधा_, _गंभी, _sýni_
  { {0x249b007a,0xf838000b,0x612b000e,0xdb1b0028}},	//   šymą_, מנות_, _küls, fstí
  { {0xcee80012,0xf8140034,0x200c189e,0xe559004c}},	//   صرين_, ążać_, _erdi_, ијој_
  { {0x7bc100bd,0x6130006f,0x6f04017b,0xe8090011}},	//   tslu, _välk, zdic, विदा_
  { {0x26340020,0xc4d2000b,0xc209000b,0xf8b2000b}},	//   ào_, וגי_, _שה_, _חשב_
  { {0xf8a90093,0x7bc1189f,0xcb6a00f5,0x613d01a0}},	//   _יש_, rslu, раме_, _bèlg
  { {0x9162008a,0x2bc50037,0x4ade0037,0xed4e0048}},	//   _sử_, _विका, फ्टव, _жо_
  { {0x7aed0051,0xb17b006f,0xfc310012,0x25ad0926}},	//   _ebat, stån, _يحث_, mpel_
  { {0x2d9f0061,0xa2e60083,0xd7060695,0xc4f80012}},	//   lque_, _дойд, озви, _دعنا_
  { {0x9182001a,0x256f09c5,0xeafa0012,0xfe050011}},	//   iển_, zült_, _ضربت_, रिंस_
  { {0xa526007c,0xb5a90003,0x69c40029,0xfd4a0001}},	// [3940] омад, مالك_, _uvie, азак_
  { {0x29040039,0xbd83002d,0x9162001a,0x2bed0037}},	//   ēmas_, дгук, _tử_, _जहां_
  { {0x6376000e,0xb8e00011,0x64410032,0x256f0031}},	//   vánj, ुण_, nzli, vült_
  { {0xdb1e0028,0x6da60003,0x386d0052,0xdcb60011}},	//   vupó, _ومجم, ßere_, _आज्ञ
  { {0x394e0061,0xc9f60012,0x386d0060,0xdb210031}},	//   tifs_, تساع, ğere_, áték
  { {0x2574004a,0x6bd60012,0x320d0032,0x14d80009}},	//   käli_, _وتأر, _drey_, _לַֽמ
  { {0xdfd0000a,0x256f000f,0x3ebf0061,0xa2d60003}},	//   رية_, rült_, faut_, _ويست
  { {0xf093000b,0xcf260003,0x7d030070,0x256f000e}},	//   ונו_, ترتي, _aans, sült_
  { {0x7d030101,0xd6770012,0x320d18a0,0x256f0031}},	//   _bans, يحًا_, _grey_, pült_
  { {0xbebd0010,0x2bd10011,0x7d0318a1,0x7c470097}},	//   ukūr, _हिमा, _cans, _úrræ
  { {0x4c9b000b,0x3ebf0052,0xc49b000b,0x29ff0002}},	//   יביו, baut_, ישית, ałać_
  { {0x20110064,0x5334003c,0x635c001b,0x6b9c18a2}},	//   _ázia_, деют, ično, _murg
  { {0xde03011f,0x6441017b,0xed5a0ef0,0x2d9f18a3}},	//   _опци, azli, _код_, cque_
  { {0x6d4a1168,0x72280024,0x16770009,0x3cf60011}},	//   _umfa, іцяв_, _וגדל_, ीयों_
  { {0x28dc0037,0x6b9c0051,0x2731001a,0x2f190015}},	//   _बारि, _nurg, _bánh_, бовь_
  { {0x4c3b015a,0x273116b6,0x291e0248,0x2fcd001b}},	//   _כתוב, _cánh_, ötar_, čeg_
  { {0x7d03003a,0x9ae8000b,0xdddd001e,0xd49b1496}},	// [3950] _yans, _וַתִ, _izsū, аре_
  { {0xdfdb0098,0x91820020,0x63a40027,0xa4d40024}},	//   _към_, yển_, _činj, дофі
  { {0xa2f5059a,0x70fa000b,0x60fa000b,0xdc98002d}},	//   зпеч, _ההתח, _ההתק, івці_
  { {0x8c1b000b,0xad9b18a4,0x320d0132,0xc2c50012}},	//   יובי, _csúc, _prey_, سيتي
  { {0x7e7d001e,0xe9d80024,0xe4d70012,0x6d58001b}},	//   _uzsp, жкі_, _وتسب, čvar
  { {0x68f80051,0x82340012,0x7bc70031,0xe1880012}},	//   gevd, برما, ájuk, يئون_
  { {0x6abb0052,0x7d0318a5,0xc9540009,0x8fa204a5}},	//   _teuf, _rans, ומס_, наще
  { {0x637613b4,0x613002bd,0xdcfd0010,0x66090191}},	//   ránk, _väli, _pusė, tvek
  { {0x7d0318a6,0x30e70024,0x3ebf18a7,0x998c0034}},	//   _pans, _міжб, raut_, ądź_
  { {0x6441008b,0x637618a8,0x1c450055,0xa4450015}},	//   tzli, pánk, зном, знод
  { {0x29ff003e,0x929d0002,0xd4690001,0x2d9f18a9}},	//   słać_, _zała, сине_, sque_
  { {0xf1cf0037,0xa088000b,0x2d990aa1,0x29050091}},	//   _हटान, _וְנִ, íses_, _hala_
  { {0x2d83004a,0x5e9a000b,0x7d0318aa,0x969a0009}},	//   _ohje_, _הבנק, _tans, _השנה
  { {0x27310020,0x290713bc,0x7d030260,0xc5680012}},	//   _sánh_, ndna_, _uans, _وحول_
  { {0x7b05004a,0xb4d70011,0x9bc90012,0x290518ab}},	//   öttä, िली_, _اوبك_, _mala_
  { {0x6e960003,0x1dc70011,0xc6920012,0x63520035}},	//   سلطا, _लिखत, ِّر_, rāns
  { {0xf772000b,0x8b3b000b,0x26c000c1,0xd3570009}},	// [3960] תקן_, _לתקצ, raio_, _מיקי_
  { {0x6b9c0108,0xa91c0029,0xee370129,0x649a0dd8}},	//   _purg, _ohľa, чну_, стар_
  { {0x309b000b,0x69d90070,0xf8b30009,0x78fb0009}},	//   _לשימ, euwe, _אשת_, _פלטפ
  { {0x23a10002,0x63780066,0x6b9c003a,0xc8dc0037}},	//   _mój_, mínk, _vurg, _बाँट
  { {0x63760164,0xdb0200b0,0xdb1b005e,0xceb30009}},	//   gáni, pplæ, putö, _ריש_
  { {0x29fd0029,0x9f5e0029,0x98a40010,0xdb1b18ac}},	//   _dňa_, _isté_, ėmė_, istá
  { {0x3b0a010b,0xb4ca0011,0x80a30012,0x7c650012}},	//   _лево_, ोली_, رمين, _قافل
  { {0xf093000b,0xa6140345,0x5c5b0009,0xe80d0011}},	//   ענה_, дмич, _הדלק, हिता_
  { {0xb0dc0037,0x7d6a002d,0x69c60aa3,0x290518ad}},	//   _बांग, йшов_, jske, _fala_
  { {0x9a3b000b,0xaa3b000b,0x3f9a000e,0x2a3b0009}},	//   _התמק, _התמח, ípus_, _העממ
  { {0x44440d26,0xa438002d,0xd6cf0695,0xf1d20011}},	//   nz_, ізму_, _пт_, _सिडन
  { {0xaf05002d,0x444418ae,0x69c618af,0x547b0009}},	//   _очік, iz_, fske, מטיו
  { {0x6e93000a,0xc333000b,0x3e850061,0x5187077e}},	//   _كلما, גור_, rêté_, зува
  { {0xf6170093,0x2bc50044,0x45fb0009,0x3f9e1448}},	//   _מחדש_, _विचा, _להדג, _kutu_
  { {0x69d90052,0x85030012,0x5bc30012,0x4ccb0009}},	//   zuwe, _سوين, _كقول, _הֶחֱ
  { {0x444418b0,0x3f9e18b1,0x6c5b0009,0x637d18b2}},	//   dz_, _mutu_, _לדוח, méno
  { {0xa3d40037,0x7bda18b3,0x69da0034,0x69c600e9}},	// [3970] िंक_, lutu, ątec, cske
  { {0x272e0028,0x2a58000b,0x19bc0009,0x91bc0009}},	//   _sýnt_, _מבחן_, _המזב, _המזי
  { {0x25f90044,0xe570000a,0xdc9b000b,0x629a0066}},	//   _उनकी_, اطق_, ציאל, ětov
  { {0xfbd00003,0x6d4e18b4,0x2bb80012,0x42550012}},	//   اتل_, _emba, سامة_, ونار
  { {0x7bda0051,0xdd910012,0xa3cf0011,0xdcfe004b}},	//   hutu, _لوح_, _शिव_, umpă
  { {0x7bda03d5,0x637618b5,0xd9980012,0x2d9d0227}},	//   kutu, ráni, سخها_, _ruwe_
  { {0x4444003e,0xccf2000b,0x7bda0051,0xdb1b0028}},	//   cz_, _שכל_, jutu, mstæ
  { {0x05a9007c,0x29050101,0xeab30003,0xee390103}},	//   овий_, _wala_, _سعر_, жни_
  { {0x290518b6,0x61300032,0x6d8909ef,0x0d850198}},	//   _tala_, _kält, _užas, млин
  { {0xb4d70037,0x273c0028,0x69c618b7,0xb9c40012}},	//   िले_, _mína_, vske, _أقلي
  { {0xa3d40044,0x273c0028,0x7bda0051,0x660d005e}},	//   िंग_, _lína_, gutu, hvak
  { {0x60c30893,0x2b160014,0xd3680009,0x929d0034}},	//   lanm, фьор, ִים֙_, _mało
  { {0xe56e0098,0xba23002d,0x127a0012,0x25fd0011}},	//   _аз_, вдяк, تحدث_, _रैली_
  { {0x7bda18b8,0x659a0009,0xc5650012,0x6d9a0009}},	//   butu, _ויסק, _تُتي, _ובספ
  { {0x660d0070,0x66e60447,0x39440010,0xdff501ec}},	//   evak, мова, ėms_, нять
  { {0x25740052,0x44440010,0x69c618b7,0xbb860012}},	//   hält_, vz_, pske, _تلبي
  { {0xcb130009,0xdb1b0097,0xb6060097,0x63a418b9}},	// [3980] _ילה_, fstæ, mráð, _čini
  { {0x63780149,0x44440f5c,0xa9e50012,0xf9860024}},	//   míni, tz_, _أثين, _ігно
  { {0xf993000b,0x68fc00b6,0xdb02006f,0x929d0002}},	//   _שרת_, merd, pplä, _cało
  { {0x3cfa0044,0x444409c1,0x68fc18ba,0xc7b30009}},	//   _उसके_, rz_, lerd, _שבר_
  { {0x25740163,0x44440d23,0x6130006f,0x6368003a}},	//   fält_, sz_, _fält, mınd
  { {0xda650003,0x6368003a,0x7bda003a,0xf653000b}},	//   راني, lınd, yutu, _יצר_
  { {0x2b0e0044,0xd0100003,0x6130006f,0xf957000b}},	//   ियाँ_, الب_, _häls, וססת_
  { {0x636800a2,0x7bda0269,0x60090009,0x2d9818bb}},	//   nınd, vutu, לִפְ, _hire_
  { {0x929d0002,0x10a6035b,0x89d70012,0x80c10011}},	//   _zało, _жизн, _يوفر_, वरमे
  { {0xe0d70046,0x6f090a9a,0x81f70012,0xbd870012}},	//   _ову_, adec, _تفكر_, ونين_
  { {0x672b000f,0x718b000b,0x6368003a,0x99800010}},	//   _fogj, _וְאַ, kınd, šių_
  { {0x2bd10037,0x2cb1003a,0x2d9818bc,0xd5ba0048}},	//   _हिसा, ızda_, _lire_, _дск_
  { {0x7bda0005,0xd3790027,0x6368003a,0x63760028}},	//   sutu, juće_, dınd, jánu
  { {0x6d41008b,0xd3790027,0xa5070001,0x68fc18bd}},	//   chla, duće_, _жеља_, gerd
  { {0xa3cb015f,0x636800a2,0xf7730003,0x5c060014}},	//   _लिए_, fınd, نار_, _цяла
  { {0x60c3003a,0x2f18002d,0x2d9818be,0x660d18bf}},	//   zanm, мось_, _aire_, tvak
  { {0xd379001c,0xf38a0081,0x63780018,0x60c30060}},	// [3990] guće_, _nảy_, cíni, yanm
  { {0x69dd18c0,0x02160009,0x5d780009,0xd5780009}},	//   muse, _נחתם_, פָּנ, פָּר
  { {0x69dd0005,0x2d980edb,0x6368003a,0x61300038}},	//   luse, _dire_, bınd, _vält
  { {0xf38a001a,0x6368003a,0x8b94002d,0xdb1b0028}},	//   _bảy_, cınd, вріч, sstæ
  { {0x69dd0005,0xa294002d,0xfe08001a,0x6130004a}},	//   nuse, ваці, _nữ_, _tält
  { {0xdb1b0c60,0xaa560012,0x3ea9004b,0xdb1c0248}},	//   lstä, علوا_, lcat_, _avrä
  { {0x6f090052,0x2d4f0002,0x60c30792,0x7afd18c1}},	//   tdec, yżej_, ranm, kest
  { {0xdb1b18c2,0x26c4009b,0x60c30058,0x6605003c}},	//   nstä, gamo_, sanm, епиа
  { {0x29d5000a,0x9f470026,0x3171000e,0x60c30060}},	//   _سياس, ntné_, kozz_, panm
  { {0xfe080020,0x69dd18c3,0x142503cd,0x63680060}},	//   _dữ_, duse, едом, zınd
  { {0xdb1b006f,0x6368003a,0x69dd0061,0x6d410028}},	//   kstä, yınd, euse, rhla
  { {0x3f99001c,0x9f470029,0x9f050012,0x794d0034}},	//   _nisu_, ktné_, _سوتو, dźwi
  { {0x69dd0005,0xdb050065,0x8de40003,0xf38a001a}},	//   guse, pphæ, _لكنه, _xảy_
  { {0xf1b20093,0x06560093,0x260c0011,0x6e2001a0}},	//   רסם_, _אינך_, ़िरी_, _àmbi
  { {0x636800a2,0x2d980061,0xe4650051,0x99890034}},	//   tınd, _rire_, ööde_, _brał_
  { {0x613403eb,0x7afd18c4,0x539a0009,0x05aa0048}},	//   _vàli, cest, _ציפו, звай_
  { {0x636800a2,0xceb2000b,0x3619000b,0xdce8001e}},	// [39a0] rınd, טין_, הוּד, lodā
  { {0x636800a2,0xec090020,0x61300248,0x6d860097}},	//   sınd, _kế_, _väls, rðag
  { {0xccf2000b,0x2b40009b,0x6368003a,0xeb9a02ad}},	//   רכב_, _klic_, pınd, чие_
  { {0x2bd10037,0x2d980132,0x99890034,0x2a3a0009}},	//   _हिरा, _wire_, _grał_, ּעַמ
  { {0x2d87008b,0x635c009b,0x200500b6,0x26c418c5}},	//   _ohne_, nčni, _asli_, vamo_
  { {0x7afd003e,0x49370024,0xdbc7005e,0xdb1b18c6}},	//   zest, нзію_, _rööv, mstå
  { {0x7afd0119,0x91620020,0x2246000e,0x9182001a}},	//   yest, _cứ_, szok_, iền_
  { {0x60c10005,0x77f7000b,0x80030015,0xdb0e006f}},	//   _eelm, תמקד_, учше, _avbö
  { {0x9162008a,0xe357000b,0xcb670015,0x60c111a6}},	//   _từ_, _נשמח_, _чате_, _felm
  { {0x69dd0005,0xa3cb0037,0x60c1003a,0x9f5e0029}},	//   vuse, _लिख_, _gelm, _istí_
  { {0x628400c1,0x3f86002a,0xdb1b18c7,0xdfcf0003}},	//   _azio, _thou_, irtö, _هيل_
  { {0x3f53007d,0xdbc70051,0x69dd18c8,0x7afd086c}},	//   nţul_, _tööv, tuse, uest
  { {0x75d30003,0xdb1b006f,0xd1380034,0x63760bf4}},	//   _مينا, vstä, _ciąg_, vánt
  { {0xa4d4007c,0x3f990005,0x7afd0b38,0x69dd18c9}},	//   _рокі, _sisu_, sest, ruse
  { {0x69dd0005,0x8f870001,0x7535000e,0xd7f8072b}},	//   suse, ећал, özze, нут_
  { {0x6c7b000b,0x447b000b,0xe47b0009,0x747b0009}},	//   _מאופ, _מנוע, _מרוכ, _מנוג
  { {0x3f990039,0xa5f8002d,0xdb1b18c2,0x80e00037}},	// [39b0] _visu_, нету_, rstä, नलाइ
  { {0xbd78002d,0x9f470029,0xdb1b0c60,0x1be40011}},	//   ебує_, rtné_, sstä, _कमाल_
  { {0x5996000b,0x9f4701e9,0x9c190012,0x9cd70009}},	//   _שכתב_, stné_, بياء_, תובה_
  { {0xd6db00e3,0x7ae200c6,0x92590015,0x2b1a0037}},	//   _это_, ggot, мает_, धाएँ_
  { {0x799a0002,0xd7f8000d,0x7bde0df5,0x39840248}},	//   _bitw, _apă_, aupu, lösa_
  { {0xb9b2000a,0xd184002d,0x7ae2009b,0x7d0a00b6}},	//   جموع, глій, agot, _nafs
  { {0xe814015f,0x60c10013,0xb8140037,0xc918000b}},	//   डिया_, _velm, डियम_, תחות_
  { {0x27e7006f,0xa3b80012,0x91820081,0x64480035}},	//   _ännu_, _سافر_, iến_, dzdi
  { {0x91820020,0x5f760003,0x3b640014,0xd7060015}},	//   yền_, خميس_, _сърв, тные_
  { {0x29cd0026,0x80a40003,0xdb050052,0xf1c80003}},	//   dľa_, _ممكن, sphä, _أولى_
  { {0xcb6a0489,0x29cd0064,0x69cb0529,0x6f1d18ca}},	//   дане_, eľa_, lsge, _onsc
  { {0x3cdd0037,0x6376000e,0x69d918cb,0x628400b8}},	//   _खाके_, váns, orwe, _pzio
  { {0x8f36000b,0x99f50024,0x69cb017e,0x613401a0}},	//   _שאנו_, лярі, nsge, _vàlv
  { {0x49990047,0xec090020,0x23d10044,0x6f1d008b}},	//   ется_, _tế_, _हिंद, _ansc
  { {0x929d0002,0x7f440061,0x8c42004d,0xc7ac0009}},	//   _całk, thiq, _веще, ּׁמָ
  { {0xd36f000a,0x41d20037,0x673b0404,0xdb1b013f}},	//   _وهو_, _सिलस, nkuj, tstå
  { {0xdca6035c,0x76490060,0xdd920012,0x63a318cc}},	// [39c0] вази, nzey, لور_, _hunn
  { {0x6c960012,0x673b005e,0x62a30035,0x045a0012}},	//   نشاط, hkuj, āvoš, وجات_
  { {0x7f440108,0xfba9002d,0x673b00ff,0xd7ca0012}},	//   phiq, етій_, kkuj, _توجه_
  { {0x6b890149,0x7ae20010,0x799a002c,0xdb1b021e}},	//   _cheg, ugot, _sitw, pstå
  { {0xe2970001,0x7bde0801,0xcb130009,0x21f40012}},	//   вац_, supu, ילא_, اكتس
  { {0x4973007c,0xd12f0003,0x6d450052,0x7bde18cd}},	//   аліс, يمن_, chha, pupu
  { {0xd6d90034,0x98a3004c,0x7af60ca4,0x63a318ce}},	//   liły_, шије, _obyt, _nunn
  { {0x6b9b00c1,0x831a0003,0xd6d00003,0x60c7001b}},	//   _giug, _تقرر_, حقة_, zajm
  { {0xe9a60098,0xd3790027,0x52d70009,0x6467004b}},	//   _разп, juća_, _שומע_, ăriţ
  { {0x91620020,0x91820020,0x636800a2,0x799a0070}},	//   _dữ_, yến_, yınc, _uitw
  { {0x44270024,0x27380097,0x63a318cf,0x6c540198}},	//   вцям_, _léni_, _cunn, укну
  { {0xfd610020,0xee3a0001,0x54530014,0x00570009}},	//   _quyế, _оне_, рвют, _בשבת_
  { {0x290c03a4,0x7d0a00b6,0xa5f80001,0xd379001b}},	//   _kada_, _tafs, _челу_, guća_
  { {0x672f0002,0x6f00003a,0x63a318d0,0x66040034}},	//   _socj, lemc, _funn, dwik
  { {0xfd610020,0x3cfb000b,0xc058002d,0xcfa4010b}},	//   _tuyế, _חלונ, віт_, ишти
  { {0x7b140014,0xd6d818d1,0x88bc0030,0x63680060}},	//   _вдъх, кту_, _hněd, rınc
  { {0xc299007c,0x5f94002d,0xa634002d,0x69c00018}},	// [39d0] _яких_, ритт, анті, âmet
  { {0xf8b7015f,0xc5340009,0xb0b70011,0x50b70011}},	//   _अभिय, נָּה_, _अभिग, _अभिष
  { {0xc7ab0003,0x7afa000e,0x403509cc,0xd8790012}},	//   _تدخل_, őtte, _сенс, _سمحت_
  { {0x6f1d03c0,0x5db70012,0x73e40024,0x6f000c51}},	//   _unsc, _لإسر, роїз, jemc
  { {0x69cb0052,0x637d0c70,0x66f60009,0x1959003c}},	//   usge, géni, _גמרא_, нады_
  { {0x69cb00c7,0x290c18d2,0xbfc40030,0x6441005e}},	//   rsge, _cada_, řížs, _ülio
  { {0xd0f80093,0x6d55003a,0x6ff50012,0xf7f50012}},	//   דמות_, _imza, استط, استد
  { {0x63a30cc8,0xaff60003,0x69cb0070,0x59c50012}},	//   _runn, افيا_, psge, _ميرك
  { {0x99d90003,0x64a5010b,0x229400fa,0x80a60011}},	//   _سواء_, лапа, _витя, _क़्वे
  { {0x9f5e03eb,0x290c001e,0x60c50052,0xbd450012}},	//   _està_, _gada_, _nehm, اندي
  { {0xf8b2000b,0xccf80030,0x2d9c18bb,0xd6d90034}},	//   _השב_, mněl_, _dive_, ziły_
  { {0x07090012,0x3f47005e,0xa3f60009,0x63a318d3}},	//   _سيتي_, _jõud_, נמרק_, _vunn
  { {0x9f470013,0x2d9c0036,0xa142001e,0x290c003a}},	//   ntní_, _five_, _šķie, _yada_
  { {0x2d9c06a3,0x63a302bd,0x06e30037,0x98760001}},	//   _give_, _tunn, _गाँव_, губљ
  { {0xd6d90002,0x7d0118d4,0xd379001b,0x186718d5}},	//   wiły_, mels, suća_, гари_
  { {0x7d0100c5,0x290c001c,0x660400bd,0x9f470066}},	//   lels, žda_, twik, ktní_
  { {0x03210011,0x05660048,0xb5a90012,0x9da60012}},	// [39e0] यारह_, гван, نالك_, اصره
  { {0x7e7d18d6,0xe3b80060,0x64640073,0x2d9c18d7}},	//   _dysp, _çık_, štiš, öve_
  { {0xdd8f000a,0xe4a8000b,0x9f5e000e,0x06e30011}},	//   أول_, דֹנָ, ító_, _गांव_
  { {0xbae5002d,0x637d000e,0x290c09b5,0xb7db0009}},	//   ицій, téni, _sada_, _אקטי
  { {0x290c00ec,0x599a000b,0xda770048,0x7d0118d8}},	//   _pada_, ֲשֶׁ, ляш_, kels
  { {0x3f800054,0xc5ff001e,0x7d010572,0x1c040011}},	//   lliu_, ģētu_, jels, रबदल_
  { {0x656b000e,0xd0100012,0x6f0018d9,0x99820073}},	//   éghe, زلة_, temc, lykų_
  { {0x8c1b000b,0xa8170012,0x7d01005e,0xd6d90034}},	//   _אולי, اتور_, eels, ykłe_
  { {0x290c18da,0xe4c60015,0xdb1b014f,0xba090012}},	//   _tada_, лённ, mstø, _لتلك_
  { {0xbdf70003,0x5f160011,0xa976004c,0x21760472}},	//   اريا_, _पोस्_, _субј, _субр
  { {0x4917000b,0xb9930003,0x51930003,0x9f5e0583}},	//   _תקבל_, _اللب, _اللذ, _está_
  { {0x41e7002d,0x63680060,0xbea60198,0x929505c8}},	//   ліга, tına, _садк, ианц
  { {0xd357000b,0x2d9c0018,0x36360012,0x61e20e25}},	//   ריכי_, _tive_, _حراس, nuol
  { {0xdd900012,0xdd8f0012,0x273c0081,0x63680060}},	//   _بوت_, _فون_, _hính_, rına
  { {0xa2c70037,0xdfd80014,0x273c001a,0x65570009}},	//   ारम्, лът_, _kính_, _תבוא_
  { {0x1fb4003c,0x8c1b0009,0x63680060,0x18470009}},	//   ссёр, _טווי, pına, רְךָ_
  { {0x6d48004a,0x3f470051,0xc4db0001,0x6d5a0872}},	// [39f0] ohda, _nõue_, еђе_, oita
  { {0x273c001a,0xf8c60011,0x16370009,0x3f800073}},	//   _lính_, वरणय, אנמר_, aliu_
  { {0x2d4f003e,0x04db000b,0x7e7d0002,0x3f800054}},	//   dżet_, תקבל, _wysp, bliu_
  { {0xb17b006f,0xd2150001,0xaab50011,0x6441005e}},	//   fråg, имећ, ंडिक, _ülim
  { {0x6d5a18db,0x20c90012,0x80e50012,0x90c501c6}},	//   kita, نبغي_, لأغل, абле
  { {0x26c90027,0x9f470030,0x6d5a06a7,0x672d18dc}},	//   _žao_, rtní_, jita, ljaj
  { {0x9f470013,0xb17b18dd,0xe7310003,0x7d010828}},	//   stní_, mråd, قصة_, vels
  { {0x6d5a0065,0xdb1e006f,0xb17b18de,0x672d18df}},	//   eita, tspå, lråd, njaj
  { {0x3f830039,0x3255002d,0xf5050014,0x6f0f03c1}},	//   ēju_, _твар, азпо, _macc
  { {0x5a340001,0x6d5a18e0,0x851f0011,0xdd8e0012}},	//   _унут, gita, बाइट_, ووي_
  { {0xdb1e006f,0xd469096e,0x290318e1,0x33660a2c}},	//   sspå, тине_, deja_, ивог
  { {0x17f80003,0xe1e70003,0x6d860097,0x2cb80060}},	//   _حركة_, يس_, rðaa, ırda_
  { {0xf770000a,0x672d18e2,0x8b670024,0xe3b80060}},	//   _عام_, djaj, рияв_, apı_
  { {0x186a002d,0x29030269,0x16640024,0xa06a0198}},	//   ваги_, geja_, _увім, вага_
  { {0x63a7009b,0x1fb5002d,0x97d90198,0x9756004c}},	//   _nujn, йстр, льту_, атаљ
  { {0x6f0f00c1,0xdfa50003,0x24a70010,0xf8630024}},	//   _cacc, صحفي, šumą_, івто
  { {0x6d860028,0x7b080035,0x6e3b016d,0x5de60024}},	// [3a00] iðan, āstī, nyub, ржза
  { {0x8cb60014,0x443a18e3,0xf53f18e4,0x75d30012}},	//   рсач, typ_, _står_, زيما
  { {0x05770003,0x35da0037,0xd8db000b,0x6c4a0003}},	//   جملة_, यूज़, _בקיר, خلاف_
  { {0x6d5a007d,0x69c40002,0x501b0009,0x394518e5}},	//   zita, _kwie, _סוכו, _alls_
  { {0xdb1b024c,0x7c3a0002,0x2bd80011,0xdebb0009}},	//   rstø, zytr, _डिवा, _במכל
  { {0x6f04008b,0x4153002d,0xf1c20010,0xb9530024}},	//   leic, овіс, višą_, овіщ
  { {0xb8070003,0xe758002d,0xa0070003,0xcae60011}},	//   ليوم_, ликі_, لقول_, _कांड_
  { {0x61e20006,0x39450054,0x69c40002,0x3ea20033}},	//   puol, _ells_, _owie, økt_
  { {0x386d00a2,0x48e60047,0xe297002d,0x5d540014}},	//   ğeri_, _возв, _ват_, йкит
  { {0xc5f3000b,0x23660027,0xf5310009,0x25a600b8}},	//   קדת_, lnoj_, ִ֥י_, _vuol_
  { {0x273c0020,0x04580003,0xa3c90011,0x637d0031}},	//   _tính_, الجة_, लीप_, ként
  { {0xdb020065,0x883b0009,0x29110034,0x6b8218e6}},	//   pplý, _שתאו, wdza_, nlog
  { {0x64450005,0x6f0f0dc5,0xdb090052,0x05b40012}},	//   _ühin, _racc, _ließ, _امتح
  { {0xd5fb000b,0xf9890012,0x69c40034,0x63780031}},	//   _ספור, انسي_, _dwie, zínp
  { {0x6f0f00c1,0x60c818e7,0xe5710009,0x18980012}},	//   _pacc, _medm, _מַה_, لضفة_
  { {0x290318e8,0xdc9b007e,0xddc40002,0x23660027}},	//   seja_, _ביול, dził, jnoj_
  { {0xa3c90037,0x6b820133,0x23660027,0x2d4f0002}},	// [3a10] लीन_, dlog, dnoj_, dżer_
  { {0x64410005,0x4a7c000b,0xb8590003,0xa3bb0003}},	//   _ülik, _ברחב, _ملخص_, ناصر_
  { {0xbca40003,0x6368003a,0x69c40112,0xf4590012}},	//   زمني, kınl, _zwie, دلاع_
  { {0xc7b2000b,0x9f470064,0x99d50012,0x59d50012}},	//   _מבט_, ktná_, متتا, مغتر
  { {0x6d5818e9,0x6368003a,0xf8b40037,0xde640048}},	//   _omva, dınl, ुरूप, _дърп
  { {0x2bac0066,0xdb07006f,0xa069028b,0x6b821468}},	//   _něco_, _stjä, лала_, alog
  { {0x98f40003,0xc0d80009,0x10150012,0x2366001b}},	//   تثنا, שֵׂה_, إبتد, bnoj_
  { {0x75350272,0x6b820054,0x929d0034,0xdb040031}},	//   _hozz, clog, _bałt, _tuné
  { {0x6d860065,0x66ef0011,0xf1c60011,0xe5790048}},	//   rðan, _छानक_, रीदन, лзи_
  { {0x6f04008b,0x99850003,0xcc350003,0xa5090001}},	//   zeic, _الطو, مرجع, ћена_
  { {0xeb9a05fb,0xc2090009,0xe9df01e3,0x661608ca}},	//   лио_, _רה_, erú_, zvyk
  { {0x1b4a004c,0xdb070248,0xa3c905f3,0x870403d2}},	//   узми_, _utjä, लीय_, _мяче
  { {0xd774000a,0x5f740003,0x3ebf00b6,0x8f9a000b}},	//   _بالع, _بالر, mbut_, _עיני
  { {0x9f5e004a,0x98ac001e,0x6f040052,0x6b82013a}},	//   _estä_, _kodā_, weic, zlog
  { {0x6f040039,0xa7860003,0x7aed004a,0x637d0649}},	//   teic, مشرو, ältö, tént
  { {0x27ea0058,0x69c40002,0x03d6000b,0x4c3a0009}},	//   _åbne_, _twie, _הוקם_, _תתקב
  { {0x6f04008b,0x99d60003,0x23660027,0x69c40002}},	// [3a20] reic, _اتبا, vnoj_, _uwie
  { {0x6d4118ea,0x5bc60003,0xd2570009,0x7afb18eb}},	//   nkla, متصف, _לשפה_, _abut
  { {0x636800a2,0x61e6003a,0x23660027,0x6f040052}},	//   yınl, lukl, tnoj_, peic
  { {0xf0930093,0xd379002d,0x2b210037,0x4df90037}},	//   _מנת_, ачі_, याएँ_, ्बाई_
  { {0xa2aa0044,0x23660027,0xb3470017,0x26c018ec}},	//   टशब्, rnoj_, luçõ, mbio_
  { {0x23660027,0x26c00010,0x3ebf0054,0xe9180024}},	//   snoj_, lbio_, ebut_, рокі_
  { {0x395c006f,0x62800002,0x63a000b6,0x6d5e18ed}},	//   rivs_, _wymo, _timn, mipa
  { {0x6d5e18ee,0xa3e60011,0x04570012,0xbdb4004c}},	//   lipa, यंस_, _طلقة_, обиј
  { {0xc2460001,0xad260012,0x3f47005e,0x7c3e0111}},	//   _унак, مردو, _jõua_, lypr
  { {0x61e6003a,0xdb23000e,0x03f80001,0xf1bf0066}},	//   dukl, öröl, аној_, ášen_
  { {0xdefa0047,0x3086000a,0x929d0002,0x9f4701e9}},	//   _был_, _الاف, _fałs, stná_
  { {0x6d4118ef,0x8c1b0009,0x6d5e07f8,0xb3470018}},	//   akla, אוטי, hipa, duçõ
  { {0x4427008a,0x6e96000a,0x6d5e18f0,0x6130004a}},	//   ̣n_, _الشا, kipa, _häly
  { {0xd0060003,0x6d4118f1,0x273c0028,0xdb1b0032}},	//   ول_, ckla, _mínu_, lstü
  { {0x273c0028,0xc0510009,0xc7d80009,0xa8990560}},	//   _línu_, ֵ֖ל_, יַּכ, ркву_
  { {0x3ceb0037,0x7eb90014,0x66f80011,0xf62b0024}},	//   _चाहे_, ргас_, ंभिक_, лізи_
  { {0x54a70003,0x61e6003a,0x6ca70012,0x443e18f2}},	// [3a30] محاف, cukl, مصال, lyt_
  { {0x85050003,0x3cb8000b,0x4c4b0015,0x98c7004d}},	//   توطن, שֶּׁ, ляем_, _усил
  { {0x6355002d,0xbc680003,0x26c000c1,0x65680058}},	//   овжу, ممكن_, bbio_, indh
  { {0x6d5e002c,0x648b0009,0x8c1b0009,0x7d050032}},	//   aipa, רְמְ, טובי, sehs
  { {0x443e004a,0x6d5e005e,0xdb1b0097,0x6d4118f3}},	//   hyt_, bipa, lstó, ykla
  { {0xa5bb0065,0x2b4901a0,0x27150081,0xa7b5004c}},	//   _próf, _llac_, _ền_, осиј
  { {0x6d860065,0xe7d50024,0xd7ee0012,0x61e60f1f}},	//   rðal, цілю, نكو_, zukl
  { {0x1dd40037,0x63b80029,0xe73900de,0xd00e0012}},	//   _दिखत, ívne, реи_, ئلي_
  { {0xf1e00037,0x05a60015,0x63aa0052,0xee360015}},	//   _नियन, овый_, _aufn, жны_
  { {0x95550003,0x05760003,0x7a880009,0x7d760012}},	//   تخبا, يمية_, _הָעַ, يمير_
  { {0xf6d5002d,0xe29f0028,0x290718f4,0x25a30227}},	//   _діля, veða_, mena_, _mijl_
  { {0xf7700351,0xa3e10044,0x98a50002,0x6d5e0ee0}},	//   _كان_, _दिन_, _rolę_, zipa
  { {0x6d4b001e,0x07080012,0x7c3e0034,0xcb880009}},	//   īgaj, _ديني_, zypr, מְשֹ
  { {0x3cf50037,0x5a9a000b,0x31af003a,0x59990009}},	//   ीजों_, ישרא, _düz_, ישָׁ
  { {0xa0a30046,0xe73a0593,0x23760012,0x7b760012}},	//   дард, аев_, _وابح, _وطبا
  { {0x661d012e,0xb3470017,0x77690207,0x236d009b}},	//   _brsk, ruçõ, nnex, _njej_
  { {0x9f4b0028,0xecba0012,0x98a50034,0x29130248}},	// [3a40] ðmát_, لطات_, _wolę_, _faxa_
  { {0x63a40051,0xf1b905b1,0x290718f5,0x27e70097}},	//   _hiin, íše_, jena_, kunn_
  { {0x63a40006,0xf81e0002,0x273c0028,0x386d0052}},	//   _kiin, ążkę_, _sínu_, ßert_
  { {0x80ba0037,0x31af003a,0x032602ad,0x8a460012}},	//   ्रवे, _yüz_, юден, يَان
  { {0xcb070003,0x63a40269,0x2d090011,0x443e0034}},	//   زيون_, _miin, _वसूल_, zyt_
  { {0x61430015,0x69db0037,0x63a40051,0x4d780009}},	//   меча, _निरी, _liin, _הָֽא
  { {0x98be007d,0x9f5e0029,0x74160012,0x443e0040}},	//   _altă_, _istú_, _بوزا, _æt_
  { {0x442000f1,0x6d860028,0x973c001b,0x443e008e}},	//   _či_, rðam, _kući, vyt_
  { {0xdb1b008b,0xcf93000b,0x28bf0037,0x290718f6}},	//   rstü, וטה_, ्रमि, bena_
  { {0x443e0006,0xdd900003,0xb6030029,0x62590024}},	//   tyt_, عود_, úšaj, _урср_
  { {0xd6cf18f7,0x2018000e,0xf19b0009,0x2b490278}},	//   _от_, _éri_, _כשמש, _plac_
  { {0x8cba0037,0x273c0028,0xbe160012,0x74ba0011}},	//   _श्रो, _míns_, _ووضع, _श्रृ
  { {0xf2d3000b,0x63a400b6,0xdb9b0009,0x539b0009}},	//   וער_, _diin, יסטר, יסטא
  { {0x3c460003,0xdc2a0012,0x6f160034,0xdb1b0097}},	//   _وَإِ, _نسبه_, edyc, tstó
  { {0x63a4000d,0xb4d60037,0xa157000b,0x4cbb0009}},	//   _fiin, िणी_, קבלה_, _דמוג
  { {0x7d080058,0x290718f8,0xb7db0009,0xfebb0012}},	//   leds, zena_, יקלי, شارت_
  { {0xd379001c,0x25a30070,0xa3e60011,0x7afb005e}},	// [3a50] jući_, _pijl_, यूर_, õutu
  { {0x6ac30037,0xd3790027,0xef190002,0xbef80011}},	//   शर्र, dući_, może_, ्जुन_
  { {0x6ec70012,0xf3f90365,0x290718f9,0x41740012}},	//   _وتحق, снеш_, vena_, _تايس
  { {0xddc40039,0xa87a000b,0x7d080058,0xf1c90003}},	//   dziņ, _לאתר, heds, موصى_
  { {0xd3790027,0x20d5002d,0xaa070012,0x9dbf0011}},	//   gući_, пійс, تظاه, लीफ़ो
  { {0x07f90003,0x3984004a,0x2b920029,0x7e9a0009}},	//   مربع_, tösi_, máce_, _לסרו
  { {0x290718fa,0xd12e0012,0x26f80011,0xa8480012}},	//   rena_, امى_, ्जूर_, يلهم_
  { {0x27e718fb,0x3ce9004b,0x290718fc,0x63680060}},	//   runn_, şivă_, sena_, rınk
  { {0xc9870001,0xddc4001e,0x290718fd,0xcb120009}},	//   _дужи, aziņ, pena_, _אלן_
  { {0x34390003,0xc5f2000b,0x64450051,0x4d49004c}},	//   مسجد_, עדי_, _ühik, спон_
  { {0xa3e60037,0x63a403bd,0x660218fe,0xe7590557}},	//   यूल_, _piin, _epok, _лижі_
  { {0xd7fa000b,0xd8740003,0x8db50024,0xdb040521}},	//   _להעל, _غالب, _ескі, _tuní
  { {0x4a430014,0x63a400ff,0xed4e091c,0xdb04004b}},	//   еняв, _viin, _зо_, _punâ
  { {0x55ba000b,0xd1320003,0xfbd10003,0x25bf18ff}},	//   _המסו, رمز_, _كتب_, mpul_
  { {0x3d0f0037,0x9919002d,0xf992000b,0x201e0eb0}},	//   ड़ने_, ціях_, גרם_, íti_
  { {0x1eaa0012,0xe7e30011,0xdb1b0025,0x7c3c1900}},	//   صاري_, _गिना_, ypté, ärre
  { {0xe737005c,0xee3a02ac,0x26e40011,0xa3c90011}},	// [3a60] чет_, щна_, गलौर_, लीस_
  { {0x2bc20044,0x98ac007a,0x65610017,0xd3790027}},	//   वीका, _kodą_, nilh, vući_
  { {0x913b000b,0xcdc9000b,0xe7eb0037,0x76400002}},	//   _העיק, רך_, जूदा_, zymy
  { {0x7d08003e,0x2f56002d,0x2918052f,0x988b0009}},	//   zeds, _хтос, ldra_, _לָכֵ
  { {0xa79b0009,0x29180227,0x8f1b0009,0x39d30012}},	//   _לשטח, odra_, _הוכת, فينأ
  { {0x6376000e,0x64580029,0xdfd00003,0x61e21901}},	//   rány, úvis, نيت_, rrol
  { {0x17f70003,0x28bf0037,0x9f9801d4,0x0f560009}},	//   كرية_, ्रति, овку_, ּיִם_
  { {0x7dc4000a,0x9989000d,0xddc4001e,0x6376000e}},	//   وقعن, _oraş_, rziņ, pány
  { {0x7d0800c5,0x75381902,0xbebb0227,0x661c0035}},	//   teds, _povz, _poëz, ārko
  { {0xc1bb0009,0x03d80048,0x31bb0009,0xd6570009}},	//   _לממש, омощ_, _לזמנ, פיית_
  { {0x76400006,0x58bb000b,0x0466002d,0x78250003}},	//   symy, _המבצ, ятим, _يعمل
  { {0xc7b3000b,0x4acc0011,0x6d4b0035,0x6fb30012}},	//   _טבע_, ारिव, īgai, _أمنا
  { {0xd3570009,0x7afd1903,0x98d00011,0xbdf70012}},	//   ליטי_, _öste, _सजाए, _فروا_
  { {0x61e0000f,0x290a0073,0xc5eb0009,0xe5a30024}},	//   ámla, geba_, _הַהֹ, _зичи
  { {0x34fb0093,0xd6db0406,0x7d15009b,0x6cfb0009}},	//   _ההוד, йта_, _razs, _הפוס
  { {0x291800c1,0xf1bf0f9b,0x9f050012,0x8e200024}},	//   adra_, ppá_, بورو, _пiд_
  { {0xaac30044,0x4ac30044,0xae1f0011,0x3a201904}},	// [3a70] _व्यक, _व्यव, बियन_, _grip_
  { {0x660d00c6,0xa5bb189a,0xd49b06e0,0x290a0018}},	//   rwak, _prób, бре_, ceba_
  { {0x60fa000b,0x9f430066,0x70fa000b,0x6d860028}},	//   _והתק, lují_, _והתח, rðah
  { {0x1ddd0037,0x63ae0066,0x7fd60009,0xf62b0024}},	//   _मिलत, _dubn, _קורס_, _ліги_
  { {0xe2900003,0x9f430066,0xdb1e0002,0x64410112}},	//   هذه_, nují_, espó, zyli
  { {0xf8bf0044,0x2bac0066,0x67390052,0x6441004a}},	//   ्रिय, _těch_, _sowj, yyli
  { {0x9f430066,0x65610017,0x7bdc000e,0xe0d00012}},	//   hují_, vilh, árul, ازه_
  { {0x321f0020,0x2f54007c,0x69c900bd,0x290a0002}},	//   _truy_, етьс, _twee, zeba_
  { {0x80bf0037,0x50bf0037,0x20bf0011,0x7bca0132}},	//   ्राइ, ्राष, ्राध, _awfu
  { {0x9f430066,0xed59002d,0x0dc80001,0x1c450400}},	//   dují_, іон_, чући_, дном
  { {0x3b0a0083,0xb8e10011,0x7afd0032,0xb17b0248}},	//   оено_, ंड_, ffst, trån
  { {0x8c1a000b,0x3cfd0011,0x935a0024,0xddc90034}},	//   קורי, र्ते_, ірну_, rzeł
  { {0xd3790027,0xc6d40012,0xcd350012,0xa3b20011}},	//   juću_, _ستنت, _يرتب, _झूठ_
  { {0x22420033,0x7db40012,0xd379001b,0xdb040031}},	//   rykk_, _أصنا, duću_, _duná
  { {0x26d2002c,0x29181905,0xb4e90011,0x9cd60009}},	//   tayo_, rdra_, यली_, _חוצה_
  { {0x26cf003e,0x60c100a2,0x9f430066,0xe4f00037}},	//   _jego_, ılma, bují_, _चाहि_
  { {0x88bc0066,0x9f430066,0x24f6004d,0xd1ba0012}},	// [3a80] _sněm, cují_, дчер, _بابا_
  { {0x3eb90065,0x80ac0037,0x3f8900b6,0x7bc10060}},	//   _efst_, _चलें, alau_, oplu
  { {0xe73a0098,0x26d20101,0x690b000b,0x201c0031}},	//   _ден_, payo_, _וּכְ, _évi_
  { {0x27e50026,0x26cf001c,0x0b46002d,0x09e6002d}},	//   álne_, _nego_, ьнен, додн
  { {0x2bac0066,0x7549000e,0x62880034,0x20050035}},	//   _věci_, ászó, ędow, _apli_
  { {0xe89400be,0xa5bb0002,0xc9830063,0xf84a0024}},	//   наль, _wróc, кущи, жчий_
  { {0x9f430013,0x61eb0028,0xf993000b,0x6d4e0623}},	//   zují_, augl, דרג_, _ilba
  { {0xf093000b,0x27e00082,0x44441906,0x1e140148}},	//   כנו_, čin_, my_, емия
  { {0x753c003e,0xe4e6002d,0x6ce60024,0xa4d40024}},	//   _korz, мінн, міне, нопі
  { {0x9f430066,0x4a57000b,0xdb1b0068,0xd826004c}},	//   vují_, _חשמל_, nstö, _одзи
  { {0xddd1001e,0x753c0a8e,0x3d0f0011,0xdb1b12fb}},	//   ēgša, _morz, ड़ते_, istö
  { {0x36060003,0xa08b0009,0xe666022a,0x9f430030}},	//   _يواف, _וְדִ, _отло, tují_
  { {0x5187022e,0xc333000b,0x753c0070,0xa2db0037}},	//   дува, דור_, _oorz, पृष्
  { {0x44440107,0x9f430066,0x30151907,0x000000c4}},	//   ky_, rují_, ндгр,
  { {0xdfd10003,0x61e6003a,0x74140012,0x9f430030}},	//   طيء_, arkl, _أوبا, sují_
  { {0xf770000a,0x95c50012,0x60170009,0x2d8300b0}},	//   لاق_, فيره, וחלף_, _skje_
  { {0x11d90003,0x20050066,0xddc90002,0x1df8003c}},	// [3a90] _عودة_, ůli_, czeń, меты_
  { {0x301506e6,0x6d481908,0x91bc0009,0xdb1b0097}},	//   _здор, nkda, _ומזי, gstö
  { {0x99490026,0xd3790027,0x798500b6,0x36d50015}},	//   núť_, suću_, _ikhw, _понр
  { {0x309a0093,0xa3e6159f,0x16350014,0x28bf0037}},	//   _משתמ, _पिन_, _земя, ्रवि
  { {0xb6ba000b,0x7d18006f,0x6eba000b,0x753c018f}},	//   _מצרי, _oavs, _מזרח, _forz
  { {0x41e00037,0xf1e00011,0xd6560009,0x753c0034}},	//   _निरस, _निरन, _טירת_, _gorz
  { {0x44440501,0x62860623,0x01380009,0x26170011}},	//   cy_, _økon, ורגת_, निकी_
  { {0xac940047,0xef12000b,0x2d810064,0x7bc1005e}},	//   _расш, ָּה_, lohe_, vplu
  { {0xf6510012,0xada50048,0x39960040,0x39890097}},	//   طئة_, наил, læse_, húsi_
  { {0xe00f0037,0x6aad0054,0x9f5e0029,0xa0c40003}},	//   ाबाद_, _agaf, _istý_, _ليكو
  { {0x26cf003e,0xdb040017,0x63680060,0x08f80012}},	//   _tego_, _junç, kınt, _ترقب_
  { {0xf989000b,0x7c3c006f,0x59c60011,0x09e612fa}},	//   _הר_, ärra, रीकर, номн
  { {0x63a91909,0xdc3b009b,0x2d810574,0xfce501d4}},	//   _mien, _išče, kohe_, _золо
  { {0x63a90108,0x963a0009,0x6e3a0009,0x7f850018}},	//   _lien, _מגנט, _מתנד, róqu
  { {0x6e220002,0x3da60024,0x27960048,0xf8b20009}},	//   _zrob, _якшо_, ешар, רשל_
  { {0xd2520003,0xa3c80037,0x44440657,0x6f0d04a3}},	//   _منع_, _लौट_, vy_, geac
  { {0x4444003e,0x6b720039,0x9f58190a,0x753c190b}},	// [3aa0] wy_, lāgo, ntré_, _porz
  { {0x63b80029,0xdce10010,0x99fb0009,0x6e930012}},	//   ívno, rolė, _צפיפ, الكا
  { {0xc1730093,0xdb1b05df,0x753c0052,0xdd8f0003}},	//   _תחת_, rstö, _vorz, حول_
  { {0xdb1b0068,0xd7bb0009,0x4444190c,0xf4950198}},	//   sstö, _מצטר, ry_, трую
  { {0xdcfc001e,0x291a190d,0xdb1b0991,0x69d90d4c}},	//   _ekrā, _kapa_, pstö, gswe
  { {0xdb040017,0x63a90033,0x4444190e,0x6b83004b}},	//   _funç, _eien, py_, îngr
  { {0x2d98008b,0xddcd0002,0x8b660012,0xa2e60048}},	//   _ihre_, czał, _كارم, _повд
  { {0x291a0039,0xdb0b0119,0xa8470003,0x3ea6001e}},	//   _lapa_, _utfø, عليم_, žotu_
  { {0x3cfd0011,0x8fa3004c,0xfeb70012,0xdb1c0025}},	//   र्वे_, ћање, رايت_, _ntré
  { {0x361b0093,0x6b8207fc,0xd24f0003,0x89db0009}},	//   לופד, loog, _انك_, _מחמי
  { {0xd498007c,0x6d480ad2,0xed570009,0x79530012}},	//   ької_, rkda, גביר_, _حَلا
  { {0x6e2203eb,0xf0930009,0x8e860012,0xe7b70009}},	//   _trob, _ענף_, _كلاه, _נהדר_
  { {0x6e220026,0x7d1800a2,0x673d0002,0x291a190f}},	//   _urob, _tavs, _rosj, _bapa_
  { {0x90d50020,0xa3e10037,0xf5780012,0x6b821171}},	//   _lòn, _दिल_, _تمتع_, hoog
  { {0x673d001c,0xf7730003,0x2d9e0052,0x74670014}},	//   _posj, هار_, mmte_, _пръв_
  { {0xa3f7000b,0x7bda0028,0x07090012,0x2d8c0248}},	//   _נמחק_, mstu, بيري_, llde_
  { {0x63a901a2,0x7bdc00a2,0x636800a2,0x8f9b000b}},	// [3ab0] _rien, _avru, rınt, לילי
  { {0x63a91910,0x4ea404a5,0xad670012,0xc6a405d8}},	//   _sien, урса, راءه, урси
  { {0x69c0007a,0x2fd9000a,0xc4d3000b,0x9cd7000b}},	//   _atme, _توجد_, רגע_, גובה_
  { {0xddcd0002,0x6b821911,0xe6950012,0x6e950012}},	//   rzał, goog, _للجد, _للجا
  { {0x213e0036,0xdb070065,0xa294002d,0xe4e7002d}},	//   _both_, _stjó, гаці, _півн
  { {0xdb040052,0xfbd30003,0x61fd0ad2,0x6d860097}},	//   _zunä, _متر_, itsl, iðas
  { {0x69c000a2,0x63a91912,0xe7391913,0xdfd10012}},	//   _etme, _tien, дей_, جيع_
  { {0x2d8c1914,0x25b90042,0x60060048,0xaec20048}},	//   elde_, íslo_, тнъм_, абъл
  { {0xc1150046,0x57240003,0xb1150014,0x3e890012}},	//   _имај, طريق, _имаш, بَةَ_
  { {0xb9c40003,0x637d000e,0xaa880012,0xc6480012}},	//   _إقلي, mény, _أنكم_, عجيل_
  { {0xf3e50014,0x9f580061,0xa3cc0037,0x98ac0030}},	//   ъжно, stré_, शील_, _lodě_
  { {0x06990003,0xdb000031,0xcad50009,0x2d8c1915}},	//   _قناة_, _kimá, כוֹת_, alde_
  { {0x20d6002d,0x98d6002d,0x7bda1916,0xe2970024}},	//   ківс, ківщ, astu, каю_
  { {0x06560009,0x7c650012,0x6e2001e3,0x99150024}},	//   _בינך_, _لاعل, _ámbi, льсі
  { {0x6d860028,0x3f8d0054,0x998f0010,0xbc19002d}},	//   rðat, oleu_, lygų_, _цілі_
  { {0xba760003,0x27e50029,0xc3230048,0xfaff0227}},	//   _لاخت, álna_, _вмък, liën_
  { {0x98d10011,0xf8d10011,0xc7a3028b,0x79830034}},	// [3ac0] हराए, हराय, ритк, konw
  { {0x64450005,0xca97000b,0xdd8f0003,0x69db0037}},	//   _ühis, _בדפי_, قوق_, _निजी
  { {0xdcfa001e,0xdee6003c,0x213e0aa6,0xb93700af}},	//   notā, _иони, _roth_, _סנטו_
  { {0xa5bb0002,0xb4ae0011,0xa3e60011,0x41e60024}},	//   _król, _कल्_, यूट_, віка
  { {0x90d5001a,0x2d870029,0x333f0061,0x6a130012}},	//   _vòn, _okne_, _doux_, لبور
  { {0xf806002d,0x3ea6001e,0xaa570012,0x7bda1917}},	//   вчин, žots_, خلها_, ystu
  { {0x7ff30003,0xb5020037,0x351b000b,0x929d0002}},	//   لسيا, र्णय_, _קולנ, _mały
  { {0x9c17000b,0x3f8d0027,0xdcfa001e,0x97140001}},	//   _בחלק_, gleu_, dotā, умиц
  { {0x68ed000e,0xcb570009,0xddcd0034,0x69c016d1}},	//   ándé, _ססמה_, czań, _utme
  { {0x7e9b000b,0xfe6f0003,0x092a0003,0xa09a0012}},	//   וספו, تدى_, _تسري_, _قضاء_
  { {0xc0a90003,0x29550014,0xa0a60014,0xe2f9002d}},	//   _كامل_, _сътр, _ражд, нені_
  { {0x7bdb000b,0x7bda09a0,0x8eda0003,0xe5020011}},	//   וקטו, rstu, _آذار_, र्ति_
  { {0x9f470029,0x07370009,0x9b580048,0x52140024}},	//   ntný_, _שאדם_, тият_, адят
  { {0x6d860065,0x70bf0037,0xc56a0003,0x929d0002}},	//   rðas, ्रेल, _تحصل_, _cały
  { {0xcd97000b,0xdfd80014,0xed570001,0x5c130012}},	//   _שדות_, кът_, _јој_, _نظير
  { {0x34cb0037,0x0ccb0037,0x3eaf0058,0xd4370009}},	//   िर्द, िर्म, øgt_, _ירוק_
  { {0xa3ac0044,0x333f0d29,0x2b8e06dd,0x7d1c1918}},	// [3ad0] _कूट_, _roux_, mých_, _bars
  { {0x637d000e,0x2d871919,0x2b8e01bd,0x7d1c191a}},	//   vény, ône_, lých_, _cars
  { {0x2ca70163,0x6ca70731,0xe1ff1214,0x7d1c191b}},	//   änd_, траж, ltó_, _dars
  { {0x9f35002d,0x2b8e00f1,0x3f84001e,0xfecb0003}},	//   _семі, ných_, jomu_, _تبدو_
  { {0x7d1c0421,0xe1ff065b,0x63ad191c,0x61e40159}},	//   _fars, ntó_, _mian, šiln
  { {0xd5fa0093,0x7d1c0010,0x04c90003,0xd184002d}},	//   _אפשר, _gars, _سوري_, алій
  { {0xccf2000b,0x2b8e0107,0xd3a70001,0x00850015}},	//   _לכם_, kých_, _арап, ылко
  { {0xe619191d,0xdcfa0035,0xdb000031,0xe7b20012}},	//   еди_, votā, _timá, حميد
  { {0x917b0020,0x645a001e,0xe1ff000e,0x9e090012}},	//   hể_, ezti, jtó_, ريدك_
  { {0xdcfa0333,0x6f1d00c1,0x28ac0037,0x80ca0321}},	//   totā, _lasc, _चलचि, _स्पे
  { {0x63ad191e,0xfaff0227,0x69dd174c,0x80bf0011}},	//   _bian, riën_, esse, ्रैं
  { {0xc7b20093,0x18a4002d,0xdcfa001e,0x9f600060}},	//   _הבא_, _таєм, rotā, ürür_
  { {0x6d860065,0xd6d90002,0x63ad17fd,0xee2e0538}},	//   rðar, mał_, _dian, _ун_
  { {0x28c60037,0x673b0133,0xf8c60037,0xd6d90002}},	//   रुपि, ljuj, रुपय, lał_
  { {0xac160001,0x6fb60012,0x929d0034,0xd9430048}},	//   _боју_, امرا, _obło, щери
  { {0xd6d90002,0x9f550001,0x673b013a,0x1db50011}},	//   nał_, ањуј, njuj, _अंशत
  { {0xceb2000b,0x6e930003,0x29110164,0x7ae40027}},	// [3ae0] מין_, ملفا, beza_, _idit
  { {0x3a37000b,0xbce50012,0x6acc0011,0xdcfc0034}},	//   _ערים_, لأمو, ार्र, _okrą
  { {0x68fb000b,0xcea9000b,0xd6d90002,0x78fb007e}},	//   _אליה, פי_, kał_, _אליפ
  { {0xd6d90002,0x7d1c191f,0x7afd031d,0x2d8505a4}},	//   jał_, _wars, _östl, hole_
  { {0x61460e0f,0xd6d90002,0x28f8002d,0x298a0103}},	//   леда, dał_, вель_, нско_
  { {0x3ff40003,0xd0100003,0x6e2b000b,0x9f470029}},	//   لكتر, قلت_, _אֵלַ, rtný_
  { {0xa3e10044,0x9f4701bd,0x8b9600db,0xb8060012}},	//   _दिए_, stný_, _брач, ابته
  { {0x20d8007a,0xdb190029,0xb09b0009,0x140b0009}},	//   džių_, _otvá, עיקר, _אִמּ
  { {0x2b8e0652,0x7607001e,0x63a21920,0x70f60012}},	//   vých_, cīzā, mmon, _مسائ
  { {0x63ad1921,0x2d851922,0x64481923,0xc243004c}},	//   _sian, gole_, tydi, _унук
  { {0x26140037,0x63ad1924,0x29110604,0x2b8e0042}},	//   नौती_, _pian, veza_, tých_
  { {0x291e00a2,0x5e260003,0xe4470003,0xd6cf0012}},	//   _hata_, _معتق, الَى_, _فقم_
  { {0x291e00c6,0x645a000f,0x2b8e00f1,0x63ad1925}},	//   _kata_, szti, rých_, _vian
  { {0x6e93000a,0xfdf7000b,0xe6930003,0xe5f7000b}},	//   _الها, _עצות_, _الهد, _עזור_
  { {0x6db20002,0xcf9b0001,0x67d50055,0x291e1926}},	//   _wład, еја_, робу, _mata_
  { {0xa3b90037,0x7bde00e2,0x2f180800,0x291e1927}},	//   _अंत_, dspu, лось_, _lata_
  { {0x59e00037,0x7bde1928,0xde580024,0x61e40031}},	// [3af0] _निगर, espu, гаті_, áill
  { {0xd6d90002,0x63a21929,0xd91b003c,0x6f1d192a}},	//   zał_, emon, _чьи_, _wasc
  { {0xc1740093,0xb605012e,0xb8f90037,0x4427192b}},	//   _לחץ_, _zašč, ार_, ín_
  { {0xd251000a,0x4c940015,0xfb84003c,0x9bc80012}},	//   ينا_, щихс, бычн, اونك_
  { {0x291e010a,0xf1b902a1,0xa3c90011,0xd6d90034}},	//   _bata_, _krši_, लीज_, chły_
  { {0xd6d9003e,0x98ba0039,0x1869034d,0x76070035}},	//   wał_, _kopā_, кали_, rīzā
  { {0xd0f8000b,0xd6d90002,0x5d54002d,0x2d85192c}},	//   אמות_, tał_, _укрт, vole_
  { {0xddc90002,0x8e090472,0xd3a40a2e,0x060908e5}},	//   cześ, внив_, _груп, вник_
  { {0xd6d90002,0x291e192d,0x7b060031,0x673b192e}},	//   rał_, _fata_, értő, rjuj
  { {0xa5090046,0x1d090001,0xd6d90002,0x291e192f}},	//   њена_, њени_, sał_, _gata_
  { {0x3a290712,0x66160034,0x2d851930,0xf9900012}},	//   _arap_, zwyk, role_, _ربك_
  { {0x34b20037,0x60d7001e,0xcb6a0048,0x69c40227}},	//   _जल्द, šamī, таме_, _ptie
  { {0x6cf70037,0xf7840003,0x9b160009,0xed4e0147}},	//   ुभाग_, _النَ, בחרה_, _до_
  { {0xdce1001e,0xa5bb1931,0xdcfe001e,0x3c050011}},	//   bilā, _trój, kopā, _रहूँ_
  { {0xccf2000b,0x3f470051,0xb4fa0009,0xdfa60012}},	//   _וכו_, _nõus_, _יפסי, لحري
  { {0xeab20003,0x63b50030,0x6d430248,0x7ae400b8}},	//   _بعث_, íznu, _hona, _udit
  { {0x05661932,0x91a0001a,0xdc3c009b,0x8d660593}},	// [3b00] аван, _trì_, ršča, авае
  { {0xa3e10037,0xe4520003,0x89db0009,0x75d30012}},	//   _दिख_, يضا_, _שחיי, تيكا
  { {0xaaba0037,0x161c0037,0xdd010030,0x3dc9020d}},	//   _इलाक, _बैनर_, _štěp, apaw_
  { {0x7bde0065,0x291e0027,0xdb1c000d,0xdb190058}},	//   rspu, _sata_, _strâ, _etvæ
  { {0xddc90002,0xaa160001,0x7bde0068,0x24860034}},	//   rześ, рфеј, sspu, łom_
  { {0x60dc0028,0x07e60001,0x26c01933,0xc16f0024}},	//   narm, ацим, lcio_, ії_
  { {0xd0100003,0xa8a30014,0x03a60024,0x01370009}},	//   سلة_, орък, _виво, ירסת_
  { {0x24530003,0x36d40001,0xdb070028,0x9c82014a}},	//   _بنفس, љопр, _stjö, _účin
  { {0x161c0037,0x6db20002,0x291e02a5,0x60dc0a9a}},	//   निटर_, _słab, _tata_, karm
  { {0x5d540098,0xe5720003,0x51630014,0x30d80009}},	//   скот, تطع_, _двуб, _תַּע
  { {0x34b7000b,0x33200054,0x3cfe0037,0xd49a0014}},	//   יפים_, _baix_, _लाने_, ъри_
  { {0x3d060037,0x645e001e,0x2b9201bd,0xf3671934}},	//   स्ते_, izpi, nách_, ртон
  { {0xfe720012,0xe9470024,0xda7b04a5,0x60c2004b}},	//   _بدا_, ахво, тян_, _şoma
  { {0xc9870867,0x224b006f,0x32d50081,0x2b921935}},	//   руми, ryck_, ấy_, hách_
  { {0x657d000e,0x2b9200d9,0x98480048,0x656f0025}},	//   éshe, kách_, аята_, èche
  { {0x442d066e,0x6447004a,0xa857000b,0x60dc0070}},	//   _če_, äjie, בילה_, aarm
  { {0x61e40470,0x29050051,0x6d5a019a,0x539c0009}},	// [3b10] šilj, õlas_, ohta, _ביהו
  { {0x91a00020,0x94ab000a,0x61440001,0xdce80010}},	//   _trí_, نطاق_, _мења, rodė
  { {0x9f4b0028,0xdcf80066,0xb97c0009,0x6d5a005e}},	//   ðmót_, _skvě, _בנזי, ihta
  { {0x9f430029,0x6020000e,0x92590015,0x26c003a2}},	//   hujú_, zámá, лает_, ccio_
  { {0x3ebf00a2,0xbf36000b,0x9f430029,0xe9f80024}},	//   vcut_, _הארץ_, kujú_, инці_
  { {0xdcfc0002,0xe9870001,0xe8f8002d,0x3f47005e}},	//   _okrę, шћен, илі_, _tõus_
  { {0x3f69057b,0x9f430029,0x44250baf,0x3158000b}},	//   лико_, dujú_, _él_, שיון_
  { {0x7c250065,0x1878000b,0x88780009,0x389c0009}},	//   _áhri, יעור_, יתוב_, כיונ
  { {0xd4d9007c,0x9f581936,0x764d1937,0x09f40012}},	//   льні_, ntrá_, nyay, _وأكد
  { {0x45190014,0x3ebf170a,0x4535003c,0x2b920064}},	//   уция_, scut_, схит, máci_
  { {0xb895000a,0x4095000a,0x6d4302b2,0x6db20002}},	//   _الاع, _الار, _vona, _płac
  { {0xa3ea0011,0x4b560048,0x6d430032,0xc9490009}},	//   _मिस_, съот, _wona, _אמ_
  { {0xc332000b,0xdb1c0002,0xa509046d,0x1d0900f5}},	//   פוך_, _zwró, _бела_, _бели_
  { {0x9f430029,0x670a0011,0x21330081,0x6d5a0cc3}},	//   cujú_, ह्नक_, _cnxh_, chta
  { {0x07ba0003,0x03a6010b,0x320201bd,0x63c60030}},	//   اهرة_, _лико, stky_, ěrné
  { {0xd0070001,0x2498004e,0x5bc40012,0xd5b20012}},	//   љете_, ürme_, _بتوف, كفر_
  { {0xa2f7000b,0x764d002c,0xf7430063,0x7bc70010}},	// [3b20] _המפה_, gyay, чето, _atju
  { {0x9a3b0009,0xc6920009,0x74ad0011,0x75d30012}},	//   _עתיק, לאן_, ुखपृ, سيما
  { {0x649a0001,0x61e4024c,0x232a00f5,0xdb1c01c5}},	//   утар_, _hvil, ложи_, _atrá
  { {0x9f430026,0xa3cc0037,0x2bb7000d,0xf1b90027}},	//   zujú_, शीट_, _căci_, _buš_
  { {0x93250012,0x2b921938,0x58d817e0,0x000000c4}},	//   ترلن, rách_, адля_,
  { {0xdb0b0052,0x9f430064,0x58d30595,0x929b0009}},	//   _zufä, xujú_, пошт, ניסת
  { {0xdc180002,0x9f430029,0x90440012,0x6724001b}},	//   ołąc, vujú_, تنغه, odij
  { {0xb8ef0037,0xcc77000b,0xc7b3000b,0x3f510028}},	//   _व्_, _העלה_, הבה_, _fáum_
  { {0xdcfc0002,0x163a0012,0xd3370009,0x9f430064}},	//   _skrę, اسعة_, _פרמה_, tujú_
  { {0xb996000a,0x91a90020,0x50cf0037,0xf531000b}},	//   _الطب, _trả_, _स्पष, ֵ֥י_
  { {0x9f430029,0xdb1c0066,0x97430027,0x6604019a}},	//   rujú_, _ztrá, šćiv, htik
  { {0x61e20051,0x04630015,0x201e013a,0xb09b0009}},	//   osol, ятым, _isti_, _גיבר
  { {0x0a6b0103,0x4e960012,0xde960012,0x26d900b8}},	//   урни_, _اشار, _اجاب, _reso_
  { {0xf617000b,0x60230066,0x25b90028,0x35db0011}},	//   _לחדש_, jímá, _rusl_, मीफ़
  { {0xad650012,0x85030012,0x61e41939,0x6604193a}},	//   _بانه, _روين, _evil, etik
  { {0xd6d800be,0xe7f001e1,0x3d060037,0x60da068c}},	//   йту_, _घटना_, स्से_, _letm
  { {0xf7700003,0x93bc000d,0x248d0035,0x61290031}},	// [3b30] راف_, zvăl, _ņem_, lölő
  { {0x7e9b0009,0xdc180034,0xf1b90064,0x6ca70229}},	//   רסמו, ałąc, íšu_, бреж
  { {0xdb1c0652,0x764d003a,0xf994000b,0x6604193b}},	//   _strá, syay, _מרץ_, atik
  { {0x6bd40003,0xdb19006f,0x39450f4c,0x42550012}},	//   ستمر, _utvä, _sols_, ينار
  { {0x6d58000f,0x6145004d,0x201e193c,0xdce80035}},	//   _olva, жела, _asti_, godī
  { {0x91a90012,0x61dc0009,0x8e360009,0x4129193d}},	//   جهتك_, נקוד, _ונשא_, роко_
  { {0xddd60002,0x3945193e,0xf9900012,0x3cfe0011}},	//   czył, _vols_, ربه_, _लाते_
  { {0x6d470164,0x00580009,0x58940012,0x30580009}},	//   _hoja, משות_, أجهز, משוך_
  { {0x61e2000f,0xbd39002d,0x9f5c0066,0x201e193f}},	//   csol, аїні_, ctví_, _esti_
  { {0xbc840020,0x6b8b028e,0x3cfd0011,0x8d650024}},	//   ườn, logg, र्चे_, івне
  { {0xca290093,0xdc180002,0x61e41940,0xccf20009}},	//   _שם_, yłąc, _svil, וכי_
  { {0x96550014,0x660403ec,0xdc880009,0xd2aa115e}},	//   _мълч, ytik, מְרָ, икне_
  { {0x84e50047,0xeab20012,0xd29a0024,0xd6270012}},	//   _долж, بعد_, ртні_, _دعاي
  { {0x412a06e6,0xa3ea0037,0x85a70001,0x28cf0321}},	//   шого_, _मिल_, _ујед, _स्मि
  { {0x3fe90009,0x63e40012,0x6db20034,0x7ae91941}},	//   יַּ֣, _فسيك, _kłan, _odet
  { {0x66040774,0xef1a004c,0x67241942,0x61e41943}},	//   ttik, јма_, udij, _tvil
  { {0x92e9000a,0x5fb60011,0x7bc30097,0xee3a11d9}},	// [3b40] _طريق_, _आंकल, ínun, шна_
  { {0x3d140044,0x3a20002c,0x7c960232,0x7ae90060}},	//   ड़ें_, _isip_, орец, _adet
  { {0x2937000b,0xf74600ac,0xc6d60012,0xd38a0024}},	//   _ואין_, _дено, _وتحت, айже_
  { {0xeb970047,0x60da0054,0xddd60002,0x3d090037}},	//   оих_, _setm, rzył, ़्ते_
  { {0x6a160003,0x11d70003,0xddd60002,0xe2160012}},	//   تبار, قونة_, szył, تباع
  { {0xdb0b006f,0xed5a0001,0x29181944,0xe9180024}},	//   _utfö, _тог_, nera_, сокі_
  { {0xd7f0000a,0x69c9004a,0x291814f3,0xfc031728}},	//   ركة_, _etee, iera_, _опро
  { {0x75230070,0x27e5029d,0xf8b30009,0x935a004c}},	//   _aanz, álni_, ושו_, _тргу_
  { {0xbe970012,0x3f980035,0x29181945,0x3a2d1946}},	//   يضًا_, ēru_, kera_, _grep_
  { {0xce37000b,0xa06a0014,0x752300c1,0x29181947}},	//   קאית_, _каза_, _canz, jera_
  { {0x836b0003,0x4cbb000b,0x63bc1948,0x29181949}},	//   لصحف_, יזיו, _jurn, dera_
  { {0xa5bb0002,0x63bc00b6,0x8c1b0009,0x395a194a}},	//   _krót, _murn, בוטי, _alps_
  { {0xc6170024,0x66760012,0xad660012,0xda220011}},	//   _моїх_, _بدار, _واته, मिगत_
  { {0x2918194b,0x75230052,0x3d140037,0x63bc0025}},	//   gera_, _ganz, ड़ों_, _ourn
  { {0x20990015,0x36d50063,0x2d8c194c,0x9f6b0024}},	//   сквы_, зобр, mode_, араз_
  { {0x98a5001e,0x9c7c009b,0x27ed0fa8,0x6443008e}},	//   _solī_, gače, čen_, änim
  { {0xe4cb0003,0x3eaf0052,0x11d70003,0x5d550014}},	// [3b50] لبان_, ägt_, _بتعد, пкат
  { {0xdd910003,0x80f50015,0x63bc194d,0x97c70012}},	//   روا_, _эпох, _burn, _وتجم
  { {0x9c7c0027,0x6d470aa3,0x69c9194e,0x49740024}},	//   bače, _voja, _stee, _ілюс
  { {0x501a000b,0x648b0009,0xead40024,0xdc8b0009}},	//   _פורו, בְדְ, доць, בְדָ
  { {0x7f3a000b,0x2d8c0260,0xeab00012,0x4f3a0009}},	//   _הערו, kode_, نعه_, _התרע
  { {0x63bc194f,0xe8b90037,0xe9a80003,0x55ba000b}},	//   _furn, _आलोच, يدون_, _למשו
  { {0xb4d70037,0x6b8b00b8,0xb0a50011,0xc1740009}},	//   सरी_, pogg, गेंग, וחס_
  { {0xd00e000a,0x907c000b,0x2b920066,0x63680dff}},	//   الي_, יטוי, náct_, _друг_
  { {0x28cf0044,0xb0cf0037,0xddd60002,0x69c4004b}},	//   _स्थि, _स्थग, czyń, ţier
  { {0x29181950,0x6f090b45,0x82880009,0x16b80011}},	//   xera_, sfec, _וְעֶ, _अल्ब
  { {0x29181951,0xc9520009,0x75231952,0x9cd600af}},	//   vera_, _רמב_, _vanz, הותה_
  { {0x889a000b,0x29010017,0x28cf0011,0x29180034}},	//   _הבעי, _acha_, _स्ति, wera_
  { {0x66ba000b,0x4426001a,0xa2f6000b,0x29181953}},	//   _המנה, ̉o_, המרה_, tera_
  { {0x27f80cfa,0x29181954,0x2d8c1955,0xfe440024}},	//   turn_, uera_, code_, _юніо
  { {0x6f0f0584,0x29181956,0x2007013a,0x8fa6085d}},	//   _bbcc, rera_, ntni_, заве
  { {0x29181957,0xcf250012,0x29011958,0x03a30048}},	//   sera_, ورقي, _echa_, _пищо
  { {0xe4d60003,0x63a4002c,0x42fb0009,0x16660048}},	// [3b60] كتاب, _ihin, _ההפס, чвам
  { {0x27f80028,0x26dd0002,0x28ac0037,0x200702a1}},	//   purn_, _lewo_, टेडि, ktni_
  { {0xc9850003,0x00bb0009,0xf9930009,0x60bb0009}},	//   _تشيي, _למימ, _ארז_, _לציד
  { {0xeb9a0047,0xc2e90012,0xcb6a004c,0x99ea0012}},	//   щие_, قعهم_, љаде_, معتق_
  { {0x98be007d,0x61e609d1,0xcb070012,0xb9c60012}},	//   _notă_, nskl, سيون_, ستشه
  { {0x7e9b000b,0xdb1c02f1,0xe894027f,0x301a0012}},	//   _לסכו, _strä, маль, متعة_
  { {0x6d90004a,0xb4c80011,0x2d8c1959,0x711b0009}},	//   säas, ईडी_, vode_, מוספ
  { {0x644900a2,0xf8b3000b,0x547b000b,0x96340a76}},	//   çmiş, עשה_, _הטלו, дниц
  { {0xbb3b000b,0x7e640052,0xa3de0011,0x20070035}},	//   _פעמי, nzip, दीन_, atni_
  { {0x4a5b000b,0xe60f0012,0x63a4020d,0x22930012}},	//   _הדמו, اشي_, _ahin, _ألكس
  { {0xb4bc0037,0x986a0003,0xf1b30009,0x1b19003c}},	//   _अली_, _احذف_, _נסע_, ожны_
  { {0x7afd195a,0x44770009,0x4c9b0009,0x2d8c16ab}},	//   ugst, לעיל_, מביו, sode_
  { {0xdb04001a,0xeb91000b,0xb7e00011,0x9f5c0064}},	//   _khiê, דָם_, _गौतम_, ctvá_
  { {0x867b0009,0x7c3c0248,0x6db20034,0x6d4a195b}},	//   _פרגו, ärrs, _kłam, öfal
  { {0x7d230003,0xd1380034,0x7ae2005e,0x853c0073}},	//   _سفين, _mną_, kaot, ymėj
  { {0x95d90014,0x6c7b000b,0x547b0009,0x7ae2005e}},	//   ждат_, _לאופ, _לטוו, jaot
  { {0x59b70044,0xfe730012,0xd7740012,0x000000c4}},	// [3b70] _इंटर, ردر_, رافع,
  { {0xdb040020,0xb4d70044,0x89dc000b,0x4a5c000b}},	//   _nhiê, सरे_, _החזי, _לדחו
  { {0x8c19000a,0x9cd70009,0xf2d50009,0xa5bb195c}},	//   تيار_, פואה_, ֵעַ_, _prós
  { {0x27e50029,0xfbd3000b,0x6d860097,0x22590012}},	//   álnu_, תתף_, rðay, يلاد_
  { {0x539c000b,0x05770012,0xd2b80009,0xe28e1044}},	//   זיאו, _فاسد, פלגת_, та_
  { {0xdb040020,0x7d1a0864,0x6f0d03de,0x20070097}},	//   _chiê, jets, lfac, ttni_
  { {0x29c2014d,0xb8e50037,0x7aed195d,0xd9420048}},	//   _eða_, _एल_, _odat, тещи
  { {0x6f0d008b,0x8038000b,0xa6db0028,0x6e2d009b}},	//   nfac, לנוע_, _boði, ovab
  { {0x2007009b,0xee390024,0x629a0034,0x6f0d0032}},	//   stni_, іно_, ętok, ifac
  { {0x7aed195e,0x6d450248,0x6e2d07fb,0x13e9003c}},	//   _adat, njha, ivab, омой_
  { {0xcc89003c,0x61e40073,0xe8550012,0x68e3195f}},	//   юбое_, šilt, _تناد, mand
  { {0x68e31960,0x6b560009,0x59d40011,0x29c20097}},	//   land, ֥ישׁ_, ठीकर, _yða_
  { {0x7d1a0163,0xa3b90037,0x27e00027,0x4a430365}},	//   bets, _अंक_, ćine_, вняв
  { {0x25ee0037,0xf652000b,0x32dc001a,0x55ba0009}},	//   ेंसी_, _בצד_, ậy_, _ומסו
  { {0x63a40036,0x66091961,0x67290034,0xdfd20012}},	//   _thin, ltek, odej, ئير_
  { {0x853c0010,0x2b050011,0x67291962,0x7e7b1963}},	//   ymėk, _वायु_, ndej, _župa
  { {0x11d70003,0xdd920003,0x67260070,0xe96a0001}},	// [3b80] _قوية_, نور_, _vakj, _маил_
  { {0x9c7c009b,0x68e31964,0x66091085,0x67290030}},	//   lača, jand, itek, hdej
  { {0x7ae20051,0x7e640052,0xdd8f0012,0x67290030}},	//   taot, szip, جول_, kdej
  { {0x9c7c0027,0x25ee0037,0x1efa0012,0x7ed60012}},	//   nača, _इटली_, _بعدة_, _تزدا
  { {0xdb040020,0xa3de0037,0x72360003,0x93430014}},	//   _phiê, _दौर_, براط, ънце
  { {0x7646004a,0x3cf90011,0x6da609ca,0x68e31965}},	//   äkym, ्भों_, _цига, gand
  { {0xd7940014,0x6447004a,0xa3b90011,0x7d1a1255}},	//   никъ, äjil, _अंग_, vets
  { {0xf7720003,0xd6d00003,0x9c7c0027,0xcdc6004c}},	//   ضاع_, دقة_, jača, мљоп
  { {0xdb040020,0x6609000f,0xf8cf0037,0x8a030014}},	//   _thiê, gtek, _स्वय, _изте
  { {0x67290066,0xab640002,0x6368000e,0x7afd02f1}},	//   adej, óżni, zűnt, _östr
  { {0x04580012,0x44980024,0x58bb0009,0xd4980024}},	//   سلحة_, явою_, _ומבצ, якої_
  { {0xee3a0047,0x291c1966,0x97a50024,0x9c7c001b}},	//   _мне_, leva_, _зріл, gača
  { {0x394c0039,0x69c01967,0x7d1a1968,0xf2040048}},	//   _kods_, _jume, pets, кяро
  { {0xdb1c0061,0xda4b0009,0xf1ab0012,0x85040012}},	//   _duré, חֲלָ, تاجه_, _أوغن
  { {0xeb9b0003,0x34fb000b,0x69c007f8,0x1d170009}},	//   _وضعت_, _והוד, _lume, _חקור_
  { {0x68e31969,0x7aed196a,0x291c196b,0x6e2d0522}},	//   zand, _udat, heva_, tvab
  { {0x6e2d0061,0x7bce196c,0x75270031,0x291c008e}},	// [3b90] uvab, _atbu, _pajz, keva_
  { {0x291c001c,0xdd9b002d,0x61fd0269,0x61e9005e}},	//   jeva_, іша_, musl, _rvel
  { {0x68e3196d,0x6e2d005e,0x69c0196e,0x2b840060}},	//   vand, svab, _aume, lıca_
  { {0x68e30052,0xc2c50012,0x45d50024,0x3d0e0011}},	//   wand, ريتي, _помс, त्ते_
  { {0xe5c40015,0x68e3196f,0xe4d70012,0x44310034}},	//   _ассо, tand, _يتسب, _wrz_
  { {0xe8e0001a,0x25b81970,0x2a580009,0x4dda0009}},	//   _kiều_, _girl_, ובדן_, _מחשו
  { {0xa7b50001,0x9991000e,0x7a470035,0x1fb50c7b}},	//   нсиј, éből_, _sūtā, нсир
  { {0x7ae00058,0xf625004c,0xa2950024,0xb0b80009}},	//   _gemt, едио, _забі, ופוס_
  { {0xe6160015,0x61e902a1,0xe8e00081,0xfce50479}},	//   еды_, _uvel, _liều_, нопо
  { {0x1c45002d,0x61fd0051,0x7bc80061,0x7d090001}},	//   еном, dusl, _éduc, чног_
  { {0x69c00052,0xa0380012,0x15f30011,0x9f580025}},	//   _zume, _يأمر_, ेंडर_, suré_
  { {0x35da0037,0x68e11971,0x66091972,0xd6d90034}},	//   _मौक़, _held, ptek, ykły_
  { {0x61fd0051,0xb69b004b,0x7e7b1973,0x9c7c090a}},	//   gusl, _scân, _župn, rača
  { {0xdb19007d,0xc5680012,0x68e100b0,0x395e0097}},	//   _cuvâ, _يحول_, _jeld, óts_
  { {0x2bc60044,0x0396085b,0x7b96002d,0x68e11974}},	//   _रूपा, _прия, _приї, _meld
  { {0xa5bb0149,0x28d00037,0x20050054,0xdcd80011}},	//   _próp, _त्रि, àlia_, यर्फ़
  { {0x61ed001c,0x9c7c1975,0xe5060037,0x7ae61976}},	// [3ba0] šalj, načn, _शामि_, makt
  { {0x8d760003,0x7ae61977,0x2cbc00b0,0x7ae00060}},	//   راءا, lakt, øvd_, _semt
  { {0x291c00c1,0x60db0009,0xadb70012,0x50db01b0}},	//   veva_, _מקינ, رهما_, _מחיצ
  { {0x9c7c00f1,0x7ae61978,0x14170012,0xa6db0097}},	//   kačn, nakt, عينة_, _boðu
  { {0x291c1979,0x68e10060,0x629a0034,0x7ae00030}},	//   teva_, _beld, ętow, _vemt
  { {0x3d060037,0x6fc7003a,0x291c0164,0xfcd60012}},	//   स्खे_, _sıca, ueva_, _سيرج
  { {0xdfd00003,0xc9530009,0xa3ea0011,0xc8c70012}},	//   جيب_, רמו_, _मिट_, روين_
  { {0x68e10051,0x7d1e197a,0x501b0009,0x65a60097}},	//   _eeld, leps, פופו, iðhe
  { {0x68e106ea,0x3377000b,0xe7310009,0x44440d29}},	//   _feld, _נתמך_, בֵי_, lx_
  { {0x61fd0051,0x9162001a,0xba170012,0x68e1197b}},	//   vusl, _dự_, _سيما_, _geld
  { {0xe2f90024,0x05770009,0x24980040,0x23600227}},	//   мені_, תגים_, ærm_, _blij_
  { {0xe453000b,0x44441000,0xdd2f0066,0x61fd01a3}},	//   רֶץ_, ix_, _měři, tusl
  { {0xc3330093,0x3f800002,0xa3e70011,0xceb90030}},	//   אור_, dniu_, _मौन_, teře_
  { {0x2b8400a2,0x7e7d0029,0x3f80197c,0x7ae60227}},	//   rıca_, úspe, eniu_, aakt
  { {0xe8950015,0xdfd10003,0x7b06004a,0x7d1e197d}},	//   тавь, شيء_, ättö, deps
  { {0x7ae600a2,0xc49b000b,0x4c9b000b,0xcf980001}},	//   cakt, _משות, _משוע, еју_
  { {0x2b9c0066,0x6d5a0060,0x0bb80009,0xceb90030}},	// [3bb0] mích_, okta, _אלהם_, peře_
  { {0x2b9c0066,0x6d5a197e,0x4a7c0009,0xc27c0009}},	//   lích_, nkta, _מרחב, _מרחי
  { {0xd7950003,0x61ed0133,0x6d4e0604,0x9c7c01bd}},	//   _للدخ, _hval, _doba, začn
  { {0x2b9c0013,0x68e7000f,0x29030028,0x52b50003}},	//   ních_, lajd, lgja_, نماذ
  { {0x22580047,0xaa580794,0xe1ff01e3,0x2bb80012}},	//   ницы_, ницу_, nuó_, رامة_
  { {0x865a0093,0x29030065,0x672d0005,0x2b9c001a}},	//   _חדשי, ngja_, ldaj, hích_
  { {0x91620020,0xe8e00020,0x7ae60033,0x0138000b}},	//   _sự_, _hiểu_, yakt, תרות_
  { {0x672d0005,0x6d4e003e,0xe8e0001a,0xee390146}},	//   ndaj, _zoba, _kiểu_, дни_
  { {0x27e00027,0xe29f0028,0x2564000e,0xf6510012}},	//   ćina_, _áð_, _föld_, شئة_
  { {0x9c7c0107,0xdb1c0623,0x7ae60631,0xdd8e0012}},	//   račn, _strø, wakt, يوي_
  { {0x9c7c0029,0x80ca01e1,0x61ed188b,0x5504004c}},	//   sačn, _स्टे, _aval, учња
  { {0x91620020,0x6d5a007a,0x628c003e,0x87d40003}},	//   _tự_, akta, żnoś, _إغلا
  { {0x2d870029,0x1d090001,0xcad6000b,0xa5450012}},	//   čnej_, _жели_, כורת_, _لضغو
  { {0x29030065,0xcdf60009,0x74290012,0x7ae6197f}},	//   ggja_, _ימני_, _يكشف_, sakt
  { {0x28c60037,0xb7960001,0xdff50109,0xdee6062c}},	//   रुटि, враћ, лять, кови
  { {0xe8e00020,0x93fa000b,0x2b9c014a,0x3d140037}},	//   _biểu_, _חלקי, cích_, न्ने_
  { {0x7e690052,0x29130028,0x660d1980,0xe6c50012}},	// [3bc0] nzep, únað_, gtak, اتفي
  { {0x69fb0093,0xa6db0065,0x3f800010,0x63a91981}},	//   _קליק, _boðs, sniu_, _ahen
  { {0x44440108,0x6faa0046,0x7ae41982,0xb5130037}},	//   ux_, _овог_, _keit, त्यय_
  { {0x7bc30065,0xe29f0028,0x5ea60012,0x44271983}},	//   _munu, afðu_, _لمجل, _msn_
  { {0x63bb00b6,0x2b9c0042,0xc4c60012,0xf1aa0012}},	//   _diun, níci_, _لتزو, واته_
  { {0x7ae4014d,0x2b9c0066,0x442700d9,0x23a7005e}},	//   _leit, zích_, _osn_, võje_
  { {0xebe30047,0x317b000b,0xb8070003,0xb0ac0011}},	//   _восп, ורסמ, نيوم_, टेंग
  { {0x63bb00c1,0x59dd0037,0x80aa0011,0x7ae41984}},	//   _giun, _नौकर, _टरने, _neit
  { {0xf7730093,0x8f9b0093,0xb5a60015,0xafb70003}},	//   יקה_, ויקי, крой, خطوط_
  { {0x6d5a0010,0x7bc31985,0x672d1986,0x201a079b}},	//   ukta, _bunu, zdaj, _oppi_
  { {0x2cfb000b,0xa4fb000b,0xfc660014,0xb4fb000b}},	//   וליא, וליט, тъпн, ופיי
  { {0x1877000b,0xa3e40037,0x3f800010,0xa6e20028}},	//   _בעבר_, पीय_, čius_, áðla
  { {0xddd60002,0xbef7000b,0x7e690002,0xd3370009}},	//   rzyś, _יצאו_, czep, דרכה_
  { {0x6c340003,0xbea30001,0x06570009,0x2b9c0030}},	//   _مفتا, _тачк, _בידך_, sích_
  { {0x7bc300b6,0x6db20002,0x7ae41987,0x1c0e0011}},	//   _gunu, _sław, _feit, _सहगल_
  { {0x61ed007a,0x2d9e008b,0x68e7003a,0xf1c20011}},	//   šali, llte_, sajd, शदान
  { {0xdbca0051,0x7b740003,0x63660164,0x63bb00c1}},	// [3bd0] _mõõt, _خطوا, _dónd, _riun
  { {0x7ae4008b,0x63bb007a,0x63660164,0xc4dd0011}},	//   _zeit, _siun, _póng, यरेख
  { {0x6be40003,0x70550012,0x63a91988,0xd49b00db}},	//   لكلم, _إنجا, _phen, фра_
  { {0xe8e0001a,0x2d9e0052,0x4c940015,0x7b940024}},	//   _tiểu_, hlte_, шихс, арії
  { {0x92670003,0x4efa0009,0x61eb0032,0x3c2c0031}},	//   خدام, _אהרו, usgl, tóvá_
  { {0xdb1c000d,0x63a9002a,0x4a5c0009,0xa4d40024}},	//   _curâ, _when, ודדו, _ворі
  { {0x10150003,0xf1b40009,0x63a91989,0xd2e30011}},	//   ابتد, בסס_, _then, _ख़ूब_
  { {0x68e5004a,0x07090012,0xab95178f,0x2d9e0347}},	//   _lehd, ريخي_, _сибі, elte_
  { {0x7bc300a2,0xa3e70037,0x853c0010,0x79c80012}},	//   _sunu, _मौत_, ymėt, _لوقف_
  { {0x7ae4008b,0x7e690002,0x7bc30fa5,0x26b60009}},	//   _seit, rzep, _punu, טִים_
  { {0x672b000e,0x79950002,0xb9070037,0x64e10011}},	//   _tagj, dozw, पर_, _फ़ैश
  { {0xa2aa0011,0x69c4005e,0xbb860012,0xb7da0009}},	//   जेक्, _puie, الحي, _נקני
  { {0x69c4198a,0x7ae40028,0xe8e00081,0x07a40024}},	//   _quie, _veit, _liễu_, _таїн
  { {0x7ae4008b,0xdb1900c5,0xceb20009,0x867a0009}},	//   _weit, _nuvæ, _היד_, _ארנו
  { {0x7646004a,0x2b9c0066,0xb4df0037,0x3a29003a}},	//   äkyv, síci_, तरी_, _esap_
  { {0xfbd2000b,0x80d40037,0xfc560009,0x853c0073}},	//   _פתח_, _ब्रे, _תבקש_, alėd
  { {0x224600a2,0x366702ca,0x8fa3004d,0x44fa0012}},	// [3be0] _çok_, гато_, сате, فراج_
  { {0x8c46022a,0x044603e2,0xf1bf0031,0x67200035}},	//   лезе, лезн, rvát_, zemj
  { {0x201a0028,0x5bc50012,0x6f040248,0x6b82071e}},	//   _uppi_, لتنف, pgic, tnog
  { {0xe5130037,0x25e80011,0xb82701d4,0x67d10035}},	//   त्ति_, _चौथी_, _союз_, _mājd
  { {0x32020029,0xcb130009,0x6a130012,0x0e560048}},	//   nuky_, מלא_, مبور, _съня
  { {0x7521000f,0x1836000b,0x082a003c,0x20ca0012}},	//   jelz, ָאֵל_, еции_, ربتي_
  { {0x8d6300f5,0xe0860012,0x8cda0011,0x22590034}},	//   _увре, دجشي, _प्यो, zysk_
  { {0x17540014,0x998d000d,0x2d9e0052,0xcf260012}},	//   рвия, _preţ_, wlte_, ارثي
  { {0xe4e6002d,0x28cf0011,0xdb0401e3,0xcb67004c}},	//   лінн, _स्कि, _chií, _сате_
  { {0x2d9e000d,0x7c220002,0x80d40321,0xc2370009}},	//   ulte_, łoru, _ब्ले, _גרמו_
  { {0x0d970093,0x9c7c001c,0xcd97000b,0x9f580164}},	//   רכים_, mačk, רדית_, ntró_
  { {0xa4b7000b,0x4fa30014,0xda350015,0xab95002d}},	//   טליה_, _лихв, аемы, римі
  { {0x629e0002,0x63b80029,0xed5a0da9,0xd7930012}},	//   ępow, ívny, _под_, _النخ
  { {0x28d00011,0xd0060012,0xe29f0097,0x31350476}},	//   तुलि, يل_, ggða_, шегр
  { {0x657a01a6,0x3cf70012,0xf3ef0012,0xa8180009}},	//   mith, _صعود_, _فأي_, כֵּי
  { {0x889b0009,0x82390048,0x387e0064,0x643b0009}},	//   גבלי, _азис_, útra_, _טעונ
  { {0xccfb0046,0xdd750001,0x3a29002c,0x25ee0037}},	// [3bf0] еће_, агањ, _usap_, ेंगी_
  { {0x6376012e,0x9c7c0027,0x31c40014,0x2d87005e}},	//   jšnj, jačk, _усъв, õne_
  { {0x19ba0009,0xa2d50012,0x63a3004b,0x67d10035}},	//   _שמתב, ليات, înno, _kāje
  { {0xa2e30037,0x92590015,0x799a002c,0x6e950024}},	//   _ख़ोज_, кает_, _aktw, _виму
  { {0x81c70333,0xf9910012,0x20030030,0x4438198b}},	//   klēš, يبت_, luji_, _err_
  { {0x645a0010,0x9c7c1831,0x8dfa0009,0x45fa0009}},	//   kyti, gačk, _בהשת, _בהשג
  { {0xa1560046,0x3158000b,0x9c290009,0x04290009}},	//   рају_, ריון_, _בֵּ֥, _בֵּֽ
  { {0x63ad0020,0xbe39002d,0x645a00aa,0x96b90560}},	//   _nhan, вчої_, dyti, купу_
  { {0x3eb9006f,0xa3e70037,0x9f4c0061,0x20030030}},	//   äst_, मीन_, édé_, huji_
  { {0x7bc70005,0x0555010c,0xb4df0011,0xf5320009}},	//   _kuju, ртия, तरे_, ַ֥ת_
  { {0xe8e00020,0xcb6a198c,0x7bc7198d,0x64a50de1}},	//   _hiệu_, ване_, _juju, рана
  { {0x63ad198e,0x672f0034,0x98a50035,0x7aeb020d}},	//   _chan, _nacj, _galā_, nagt
  { {0x6db2003e,0xe7e80011,0xc7b20009,0x7c2a0018}},	//   _płat, टीना_, _ובא_, _esfr
  { {0xa2aa0037,0xe0860012,0x320206dd,0x645a0064}},	//   जेट्, لجزي, ruky_, byti
  { {0xb8ce015f,0xe8e00020,0x661d134f,0xd466002d}},	//   _और_, _liệu_, _apsk, _вище_
  { {0xd0070046,0x6b890082,0x7aeb0058,0x2b40000d}},	//   јете_, _njeg, jagt, _unic_

  { {0x539b000b,0xc4e60015,0xdb9b01b0,0xe4d60012}},	// [3c00] _ביקו, ижай, _בסקר, لتاب
  { {0x6db20002,0xee370538,0xbce50012,0x9a3b0009}},	//   _ułat, шну_, مأمو, _יתפק
  { {0xb4d60044,0x9c7c001c,0x72c6002d,0xe0fb000b}},	//   _सभी_, vačk, абез, _בליל
  { {0xeafa0003,0x7aeb0058,0x6d5e005e,0xb5fd0159}},	//   ئرات_, gagt, skpa, azši
  { {0x78c5000f,0x2d82000e,0x6724004a,0x9f58198f}},	//   _átvá, ékek_, meij, stró_
  { {0xca370009,0x49730024,0x28f7003c,0xe8e00081}},	//   יננה_, оліс, аешь_, _diệu_
  { {0xa1270003,0x9d1b0009,0x9c7c001b,0x6604008e}},	//   شكيل_, _שולט, račk, luik
  { {0x03d7000b,0x8bd7000b,0xd1380002,0x61fd0028}},	//   _כולם_, _כולו_, _skąd_, yrsl
  { {0xf11a000a,0xbafb000b,0x20030066,0x8afb0009}},	//   _لغات_, _שהמש, zuji_, _שהמי
  { {0x4096035c,0x9c7c0a16,0xd8430030,0x645a0073}},	//   _крет, lači, ličů_, tyti
  { {0x7bc0000e,0xc334000b,0xf19b0009,0xdcfa004b}},	//   _kimu, ֖וֹ_, _ישמש, entă
  { {0x6db20002,0x5e260012,0x59dd0011,0x3d170011}},	//   _płas, _نعتق, नीकर, ब्बे_
  { {0xd2460003,0xa5f80177,0x2c080011,0x672f0034}},	//   أن_, _селу_, ांडू_, _racj
  { {0x7af6003e,0x6e970024,0x6e3b0009,0x20030030}},	//   _edyt, _твір_, _שתגד, tuji_
  { {0x63ad1990,0x6db2003e,0x68e81991,0x3fb70012}},	//   _than, _włas, _medd, لإرس
  { {0xdcfe0039,0x1cbb000b,0x501b000b,0x68e8013f}},	//   kopē, _במוע, כולו, _ledd
  { {0x7a1a001e,0x91e4004c,0xd8430030,0xa3e40011}},	// [3c10] nātā, _доње, dičů_, पीस_
  { {0x98b80037,0x63a208ce,0x621a000b,0x6b9b03ce}},	//   ेखाए, elon, _עותק, _skug
  { {0x6366000e,0x6e360010,0x5c070048,0x6aa90034}},	//   _hóna, avyb, ряза, _szef
  { {0x33840014,0xc9f50003,0x9c7c0027,0x27fe0029}},	//   оучв, مستع, gači, átne_
  { {0x5694007c,0xf1da0037,0x7ac4002d,0x7bc000b6}},	//   _мают, _बढ़ान, ісце, _dimu
  { {0x7bc700c6,0x7a1a001e,0xceb6000b,0x98ac003a}},	//   _tuju, dātā, _לפרק_, _aldı_
  { {0x6296003a,0x7aeb002c,0x9f050012,0x286b0048}},	//   üyor, pagt, موثو, ърдо_
  { {0xbb85000a,0x43850003,0x6458004a,0x2d9c001b}},	//   _الري, _الرق, ävie, _akve_
  { {0x16390003,0xa7620014,0x6d551992,0x68e8068e}},	//   اسبة_, якъд, _koza, _fedd
  { {0xfd49003c,0xdce10035,0x4d6510c2,0x85490357}},	//   узок_, vilē, сков, узов_
  { {0x94750003,0xca290009,0x9b460012,0x3f580018}},	//   إدخا, _רם_, مندو, _céus_
  { {0x7a1a0035,0x78bc0097,0x99840030,0x6d410097}},	//   bātā, _úrva, ímž_, _ólaf
  { {0xdce8003a,0x7ae91993,0xe1ff1994,0xed4e0048}},	//   aldı, _meet, gró_, _ео_
  { {0x2bcf0044,0x999f003e,0x6d55001e,0x23cf0011}},	//   _संपा, _usuń_, _noza, _संपद
  { {0x3fa60003,0x6d431995,0x3d0b0011,0x6e291996}},	//   مصرف, _inna, ालने_, lweb
  { {0x6f0900b6,0x290c0002,0xe5130037,0xa3e70011}},	//   ngec, żda_, त्रि_, मीण_
  { {0x7bc001a2,0xf1a70037,0x9c7c0ecf,0xda660012}},	// [3c20] _rimu, गतान, vači, _داغي
  { {0x660400bd,0xa3de0011,0x8066004c,0xca370009}},	//   ruik, दीक_, _гвож, _פניה_
  { {0xd5c8001a,0x63a205e2,0x3a2d00b6,0x2d82000e}},	//   _nền_, tlon, _asep_, ékei_
  { {0x63a2002c,0x69c11997,0xcb090024,0x68ee057f}},	//   ulon, _aile, ихід_, labd
  { {0x2905000e,0xffb70009,0x82330012,0x9c7c1998}},	//   ólag_, _ללטש_, كروا, rači
  { {0x7a1a001e,0x63a2017b,0xe6e00011,0x044606bd}},	//   vātā, slon, नर्ज, _легн
  { {0x7bc000c6,0x9c7c003d,0xf0e60011,0x17f70012}},	//   _timu, pači, _क़ैद_, مرية_
  { {0x984c001e,0x26df002c,0x7ff30012,0x232a0024}},	//   dēļa_, gbuo_, أسوا, _щоби_
  { {0x2cea064f,0xa5bb0aa1,0xc693000b,0xb4c00011}},	//   льно_, _próx, ּאת_, ंख्_
  { {0xd657000b,0x0e570009,0x71d70009,0xda650012}},	//   ציית_, משפט_, _לומד_, _بافي
  { {0x40960003,0x60d7000b,0xb8960012,0xaf0a0012}},	//   _الضر, _הובא_, _الضع, _مقام_
  { {0xdfcf0003,0x69c1000d,0x65b0004a,0x6d430038}},	//   _أين_, _zile, lähd, _enna
  { {0x36360003,0x2918006f,0xaaba0011,0x2d9a0035}},	//   _دراس, ffra_, ेशिक, kope_
  { {0xdd8f0003,0x7bda005e,0xdd900012,0x7db40012}},	//   _كون_, pptu, _توت_, _بمتص
  { {0xc7f80009,0x4d7b0009,0xa3e70011,0x4ff80009}},	//   יִּר, _תרוע, मीद_, יִּנ
  { {0x28d90044,0x78a90030,0x44a30012,0x2e4b0048}},	//   _ब्रि, řevo, _عميق, лязо_
  { {0xa2a00037,0x67d1001e,0xedd50012,0xe6100012}},	// [3c30] _गुप्, _māja, زياد, فشل_
  { {0x7ae90051,0x443c142f,0x65b0008e,0x6f090060}},	//   _seet, _krv_, jähd, zgec
  { {0x7ae90051,0xb8df0037,0x69c11999,0x3ea60035}},	//   _peet, ेश_, _rile, ļota_
  { {0x1dc80037,0xdc9b0009,0x2564199a,0x69dd005e}},	//   रदात, ניאל, _höll_, opse
  { {0x2bcf0037,0x7ae90051,0xe2990001,0x69c9199b}},	//   _संभा, _veet, јал_, _quee
  { {0x61420046,0xc27c0009,0xa0090012,0xe1ff0034}},	//   деша, נרגי, لقتل_, szów_
  { {0x47d20003,0x7aef0070,0x40ec0009,0x02fb0011}},	//   ويور, kact, אַחֲ, ्लाह_
  { {0xf771000a,0x7fe80003,0x27e50029,0x23cf0037}},	//   بات_, حروف_, álny_, _संबद
  { {0x645c01fb,0x443c0051,0xf505002d,0x9758000b}},	//   ørin, _arv_, озпо, מיהו_
  { {0xe5790103,0x28d90011,0x6b8d005e,0x98a70034}},	//   рзо_, _ब्लि, _ajag, edną_
  { {0x6e3c001e,0xfb8a0021,0x34a9035c,0x1b4a00f5}},	//   ārba, ибок_, рвно_, азни_
  { {0x920d01e1,0x2007199c,0x93680009,0xdce90060}},	//   _समाज_, muni_, ֶ֣רֶ, ının
  { {0x539a000b,0x645e0002,0xd7f1001a,0xd6e80009}},	//   שירו, zypi, ẫn_, _הַצָ
  { {0x6f1d008b,0x645e004a,0x443c0028,0x3f890032}},	//   _absc, yypi, _frv_, enau_
  { {0x65b00052,0x659a0009,0x29180192,0x4f7a003c}},	//   nähe, _דיסק, rfra_, ащая_
  { {0x2087002d,0xdee60012,0x2bd005f3,0xa3ae05f3}},	//   ійти_, تأسي, _तंबा, _कठि_
  { {0xbea317fe,0x98c90037,0x27e00027,0x200700b6}},	// [3c40] датк, िखाए, ćini_, huni_
  { {0x4c860014,0xc6030015,0x31a4000e,0xe5060012}},	//   олзв, ьзуй, közi_, تبري
  { {0x8c260012,0xfc2a003c,0x2d9a199d,0x7ac6199e}},	//   تفاه, ржек_, rope_, осле
  { {0x8cda0044,0xe73a08b0,0xd1160037,0x3e700061}},	//   _प्रो, _тем_, द्रण_, _côté_
  { {0xbddb03eb,0x094a0ac5,0x27ed0027,0x9c7c0029}},	//   _crèd, ички_, ćene_, lačt
  { {0x7aef007d,0x66160262,0x422b0009,0x65ab005e}},	//   zact, mtyk, שֵׁ֣, püha
  { {0xa0670001,0xf66a0028,0x200714d5,0xdb0f0042}},	//   жаја_, kvæð_, guni_, ždéh
  { {0xeb970024,0xc7ba003c,0x8b23004c,0x7bde008e}},	//   _дис_, шёл_, _одсе, mppu
  { {0xc7b30093,0xed8a0800,0x3ea20028,0x66160914}},	//   ובה_, исок_, ækt_, ntyk
  { {0xdb0d0061,0x443c0029,0x66160010,0x7bde0feb}},	//   _chaî, _prv_, ityk, oppu
  { {0x200701a2,0xc4d3000b,0x4f660012,0x32020064}},	//   cuni_, וגת_, _واصف, erky_
  { {0x66160002,0x0a6b0024,0x926b0560,0xb09b0009}},	//   ktyk, арги_, арга_, _דיבר
  { {0xcaa70003,0xb5fd0066,0x69dd008e,0x6d4e005e}},	//   تصدي, uzšt, upse, öbas
  { {0x9f5800c1,0x2fd70012,0x314a0009,0x7aef199f}},	//   errà_, قترح, ׁתָּ, sact
  { {0xd5b80039,0x75280026,0xd5c8001a,0x645c0051}},	//   mmā_, medz, _mềm_, ärid
  { {0xa857000b,0x75280002,0x92950024,0x2bcf0011}},	//   חילה_, ledz, _найц, _संता
  { {0x9c7c048b,0xa6e20028,0xe6670024,0x97570009}},	// [3c50] raču, óðan, цтво, קימו_
  { {0x8c67000a,0x7528000e,0x6d580027,0x27fe09d2}},	//   يطان, nedz, _jova, štna_
  { {0xdd980024,0xa1b80012,0xdee70012,0x75280034}},	//   ішу_, _بطيء_, _وأحي, iedz
  { {0x8c1b000b,0xb09a0009,0x3b640048,0xb5fd0030}},	//   שואי, _ליתר, мъчв, lyše
  { {0x32f20003,0x9a270012,0xeb920009,0x7bde19a0}},	//   ركوز, تعان, עָב_, appu
  { {0x26c70066,0x6d5819a1,0xae5a0009,0x81050011}},	//   ěnou_, _nova, _הכשר, रलेख_
  { {0xa3ae0037,0x53c60011,0x2bc60011,0xe0420367}},	//   कतम_, _रंगश, _रंगा, енщи
  { {0x7aed0113,0xdb1c066d,0x6f0d19a2,0x87e30011}},	//   _neat, _strö, ngac, टीएफ़_
  { {0xc3320009,0x7bc4005e,0x7afb0073,0x49750fb1}},	//   _און_, _riiu, _idut, _елас
  { {0xa5090001,0x1d090001,0x20070d03,0x7ac40024}},	//   љена_, љени_, puni_, _істе
  { {0x04450094,0xc2090009,0x6d5c005e,0x6e2d0e00}},	//   ченн, _תה_, öraa, hwab
  { {0x69c50006,0x1036000b,0xeaa70003,0x661619a3}},	//   _aihe, _מטעם_, فع_, ytyk
  { {0x7aed0036,0x2564006f,0x6b8b010a,0xd36f0012}},	//   _deat, _dölj_, ingg, اهُ_
  { {0xb2270065,0x2d82000e,0x4dda0009,0x8e560009}},	//   _svæð, éket_, _החסו, _מינג_
  { {0x7aed0036,0x2564006f,0xdca20430,0x69c5016d}},	//   _feat, _följ_, _паши, _dihe
  { {0xf412000b,0xdfcf0003,0x10a3002d,0x645c008e}},	//   _נפח_, طيك_, хисн, ärie
  { {0x6729001e,0x05660014,0xa3e70011,0x644e005e}},	// [3c60] ieej, пван, मीर_, äbiv
  { {0xdd920003,0xaa3b000b,0x66160002,0x6b8b00b6}},	//   روض_, _פתיח, rtyk, engg
  { {0xdd8f000a,0xe1ff000e,0x661619a4,0x515b0009}},	//   دول_, szót_, styk, _הכיו
  { {0x7f4a0003,0xe3c9001a,0x75280002,0xd379002d}},	//   _الحق_, _nằm_, zedz, очі_
  { {0x7ae219a5,0x19560009,0x463a0024,0x201819a6}},	//   rbot, ּבֶל_, _учня_, ltri_
  { {0x6b8b0160,0xdcfa001e,0x61e9002a,0x6933002d}},	//   angg, rotī, _dwel, еншу
  { {0x7c5a0003,0x75280029,0x200a13cd,0x80b80011}},	//   _الزر_, vedz, nubi_, ेखें
  { {0x95d80047,0x75280002,0x20180159,0x78a10031}},	//   одит_, wedz, itri_, ülvi
  { {0xe8e0001a,0x7bce00b6,0xe666002d,0x660419a7}},	//   _chịu_, _hubu, ятко, nrik
  { {0x63ae0010,0x2056002d,0xe2450012,0x24e30024}},	//   šinė, _нтер, _تخفي, нцюг
  { {0x75280039,0x7aed0005,0xd5b8001e,0x63660028}},	//   redz, _peat, rmā_, _tónl
  { {0x98ac001e,0xa3e40037,0x93270003,0x80250012}},	//   _gadā_, पीए_, أردن, _تركم
  { {0x27e00027,0x65ab0052,0x16340063,0xdb9b0009}},	//   ćinu_, fühl, _целя, מסטר
  { {0x35b3002d,0xb6bb0009,0xdebb0009,0x4dfb0009}},	//   _збір, _הצדי, _המדל, _פפוא
  { {0xad1b007e,0x98c1001e,0x26c20029,0x443a001a}},	//   _הוור, _āpēc_, ľkou_, _ép_
  { {0x27ff102c,0xee3f0066,0x3f5c0028,0x26c20042}},	//   čun_, _prý_, _síur_, žkou_
  { {0x5afc000b,0x69c50269,0x4b7c0009,0xe6130012}},	// [3c70] _הלחצ, _tihe, _לאהו, عشر_
  { {0x2d9e19a8,0x853c0010,0x7bce0a60,0x77a50056}},	//   note_, klėm, _bubu, róxi
  { {0x2d8119a9,0x394b0081,0xe1ff0034,0x61e90bb5}},	//   rihe_, _đcs_, czór_, _swel
  { {0x2bcf0037,0xcff6000b,0x660419aa,0x23cf0011}},	//   _संसा, _קצרה_, brik, _संसद
  { {0xcf56000b,0xb90a001a,0x2d9e0010,0x7f3a0009}},	//   _חברת_, _nghệ_, kote_, _וערו
  { {0x2d9e19ab,0x32380009,0xa3b40011,0x10a50048}},	//   jote_, פטון_, _जीन_, милн
  { {0x999f000e,0xd404003c,0xd12e0012,0x2d9e19ac}},	//   éről_, _пяти, شمي_, dote_
  { {0x853c0010,0x61e9002a,0x387e0029,0x6d5c00e5}},	//   slėl, _twel, útri_, öran
  { {0x7bd2001e,0xee36003c,0x61fb001b,0xef16003c}},	//   ējuš, дны_, šulj, фмы_
  { {0xe81e0044,0x9e640003,0xb465028b,0x3c6504a5}},	//   _पहला_, عاين, дкол, дког
  { {0x9cd60009,0xa1560009,0x61fc0035,0xdb060031}},	//   וותה_, _קבעה_, _ārli, llké
  { {0x2d8c0643,0x889a0009,0x7983020d,0x25fe0011}},	//   ande_, _ובעי, linw, _लिली_
  { {0x2bcf0044,0xf7700003,0x0caa0037,0x95550003}},	//   _संवा, _حال_, _कर्म, _يختا
  { {0xd5bb002d,0x2d9e19ad,0x66ba0009,0xd1320012}},	//   _усе_, cote_, _ומנה, خمس_
  { {0x3f8d03eb,0xa3bf0037,0x475a0015,0xbca50012}},	//   oneu_, ीदा_, орая_, _تمثي
  { {0x290400a2,0x27fe009b,0x93960012,0x79830032}},	//   şma_, štno_, _تجتا, hinw
  { {0x80a40044,0xdcfa0039,0x1da90037,0x27ed0027}},	// [3c80] _चुने, litā, कतंत, ćena_
  { {0x59830109,0xe2a90012,0x05850024,0xb9c60012}},	//   _альб, _عاين_, нуєм, _تتعه
  { {0xdcfa001e,0xec770024,0xdb06017a,0x660419ae}},	//   nitā, мпф_, elké, srik
  { {0x61e9007d,0x2ca70065,0xdb160025,0x200508ca}},	//   ţele, _mynd_, écèd, álie_
  { {0x6a130012,0xe46a005e,0x2d8c19af,0x6b8219b0}},	//   نبور, otöö_, ynde_, riog
  { {0x6b82007a,0x23660027,0x7bce00b6,0x7c3a0029}},	//   siog, skoj_, _tubu, _štru
  { {0x2d9e007a,0xa3ae0037,0x7bdc19b1,0xa2a00011}},	//   vote_, कता_, _utru, _गुस्
  { {0xc6f81104,0x96ea002d,0x93430001,0x236d009b}},	//   чних_, цька_, _инсе, _glej_
  { {0x2d9e0010,0x6d5c19b2,0x98a70030,0x626600ae}},	//   tote_, _kora, odně_, _غارق
  { {0x63a40101,0x7c3e009b,0x6d580051,0x6454004c}},	//   _akin, ovpr, övah, евођ
  { {0x7bda0108,0xb4de0037,0x2388000e,0x6d5c12a2}},	//   _étud, _तभी_, zője_, _mora
  { {0x69c60037,0x3dc70032,0x7c3a0031,0x2d9e19b3}},	//   ादकी, _einw_, _átru, sote_
  { {0x7e9a0003,0x66730012,0x0a6b0024,0x61e219b4}},	//   _بنشر_, _لدور, ірми_, npol
  { {0x6d5c0039,0x63a40060,0xe9ff0081,0x23880031}},	//   _nora, _ekin, hiếc_, vője_
  { {0x58d4026d,0x6458008e,0x69c819b5,0xd59b0009}},	//   тост, ävil, _mide, _ובגל
  { {0xc3fb000b,0x2388000e,0x93fb000b,0x4bfb000b}},	//   _ולהש, tője_, _ולהי, _ולהס
  { {0xd0d50014,0x60da0052,0x6d5c19b6,0xbdb5004c}},	// [3c90] _попъ, _oftm, _bora, ебај
  { {0x25690028,0xb0350024,0x23b20031,0x99990034}},	//   _núll_, _знош, mája_, żyło_
  { {0x23b2000e,0x3f840010,0x2ca70040,0x23880031}},	//   lája_, kimu_, ænd_, sője_
  { {0x14df0044,0x66020010,0x3f840010,0x69c80573}},	//   _प्रण, šoka, jimu_, _aide
  { {0xdb160061,0x7e760002,0x6d5c19b7,0xdcfa0035}},	//   écéd, czyp, _fora, zitā
  { {0xe3d70012,0x80c90011,0x6d5c19b8,0x753819b9}},	//   _يتزع, िखें, öral, _navz
  { {0x69c819ba,0x25a10066,0x6bd40012,0x10a20479}},	//   _dide, mohl_, _لتقر, лишн
  { {0xdcfa0039,0x6d4a031d,0x23b20031,0xd00c0009}},	//   vitā, _anfa, kája_, קּוֹ
  { {0x3f8d03eb,0x76420573,0x61e20002,0xee390024}},	//   rneu_, _croy, cpol, їно_
  { {0x69c8003a,0x68f5084b,0x78270012,0x672d005e}},	//   _gide, jazd, _يعال, heaj
  { {0x9814000a,0x98ac000d,0x61ed00b6,0x809f0011}},	//   _لبنا, _vadă_, _awal, _खुले
  { {0xd7c80003,0xdcfa001e,0x69c80002,0xe29a096e}},	//   _قوله_, ritā, _zide, зам_
  { {0x7bc90061,0xc7b2000b,0x57780012,0x56670012}},	//   _mieu, _עבד_, _تصلح_, _تداف
  { {0xdcfa001e,0x68f5000e,0x7bc90ebe,0xf9920012}},	//   pitā, gazd, _lieu, ابح_
  { {0xf9920009,0xdfd20003,0xa3bf0037,0x61e204d2}},	//   טרך_, اير_, ँगा_, zpol
  { {0xe29a0098,0x7bc919bb,0xe46a0051,0x63a400eb}},	//   _най_, _nieu, stöö_, _ukin
  { {0xdd92000a,0x661b00c6,0x6d5c19bc,0x82360012}},	// [3ca0] هور_, ntuk, _pora, _أربا
  { {0xd29b0093,0x661b0006,0xba9b000b,0xa3b40037}},	//   _משפט, ituk, _מספי, _जीत_
  { {0x61fb0006,0xdcfa007d,0x6d5c0052,0x2619001a}},	//   _avul, lită, _vora, hèo_
  { {0x673b003e,0xeb9719bd,0x69c819be,0x6d5c0052}},	//   jduj, них_, _side, _wora
  { {0xdcfa007d,0xd9d7002d,0x3f840010,0x61d7002d}},	//   nită, емії_, vimu_, емія_
  { {0x61e4007d,0x916c001a,0x63ab005e,0xe5a60198}},	//   ţilo, _bốn_, algn, _чиги
  { {0x7dc90010,0x877a0009,0x2d8511e8,0xc7c60048}},	//   _užsa, ּאִי, dile_, нсии
  { {0x764219bf,0x7c3e000e,0x26ee0037,0xf7720003}},	//   _proy, _ápri, _ज़ोर_, طاع_
  { {0x661b007a,0xf6520003,0xadc3001a,0x916c001a}},	//   gtuk, ائع_, _hoạc, _tồn_
  { {0x51fb0009,0x2d8519c0,0xdcfa004b,0x65b00032}},	//   _מהמצ, gile_, dită, zähn
  { {0x05770009,0x6443001b,0x4c9419c1,0x201a01a0}},	//   גגים_, _crni, тинс, àpid_
  { {0xe0df001a,0x63a2002c,0x20570009,0x6722001b}},	//   _đòi_, noon, _ריאל_, _uboj
  { {0x6458004a,0x2d8519c2,0x8b080030,0x78a40060}},	//   ävij, bile_, _spří, şivd
  { {0x4aa50037,0x65b00052,0x9e770009,0xce370009}},	//   _गुणव, wähn, _אגדה_, _נאות_
  { {0x395e01f2,0x27ed0027,0x63ab0028,0x63a200e6}},	//   _mots_, ćeno_, ylgn, koon
  { {0x25a1008b,0x2cb1003a,0x63a20574,0x34370012}},	//   wohl_, üzde_, joon, _أسود_
  { {0xdcfa000d,0xb9990001,0xa3ae0011,0x63a2005e}},	// [3cb0] cită, _ових_, कतर_, doon
  { {0x40950012,0x2dab0012,0x6d9c0060,0x7bc90d29}},	//   _للخر, ساءً_, _uçağ, _sieu
  { {0x63a20070,0x7bc90025,0x8b080030,0x661b0034}},	//   foon, _pieu, _upří, ztuk
  { {0x2007009b,0x7bdb0009,0xead80024,0x99620035}},	//   vrni_, פקדו, емці_, _cīņu_
  { {0x7bc90061,0x2396001e,0x1dd80011,0x395e19c3}},	//   _vieu, nāja_, _भूपत, _bots_
  { {0x9102004c,0xb08b0009,0x6be500ae,0x2d8519c4}},	//   апше, ּנֵ֖, _لكسم, xile_
  { {0x0138000b,0xb795004c,0xdcfa004b,0x395e19c5}},	//   גרות_, крић, zită, _dots_
  { {0x394c19c6,0xd6ce0012,0xb0380009,0x2d850034}},	//   _ends_, يقى_, תנהג_, wile_
  { {0xdce10039,0x661b0006,0xe3b00003,0x1a5b0003}},	//   eklā, utuk, _طرف_, _عشرة_
  { {0x4d65007c,0xdcfa000d,0x661b104a,0x1c450400}},	//   тков, vită, rtuk, вном
  { {0x2d8519c7,0x3d1901e1,0x661b083c,0x3b0a05fb}},	//   rile_, _पाने_, stuk, мено_
  { {0x6443012e,0x3d130037,0x00560009,0x6ee70012}},	//   _vrni, _दावे_, _בשעת_, _أسال
  { {0xff500003,0xd2f20011,0x9e640012,0x2d8511e9}},	//   _دخل_, _अजीब_, _ماون, pile_
  { {0xc01c0020,0xdcfa000d,0x3ceb0037,0xdce80010}},	//   _nước_, rită, टरों_, didė
  { {0x98a6010c,0x3c440012,0xc9520009,0xdcfa004b}},	//   тиве, _مضيف, סמל_, sită
  { {0xd00f0003,0x9a6a0003,0x7bd8000e,0xab9a0012}},	//   تلف_, _يمثل_, ívum, _تختر_
  { {0xc01c0020,0x7c24001b,0x9196004c,0x0e63016e}},	// [3cc0] _bước_, _ćiri, _ајнш, актн
  { {0x6d8b0039,0x5bca0037,0x63a20070,0xc01c001a}},	//   kļau, िद्व, woon, _cước_
  { {0xceea002d,0x1c090037,0x65630244,0xdce80073}},	//   _одне_, _विफल_, önha, aidė
  { {0x91e619c8,0x09e602ba,0x660919c9,0xd2660667}},	//   воде, водн, krek, ккей
  { {0x395e03eb,0x25640028,0x66090058,0x66e20066}},	//   _pots_, _sölu_, jrek, níků
  { {0x5e77000b,0xc27b000b,0x3913002d,0xfce301d4}},	//   _יתכן_, ורני, имір, _воро
  { {0xf993000b,0xa3c40011,0x98130012,0x395e01a0}},	//   ברג_, ौदा_, لبيا, _vots_
  { {0xf0930093,0x65b00052,0x660919ca,0x442a19cb}},	//   ינו_, zähl, frek, _ipb_
  { {0x395e03eb,0x9a250003,0xab5b0032,0x9663004c}},	//   _tots_, _معلن, hmüc, икће
  { {0x6b840583,0x25640028,0xd24f0012,0x114a0012}},	//   _amig, _tölu_, _بنك_, _تجرى_
  { {0x21750103,0xd00f0012,0xb4d20011,0x74140012}},	//   _сутр, _ولك_, _वली_, دوجا
  { {0xf4130093,0x23960039,0xdce10039,0x65b00052}},	//   ספר_, tāja_, rklā, wähl
  { {0xc3330093,0x2d8f000f,0xd2460003,0xed5a0014}},	//   בור_, égek_, حن_, _оод_
  { {0x753c003e,0xc987004c,0xd83808ca,0x68f819cc}},	//   _narz, туми, _ksč_, navd
  { {0x84380003,0x97a70015,0x50f40014,0xd7f80538}},	//   _أكبر_, врал, рзст, кут_
  { {0x6ab20037,0x25fe0011,0x8afd0030,0x753c0227}},	//   _जरूर, _लिखी_, _koře, _aarz
  { {0x28a90037,0xc7c80015,0x46150003,0x98a7001e}},	// [3cd0] _चुनि, тыре_, طوار, ienā_
  { {0xdcb10020,0x9be7002d,0xe6100003,0xdce80010}},	//   _ở_, відк, تشف_, ridė
  { {0xdce80010,0x97c70012,0x6acb0011,0x9f5801e3}},	//   sidė, _لتحم, िश्र, guró_
  { {0x6d4e006f,0x8f19000b,0x20130054,0xc477000b}},	//   _enba, _אוֹת, àxim_, כתבו_
  { {0x3f89007a,0x20110027,0x9e670012,0xc01c0081}},	//   miau_, luzi_, _شاحن, _tước_
  { {0xdb1c008b,0x3f8919ba,0x6d8b001e,0x0d640014}},	//   _zurü, liau_, tļau, _късм
  { {0xb8db0037,0xc9540009,0x321d0034,0x90450012}},	//   _घर_, ימס_, stwy_, انبه
  { {0x753c003e,0xee3919cd,0xb4c10011,0x3f890073}},	//   _zarz, ени_, ुशी_, niau_
  { {0x5cf5002d,0xa6e20028,0x673d00b6,0xdb1c19ce}},	//   ляну, óðin, _masj, _euró
  { {0x257600c5,0x27fe009b,0x673d0159,0x66060031}},	//   _vælg_, štni_, _lasj, ákka
  { {0x9f05000a,0x63bb001a,0xa0c40012,0xc4b10011}},	//   _موضو, _khun, _نيكو, _झरोख
  { {0x2bba000a,0x673d0033,0xb4360009,0x91e60578}},	//   عادة_, _nasj, נָיו_, ломе
  { {0x660500b3,0x4b7a0009,0xa5450012,0x42230048}},	//   _спла, תארו, _مضغو, бдяв
  { {0xe4e7002d,0xb33b0018,0x644719cf,0xfce20681}},	//   _рідн, boço, _orji, _лошо
  { {0x5f060098,0x63a9009b,0x9d1a0009,0x31040011}},	//   лзва, _oken, _נוקט, रणतः_
  { {0x3f89039c,0xb6a601d4,0xf4120009,0x4a760012}},	//   giau_, гибл, _הפה_, _مُعر
  { {0x023a0012,0x64430040,0x63a60031,0x7e69016d}},	// [3ce0] _أثبت_, ænin, mokn, nyep
  { {0x63a9005e,0x23b90031,0xad660012,0x201819d0}},	//   _aken, réje_, داره, _årig_
  { {0xbb460014,0x3f890010,0x4095002d,0x31370009}},	//   лежк, biau_, _врят, _גנים_
  { {0x63bb0020,0xe29a0048,0x63660031,0xcaf60012}},	//   _chun, нае_, _tónu, اساب
  { {0xe918002d,0xa6830055,0xab770012,0x98a70035}},	//   волі_, _гляд, دمنا_, venā_
  { {0x64a6022e,0xb4d20011,0xaa47004c,0x673d001b}},	//   _бага, _वले_, упља_, _zasj
  { {0x629c003e,0x3d190037,0x63a61110,0xb0260012}},	//   _środ, _पाते_, kokn, اءته
  { {0x7c930003,0xb4c00037,0x7af60028,0x61e400e5}},	//   _الفص, ँधी_, _neyt, _otil
  { {0xfad7000b,0x7bd50052,0x8fa30001,0x55740867}},	//   _תומך_, _zuzu, љање, игит
  { {0x90d5008a,0xa3d30044,0x71d7000b,0xecb80037}},	//   _hàn, _हूँ_, _עובד_, _अराफ
  { {0xdb550015,0x2d8f000e,0x6aad00b6,0x635519d1}},	//   авны, égei_, _syaf, авну
  { {0x213e002a,0x44441398,0xb09b0009,0x69d60d96}},	//   _hath_, iv_, _איבר, _buye
  { {0xc3330093,0x44440051,0x3f890010,0xb69b004b}},	//   זור_, hv_, viau_, _adân
  { {0x61e9004b,0x2d8b0031,0x2018005e,0x90d50081}},	//   ţelo, écet_, _äris_, _làn
  { {0xa3d30037,0x8cdb0009,0xe0ce0024,0x04db0009}},	//   _हूं_, _אחות, овi_, _אקול
  { {0x7bc20066,0xd491001a,0x853c0010,0xe44f0012}},	//   jmou, oàn_, alėt, _رضى_
  { {0x3f89011c,0x213e0132,0xa3da0011,0x4dd70012}},	// [3cf0] riau_, _oath_, _डूब_, اترس
  { {0x8e200024,0x224919d2,0x3f890073,0x7af606ed}},	//   _мiж_, _irak_, siau_, _zeyt
  { {0xd6d1000a,0xe1ff000f,0x3d1c0037,0xc9520009}},	//   _وقد_, lsó_, _माने_, _ומי_
  { {0x90d5001a,0x6d5817c5,0x6a1500ae,0xdb5803d2}},	//   _càn, övar, لبتر, люч_
  { {0x44440039,0x90d50020,0xe9ff001a,0xa2940024}},	//   av_, _dàn, _trận_, баці
  { {0xa4d4002d,0xd009003c,0x63a60031,0x61450400}},	//   _горі, веке_, zokn, река
  { {0x70520003,0x25a50202,0xa3b50011,0x63a60031}},	//   قنوا, voll_, झता_, yokn
  { {0x16390003,0x6f650014,0x63a90260,0xef120009}},	//   نسخة_, рвиз, _uken, ַּח_
  { {0x660d003a,0x7af6055d,0x442119d3,0xaec20048}},	//   nrak, _reyt, lth_, объл
  { {0x2705001a,0x79c80003,0xe6280003,0x4421021b}},	//   ồn_, _موقف_, اثين_, oth_
  { {0xf1c80066,0x442119d4,0xb9c40012,0x473502c4}},	//   ntář_, nth_, _اقلي, _внес
  { {0x22490eb4,0x4421002a,0xcad50009,0xeaa70012}},	//   _brak_, ith_, יוֹת_, قع_
  { {0xeb9705cc,0xeab20003,0xc6d40012,0x333f0025}},	//   рия_, تعد_, _اتمت, _maux_
  { {0xfce50046,0xa2c20037,0x63a60ff4,0x1d0900de}},	//   _токо, रेष्, sokn, _реки_
  { {0x853c0010,0x65b0004a,0x9d1a0009,0x660d079a}},	//   alės, sähk, _יוסט, erak
  { {0x8c1a000b,0x684019d5,0xe3b9003a,0x9f580097}},	//   _סופי, ládá, ltın_, gurð_
  { {0x7de50003,0xdb1b001a,0x67240070,0x853c0010}},	// [3d00] مسلم, _thuê, rfij, plėt
  { {0x79fb000b,0x90d5001a,0x7abb000b,0x4421002a}},	//   _שליח, _sàn, _בצפו, fth_
  { {0x74130012,0x660d19d6,0x9f580097,0x67d10035}},	//   قولا, arak, burð_, _mājs
  { {0x68fc00a2,0xdbdf0028,0x69c319d7,0xd6d90034}},	//   lard, _víðt, emne, ydła_
  { {0x98b3000d,0x442103d9,0x7dc60012,0x213e19d8}},	//   _taxă_, ath_, _نتسك, _path_
  { {0x99f5002d,0x333f0061,0x90560009,0xd24f0012}},	//   сяці, _eaux_, ֹסֵף_, بنه_
  { {0xa9670046,0x21670001,0x333f0ca7,0xb97b0009}},	//   рија_, рији_, _faux_, כנסי
  { {0x69c30248,0xab620060,0xc7d70009,0xcfaa0012}},	//   amne, çüle, סופי_, خاتم_
  { {0x27ed0027,0xba290003,0x656319d9,0xa7730024}},	//   ćeni_, _مسلم_, _bonh, ільч
  { {0xe2a60065,0x65630149,0x65b00052,0xef26005e}},	//   íðum_, _conh, fähi, üübi_
  { {0x10a6002d,0xe2f9002d,0xd314002d,0xdcba0014}},	//   _тижн, лені_, _вiдт, ъщи_
  { {0xdfcf0003,0xbb940015,0x31820002,0x2d8700e2}},	//   _قيل_, жающ, ższą_, _emne_
  { {0x52140055,0xe57a042a,0xdb0a0031,0x0f7b00af}},	//   одят, _изд_, ónál, _בראל
  { {0xac18002d,0xd5af002d,0x3d100037,0x3af5001a}},	//   _боку_, _єс_, ालों_, ấp_
  { {0xb8680046,0x2bd00037,0x4421002a,0xf0440015}},	//   ајте_, _संचा, xth_, оэто
  { {0x853c007a,0x36d50014,0x68fc1730,0x8b670012}},	//   plės, соар, aard, _خاتم
  { {0x7bd80163,0x539c000b,0x3bbc000b,0x76b90001}},	// [3d10] _huvu, _שיחו, _במהד, улар_
  { {0x2d8c0005,0xdcf90003,0xe4e7002d,0x201e0054}},	//   nide_, افات_, ріан, àtic_
  { {0x65ab008b,0x7afd000d,0x9f35002d,0xc19a0009}},	//   führ, oast, _лені, _תשתי
  { {0xa3b4007c,0x91a00020,0x2d8c000d,0xa5bb0028}},	//   обхі, _trị_, hide_, _apót
  { {0x2d8c0005,0x0756000b,0x7bd8004a,0xb5fd0010}},	//   kide_, _הסרט_, _luvu, ryšk
  { {0x69c3007d,0x2731001a,0x89a8002d,0xd1310003}},	//   umne, _ạn_, аків_, سمع_
  { {0x333f0061,0x2569000e,0x65ab0052,0x9be40024}},	//   _taux_, _múlt_, bühr, _мітк
  { {0xf7710003,0x65630017,0x28980009,0xdfa40012}},	//   ثات_, _sonh, ידון_, يحيي
  { {0x9f5e0108,0x52850003,0x443c0035,0x2d8c068b}},	//   été_, _الذك, _asv_, fide_
  { {0x7bd80010,0x26b6000b,0x66e70011,0x2d8c19da}},	//   _buvu, מִים_, _ट्रक_, gide_
  { {0xcb6a0ad3,0x68fc19db,0xd91a0009,0xf2c90009}},	//   гане_, vard, _תועל, _נע_
  { {0x25760028,0x31650052,0x68fc19dc,0xc1690009}},	//   _mæla_, _holz_, ward, _אח_
  { {0x68fc19dd,0xc6a70001,0x539a0009,0x9d45003c}},	//   tard, _тржи, רירו, _гелд
  { {0x0fd60037,0xf652000b,0x1ddb0037,0x6d5c0051}},	//   _ढूँढ, _מצד_, _बढ़त, örat
  { {0xdee601b6,0x46c50011,0x48070048,0x66e60024}},	//   йови, लेसह, йерн_, йова
  { {0xea5a0046,0x43930001,0xd6d20012,0xaf790024}},	//   _број_, _најс, سقط_, асує_
  { {0xe4d60003,0x6d8b0034,0xdcee0035,0x68fc19de}},	// [3d20] متاب, rżan, _albā, pard
  { {0xceb2000b,0xc5b90009,0x3f8d12f3,0x320219df}},	//   לין_, אֶ֣ר, hieu_, msky_
  { {0xcc8a0003,0xab5d0002,0xbca60003,0x6b9b0028}},	//   دناه_, _niżs, حماي, _bjug
  { {0xeafa000a,0xcb160003,0x8afd0066,0x8bd60009}},	//   ارات_, إذاع, _pořa, צונו_
  { {0x65ab0052,0x298a0345,0xbb470012,0x2369005e}},	//   rühr, лско_, صلون_, öaja_
  { {0x64580006,0x2d8f000f,0x7afd00f1,0xdb06031d}},	//   ävis, éget_, zast, llkä
  { {0xdc28001e,0x71090024,0x7d0b0073,0x660219e0}},	//   rķēt, рхів_, ėgst, _svok
  { {0xab960003,0x2d99000e,0x7f440007,0x33960012}},	//   _الرغ, ésen_, ndiq, _الرز
  { {0x2d8c0005,0x7afd02bd,0xba560014,0xda630014}},	//   tide_, vast, _утвъ, _евти
  { {0x71650003,0x867b000b,0x38c30061,0xea770009}},	//   _والك, טרפו, néré_, _הגמר_
  { {0xb09a002d,0xcb990024,0xc3340009,0xa2cb0011}},	//   _стає_, ивої_, ֗וֹ_, सेन्
  { {0xd366000a,0x1cb7000b,0x6e24002c,0x29f60002}},	//   ذه_, מליל_, ktib, oła_
  { {0x256f003a,0x7afd19e1,0x2d8c19e2,0xa5f807b9}},	//   _yılı_, rast, pide_, _телу_
  { {0x98a70010,0x7bc6005e,0xcebf0030,0x0c7a0012}},	//   seną_, amku, ářem_, _مصعب_
  { {0x7dc9007a,0xc058002d,0x38c30061,0x63e60003}},	//   _užsi, біт_, déré_, _استك
  { {0x29f60002,0x74970009,0x7e6d0060,0x320208ca}},	//   kła_, _לדוד_, tyap, bsky_
  { {0x38c30061,0x07080012,0x45d4003c,0x644f0035}},	// [3d30] féré_, صيلي_, зоус, ācie
  { {0x29f60002,0x67d50010,0x99f80009,0xd6d90034}},	//   dła_, _sąju, _הזזה_, ydło_
  { {0xe4350003,0x29f60002,0x3ed50012,0x940b0009}},	//   تفاد, eła_, _وقدر, ָּבֵ
  { {0x8c1b0009,0xdb060031,0xdfc60012,0x69c70031}},	//   רואי, toké, _زي_, lmje
  { {0x3f8d03eb,0x2d8f000f,0x2bb80003,0x29f60002}},	//   vieu_, éges_, حالة_, gła_
  { {0x11d40003,0x98be003a,0x18690014,0xbddb0025}},	//   ستهد, _altı_, иали_, _brèv
  { {0x29f60002,0x8fa50012,0x961d0035,0x6d5519e3}},	//   ała_, يمته, izņe, _inza
  { {0xef11000b,0xce590012,0x257b0025,0x0609115e}},	//   וּ֙_, لشخص_, _mêle_, аник_
  { {0x96b9002d,0x63ab0027,0xfd110003,0x8c44004b}},	//   шуку_, mogn, وجد_, ăşes
  { {0x98ba0039,0x7afb008b,0xa5090001,0xfc290015}},	//   _lapā_, _heut, јена_, ажок_
  { {0xf992000b,0x3f8d0054,0x78ac01e9,0xf1c80012}},	//   _קרב_, pieu_, čové, _اولى_
  { {0x65b0004a,0x853c0010,0x98b80010,0x8c1a000b}},	//   läht, slėp, ndrą_, סורי
  { {0xa2dc0037,0x32040042,0x201119e4,0x672919e5}},	//   _फलस्, émy_, erzi_, mfej
  { {0x65b00051,0x7afb0052,0xa6db0028,0x2eff0052}},	//   näht, _leut, _raða, lauf_
  { {0xc9520009,0x38550048,0xafe3005f,0x69db005e}},	//   ומם_, пътс, досл, _luue
  { {0x6d430101,0x6d55008b,0x29f60002,0x6f1b00b6}},	//   _hana, _anza, yła_, nguc
  { {0xd5e90003,0x69c10066,0x614602e2,0x6729000e}},	// [3d40] معلن_, _ohle, _депа, ifej
  { {0x8cb60046,0x22400005,0x859c0009,0xa1e90012}},	//   осеч, _isik_, ְשׁו, _اريك_
  { {0xdd8f0003,0x63060003,0x7afb0052,0x31570009}},	//   خول_, قوال, _beut, _ויין_
  { {0xfe67000a,0x6e2419e6,0x04570012,0xab2a169b}},	//   _قد_, ptib, تلمة_, рода_
  { {0x7afb19e7,0x98a709bb,0x201819e8,0x539b0009}},	//   _deut, menę_, luri_, סינו
  { {0xbddb0054,0x29f60002,0x6729000e,0x7bcf01bd}},	//   _prèv, rła_, efej, íbuz
  { {0x29f6003e,0x61e9004a,0x201819e9,0x6fb00011}},	//   sła_, _etel, nuri_, ूतपू
  { {0x69c70027,0x63ab0c63,0xb7ca0012,0x35f4003c}},	//   zmje, cogn, جبتك_, ппир
  { {0x4425003e,0x65940015,0x7bdc19ea,0x877b0009}},	//   etl_, запу, _huru, יאקי
  { {0xceb3000b,0x7bdc19eb,0xa2a30011,0x81780009}},	//   ויח_, _kuru, _छुट्, _פְּק
  { {0x9cdb000b,0x7bdc1146,0x55bb0009,0x7bc80073}},	//   יקיפ, _juru, שמיו, įjun
  { {0x9e660003,0x9f51000e,0x61e90033,0xd62a096e}},	//   _واشن, sszú_, _ytel, _воде_
  { {0x539b0009,0x7bdc016d,0x4e960012,0xfa6a0009}},	//   שיכו, _luru, _بشار, ׁכֹּ
  { {0x2735001a,0x6f00003a,0x644e19ec,0xaac70011}},	//   _ấn_, lamc, _orbi, रेषक
  { {0x98480098,0xf7730003,0xe9ff001a,0x8bb70003}},	//   оята_, وار_, _trần_, _وإعا
  { {0x2003003e,0xe47b0009,0x69c7001b,0x6d4319ed}},	//   rsji_, _כרוכ, smje, _zana
  { {0x0ec50037,0x7e600054,0x7ada000b,0x85750014}},	// [3d50] लेंड, _àmpl, _לַיה, плах
  { {0x344b0098,0x7bdc00c6,0x721a0009,0xd5b10012}},	//   ичен_, _buru, _פותח, رفا_
  { {0x201804f1,0x917b001a,0x913a000b,0xe7100010}},	//   curi_, hệ_, _העתק, dėžė
  { {0x7bdc00a2,0x23960039,0x224d012e,0x883a000b}},	//   _duru, tāji_, _prek_, _פתרו
  { {0x65b000ff,0x41e40012,0x66040031,0x9608003c}},	//   täht, وسوف, csik, _мэра_
  { {0x4dda000b,0x63ab03a2,0xcdf60009,0xd24e0012}},	//   _לחשו, sogn, _ממשי_, انو_
  { {0xddc90002,0xf7710003,0xf9940009,0xd0f80009}},	//   rzeż, فاة_, ורס_, חמות_
  { {0x309c000b,0x16060037,0x6d4319ee,0x889c0009}},	//   ישומ, _शिखर_, _sana, יבוי
  { {0x2eff008b,0x61e909d9,0x2018000d,0x6d4319ef}},	//   rauf_, _utel, zuri_, _pana
  { {0x0d8219f0,0x67290058,0x6b8d19f1,0x41770012}},	//   ельн, sfej, _amag, _بارس
  { {0x3d1c0037,0xc172000b,0x6d430643,0xff530012}},	//   _मारे_, _רחב_, _vana, _يخص_
  { {0x60ba000b,0x65b00052,0x00ba0009,0x58ba0009}},	//   _הצעד, nähr, _המעמ, _המעצ
  { {0x6d430807,0x34b80011,0x442519f2,0xee2e0934}},	//   _tana, _अर्द, stl_, _ян_
  { {0xdce319f3,0x201819f4,0xfe790030,0x66040248}},	//   _konč, turi_, ncům_, vsik
  { {0x645c0006,0xa5080009,0xdfd20012,0x764f0034}},	//   ärit, _וּפִ, فيس_, _arcy
  { {0xab66002d,0xb759002d,0x2018000d,0x65b00052}},	//   _хвил, ошує_, ruri_, jähr
  { {0xfbd3015a,0xcbc50003,0x644e09ea,0x3f670001}},	// [3d60] _אתה_, _تزوي, _srbi, чито_
  { {0x2018007d,0xddcb003a,0x6b8d0328,0xdca60345}},	//   puri_, ğişm, _zmag, пази
  { {0x50db0093,0xc689000b,0x65b00052,0xdb0b0058}},	//   _לחיצ, נא_, fähr, ilgæ
  { {0xe3b20012,0x7bdc0060,0x62820227,0xfa760009}},	//   ررا_, _vuru, tzoo, ּעַת_
  { {0xade30037,0x0ab60012,0xe297004c,0xc3270012}},	//   _कूपन_, أحاد, пац_, سكون_
  { {0xdb1b001a,0x7d01009b,0x88bc0066,0xe3b9003a}},	//   _chuâ, jals, _obět, ttık_
  { {0x3a26012e,0x07200037,0x94790024,0x64a30bda}},	//   stop_, _यादव_, _дсту_, _зара
  { {0x4c9b000b,0x780c0037,0xe3b9003a,0x232700f5}},	//   _הבלו, _सटीक_, rtık_, _носи_
  { {0xc6f70015,0xf6230001,0x23960035,0xf1bf0031}},	//   чных_, едњо, nāju_, dtán_
  { {0x09690003,0xc24300b3,0x270c001a,0xc5f30009}},	//   _وإلى_, _янук, ớn_, עדת_
  { {0x6b9d0031,0x44270024,0x6f060031,0x69ca0602}},	//   érgo, пцям_, ókcs, mmfe
  { {0x7bc401a2,0x1877000b,0x7d010051,0xdce8003a}},	//   _chiu, _מעבר_, aals, ğlıy
  { {0x59da0044,0xe9ff001a,0x7d0119f5,0xdce8003a}},	//   _यूआर, _trấn_, bals, şlıy
  { {0x5e570093,0xd657000b,0x5e430012,0x7ae60245}},	//   _מידע_, _מידת_, _أَوْ, ackt
  { {0x68fe00b6,0x55bb0009,0xe44f0012,0x753a0032}},	//   _depd, _המגו, _مضي_, metz
  { {0xa8570093,0x753a0052,0xc49b000b,0x6b8d0ddc}},	//   הילה_, letz, _לשות, _umag
  { {0xc3340009,0x2fc90032,0x98ba004b,0x63af19f6}},	// [3d70] _טוק_, rmag_, _papă_, mocn
  { {0xf9fc000b,0x65b00052,0x6d4819f7,0xfc330012}},	//   _ההזמ, währ, ndda, فحص_
  { {0x6d4801cf,0x29030e0c,0xf8c10011,0x84390012}},	//   idda, maja_, _एरिय, تكار_
  { {0xdecb0001,0xf99f0007,0xf4100012,0x63af0929}},	//   _гугл_, près_, اؤل_, nocn
  { {0x2d99000f,0xd5b80039,0x2bcc0037,0x614519f8}},	//   ések_, klā_, ़ग़ा, дела
  { {0xeab00003,0xbddb0061,0x99670063,0xf1bf0bf4}},	//   دعم_, _frèr, ятел, ztán_
  { {0x7d01012e,0x69d7002a,0x18660048,0x394519f9}},	//   vals, _mixe, дащи_, _vals_
  { {0x0858000b,0x85e9002d,0x69d70017,0x290319fa}},	//   לבום_, одив_, _lixe, haja_
  { {0xdb1b001a,0x6d4719fb,0x66150034,0xe7080012}},	//   _thuâ, _kaja, ązko, ستين_
  { {0x49170037,0x6d4700b6,0x72040003,0x7bd6002c}},	//   _नाटो_, _jaja, _أولم, _siyu
  { {0x6d47093d,0x6fbf0011,0x03a619fc,0xf8750012}},	//   _maja, ्षां, дино, _تهاج
  { {0x9bca0012,0x69d701a0,0x98a70030,0x3e350012}},	//   توجك_, _aixe, zeně_, _يفار
  { {0x1c1f0037,0x7e280003,0x1d0900db,0x8ad60012}},	//   मंडल_, _فسوف_, _дели_, بتدئ
  { {0xdb0b0163,0x3afc001a,0x98ba0073,0xc7b90031}},	//   llgä, ập_, _lapą_, llő_
  { {0x2bd90037,0x66e60511,0x6fd60024,0xb9060011}},	//   _बंगा, доба, діац, _फल_
  { {0x23960039,0x69c5000f,0xe29a1103,0x1bfa000b}},	//   tāju_, _ehhe, _май_, _ולקב
  { {0xd6250003,0x6fea0002,0xdfcf0012,0x1b290012}},	// [3d80] فعلي, _ięce, شيك_, _رأيي_
  { {0x7ae90017,0xf1e10037,0x41da0011,0x78a40060}},	//   _afet, _पढ़न, _यूएस, şivi
  { {0x53e5007c,0x2005015b,0x6d4709d2,0x515b0009}},	//   еціа, álit_, _daja, _וכיו
  { {0x7d07000f,0xeb970400,0xc7b90031,0x661b079b}},	//   térí, мих_, jlő_, kuuk
  { {0x6d48006f,0x09e302ad,0xf1aa0012,0xf1bf0031}},	//   ydda, вочн, ياته_, ktál_
  { {0x7ae90149,0x64430027,0x2738001a,0x6f04001e}},	//   _efet, _osni, _ẩn_, laic
  { {0xf1bf0031,0x7ae900b8,0xd19700af,0x8c4303d2}},	//   dtál_, _ffet, וכסי_, _иере
  { {0x8b95002d,0xf60a003c,0x98b1004b,0x41da0011}},	//   _зруч, охой_, leză_, _यूऍस
  { {0xc7b30009,0x2dd40223,0xc2460adc,0x11e90012}},	//   כבה_, нжир, _юнак, _فعلي_
  { {0x98b1000d,0x62860b7f,0x3eb80035,0x61ed0060}},	//   neză_, dzko, ārt_, _rtal
  { {0x6d48006f,0xc953000b,0x986a0003,0x290302a1}},	//   rdda, _שמע_, _بحذف_, vaja_
  { {0x753a008b,0x93bd000d,0xd5b8001e,0x938b0024}},	//   setz, ptăm, slā_, існа_
  { {0x61e000c6,0xc6760003,0x290319fd,0xda7b002d}},	//   _juml, _تطاب, taja_, іям_
  { {0x661607c2,0x6d5815ef,0x76bb0009,0xb6bb00af}},	//   dryk, _unva, _ומדפ, _וצדי
  { {0xdb0b0163,0xd48f002d,0x98b1004b,0x5ba70048}},	//   llgå, _рр_, deză_, _ориз
  { {0x4f94004c,0xdfd00012,0x36d51728,0x6d4719fe}},	//   врђу, ليّ_, еобр, _saja
  { {0x5d550014,0x61ed000e,0xc50b0003,0x6d470acb}},	// [3d90] нкат, _utal, قتال_, _paja
  { {0x2d9e008b,0x2005000f,0x71750003,0x99d70003}},	//   nnte_, ális_, _أهدا, _تتعا
  { {0x5b150098,0x2d9e0e32,0x6d4719ff,0x2d99000e}},	//   емет, inte_, _vaja, ései_
  { {0x2d9e0052,0x6d4700b6,0x501a000b,0xf1bf000e}},	//   hnte_, _waja, _צורו, ztál_
  { {0xa3c20037,0x29010051,0x34bb0011,0x63c80012}},	//   ्गत_, _keha_, _उर्द, ذِهِ_
  { {0xc1050003,0x7d0a0028,0xea78000b,0x34950138}},	//   روبي, ófst, וגדר_, _загр
  { {0xdce3001e,0x78fc0009,0xb8040012,0x88bc0030}},	//   _nonā, חלופ, نبيه, _sběr
  { {0x2d9e1a00,0xf7710012,0x62860030,0x7d050060}},	//   ente_, طاب_, yzko, lahs
  { {0xee360047,0x9f51000f,0xf6510003,0xe732000b}},	//   ены_, lszó_, ائب_, אֵת_
  { {0x88c70012,0x316c0034,0xdcfa0035,0xdb061038}},	//   _قتال, _godz_, ditē, doká
  { {0x5fdb0037,0x661b004a,0x6e291a01,0xc7b9000e}},	//   _मंगल, suuk, steb, plő_
  { {0xc4d20009,0x547a0009,0x62860032,0xf1bf03a7}},	//   טגי_, פטרו, tzko, stál_
  { {0xe2920003,0x59c40011,0x09e30048,0x555909e8}},	//   اذج_, _लीडर, лоян, _надя_
  { {0x23960039,0x644a0058,0x3d190011,0xdca50a21}},	//   tājs_, æfik, दलों_, _пали
  { {0x0d160093,0xe4e4002d,0xb4640003,0x3c450003}},	//   _טקסט_, _річн, _لديه, _أَبِ
  { {0x6133003a,0x22520058,0x42260024,0xdcfa0035}},	//   lılı, _tryk_, _здив, bitē
  { {0x539b0093,0xe61a022a,0x639b0009,0x66091a02}},	// [3da0] _מיקו, яда_, _מסקנ, nsek
  { {0x6133003a,0x66090ad9,0xbd460012,0xb5a90012}},	//   nılı, isek, عناي, والك_
  { {0x61e0009b,0xe9a90012,0x6b821348,0x25e50011}},	//   _suml, _تدين_, thog, _झूठी_
  { {0x1ddf0037,0xe29f0028,0xc053000b,0x25760028}},	//   नदात, laða_, _עזר_, _mæli_
  { {0xbaba0003,0x32ba0003,0x6b820070,0xcb070003}},	//   أداء_, أداة_, rhog, ريون_
  { {0xe894027f,0x889a0009,0xe29f0097,0x66091a03}},	//   каль, ּבֵי, naða_, dsek
  { {0xc0e70003,0x2d9e0262,0xc1730009,0xdca6004c}},	//   رفين_, vnte_, רחו_, _чави
  { {0x7bde0061,0x96341a04,0x9c0b0009,0x1754004d}},	//   _épui, вниц, _מִמִ, твия
  { {0x61ba0003,0x929d0034,0x7f3b0009,0xe29f0097}},	//   _فهرس_, _pełe, לעקו, kaða_
  { {0xa4d40024,0x4438016d,0xdb0603a7,0x2d9e1a05}},	//   копі, _kpr_, voká, unte_
  { {0x98be007d,0x2d9e0052,0x2cb80040,0x38610032}},	//   _dată_, rnte_, ærd_, ährt_
  { {0xab95002d,0x69da13ea,0x889b000b,0x69ce1a06}},	//   тимі, _hite, _צבאי, embe
  { {0x69da07cc,0xfe720012,0xd1bb0012,0x98be004b}},	//   _kite, _حدا_, كاسا_, _fată_
  { {0x6133003a,0x865b0009,0x6fc50034,0xdcfa0035}},	//   cılı, _מדדי, róce, ritē
  { {0x69da067c,0xf1bf000e,0x44380133,0x65750031}},	//   _mite, lták_, _npr_, özhe
  { {0x1cbb0009,0xba55004c,0xccf80030,0xddd60034}},	//   _ממוע, _авиј, lbě_, czyź
  { {0xc8f50098,0x29010005,0x98ba0002,0xa3e40011}},	// [3db0] _изпъ, _teha_, _mapę_, _भूत_
  { {0x63bd006f,0x69da009c,0xab5b0032,0x9f510031}},	//   llsn, _nite, flüg, tszó_
  { {0x61d6000b,0x8c590012,0x7c590012,0x320b0034}},	//   _שותף_, بلاء_, بلار_, lscy_
  { {0x3f6700e3,0x443800c6,0x6133003a,0x8c1b000b}},	//   _чтоб, _dpr_, zılı, לובי
  { {0x9f51000f,0xaa450015,0x6133003a,0xc3340009}},	//   sszó_, телл, yılı, טוף_
  { {0x7c380070,0xf1bf000e,0x6609005e,0x22b70034}},	//   _opvr, dták_, vsek, _ręką_
  { {0xdb0b02d1,0x69da1a07,0x5ba7002d,0xa1560001}},	//   logí, _dite, _зраз, тају_
  { {0x66090051,0x69da0052,0x905c000b,0x64550035}},	//   tsek, _eite, לכות, _irzi
  { {0x0ea9007c,0x6133003a,0x6f02000d,0x3eb900d2}},	//   ький_, tılı, _deoc, æst_
  { {0x17fb0003,0x13e90015,0x63b603ce,0xd5ae0012}},	//   _فرصة_, ммой_, _skyn, يفي_
  { {0x6133003a,0xe29f0028,0x29071a08,0xa1560009}},	//   rılı, vaða_, mana_, _שבעה_
  { {0x7ff40003,0xb8f40037,0x6133003a,0x91e604b3}},	//   _إسلا, से_, sılı, коме
  { {0x69c80006,0x4a430014,0xe29f0028,0x6133003a}},	//   _yhde, аняв, taða_, pılı
  { {0xdb0602b9,0x273c0081,0xd946004c,0x69ce1a09}},	//   llkü, _ận_, њеви, umbe
  { {0x25b60003,0xbbe80012,0x2d850030,0xe29f0097}},	//   _جهود_, _كريم_, mhle_, raða_
  { {0x8c1a0093,0x7e760006,0x6d210037,0x7d030260}},	//   _חוקי, tyyp, _माँग_, _hens
  { {0x29071a0a,0x3cf80031,0xe29f0097,0xab5b0032}},	// [3dc0] kana_, űrve_, paða_, rmüt
  { {0x64550027,0x2258009b,0x4583002d,0xed5a0024}},	//   _brzi, _črk_, агув, ьоз_
  { {0xe6be0037,0xcb6a0001,0xa7d60003,0x6e2d1a0b}},	//   _ऊर्ज, маже_, _لتحص, atab
  { {0x59bc0037,0xd3790024,0xe3b90060,0x7d031a0c}},	//   ोगकर, нчі_, ltır_, _lens
  { {0xdb15000f,0x61e40061,0xccf80066,0x6d210037}},	//   óbál, _juil, ybě_, _मांग_
  { {0x644f0333,0x9166001a,0x61e4004a,0xd0100003}},	//   ācij, _bổ_, _muil, ملت_
  { {0x26c0007a,0x98a50010,0x70540003,0xccf80066}},	//   _šio_, _dalį_, انبا, vbě_
  { {0xf1bf000f,0x78ba0107,0x6d4a1a0d,0x320b0034}},	//   tták_, _vytv, _safa, yscy_
  { {0xe3b900a2,0xcf93000b,0x49ba0003,0xccf80066}},	//   ktır_, יטה_, _قائد_, tbě_
  { {0x69da0070,0x7aed000d,0x44440a5f,0xe7e50011}},	//   _uite, _sfat, ow_, कदमा_
  { {0xdce10039,0xf1bf000e,0xad1b0009,0x351b0009}},	//   eklē, sták_, וויר, ווינ
  { {0x61e40036,0xc884003a,0x6d4a00b6,0x40950048}},	//   _buil, ışı_, _wafa, _срут
  { {0x645e0066,0x98be0914,0x7d031481,0xa9970012}},	//   _špid, _datą_, _fens, نشست
  { {0x6e2018bd,0x7d031a0e,0x2d850042,0xf2d30009}},	//   mumb, _gens, chle_, יער_
  { {0xb33b0017,0x61e40025,0xda080081,0x20d40012}},	//   ança, _euil, hỏ_, لتفج
  { {0x0aeb0012,0xe3b90060,0xdce70030,0x7d081a0f}},	//   _غربي_, atır_, _pojď, lads
  { {0xdfd80098,0x6e201a10,0x44441a11,0x8704003c}},	// [3dd0] тър_, numb, ew_, рясе
  { {0x27130020,0xbbcb0037,0x44f4002d,0xdce7001e}},	//   ện_, िष्क, ипус, _bojā
  { {0x98ba0066,0x6e2d1a12,0xc1720009,0x442b003c}},	//   _mapě_, stab, _החי_, ьцам_
  { {0x2907003e,0x9056000b,0xddc20002,0x99860002}},	//   wana_, _עברו_, _proś, proś_
  { {0x9166001a,0x471a000b,0xee870015,0x8f1a0009}},	//   _sổ_, _אורג, _рыно, _אורת
  { {0x9aa40003,0xc27c000b,0xa924002d,0x6d430051}},	//   جمهو, ורדי, иділ, õnad
  { {0x01380093,0xb9380009,0x18350012,0xa3b50011}},	//   דרות_, דרוג_, ارتح, ढ़ता_
  { {0x2f540047,0x7d031a13,0xd7750012,0x4421016d}},	//   атьс, _sens, طابع, muh_
  { {0x442100b6,0x29071a14,0x1ea90012,0x9599178f}},	//   luh_, pana_, عاعي_, етну_
  { {0x9166001a,0x4d650ed4,0x660d0051,0xfd110012}},	//   _tổ_, уков, isak, حجة_
  { {0x442100c6,0xa3c70037,0x6445002a,0x7c640012}},	//   nuh_, _उठा_, nwhi, لاَل
  { {0x4fa4007c,0x29050163,0xdcfa0010,0x7d030070}},	//   _києв, _hela_, kitė, _wens
  { {0x2249000f,0x2d8b0061,0x7d08000e,0xdd2c0010}},	//   _csak_, èces_, bads, _rėži
  { {0x0d84002d,0x442100b6,0x05790012,0x660d1a15}},	//   _клін, kuh_, _سمعة_, dsak
  { {0x25760028,0xef190002,0x442100b6,0xe73a010c}},	//   _mælt_, akże_, juh_, нев_
  { {0x1cba000b,0x442100b6,0x661b0027,0xdfa50012}},	//   _אמצע, duh_, oruk, لحقي
  { {0x1fa70232,0x4b250012,0x4444005e,0xe3b90060}},	// [3de0] укти_, _ضعيف, ww_, ptır_
  { {0x6d411a16,0xa3e70011,0x29050018,0x5bdc0011}},	//   nela, _बढा_, _nela_, यद्व
  { {0x444400bd,0x442100b6,0x2d83009b,0x290a184a}},	//   uw_, guh_, _dlje_, maba_
  { {0x501b0093,0xd9cc0037,0x7dc20029,0x7dc60028}},	//   _אוטו, ाष्ट, pôso, iðsa
  { {0x8e760001,0x4421016d,0x7c210032,0x98a70035}},	//   _сунч, auh_, hulr, kenē_
  { {0x29050108,0xfce30800,0x442100b6,0x290a0164}},	//   _cela_, _горо, buh_, naba_
  { {0x17f70003,0x628b0027,0xbbe90012,0x98130012}},	//   هرية_, azgo, _لرقم_, مبيا
  { {0x6d4e0101,0xa857000b,0xa3e70037,0x6d410051}},	//   _haba, ריקה_, _बढ़_, eela
  { {0x29050028,0x6d4e0160,0x7d081a17,0x2fc00032}},	//   _fela_, _kaba, tads, ilig_
  { {0x1637000a,0x01d7000a,0x6d4e00c6,0x186a06bd}},	//   اسية_, _موقع_, _jaba, _пази_
  { {0x6d4e0101,0xcdb7000b,0x759b000b,0xd7ef0012}},	//   _maba, רפיה_, תייח, _فكل_
  { {0x501b000b,0x600b0009,0x2d9a004b,0x6d4e1a18}},	//   _טובו, _נִבְ, hipe_, _laba
  { {0x518701b6,0x2fc01a19,0x7d081a1a,0x6d411a1b}},	//   гува, dlig_, pads, bela
  { {0x2249012e,0xa4d4002d,0x6d4e1a1c,0x69de0604}},	//   _vsak_, _колі, _naba, _cipe
  { {0x69de06ac,0x6b84002a,0x54330003,0xab5b0052}},	//   _dipe, _flig, _هرير, glüc
  { {0xb4c20037,0x6d4e002c,0x660d1a1d,0xb7940012}},	//   ्धी_, _aaba, tsak, مؤقت
  { {0x290a0101,0x6d4e1067,0x15f40003,0x98a5003a}},	// [3df0] baba_, _baba, مسلح, ılı_
  { {0x7afd0052,0x442100b6,0x8d770003,0x261c0011}},	//   lbst, tuh_, دارا, _मिनी_
  { {0x6d4e007a,0xe5c40015,0x290500b6,0x660d1a1e}},	//   _daba, ссто, _rela_, ssak
  { {0x442100c6,0x02d90003,0xdb0b000e,0x660d0a50}},	//   ruh_, نواب_, fogá, psak
  { {0x29050149,0xb4c20037,0x442100b6,0x82680024}},	//   _pela_, ्धु_, suh_, лаїв_
  { {0x6edb0039,0x09af0037,0x4421016d,0x6d411a1f}},	//   _jābū, टवेय, puh_, xela
  { {0xddcb007a,0xa3e40037,0xc9840001,0x515c0009}},	//   žiūr, _भूल_, ључи, תכוו
  { {0xee390ac5,0xf7710003,0x290a0164,0x7f4f1a20}},	//   вни_, تات_, zaba_, _jacq
  { {0x6d4100c6,0x6d4e003a,0x645814fa,0xda1c0037}},	//   tela, _yaba, _arvi, _नियत_
  { {0x6b84002a,0xe576003c,0x7afd1a21,0xad591a22}},	//   _slig, изы_, ebst, трих_
  { {0x63a90033,0x69de06b5,0x30a702ad,0x290a01f9}},	//   _kjen, _ripe, _срав, vaba_
  { {0xa4b6000b,0xeb9a013b,0x7bcd01da,0x7f4f00b8}},	//   ילתה_, тим_, _chau, _nacq
  { {0x63a90027,0x290a1a23,0xb77a0009,0x87d40012}},	//   _mjen, taba_, _שאנש, _اغلا
  { {0x7d070013,0x3d0f0011,0xc27a0009,0x644a008e}},	//   _nejs, ाणों_, דרשי, ämiä
  { {0x6fb6000a,0x98b8000d,0x7bdf0017,0x7afd006f}},	//   لمسا, deră_, _fiqu, bbst
  { {0x290a1a24,0x63a9017b,0x1fa7035c,0x261c0011}},	//   saba_, _njen, акси_, _मिमी_
  { {0x0e66002d,0x6d4e16f9,0x98b8000d,0x98be0002}},	// [3e00] шкан, _paba, feră_, _datę_
  { {0x929d003e,0x63bb00b6,0x4d63002d,0xb9930012}},	//   _pełn, _akun, окув, _وليب
  { {0x6d4e0005,0xa6db0028,0x0fda0012,0x29370009}},	//   _vaba, _baðs, _لبحث_, _דאין_
  { {0xfbc30406,0x3f891a25,0x93bd004b,0x63a9001b}},	//   обхо, chau_, ltăr, _cjen
  { {0x4254000a,0xfce6002d,0xf20302ac,0x7ae40042}},	//   إنتر, _вого, оящо, žito
  { {0x93bd000d,0xf1bf0029,0x63a90058,0x33f60024}},	//   ntăr, stáv_, _ejen, _вчас
  { {0xe3ba0048,0xdca307e8,0x0f560009,0x63a90040}},	//   _абв_, _дари, ֹיִם_, _fjen
  { {0x63a903a0,0x3f800010,0xf1bf0031,0x7ae4020d}},	//   _gjen, nkiu_, ltát_, _ngit
  { {0xd0fb0044,0x3da6002d,0x7bc20066,0xe7310009}},	//   ्रमण_, ироб, mlou, הֵי_
  { {0x6458017b,0x96b7004c,0xdcfa0035,0x7bdf0c9d}},	//   _prvi, јућу_, mitī, _siqu
  { {0xdeef0047,0x2ec30044,0xc5730003,0xfe180037}},	//   _мы_, _शर्त, تطيع, _दिवस_
  { {0x287b000b,0x93bd000d,0x5c73002d,0x600b0009}},	//   _שנאמ, etăr, ілят, _יִדְ
  { {0xc3330093,0x7bdf03eb,0x7afd0032,0x6da60e63}},	//   חור_, _viqu, rbst, _кида
  { {0xa63b0009,0x7c660012,0x7db30012,0xf67b0009}},	//   _סגור, _نابل, _وصوا, _באדמ
  { {0xb4930001,0x37070345,0x7ff70012,0x74140012}},	//   _мишљ, ичав, ؤسسا, _اوبا
  { {0x04db0009,0x386d001b,0x93bd0f7f,0x9cdb0009}},	//   _בקול, ćer_, drăg, _בקופ
  { {0x3e070014,0x645d001e,0x8515002d,0x7bc20066}},	// [3e10] рябв, āsie, ймає, dlou
  { {0x93bd000d,0x63bb03ab,0x3abc0009,0x63a9001b}},	//   ctăr, _skun, _במחנ, _sjen
  { {0x2dd80003,0x04670538,0x70550012,0x59d40012}},	//   شبكة_, штам, _انجا, _بغير
  { {0x8b94002d,0x98b8000d,0x03940024,0x9b740012}},	//   оріч, seră_, орія, يانص
  { {0x926b0014,0x0a6b0048,0x2d8f0025,0x98b8004b}},	//   ържа_, ържи_, èges_, peră_
  { {0x5d85000a,0x9e760009,0x80f80048,0x7bc21a26}},	//   _السل, _הגשה_, ахът_, alou
  { {0xf1bf000f,0xe0550003,0x63a9038e,0x7bc2000d}},	//   ltás_, إختب, _tjen, blou
  { {0x7bc203eb,0x1f650015,0x6575000e,0x6fc50002}},	//   clou, ским, _hozh, róco
  { {0xf1bf000f,0xa3c60011,0x87240012,0x63b90034}},	//   ntás_, ॉगर_, زعيم, mown
  { {0x27170020,0x5174000a,0x4174000a,0xc9740003}},	//   ển_, _والأ, _والس, _والث
  { {0xe7c70037,0x0445027f,0x61e91a27,0x3b0a02c4}},	//   लताप, щенн, _huel, лено_
  { {0x63b9003e,0xdce1007a,0x03a602ad,0x61e102ec}},	//   nown, yklė, симо, _hill
  { {0xeb97085b,0xd29a002d,0x61e11a28,0xd2990024}},	//   сия_, утні_, _kill, атрі_
  { {0xf9870012,0xf2d20009,0xad580048,0x60c1008e}},	//   سب_, פעם_, _връх_, _kylm
  { {0x7dc6014d,0x63b9003e,0xbbf50003,0x65631712}},	//   iðsl, kown, _استث, _innh
  { {0x4425007d,0x93bd0bc8,0x13060001,0x672900b6}},	//   mul_, stăr, _узим, ngej
  { {0x4425007d,0xa3b50011,0x93bd004b,0xf1bf0031}},	// [3e20] lul_, जकर_, ptăr, ttát_
  { {0xca970009,0x6d4507d7,0xf2970009,0xd6cf0012}},	//   _לדפי_, geha, _לכפר_, رقل_
  { {0x98a7007a,0x8c95002d,0x44251a29,0x89db0009}},	//   menė_, орці, nul_, _תחיי
  { {0x61e10061,0xf1bf000e,0x9166001a,0x0b1a0003}},	//   _aill, stát_, _hồ_, اقشة_
  { {0x44250005,0x61e11a2a,0xd9fa0011,0x61e901e3}},	//   hul_, _bill, ्ठित_, _cuel
  { {0xda650003,0x44251a2b,0x7bc207d8,0x11d70012}},	//   تامي, kul_, slou, مونة_
  { {0x6c86000a,0x01330003,0xdfd00003,0xa9670001}},	//   _الأم, سعود, ويت_, сија_
  { {0x63b90002,0x9c17000b,0xab5b000e,0xf1bf1356}},	//   cown, _לחלק_, elün, ntár_
  { {0xceb3000b,0x44250025,0x61e11a2c,0x6b82005e}},	//   ּית_, eul_, _fill, mkog
  { {0x442509f5,0x61ef0061,0x5d660001,0x4d980024}},	//   ful_, _écla, стиз, ркою_
  { {0xb5fb01c5,0xe0850012,0x55bb0009,0xd5bb0009}},	//   _gráf, _وجمي, רמיו, רזיל
  { {0xe29f0028,0x29c901e3,0x6d450031,0xd7ef0012}},	//   laði_, núan_, zeha, _أكن_
  { {0x3eab0029,0x539b0009,0x753c0034,0x91660081}},	//   čitú_, ריכו, _obrz, _bồ_
  { {0xe29f0065,0x44251a2d,0x3d220037,0x7dc60097}},	//   naði_, bul_, मलों_, oðsm
  { {0x44250c36,0x657500f1,0xf5370009,0xd8180009}},	//   cul_, _rozh, _הטור_, יֵּש
  { {0x53a40046,0x7d0a0028,0xd7940048,0x2d9e1a2e}},	//   _најб, _hefs, писъ, lite_
  { {0xd1310003,0x7dc60028,0x557507e8,0x5eeb0009}},	// [3e30] _قمة_, yðsl, огат, אַבְ
  { {0xf1bf000e,0x2d870029,0x2d9e17fa,0xd7f8004b}},	//   rtás_, óne_, nite_, _otă_
  { {0x61e90164,0x6d451a2f,0xf1bf01e3,0x98b80034}},	//   _suel, reha, stás_, terą_
  { {0x53c90037,0x23c90037,0x6d450807,0x61e11a30}},	//   रतिश, रतिद, seha, _sill
  { {0x2d9e039c,0x2bb1003e,0x645c0052,0x63b90002}},	//   kite_, jące_, _erri, rown
  { {0x61e902d1,0x63b90002,0xb4e70037,0x2d9e0470}},	//   _vuel, sown, _भले_, jite_
  { {0x4425000d,0x397c000b,0x2d9e1a31,0x297c0009}},	//   xul_, רטונ, dite_, רטוא
  { {0x10080003,0x4425000d,0xcb340014,0x224d002c}},	//   حتوى_, vul_, _несъ, _tsek_
  { {0x69c30029,0x1bd40015,0x61e90051,0x61e10b0e}},	//   plne, _хотя, _uuel, _till
  { {0x2d9e0149,0x44251a32,0x161e0037,0xf1bf000e}},	//   gite_, tul_, यूटर_, ztár_
  { {0x0468000b,0x2ef500fa,0x9346003c,0x5baa0170}},	//   ֶיךָ_, _дзер, онне, иком_
  { {0x442501b3,0xdb96002d,0x2c57000d,0xf412000b}},	//   rul_, ішнь, _văd_, ופט_
  { {0x2d9e0470,0x19f70003,0x44251a33,0x0cc60011}},	//   bite_, يَّد_, sul_, _वर्म
  { {0x44250771,0x9166001a,0x6b890e8c,0x3f8d0017}},	//   pul_, _bố_, _lleg, lheu_
  { {0x9166001a,0xd00a0001,0xaf9a027f,0x39471a34}},	//   _cố_, ребе_, атах_, iens_
  { {0x82a6002d,0xfbc30014,0xeee70012,0xc0520009}},	//   _майж, _общо, قِّي_, וזל_
  { {0x1dc50037,0x6f0b000e,0xb6a605cc,0x39471a35}},	// [3e40] वतंत, _megc, циал, kens_
  { {0x6b890396,0x5046004c,0x6f0b0031,0x26c20073}},	//   _aleg, _деоб, _legc, _vyko_
  { {0xf1bf000e,0x2bb10002,0x7dd0004a,0xe73a05fb}},	//   ptár_, zące_, jäse, _кен_
  { {0xd62a0001,0xb8fd0037,0xdcfa0035,0x72c6052c}},	//   _коме_, ते_, iktā, обез
  { {0xc9f30003,0x5f03002d,0xe29f0028,0xf773000b}},	//   وسوع, _ізра, taði_, _חקר_
  { {0x753c0027,0xab5b000e,0x4a53002d,0x39471a36}},	//   _ubrz, elül, ькіс, gens_
  { {0x290e0065,0xe29f0028,0x2d9e1a37,0xf1a90012}},	//   rafa_, raði_, vite_, حانه_
  { {0x93fb000b,0x8b660012,0xc6f80024,0xdfda0048}},	//   _כללי, _باسم, щних_, шъл_
  { {0x39470052,0xdcfa0066,0x9343002d,0x8d6a0001}},	//   bens_, chtě, _інфе, ајна_
  { {0x6609003a,0xc9860003,0x63ad0033,0x2bb10034}},	//   _çeke, _بشري, _sjan, rące_
  { {0x7d0a014d,0xc3340009,0xccf30009,0xa3e40011}},	//   _vefs, ֔וֹ_, וכת_, _भूख_
  { {0x27f30029,0x661d098f,0xf7460055,0xbe660012}},	//   žané_, šska, _федо, _وهاي
  { {0x91660020,0x753d000f,0x290c0051,0x2d9e1a38}},	//   _số_, ősza, _keda_, pite_
  { {0x7dc60065,0xf8070024,0x6fea0034,0x7bc61a39}},	//   iðsk, жчан, _pęch, alku
  { {0xcf9b0046,0xdfd50015,0x67d500b3,0x6cfb0009}},	//   аја_, зовы, зову, _דפוס
  { {0x4421022d,0x7c2800b6,0x39470087,0x6d481a3a}},	//   vrh_, mudr, zens_, leda
  { {0x39470061,0xd6db0055,0x16340048,0x645a1a3b}},	// [3e50] yens_, ртв_, метя, lvti
  { {0x9166001a,0x6b890028,0x7db40003,0x93bd004b}},	//   _tố_, _sleg, وصلا, brăc
  { {0x394700bd,0xc058002d,0x69c7080a,0xd5b80024}},	//   vens_, _дія_, mlje, ісу_
  { {0x291102d1,0xdfc6000a,0x6d480051,0xd491001a}},	//   laza_, _سي_, heda, gày_
  { {0x290c00b6,0x539c0009,0x6d481a3c,0x01650048}},	//   _beda_, סידו, keda, зкло
  { {0x867a000b,0x6d480027,0x6fc5000e,0x067a000b}},	//   _הרשו, jeda, móci, _הנשל
  { {0x91660020,0x6d48007a,0x76420164,0x98a7001e}},	//   _hỗ_, deda, _apoy, menī_
  { {0x672d00c6,0x6b890002,0x6235002d,0x0609057e}},	//   ngaj, _uleg, _небу, бник_
  { {0xd7060015,0x6d551a3d,0x2911013a,0xab5b04e7}},	//   чные_, _kaza, kaza_, rlül
  { {0xb9980015,0xdce70002,0xe29f0028,0xa3e70037}},	//   _двух_, _poję, naðu_, बदल_
  { {0x3209002a,0xa2d90037,0xca290009,0x657c0248}},	//   _away_, नेस्, _תם_, örha
  { {0x69c71a3e,0x2911004b,0xeb97003c,0x6d48005e}},	//   elje, eaza_, зию_, aeda
  { {0x61ed02d1,0xe29f0028,0x9166001a,0xab5b003a}},	//   _cual, kaðu_, _nỗ_, nmüy
  { {0xa6e10028,0x6d550133,0x321e0042,0x8dfa0009}},	//   öðug, _naza, čty_, _ההסת
  { {0xd0590024,0x9d5200ae,0xe29f07ef,0x291a068e}},	//   орті_, _سنيت, daðu_, ópai_
  { {0x7ae40026,0x09a80011,0x7306003c,0xb7e3003c}},	//   žiti, _औद्य, _эпиз, ежск
  { {0x69c70133,0x6fc51a3f,0xe29f0028,0x6d551a40}},	// [3e60] blje, góci, faðu_, _baza
  { {0xe29f0065,0xe617007c,0xd6cf0003,0xd5b20003}},	//   gaðu_, яду_, اقك_, رفض_
  { {0x717b0093,0xb97b000b,0xa97b000b,0x98160003}},	//   _הניס, _הניי, _האיכ, _عبدا
  { {0x290c0005,0x225f1a41,0x261c0037,0x6d480002}},	//   _seda_, _bruk_, _मिली_, zeda
  { {0x11540800,0x6f041a42,0x6fc50018,0x517600af}},	//   дклю, mbic, cóci, ּגֶב_
  { {0x644300bd,0x15f10037,0x8a17000b,0xb5fb0028}},	//   _opni, _अंतर_, לחנו_, _fráb
  { {0x8c431a43,0x61fb004a,0xf7720003,0x04431a44}},	//   _пере, _etul, فاظ_, _перн
  { {0x69c100a2,0x645b0002,0xafe3004c,0xdb090060}},	//   _ekle, śció, нојл, ülüy
  { {0x6d55003a,0x290c1a45,0xb5fb0066,0xf2020011}},	//   _yaza, _teda_, _irác, रीख़_
  { {0x61eb0061,0x71a30001,0x1dbe0011,0x51fb0009}},	//   _égli, _зауз, ्तित, _להמצ
  { {0x69c7048b,0xab5b003a,0x6fc5000e,0x7ee60012}},	//   vlje, slüm, zóci, _فكان
  { {0x60c50006,0x6d48012e,0x9582003e,0x63a21a46}},	//   _ryhm, seda, _żąda, nion
  { {0x61ed1a47,0x2a600132,0xe3b00012,0xf77f01a0}},	//   _qual, _crib_, ارٍ_, _niça_
  { {0x26db000b,0x69c7008e,0x63bd0031,0x7d0e0032}},	//   _הקדמ, ulje, sosn, _nebs
  { {0xe53b000b,0x5d3b000b,0x63bd009b,0x0d3b0009}},	//   _התור, _התוא, posn, _הגוב
  { {0x69c7001c,0x15f10037,0xf7730003,0x4fc404ad}},	//   slje, _अंदर_, راز_, есуа
  { {0xe29f0065,0x6b8d0101,0xbbc90037,0x2bb10002}},	// [3e70] taðu_, _ilag, रतीक, jąca_
  { {0x6fc50002,0x5d980009,0x27e61a48,0x26c70035}},	//   róci, קֹּד, _lion_, āno_
  { {0xe29f0028,0x61fb0914,0x645e001b,0x7dc60097}},	//   raðu_, _stul, _špij, rðsh
  { {0x6008000b,0x8a59001e,0xd8080009,0xf8b20009}},	//   _מִשְ, ņēmā, _מִשָ, _ישי_
  { {0x1995002d,0x6e24198a,0xe29f0028,0x2d851a49}},	//   мадя, crib, paðu_, ykle_
  { {0xbd450003,0x2fc9000e,0xa0690001,0x992b003c}},	//   _تنسي, llag_, жака_, сюда_
  { {0x63a20002,0x23690027,0x6b8d006f,0xd91c0009}},	//   bion, _onaj_, _olag, זוול
  { {0x69c10002,0x225f1a4a,0x0e6504a5,0x7ae9004b}},	//   _wkle, _truk_, дкин, _uget
  { {0xa3c30037,0x0f58000b,0xe3b00012,0xf1f80012}},	//   ्तन_, ליהם_, _صرف_, _فعلت_
  { {0x6e290164,0x2fc90052,0x6f0f0e9c,0x6b8d1a4b}},	//   rueb, hlag_, _lecc, _alag
  { {0x1b4a0345,0x6b8d02a1,0x5f450012,0xa34a0373}},	//   озни_, _blag, _ينطل, озна_
  { {0x78880003,0xe2870003,0xf9890009,0x58ba0009}},	//   _عَنِ_, نذ_, _דר_, _ומעצ
  { {0x7ae4009b,0xcf920009,0xe297003c,0xf7720009}},	//   žitv, _בטא_, дая_, _שקד_
  { {0x63a21a4c,0xdb060034,0x94050012,0xa3d40011}},	//   zion, tokó, _قوته, _सीन_
  { {0x7c920003,0x04920012,0x7dcb0060,0x91e30511}},	//   _للوص, _للوح, rüsl, торе
  { {0x29050028,0xdb061a4d,0x6b8d0412,0x201e001b}},	//   ðlar_, rokó, _glag, štio_
  { {0x6f0400b6,0xbbd7000b,0x6d5a0097,0x62730012}},	// [3e80] rbic, _קופץ_, _ótak, _لهيئ
  { {0x63a2003e,0x31e60012,0xdb060034,0x07fa0012}},	//   wion, _تسعّ, pokó, _ورجع_
  { {0x6c4a0003,0x661600b0,0x5f061a4e,0x7d0e001b}},	//   تلاف_, ssyk, _озна, _vebs
  { {0x27f7022d,0x7dc60028,0xcc760009,0x6e241a4f}},	//   žené_, rðsi, וגעת_, prib
  { {0xb5fb0066,0xda770048,0x22160a8b,0x63a21a50}},	//   _vrác, дящ_, ффер, rion
  { {0x69dc0027,0x2bb10034,0x61eb0025,0x6a830048}},	//   nmre, rąca_, _ègle, ълча
  { {0xa3c30037,0xb5fb001a,0xf2020037,0x4b260003}},	//   ्तम_, _trác, रीज़_, _يعرف
  { {0x97a30015,0xab5b1407,0x501b0009,0x649b0009}},	//   крыл, rlük, קופו, _וילה
  { {0x7ae90027,0xf3f9004b,0x657c0031,0xcb370009}},	//   žetk, _ăţi_, _korh, _קאמי_
  { {0xfe6f0003,0xe1660003,0x4498002d,0xceb30009}},	//   ؤدي_, _تدري, звою_, כיח_
  { {0xe046002d,0xec6a0024,0x69dc0159,0xe73a028b}},	//   _інди, ірок_, dmre, _меж_
  { {0x0a6b0014,0xa3c00011,0xa3d40011,0x61eb0031}},	//   орги_, ुति_, _सीम_, _úllé
  { {0xfe720003,0xc2cb0012,0xcf250012,0x3a2600b0}},	//   _جدا_, تبدل_, _أرمي, nrop_
  { {0xc8fb0037,0x6f0f1a51,0x7dcf0260,0x3d080011}},	//   ्रेम_, _secc, løsn, षरों_
  { {0x61e81a52,0x55bb0009,0x14730012,0x2d8e0032}},	//   _midl, _ומגו, _لايج, _ilfe_
  { {0x93780003,0x9df90294,0x6b8d1a53,0x00570009}},	//   _يصير_, знат_, _ulag, ושלת_
  { {0x6f0f00c1,0x6d5a0058,0x7aed0051,0x442c1a54}},	// [3e90] _vecc, odta, _igat, lud_
  { {0xf9fc0009,0xe5730012,0x6da4004c,0xeca7004c}},	//   _והזמ, خطر_, виђа, мјен
  { {0x442c03fb,0x3c38000e,0x2fc900b0,0x0cd40009}},	//   nud_, név_, plag_, תֵּר_
  { {0x61fb000d,0x291e000e,0x43080012,0x69ca1a55}},	//   ţulu, _adta_, ِينَ_, elfe
  { {0x657c038e,0x824b0003,0x645a0027,0xa96900db}},	//   _forh, تشاف_, _štit, зила_
  { {0x442c1a56,0x30550001,0x20550e99,0x7dd00248}},	//   kud_, еђит, етир, läsn
  { {0x6e2d002a,0xb8f70011,0x20890048,0x645c0097}},	//   luab, _सर_, яйки_, æril
  { {0xa4d4007c,0x442c0005,0xef190b4e,0x99800034}},	//   _росі, dud_, чми_, _zwiń_
  { {0x7e620132,0x7c3a0025,0x645d0035,0x67260031}},	//   _crop, ettr, āsim, ókja
  { {0xe5710003,0x8c95002d,0x7e621a57,0x61e80097}},	//   اطة_, ермі, _drop, _gidl
  { {0x7e6200b6,0x2907009b,0x442c0051,0xd469096e}},	//   _erop, mbna_, gud_, чине_
  { {0xb9020011,0xab770012,0x6d580227,0x6e2d005e}},	//   ने_, ّمَا_, _eava, kuab
  { {0xbe870003,0x3e870012,0x3f8f0035,0xc6040024}},	//   _تجاو, _تشاف, _ilgu_, _азій
  { {0xfe700003,0x44250159,0x201e001b,0x64550032}},	//   _خدم_, prl_, štim_, _oszi
  { {0x2bb10002,0x75d20003,0xdc32001e,0xa067005f}},	//   jąco_, _حيوا, kļāv, нара_
  { {0x9f4600c1,0x657c0031,0x3f89016d,0x6d581a58}},	//   _cioè_, _sorh, gkau_, _zava
  { {0x3ea00065,0x6d58003a,0x05660048,0x6e2d1a59}},	// [3ea0] _þitt_, _yava, нван, guab
  { {0x7abb0009,0xb2bb0009,0xdb090097,0x69a40011}},	//   _מצפו, _ממפר, _skeð, _औषधी
  { {0x657c008b,0x10a6002d,0x3f8f1652,0xcb0a0012}},	//   _vorh, _чинн, _olgu_, كيان_
  { {0x61e8006f,0x2b5b000b,0xb5fb029d,0xd7fb0009}},	//   _sidl, ּ֣אמ, _irán, _מהטל
  { {0x6f630047,0xbd8a0003,0xf1bf01e3,0xb97a0009}},	//   _связ, _فنحن_, irán_, ּנֶי
  { {0x64a6022e,0x6f16003a,0x7c3a0028,0xdca6077e}},	//   _зага, layc, yttr, _заги
  { {0xb0da0037,0x61e80027,0xd7f1001a,0xfdbe0037}},	//   येंग, _vidl, _cũ_, ्तीफ
  { {0xdb1d0061,0x395a1326,0x6d581a5a,0xae210011}},	//   posé, _laps_, _sava, _मिशन_
  { {0x6d58007a,0xe297002d,0xf1bf0164,0x61e8024c}},	//   _pava, _зат_, drán_, _tidl
  { {0x40961154,0x63a60065,0x721b000b,0x442c1a5b}},	//   _прет, eikn, _מומח, tud_
  { {0x0caa003c,0x442c005e,0x320d0032,0x6fc501e3}},	//   ятии_, uud_, _zwey_, tóct
  { {0xdc8b000b,0x60c40060,0x86c60012,0xd5be0011}},	//   לְכָ, ğimd, _كيان, ्तुओ
  { {0x6d5807f6,0xb5fb000e,0x442c1a5c,0x722a0009}},	//   _tava, _arán, sud_, הוָ֗
  { {0xa024008b,0xb5fb00d9,0xdee300bb,0x5dfb0009}},	//   _größ, _brán, _сочи, _צפונ
  { {0x8d5b0093,0x1048002d,0x23790012,0x6fc501e3}},	//   _זכוי, няти_, _يمتد_, mócr
  { {0x0aeb0003,0x7dc61a5d,0x6e2d1a5e,0x3f8f0097}},	//   _عربي_, rðsu, tuab, ógu_
  { {0x8d870015,0x62860248,0x6e220064,0xc33400af}},	// [3eb0] нужд, cyko, šobn, _עוץ_
  { {0x22490027,0x57f5010c,0x61ef0025,0x3f890032}},	//   _ipak_, _ипот, _écli, skau_
  { {0x645a009b,0xdcf80027,0xe8950015,0xf9900003}},	//   _štir, _novč, _рань, _دبي_
  { {0xa3c30044,0x501a0009,0x93580024,0x94040012}},	//   ्ति_, _קורו, ершу_, اونه
  { {0xff160009,0x42090024,0xdc130060,0xfbd00012}},	//   _בקרת_, єнко_, rşıt, حتل_
  { {0x25a50065,0x7dcb0051,0x7dc60028,0xd9450048}},	//   _öll_, küsi, iðss, теки
  { {0xa3c30044,0x7bc60028,0x1fb503e2,0x31580009}},	//   ्ता_, _íhug, ксир, גיון_
  { {0xd00e0003,0x883c000b,0xf7710012,0xaf020048}},	//   آلي_, פתחו, شاب_, апъл
  { {0x236d0029,0x25a51359,0x92b70012,0x3e320012}},	//   _inej_, till_, _أحزا, لفير
  { {0xb465002d,0x45850014,0x6e3b03fe,0x39940032}},	//   вкол, тгов, rtub, _käse_
  { {0x63a6120d,0xccf20009,0xa1280012,0x25a51a5f}},	//   tikn, יכי_, _أكمل_, rill_
  { {0xf6750012,0x62990034,0xdb0b0034,0x6604008e}},	//   _لاتخ, ozwo, mogó, ypik
  { {0xeb9705cc,0x2d990025,0xed4e0f28,0x69c3068b}},	//   тия_, èses_, _ко_, oone
  { {0x412a007c,0xc212000b,0xdbdf0097,0x63a60754}},	//   ього_, שהם_, síðn, sikn
  { {0x03aa0003,0x6f0901e9,0x661d013e,0xc7a60048}},	//   _يدعو_, obec, _avsk, вивк
  { {0xe4e4002d,0x2fcd0fc4,0x6ce4002d,0x62660063}},	//   _січн, nleg_, _січе, _авиа
  { {0xee3a00c0,0x6609003a,0x69c31a60,0x395a1a61}},	// [3ec0] ьна_, _çekl, kone, _taps_
  { {0x69c30119,0xdb000061,0x660400b6,0xb5fb1a62}},	//   jone, _immé, rpik, _trán
  { {0x69c300ec,0x74130003,0xb5fb1a63,0x2fcd0097}},	//   done, لولا, _hrál, kleg_
  { {0xb5fb05b1,0x29181a64,0x661b01a3,0x9cd60009}},	//   _král, lara_, ksuk, דועה_
  { {0x27e00006,0x63a400c1,0xc3330009,0x2fcd0097}},	//   mmin_, _mmin, שוד_, dleg_
  { {0xf5030015,0xba9b0009,0xb4260012,0x11d70012}},	//   _взро, וסני, _لعرو, نونة_
  { {0x63a40006,0xf993000b,0xd7f8001a,0xa9670001}},	//   _omin, שרו_, _trăm_, тија_
  { {0x2fcd0065,0x6d5c093e,0xcc570009,0x00bb0009}},	//   gleg_, _hara, _בבלי_, ומצמ
  { {0x6d5c1a65,0x3246004c,0x201e001b,0x661b020d}},	//   _kara, _језг, štih_, gsuk
  { {0x63a41636,0x27e0003a,0x6d5c00b6,0x55740014}},	//   _amin, hmin_, _jara, угот
  { {0x6d5c1a66,0x19b90223,0xd3710012,0x29181a67}},	//   _mara, _чуть_, مهد_, dara_
  { {0x6d5c0175,0xa7fc0060,0x03c4003c,0x8c1b0009}},	//   _lara, _yrın, исям, ווטי
  { {0x661b000e,0x7e9a0012,0xdb060031,0x8d760012}},	//   csuk, _تنشر_, unká, _لاغا
  { {0x291800ec,0x9f810065,0x6ff1001e,0x7dc60028}},	//   gara_, lóð_, _sāci, rðss
  { {0x25ab0108,0x28f80800,0xdb1b001a,0x6d8b0009}},	//   ècle_, тесь_, _khuô, _קָדְ
  { {0x63a40002,0x6d5c002c,0x40340001,0xe4e30011}},	//   _gmin, _aara, јетс, _कृषि_
  { {0xdb1d000f,0x6d5e0070,0x6d5c1a68,0x6ff1001e}},	// [3ed0] nosí, fdpa, _bara, _vāci
  { {0x27e00101,0x29180a63,0x6609003a,0x1e3b000b}},	//   amin_, cara_, _çekm, וגמא
  { {0x6d5c1a69,0x95c40012,0x443e1a6a,0x80a20610}},	//   _dara, جيله, ntt_, _केले
  { {0xff040014,0x69c3009a,0x9f810028,0xd8b80012}},	//   _вярн, wone, jóð_, _جدًا_
  { {0x1308002d,0x32450012,0x82a4004c,0x69c31a6b}},	//   тній_, انتف, ишље, tone
  { {0xdb1d000f,0x32b8000a,0x6e2900c1,0xd656000b}},	//   dosí, خدمة_, vreb, _גישת_
  { {0x34950001,0xc174000b,0x317c0009,0x6ce40024}},	//   _савр, יחס_, ורגמ, _віте
  { {0xdb1b001a,0x6d5c0650,0x95fb0009,0x21290060}},	//   _chuô, _zara, ֵּ֖ח, şah_
  { {0x6d5c00a2,0xab5b0052,0x7f5d0573,0x2fcd1a6c}},	//   _yara, hlüs, _masq, rleg_
  { {0x69da0037,0x91e40001,0x6e26000e,0xdb0d0028}},	//   _पीपी, _вође, ákba, _skað
  { {0x2d990010,0x29181a6d,0x6d411a6e,0x7de40012}},	//   ėse_, vara_, rfla, جسيم
  { {0x6e290aa3,0x709a0009,0x60c40060,0x386a0031}},	//   preb, _אֱדו, şimc, _ábra_
  { {0x69da03fc,0x29180db2,0x2905003a,0x6d410052}},	//   _yhte, tara_, ılan_, pfla
  { {0xf652000b,0xceb20009,0xcad60009,0xaec40024}},	//   _לצד_, _פיג_, טורת_, _тбіл
  { {0xb1840066,0xe61f0018,0x6fc70011,0x80e50012}},	//   šťov, _avô_, ावपू, لأفل
  { {0x7c3c0054,0x18670001,0xd1380002,0x3f8d00b6}},	//   àrre, ћати_, żą_, nkeu_
  { {0xa3c30044,0x26160037,0xb50f0011,0x9f490032}},	// [3ee0] ्तर_, पीपी_, िरूप_, smaß_
  { {0x3c3c000f,0xc88500a2,0x5a9b000b,0x7e640584}},	//   tív_, _başı_, _נשיא, _šipk
  { {0xef19003e,0x6d5c1a6f,0xc9530009,0x657c0248}},	//   każ_, _vara, _המת_, örhi
  { {0x2f56007c,0x93bd000d,0x44260a3d,0x8bc5002d}},	//   _стос, luăr, čo_, асід
  { {0x6d5c00a2,0xef190002,0xeab60009,0x92580024}},	//   _tara, daż_, נִ֣י_, талт_
  { {0xada60001,0x443e0e21,0x1db80011,0x7c3e0032}},	//   _сагл, ytt_, _आदित, ptpr
  { {0x853b000b,0x0f560009,0x7bc61a70,0x764b0073}},	//   _רגלי, ָיִם_, koku, _apgy
  { {0xf093000b,0x3f82004a,0xdb1d000e,0x2d83004a}},	//   מנו_, _joku_, tosí, öjen_
  { {0x0936000a,0xa91c0026,0x01360012,0x79810034}},	//   _مراج, _voľb, _معاد, _folw
  { {0xaa930003,0x5c060014,0xd657000b,0xdd900003}},	//   _الكث, ляма, ניית_, زوج_
  { {0xdb1b0020,0xa4d40024,0x94d40f09,0xdb020030}},	//   _thuô, роні, ронц, dnoú
  { {0xdb1d0030,0x443e0e00,0x395e1a71,0xe8d700af}},	//   posí, rtt_, _hats_, _גובר_
  { {0xdcee0066,0x4f650012,0xeb910009,0x98f50081}},	//   _pobě, _خالف, חָם_, _mản
  { {0x365b000b,0xdb06004a,0x7dcb0060,0x3ea20097}},	//   _נכונ, enkä, nüst, úktu_
  { {0x7d1a0416,0x20d40012,0xb5fb0064,0x3cfb0009}},	//   mats, متفج, _vrám, _אלונ
  { {0x291e0028,0xc43b000b,0x998605b1,0x29c90028}},	//   ótar_, _נתחי, spoň_, núar_
  { {0xb5fb1a72,0x51d90001,0xc3340009,0xaaa40011}},	// [3ef0] _irák, _имиџ_, _הופ_, _खेलक
  { {0x442c07b7,0x86e80012,0x3e7a0073,0x7d1a1a73}},	//   ord_, اعِف_, mštą_, nats
  { {0x98f50020,0x7f5d0054,0x7dcb003a,0x70fa000b}},	//   _bản, _tasq, düst, _בהתח
  { {0x442c008b,0x98f5001a,0xdfc60003,0x907a0009}},	//   ird_, _cản, _ذي_, _סטרי
  { {0x6f0d00c6,0x853c0010,0x471a0009,0x2bb80012}},	//   mbac, riėj, _בורג, دالة_
  { {0x69c70006,0xef19003e,0xc885003a,0xda62002d}},	//   noje, waż_, _taşı_, івщи
  { {0x79810070,0x6f0d0112,0x01380009,0x7bc60415}},	//   _volw, obac, ארות_, yoku
  { {0x82f8000a,0x2d830017,0x6e2d009b,0x72050012}},	//   _مركز_, _hoje_, orab, _نورم
  { {0x2d83077d,0x442c00bd,0xbb84000a,0x39940163}},	//   _koje_, erd_, _القي, _läsa_
  { {0x68e7000e,0x2d830010,0x1c45002d,0x20070028}},	//   _újdo, _joje_, аном, ppni_
  { {0x044500be,0x7dcb0052,0x3f8d00b6,0x628b1a74}},	//   шенн, lüss, pkeu_, lygo
  { {0x7d1a0cc6,0x907a0009,0xc4820024,0xd4360009}},	//   aats, _בטעי, іляк, סטרי_
  { {0x69da0037,0x442c1a75,0x31a60012,0x61ee0060}},	//   _पीडी, ard_, لمحف, _ünlü
  { {0x23af004a,0x395e0054,0xdcfe001e,0x69c704d2}},	//   töjä_, _xats_, āvīg, goje
  { {0xa3d50037,0xc0e60063,0x7dcb0032,0x3e7a0073}},	//   हता_, ровк, hüss, aštą_
  { {0xb4c10037,0x1cba0009,0x67a50012,0x64411a76}},	//   ंथी_, _במצע, محقق, mtli
  { {0x44330061,0xf772000b,0x64411a77,0xa3b50011}},	// [3f00] eux_, חקן_, ltli, ड़कर_
  { {0x75d30003,0xe3b9003a,0xf6230024,0xddcd0034}},	//   قيقا, brıs_, ідхо, ewał
  { {0x14170003,0xb97b0009,0xd7f8004b,0x7afb0073}},	//   ليلة_, _סנטי, _trăi_, žute
  { {0xdcf6003a,0xdb0b0017,0xd7fb0009,0x6b840025}},	//   ıcıl, ligê, _שהכל, _joig
  { {0x44330108,0x3f820028,0x395e0213,0x64411a78}},	//   aux_, ökum_, _pats_, htli
  { {0xfad70093,0xa3dd0044,0xf84a002d,0x60c9003a}},	//   בונך_, _तीन_, вчий_, şeme
  { {0x7d1a1a79,0x7547000e,0xdb1d000e,0x7dcb07a4}},	//   vats, észő, őzés, rüst
  { {0x7dcb0051,0x9fae0066,0xf1bf081b,0xddc40034}},	//   süst, _tří_, nuár_, ywiś
  { {0xd6d71a7a,0x539b000b,0x64410002,0xdcb1001a}},	//   ить_, _סימו, etli, uản_
  { {0x80f50037,0xddc20002,0x27ef0028,0x64411a7b}},	//   _आलेख_, _społ, _eign_, ftli
  { {0x1b190047,0x7d1a1a7c,0xd12f0003,0x442c0ca5}},	//   лжны_, rats, _زمن_, urd_
  { {0x7d1a1a7d,0x69c70002,0x0ba7002d,0xc0d30012}},	//   sats, woje, ршом, _بيمب
  { {0x69c71a7e,0x9f42004a,0xf1bf000e,0x6b840b66}},	//   toje, _mikä_, nság_, _doig
  { {0x660900a2,0x88c70003,0xe3be003a,0x69c7008e}},	//   _çeki, لتأل, ğıya_, uoje
  { {0xf773000a,0x628b0002,0xddcd0002,0x6b961a7f}},	//   يار_, zygo, ywał, _flyg
  { {0xcf980046,0xa3d20044,0x27ef0028,0x5bc40012}},	//   ају_, वतः_, ögn_, _وقول
  { {0xfe700003,0x69c700f1,0x291c1277,0x46150012}},	// [3f10] ودك_, poje, kava_, صوار
  { {0xca360009,0x291c1a80,0x4d98003c,0x2b5f0035}},	//   _פנתה_, java_, акую_, _sauc_
  { {0x201e0066,0x9af50003,0x5ca90009,0x55640012}},	//   átit_, مكات, ְׁנַ, تهلك
  { {0x2d830034,0x628b0034,0x3a7509e8,0xa2c305f3}},	//   _woje_, tygo, йлер, िअल्
  { {0xd6db0046,0xca490003,0xf1bf000e,0x2d830010}},	//   _што_, الته_, gság_, _toje_
  { {0x9f420006,0x27ef006d,0x628b01f6,0x98a50060}},	//   _eikä_, _sign_, rygo, _salı_
  { {0x0495000a,0x7c95000a,0x6c850003,0xe9df01e3}},	//   _الأح, _الأص, _الزم, ctúe_
  { {0x28b80093,0x67170037,0x5ba404b3,0xf8b80009}},	//   יפוש_, तरिक_, _друз, יפוי_
  { {0xdfa4000a,0x2294002d,0x63a9048b,0x6f1b1a81}},	//   تحوي, _дитя, _imen, rauc
  { {0x6f1b001e,0xa928002d,0x6b840fac,0x7bcd001b}},	//   sauc, _віце_, _soig, _akau
  { {0x84580014,0x30a70ae9,0xd5e80012,0xb9c40012}},	//   арят_, _трав, جعين_, _بقلي
  { {0x63a90066,0x4421002a,0x7dd00374,0x8b96022a}},	//   _jmen, ish_, räsi, сроч
  { {0x66050a15,0xcad50009,0x7dd0008e,0x09e60024}},	//   _упла, מוֹת_, säsi, йомн
  { {0x910300ac,0xd9460001,0x99d60012,0x64410032}},	//   зпре, љеви, إتحا, ptli
  { {0xdcfc0333,0xcd76000b,0xb7960001,0xb9000321}},	//   _norā, _לעסק_, браћ, _तर_
  { {0xd00f0003,0x4fa30014,0x07a3005c,0xa7d00037}},	//   علق_, писв, пасн, _डीफ़ॉ
  { {0x67c10039,0x32460003,0x75d60012,0xdcb10081}},	// [3f20] mējd, _انخف, ميرا, iảm_
  { {0x63bb1583,0x6e2b000e,0xe3b9003a,0x649a0863}},	//   _ajun, ágba, nsın_, лтер_
  { {0x6ab00037,0xcb6a0001,0x25d60009,0xab5b005e}},	//   जप्र, лаже_, צוען_, foüh
  { {0x201e0010,0x63a90002,0x031a0012,0xf2360009}},	//   štis_, _cmen, اتات_, ֶרֶץ_
  { {0x23270014,0x27030081,0xe3b90060,0x63bb1a82}},	//   сочи_, _ổng_, ksın_, _djun
  { {0x5d860003,0xf5960003,0x55e30015,0x7d960003}},	//   _الآل, _السج, _нояб, _السؤ
  { {0xf1bf000e,0xc866010c,0x6e221a83,0x3c780009}},	//   sság_, стли, _svob, _דָּב
  { {0xbb430047,0x33b60003,0xf76f0003,0xc7c6004c}},	//   _неск, _امرأ, فاً_, љски
  { {0xa3d50044,0xd6d0000a,0x7f770009,0xf66a0012}},	//   हतर_, بقة_, מעקב_, احبه_
  { {0x63a904b4,0x7d1e1a84,0x6f190034,0x865b0009}},	//   _zmen, naps, ówcz, נדיי
  { {0xe6d50037,0xdb550015,0x50960001,0x6cd40012}},	//   _दर्ज, овны, _урађ, تقدا
  { {0xc7f7000b,0x44441a85,0x18770009,0xe3b90060}},	//   _הזאת_, it_, _לעבר_, asın_
  { {0x2aab0046,0x44441475,0x7d1e0f33,0xc3330009}},	//   утно_, ht_, kaps, הור_
  { {0x398f0051,0xd2b70009,0x06570009,0x1e570009}},	//   _küsi_, מלכת_, _לידך_, _לשדר_
  { {0x6f0d007d,0x7c060012,0x251b0009,0x4da50012}},	//   _încâ, _ابتك, _גווא, _بإنف
  { {0xd5b8001e,0xa3bd0037,0x06150021,0x5a350048}},	//   lnā_, _आदि_, ждаю, _днит
  { {0x88bc0066,0x22590015,0x7644002c,0xaa590400}},	// [3f30] _sděl, _типы_, gtiy, _типу_
  { {0x63bb006f,0x44441a86,0xd5b80035,0xa3c30011}},	//   _sjun, ft_, nnā_, ्तक_
  { {0x28080066,0xa91c0029,0x9f63000e,0x24550012}},	//   ětné_, _poľn, ívók_, تناس
  { {0x93bd000d,0x398b0262,0x7c940012,0x44211a87}},	//   crăt, _løst_, أشكا, rsh_
  { {0xa91c0029,0x60c4003a,0x59fc0009,0xd5b80035}},	//   _voľn, şiml, ָּׂד, knā_
  { {0x29030002,0xcad80009,0x44441a88,0x851d0011}},	//   ncja_, צוגת_, bt_, _फ़िट_
  { {0x26160044,0x88bc0066,0xab95002d,0x93e90003}},	//   पीसी_, _uděl, _диві, _نفسك_
  { {0xdfd10003,0x6fb50003,0x63bb00b6,0x63a91a89}},	//   بيع_, تمعا, _ujun, _umen
  { {0x7bcb001c,0x29030002,0x9b880012,0xed590024}},	//   mogu, kcja_, _انقل_, аоп_
  { {0x05a90015,0xdb0b1a8a,0x22b80012,0x61fb020d}},	//   рвой_, digé, _ادفع_, _iuul
  { {0xe3ba0015,0x7dd01512,0xb5fb0018,0xc1040012}},	//   ибо_, mäst, _gráv, _روني
  { {0x3ce1015f,0x61fb07f6,0xfbc90037,0x64450bf8}},	//   _करने_, _kuul, िकिम, ithi
  { {0x61fb0051,0xb69b000d,0x44441a8b,0xdb1d0248}},	//   _juul, _sfân, zt_, dosä
  { {0xdb0f0054,0x61fb00e6,0x7dd01a8c,0x44441a8d}},	//   ancà, _muul, näst, yt_
  { {0x7bcb0005,0x6fea0002,0x2b4d00d9,0xc1720009}},	//   kogu, _ręcz, _obec_, וחם_
  { {0xd00f0012,0x29030034,0x6b9d0032,0x673b105f}},	//   ضلك_, acja_, chsg, nguj
  { {0x660d002c,0x7dd0027e,0xddc20159,0x45860365}},	// [3f40] gpak, käst, _hroš, огав
  { {0x7644003a,0x22420051,0x5bd20011,0xe617003c}},	//   rtiy, _äkki_, तत्व, юду_
  { {0x44441a8e,0xcb0a0012,0x660d1a8f,0x76441937}},	//   ut_, ليان_, apak, stiy
  { {0x29050290,0xe8000011,0xa3d40011,0x59b20011}},	//   _afla_, _लंबा_, _सीख_, ँचकर
  { {0xff57000b,0xba170012,0xaaba0012,0x64450132}},	//   _ובכך_, قينا_, جدار_, athi
  { {0x082a005c,0xb5fb0107,0xdd02001e,0xf806161c}},	//   ации_, _práv, ārīg, очин
  { {0xcf9a0046,0x23ca0011,0x7d1c1a90,0xf1bf06dd}},	//   ији_, रवाद, _iers, práv_
  { {0x39581a91,0x65630070,0x644301a0,0xc7b90031}},	//   hers_, _aanh, ànie, gnő_
  { {0xe3be00a2,0x29030002,0x6609003a,0x39581a92}},	//   ğıda_, ycja_, _çekt, kers_
  { {0xe3b9003a,0x48e617fe,0x2d9817a4,0x7dd01a93}},	//   asıl_, _дозв, óre_, mäss
  { {0x2d87002a,0xb4fb007e,0x3e4e001e,0x32091a94}},	//   _done_, יפיי, lētā_, _stay_
  { {0xddc20039,0xbb940015,0xf1bf0066,0x6b82000e}},	//   _droš, дающ, hrát_, njog
  { {0x290c003a,0xf1bf0042,0x39581a95,0x22461a96}},	//   ıdan_, krát_, fers_, ntok_
  { {0x65630017,0x2d87002a,0x60cd000d,0x5bb70037}},	//   _ganh, _gone_, şame, _अद्व
  { {0x6ca30014,0x6bd70012,0xf20f0011,0x79540012}},	//   _оръж, _وتعر, ़ीज़_, بَّا
  { {0x23280001,0xdfd00012,0xc6f90048,0x6720001b}},	//   _доћи_, نيّ_, снах_, namj
  { {0x2b59000d,0xccfb0001,0x7d1c1a97,0x59ca0011}},	// [3f50] mesc_, аће_, _bers, ाकार
  { {0x3958002a,0x93bd000d,0x61c60011,0xfd100012}},	//   cers_, crăr, लकृष, نجم_
  { {0x515a0093,0xdb060485,0x43750e0f,0x7bcb0010}},	//   _הכתו, liká, зулт, togu
  { {0x7d1c00bd,0x2b59000d,0xb5fb1a98,0x6d4e0248}},	//   _eers, nesc_, _brát, _ebba
  { {0xea000020,0x27e91330,0x81d5010c,0x877a0009}},	//   _đảm_, mman_, подх, _הארי
  { {0x8dfa0093,0x89a8002d,0x4e16000b,0x45fa000b}},	//   _להשת, оків_, _מחשב_, _להשג
  { {0x319c0093,0x63ad0005,0xf1b4000b,0x7dd0004a}},	//   שבונ, _oman, וסס_, räst
  { {0x27e90101,0x3858000a,0x7d1c0052,0x6563002c}},	//   nman_, تشهد_, _zers, _sanh
  { {0x28d20044,0x39640006,0x39580503,0xa3d40011}},	//   _दुनि, össä_, yers_, _सीट_
  { {0xf2d2000b,0xdbd70269,0xddc21740,0x26b60009}},	//   _טען_, hääl, _proš, לִים_
  { {0x65630006,0x8afd0066,0x8d48000b,0xfbd20003}},	//   _vanh, _zařa, חֲרֵ, فتح_
  { {0x39580087,0x25a2001e,0xdb061a99,0x6b890227}},	//   wers_, īkla_, fiká, _joeg
  { {0x8c49003a,0x93bd000d,0xc7b20009,0xa3bd0011}},	//   laşı, trăr, _אבא_, _आदर_
  { {0xddc21975,0xdcb1001a,0xf1bf0649,0x2d9e1a9a}},	//   _troš, hải_, drás_, chte_
  { {0x251a000b,0x7d7a000b,0x6f1d0b3d,0xa06a0014}},	//   _הוצא, _לנסו, _besc, щава_
  { {0x2fcd0070,0x7d050052,0x6fb60012,0xf4940012}},	//   noeg_, echs, أمرا, _تشهد
  { {0x59cb0037,0xbb3b01b0,0x539b0009,0x41cb0011}},	// [3f60] िवार, _העפי, _ליקו, िवास
  { {0x7dd0004a,0x63ad1a9b,0x27e91a9c,0x6b9b1a9d}},	//   väss, _zman, aman_, _alug
  { {0xcea9000b,0x7dd00052,0x39c50012,0x60fb0009}},	//   ני_, wäss, _تغيّ, _להיק
  { {0x7d1c003e,0x6f1d0518,0x8c49003a,0xd5b1001a}},	//   _wers, _gesc, daşı, hí_
  { {0x7d1c00ec,0x79880002,0x98be0010,0x298a022a}},	//   _ters, _podw, _patį_, йско_
  { {0x2246000f,0xb5fb022d,0x3e4e001e,0x159a0003}},	//   rtok_, _vrát, rētā_, _انسخ_
  { {0x3e4e001e,0x34a7010c,0x6b9b1168,0xc1730009}},	//   sētā_, _евро_, _flug, תחו_
  { {0x3ce10044,0x9cbb000b,0xa91c0029,0x69ce0052}},	//   _करते_, _הצלח, _koľk, hobe
  { {0xed580026,0x98b1001e,0x2b59000d,0xd37b000b}},	//   teľ_, ībām_, vesc_, _פרמט
  { {0xf64f0003,0x63ad0027,0x5a9b000b,0xba9b0009}},	//   ائي_, _sman, _השמא, _הסמי
  { {0xdcfc0002,0x2b59004b,0x6441008e,0xf1bf0097}},	//   _gorą, tesc_, _älit, krár_
  { {0xdb06000f,0x57fb000b,0x907b0009,0x34b70009}},	//   tiká, _הלאו, _לטבי, לפים_
  { {0xdfa50003,0x2b59000d,0x2707001a,0x69d81a9e}},	//   _تحلي, resc_, _ống_, olve
  { {0x3eb90026,0x2b59000d,0x1677000b,0x67c1001e}},	//   úste_, sesc_, _מגדל_, mēja
  { {0x6d5a1a9f,0xa3be0037,0xfce30001,0x67c1001e}},	//   meta, ीका_, _пољо, lēja
  { {0x443a00c6,0xbfd9002d,0x291e1aa0,0x1cbb000b}},	//   dup_, ідає_, _leta_, _למוע
  { {0x9f4c0026,0xd6db064f,0x6d5a0051,0x6f1d1aa1}},	// [3f70] _budú_, ств_, oeta, _vesc
  { {0x7bcf000d,0xf1bf000e,0x7d050052,0xe29c0009}},	//   locu, rrás_, uchs, _לשחר
  { {0x7d05008b,0x44271205,0xac190024,0x6b9b1aa2}},	//   rchs, én_, іоду_, _plug
  { {0x14740003,0xfc300003,0x6d5a03ae,0x8c49003a}},	//   عالج, احل_, heta, vaşı
  { {0xa294002d,0x6b890070,0x957c0010,0x5f940014}},	//   наці, _voeg, rmąj, _чият
  { {0xac19069b,0x67c1001e,0x44250066,0x7c3a000e}},	//   _могу_, dēja, ysl_, kutr
  { {0x6b8900bd,0x246c0066,0x7e6d1aa3,0x6d5a0d19}},	//   _toeg, _něm_, lvap, deta
  { {0xefc8001a,0x409c0009,0x69d81aa4,0x389c0009}},	//   _địch_, מבוס, alve, מיונ
  { {0x7e62000f,0xb659002d,0xbbc90011,0xdb060060}},	//   _csop, іших_, िकीक, likç
  { {0x291e0065,0xdc12003a,0x1dbf0037,0xd658000b}},	//   _geta_, _ağın, ्वित, ליחת_
  { {0xb8080003,0x6567009b,0xd5b1001a,0xf494003c}},	//   _فيلم_, _majh, rí_, еряю
  { {0x7e6d05b1,0xeb97003c,0x6d5a008e,0x09c60011}},	//   kvap, дию_, aeta, लक्य
  { {0x65a00052,0x644e003a,0x67c1001e,0x6d5a1736}},	//   _höhe, çbir, cēja, beta
  { {0x9f5e03fc,0x64551aa5,0x443a003a,0x4a5a0009}},	//   _että_, _opzi, yup_, חדשו
  { {0xdb00004a,0x43860003,0x69ce1aa6,0x7e6d0060}},	//   _ymmä, _يلتق, robe, evap
  { {0xe61a0ac5,0xe3b20003,0x04560012,0xdb060060}},	//   жда_, _جرت_, _آلية_, dikç
  { {0x60c400a2,0x558a002d,0xdcf80066,0x6455001e}},	// [3f80] ğimi, обам_, _nově, _apzi
  { {0xee37002d,0x60c4003a,0xca370009,0xe6de0011}},	//   ьну_, şimi, _קניה_, _मरीज
  { {0x1d19002d,0x7649004a,0x67c1001e,0x8b6a0014}},	//   яють_, htey, zēja, жиев_
  { {0x7649003a,0x99820010,0xa91c0029,0x64430054}},	//   ktey, pukų_, _toľk, ània
  { {0xd250000a,0x925a0003,0x7c3a0052,0x291e1aa7}},	//   انت_, تشار_, zutr, _peta_
  { {0x67c10035,0xdb06079b,0x6724008e,0x7dd401a0}},	//   vēja, likä, laij, nàst
  { {0xa3d90044,0x291e006f,0x8b260001,0xc9530009}},	//   _ठीक_, _veta_, _одве, דמו_
  { {0x67c1001e,0x57fb0009,0x332001a0,0x88bc0030}},	//   tēja, חלקו, _neix_, _oděv
  { {0xf54e008a,0x6d5a0933,0xe2460012,0xc7d70009}},	//   _dụng_, teta, _تخزي, ווקי_
  { {0x60cd003a,0x67c1001e,0xaad20011,0x867b0009}},	//   şama, rēja, _सड़क, קריו
  { {0xf5370009,0x6d390009,0x75370009,0xc0490081}},	//   וניי_, הֲרו, ואיד_, _mướn_
  { {0x69c00108,0x67c10039,0x6e360002,0x7c3a17c5}},	//   émen, pēja, kryb, rutr
  { {0x4e960003,0x7c3a190d,0x6d5a1aa8,0x61f70248}},	//   _تشار, sutr, peta, _pixl
  { {0x7c3a0f50,0x246c0030,0xb9e40024,0x6e360b64}},	//   putr, _těm_, віси, dryb
  { {0x8557000b,0x4bdb0003,0x98480014,0x44a30003}},	//   _חשוב_, _وبعد_, мята_, _لموق
  { {0xab5b003a,0x2d8e0032,0xdb1d0248,0xb6f5004c}},	//   ylüy, öfen_, elsö, езбј
  { {0x7e6d008e,0x93bd004b,0xd64b0024,0xdfd80048}},	// [3f90] uvap, nsăm, дiсл, фър_
  { {0xc4db0001,0x99540029,0xdb06003a,0xd9e30011}},	//   ође_, _päť_, tikç, _गठित_
  { {0xddc20002,0x7bc80025,0xf3f90365,0x6e360073}},	//   _spoś, éjug, чнеш_, aryb
  { {0xa3a90044,0xdcf80066,0xa5f90593,0x17190009}},	//   गों_, _sově, _нему_, _מוֹע
  { {0xdcf80066,0x7d0a1aa9,0xd6270012,0xf54e0081}},	//   _pově, _offs, _تعجي, _rụng_
  { {0xda620021,0xae1a0009,0xa3e60011,0xddc4004b}},	//   увши, _מושכ, _बीन_, rviţ
  { {0x395a0051,0x20010051,0x7dcb0031,0x0319004c}},	//   õpsa_, _juhi_, küsz, _новј_
  { {0x501c0093,0xd0f80093,0x0e650001,0x166502e3}},	//   קוחו, ומות_, екин, евим
  { {0xa3cc0011,0xea000081,0xb8d60610,0x8db50557}},	//   रकर_, _đầm_, _चे_, есні
  { {0x3f820028,0x099b0012,0x76490097,0x4c8509c6}},	//   ökur_, _بضرب_, rtey, елов
  { {0x3f150047,0xbb4600b3,0xe5720009,0x6f160030}},	//   _здес, ненк, רַח_, ybyc
  { {0x4c82002d,0x8f680003,0x6e360010,0xcb6a0048}},	//   улюв, _يملك_, yryb, чаме_
  { {0xc332000b,0x99840066,0xaae50003,0x95990024}},	//   נוך_, émů_, َسُو, _нтку_
  { {0xc212000b,0x25a80012,0xb5fb0030,0x27ed1aaa}},	//   רהם_, _يدوي_, _psán, lmen_
  { {0xddc4048b,0xf5360009,0xf9920009,0xf1bf0030}},	//   jviš, _טנסי_, נרל_, psán_
  { {0x273a003a,0x2a720002,0xc246002d,0x8e0a0024}},	//   münü_, _tryb_, _зник, знав_
  { {0x290500a2,0x27ed0feb,0xee3a1aab,0x97c3027f}},	// [3fa0] ılar_, imen_, яна_, уйте
  { {0x27ed008b,0x0585002d,0xdb06019a,0x7ae4004b}},	//   hmen_, куєм, sikä, _izit
  { {0x98b8007a,0x88bc0066,0x29181aac,0xbc6a0012}},	//   merį_, _jdět, mbra_, ثمان_
  { {0x8c1a000b,0x67c1001e,0x24860027,0x68e10eb2}},	//   פוני, dējo, ćom_, ülde
  { {0xc6d60003,0xe2970001,0xc3330009,0xc3270012}},	//   _ستحت, нац_, רוד_, ركون_
  { {0x7db60003,0x20660001,0x98b80073,0x6e290159}},	//   _أصحا, еђив, nerį_, dseb
  { {0xdce3012e,0xb8820066,0x84e3002d,0xfce31aad}},	//   _banč, _říjn, _борж, _боро
  { {0x2fc00065,0xdd25007a,0x69dc0052,0xa857000b}},	//   nnig_, _rūši, hlre, תיקה_
  { {0x63a00051,0x67c50010,0x6d5e0227,0x7c3e0ba5}},	//   _ilmn, nėja, oepa, lupr
  { {0x9f40008e,0xdcfc0034,0x3994005e,0x01690012}},	//   lmiä_, _porę, _käsu_, _يحلو_
  { {0xdcba0014,0x80a60003,0x18360012,0x859b0009}},	//   ящи_, _ثمان, _سراح, פשטו
  { {0x67c50010,0x889b000b,0x67e50031,0x6d411aae}},	//   kėja, _משבצ, tóje, agla
  { {0x61fa003a,0xdfcf0003,0x9f40008e,0x7c3e005e}},	//   _kitl, _اين_, imiä_, hupr
  { {0x17fb0003,0x67c50010,0x9f40004a,0x660f0029}},	//   كررة_, dėja, hmiä_, ícke
  { {0xdb0f0164,0xadd7000b,0x9dd70009,0xb9090011}},	//   licí, _רווח_, _רווק_, _बर_
  { {0x61fa0028,0x2553003a,0xc275004c,0x9c0b0009}},	//   _litl, ağlı_, _алиј, _צִוִ
  { {0x2918000f,0x67c1001e,0xdb0f10b1,0x443e1aaf}},	// [3fb0] bbra_, zējo, nicí, lut_
  { {0x66020006,0x4e180003,0xe2a70028,0x11d90012}},	//   _muok, عتقد_, öður_, _زوجة_
  { {0x66020006,0xe3be003a,0xc952000b,0xf99f0054}},	//   _luok, ğına_, _דמי_, spès_
  { {0x04c8000a,0x80480093,0xe3be00a2,0x67c1001e}},	//   روني_, _אֲשֶ, şına_, vējo
  { {0xa3c40011,0x216913f0,0x273a0060,0xa9691a4e}},	//   ्वत_, дили_, zünü_, дила_
  { {0xd838012e,0x23690082,0x66640014,0xade50037}},	//   šče_, žaj_, _съюз, _कठिन_
  { {0xa0660014,0x18660014,0xf7710012,0xb0680012}},	//   ваща_, ващи_, لاة_, فصيل_
  { {0x8cca0037,0x67c1001e,0x3f8900b6,0x443e0df5}},	//   _सँजो, rējo, njau_, dut_
  { {0x764d0101,0x443e0061,0x6458001e,0x67c1001e}},	//   ntay, eut_, _apvi, sējo
  { {0x6e2900c6,0xfe42002d,0x68e40066,0x67c1001e}},	//   rseb, шньо, řida, pējo
  { {0x443e03eb,0x8f550012,0x98170012,0xf9900012}},	//   gut_, _لناش, _أبطا, _ابق_
  { {0x764d003a,0x273a003a,0x3994006f,0x98140012}},	//   ktay, rünü_, _läst_, _إبلا
  { {0xa2d50037,0x2127001a,0xdb0f000d,0x273a0060}},	//   _युद्, oanh_, ficâ, sünü_
  { {0x7bdd0051,0x3ea9001e,0x67c50010,0x443e1ab0}},	//   alsu, dzat_, vėja, but_
  { {0x3f8f0005,0xdfd20003,0x443e1ab1,0xb5fd01bd}},	//   _kogu_, ليس_, cut_, avšt
  { {0xdee60001,0x18670001,0x2127001a,0x6c560009}},	//   воби, њати_, hanh_, _ייצא_
  { {0x3f8f001c,0x2fc00065,0x6d5e044f,0x3994006f}},	// [3fc0] _mogu_, rnig_, tepa, _bäst_
  { {0xdb0b0570,0x67c50010,0x2fcd04d2,0x3f8f1ab2}},	//   vigá, rėja, čega_, _logu_
  { {0xdd100026,0x0326002d,0x0137000b,0x499b000b}},	//   _týžd, вден, _ברית_, _חשיב
  { {0x61ca0037,0xa3c40011,0xeb971ab3,0x67c50073}},	//   ाक्ष, ्वि_, ких_, pėja
  { {0x42540003,0xa1ea0003,0x9f40004a,0x443e0899}},	//   انتر, ورتك_, rmiä_, zut_
  { {0xe2970001,0x7f440061,0xa2c30037,0x6602004a}},	//   ђај_, lgiq, रपत्, _ruok
  { {0x1c390015,0x61fa09d8,0x93460de1,0xa3c40011}},	//   _пять_, _vitl, _инве, ्वा_
  { {0x443e0006,0xf093000b,0xf76f0003,0xe0cf0012}},	//   vut_, שנה_, قاً_, غزو_
  { {0xc7b30093,0x5e430003,0xc9660014,0x75231ab4}},	//   יבה_, لَيْ, _ивай, _benz
  { {0x6602004a,0x61fa0070,0x70560003,0xdcee001e}},	//   _vuok, _uitl, _لنطا, _nobī
  { {0x853b000b,0x443e0872,0x6d3b0009,0x986a0012}},	//   וגיי, uut_, ותינ, _تحذف_
  { {0x040d0020,0x7e67001e,0x443e1ab5,0xc4d30009}},	//   _hưởn, ājpr, rut_, יגת_
  { {0x3f8f0028,0x7e9a001e,0x4e1b0037,0x163404ad}},	//   ögum_, _jāpā, पीआई_, _селя
  { {0x7bc20066,0x5e57000b,0x656a0058,0xa9c4003c}},	//   hnou, _סיוע_, _uafh, асск
  { {0x75280002,0x7bc20066,0x9f35002d,0x31c40048}},	//   madz, knou, леві, рсяв
  { {0x3ea903eb,0xa857000b,0x394d0030,0xb8db0011}},	//   tzat_, כילה_, řes_, _आइ_
  { {0x8bb40003,0x5d550014,0x7bc20066,0x7c2e028e}},	// [3fd0] _خصوص, лкат, dnou, _avbr
  { {0x85140024,0x95c40012,0x9f9a005e,0xd2560009}},	//   имує, ليقه, _hääl_, _עשתה_
  { {0xf7eb000a,0xdce30039,0xf992000b,0x764d003a}},	//   _يرجى_, _kanā, _הרי_, stay
  { {0x09cb0037,0x67c50010,0x409a0009,0x764d0060}},	//   िव्य, mėjo, _נברס, ptay
  { {0x67c50010,0xdce3001e,0x443a0010,0xaa040012}},	//   lėjo, _manā, arp_, لِني
  { {0x75280039,0xa5bb0002,0x644a0054,0xe1f80024}},	//   jadz, _dwóc, àfic, вгі_
  { {0xe0550003,0x3f8f001e,0xdb1d0051,0x2127001a}},	//   اختب, _pogu_, fosü, ranh_
  { {0x6d5c0051,0x75231ab6,0xf0620014,0xf7710012}},	//   õran, _senz, скъп, صاب_
  { {0xaab70302,0x69d50070,0x4ab70011,0x3d080011}},	//   _अधिक, koze, _अधिव, ाँचे_
  { {0xc692000b,0x6d450295,0x45851ab7,0xceb40009}},	//   צאי_, ngha, угов, ייפ_
  { {0xa91c0029,0x2d910355,0xfbb70011,0x41df0011}},	//   _voľt, _moze_, _आगाम, _पीएस
  { {0xe72e1154,0x29cd0026,0xf7700003,0x67c50010}},	//   _ће_, hľad_, _وان_, dėjo
  { {0x69c30108,0xff040014,0x2005002c,0xdce1003a}},	//   onne, _тяхн, _huli_, rklı
  { {0x957c003e,0x186a0098,0x75eb003a,0x3aba0009}},	//   gląd, наги_, nüzd, תמשנ
  { {0x6e2d00a2,0x65610017,0x5895002d,0xf1b20009}},	//   esab, melh, ашту, מסך_
  { {0x20050101,0x6d45000e,0xdd1100d9,0x6825003c}},	//   _muli_, egha, výši, рьёз
  { {0x644f000d,0xe57a0345,0x6e2d04b0,0x7b450012}},	// [3fe0] ăciu, нза_, gsab, _ضئيل
  { {0x52b20037,0x67c50010,0xc9660063,0x5ee80009}},	//   ीपीस, bėjo, _свой, דַעְ
  { {0x6441146c,0x7bc20066,0xe3be003a,0x62991ab8}},	//   nuli, tnou, şıma_, eywo
  { {0x1417000a,0x6d450101,0xa22a010c,0x3f9e001e}},	//   اينة_, agha, ежда_, ītus_
  { {0x8bd70009,0x64411ab9,0xdb0f01e3,0x2bb10034}},	//   נונו_, huli, nicá, nący_
  { {0xe8940047,0xb4260003,0x0f1c0037,0x27e01aba}},	//   иаль, _معرو, नर्स_, llin_
  { {0x7bc20066,0xdd3a000d,0x660600ff,0x4ddb0009}},	//   pnou, _lăţi, _hukk, _נחלו
  { {0x7528003e,0x63b90002,0xa91c0029,0x5f940014}},	//   wadz, ciwn, _poľs, риит
  { {0x2bb1003e,0x9b930003,0xcf93000b,0xdd900003}},	//   jący_, _القت, מטה_, قوة_
  { {0xa3b00037,0x442c000e,0x545400ac,0x63a41abb}},	//   टोर_, tsd_, авот, _alin
  { {0xdce3001e,0x244e0107,0x7528084b,0x66060260}},	//   _panā, ným_, radz, _lukk
  { {0x7528047f,0xdc9b0009,0x6ab20011,0x97a50024}},	//   sadz, גיטל, ीपूर, _кріл
  { {0x6b9d0028,0x41b50012,0x75280034,0x25560012}},	//   rksg, لمحر, padz, _منشآ
  { {0x6441007a,0x301b0003,0x99890002,0x244e014a}},	//   buli, فترة_, _stał_, kým_
  { {0xd0840015,0x64411abc,0x62990034,0xddc20159}},	//   быти, culi, zywo, _krož
  { {0x161b0011,0xb4c00011,0x2d8c0248,0x67c50073}},	//   पीकर_, ंपी_, ljde_, rėjo
  { {0xa3c40037,0x93fc000b,0xdb0f0051,0xa9c70012}},	// [3ff0] ्वर_, _אלהי, öjõu, _مزدو
  { {0xd838012e,0xdb1d0002,0x27e01abd,0x2d9e12d4}},	//   šča_, posó, alin_, nkte_
  { {0x2dd8000a,0x2d9e0070,0xfd100003,0xddc2009b}},	//   ابقة_, ikte_, سجل_, _orož
  { {0xae040044,0x501a000b,0xb7671103,0x62990002}},	//   रदान_, _שורו, _стой, tywo
  { {0x3ce10044,0x15f60011,0xceb90030,0x645c1abe}},	//   _करके_, ीदार_, obře_, _epri
  { {0x05870047,0x67c1001e,0x50590048,0xe29600ef}},	//   _сумм, mēji, вшия_, раш_
  { {0xe588000b,0x67c1001e,0xd00e0012,0x2bb10034}},	//   _עָשָ, lēji, ولو_, zący_
  { {0xa295007c,0xe3b00003,0xd8b80003,0x69da1abf}},	//   _кабі, _فرق_, ددها_, _ekte
  { {0x2d9c000f,0x65611ac0,0xcee90048,0x67c10035}},	//   öveg_, telh, ъдие_, nēji
  { {0xdcf80039,0x20050038,0x6f1b0032,0xc9770012}},	//   _novē, _tuli_, sbuc, _حارث
  { {0xe97a000b,0x0bb5000b,0x65611ac1,0x397a0009}},	//   _שנעש, ֹלָם_, relh, _שטענ
  { {0x765d002c,0x6e3b002c,0x64410cb1,0xe29a06e0}},	//   _opsy, prub, ruli, вам_
  { {0x8f9a000b,0x67260028,0x64411ac2,0x7ff40012}},	//   _שיני, _rekj, suli, _اسلا
  { {0x67c1001e,0x66060028,0xd9460001,0x672600b6}},	//   dēji, _rukk, јеви, _sekj
  { {0xa3d50037,0xd7060014,0x3947002a,0xb5fb01bd}},	//   सका_, изви, igns_, _fráz
  { {0x244e0107,0xc7a300de,0x201800b6,0xe73700b5}},	//   vým_, оиск, rpri_, иес_

  { {0xb69b000d,0xa50a0001,0x27f20010,0x8fa302ad}},	// [4000] _sfâr, веза_, rmyn_, цате
  { {0x67f5007a,0x637b004a,0xbc1a002d,0x244e01bd}},	//   _išju, _tänä, віді_, tým_
  { {0x913b000b,0xdd8f0003,0x67260028,0x31570009}},	//   _בעיק, بول_, _tekj, _דיין_
  { {0xa3b00044,0x244e0042,0x6d5c0064,0x7bc60097}},	//   टों_, rým_, ôraz, nnku
  { {0x98a3001e,0x67c1001e,0xddc90027,0xd7bb0009}},	//   majā_, cēji, zveš, _יצטר
  { {0xfe080020,0x77640054,0x98a3001e,0xd8760012}},	//   _nữa_, leix, lajā_, لاعب
  { {0x6e220002,0x8d5b0009,0x71090024,0x4c980009}},	//   _swob, _שכלי, ухів_, _גֹּא
  { {0x9c17000b,0x77640054,0xc7c60001,0x98a3001e}},	//   _כחלק_, neix, јски, najā_
  { {0xfaa30046,0x61460046,0xd6d00003,0xe8950002}},	//   _дато, _веза, ثقة_, gółó
  { {0xd657000b,0x5e57000b,0xf6530009,0xc6f7003c}},	//   סיית_, סייע_, קצת_, шных_
  { {0xddcd007d,0x03f90001,0x67c1001e,0x98a3001e}},	//   lvaţ, лној_, zēji, kajā_
  { {0x9ffa0003,0x06560003,0xa3cc0037,0x9cd70009}},	//   _شراء_, _ننصح, रकट_, שוטה_
  { {0x77640054,0xe7b30012,0x6fb30012,0x5fb30012}},	//   deix, _بمند, _بمنا, _بمنط
  { {0xc1050003,0x6b5c0058,0x67c1001e,0x1cba0003}},	//   صوري, _pågæ, vēji, _لاعب_
  { {0xada30001,0xd57b000b,0x44441ac3,0x7ae600b0}},	//   _фајл, _שָׂר, ju_, _øktf
  { {0x34fb000b,0x77640054,0x67c1001e,0x98a3001e}},	//   _בהוד, geix, tēji, gajā_
  { {0x44441ac4,0x8ed80012,0xdc0f0030,0x929d0034}},	// [4010] eu_, لذكر_, _věčn, _ogła
  { {0x4431007a,0x67c1001e,0x6d481ac5,0x7ae90034}},	//   _pvz_, rēji, ngda, _rzet
  { {0x629d004a,0x98a3001e,0x7ddd0054,0xad1b0009}},	//   lyso, bajā_, mèst, דובר
  { {0x67c10039,0x7ddd0054,0x69c7009b,0xe3b00003}},	//   pēji, lèst, lnje, ورن_
  { {0x443e008b,0x7b740003,0x4df60011,0x23760012}},	//   hrt_, تطلا, ँगाई_, صمود_
  { {0xdca60003,0x672d004a,0xe9d8002d,0x69d80008}},	//   _فى_, laaj, акі_, gove
  { {0x01380093,0x99990010,0x44441ac6,0x11380009}},	//   ברות_, _ūsų_, cu_, שָׂר_
  { {0x1bd4002d,0xc7b20009,0xaf98003c,0xfe080081}},	//   _дося, ּ֑ה_, итых_, _sữa_
  { {0x69c7009b,0x7ae90027,0xdb0e000e,0x443e1ac7}},	//   knje, _uzet, ókís, ert_
  { {0x3f9f004a,0x69d81ac8,0x31580012,0x21580012}},	//   skuu_, cove, _نجمة_, _نجمع_
  { {0x672d0051,0x69c70133,0x3ead000e,0x64450a60}},	//   kaaj, dnje, szet_, nuhi
  { {0x929d0002,0x6d48002c,0x672d0269,0x63bd016d}},	//   _zgła, agda, jaaj, gisn
  { {0x98a3001e,0x68e10058,0x443e1ac9,0xed5903b0}},	//   vajā_, _hyld, art_, _бол_
  { {0x44440225,0x6445019a,0xcad60009,0x3d210011}},	//   yu_, kuhi, מורת_, यरों_
  { {0x3ce6015f,0x68e90013,0x776403eb,0x98a3001e}},	//   _करें_, ředn, teix, tajā_
  { {0x64450101,0xa3ac0037,0x2a6d009b,0x24510042}},	//   duhi, _गति_, _oseb_, mám_
  { {0x776403eb,0x444411f7,0x98a3001e,0x82360012}},	// [4020] reix, wu_, rajā_, _اربا
  { {0x67c100cd,0xdb06005e,0x7ae9005e,0x44441aca}},	//   mēju, hikü, üete, tu_
  { {0x64450101,0x67c1001e,0x01fb000b,0xdd8f0003}},	//   guhi, lēju, _תפיל, عوم_
  { {0x7f860012,0x7f190024,0xf7860012,0x24510081}},	//   _الحن, _віру_, _الحَ, iám_
  { {0x19940014,0xdb59002d,0x91e60867,0xdb061acb}},	//   жаля, рює_, боде, likó
  { {0xa8980001,0xddcd000d,0x443e081f,0x44441acc}},	//   иклу_, rvaţ, yrt_, pu_
  { {0x24770020,0x443e0020,0xdb06003e,0xdce7001e}},	//   _năm_, _ít_, nikó, _tajā
  { {0x69c7009b,0xa614004d,0x501b0009,0x987b0009}},	//   znje, омич, נופו, ראקט
  { {0xf773000b,0x539b0009,0xa3d50011,0x69d81acd}},	//   לקה_, _עימו, सकर_, pove
  { {0xddc40039,0x68e103ee,0x7afd0042,0x24510030}},	//   stiņ, _fyld, _ústa, fám_
  { {0xb7fa0037,0xe9df0029,0x68e1038e,0xcb040037}},	//   ्दाम_, ktúr_, _gyld, रखंड_
  { {0x9f400061,0x629d004a,0x2578000e,0x443e031d}},	//   blié_, tyso, dülő_, rrt_
  { {0x63bd077d,0xddc20039,0x5187007c,0x3209001a}},	//   risn, _esoš, бува, _quay_
  { {0x67c50010,0x443e0811,0x6b841224,0x6df40012}},	//   mėji, prt_, _enig, _بكتا
  { {0x68110039,0x67c5007a,0x58840015,0x29110002}},	//   _kāda, lėji, пыта, rcza_
  { {0x02a7007c,0x6811001e,0x68e90066,0x69c704d2}},	//   _гром, _jāda, ředo, snje
  { {0xdb0d003a,0x67c50010,0x877b0009,0x672d029c}},	// [4030] _amaç, nėji, נאמי, raaj
  { {0xdcfc0039,0x672d00ff,0xec090081,0x69c00031}},	//   _norē, saaj, _mến_, émet
  { {0x70550003,0x93190003,0xa9880009,0x8d5b0009}},	//   _بنجا, لقاء_, _הָרִ, רכבי
  { {0x67c5007a,0x6008000b,0x8f470015,0xe1ff0002}},	//   kėji, _לִשְ, _уход, zwól_
  { {0xc334000b,0x2451000e,0xeb900003,0x6445002c}},	//   פוס_, zám_, عظم_, suhi
  { {0x9f42004a,0x67c50010,0xf2d00012,0x7bd90034}},	//   _ehkä_, dėji, رآن_, sowu
  { {0x299c000b,0x01380009,0x999c0009,0xa99c0009}},	//   רסומ, זרות_, רבוט, רבור
  { {0xd7090015,0x24510042,0xee3913e3,0x53a50012}},	//   шние_, vám_, ани_, _بمرك
  { {0x05a9002d,0xbebb0070,0x68e1000e,0xef120009}},	//   ивий_, _beëi, üldj, וּת_
  { {0xdcf50039,0x67c1001e,0x245100d9,0x7bdf0032}},	//   _nozī, vēju, tám_, _akqu
  { {0xa0c40003,0x9166001a,0x84580048,0xdbca0024}},	//   _فيكو, _lộ_, брят_, игод_
  { {0x67c5007a,0x06fb0037,0xf989000b,0x67c1001e}},	//   bėji, ्शाव_, _בר_, tēju
  { {0x6b600028,0x7aed0002,0x7fe80024,0x6ee70012}},	//   _hágæ, _czat, _уєфа_, _اسال
  { {0xd3780656,0x63a91ace,0x3ea20033,0x67c1001e}},	//   ść_, _llen, økte_, rēju
  { {0x67c1001e,0x929d0002,0x63a90269,0xa06a0294}},	//   sēju, _ogło, _olen, шава_
  { {0x91660020,0xa2d501e1,0x9f46001a,0x1fa70686}},	//   _bộ_, _युक्, _khoá_, окси_
  { {0x672b0272,0xe61705cc,0xcd360012,0x63a20615}},	// [4040] _megj, жду_, قراب, vkon
  { {0xa3c40037,0xba9b000b,0x672b000e,0x0446002d}},	//   ्वक_, _כספי, _legj, жежн
  { {0x05770003,0x6603087b,0x2002003d,0x31670032}},	//   تملة_, _mink, _tiki_, denz_
  { {0x64411acf,0xddce0034,0x69dc18b4,0x14170012}},	//   irli, ódłe, lore, زيهة_
  { {0xadeb0037,0x64410052,0xb5fb000e,0x6a130012}},	//   _जीवन_, hrli, _csás, وبور
  { {0x44270036,0x63a90d20,0x71f70012,0x31670032}},	//   _own_, _elen, يروس_, genz_
  { {0xf993000b,0xbfaa085b,0x99390109,0xf8bc0011}},	//   ורג_, итие_, сячу_, ोपिय
  { {0xdfd0000a,0x2d980029,0x02460003,0xaa46002d}},	//   عية_, _hore_, _وَأَ, _мебл
  { {0x7656004a,0x69dc1ad0,0x64411ad1,0x2d981448}},	//   ntyy, kore, erli, _kore_
  { {0x929d003e,0x161f0037,0xa2d50037,0x98a30002}},	//   _zgło, मीटर_, _युग्, lają_
  { {0xdb1d0108,0x2d980c97,0x7d7b000b,0x69dc0583}},	//   lisé, _more_, בניו, dore
  { {0x67c50010,0x660305df,0x78790009,0x54570009}},	//   pėji, _eink, _לָנו, חסטן_
  { {0x2bdb0037,0xdcf5001e,0xc7f7000b,0xdb1d0061}},	//   यकता, _pozī, _וזאת_, nisé
  { {0xbf9b0017,0xa1840015,0xad660012,0xf5770012}},	//   _ciên, мысл, _ذاته, _ومنع_
  { {0x84380003,0x98a30002,0x0ffb0012,0x142a0024}},	//   _اكبر_, kają_, لعرب_, _тіло_
  { {0x64481ad2,0x31670052,0xd7740003,0x96150024}},	//   mudi, zenz_, واقع, змаї
  { {0x1ab400e3,0xdce70002,0x98a30002,0x9a590003}},	// [4050] _объя, _mają, dają_, _الخط_
  { {0x69dc007d,0xe1ff0002,0x80d60011,0xbf9b0081}},	//   core, zwój_, _मुके, _giên
  { {0x200c00eb,0x59d40012,0x33190024,0xbc680012}},	//   _nudi_, _تغير, біля_, يمكن_
  { {0x98a30002,0xa088000b,0xe51b0011,0xb51b0011}},	//   gają_, _וְשִ, _प्रि_, _प्रय_
  { {0xa294002d,0xc5f8001e,0x672b0033,0x7e7d1ad3}},	//   маці, kmē_, _regj, _ursp
  { {0x672b0028,0x4efa000b,0x200c051f,0x2d981ad4}},	//   _segj, _להרו, _budi_, _gore_
  { {0x6603007a,0x31670052,0x68e1000e,0x98ba0060}},	//   _rink, renz_, üldh, _yapı_
  { {0x69dc01ae,0xc4d20009,0x98a30034,0x31670032}},	//   zore, _נגן_, cają_, senz_
  { {0x69dc0164,0x7bdd000e,0x16620015,0xdd910012}},	//   yore, dosu, евым, فوظ_
  { {0xc05b00bc,0x41b50012,0x67c50073,0x0d960009}},	//   _від_, _عمار, mėju, ִ֛ים_
  { {0xbf9b0020,0x67c50010,0x64410227,0x7ae4008e}},	//   _riên, lėju, urli, _syit
  { {0x64410052,0x7bdd1726,0xa0c40012,0xd8740012}},	//   rrli, gosu, _تيمو, _زامب
  { {0x6603039c,0x28df0037,0x68110035,0xd2990024}},	//   _tink, _पुति, _kādo, отрі_
  { {0x6d1b0037,0xdce70002,0xf9870003,0x7c650003}},	//   _प्लग_, _zają, رب_, _فاعل
  { {0x7e7b0065,0x69dc0164,0x2d871ad5,0x03a61ad6}},	//   lvup, rore, _inne_, _нико
  { {0x4c3a000b,0xf43a000b,0xc43a000b,0x7656004a}},	//   _התקב, _התקש, _התקי, ttyy
  { {0xa3d90011,0x69dc1ad7,0x023a0012,0x2d981ad8}},	// [4060] ़कर_, pore, _اثبت_, _pore_
  { {0x7abb000b,0xb2bb000b,0x3f8f0028,0x7a7b000b}},	//   _לצפו, _למפר, ögur_, _פריס
  { {0x299b000b,0x999b000b,0x1d19002d,0x319b000b}},	//   _הסימ, _הביט, юють_, _הבינ
  { {0xb6a30020,0x2d980132,0xdb1d0d05,0xdc3b06dd}},	//   _khẩ, _wore_, tisé, _náče
  { {0x5213002d,0x98a30002,0x93bd004b,0xf2da0012}},	//   едіт, rają_, spăg, حظات_
  { {0xdb1d0061,0x98a30073,0xc2130009,0x7bcb1ad9}},	//   risé, sają_, עהו_, angu
  { {0xb4ea0037,0x68ed0066,0xf9570009,0xcfb60009}},	//   _मरे_, řadn, פסקת_, ּלִי_
  { {0xcc57000b,0x6c570009,0xf4570009,0xa8570009}},	//   _מבלי_, _מילא_, _מילר_, ליצה_
  { {0xe7310009,0xb7130012,0x1f130012,0x7bdd001b}},	//   כֵי_, ربيش, ربيج, vosu
  { {0x200c012e,0xb21b0065,0x64430039,0xa1c3002d}},	//   _tudi_, lvæg, šnie, _збуд
  { {0xe3b9003a,0xd91b000b,0x7bdd19a3,0x65570009}},	//   msız_, _הובל, tosu, הביא_
  { {0xb4cc0037,0x68e90066,0x9202001e,0x2d871ada}},	//   _रखी_, ředk, žāda, _enne_
  { {0x753c003e,0x4444008b,0x2f97000b,0xb6a3001a}},	//   _odrz, hr_, _מכאן_, _chẩ
  { {0xddcd0002,0xe3b9003a,0xe6c50012,0x45f80012}},	//   ztał, nsız_, _تتمي, _بفتح_
  { {0xf55b000b,0x155b0009,0xddcd0034,0x98a7004b}},	//   _הדומ, _הכוב, ytał, mană_
  { {0x9473000a,0x5f9407ae,0x3ce00011,0x501b0009}},	//   _أدوا, нист, _कड़े_, מולו
  { {0x63ad0891,0x3bbc000b,0xdcfc0010,0xbb3c0009}},	// [4070] _ilan, _למהד, _korė, _התחז
  { {0xb606001e,0x799a03c0,0x67c50010,0x0dbb0012}},	//   jošā, _notw, vėju, حارث_
  { {0x63ad00bd,0x515a000b,0xf992000b,0x200c0030}},	//   _klan, _וכתו, _סרט_, ídit_
  { {0x7bc20a5f,0x32050064,0x18360009,0x7bcb1adb}},	//   giou, _sily_, _קארל_, ungu
  { {0xd25b002d,0xdce1001e,0x0f7a0009,0x877a0009}},	//   сце_, ielā, _וארב, _וארי
  { {0xddcd003e,0xdcfc007a,0xfa780093,0x22a3001e}},	//   stał, _norė, פעות_, _rīkā_
  { {0x63ad1adc,0x7bc20132,0xa4d40024,0x2901005e}},	//   _olan, biou, _зорі, äha_
  { {0x7bc2002a,0x27e918eb,0xe6191add,0x0ea90198}},	//   ciou, nlan_, оди_, жкий_
  { {0xc2c40003,0x66070070,0x9e650024,0x68110035}},	//   _كيفي, _kijk, євод, _tādo
  { {0x63ad039f,0xd838009b,0x67241ade,0x27e90385}},	//   _alan, šči_, zbij, hlan_
  { {0x69c31adf,0x67650012,0x673d001b,0xbb460511}},	//   mine, _يُطل, _odsj, менк
  { {0x547a0093,0xb6a30020,0x66070070,0x21e40052}},	//   קטרו, _phẩ, _lijk, höht_
  { {0xeb97085b,0x8db5002d,0xc7b20009,0x98a7004b}},	//   фия_, _оскі, _בבא_, bană_
  { {0xdcee0039,0x2ca90066,0x63ad1ae0,0x4efa01b0}},	//   _labā, _řadu_, _elan, _והנו
  { {0x11d70003,0x661d1ae1,0x37e60024,0x28b00011}},	//   ذوفة_, _atsk, довг, जनयि
  { {0xa3e60044,0x7bc20132,0x69c31ae2,0x660f1ae3}},	//   _बीच_, xiou, hine, _buck
  { {0x7bc20036,0x6e360010,0x67241ae4,0xcb8b0009}},	// [4080] viou, usyb, rbij, _וְיֹ
  { {0x272c0020,0x27e900c6,0xad660012,0xddc90035}},	//   ến_, alan_, باره, steņ
  { {0xbc6a000a,0x7bc2002a,0x44441ae5,0x6b9b03b5}},	//   تمان_, tiou, ur_, _boug
  { {0x69c31ae6,0x6b9b1ae7,0x96ba076b,0x799a020d}},	//   eine, _coug, _дугу_, _sotw
  { {0x799a003e,0x7bc20036,0xb0c30037,0xb606001e}},	//   _potw, riou, _वेबग, tošā
  { {0x6b89009b,0x27e0004a,0x64430164,0x69c31ae8}},	//   _eneg, loin_, ánic, gine
  { {0xa9670001,0xaf390028,0xb4cc0037,0xe3b9003a}},	//   фија_, _óþæg, _रखे_, rsız_
  { {0x17f70003,0x9cd70009,0x27e0008e,0x66070227}},	//   ورية_, _חולה_, noin_, _zijk
  { {0x23890066,0x056a004c,0x98a7004b,0x8d6a004c}},	//   šují_, ојни_, tană_, ојна_
  { {0xc9860003,0x69ce0070,0x68e90066,0x63ad1ae9}},	//   _تشري, jnbe, ředi, _slan
  { {0x44380065,0x9f400028,0x6b9b0025,0x98a7004b}},	//   ér_, ymið_, _youg, rană_
  { {0xe3b9003a,0xb8650012,0x04650009,0x6f770012}},	//   apın_, _سامو, ׂיתָ_, _يملأ_
  { {0xc17b0024,0x6ffb0009,0x57fb0009,0xd7fb0009}},	//   оїв_, _והאפ, _ולאו, _והאל
  { {0xa4d4007c,0xddc90066,0x224b0e22,0x661d0030}},	//   _полі, kteř, ruck_, íske
  { {0xcf9b0046,0x27e9000e,0x66070070,0xc0580024}},	//   оја_, tlan_, _rijk, міт_
  { {0x63ad00b6,0x27e900b6,0xc43b0009,0x9e090012}},	//   _ulan, ulan_, _ותהי, كيرك_
  { {0x9f400028,0x6b9b0440,0x24581aea,0x69c3008e}},	// [4090] rmið_, _roug, lém_, yine
  { {0xd657000b,0xdce70002,0x6b9b002a,0x34ab0003}},	//   וימת_, _zaję, _soug, يداً_
  { {0x645a0006,0x24580013,0x2d9c002a,0x24f4000b}},	//   ntti, ném_, _move_, תֶּם_
  { {0x60fa000b,0xce950014,0x645a0855,0x2d9c1aeb}},	//   _מהתק, _замъ, itti, _love_
  { {0xdb061310,0x201e00c1,0x661d079d,0x471a0009}},	//   sikö, _atti_, _utsk, _מורג
  { {0x018b0015,0x24580066,0x2d9c1aec,0x3875004c}},	//   ющей_, kém_, _nove_, ећит
  { {0xc0e20001,0x98be003a,0x853c0010,0x6474003c}},	//   лошк, _batı_, rkėl, _игру
  { {0xd00e0012,0x68150034,0xddcd0034,0x225b0012}},	//   حلي_, _lądo, stań, _وجذب_
  { {0x201e003a,0x68e80028,0x98a70002,0x645a1aed}},	//   _etti_, _eydd, daną_, etti
  { {0xa5bb0031,0x201c0031,0x7bcf016d,0x2fcd016d}},	//   _utód, _évig_, encu, sneg_
  { {0x2d9c15f2,0x853c0010,0x6ac80011,0xa3ea0148}},	//   _dove_, okėj, रप्र, здна_
  { {0xe3b20003,0x7f840003,0x61e500b6,0x7ae9008e}},	//   ارد_, _للمن, _akhl, _kyet
  { {0x645a1aee,0xda0f0037,0x27e0004a,0x6d550034}},	//   atti, ादित_, voin_, _ocza
  { {0xe9df0028,0xed560024,0xfe9a0009,0x765b0097}},	//   trúa_, _зош_, _מינמ, mtuy
  { {0xe3b2000a,0x7d760012,0x24580018,0x27e0008e}},	//   _مرة_, _سمير_, cém_, toin_
  { {0x201e0039,0xafe30469,0x2d9c001b,0xd706004c}},	//   īti_, госл, _zove_, езби
  { {0x201e0cac,0x464a0593,0x36670103,0x0d860048}},	// [40a0] ūti_, язан_, нато_, нлан
  { {0xe1f20003,0x27e00061,0x7bc61aef,0x7c660012}},	//   _حسب_, soin_, liku, فاصل
  { {0x28df0044,0x75d30003,0x68e1000e,0x0b4604ac}},	//   _पुलि, ديلا, üldt, енен
  { {0x6d55003a,0x7bc61af0,0x501b0009,0x64430031}},	//   _ecza, niku, _מוטו, ánia
  { {0x41e6002d,0x5bc50003,0x5b13002d,0x599a0009}},	//   ніка, ختلف, уміт, ּשֶׁ
  { {0xd838009b,0x7bc60574,0x63af0035,0xdb1d1af1}},	//   šču_, hiku, ībni, visí
  { {0x232a0e0f,0xc9530009,0x68e90030,0xab2a16a7}},	//   _нови_, אמו_, ředv, _нова_
  { {0x24580013,0x8626002d,0xf093000b,0xa8570009}},	//   vém_, ньое, רנה_, גיקה_
  { {0x2d9c009b,0x67c80030,0xdce50035,0x3d940024}},	//   _pove_, dějt, mehā, випр
  { {0x98a70002,0x2ca50058,0x9a3b000b,0xb6bb0009}},	//   waną_, fyld_, _מתמק, פציי
  { {0xa4d4002d,0x4f260024,0xaf0a0012,0x98a70034}},	//   тоні, _здеб, _فقام_, taną_
  { {0x68150002,0x645a1af2,0x7bcf00b6,0x24581af3}},	//   _sądo, rtti, uncu, rém_
  { {0x69da0066,0x62841af4,0xb5fb0097,0x75f00064}},	//   čten, _crio, _spám, väzn
  { {0x04940003,0x5e77000b,0x65780033,0x22440042}},	//   _للتح, _נתון_, _uavh, ámka_
  { {0xbd17000b,0x33990012,0x4d7b0009,0x28db0011}},	//   _אחוז_, _ينتج_, _זרוע, _मुखि
  { {0x17f80003,0xddc40060,0x7c3a1af5,0xfca900ae}},	//   فرقة_, ttiş, mstr, _تاهو_
  { {0xe6130003,0xa3de0011,0x65a00032,0x78a10248}},	// [40b0] اشر_, तकर_, _röhr, älvb
  { {0xa1150012,0x98b00011,0x201e01a0,0x64481af6}},	//   _جودت, जनाए, ític_, ordi
  { {0x69c7001c,0xdb1d0017,0x7c670003,0x9f5a0054}},	//   mije, cisã, عائل, _cupó_
  { {0x69c71af7,0x64480060,0xacf40012,0x8c1b0009}},	//   lije, irdi, اسكت, פודי
  { {0xfe080020,0xbf36000b,0x7d24000e,0x853c0010}},	//   _hữu_, _בארץ_, ítsé, rkėj
  { {0x89a8002d,0x69c71ade,0x7bc61af8,0xc27c0009}},	//   нків_, nije, ziku, פרוי
  { {0x68110035,0xa3e10011,0xa8cc0009,0xab5b005e}},	//   _kādi, थवा_, ּ֖וֹ, tiül
  { {0xa5bb000e,0xf1a4002d,0x53140012,0x765b0060}},	//   _utób, _ґрун, _مذكر, ttuy
  { {0x7bc60554,0x200b000d,0xba550001,0xf1e10011}},	//   viku, _mici_, _швај, पकान
  { {0x0d820625,0x3ce60037,0xaea80003,0xb5fb0064}},	//   альн, _जुडे_, عطيل_, _spáj
  { {0x69c70604,0x7bc61af9,0xe5720009,0x319a0009}},	//   dije, tiku, בַר_, _קבענ
  { {0x200b007d,0xdb1d0149,0xe72e0001,0x680a0034}},	//   _nici_, visã, _ње_, _wędr
  { {0x7c3a01b3,0xe2970047,0xc332000b,0x7bc61afa}},	//   astr, вая_, סוך_, riku
  { {0x7c3a0026,0x200b007d,0x0ea8002d,0x6f1d0070}},	//   bstr, _aici_, _якій_, _afsc
  { {0xddd60042,0x7d560009,0x200b001b,0xc0e60511}},	//   jvyš, _ייסד_, _bici_, товк
  { {0x9f4f0028,0x6a860048,0xca4a0012,0x6f1b016d}},	//   ögð_, _алиа, _قلبه_, ncuc
  { {0x64430065,0x69c70027,0x27ed1afb,0x93fb0009}},	// [40c0] ánin, bije, ilen_, _קלפי
  { {0x27ed008b,0x75d30003,0x69c70027,0xa2f70009}},	//   hlen_, ليقا, cije, _במפה_
  { {0x07fa0003,0x443c000e,0xb5a90012,0xed5706bd}},	//   _يرجع_, év_, راكك_, тох_
  { {0xe627001a,0xfba90024,0xac450012,0x4c9a0009}},	//   _phố_, нтій_, ائله, ובעו
  { {0xda770048,0xdce80064,0xba730012,0x68e90030}},	//   вящ_, vedč, لاوت, ředt
  { {0x4153002d,0xdb0b0028,0x28f80021,0x201a0017}},	//   ивіс, rigð, нель_, ípio_
  { {0x2eca0037,0xddc90002,0x5f190011,0x25d70009}},	//   ाप्त, steś, युक्_, _סולן_
  { {0x27ed0006,0x7649003a,0x245c05b1,0xcc770009}},	//   glen_, frey, mím_, _בעלה_
  { {0xb8e90044,0x6e3b0101,0xda650003,0x245c00d9}},	//   _ले_, gsub, _مالي, lím_
  { {0x6448012e,0x6b8d0027,0x27ff00b6,0x05780012}},	//   trdi, _snag, amun_, رمجة_
  { {0x69c7001c,0xad37000b,0x245c00f1,0x62820070}},	//   vije, כניס_, ním_, lvoo
  { {0x76490028,0xa3d50037,0xa73a0012,0x5ba7091c}},	//   brey, िचय_, _آثار_, троз
  { {0xec0a008a,0x7af60002,0x3c380066,0x6811001e}},	//   _nếu_, _czyt, _bývá_, _rādi
  { {0x6e2d003a,0x7c3a1afc,0xe6c50012,0xe5340024}},	//   _çaba, pstr, _حتمي, _секь
  { {0x69c71afd,0x245c0042,0x2d0e0011,0x99990064}},	//   rije, jím_, सशील_, _ísť_
  { {0x245c01bd,0xc355004c,0x645d004b,0xdb0f0420}},	//   dím_, _скиј, ăsit, ricó
  { {0x628200bd,0xfe70000a,0x291e0163,0x61fa0051}},	// [40d0] jvoo, يدك_, _ofta_, _ohtl
  { {0x68ed0066,0x865b000b,0x8d790012,0xdc420030}},	//   řadi, ודמי, عماء_, _léče
  { {0x7cf80009,0x61e3008e,0x68110035,0xddc20064}},	//   תִּק, vonl, _tādi, _osož
  { {0x68e90066,0x9b440012,0x6e220060,0xe4ab0009}},	//   ředs, لنمو, _otob, וֹדָ
  { {0x61e3003a,0xeab00003,0x27ed09bc,0x63a01afe}},	//   tonl, يعه_, vlen_, _domn
  { {0xec0a0020,0x48790014,0x99d70003,0x27ed0518}},	//   _hết_, есия_, ختصا, wlen_
  { {0xec0a008a,0x27ed1aff,0x245c1b00,0xc19c0009}},	//   _kết_, tlen_, cím_, ושגי
  { {0xec0a001a,0x7ff50003,0x61e31b01,0xd0f80009}},	//   _yếu_, دستا, sonl, כמות_
  { {0x7aed00b6,0x61ee006f,0x3171000e,0x3ea90054}},	//   _nyat, ylbl, kezz_, nyat_
  { {0x59b70044,0x27ed1b02,0x6e3b00ed,0xdb0d0025}},	//   _अतिर, slen_, rsub, _plaî
  { {0x753500c1,0xa87b0012,0x58d409e8,0x76490097}},	//   _mezz, _تحذر_, _кофт, srey
  { {0xc209015a,0x3ea900c6,0xddcd0604,0xccf20009}},	//   _זה_, kyat_, jvaž, מכי_
  { {0x245c0066,0x59b70011,0xbb760009,0x8bd60009}},	//   zím_, _अतार, נעשו_, רורו_
  { {0x99d60003,0xddcd0027,0x9d550012,0xbd450012}},	//   اتحا, evaž, _صنعت, _صنبي
  { {0xa3e30037,0x4dda000b,0xf7460021,0xc0aa0012}},	//   नका_, _אחסו, лево, راسل_
  { {0x245c0145,0x645c0054,0x44f30081,0xe5070011}},	//   vím_, àrie, _ị_, _वृधि_
  { {0x657c004a,0xdfcf0003,0x05660345,0xfd120012}},	// [40e0] _parh, سيك_, лван, مجا_
  { {0x245c0107,0xb956004c,0xed57019c,0x63a01b03}},	//   tím_, _стић, лоу_, _somn
  { {0xacf60001,0x6811001e,0x63a01b04,0xbc190024}},	//   учај, _kādu, _pomn, вічі_
  { {0x65ad0029,0x245c0029,0x62820070,0xb09b0009}},	//   _súhl, rím_, tvoo, _ניכר
  { {0x245c0652,0xa294002d,0x6d430002,0xdce8001e}},	//   sím_, ралі, _odna, iedā
  { {0x628200bd,0x91e30015,0x70540012,0xd12f0012}},	//   rvoo, боче, لنتا, كمه_
  { {0x5478000b,0x4478000b,0xc953000b,0xa5bb0002}},	//   _בְּנ, _בְּא, צמה_, _twór
  { {0xf8b3000b,0x8b660012,0xf76f0012,0xab5b005e}},	//   משו_, _حاسم, كاً_, riük
  { {0xd0070001,0xd6d00012,0x5e430012,0x36d40790}},	//   ћење_, تقة_, مَيْ, ропр
  { {0xd5b3000b,0xa5f80001,0x3f8f0028,0xba0a0012}},	//   ֶׁר_, ђену_, _engu_, _أترك_
  { {0xd7ef002d,0x0d970009,0x2ed10011,0xbdf70012}},	//   _гу_, אכים_, _सख्त, دريا_
  { {0x6d4e000e,0xdb000018,0x7c3e1b05,0x9cd700af}},	//   óbab, _romê, ispr, רוטה_
  { {0xdcf50039,0x65940103,0x7ac70148,0x7c3e0032}},	//   _mazā, _валу, усне, hspr
  { {0x76570009,0x2d9a005e,0xdee3004c,0x1e570009}},	//   _עבוד_, _õpe_, _уочи, _עשור_
  { {0x1048002d,0x98480014,0xa8350001,0xd48f1b06}},	//   ляти_, лята_, ребљ, _ур_
  { {0x6d4a0028,0x36d5004c,0x443e1b07,0x753a0032}},	//   ófan, аобр, mst_, latz
  { {0x69ca000e,0x753500c1,0xa535004c,0x260d001b}},	// [40f0] kife, _pezz, инач, _džon_
  { {0x67010011,0xdd910012,0x99990073,0x69c50032}},	//   लेषक_, غوا_, rusų_, _umhe
  { {0xab5b0051,0xec0a001a,0x998d0060,0x69ca0e30}},	//   tiüh, _tết_, _ateş_, dife
  { {0xa09a000b,0xf1ed0011,0x753a0032,0x443e1b08}},	//   _סירט, _चीज़_, hatz, ist_
  { {0x443e0052,0xab5b0051,0x7f3a0009,0xc73a0009}},	//   hst_, riüh, _שעשו, _שתשת
  { {0x69d50052,0x80ca0037,0x644a060e,0x216902c4}},	//   nnze, _हेडे, áfic, тики_
  { {0x443e15e2,0x1128002d,0xf77f003a,0xdb1d0028}},	//   jst_, уючи_, _kaç_, nnsó
  { {0xf7710003,0x07a50686,0x443e1b09,0xaa7d008e}},	//   زاب_, раин, dst_, _käää_
  { {0xee360047,0xdcf8009b,0x443e1b0a,0x9f5e000e}},	//   аны_, _davč, est_, _autó_
  { {0x2733008a,0x443e1b0b,0xc692000b,0x27e00133}},	//   ản_, fst_, קאי_, čina_
  { {0x72040003,0xab2a0c1e,0x443e1b0c,0x98170012}},	//   _اولم, кона_, gst_, _إبطا
  { {0xbef50044,0x889a000b,0x2d98006f,0xe0d00012}},	//   _आरंभ_, _בבעי, örer_, _عزل_
  { {0x2d9100bd,0x539a000b,0xf1bf0030,0x443e1770}},	//   _onze_, דירו, rpán_, ast_
  { {0x673b0010,0x76ba000b,0xdb000054,0x66ba0009}},	//   lauj, _שמספ, _domè, _במנה
  { {0xac160046,0x475a0014,0x6811001e,0x64430027}},	//   _коју_, края_, _tādu, šnij
  { {0x673b007a,0xc7a60015,0x70530003,0xe8530012}},	//   nauj, шибк, تنفا, تنفد
  { {0xd0071b0d,0x68e90066,0x7bcb0d86,0x5e250012}},	// [4100] рете_, ředp, digu, معلق
  { {0xf815001a,0x7c3e1b0e,0x78800066,0x9d46004d}},	//   _ước_, tspr, nává, режд
  { {0x98a70066,0x764d003a,0xe45a0024,0x8c7a0048}},	//   raně_, aray, тже_, ъщат_
  { {0x1a2a002d,0x317e0052,0x82a6010c,0x9cd60009}},	//   вжди_, _satz_, ишле, בועה_
  { {0x63a40108,0x673b007a,0x02060015,0x98a70066}},	//   _moin, dauj, аздн, paně_
  { {0x3eaf0058,0x443e1b0f,0x27f21b10,0x63a40d29}},	//   øgte_, yst_, llyn_, _loin
  { {0x7b96007c,0x78800013,0x8c43106a,0xb9c30003}},	//   _краї, dává, _мере, تقوي
  { {0x9634007c,0x22490027,0x2ca71ad3,0xe78602e3}},	//   бниц, šaka_, ände_, руко
  { {0xa3e30037,0xbda60012,0x200f03bd,0xd6d90034}},	//   नकर_, لحدو, _digi_, ogły_
  { {0xdb0003eb,0x443e0070,0x200f0028,0x6b82000e}},	//   _nomé, tst_, _eigi_, ldog
  { {0xe7fb0011,0x91bb0009,0x19b901c6,0x443e1b11}},	//   ्षमा_, _שמבי, _суть_, ust_
  { {0x753a0052,0x0077000b,0xdb240028,0x200f1b12}},	//   satz, _כתבי_, örðu, _gigi_
  { {0x443e10cc,0x63a412c5,0xc6760012,0xc1a7004c}},	//   sst_, _doin, _خطاب, ајви
  { {0x394d0052,0xdb000576,0x443e074f,0x261a0011}},	//   ßes_, _comé, pst_, _बढ़ी_
  { {0xd5fb000b,0xe5e50003,0x45fb000b,0xdb001b13}},	//   _שפור, _اثني, _שהוג, _domé
  { {0x63a4002a,0x1cb7000b,0x98b1000d,0x649b000b}},	//   _goin, _כלול_, ează_, _יסוד
  { {0x60150010,0x16380012,0x764d0060,0xec0a0081}},	// [4110] _išme, لسلة_, uray, _iếp_
  { {0x71750003,0xdb1d004a,0x3ebb0009,0x71790337}},	//   _اهدا, sisä, דצמב, _сбор_
  { {0x2ca7007d,0x89da000b,0x5b370003,0xfb150003}},	//   ând_, _תחתי, لعشر, مواج
  { {0x6f950003,0x6d5c0fd0,0x77b80840,0x644a0031}},	//   _الحض, _ecra, _píxe, áfia
  { {0xb21b0065,0x59bb0037,0x60db003a,0x673b0010}},	//   kvæm, _उतार, ğumu, vauj
  { {0x7bcb1b14,0x90450012,0x39e80024,0x4e160009}},	//   sigu, منته, адіо_, _לחשב_
  { {0xa4d4002d,0xc9b8000b,0x78800066,0x673b098f}},	//   _дорі, שהות_, vává, tauj
  { {0x63ad0005,0xd8d8000b,0xe8d80009,0xc0c80024}},	//   öand, יווט_, יוור_, шуче_
  { {0xddc2009b,0x673b0cac,0xfe710012,0x78800030}},	//   _spoš, rauj, سدة_, tává
  { {0xb5790021,0x63a40e67,0xaab40012,0x6b800034}},	//   ущих_, _soin, _بصفت, _zamg
  { {0x63a41b15,0x2bc40011,0xb50a0011,0x78800030}},	//   _poin, लोवा, _हृदय_, rává
  { {0x645c0054,0xf1a90009,0xdc880009,0xb5fb0030}},	//   ària, _אס_, בְשָ, _zpát
  { {0x63a408d4,0xfe700012,0x79810034,0x6d471b16}},	//   _voin, _يده_, _kalw, _odja
  { {0xc692000b,0x09fa0003,0x6fde001e,0x7c950024}},	//   _מאד_, افسة_, rīce, _гриц
  { {0x63a40006,0xddc2012e,0x290c02eb,0xa7b6004c}},	//   _toin, _upoš, äda_, бсај
  { {0x44240003,0x18670001,0x24430060,0x7bcf0025}},	//   _بروف, љати_, mım_, ébut
  { {0x2443003a,0x13b7000b,0x8fa302ad,0x07a302ad}},	// [4120] lım_, _להקל_, чате, чатн
  { {0x8b080002,0xe29b0009,0x1d0a004c,0xa5bb0031}},	//   _cięż, _עשיר, гези_, _utól
  { {0x244300a2,0xb4b20037,0x7afb000e,0x30860012}},	//   nım_, टने_, _azut, _الجف
  { {0xec0a0020,0xd36f0003,0xa3ba0012,0x64411b17}},	//   _xếp_, فهم_, دائر_, isli
  { {0xab65001e,0x201a008e,0x6b821b18,0xcb1300af}},	//   daļā, _hupi_, rdog, פלג_
  { {0x3ead0101,0x6441007a,0x3f820006,0xa2f7000b}},	//   dyet_, ksli, _haku_, זמנה_
  { {0x644100c5,0xc173000b,0x58860015,0x7afb000e}},	//   jsli, פחה_, сыла, _ezut
  { {0xf0930093,0x2443003a,0x27e0009b,0xdbf10066}},	//   לנו_, dım_, čino_, _příb
  { {0x7e641b19,0x26c01641,0x8f9b0009,0xe7fb0011}},	//   ntip, nzio_, ריפי, ्षता_
  { {0x3f82120d,0x667b0009,0xc6930009,0x4427016d}},	//   _laku_, נטיק, פאת_, _btn_
  { {0x5399002d,0x6ad10011,0xe375003c,0x2fcd0034}},	//   авня_, सप्र, олны, bieg_
  { {0x69d80039,0xb8de0044,0x5f760003,0x7883000e}},	//   lnve, ुछ_, _دائر, hívá
  { {0x9b580014,0xd6d90034,0x99d70012,0x02cb004c}},	//   щият_, tałe_, متسا, ућни_
  { {0x2443003a,0x8b080066,0x865b0009,0xa159004c}},	//   bım_, _stří, _עדוי, јаву_
  { {0xfdf7000b,0x44260003,0x78830066,0x3f821b1a}},	//   _הצגת_, _ارتف, dívá, _baku_
  { {0x58d4002d,0x17fb0003,0xba55004c,0x69d80032}},	//   чост, ارسة_, _двиј, hnve
  { {0x680a003e,0x3f870066,0xde59002d,0x95390014}},	// [4130] _będz, ěnu_, разі_, изат_
  { {0x2737001a,0x6d5a1b1b,0x7afb0034,0x3a290060}},	//   ần_, ngta, _rzut, _itap_
  { {0x442700bd,0xccfb0001,0x9d1b0009,0xbc750012}},	//   ën_, ућа_, אובט, تهاب
  { {0x395e002a,0x2d9c006f,0x69d81b1c,0x79811b1d}},	//   _acts_, över_, enve, _salw
  { {0x69d80028,0x2443003a,0xc3340009,0xe2990588}},	//   fnve, zım_, לוף_, рал_
  { {0x6e2d00c1,0x2443003a,0xd23c000b,0x38290024}},	//   mpab, yım_, נגול, ажко_
  { {0x2fcd0052,0xe1f00012,0xa156004c,0xab650035}},	//   tieg_, رسه_, цају_, taļā
  { {0x6d5a1b1e,0x501c0009,0xce4905c8,0xf6251240}},	//   egta, נוחו, азие_, одио
  { {0xe6160015,0x2fcd0052,0x69ce000e,0x959902e3}},	//   оды_, rieg_, yibe, атну_
  { {0x2443003a,0xdcf8001e,0xddc5002d,0xfc450042}},	//   tım_, _savā, ібни, žíme_
  { {0x87e700be,0xd469011d,0x3a29016d,0x7bcf1b1f}},	//   _люде, шине_, _atap_, ficu
  { {0x244300a2,0x6d5a002c,0xe6950012,0xda660024}},	//   rım_, agta, _ولاد, овми
  { {0x2443003a,0xbebb0070,0xaffc0024,0x29cd001b}},	//   sım_, _geëx, _соцi, ržan_
  { {0xe4d50012,0x24430060,0x63b80035,0x36050012}},	//   _وتثب, pım_, īvni, _بوتف
  { {0xf992000b,0x64430066,0x03a604ad,0xa7aa00f5}},	//   ורם_, _uvni, _мико, аква_
  { {0xd5e2001a,0xa6db0028,0x680a0002,0x7e641b20}},	//   _trọ, _meðf, _sędz, ttip
  { {0xd5b20003,0x3e870014,0x2d850066,0x6e2d002c}},	// [4140] وفر_, ойто_, odle_, gpab
  { {0x6b840051,0x2ca90030,0x26c000b8,0xdd920012}},	//   _haig, _řady_, rzio_, بوط_
  { {0x6b96007a,0xec9a0046,0x7e640f58,0x07a6005c}},	//   _knyg, штај_, stip, _данн
  { {0x2ca70163,0x61fd001e,0xcb6a011d,0x75f00064}},	//   ända_, _īsla, раде_, väzu
  { {0x6b841b21,0xe28d0009,0x420a12b4,0x7bdb00af}},	//   _maig, ָרוֹ, андо_, סקנו
  { {0x67240412,0x8d7600ae,0x764409b8,0x76460b64}},	//   lcij, _باحا, msiy, škyk
  { {0x2d8507ac,0xbb560012,0x399b0009,0x999b0009}},	//   ddle_, _ونسب, ייסד, יבסט
  { {0xca760015,0x0c23002d,0x67241b22,0xa0070012}},	//   _музы, _імун, ncij, يقول_
  { {0x76440891,0x68150034,0xdb0d0060,0x3f820064}},	//   nsiy, _jądr, _ilaç, ľku_
  { {0x0697000b,0x28960001,0x3f8200f1,0xda7b000b}},	//   קדים_, _мјес, žku_, _דנמר
  { {0x6b84007a,0x3a2900bd,0xd5b7002d,0x4917000b}},	//   _baig, _stap_, ісь_, _וקבל_
  { {0x76440891,0xf1bf0031,0x28c30011,0x6b840bf2}},	//   ksiy, ppák_, _वेटि, _caig
  { {0x9f4903eb,0x69c0001e,0xaac50011,0x60150073}},	//   llaç_, īmen, _लेखक, _išma
  { {0x7bcf00c1,0x44441b23,0xc1eb003c,0xbebd0035}},	//   sicu, ks_, рьме_, rbūt
  { {0x5cc30014,0xab870014,0x85570009,0x63f70012}},	//   _осъз, _дупк, _ושוב_, _وأعر
  { {0xcf980046,0x09b70037,0x6e2d0051,0x5bc40003}},	//   оју_, _अत्य, tpab, _يقول
  { {0xf1db0044,0xa5bb000e,0xcd2b0012,0x7644020d}},	// [4150] _बदलन, _utók, لسان_, gsiy
  { {0x9f4405b1,0x44441b24,0x95570012,0xd6d90034}},	//   domí_, fs_, تخرا, nała_
  { {0xdb000149,0x753c0052,0xb97a0009,0x71880009}},	//   _domí, _derz, _הנתי, _וְרַ
  { {0x907a0009,0x5bb50011,0xbbb50011,0x207a0009}},	//   _פטרי, ंसेव, ंसेक, _פארא
  { {0xbf9a000b,0x2009001e,0x7af60002,0x7f9a0009}},	//   _הירש, mmai_, żytn, _הברז
  { {0x1a7c000b,0x20090010,0x81c80024,0xc984004c}},	//   שְׁמ, lmai_, огів_, дући
  { {0x0138000b,0xcb350014,0x44441b25,0xd6d90002}},	//   חרות_, _невъ, cs_, dała_
  { {0x63a20002,0xd8dc000b,0xb4d70037,0x60dc000b}},	//   cjon, יקור, ापी_, יקונ
  { {0xe81b0044,0xf6510012,0x9b880012,0x2a7f005e}},	//   _पूरा_, رئة_, _بنقل_, _usub_
  { {0xd1310003,0x22b80012,0xd6d90034,0xed59004c}},	//   _أما_, _بدفع_, gała_, љон_
  { {0x6b840051,0x75250052,0xb9c40003,0x98b8001e}},	//   _paig, ichz, _تقلي, karā_
  { {0x78fa0093,0x2d830470,0x6908000b,0xdb06008e}},	//   _הפעו, žje_, _וּנְ, ykkä
  { {0x798500c6,0x661d007a,0x4444001e,0x471a000b}},	//   _bahw, _nusk, zs_, _הונג
  { {0x764400a2,0x63a90051,0x91b1001a,0x6615009b}},	//   vsiy, _loen, _đạt_, _nizk
  { {0x6b840010,0x7531001e,0x63bb003a,0x10a60014}},	//   _taig, īdzē, _olun, чивн
  { {0x44441b26,0x6615001e,0x6d411b27,0xef1a0103}},	//   vs_, _aizk, lala, сма_
  { {0xe7370047,0xeab20003,0x442a0bb3,0xcd360012}},	// [4160] яет_, _سعة_, _stb_, كراب
  { {0x76440b70,0x224400d9,0xadfd0011,0xfce6004c}},	//   rsiy, ámku_, ॉगिन_, позо
  { {0xe1ff0164,0xd4c60012,0x224c0034,0x644515d1}},	//   otón_, أغذي, ądku_, gshi
  { {0xdb00007d,0x8c1a0093,0xd6d90002,0x161b0037}},	//   _româ, צוני, zała_, नदार_
  { {0x753c00c1,0x63a90017,0x61ee009b,0xcaf60012}},	//   _terz, _doen, oobl, أساب
  { {0x63a21b28,0xa5d8000b,0x7af6004a,0x69dc081f}},	//   sjon, _וַֽי, _myyt, nnre
  { {0xf993000b,0x2d980248,0x64430064,0x3c210097}},	//   תרו_, _inre_, ánit, _nóv_
  { {0xd6d9003e,0x27ed0033,0xdcfc001e,0x63a9016d}},	//   wała_, goen_, _garā, _goen
  { {0xa3c00037,0xd6d90002,0x9f40000e,0x6d411b29}},	//   ंघन_, tała_, llió_, fala
  { {0xfe6f0003,0x273a001a,0xdd9a0014,0x6d411b2a}},	//   ادي_, ẫn_, сши_, gala
  { {0x2009007a,0xd6d90002,0xe1650003,0x61ee04d2}},	//   ymai_, rała_, _تدقي, dobl
  { {0xb09b000b,0x6d4114d5,0x9cd70009,0xb4fb0009}},	//   _ליבר, aala, לויה_, מפיי
  { {0xbf130012,0xe61f0081,0x59b00011,0x98b80035}},	//   _كومب, _trôi_, _जकार, varā_
  { {0xd49a002d,0x673d1b2b,0x6d4a0040,0xf67b0009}},	//   _гри_, _sesj, _udfa, _לאדמ
  { {0x661d1b2c,0x657a1b2d,0x5dfb0009,0x15fb0009}},	//   _susk, meth, _הפגנ, _ההגע
  { {0x20091b2e,0x04db0009,0x30140048,0xb814004c}},	//   umai_, _לקול, едср, едсј
  { {0x1ef80012,0x394c1b2f,0x061501c6,0x64451b30}},	// [4170] كعكة_, _odds_, ддаю, wshi
  { {0x27ed0070,0x63bb0066,0xbbb50011,0x3abc0009}},	//   zoen_, _slun, ंस्क, _למחנ
  { {0xdcfc0039,0x69c00037,0x75250052,0x254f001e}},	//   _parā, वसनी, rchz, vēlē_
  { {0x6d5e0101,0x64451b31,0x6d411b32,0xdab90012}},	//   agpa, rshi, zala, يهات_
  { {0xc5f8001e,0x026b003c,0x645a005e,0x20fc0081}},	//   klē_, сшей_, huti, _ải_
  { {0xfe9a0009,0x64430030,0x63a90227,0x7bdd0032}},	//   _וישמ, ánis, _woen, hnsu
  { {0xb7b5008a,0xe7390047,0x63a90070,0xf7710003}},	//   _dụn, оей_, _toen, ناة_
  { {0x6d4105e2,0xc4d2000b,0x98b8000d,0x645a1b33}},	//   wala, _סגן_, lară_, duti
  { {0x29cd0027,0xdce70010,0x22460031,0x645a0032}},	//   ržaj_, _pajė, csok_, euti
  { {0xe290000a,0x657a002a,0x98b8000d,0xe6110012}},	//   _حذف_, geth, nară_, خشب_
  { {0x8cb40015,0x7af6004a,0x9f4b0066,0x6d411b34}},	//   есяч, _syyt, _akcí_, rala
  { {0x333f0061,0x7af6004a,0x60150010,0xceb50001}},	//   _jeux_, _pyyt, _išmo, _обећ
  { {0x6d411b35,0x539a000b,0x7fb60012,0x412a04a5}},	//   pala, קישו, _زهور_, жого_
  { {0xceb20009,0xe1ff01e3,0xe61f0064,0xdcf80073}},	//   _ביד_, stón_, _osôb_, _savą
  { {0xe1ff000e,0xdfd20012,0x3075003c,0x5fd10011}},	//   mtól_, نيس_, нутс, _तगाल
  { {0x3e660061,0x7af6004a,0xee3a0829,0x61ee0864}},	//   tôt_, _tyyt, жна_, sobl
  { {0x7dc00163,0x99e60015,0x42c70014,0xe61a0024}},	// [4180] _löse, _ожид, _огън_, ідж_
  { {0xe1ff000e,0x93bd000d,0x27e0017b,0x3f86015b}},	//   ntól_, spăt, čini_, žou_
  { {0x93bd000d,0x999b000b,0x2d87078d,0x319b0009}},	//   mpăr, _וביט, _mane_, _ובינ
  { {0x333f0108,0x657a000e,0x3e660061,0xf6260001}},	//   _ceux_, zeth, pôt_, _одмо
  { {0x333f0108,0xe1ff000e,0x41e60024,0xab770012}},	//   _deux_, któl_, міка, ظمها_
  { {0x27ed0133,0xa5760003,0x082a0083,0xfaa30001}},	//   čene_, _تُست, оции_, таљо
  { {0x232a002d,0xab2a002d,0xdb000042,0xc1730009}},	//   _мови_, _мова_, _domá, דחו_
  { {0xf76f000a,0x645a035f,0x6284004a,0xd6d90034}},	//   لاً_, vuti, _osio, gało_
  { {0x2d871b36,0x8966022a,0xe9da0048,0x7e690227}},	//   _bane_, _окаж, _дка_, gtep
  { {0x65ad0026,0xfe9b000b,0xb8b60001,0xfcaa000b}},	//   _súhr, קיימ, _осећ, ַיָּ
  { {0x2d8713a6,0x333f0061,0x6284004a,0x61430345}},	//   _dane_, _yeux_, _asio, _реха
  { {0xbb940015,0x7bc20070,0xb21b0028,0xd7930012}},	//   вающ, nhou, kvæt, _للمخ
  { {0xc333000b,0xbda60003,0x6d4e0027,0xd337000b}},	//   כור_, _يحتو, _odba, ורכה_
  { {0x79881b37,0xdb1d005e,0x4efb0009,0x1efb0009}},	//   _jadw, lisü, _והדו, _ולדע
  { {0x9cf4002d,0x69c60010,0x6bd70003,0x4d770009}},	//   _язкі, _įkel, _يتعر, _חתול_
  { {0x7bc20070,0x80a00037,0xdb1d005e,0x31db0011}},	//   jhou, _ऑपरे, nisü, _बद्ध
  { {0x799a00bd,0x98b8000d,0x19950015,0x7c2e001e}},	// [4190] _ontw, tară_, _запя, _atbr
  { {0x8d770003,0xa2ae0037,0xd6d90002,0xd1310012}},	//   بارا, ुनर्, zało_, _حمد_
  { {0xdb041b38,0x98b8000d,0x2d870029,0x3a2d0bad}},	//   _hlið, rară_, ľne_, _step_
  { {0x98b8000d,0x7bc20087,0x799a036a,0x69d51b39}},	//   sară_, ghou, _antw, lize
  { {0xda640003,0x333f0061,0xdb000042,0x600506fe}},	//   ناوي, _veux_, _pomá, nóme
  { {0xd6d90002,0x9f400028,0xd2b80009,0xdcef0064}},	//   wało_, llið_, ולדת_, _čeľa
  { {0x6d450160,0xd6d90002,0x2019016d,0x79a40048}},	//   maha, tało_, _kisi_, ърце
  { {0xc9180093,0xde880020,0x799a008b,0x7e690051}},	//   וחות_, _bị_, _entw, ttep
  { {0xc1750098,0xe1ff000e,0x20191b3a,0x3eb91b3b}},	//   _плащ, ttól_, _misi_, ást_
  { {0x69c0001e,0x62340001,0x77b50583,0xde88001a}},	//   īmek, _рефу, _máxi, _dị_
  { {0xc5f2000b,0xe1ff1b3c,0xf1c80012,0x28cf0011}},	//   רדי_, rtól_, _تولى_, _हेलि
  { {0xdb0000c5,0x6d450101,0xe1ff000e,0xc1690009}},	//   _domæ, haha, stól_, _לח_
  { {0x63ad0020,0x69d5000f,0x2d87003a,0x2b40001e}},	//   _doan, fize, _tane_, _veic_
  { {0x6d450190,0x85050012,0x76491415,0xdd880024}},	//   jaha, _كوشن, msey, _обід_
  { {0x25f50037,0x6d45046c,0x7dc00052,0x11d70003}},	//   ्तनी_, daha, _lösc, روفة_
  { {0xc7b20003,0x93bd000d,0x8c1a0009,0x672901e3}},	//   دّر_, spăr, _צופי, ncej
  { {0x76491b3d,0xc3330009,0x98b80073,0x8d56004c}},	// [41a0] nsey, _עוז_, darą_, етеч
  { {0x7af6003e,0x9f400028,0x6d450a60,0x4d630232}},	//   żytk, alið_, gaha, лкув
  { {0x19b7000b,0x7bc21b3e,0x7c2b004b,0xa1e90012}},	//   _נפטר_, thou, _înră, _تريك_
  { {0x2e240028,0x4fb60012,0xddcd0034,0xb2ba0009}},	//   _töf_, _أصدر, grał, ּמַר
  { {0x6d4513b9,0x7bc208de,0xb21b014f,0xa3b10011}},	//   baha, rhou, lvær, _ओवर_
  { {0x6d4500b6,0x28f80055,0x58d40048,0x6d4e0040}},	//   caha, мель_, колт, _udba
  { {0xddcd0002,0x63a40051,0x6f02000e,0xb21b0722}},	//   brał, öins, _szoc, nvær
  { {0x27e01b3f,0xdfd00003,0x2d8a0480,0x3ec50010}},	//   nnin_, ؤية_, _habe_, ųstų_
  { {0x7bc00289,0x171b0009,0x8b030034,0xdb1d005e}},	//   _ilmu, הופע, łęzi, risü
  { {0xde880020,0x69c3008b,0xceb3000b,0xb21b0040}},	//   _vị_, chne, טיח_, kvær
  { {0xa5bb0656,0xa6db0065,0x6448007a,0x70560012}},	//   _któr, _meða, usdi, _أنصا
  { {0xd5b80039,0xcf260012,0xdb1d0018,0xde880081}},	//   skā_, _أرضي, visó, _tị_
  { {0x6d451067,0x28d60037,0x628208de,0x69d51b40}},	//   yaha, _डेबि, nwoo, tize
  { {0xa6db0065,0xda100037,0x201900b6,0x27e01b41}},	//   _neða, ाषित_, _sisi_, činu_
  { {0x645e0039,0xf8070803,0x7bc0003a,0x6d45004a}},	//   jupi, ечан, _olmu, vaha
  { {0x628200bd,0xbc670003,0x34fb0009,0x3cfb0009}},	//   kwoo, _أمين_, _מהוד, _מלונ
  { {0x9f400028,0x20191b42,0xbe190024,0x201e0097}},	// [41b0] rlið_, _visi_, джає_, ítir_
  { {0x9f400028,0x78a1006f,0x2d8c0227,0x9df8004c}},	//   slið_, älvs, ndde_, енут_
  { {0x645e0051,0xf99f001a,0xdce70034,0x2d8c0227}},	//   gupi, _đè_, _obją, idde_
  { {0x6d450a26,0x10360009,0x18360009,0x62820227}},	//   saha, _שטרם_, _שארל_, fwoo
  { {0x22940024,0x645e0097,0xaab30011,0x6d451b43}},	//   лиця, aupi, ुनिक, paha
  { {0x7bc00bf4,0x2d8a0e00,0x98b80073,0xe2960488}},	//   _elmu, _gabe_, sarą_, таш_
  { {0x4425007d,0x645e1b44,0xf9940009,0xdcf80073}},	//   _îl_, cupi, טרס_, _tavę
  { {0x389c000b,0x2019004a,0x7ff50012,0x27e904d2}},	//   ליונ, ösi_, خستا, čano_
  { {0x200d000d,0xaf050014,0x7e6d0577,0x9be40024}},	//   rmei_, ъпил, ntap, _сірк
  { {0xdb000163,0xceb4000b,0x7e6d003a,0x64580010}},	//   _domä, ריץ_, itap, švie
  { {0x69c11b45,0xf5020048,0xfce506e5,0xd35f0024}},	//   _ille, изьо, тоно, _вiдч
  { {0x6b560009,0xab2a0024,0xeb97003c,0x2d8c19cc}},	//   ֣ישׁ_, ьома_, вию_, adde_
  { {0xd299002d,0x8d950003,0xddc4000d,0xf4120009}},	//   нтрі_, _للإش, ntiţ, יפט_
  { {0xaf04007c,0xddc20066,0xe579002d,0xdb1b01a0}},	//   _спіл, _zpož, _цзк_, _lluï
  { {0xb21b00c5,0x3f8d0054,0x18670345,0xabaa0012}},	//   tvær, odeu_, кари_, _يهتم_
  { {0xc2c60003,0x3f8d0017,0x2d8a01c5,0xf0920009}},	//   _ليبي, ndeu_, _sabe_, סנן_
  { {0x05660098,0x6d430755,0xb21b0058,0x26060037}},	// [41c0] кван, _kena, rvær, _सीडी_
  { {0xb21b00c5,0xa5bb0028,0x1ea90003,0x645e00ff}},	//   svær, _stór, راقي_, tupi
  { {0x0b46002d,0xc1bb000b,0xdd8f0003,0x6d431b46}},	//   внен, _חמיש, تول_, _mena
  { {0x628200bd,0xacf51b47,0xdca30001,0xd2520003}},	//   twoo, учуј, јаци, لنص_
  { {0xd36f0012,0x4ad20011,0x29cd0159,0x02d20011}},	//   تهن_, _देशव, ržav_, _देशभ
  { {0xa5bb0034,0x5eeb0009,0x26060011,0xddc20035}},	//   _wtór, _חַלְ, _सीढी_, _spož
  { {0x40940012,0x04430400,0x8c4314ea,0xdca3193d}},	//   البر, _весн, _весе, _кари
  { {0xa8570093,0xab5d0034,0x90570009,0xdce10073}},	//   דיקה_, _elżb, דבקו_, lelė
  { {0x83fd0027,0x0357000b,0x6fde001e,0xd0070001}},	//   nuđe, _שימש_, nīci, њење_
  { {0x68e9007d,0x3d200037,0x6d431b48,0x39471b49}},	//   şedi, _बलों_, _cena, cans_
  { {0x6d431620,0x23b60011,0x2d8a0064,0x69d81b4a}},	//   _dena, _अकाद, ľbe_, mive
  { {0xccf30093,0x22590015,0xe7370014,0xe6960012}},	//   יכת_, нимы_, _аец_, _للصد
  { {0xdfcf000a,0x3a240611,0x645d0073,0x957c0034}},	//   _بين_, _jump_, ąsia, gnąc
  { {0xca48001a,0x7e601b4b,0x6d4300d6,0xc2110009}},	//   iờ_, mump, _gena, ֶ֔ם_
  { {0xdce10010,0x4bdb0012,0xca480081,0xe82409f8}},	//   delė, _يبعد_, hờ_, ифто
  { {0x39471b4c,0x7bc60032,0x7e6d1b4d,0xf7700012}},	//   zans_, chku, ttap, ياق_
  { {0x661c003a,0x7e60010a,0x5575019c,0x7d010031}},	// [41d0] _birk, nump, лгат, _úlsz
  { {0x69d80159,0xad670012,0x6d481b4e,0x27460073}},	//   jive, ضائه, nada, vūnų_
  { {0x6b8d0101,0x661c09d2,0x63bd0073,0x7e6d1b4f}},	//   _kaag, _dirk, oksn, stap
  { {0x6d4800c6,0x645a0065,0xa3cd0037,0xdfc60012}},	//   hada, irti, षों_, _طي_
  { {0x8aa70014,0x69c7004a,0x98b80010,0x6d481b50}},	//   ържд, ohje, darę_, kada
  { {0x69d80bbd,0x3abc0009,0xe81b0011,0x60150073}},	//   give, ומדנ, _पूजा_, _išmi
  { {0x2d810051,0xddc4000d,0x59640014,0xc5f20009}},	//   mehe_, stiţ, ръча, _הדם_
  { {0x2d810051,0x2cbc0033,0x6d431b51,0x178506fd}},	//   lehe_, øvde_, _sena, угим
  { {0x7e600101,0x224d0027,0x6d431b52,0x3f8d0d04}},	//   gump, _uvek_, _pena, rdeu_
  { {0xddcd0002,0x7dc0006f,0x69d800b8,0xddc40060}},	//   jważ, _lösn, cive, iriş
  { {0x59b80037,0x6fde001e,0x6d431b53,0x2d810032}},	//   _अवतर, zīci, _vena, iehe_
  { {0x4e950003,0xdb1b0054,0x6d4800ff,0xf9890009}},	//   _مشتر, _lluí, aada, _מר_
  { {0xe1ff003e,0xee38002d,0x6d431b54,0xe2970223}},	//   ntów_, _ані_, _tena, гая_
  { {0xf1ce0037,0xa5940014,0x6d4801c5,0x36660048}},	//   होंन, _връщ, cada, _сашо_
  { {0xbca8000a,0xaf9a0109,0x8d740012,0x50b5026d}},	//   _لديك_, нтах_, _خانا, асту
  { {0xe1ff0002,0x200b0066,0x661c1b55,0xab660451}},	//   któw_, _chci_, _sirk, _свил
  { {0x67220039,0xdce10010,0x76550002,0xe81b0037}},	// [41e0] žojo, telė, ązyw, _पूछा_
  { {0x59860046,0x531b000b,0xd23b000b,0xdca60001}},	//   _слоб, _אופצ, _רגיל, лази
  { {0x5a17000b,0xb4250003,0x661c1b56,0x27e907a5}},	//   _תקין_, لعنو, _virk, čanj_
  { {0x929d003e,0x661c008b,0x61e30033,0x232a04ad}},	//   _czło, _wirk, ennl, ходи_
  { {0x673b009b,0xe2970538,0x69d81943,0x6d481b57}},	//   dbuj, лац_, tive, yada
  { {0x7bc40054,0xa6db0028,0x7d030052,0x7c2900d9}},	//   _lliu, _meðl, ünsc, _červ
  { {0x39450663,0xdce70002,0x65c300bb,0x4dfb0009}},	//   _dels_, _obję, _убра, _נפלא
  { {0xa3b80044,0xdfd00003,0x76aa0015,0xa8e2001a}},	//   _छवि_, تيب_, етов_, _đồn
  { {0xd5b00003,0xcfb70009,0x9ed70048,0xa51c0011}},	//   قفة_, טלקי_, лмът_, नश्च_
  { {0x27ff0051,0x6b8d0051,0x5c740014,0x7a7b0009}},	//   alun_, _saag, алот, _ארמס
  { {0xdb090028,0x7e60019e,0xc8ca0012,0xfdf70009}},	//   _hleð, sump, _ثوان_, רצית_
  { {0x764d002c,0xd2510012,0xa73a0012,0x1bf40011}},	//   ysay, ينج_, _أثار_, इकिल_
  { {0x6d481b58,0xdb190032,0x59b80011,0x63bd1b59}},	//   pada, chwä, _अवार, rksn
  { {0xc214000b,0x283b0012,0x171b0009,0x2c4e0034}},	//   יהָ_, فأرة_, _נוגע, pęd_
  { {0x8607000a,0x4dfb000b,0xdb000164,0xd5fb0009}},	//   _حقوق_, _רפוא, _comú, _רפור
  { {0x2bbb0003,0xddc90002,0xb5fd0042,0xdc9b0009}},	//   _ساعة_, kreś, ruše, _טיול
  { {0x672d1b5a,0xc3b80009,0x141c0009,0xde580024}},	// [41f0] rcaj, _תלחץ_, _אוהב, латі_
  { {0x764d00a2,0x21670103,0x28d60011,0x2000004b}},	//   rsay, _стиг, _डेवि, alii_
  { {0x764d0061,0xcd070014,0xb60401d4,0xdcf7004b}},	//   ssay, учаи, сятк, dexă
  { {0x94740012,0xd7950048,0x764d0060,0xccf8004c}},	//   إدلا, _тимъ, psay, ућу_
  { {0x394503eb,0xe1f10003,0xa96914cf,0xc6860012}},	//   _pels_, يست_, вила_, _بِ_
  { {0x321e0036,0x9f520061,0xe1ff0002,0x30550001}},	//   _city_, voyé_, rtów_, ађит
  { {0xe1ff003e,0x27ff0028,0xdb1d0051,0xdb020028}},	//   stów_, tlun_, misõ, skoð
  { {0x98a5000d,0x765b0164,0xe1ff0034,0x7d1a0097}},	//   _află_, truy, ptów_, _útsa
  { {0x6d4700c6,0x39450061,0x2c510002,0x2003001e}},	//   _keja, _tels_, ląd_, ēji_
  { {0x7bc80039,0x6d4700b6,0xe8070011,0x32b80012}},	//   ījum, _jeja, _वीसा_, _صدقة_
  { {0xa3ea0044,0x79830070,0xe5720009,0x6bd60012}},	//   _मदद_, menw, חַר_, لتحر
  { {0xb6010066,0x7e7d17fc,0xad1a0009,0x33d60024}},	//   _řáde, _opsp, כותר, ріот
  { {0x2ba80037,0xd24f0003,0xe5a50469,0xada50223}},	//   गाबा, ونَ_, _вили, _валл
  { {0x8cb50098,0x865a000b,0x2c510034,0xec790adc}},	//   _всич, _ידני, kąd_, _апк_
  { {0x7aed0017,0xa988000b,0xc5f40012,0x4dda0009}},	//   _exat, נָשִ, _اثنت, _בחסו
  { {0x3f8f0051,0x69c5000e,0x1867004c,0xd2590035}},	//   _jagu_, _elhe, јати_, šņa_
  { {0xabfb000b,0x44271b5b,0xcd360012,0x93fb0009}},	// [4200] _שהפר, _hun_, لراب, _שלפי
  { {0x3f8f06db,0x5d1a0003,0x44271b5c,0xe29b0009}},	//   _lagu_, نتاج_, _kun_, _ישפר
  { {0x6d471b5d,0x546a0593,0x515b0009,0x115b0009}},	//   _deja, таем_, _בכיו, _בדיע
  { {0x44270065,0x3f8f0005,0xfc030001,0xda660003}},	//   _mun_, _nagu_, опхо, لاتي
  { {0x4420000d,0x321e0132,0xdcfa0035,0x79830032}},	//   _mii_, _pity_, ietā, fenw
  { {0x51f7002d,0xd6d90002,0x60860003,0x6d4700b6}},	//   анію_, nału_, لشبك, _geja
  { {0x25f50037,0xc953000b,0xfce300be,0x44271b5e}},	//   ्तरी_, קמה_, _доро, _nun_
  { {0x44200005,0x225a0012,0xf7f30012,0x2d8e1b5f}},	//   _nii_, _للرد_, يسيد, _safe_
  { {0x442702d1,0x8c1b000b,0x79830032,0x35e60048}},	//   _aun_, _יולי, benw, ицов
  { {0x4427000d,0x77bc0d85,0x69dc004b,0xc4c60012}},	//   _bun_, _méxi, jire, لتجو
  { {0x77860014,0x30860003,0x2fc00227,0xcd970009}},	//   _влез, _خلاف, kkig_, בדית_
  { {0x62080010,0x98a30ff7,0x6fb30012,0xe73a11d9}},	//   šplė, ncją_, _وملا, _ред_
  { {0x6594007c,0x9b580014,0x91f70003,0x3e340003}},	//   _галу, шият_, لأسا, _افتر
  { {0xd4da0003,0x61f8017b,0x667b0009,0x44271b60}},	//   _لبعض_, novl, _סטוק, _fun_
  { {0x5214002d,0xed570001,0xdb1d0017,0xe759002d}},	//   ідст, _тој_, visõ, ливі_
  { {0x6d471b61,0xee1f0037,0xe019002d,0x90570009}},	//   _seja, बद्ध_, ужбі_, יבלו_
  { {0xd251000a,0x6d4700b6,0x5d550014,0x83b60009}},	// [4210] _عند_, _peja, йкат, _הִיא_
  { {0x2c510002,0x27e904d2,0x7bdd0269,0x5afc0009}},	//   tąd_, čani_, lisu, _בלחצ
  { {0x44270020,0xe4d90003,0x40950003,0x6c750001}},	//   ên_, دوات_, _الجر, слеђ
  { {0x889a000b,0x289a000b,0xdb1d0051,0xfbd00012}},	//   _עברי, _עירא, sisõ, وتن_
  { {0xddc9007d,0x2ba80011,0x2bba0011,0xdb230097}},	//   nteţ, गाता, _उकसा, _þríh
  { {0x3238000b,0x2ca7006f,0xb5fd1b62,0x2d87005e}},	//   סטון_, änds_, kuša, õned_
  { {0xb5fd001e,0x3b670014,0x7bdd0312,0xb3670014}},	//   juša, _възв, kisu, _възк
  { {0x44270036,0xf7710003,0xdce1001e,0x6d5c0097}},	//   _run_, ساب_, selī, óran
  { {0xef190047,0x5fa90037,0xc68e0012,0x929d0034}},	//   ыми_, काबल, فِي_, _byłe
  { {0x442700c6,0x69ca0052,0x7bdd005e,0x86980048}},	//   _pun_, chfe, eisu, ртът_
  { {0xb5fd001e,0x3f8f1b63,0xdddd0035,0x2fc60032}},	//   guša, _tagu_, _apsū, _flog_
  { {0x30150015,0x9cd60009,0x671b0011,0x48150578}},	//   _удер, מותה_, _पृथक_, _умес
  { {0x539a000b,0x501a0009,0x7ff40012,0x86c40012}},	//   אירו, _עונו, _بسلا, _ويمن
  { {0xa06a0098,0xd83e009b,0x44271b64,0x6e3b01ea}},	//   лага_, ščen_, _tun_, mpub
  { {0x2d8501b3,0xd4350003,0x69dc1b65,0x8fa600f5}},	//   mele_, _اعتب, rire, баве
  { {0x2d85043c,0x2cb8006f,0x29c20028,0x69dc1b66}},	//   lele_, ärde_, _aðal_, sire
  { {0xb8ff0044,0x2c71000e,0xe57a0014,0xcf920009}},	// [4220] _दे_, lád_, лза_, הטן_
  { {0x9986000a,0xef17004c,0x3f840034,0x2d851b67}},	//   _الدو, сму_, zemu_, nele_
  { {0xdb0d0028,0x645e001e,0xe45a0129,0x6b860227}},	//   _hlað, urpi, уже_, oekg
  { {0x63a40039,0x2d85063c,0x629b0073,0xddc20030}},	//   ķino, hele_, _bruo, _dvoř
  { {0x7e6403eb,0xa3d70037,0xcaf60003,0x2d850643}},	//   quip, ाफ़_, حساب, kele_
  { {0xd9f80044,0xcaa50003,0x9f490028,0x2d8512b7}},	//   ंकित_, تصمي, llað_, jele_
  { {0xd0100003,0x2d851b68,0x3ff40012,0x30140148}},	//   ولت_, dele_, يكتر, одкр
  { {0x289b000b,0x389b000b,0xb0270003,0x96340863}},	//   ריקא, ריקנ, حكيم_, ониц
  { {0xcf93000b,0x629b0010,0xd36f0003,0x25ef0037}},	//   לטה_, _gruo, _سهل_, _आदमी_
  { {0xc58a0015,0x54540232,0x6dbb0034,0x45d40024}},	//   ущие_, овот, płań, іонс
  { {0xc7af0047,0x5f460003,0x29370009,0x399b0009}},	//   _её_, _هنال, _האבן_, _תיבד
  { {0xdc8b0009,0x74150012,0xfbab003c,0x2fc6001b}},	//   נְיָ, توجا, утой_, _ulog_
  { {0x442a0656,0x2f970093,0xadfa0037,0xddc9000d}},	//   _lub_, _לכאן_, ्तान_, uteţ
  { {0x236d003e,0x0e570093,0x6ca60014,0x63a4004a}},	//   żej_, _פשוט_, _гриж, _enin
  { {0x6115002d,0xe919002d,0x0bd50012,0xeb9f0040}},	//   ідбу, рові_, _ويتح, rløb_
  { {0x6031001e,0xdfd4003c,0x2d850034,0x9f490097}},	//   _jāma, посы, _źle_, glað_
  { {0x69c8002a,0xa37b0017,0xbdb50001,0x8f9b000b}},	// [4230] _olde, giõe, обај, נימי
  { {0x85bb0012,0x6d4a01e3,0xb527003c,0xd66800ae}},	//   دارس_, _jefa, сьак, صممو_
  { {0x6280007a,0xb5fd009b,0xf1ac0037,0x9f490028}},	//   _apmo, kušn, चानन, blað_
  { {0xfd100003,0x78ba006f,0x2d851b69,0xd8380030}},	//   رجل_, ätve, zele_, íče_
  { {0x957c003e,0xdcf8001e,0x51f50012,0x62650024}},	//   ciąg, _kavē, يستر, івка
  { {0xfa780093,0xddc20066,0xda7c000b,0x957c0002}},	//   צעות_, _tvoř, טנדר, niąd
  { {0x27e91b6a,0xa2db0011,0xb3cc0011,0x31580009}},	//   onan_, _पेस्, ासमख, זיון_
  { {0xdbf20013,0x27e91b6b,0x73c50012,0x6009004c}},	//   _přís, nnan_, _بيرم, јним_
  { {0x7c2a0052,0xa6db0028,0x27e90c55,0x6d4a1b6c}},	//   _aufr, _beði, inan_, _befa
  { {0xe6280003,0x7c2a0033,0xed59004c,0xa2b80011}},	//   حثين_, _bufr, јон_, ्नर्
  { {0x7bc900bd,0x2d85043c,0x6e3b0010,0xcb09000b}},	//   _kleu, rele_, spub, _סל_
  { {0x2d851b6d,0x645c0017,0xf1a90009,0xb8df0011}},	//   sele_, ária, _בס_, ुन_
  { {0xeb9705cc,0x9c080009,0x4a430048,0x03760009}},	//   ция_, מִשִ, мняв, חתרת_
  { {0x38a0007d,0x8c450014,0x7bc20066,0x7bc90054}},	//   _fără_, _деке, zkou, _lleu
  { {0x6e2b0028,0x9f490028,0xab5b003a,0x290c0248}},	//   _hugb, tlað_, mkün, åda_
  { {0x29040039,0x27e91b6e,0x98a30002,0x6fda0066}},	//   āma_, gnan_, ncję_, můck
  { {0x99890029,0x7c2a0052,0x442a1b6f,0xee370339}},	// [4240] _stať_, _zufr, _sub_, жну_
  { {0xad660003,0x6abb0052,0x7c240038,0xed5a0024}},	//   تاره, äufe, _hiir, рож_
  { {0x7c240005,0x98a30002,0xcc360003,0x6e230033}},	//   _kiir, kcję_, زراع, _minb
  { {0x13060447,0x61fc0e03,0xab5b005e,0xa2c10011}},	//   озем, lorl, shüv, रैक्
  { {0xc7b30093,0x27e0004a,0xbd460012,0xfbd30009}},	//   _חבר_, miin_, _ونحي, ותא_
  { {0x27e01b70,0x3e74004a,0x7bc2004a,0xa3e60011}},	//   liin_, mät_, skou, _पदक_
  { {0xa9670046,0x91a90020,0x21670046,0x316000a2}},	//   ција_, _quả_, цији_, ğiz_
  { {0x88bb000b,0x27e0004a,0xb6020066,0x17f70003}},	//   יזצי, niin_, řáda, يرية_
  { {0x7c3e0070,0x3f980066,0x7c2a11f8,0x3e7408fb}},	//   lppr, ěru_, _sufr, nät_
  { {0x44240036,0x667b000b,0x27e9009b,0x2b85001a}},	//   _him_, סטיק, znan_, _ặc_
  { {0xddcd000d,0x27e0004a,0x659b000b,0x6d4a0839}},	//   ltaţ, kiin_, בייק, _vefa
  { {0xb5fd09ea,0x47c30014,0xb4fb000b,0xddc9000d}},	//   vrše, _обхв, שפטי, preş
  { {0x3e740006,0x67160037,0xddcd000d,0x6d410c86}},	//   jät_, देशक_, ntaţ, bbla
  { {0x3e74004a,0x6d55000e,0x6d581b71,0x442404e2}},	//   dät_, ózat, _udva, _lim_
  { {0xdb000002,0x61ea0052,0xc1050003,0x61fd0028}},	//   _komó, infl, سوري, _ísle
  { {0x443e1ae3,0x44241b72,0x8e3b0012,0x0e350198}},	//   mpt_, _nim_, لسطر_, знаю
  { {0x443e17c8,0x98bc0030,0x97420024,0x9f44026b}},	// [4250] lpt_, tavě_, вiть_, lomó_
  { {0x69ce0052,0x443e0070,0xb5fd0066,0xdd910003}},	//   chbe, opt_, prše, عوا_
  { {0x98bc0066,0x98a30002,0x7aeb001e,0x7bc919d9}},	//   ravě_, ycję_, ņotā, _pleu
  { {0x70fa0093,0x60fa0093,0x78fa000b,0xab5b0052}},	//   _להתח, _להתק, _לפתו, chüt
  { {0x80d30044,0xd736000b,0x442403c1,0xbf360009}},	//   _भेजे, _מטרת_, _dim_, _מארץ_
  { {0x76ba0093,0xdeba000b,0xe9d80024,0x3e7b004b}},	//   _המשפ, _המשל, окі_, râtă_
  { {0x225e0002,0x44241b73,0xfc300012,0x443e0227}},	//   ątki_, _fim_, _لحق_, jpt_
  { {0x1a5b0003,0xd7750012,0xa2d60011,0x2cbc0248}},	//   _نشطة_, سابع, _मेक्, ävde_
  { {0xddcd007d,0xa159002d,0xee390001,0x61fc003a}},	//   ctaţ, _газу_, љно_, yorl
  { {0x7c240006,0x6e3b00a2,0x6d411b74,0x49b80012}},	//   _siir, _çubu, ubla, _والد_
  { {0xdca50047,0x7c240176,0x98a30002,0xab5b0052}},	//   чани, _piir, pcję_, rkün
  { {0x907a0009,0x28960009,0x64880009,0x14160024}},	//   _לטעי, _מדען_, חְשְ, яєпр
  { {0x27e00006,0x7c240051,0x80b10011,0xb6a5003c}},	//   viin_, _viir, _अपडे, _хилл
  { {0x3e740006,0x8e08002d,0xab5b000e,0x6e920003}},	//   vät_, _днів_, lkül, _ألوا
  { {0x27e00006,0x55020037,0x00c90009,0x87850064}},	//   tiin_, _रुपए_, זֶּֽ, ahŕň
  { {0x3e741b75,0xf0920009,0xdfd20012,0x4abd0011}},	//   tät_, ענן_, ريذ_, ्नाव
  { {0x61fc00a2,0x27e01b70,0x166600ac,0xc2c60012}},	// [4260] porl, riin_, явам, _ريدي
  { {0x27e00006,0x7d1a0028,0x3e7403d7,0x44241b76}},	//   siin_, _útsk, rät_, _sim_
  { {0xc32a0003,0x91bb000b,0xdcfe000d,0x487a0014}},	//   مكان_, _המיי, depă, _успя_
  { {0x7c2e0018,0xcb6a076b,0x3f891b77,0x6d430097}},	//   íbri, саде_, ceau_, ðnar
  { {0xf1b0015f,0xc333000b,0x6d5c000e,0xddd60002}},	//   ञापन, גוד_, órak, owyż
  { {0x29051b78,0xddcd000d,0x5eeb0009,0xc27b0009}},	//   _byla_, rtaţ, _הַלְ, מרני
  { {0x7dcb0002,0xdb000002,0xddcd000d,0xf9930009}},	//   yższ, _pomó, staţ, גרו_
  { {0xddcd007d,0xf093000b,0xcc77000b,0x67360002}},	//   ptaţ, תנה_, _מעלה_, ncyj
  { {0x6d4e00c6,0x9f5f0018,0x45d40681,0x7c2e0e00}},	//   _keba, cluí_, допс, _hubr
  { {0x645c0149,0xddd60002,0x60e70028,0xcaa50003}},	//   ário, jwyż, ármá, _تصفي
  { {0x493b000b,0x67360002,0xa4d4002d,0x443e0052}},	//   _הגבו, kcyj, фоні, upt_
  { {0x14190003,0x6d4e1b79,0x7656008e,0x443e1b7a}},	//   تيجة_, _leba, ksyy, rpt_
  { {0x3f891b7b,0x35a60b22,0x6d5c0618,0xcfb70009}},	//   veau_, _надг, _odra, _מלאי_
  { {0x171b0093,0x6d4e0010,0xdee50003,0x7bc60574}},	//   _הודע, _neba, _تأمي, akku
  { {0x757b000b,0x5d7b0009,0x7d7b01b0,0x61140024}},	//   _הטופ, _האוק, _הרוג, едру
  { {0x6b84005e,0xab5b0060,0x69de1026,0x443c1b7c}},	//   õigl, oküm, _empe, _itv_
  { {0xe6640046,0x05870015,0x7dc00052,0x6d4e1b7d}},	// [4270] етхо, зуем, _lösu, _beba
  { {0x2002014d,0x3f890108,0xd7bf0011,0xdd9b004c}},	//   _ekki_, seau_, _एकवच, љша_
  { {0x7bcd0a1f,0x3f890061,0x6b96003a,0x6fe80066}},	//   _klau, peau_, _yayg, pěch
  { {0x443c1b7e,0x90560009,0x7c2e1b7f,0x69c700b0}},	//   _mtv_, _קברו_, _dubr, lkje
  { {0x7e641b80,0x4f9a0009,0xdb0d0018,0x6d430060}},	//   crip, _וברצ, _doaç, ınab
  { {0xc692000b,0x27ed0027,0x6d4e01e0,0x69c71b81}},	//   _שאם_, čenu_, _geba, nkje
  { {0xfc640014,0x84640014,0xa37b0051,0xab5b12b8}},	//   _пътн, _пъте, lnõu, tkül
  { {0x43940015,0xee390959,0x9b94076b,0x00780009}},	//   _пасс, они_, _писц, פתחי_
  { {0x442e032b,0x200900b6,0xb9040037,0x64581b82}},	//   _auf_, ilai_, _पे_, _avvi
  { {0xf1a40044,0xde160003,0x6b96003a,0xab5b12b8}},	//   _गोपन, وقيت_, _sayg, skül
  { {0x69c70119,0x957c0002,0x20090010,0x91640012}},	//   dkje, wiąc, klai_, _أهمه
  { {0xe72e1154,0x3b0a0731,0x6b8b1b83,0x30180012}},	//   _је_, жемо_, negg, _فتنة_
  { {0xd378003e,0x27380020,0xe56e1b84,0xdce10002}},	//   ęć_, _ứng_, _из_, dglą
  { {0x63a40333,0x27ed0052,0x60350073,0x6b8b0a11}},	//   ķini, lnen_, _sąma, hegg
  { {0x957c0002,0x9f8b0028,0xabf60055,0x6cd20012}},	//   siąc, töðu_, _очищ, _لقوا
  { {0x6d4e00ec,0xa6db0028,0x7bcd1b85,0x27ed1b86}},	//   _seba, _neðs, _glau, nnen_
  { {0x61e300a2,0x27ed0723,0xfe790066,0x6e270070}},	// [4280] kinl, inen_, ntů_, _bijb
  { {0x3f4c0020,0x27ed0052,0x04460593,0x3f5e0081}},	//   ếu_, hnen_, дежн, ữu_
  { {0x63bb002a,0x225e0002,0xeb9a00de,0x718b0009}},	//   _boun, ątku_, жие_, _וְכַ
  { {0x63bb0036,0x27ed00bd,0xfe790066,0x83830015}},	//   _coun, jnen_, ktů_, выше
  { {0x6d4e1b87,0x8c1b0009,0xfe790030,0x320a0030}},	//   _teba, קוני, jtů_, olby_
  { {0xcad7000b,0xdcf80010,0x61e30028,0xe2a70028}},	//   וונת_, _gavė, ginl, æðis_
  { {0x63bb0036,0xdcfc0039,0x64b50066,0x27ed0052}},	//   _foun, _varē, _přiš, fnen_
  { {0xb5fd001b,0x6e270070,0x442e1b88,0x2d981b89}},	//   vrša, _zijb, _ruf_, _hare_
  { {0x7dc00028,0x61e30060,0x2d981b8a,0x7b300073}},	//   _föst, binl, _kare_, gėuž
  { {0x7dc000a1,0xcad70009,0x89160012,0x3abb0009}},	//   _göst, _חומת_, _قبائ, _וממנ
  { {0xd12f000a,0x659b0093,0x63bb0036,0x61fd0028}},	//   _ضمن_, קיטק, _youn, _ísla
  { {0xaec60001,0x20140002,0x690b0009,0x443c0081}},	//   _обел, ócić_, _וּדְ, _vtv_
  { {0xdcf5001e,0x5f160011,0x2d98004b,0xdb190032}},	//   _pazī, _पृच्_, _oare_, ckwä
  { {0x7c660003,0xb5fd0029,0xf5770003,0x7c580012}},	//   _قابل, prša, _يمنع_, _فلتر_
  { {0x69c70033,0x2d8c0773,0xd7f5003c,0xa6db0097}},	//   rkje, mede_, езвы, _neðr
  { {0x69c70119,0x61e3003a,0x200900b6,0xf4830024}},	//   skje, zinl, ulai_, _рушн
  { {0x2d981b8b,0x63bb002a,0xc20e0037,0xa615046d}},	// [4290] _bare_, _roun, िताब_, емач
  { {0x9e770093,0x2d981b8c,0x2bc70037,0xbe18002d}},	//   וגמה_, _care_, लस्थ, джує_
  { {0x7dc0006f,0xb5fd009b,0xa37b0051,0x6b8b1b8d}},	//   _röst, kršn, snõu, tegg
  { {0xe6670098,0x26c4007a,0x67d50024,0x04c80012}},	//   _отго, kymo_, _чому, بومي_
  { {0x2d981b8e,0x44291b8f,0xa294002d,0x61e30c6e}},	//   _fare_, _mia_, каці, tinl
  { {0xba3d0066,0x26c40010,0x63bb002a,0x40950751}},	//   _průb, dymo_, _woun, ерит
  { {0x3f990051,0x2d8c1b90,0x27ff1b91,0x61e31b92}},	//   _kasu_, dede_, toun_, rinl
  { {0x61e3003a,0x63a9116c,0xa3c50011,0x9f910031}},	//   sinl, _unen, एसओ_, _káé_
  { {0x2ec90037,0x27ed1b93,0x6f7a0009,0x06960012}},	//   िनेत, rnen_, הְיו, فنية_
  { {0xc692000b,0x7c29036a,0xd1310003,0xe6160015}},	//   נאי_, _hier, _إما_, нды_
  { {0x7c291b94,0xfe790066,0xdc030030,0x3e830035}},	//   _kier, stů_, _zčás, lītā_
  { {0x889a0009,0x3f99001b,0xfe790030,0xdcfa0030}},	//   _מבעי, _nasu_, ptů_, letě
  { {0x44291b95,0x4431052e,0x7c291b96,0x5ac704ac}},	//   _dia_, _luz_, _mier, елям_
  { {0x6031001e,0x395e0061,0x6455000e,0x66ba0009}},	//   _rāmj, ûts_, ázis, _ממנה
  { {0xf505007c,0xb5fd001e,0x4d76000b,0x64a20048}},	//   _язко, juši, _נתקל_, _баща
  { {0x44290020,0x7c291b97,0x25db0011,0x35c50011}},	//   _gia_, _nier, गोरी_, _लकड़
  { {0x7dd20058,0x6b84002c,0x2d981b98,0xd00f0012}},	// [42a0] _læse, _ibig, _pare_, صلك_
  { {0x3e83001e,0x699f0011,0x8d760012,0x2b5f004b}},	//   dītā_, _गोली, عاءا, _aduc_
  { {0x8ca20037,0x35a60011,0x139a0009,0x7e7b005e}},	//   गियो, _कोफ़, ּבְע, htup
  { {0xe9f90020,0x78ad0066,0x2d8c1b99,0x7c291b9a}},	//   _trả_, ňová, zede_, _cier
  { {0xa294002d,0xf2060014,0x32d80002,0x3d060037}},	//   талі, няко, _użyć_, _सुने_
  { {0x98a5003a,0x27ff017b,0x7c291b9b,0xcb130009}},	//   _adlı_, čune_, _eier, אלד_
  { {0x21570003,0x6b840032,0xc7cb0081,0xba3d0030}},	//   رجوع_, _obig, _hiêị, _průc
  { {0xdfd00003,0xf76f0003,0xf8b3000b,0xdb210052}},	//   شيخ_, ماً_, רשה_, _äuße
  { {0xc6f8007c,0x44440119,0xadf40037,0xddc4000d}},	//   ьних_, lp_, _आदान_, cuiţ
  { {0x44291b9c,0x81a50003,0xd677000b,0x2d8c0164}},	//   _sia_, _لحمل, עתיק_, uede_
  { {0x2d8c1b9d,0x9bd5002d,0x26c40073,0x2240016d}},	//   rede_, вжні, symo_, _atik_
  { {0x2d8c066e,0x87da0003,0xbb940015,0x44441b9e}},	//   sede_, _عباس_, гающ, ip_
  { {0x5fbb000b,0x430b002d,0x5187059a,0x5a340593}},	//   _מצאנ, яхом_, нува, лнят
  { {0xcb13000b,0x45f80012,0x6da3004c,0x91a90081}},	//   טלר_, _تفتح_, _биља, _quà_
  { {0xddc4000d,0x25370009,0x0db70012,0x34940024}},	//   zuiţ, _אנוש_, _ساوث_, _райр
  { {0xc9170009,0x645a1b9f,0x6d480073,0x5f940588}},	//   תחלת_, msti, lbda, лист
  { {0xb9080037,0x44441210,0x645c0061,0x3f990027}},	// [42b0] _मे_, ep_, _avri, _vasu_
  { {0xf41f0006,0xb21b0058,0xd5380012,0x7c291ba0}},	//   lmä_, dtæg, ّثنا_, _sier
  { {0x3f990051,0x89dc000b,0xb4bd0037,0x98b80010}},	//   _tasu_, _מחזי, ेने_, darė_
  { {0xf8b6000b,0x6b9d0078,0x3e830035,0xb5fd0c51}},	//   _ספרי_, ndsg, tītā_, ruši
  { {0x2bb80003,0x0756000b,0x7d0a0028,0xe28e0109}},	//   عامة_, _בסרט_, _lyfs, ша_
  { {0xc0e50098,0x7c29003e,0xf41f004a,0x6fdd0011}},	//   колк, _wier, hmä_, नोरं
  { {0xe1f00003,0x66010070,0x997d001e,0x3e830035}},	//   حسن_, volk, pāņu_, sītā_
  { {0x645a00c5,0xf41f0029,0x7e7b0028,0x7dd20058}},	//   dsti, jmä_, ttup, _væse
  { {0x799a00b6,0xd2bb0012,0x644516ab,0x3f8d01a0}},	//   _fatw, _عارض_, lphi, reeu_
  { {0x645a0e2a,0x69ca1ba1,0x63ad1ba2,0x6b9b1ba3}},	//   fsti, ckfe, _anan, _haug
  { {0x6b9b05cf,0x2240009b,0xbebd0010,0xe1ff1ba4}},	//   _kaug, _stik_, ncūz, trón_
  { {0xa3dc0037,0x799a0002,0xd5b8001e,0x957c0002}},	//   णों_, _zatw, ajā_, wnąt
  { {0x6ec40003,0x6601004a,0x6b84005e,0x5fa50011}},	//   _متوق, polk, õigi, _ऑफ़ल
  { {0xdce10002,0x6d5c1ba5,0xf50507e8,0x6b9b1ba6}},	//   zglę, órat, _изло, _laug
  { {0x91a90020,0xe1ff000e,0x1c110037,0xdd8e0003}},	//   _quá_, mról_, ़ताल_, _ذوي_
  { {0xdfd20003,0xe1ff000e,0x6fde001e,0x38650031}},	//   جير_, lról_, tūci, álra_
  { {0xf1c2001e,0x78a50058,0x8c1b0009,0xd0070229}},	// [42c0] _pašā_, _erhv, _קופי, тете_
  { {0xdca60001,0x2a57000b,0x08c60264,0x69d50832}},	//   кази, _שבין_, _абон, chze
  { {0xe1ff000e,0xa03a0012,0x05770012,0x44441ba7}},	//   iról_, _تأخر_, ضمنة_, up_
  { {0xaf0a0003,0x6b9b002a,0xfdbd0037,0x799a00b6}},	//   _يقدم_, _caug, ोसॉफ, _satw
  { {0x6b9b1ba8,0xe1ff000f,0x27f8000e,0x98b80073}},	//   _daug, król_, _írni_, tarė_
  { {0x645a0a58,0xdddb001e,0x44441ba9,0x7e691baa}},	//   ysti, lruņ, pp_, drep
  { {0xb0570003,0xf41f004a,0xe1ff000e,0xcdf70009}},	//   نشيط_, ymä_, dról_, _סמלי_
  { {0xb4250012,0x78fb0009,0xd6d90034,0x4ab40011}},	//   _معقو, ופצו, lały_, ुहाव
  { {0x60c70002,0x8fa30001,0xf76f0012,0x765b020d}},	//   zyjm, рање, زاي_, gsuy
  { {0x22460807,0xd6d90002,0x6b82000e,0xab290003}},	//   mpok_, nały_, lfog, _أسفل_
  { {0x7f860003,0x6d480010,0xb8650012,0xcf8f004c}},	//   _للان, rbda, _مانو, _кј_
  { {0x3d1a0037,0x39581bab,0xf7460294,0x645a1bac}},	//   _भरने_, ears_, _редо, rsti
  { {0xe7370a25,0xd6cf0003,0xc2b80024,0x41e70024}},	//   _реч_, _وقم_, вляє_, віва
  { {0x645a1bad,0x5e570009,0x3cfd0011,0xa164004c}},	//   psti, _יידע_, _रुके_, ињск
  { {0xdfd50015,0x61ed0061,0xf80700f4,0xa6170009}},	//   говы, éali, вчан, _שקוד_
  { {0x2d9c1bae,0x889b000b,0x63ad1baf,0x938b0014}},	//   _have_, ובלי, _unan, _цска_
  { {0xa3b60011,0xb4bd0011,0x9715188d,0x2b591bb0}},	// [42d0] जान_, ेन्_, умац, masc_
  { {0xab5d003e,0x6b9b007a,0x9d550003,0x867b0009}},	//   _może, _saug, انات, ורמו
  { {0x20040010,0x201f0010,0xf992000b,0x659401b6}},	//   komi_, ymui_, _פרט_, раху
  { {0xdb040017,0x6b82000e,0x2d9c1bb1,0x3af5003c}},	//   _uniã, gfog, _lave_, лялс
  { {0x200401ff,0x7c2d0002,0x290c003a,0x7bc0088c}},	//   domi_, _miar, _ayda_, _domu
  { {0x6ff3004b,0xd6d90034,0x27e91bb2,0x2d9c1bb3}},	//   tăco, cały_, lian_, _nave_
  { {0xe73908b0,0xdb00006f,0x6b9b0bf8,0xa4d50024}},	//   ней_, _anmä, _taug, _сові
  { {0xdb000026,0xccf2000b,0x7c3a0061,0xc0c80001}},	//   _pomô, _הכל_, _étra, ђује_
  { {0xe1ff000e,0x5a3400be,0x27e9004a,0x51f901d4}},	//   tról_, _внут, iian_, _знаю_
  { {0x7bd6001e,0xb5fb0042,0x808b0012,0xbbcc0011}},	//   īzum, _uvád, _يضاف_, ास्क
  { {0x27e900c6,0x7c2d00b6,0xe1ff000e,0xa3ea00f5}},	//   kian_, _biar, rról_, една_
  { {0x442d007a,0x27e900b6,0xe1ff000e,0xd6d90002}},	//   _jie_, jian_, sról_, zały_
  { {0x27e91bb4,0xe1ff000e,0x7c2d1bb5,0x2f960009}},	//   dian_, pról_, _diar, _תכנן_
  { {0xe29f0028,0x2d9c1bb6,0x4d880012,0x442d1bb7}},	//   _áðu_, _gave_, _لَهُ_, _lie_
  { {0xb5fb000e,0xa3b60011,0xdb190032,0x41090009}},	//   _ováb, जाम_, chwö, גִּ֣
  { {0xb8dc015f,0x442d1bb8,0xd6d90002,0x27e91bb9}},	//   _आप_, _nie_, wały_, gian_
  { {0xd6d90002,0x8fa3010c,0x0d860109,0x8c1b0009}},	// [42e0] tały_, щате, ллан, _אוקי
  { {0x02b70093,0x9f440108,0xb5fd0027,0x27ff048b}},	//   _עליך_, rimé_, dršk, čuna_
  { {0x6d5507b6,0x0b46002d,0xdce3003a,0xb97b0009}},	//   _deza, гнен, _kanı, _אריז
  { {0x9f06000a,0x2897000b,0x7c3e0061,0xd9be0011}},	//   _موجو, _עדכן_, _épre, ्स्ट
  { {0x16030044,0x442d1bba,0x6fca0026,0x15f50037}},	//   रकार_, _die_, _rých, ीकार_
  { {0x6d550ad2,0x69ce1bbb,0xab5b1bbc,0xba3d0030}},	//   _geza, nkbe, lküt, _trůn
  { {0x442d1bbd,0x94790001,0x7dd20028,0x58d400de}},	//   _fie_, _исту_, _gæsa, ройт
  { {0x09d10037,0x5ea40003,0xaa8600f1,0x2d9c1bbe}},	//   _हत्य, لمعل, _zvýš, _save_
  { {0x6b840005,0x6fca014a,0x69ce1bbf,0x57180048}},	//   õigu, _vých, kkbe, ъжия_
  { {0x442d00bd,0xc693000b,0x5d540014,0x06970009}},	//   _zie_, צאת_, шкот, נדים_
  { {0x6fca0026,0xa5b70009,0x7c2d1bc0,0x2d9e0064}},	//   _tých, אליק_, _piar, rdte_
  { {0x69ce110c,0x2d9c1bc1,0xa3ba0011,0x98b10034}},	//   ekbe, _wave_, आउट_, nczą_
  { {0xdce3003a,0x2d9c0010,0xdee3004c,0xdcfc0035}},	//   _danı, _tave_, _лоци, _barī
  { {0x69d805e8,0x7c2d0002,0x26db0009,0x25ba005e}},	//   nhve, _wiar, _אקדמ, _õpl_
  { {0x248d001c,0x69cc0044,0x27e91bc2,0xdcfc001e}},	//   _ćemo_, _तकनी, tian_, _darī
  { {0x6d43003a,0x937b0012,0x6d5a1bc3,0xd4990024}},	//   ınam, _أصغر_, lata, _шрі_
  { {0xb5fd0a48,0x27e91bc4,0x5d551ad6,0x6e2e1bc5}},	// [42f0] pušt, rian_, икат, _bibb
  { {0x442d032b,0x3eb9083c,0x27e91bc6,0xdcfc0035}},	//   _sie_, ästi_, sian_, _garī
  { {0xdce300a2,0x442d1bc7,0x6d5500eb,0x4c570012}},	//   _yanı, _pie_, _veza, اضطر
  { {0xa3df0037,0x6d5a15cf,0x20840012,0x44770009}},	//   धों_, hata, _الَّ, רעאל_
  { {0xbd6b0001,0x93940003,0x6d5a1bc8,0x442d1bc9}},	//   _прве_, إجما, kata, _vie_
  { {0x442d0732,0x6a6c0028,0x90c50198,0x89a80024}},	//   _wie_, _höfð, ибле, лків_
  { {0x7d1c0065,0x8c250003,0x31580003,0x69c11bca}},	//   ýrsl, _نفسه, اجهة_, _vole
  { {0x6d5a1181,0x28b60011,0x57460048,0xda670012}},	//   eata, _अपरि, азъм_, _مائي
  { {0x8db5002d,0xfbd20009,0xe6920012,0x78a80073}},	//   асні, _ותן_, قليد, _erdv
  { {0x69d80052,0x39a4000e,0xdce3003a,0x0d82027f}},	//   chve, tésű_, _sanı, ольн
  { {0x3207002a,0xb8950012,0x5f9506bd,0x7e6d1bcb}},	//   mony_, _خلاع, _виет, hrap
  { {0xcc76000b,0xddc4000d,0x6aa91891,0x8b26010c}},	//   סגרת_, oriţ, _kref, идне
  { {0x6d5a1bcc,0x7e6d0031,0xdcfc0035,0xa3b60011}},	//   bata, jrap, _parī, जात_
  { {0x200b0066,0x3a36000b,0x64a504ad,0xb5fd001b}},	//   _akci_, ירשם_, _вака, krši
  { {0xdce300a2,0xfca80003,0x69ce1bcd,0x6b890248}},	//   _tanı, _مايو_, rkbe, _obeg
  { {0xba3d0030,0x34fa0009,0x645e0a8a,0x32071778}},	//   _průl, _שהקד, vspi, hony_
  { {0xd6cf0003,0xab5b0060,0x32071032,0x7e6d1bce}},	// [4300] وقف_, rküt, kony_, grap
  { {0x7bc40051,0xd9460001,0x4a5b0009,0x32070034}},	//   _hoiu, _њени, _שדיו, jony_
  { {0x7e6d1bcf,0x645e1bd0,0x6aa907ef,0xdcfc0972}},	//   arap, uspi, _aref, _obrą
  { {0x6d5a000e,0xb4250012,0xc1010081,0x07a6004c}},	//   zata, معنو, _lượt_, _тамн
  { {0x6d5a00c6,0x61ea003a,0x98b10034,0xbb3b0009}},	//   yata, tifl, rczą_, דעני
  { {0xceb3000b,0x20660001,0xa37b0051,0x6abb0052}},	//   _ויש_, ађив, riõi, äufi
  { {0xa3c60044,0xc9530009,0x30770012,0x6d5a1bd1}},	//   _एवं_, חמו_, لحية_, vata
  { {0x4c9b000b,0xbfa70015,0x6d5a00b6,0x7bd90052}},	//   _בבלו, атье_, wata, chwu
  { {0x44380163,0xab5b00a2,0x19960001,0xe29702ac}},	//   _hur_, kkür, _вјер, _кат_
  { {0x14ca0015,0x32070002,0xf531000b,0x63a0006f}},	//   выми_, cony_, ּ֥י_, _hamn
  { {0xf1c2007a,0xa3ab01e1,0x4c940014,0x62820b7d}},	//   rašą_, _कोड_, щинс, ltoo
  { {0xc7c70015,0xd5b8001e,0xb8650012,0x44381bd2}},	//   _выше_, mmām_, _داكو, _mur_
  { {0x926b0014,0x0a6b0014,0x3a7400fa,0x6d5a1bd3}},	//   ърна_, ърни_, оляр, pata
  { {0x44380689,0xa2a70037,0xf20700b3,0x7e6d00c1}},	//   _our_, चित्, рямо, vrap
  { {0x6d580039,0x44380e5a,0x55bb0009,0x361b0009}},	//   _ieva, _nur_, _במגו, _שווד
  { {0x63a2000f,0x63a00163,0xb5fd0416,0x32070002}},	//   jdon, _namn, vrši, zony_
  { {0xba3d0013,0x6d580051,0x9df90014,0x79c90012}},	// [4310] _prům, _keva, гнат_, _موظف_
  { {0xeca70046,0x2705001a,0xb9950003,0x63a200c1}},	//   ијен, ồng_, _الدب, edon
  { {0xd49b0098,0x8ca90037,0x31740029,0xf9fc0009}},	//   ъра_, टियो, ňazí_, _בהזמ
  { {0x5b250003,0xb3670014,0x69c50052,0x6d581bd4}},	//   مفضل, ръжк, _hohe, _leva
  { {0xc334000b,0x69c51bd5,0x66640048,0x68fb0060}},	//   קוס_, _kohe, _мърз, ğudu
  { {0x7c380108,0x6fd80066,0x6d581bd6,0x11d90012}},	//   _ouvr, _více, _neva, طوعة_
  { {0x3207003e,0xdcfa001e,0x79950034,0x6fca06dd}},	//   rony_, ietē, iezw, _výcv
  { {0xd0f80093,0x38690864,0xe3b30012,0xe0f80009}},	//   ימות_, čar_, _برس_, יצוח_
  { {0x4438008b,0x8e090015,0x06090345,0x6d581bd7}},	//   _zur_, лнив_, лник_, _beva
  { {0x6d5800a2,0x58870015,0xddc40027,0x7e620159}},	//   _ceva, _выда, oriš, _dvop
  { {0xddcd039c,0xc101001a,0x5f770003,0x6d581bd8}},	//   ktaž, _vượt_, _ناشر, _deva
  { {0xe9f9001a,0xccf20009,0xe1ff0034,0x929d0034}},	//   _trẻ_, לכי_, orów_, _wyłu
  { {0xed4e05cc,0x87070015,0x27ed1bd9,0x6e450012}},	//   _но_, _тяже, mien_, _انتم
  { {0xd5b1000a,0x6d5800bd,0xceb2000b,0xddc4001e}},	//   _رفع_, _geva, _מיד_, kriš
  { {0x27ed0070,0xddd60002,0x3f6a15db,0x7dd20040}},	//   oien_, ysył, ливо_, _sæso
  { {0x6ab70011,0x63e50012,0xddc20034,0xdc280035}},	//   _आपूर, _وسيك, _owoś, rķēj
  { {0x443802b5,0xdfcf0003,0x7546000e,0xdd3c0010}},	// [4320] _sur_, ريك_, _érzé, rąži
  { {0x63a00028,0x27ed1bda,0x7abb0009,0xdd3c0073}},	//   _samn, hien_, _עציו, sąži
  { {0x4420008a,0x7dc0000f,0x27ed1bdb,0x9a250003}},	//   _khi_, _kösz, kien_, _بعين
  { {0x27ed0006,0xda66000a,0x53e5002d,0xd379002d}},	//   jien_, ماتي, оціа, ичі_
  { {0x395c001e,0xc3330009,0x4432020d,0x63a21bdc}},	//   tavs_, פוג_, _miy_, rdon
  { {0xddc4017b,0x7db60012,0x80a40011,0x62821bdd}},	//   briš, _اصحا, किले, rtoo
  { {0x443800bd,0x628203d5,0xa3ca0037,0xf993000b}},	//   _uur_, stoo, ोसा_, פרה_
  { {0x6d41007d,0xb5fd0010,0x44200081,0x2fc00159}},	//   ecla, iršu, _nhi_, njig_
  { {0x20d30020,0x66f80037,0xd0070001,0x63b30042}},	//   ại_, ंपिक_, љење_, šení
  { {0x6d5e0101,0xceb3000b,0x7e9b0009,0x27ed02a2}},	//   napa, פית_, נסיו, aien_
  { {0xab5d003e,0xddcd000d,0x66080504,0x5bb90048}},	//   _możn, luaţ, rodk, алня_
  { {0x44201bde,0x27ed0061,0xa09b000b,0xddc9000d}},	//   _chi_, cien_, _תיאט, pseş
  { {0xddcd000d,0x443200b6,0x6d5e1bdf,0x7bdd0010}},	//   nuaţ, _diy_, kapa, ūruo
  { {0x867b0009,0x2fc60070,0x22440029,0xab5d0034}},	//   _תרגו, _hoog_, ímka_, _nożn
  { {0x84460003,0x999a000e,0x6d5e00b6,0x30d80009}},	//   _اختل, _cipő_, dapa, בַּע
  { {0x44200020,0xc5f8001e,0x69dc0052,0x69c50032}},	//   _ghi_, lnē_, ahre, _wohe
  { {0xa3ac0037,0xe3b00003,0xe7ea0011,0x6b8d020d}},	// [4330] _औफ़_, _أرى_, जोया_, _ibag
  { {0x98a3003a,0x3f57001a,0x6d5e050a,0x657a002a}},	//   sajı_, ầu_, gapa, ngth
  { {0xddcd007a,0x69c50006,0x2bdd0037,0x2369009b}},	//   ptaž, öhem, _मतदा, _kdaj_
  { {0xedb50044,0xe3150046,0xe1ff0002,0x6d4101e3}},	//   _अच्छ, омењ, trów_, zcla
  { {0x27ed1be0,0x9a870024,0x3b09004c,0xfc300012}},	//   vien_, суел, јело_, رحم_
  { {0x44261be1,0x27ed0679,0xddc41715,0x4a5c0009}},	//   amo_, wien_, priš, נדוו
  { {0x79840003,0x6013003a,0x3ea91be2,0xdcfc0002}},	//   سؤول, eçmi, lvat_, _obrę
  { {0x224900b6,0x7a200248,0x27ed1be3,0x17c90337}},	//   _otak_, möte, uien_, ргии_
  { {0xee360047,0xd00e0003,0xee390001,0x06960012}},	//   оны_, خلي_, јно_, قنية_
  { {0x27080020,0x27ed1be4,0x5de5002d,0x3ea9004a}},	//   ởng_, čeny_, іжна, ivat_
  { {0x4420001a,0x22491be5,0xfd110012,0x3ea91be6}},	//   _phi_, _atak_, بجة_, hvat_
  { {0x232a05fb,0x547a0009,0x98170012,0xba3d0030}},	//   иони_, סטרו, _ابطا, _průh
  { {0x539a000b,0x6aad1be7,0x61ee1be8,0xfdfb0011}},	//   בירו, _craf, tibl, ्वास_
  { {0xb21b0058,0x44261be9,0x6aad1bea,0x317e0032}},	//   stæn, zmo_, _draf, ütz_
  { {0x4426007a,0x4420001a,0xf1b2000b,0xe73a022a}},	//   ymo_, _thi_, וסם_, иев_
  { {0xe7370047,0x7bdd0052,0x61ee1beb,0x6aad1489}},	//   жет_, chsu, sibl, _fraf
  { {0xfe720003,0x764d002c,0x85ea0024,0xcf920009}},	// [4340] بدأ_, gpay, адав_, וטן_
  { {0x44d50020,0x2369012e,0x05660024,0x63a41bec}},	//   ó_, _zdaj_, івен, _hain
  { {0x63a4007a,0x3ea90006,0x6d5e13b9,0xa3b60037}},	//   _kain, avat_, rapa, जाल_
  { {0xddcd000d,0xccf2000b,0xe7320012,0x44d50081}},	//   tuaţ, וכב_, _يصح_, í_
  { {0x6d5e0101,0x1a960003,0x63a41bed,0xeab20003}},	//   papa, تجاج, _main, بعا_
  { {0x7d06003e,0x63a40947,0xf2d3000b,0x629a0002}},	//   ększ, _lain, ועד_, łtow
  { {0x6d5c0039,0xd4670015,0xa37b0017,0x62860051}},	//   _iera, _мире_, lhõe, htko
  { {0xef19003e,0xf76f0003,0x6fe80002,0x6d5c1bee}},	//   leży_, ناً_, ości, _hera
  { {0xab5d003e,0x6d5c00c6,0x6fdc0108,0xc5f8001e}},	//   _możl, _kera, _néce, tnē_
  { {0xe5e60003,0x69c80051,0x186a05fb,0x6b8d00b8}},	//   تثبي, ödel, _важи_, _sbag
  { {0x7ae2000f,0x6d5c1bef,0x77660014,0x9d140015}},	//   lzot, _mera, _дълж, ядоч
  { {0x7bc20061,0x69c807c9,0x6fe80002,0xe6c60012}},	//   njou, _hode, kści, _وتشي
  { {0x6fe80002,0x64480061,0x68350010,0x69c81bf0}},	//   jści, _édif, _išda, _kode
  { {0x6fdc0061,0x3eb9006f,0x7c3e0061,0x6d5c1bf1}},	//   _déce, åste_, _épro, _nera
  { {0x6fe80002,0xe5020037,0xe919002d,0x91b20081}},	//   eści, _रुचि_, сові_, _quý_
  { {0xb4c80037,0x63a400d4,0xf7730012,0x3ea9005e}},	//   ोनी_, _gain, باس_, tvat_
  { {0x6d5c00c6,0xa3ab0044,0x3e350003,0x8f9b0009}},	// [4350] _bera, _कोष_, سفار, סימי
  { {0x63a405bd,0x69c81bf2,0x7a200a2d,0x9e090012}},	//   _zain, _node, töte, حيطك_
  { {0x7c3c0036,0xd3710003,0xc19a0009,0x6d5c1bf3}},	//   _curr, فها_, _השתי, _dera
  { {0xf367002d,0x389a0009,0xf2d50009,0xa3e60011}},	//   ітен, _פירנ, ּעַ_, योल_
  { {0x29f6003e,0xfbd4000b,0x67ba000b,0x77ba000b}},	//   kład_, ותף_, _המרק, _המרח
  { {0x44d5001a,0xe7a30037,0x614502e3,0xfa780009}},	//   ý_, _खोजप, чека, קעות_
  { {0x6e3d002a,0xdd1c0029,0x2284000e,0xf958000b}},	//   _husb, yšši, zök_, חסות_
  { {0x6286003e,0x61c80037,0x9f400028,0x78fc000b}},	//   ytko, _रक्ष, nnið_, ילופ
  { {0xfe710003,0xbb840003,0x644a0073,0x6d5c15ef}},	//   ردة_, _تلقي, _atfi, _yera
  { {0x6fdc0108,0x7f5d0061,0x63a41bf4,0xf2560009}},	//   _réce, _lesq, _sain, _זֹאת_
  { {0xcb09015a,0xb21b0058,0x63a41bf5,0x9f400097}},	//   _על_, rtæl, _pain, knið_
  { {0x62860f33,0x2904003a,0x69c3009b,0x22841b3c}},	//   ttko, şmak_, ljne, tök_
  { {0x7dd3003a,0x98a7003a,0x7f3a007e,0xdcfa0010}},	//   _kısı, manı_, _התנג, ketė
  { {0x22840074,0x98a70060,0x6592004c,0x853c0073}},	//   rök_, lanı_, _заљу, ndėl
  { {0x22841bf6,0x6e3d0052,0x9f400028,0x291e006f}},	//   sök_, _ausb, fnið_, åta_
  { {0xe1ff0002,0xe89b003a,0x2d82000e,0x7e641bf7}},	//   wrót_, şağı, őket_, tsip
  { {0x6d5c00c6,0x2216002d,0x2441001a,0x7c3c0614}},	// [4360] _pera, _нфор, _hóm_, _surr
  { {0x6907000e,0x93250012,0xf5e50024,0xa37b005e}},	//   érdé, _غرين, мієм, liõp
  { {0xc953000b,0x3157000b,0x98a7003a,0xa9570009}},	//   _אמת_, _מיין_, kanı_, _מייק_
  { {0xa3e60044,0x69c8012e,0x00bb000b,0x7bc20025}},	//   यों_, _sode, _המטמ, ujou
  { {0x7bc2004a,0x6fd505b1,0x6d5c1bf8,0x69c81506}},	//   rjou, _václ, _tera, _pode
  { {0x27e0002c,0x98c601b6,0x7bc210a6,0x09e30842}},	//   lhin_, зсил, sjou, ночн
  { {0xec770001,0x65611bf9,0x69c8017b,0x76490060}},	//   _нпр_, dalh, _vode, _çeyr
  { {0xdfd0000a,0x28970093,0x27e00101,0xf093000b}},	//   ئية_, פדפן_, nhin_, גנה_
  { {0x27e00006,0x4424008b,0x69c8067c,0xa3c60011}},	//   ihin_, _ihm_, _tode, _एवज_
  { {0x69da0016,0xba3d0066,0xf653000b,0x27ff017b}},	//   _ulte, _prův, עצת_, čuni_
  { {0xb4c80037,0x395e0070,0x53990015,0x40560003}},	//   ोने_, _iets_, овня_, _رئاس
  { {0xddc9000d,0x7dcd0029,0x883b000b,0x65610051}},	//   treţ, _súst, _התאו, aalh
  { {0x65610149,0xbae50012,0xf62a0024,0x853c0073}},	//   balh, ذكسي, _ліки_, ldėm
  { {0x398f003a,0xa4100066,0x3ea20028,0xd6cf0012}},	//   cısı_, ětší_, æktu_, _حقه_
  { {0x7f5d05ab,0xa8490003,0xddc40010,0xb21b0028}},	//   _pesq, تلزم_, asiū, ltæk
  { {0x1d170093,0x2d8c00bd,0x34fb000b,0xbd17000b}},	//   _מקור_, lfde_, _להוד, _מחוז_
  { {0x6d450163,0x69c30002,0x9f400097,0xce940b2b}},	// [4370] tcha, yjne, rnið_, натъ
  { {0x06140047,0x4df4002d,0x9f400028,0xc3340009}},	//   едую, няєт, snið_, _אופ_
  { {0xf8d10037,0xd9180109,0xc1720009,0x0dc80472}},	//   _हथिय, _нью_, _בחי_, чути_
  { {0x6d450518,0xd8280024,0x4c9b0009,0xbddb0025}},	//   scha, _ніяк_, מבבו, _suèd
  { {0x398f00a2,0xe8100037,0x59d10037,0x98a70060}},	//   yısı_, ावना_, _सकार, vanı_
  { {0x2d9a007d,0x1308002d,0xe7d5003a,0xf9c7027f}},	//   cepe_, чній_, _yığı, ящен
  { {0x98a204ad,0x395e1bfa,0xb4c80011,0x65610018}},	//   вище, _dets_, ोनो_, valh
  { {0xd8dc0009,0xb0680012,0xe5340024,0x7ed50024}},	//   מקור, أصول_, _чесь, діоч
  { {0x65611bfb,0xc91a0037,0x395e0054,0x70ba0011}},	//   talh, _धर्म_, _fets_, _उप्ल
  { {0x75e000a2,0x395e002a,0x853c1bfc,0xb5fb0031}},	//   _gözd, _gets_, bdėm, _sváj
  { {0xddc9001c,0x398f003a,0x2a690051,0x44240032}},	//   greš, rısı_, _avab_, _yhm_
  { {0xc1690093,0x30780012,0x656103f0,0x6fd81bfd}},	//   _כח_, _رحمة_, salh, _cícl
  { {0xe60e0098,0x65610017,0x398f003a,0xef1f0051}},	//   _ад_, palh, pısı_, üüd_
  { {0x2441001a,0xc58e001a,0x75e0000e,0xdb06000e}},	//   _tóm_, _hồng_, _köze, ndké
  { {0x27e01a91,0x7c241bfe,0x7e7b0028,0x7dc40012}},	//   thin_, _thir, luup, _ستوك
  { {0x6ca40012,0x6d0800af,0x69c11bff,0x000000c4}},	//   _أصول, _מִפַ, öler,
  { {0x27e00052,0xa3ab0037,0x32460012,0x321a0012}},	// [4380] rhin_, _कोइ_, _تنخف, _ويعد_
  { {0x270c0020,0x6fdc0061,0xc58e0081,0x27e01c00}},	//   ớng_, _méca, _lồng_, shin_
  { {0xe73a0098,0x91bb0009,0x600a004c,0x3b860635}},	//   _мен_, _ומיי, _мном_, длег
  { {0xd36f0003,0x799c0052,0x7e7b0051,0x395e1c01}},	//   لهم_, lerw, kuup, _sets_
  { {0xa3e30037,0xddc904d2,0xa2a40011,0x91d20011}},	//   फोट_, zreš, _चैम्, _हवाई
  { {0x7c2b0005,0xc333000b,0x298a0024,0xee370048}},	//   amgr, דוד_, ісло_, _оня_
  { {0xe3660001,0xf993000b,0x799c0002,0xd90f0024}},	//   _окви, דרו_, ierw, ть_
  { {0x98a30001,0x799c1c02,0x3f801c03,0x776401a0}},	//   тиће, herw, ngiu_, naix
  { {0xe2460003,0xc6f8002d,0x96340695,0x7c23004b}},	//   _آخري, яних_, нниц, înre
  { {0x7dcd02d1,0xb21b0065,0xc6f70047,0x3ebb0009}},	//   _búsq, rtæk, ьных_, קציב
  { {0x0577000b,0xd577000b,0x75e0034f,0x799c158b}},	//   וגים_, ותיה_, _közb, derw
  { {0x50650012,0x6fb30012,0x7e761c04,0xc4f70012}},	//   _أطلق, _لمما, kryp, بعًا_
  { {0x5187007c,0xf743002d,0xfd65001a,0xf7d70009}},	//   мува, _речо, _chuỗ, _קודש_
  { {0xa3ab015f,0x2014003e,0x91780020,0x7a20004a}},	//   _कोई_, ścią_, _bởi_, töta
  { {0x8637000b,0x3cfa0037,0x757b0009,0xfe370009}},	//   _קרוב_, ्थों_, _וטופ, _קרוי_
  { {0x14cb0037,0xf7730012,0x69de0227,0x5f94112d}},	//   ाहरण, ضار_, _elpe, кист
  { {0x644e0039,0xee3f001a,0x8cc60037,0xd6db0024}},	// [4390] _atbi, _quý_, ाहको, цтв_
  { {0xdce50029,0xd5b8001e,0x11550024,0xddcd004b}},	//   rehľ, mmās_, _якою, draţ
  { {0x61f5003a,0xc156000b,0x77641c05,0x31560009}},	//   mizl, _אשתו_, baix, _איתן_
  { {0x94bf0037,0xe8df001a,0x64410061,0x61f50060}},	//   _एपीआ, _niềm_, _élim, lizl
  { {0x4374002d,0x9f8a0051,0xdb0001d7,0x8c1c0009}},	//   туєт, tööd_, _famí, קודי
  { {0x61f500a2,0x27ff048b,0x6fdc0061,0x7a7c000b}},	//   nizl, čunu_, _réca, קרוס
  { {0x5fd30037,0x8cd60011,0xdd030073,0xa2d10011}},	//   _सवाल, _मॅपो, _įrėm, _डॅस्
  { {0x01380093,0x7e7b0065,0xdb000066,0x799c0002}},	//   ורות_, tuup, _zamí, zerw
  { {0xf3900020,0xddcd000d,0xcdf50015,0x98c4001e}},	//   _bảng_, craţ, ечны, ētām_
  { {0x22b80003,0xab620051,0x69b90037,0x3ead1c06}},	//   _تدفع_, _üüri, _एचटी, rvet_
  { {0xd5e80003,0x3236000b,0x3ead009b,0x799c0a34}},	//   بعين_, _נטען_, svet_, verw
  { {0x6d4a0108,0xff530003,0x7dd20028,0x90560009}},	//   _effa, _شخص_, _hæst, _נבנו_
  { {0x4a430014,0xe6a80066,0x2bc70037,0x27ff169c}},	//   лняв, _příš, _रचना, mnun_
  { {0x63a90051,0x69c10051,0xdb0f000e,0x19b9002d}},	//   _laen, ölep, ájáv, мусь_
  { {0x9f9d0028,0x98aa003a,0x6606000e,0x4dda0009}},	//   tæðu_, tabı_, ékke, _מחסו
  { {0xdfd20003,0x63a9009b,0x27ff1c07,0x799c0679}},	//   دير_, _naen, nnun_, serw
  { {0x27ff004a,0xd707011d,0x7e691c08,0x9bfb0009}},	// [43a0] inun_, енте_, nsep, _מהקט
  { {0x98aa00a2,0xdcee003a,0x7dd21c09,0x63bb1c0a}},	//   sabı_, _sabı, _næst, _anun
  { {0x515b000b,0xaa090003,0xbddb01a0,0x27ff0097}},	//   _מכיו, _تزيل_, _suèc, knun_
  { {0xf8b3000b,0xddcd000d,0xd3a5002d,0x6fd5052e}},	//   _עשר_, traţ, кріп, _fáci
  { {0xa3e60044,0xdbc70005,0x91be0011,0xddcd004b}},	//   योग_, _tööl, _एचआई, uraţ
  { {0x2000004b,0x68050073,0xe8fa0009,0x02430012}},	//   lnii_, mėda, ּהֵן, دَوَ
  { {0xde03106a,0x644e006f,0x27ff0028,0x68050010}},	//   _спри, _utbi, fnun_, lėda
  { {0x6c360003,0x28b30011,0x07040011,0x27ff0097}},	//   _أفرا, ुमति, _रखाव_, gnun_
  { {0x8f9b0093,0xd5b0000a,0x59ab0011,0x4375004c}},	//   ליקי, لفة_, _टोकर, _јуст
  { {0x7dd20058,0x63a9009b,0xa96a0048,0x82970009}},	//   _gæst, _zaen, _хижа_, _אדמס_
  { {0x8afd0066,0xe8df001a,0x6d48001e,0x7fd6002d}},	//   _veře, _tiềm_, rcda, _піді
  { {0x7985008b,0xb4fb0009,0x9cd70009,0x32110034}},	//   _schw, לפיי, גוטה_, wozy_
  { {0xf6d30012,0xf3900081,0x9e730012,0x03d70009}},	//   _مزود, _tảng_, _مهنت, תוכם_
  { {0x68050010,0xddcd0010,0xf3900081,0x3ea6008e}},	//   dėda, kraš, _uảng_, _isot_
  { {0x3d1f0044,0x4e17000b,0xc60c0011,0x2d9e1c0b}},	//   _भरें_, _רחוב_, सकीय_, mete_
  { {0xe8df001a,0xddcd0010,0x6bd70012,0x6fdc0025}},	//   _hiểm_, draš, _ستعر, _méco
  { {0xe8df0020,0x47350048,0xc91d0011,0xddcd0073}},	// [43b0] _kiểm_, тнас, _फर्म_, eraš
  { {0x02fc0093,0xaa640014,0x395405b1,0x8afc0009}},	//   _מלחמ, _стък, časí_, _מהחי
  { {0x75e000a2,0xf1bf001a,0xdb1e0025,0x5d840012}},	//   _sözc, _đá_, _évêc, المل
  { {0xe8d6015a,0x6d580028,0xa856000b,0x94740012}},	//   _יותר_, ðvar, _שירה_, ادلا
  { {0x63a90051,0xf9910003,0xddcd0010,0xe9ce00dc}},	//   _vaen, لبث_, araš, ак_
  { {0xbef60009,0x22890031,0xe9d80024,0x44291c0c}},	//   _יצרו_, rúk_, нкі_, _lha_
  { {0x91e20055,0xddc90034,0x79ac0009,0x27ff0097}},	//   роще, ypeł, לֹהַ, tnun_
  { {0x6fdc0108,0x7e690051,0x44291c0d,0x27ff0c6e}},	//   _déco, tsep, _nha_, unun_
  { {0x27ff0028,0x6fdc01c5,0x1ef90012,0x44dc0081}},	//   rnun_, _técn, بعثة_, ẻ_
  { {0x4429003a,0x7e691c0e,0x6fdc0025,0xc6920009}},	//   _aha_, rsep, _féco, סאי_
  { {0xd7950012,0x5f950012,0xeb9a0012,0x2d8b0034}},	//   _للاخ, _للائ, وضحت_, ęce_
  { {0xc209000b,0x2056000b,0x44291c0f,0xc2c60012}},	//   _וה_, _ייעל_, _cha_, نيجي
  { {0x44dc001a,0x9f910028,0xd24f0003,0x2d9e1c10}},	//   ả_, _káþ_, ينَ_, bete_
  { {0x2d9e0628,0xc27a000b,0x64c50012,0xdb0001e3}},	//   cete_, ורשי, _ليتل, _jamá
  { {0xc9520009,0xa9880009,0x98b80035,0xfce50264}},	//   שמל_, עָשִ, mbrī_, _шоко
  { {0x2000000d,0x6443000d,0xc0030001,0x65630623}},	//   unii_, _iuni, апск, _henh
  { {0x36670098,0xadf80011,0xa3d50011,0x44250012}},	// [43c0] като_, ुवचन_, ाउन_, _حروف
  { {0x67fb0006,0x6805007a,0x2fcf09d9,0xc333000b}},	//   täjä, rėda, _logg_, _דוח_
  { {0x80a10037,0xd5af0012,0xa3c90011,0x7c3b0455}},	//   _कैले, تفل_, लॉक_, _biur
  { {0xc5e9000b,0xad250003,0xddcd0010,0xdb0411ec}},	//   חד_, اركو, rraš, _unió
  { {0x6fdc0061,0x2d9e003a,0x64430ced,0xa2940024}},	//   _décl, yete_, _luni, уалі
  { {0x65630149,0xddcd1c11,0xcad7000b,0x159a0012}},	//   _nenh, praš, כונת_, _تنسخ_
  { {0x75e0003a,0x98c30014,0x67fe0035,0x7aed0097}},	//   _göza, исъл, līji, úatr
  { {0x7c3b1017,0xd6da0055,0xdce10064,0x69c51683}},	//   _giur, дто_, galč, öher
  { {0x68250002,0x99a4000e,0x2bab0011,0x67fe0035}},	//   wódc, őtől_, _घोटा, nīji
  { {0xc1d10037,0xdcfa001e,0xf77f003a,0xdb0c0051}},	//   _सकेग, egtā, _ilçe_, öhõi
  { {0x7d7b000b,0x9dd7000b,0x11d70003,0x69dc1b2b}},	//   וניו, דויק_, _جولة_, dkre
  { {0x644300c6,0x65630070,0xa7850012,0x69dc1c12}},	//   _duni, _eenh, _مشهو, ekre
  { {0xa3c90037,0xf413000b,0x44290058,0x929d0034}},	//   लॉग_, שפר_, _vha_, _były
  { {0xc333000b,0x67fe001e,0x64431c13,0x06970009}},	//   יור_, dīji, _funi, _סדום_
  { {0x629a007d,0x859b000b,0x656800b6,0xe9180024}},	//   ătoa, _חשוו, madh, ворі_
  { {0x58d4002d,0xf53701b0,0xf3f00012,0x69dc0034}},	//   шост, _בנוי_, _وأي_, akre
  { {0x6e3c003a,0x6fdc0061,0x3d950083,0x02be0011}},	// [43d0] _birb, _récl, лиар, ्होन
  { {0xf41f03fc,0x3f730020,0x8d740003,0x2d870d33}},	//   llä_, ệu_, لاما, üne_
  { {0xdb1d0005,0x6e3c0010,0x31670052,0x515a0009}},	//   rksõ, _dirb, vanz_, _אכתו
  { {0x2d87003e,0x63ad0051,0x50da0009,0xbf150012}},	//   żne_, _jaan, _נקרא, _موجب
  { {0x60080093,0x31670052,0xdb000066,0xdce1009b}},	//   _יִשְ, tanz_, _pamá, valč
  { {0x7c290036,0x7d1c0065,0x94770012,0x2006008e}},	//   _wher, _fyrs, _لدرا, _ajoi_
  { {0x3da40098,0x7c290742,0x2edb0037,0x28a60037}},	//   _тряб, _ther, यन्त, _कैदि
  { {0x65630149,0xfe790066,0xa3ab0011,0x7c2908ca}},	//   _senh, trů_, _कोच_, _uher
  { {0xee390098,0xa3d4003c,0x7e6d1c14,0xc99b0012}},	//   нни_, _тотч, nsap, _يخطط_
  { {0x6568000e,0xcc750009,0xe5710012,0x6fd80018}},	//   gadh, ְעָה_, حطة_, _víci
  { {0xd0840015,0xe3660015,0x35c80011,0x65630018}},	//   _вычи, лкни, ाउज़, _venh
  { {0xf1a9000b,0x61e60010,0x185a0009,0x46b50012}},	//   _מס_, _įkli, _נכנע, _محتس
  { {0x65630149,0x6ec40012,0x92f60024,0xadbd0024}},	//   _tenh, _نتوق, учні, _надi
  { {0x7eb6000b,0x69dc0010,0x7bdd0038,0x2019013d}},	//   _תהסס_, ukre, aksu, _aksi_
  { {0xb21b00c5,0xe0d5007c,0xdb000052,0xc0e306a5}},	//   kræf, ають, _unmö, борк
  { {0x63ad0101,0xdce70066,0x67fe001e,0x8c43003a}},	//   _gaan, ůměr, tīji, ışla
  { {0xd0070015,0x25a10052,0x7e6d002c,0x562a003c}},	// [43e0] уете_, fehl_, gsap, ежам_
  { {0xcf25000a,0xe9a60001,0x67fe001e,0x2d851443}},	//   شرقي, _саоп, rīji, ngle_
  { {0xb33b0149,0x7656004a,0x629b004a,0x67fe001e}},	//   meça, spyy, _apuo, sīji
  { {0x130a003c,0x8afd0030,0xb5fb0030,0x6e3c0032}},	//   нней_, _seřa, _svát, _wirb
  { {0x853c0073,0x7e6d0031,0x61f81c15,0x2327004c}},	//   ldėt, csap, tivl, гоци_
  { {0xf126002d,0xd9f60037,0x7c660012,0x9d4309e8}},	//   льйо, ुचित_, _مارل, _герд
  { {0x20190006,0x361b000b,0x660b000e,0x853c0010}},	//   _yksi_, _נולד, égke, ndėt
  { {0x61d10037,0x9f490028,0x27e20028,0xd8b70012}},	//   _सक्ष, nnað_, ókn_, ادوا_
  { {0x73060014,0x63a2002a,0x98ae0060,0x420a004c}},	//   _спаз, meon, rafı_, _знао_
  { {0x211a0003,0x929b0009,0x0ae90012,0xadf40024}},	//   _كتاب_, _אימת, _شرقي_, рпош
  { {0x63ad0101,0xdb040065,0x4e17000b,0x7c660003}},	//   _paan, _snið, רחיב_, داخل
  { {0x53350406,0x201f0017,0xccf3000b,0x6825000e}},	//   иент, clui_, מכת_, lódn
  { {0x2d980d04,0x7bdd1c16,0x7e560560,0x11d90012}},	//   _obre_, rksu, _стец, نوحة_
  { {0x3da30048,0x3eb90040,0xe7370048,0x7bdd005e}},	//   _гръб, æste_, _сеч_, sksu
  { {0x9f490065,0x91780020,0x8898000b,0xe919002d}},	//   fnað_, _mời_, כֹּה, тові_
  { {0x91780020,0x94730003,0x0ea80037,0x9f490028}},	//   _lời_, _ادوا, _कनाड, gnað_
  { {0x311b0044,0xb33b0017,0x8c43003a,0xdab90003}},	// [43f0] _पुनः_, beça, ışma, _شهدت_
  { {0x6b8901a2,0xf402000d,0xa2270012,0x7bc00032}},	//   _sceg, hiţă_, _حربه, _anmu
  { {0x67fe0039,0xd3710003,0x8d740003,0xd6d90002}},	//   līju, قها_, صالا, zył_
  { {0x7851001e,0x485a0009,0xa85a0009,0x9f4b008e}},	//   _jāve, _שכרג, _שדרכ, ämät_
  { {0xb5fd0010,0x75e0000e,0xe8df001a,0x2ddb0012}},	//   aršy, _közl, _kiệm_, _كبسة_
  { {0x27e90101,0x867a000b,0x291e006f,0x7e7b003a}},	//   lhan_, _ברשו, _byta_, vrup
  { {0xc0e5005c,0x2258009b,0x5dc8000b,0x3158000b}},	//   ройк, _črke_, _עֶשְ, ניהן_
  { {0xccf2000b,0x7df40002,0x5ea50003,0x201f000d}},	//   _וכל_, yńsk, لمبل, ului_
  { {0xda780014,0x6aa9002a,0xba740012,0x6fdc0025}},	//   _бях_, _usef, _هالت, _méch
  { {0x67fe0039,0xdcf500a2,0xe8df001a,0xab5d0002}},	//   dīju, _hazı, _niệm_, _tożs
  { {0x1d0900f5,0x27e90376,0x84060024,0x63f60012}},	//   тени_, khan_, ипож, لأحر
  { {0x672e000f,0xca290009,0x33f60024,0xddc40073}},	//   önjü, _חם_, рчос, isiš
  { {0xe9ff0020,0x27e900b6,0xfc49001a,0xaa46161c}},	//   _luận_, dhan_, _bậc_, регл
  { {0x442d0149,0xd9e50037,0x35c90037,0xca350009}},	//   _lhe_, कसित_, राफ़, ינָה_
  { {0x67e30051,0x7a200052,0x291e0028,0x853c0010}},	//   _sõja, nöti, æta_, udėt
  { {0x91780020,0xd7060014,0xf1060011,0x2fcd001b}},	//   _mới_, азби, _रशीद_, njeg_

  { {0x8d660047,0x67fe001e,0x9f490028,0x6fdc0061}},	// [4400] ивае, cīju, rnað_, _déch
  { {0x957c003e,0x75e0003a,0xb21b11b6,0x27e91c17}},	//   wiąz, _gözl, græd, ahan_
  { {0x3eb9008b,0xb97b000b,0x76630066,0xdcf5003a}},	//   _erst_, _בניי, _čtyř, _bazı
  { {0x442d034e,0x61fc00a2,0x32180002,0x6b490009}},	//   _che_, lirl, lory_, ְרוּ_
  { {0x31c60098,0x443f0054,0x68250031,0x853c0073}},	//   искв, _diu_, tódn, ndėr
  { {0x27e00006,0x442d0052,0x61fc1c18,0x291e0034}},	//   lkin_, _ehe_, nirl, _pyta_
  { {0x07e60001,0x9965002d,0x18760009,0x759b0009}},	//   ицим, стіл, ׁעַר_, _שילח
  { {0x27e00006,0x10130003,0xdb000029,0x61fc0225}},	//   nkin_, يبيد, _pamä, hirl
  { {0x61fc003a,0x2606002d,0xdcea003a,0xdb7b0009}},	//   kirl, ичог, _ınız, _שנמכ
  { {0x7c221c19,0xa3b60037,0x7c2d1c1a,0x06970009}},	//   llor, ड़ाव_, _shar, סדים_
  { {0xdcf500a2,0x2db70009,0xc8ca0012,0xdce10035}},	//   _yazı, בלין_, _جوان_, talā
  { {0x67fe0039,0x75e0003a,0xa2b30011,0x90e50012}},	//   tīju, _sözl, इटल्, _اسكن
  { {0x6d5c003a,0x06540003,0x61fc0028,0x4425001e}},	//   ırab, _انتح, firl, ēl_
  { {0xd9f80037,0x67fe001e,0xfe9b000b,0x32181c1b}},	//   ्चित_, rīju, _סיומ, gory_
  { {0x6c84000a,0x98480098,0x67fe0039,0x04c70012}},	//   _العم, ията_, sīju, _نووي_
  { {0x0d3b000b,0xe53b000b,0x653b000b,0x27e900b6}},	//   _בגוב, _בתור, _בעוד, uhan_
  { {0xb33b0017,0xd9f80037,0x443f0054,0x61fc1c1c}},	// [4410] meço, ्चात_, _riu_, birl
  { {0x442d0036,0xd657000b,0x3eb9009b,0x915e001a}},	//   _she_, יימת_, _vrst_, _nằm_
  { {0xfa34000a,0x72340003,0x68080066,0x442d001a}},	//   _بريد, _بريط, vědn, _phe_
  { {0x98a1001a,0x9f910028,0x645a0010,0x6280000e}},	//   _nghĩ_, _náð_, ipti, ámog
  { {0x479a000b,0xd5b1001a,0x6fd81209,0xfaa70434}},	//   _גירס, hóa_, _víct, ршен
  { {0xbf36000b,0x7a20004a,0x2a580009,0xe1ff0034}},	//   _לארץ_, töti, סבון_, rsów_
  { {0x442d1c1d,0x6ce4007c,0x39780024,0xdb1b0097}},	//   _the_, _діте, рсію_, _inuí
  { {0x9178008a,0x64400010,0x321812d8,0x40940024}},	//   _với_, _gimi, zory_, юріт
  { {0x19590015,0x501c0009,0xfe710012,0x6e920012}},	//   _базы_, כוהו, أدب_, كليا
  { {0x91780020,0x3f77001a,0xa2c60037,0x69c10bf8}},	//   _tới_, ểu_, ामस्, _unle
  { {0x644112f3,0xddc70031,0xa3ae0011,0xdca500a6}},	//   _élis, áműz, _कसम_, щани
  { {0xfeb90012,0x32180034,0xb035004c,0xc7b40012}},	//   _ماتت_, wory_, _унеш, _وصنع
  { {0xddcd0333,0xdfb80003,0x61fc1c1e,0x32181c1f}},	//   mpaņ, _خالص_, tirl, tory_
  { {0x6d430101,0x6d5c003a,0x6fdc0061,0x5fc50037}},	//   _ugna, ırac, _réci, वावल
  { {0x25a50028,0xc8b50015,0x27e005a2,0x48e30048}},	//   mell_, осты, tkin_, порв
  { {0x999a0066,0x4759003c,0xb7da0012,0x10090012}},	//   _tipů_, ируя_, دورا_, لتقى_
  { {0xf413000b,0x7bc4002c,0x27e01c20,0x62800031}},	// [4420] _מפה_, _iniu, rkin_, ámod
  { {0xc9aa0063,0x63a61c21,0x27e01c22,0xa2f70009}},	//   _свое_, lekn, skin_, _למפה_
  { {0xec7a0046,0x7bd6003a,0x3ea9002c,0x628601a5}},	//   упе_, _koyu, awat_, luko
  { {0x32070002,0xb09b000b,0x68080066,0x28bd0011}},	//   enny_, _גיטר, vědo, ्मनि
  { {0x8c1b000b,0xeafa0003,0x9f910028,0x3d180011}},	//   נוני, درات_, _ráð_, _बुरे_
  { {0xd46a0012,0xca970009,0x9a670012,0x25a500b0}},	//   _محرم_, מדני_, حمول_, jell_
  { {0xddcd0034,0x915e0081,0xdce70034,0x935a004c}},	//   yraź, _cắm_, _odję, _брзу_
  { {0xa857000b,0x628603d5,0xdb06006f,0xa8470012}},	//   זיקה_, kuko, odkä, حليم_
  { {0xe9ff0020,0xf2df000d,0xc7b30009,0xf1a80011}},	//   _quản_, ncât_, לבה_, ग़ान
  { {0x29f2001e,0x4498002d,0x2d99000e,0x78bc0017}},	//   iņas_, авою_, ősen_, _árvo
  { {0x7bd600a2,0xd4970015,0x25f00037,0x1dc90037}},	//   _boyu, бря_, _इतनी_, रातत
  { {0xe6c80037,0xc4d3000b,0xac190109,0x853b0009}},	//   रमाङ, לגת_, рому_, טגיי
  { {0xb33b0017,0x62860051,0x9eda0003,0xa3d00011}},	//   reço, guko, _حذاء_, _वचन_
  { {0x0737000b,0xe677000b,0x2d570015,0xeab1000b}},	//   _האדם_, _פתוח_, _лишь_, וֹל_
  { {0xba3d0066,0xf2df000d,0x80780009,0x26150011}},	//   _průz, ecât_, יְּה, नकरी_
  { {0xa8570009,0xb5050012,0x00570009,0x07090012}},	//   מילה_, _بظهو, משלת_, ليزي_
  { {0x75e0000e,0x9df905f8,0x95c50012,0xe3b00012}},	// [4430] _közh, анат_, ييره, _سري_
  { {0xdce7003e,0x0657000b,0x3ea90002,0xbc84001a}},	//   _zdję, ציבך_, rwat_, ưởn
  { {0x2127001a,0xfc49001a,0x9626001e,0x59960009}},	//   _ánh_, _lận_, diņā, _וכתב_
  { {0x78fa0093,0x60da0051,0x6abb0028,0x1d340024}},	//   _כפתו, ätme, _pruf, їнця
  { {0xa9690001,0xf42a008e,0xdce90060,0x6a850024}},	//   аила_, lvää_, ınıf, ілка
  { {0x51870047,0x20090010,0x0dcb077e,0x828c0009}},	//   суда, lnai_, _суми_, רְאֶ
  { {0x25a503eb,0xddc90cc7,0xf9940009,0x20090073}},	//   vell_, trež, פרק_, onai_
  { {0xb068000a,0x6abb1c23,0xfc490081,0x7a200031}},	//   حصول_, _truf, _bận_, lött
  { {0xfc49001a,0x7bcd001e,0x7a540003,0x4ec5002d}},	//   _cận_, ķaud, _فضلا, ійов
  { {0x69c50028,0xceb40009,0x661a001b,0xb33b0060}},	//   _nnhe, ליפ_, gotk, reçl
  { {0xf9900012,0x75e00060,0x2009016d,0xc3290009}},	//   _سبل_, _sözk, knai_, _סו_
  { {0x62861666,0xeaa70003,0x59c70011,0x68250031}},	//   tuko, وع_, लावर, zódj
  { {0x8c1a0093,0x96e80001,0xf7700003,0x8df50012}},	//   שורי, мaну_, _سان_, _وستص
  { {0x8236000a,0xfce500be,0x8f36000b,0x27ff00b6}},	//   ترجا, _моло, _ואנו_, liun_
  { {0x62861c24,0xa06a0048,0xd94300db,0xd5b80035}},	//   suko, раба_, дери, klāj_
  { {0x7bc4000d,0x2475001e,0x69c50846,0xf8b20009}},	//   _uniu, mām_, _enhe, ושל_
  { {0x44201c25,0x26360002,0x2475001e,0x29f60034}},	// [4440] _iki_, _głos_, lām_, cław_
  { {0x7870000f,0x8d5a0148,0x78550073,0xe8df0081}},	//   _jóvá, ршат_, _sąve, huốc_
  { {0x24750039,0x7643046c,0x136a0001,0xdd8f0003}},	//   nām_, _miny, ашли_, ضون_
  { {0x76430101,0xdb4d0009,0x27ed0159,0x03260662}},	//   _liny, ְעוֹ, jhen_, оден
  { {0x539b000b,0x05a90037,0xa9230066,0x599a0009}},	//   שינו, क़ाब, ížno, ֹשֶׁ
  { {0x764301e5,0x24750039,0x27ed0052,0x14c90011}},	//   _niny, kām_, ehen_, िमाण
  { {0x24750039,0x44200e64,0xd943004c,0xe78605d4}},	//   jām_, _oki_, мељи, оупо
  { {0x24750039,0x30170003,0x7df40002,0xa3ce0011}},	//   dām_, يتية_, ańst, राफ_
  { {0xa3ce0044,0xdee60012,0xceb30009,0x644a1c26}},	//   रान_, تأثي, ֥ית_, _sufi
  { {0xfc490020,0x6fdc0108,0x44f4002d,0xf42a004a}},	//   _vận_, _récu, зпос, yvää_
  { {0x656a0065,0x2475001e,0x764300b6,0x6fdc0fc9}},	//   _vefh, gām_, _diny, _sécu
  { {0x27ed032b,0xfc49001a,0x7a20012b,0x27ff000d}},	//   chen_, _tận_, zött, ciun_
  { {0x442000b6,0x7a20004a,0x53440048,0x44261557}},	//   _dki_, yött, дхра, ilo_
  { {0x24750039,0xddc3002d,0xadb70012,0x6fdc0025}},	//   bām_, _обчи, _وهنا_, _vécu
  { {0x64580119,0x29f60002,0x2475001e,0xdcf80060}},	//   _utvi, sław_, cām_, _tavı
  { {0x35e00037,0x907b000b,0x2d8c0070,0x7f070024}},	//   _पकड़, יטלי, lgde_, оїзд
  { {0xdce30039,0xc7d7000b,0x442600f1,0x7a20000e}},	// [4450] _ienā, קומי_, dlo_, tött
  { {0xdcbb034d,0x44261c27,0x2d8c1c28,0x61ee0032}},	//   ище_, elo_, ngde_, chbl
  { {0x2fc6001b,0xf9920009,0x2d8c0227,0x44391c29}},	//   _onog_, _ארי_, igde_, oms_
  { {0xc4d30093,0xfc300012,0xeab10012,0xa3ce0011}},	//   וגע_, نحن_, فعت_, राय_
  { {0x59df01e1,0xa756000b,0xeab30003,0xd5b8001e}},	//   _नकार, _משרד_, بعض_, glāk_
  { {0x7f3a0214,0xda5c0009,0xa9660048,0x81c7003c}},	//   _לערו, סכול, пиша_, ющее
  { {0xa3ce0037,0x6825000e,0xc19c0009,0x6282005e}},	//   राम_, lódi, ישגי, aroo
  { {0x2475001e,0xf7710003,0x44390027,0xa2950024}},	//   vām_, راب_, jms_, _набі
  { {0xeab00012,0x6d5c0060,0x76431c2a,0x62821bfd}},	//   _لعل_, ıran, _piny, croo
  { {0x24750039,0x4439007a,0x271a001a,0x28bd0037}},	//   tām_, ems_, ỏng_, ्मदि
  { {0x7c950003,0xc5f20009,0x29040060,0x4420016d}},	//   أشخا, גדי_, şmaz_, _pki_
  { {0x38350015,0x2475001e,0xdce70066,0x2d8c0070}},	//   _энер, rām_, _nejč, agde_
  { {0x67ea0065,0x24750039,0xa3ce0037,0xd6ab0012}},	//   _nýja, sām_, राब_, _خدام_
  { {0x24750039,0x66ba000b,0xceb2000b,0x9856002d}},	//   pām_, _למנה, _ניו_, зташ
  { {0x44260066,0x75e0000e,0x4432002a,0x442000b6}},	//   ylo_, _közv, _thy_, _tki_
  { {0x62820101,0xdb040017,0x8ca60011,0xd47a0009}},	//   yroo, _maiú, _टैगो, _האקל
  { {0xd5b1001a,0x9f4a0030,0x22580159,0x6813004b}},	// [4460] hóm_, ímém_, _črko_, căde
  { {0x42fb000b,0x8afb000b,0x05660024,0x3abb0009}},	//   _להפס, _להפי, ївен, _פמינ
  { {0x63b600a2,0xdb06000f,0x89db000b,0xddcd009b}},	//   _kayn, deké, _החיי, braž
  { {0x44200020,0xd4690003,0x53980024,0x62821c2b}},	//   ôi_, تحكم_, івля_, troo
  { {0x68250164,0x3253002d,0x62820269,0x44261c2c}},	//   códi, евір, uroo, rlo_
  { {0x98b800a1,0x89d80003,0x244a0012,0xee370024}},	//   ları_, توتر_, _هجري_, _ння_
  { {0x30a30015,0xb21b0058,0xd12f0012,0x997d0035}},	//   ерыв, kræn, همه_, nāšu_
  { {0x7ceb000b,0x644e000d,0x547b0009,0x5c7b0009}},	//   _הַמֶ, _iubi, _לטלו, _לאלה
  { {0x61fe0054,0x644e0164,0x74130003,0x96340d7c}},	//   _ompl, _hubi, _أوقا, мниц
  { {0x36f7000b,0x69da0c57,0x4a5b0009,0xba0a0012}},	//   פצים_, ötel, _לדמו, _اترك_
  { {0x6fdc0061,0xdcfc003a,0x98b8003a,0x515b0009}},	//   _décr, _karı, karı_, _הכבו
  { {0xb21b00c5,0x44390113,0x21ef0032,0x656e0032}},	//   græn, ums_, _mühe_, _lebh
  { {0xdfcf0003,0xe9ff001a,0xddcd1afe,0x44391c2d}},	//   _حين_, _quần_, nsaţ, rms_
  { {0x69da004a,0x7f3b0009,0x867b0009,0xdcfc0060}},	//   _jote, _העדו, _פרוו, _ları
  { {0xddcd001c,0x859b000b,0xd59b000b,0x759b0009}},	//   traž, _השוו, _הבול, _הסוג
  { {0xe9ff001a,0xcce50012,0x0ec80011,0x54450012}},	//   _tuần_, _تسهي, रमंड, _تنعك
  { {0x69c801e4,0xe9ff001a,0x4b7c0009,0x69da005e}},	// [4470] _onde, _huấn_, _האחו, _oote
  { {0x7aef003a,0xd5b8001e,0x3c320029,0x3f830073}},	//   ıntı, ndā_, ráve_, ėjui_
  { {0xdcfc003a,0x68250017,0x319a0009,0xc19a0009}},	//   _barı, sódi, _ובתנ, _ושתי
  { {0xd7e60012,0x69c81c2e,0x3eb2008e,0x22451b60}},	//   _شك_, _ande, äntä_, _silk_
  { {0x89d5002d,0xdb06000e,0x160c0011,0xa3ce0011}},	//   дійш, teké, िचार_, रात_
  { {0xceb20093,0xa8590001,0x38590015,0xd2b80009}},	//   _שים_, ојих_, орию_, פלות_
  { {0x3f8d0054,0x644e0b37,0xf484010b,0x7c84020e}},	//   tgeu_, _gubi, _путн, _путе
  { {0x69c81c2f,0x6b9d0227,0xdb060031,0xaec50560}},	//   _ende, jfsg, seké, дбил
  { {0x69da1c30,0xdce80035,0xc68e0012,0x66011c31}},	//   _fote, vadā, لِي_, tilk
  { {0xd7060047,0xa37b0051,0x98b8003a,0x628b002c}},	//   ьные_, skõl, zarı_, mugo
  { {0x64480108,0xdcfc003a,0x98b8003a,0x628b09dd}},	//   _édit, _yarı, yarı_, lugo
  { {0xcfab0003,0x68e31c32,0x66011c33,0xa3ce0011}},	//   _دائم_, mynd, silk, राध_
  { {0x0376000b,0x539a000b,0x75e0000e,0x0f56000b}},	//   ותרת_, חירו, _közt, _חינם_
  { {0x22960040,0x3253003c,0xc7b90031,0x200d0035}},	//   ræk_, твёр, ldő_, lnei_
  { {0x3cf90037,0x62990070,0x98b8003a,0x7e080009}},	//   ्पों_, htwo, tarı_, _מִקֶ
  { {0xc7b9000f,0xdfd20003,0x07a30001,0xe76a0012}},	//   ndő_, خير_, касн, تحسن_
  { {0xdb000065,0x98b8003a,0x644e1c34,0x1dc90011}},	// [4480] _samþ, rarı_, _subi, रांत
  { {0xee370731,0x9a460012,0x72360012,0xdcfc0060}},	//   дну_, _تضعه, _تربط, _sarı
  { {0x200501a0,0xb4e80011,0x1cba0012,0xe3ba07b9}},	//   èlic_, यने_, غائب_, жбе_
  { {0x8cbe0037,0x53e5002d,0x644a0054,0x14170012}},	//   षितो, нціа, ífiq, ويلة_
  { {0xf7730093,0xdcb1001a,0xdcfc0060,0x24530081}},	//   _בקר_, _ẩn_, _varı, _lãm_
  { {0xddcd007d,0x98c601b6,0x628600ff,0x71740012}},	//   rsaţ, дсил, irko, رهبا
  { {0x68e300c5,0xdcfc003a,0x98a30001,0x628b0071}},	//   gynd, _tarı, вије, augo
  { {0xdfd0000a,0xb9060037,0xc6e6002d,0x6d5c003a}},	//   اية_, _पथ_, діоп, ıram
  { {0x30130014,0x69da1c35,0x75d30034,0x8fa3004c}},	//   ъдър, _tote, _węzł, тање
  { {0x752f003e,0x200d000d,0x7bc90042,0x4d980024}},	//   ęczn, anei_, _zneu, чкою_
  { {0x35f7000a,0xd5b8001e,0x439508e0,0x4424005e}},	//   بريد_, rdā_, нанс, _kkm_
  { {0x75e0000e,0xa2c20037,0xddc2090a,0xab5d0034}},	//   _közs, लिप्, _uvož, _boży
  { {0xa2c60037,0x6e930003,0x5e930003,0x4424005e}},	//   ामग्, _للنا, _للنط, _mkm_
  { {0xedd40012,0xbdf70012,0xe9ff0081,0xab5d0034}},	//   _سيبد, _يروا_, _tuấn_, _doży
  { {0xa3ae0037,0xc1050012,0x2004008e,0x62861c36}},	//   क़ा_, روري, oimi_, arko
  { {0xb21b0065,0x2d9e0052,0x50db0009,0x20041c37}},	//   mræm, lfte_, חקלא, nimi_
  { {0x98af00a2,0xc6f90048,0x63ab1c38,0x2004008e}},	// [4490] ınız_, чнах_, vegn, iimi_
  { {0xc7b9000e,0x2d9e0032,0x68250031,0xd5c90011}},	//   zdő_, nfte_, lódt, राइज
  { {0xc534000b,0xe759002d,0xdcfc0035,0x3c320064}},	//   תָּה_, _нині_, _marķ, láva_
  { {0x2004179a,0x25b81c39,0x7a320097,0x628b1c3a}},	//   jimi_, _earl_, mæta, tugo
  { {0x27e900b6,0x63ab0989,0x4abf0011,0xb6040030}},	//   mkan_, regn, एटिव, _stář
  { {0x27e900c6,0x9f980065,0x63ab0a5a,0x48b50014}},	//   lkan_, _séð_, segn, ещит
  { {0x63ab00c1,0x200d001e,0xb5940024,0x2bb20011}},	//   pegn, tnei_, _ширш, ज़मा
  { {0x27e900c6,0xc7b2000b,0x20040328,0x04c80003}},	//   nkan_, ָ֑ה_, gimi_, _توفي_
  { {0x5215002d,0x27e90fa6,0xd709004d,0xd5c90011}},	//   _здат, ikan_, яние_, राऊज
  { {0x7c24007a,0x27e900c6,0x3c320029,0xee360015}},	//   _skir, hkan_, dáva_, нны_
  { {0x27e900c6,0xdb0a05b1,0xdc390009,0x64c90011}},	//   kkan_, čním, ּעָר, िमेश
  { {0xca290093,0xab5d0002,0x2004072c,0x301501d4}},	//   _הם_, _poży, cimi_, _ядер
  { {0x27e900b6,0xc7d60009,0x7c2b068a,0x2bb20011}},	//   dkan_, _רוני_, ilgr, ज़बा
  { {0x67e30005,0xdb000002,0xd24f0012,0xb8660012}},	//   _mõju, _zamó, صنف_, فارو
  { {0x6e210027,0x1c1f0037,0x27e900b6,0xf8a70012}},	//   molb, यकाल_, fkan_, دة_
  { {0x27e900b6,0x64490034,0x6286001b,0x7c24016d}},	//   gkan_, _niei, prko, _ukir
  { {0x4422000f,0x63a4002c,0xaa570012,0x6fa10011}},	// [44a0] mok_, _ibin, _كليا_, क्यू
  { {0x3ebf004a,0xa3ce0011,0x271e0081,0x531b0009}},	//   ivut_, राव_, ịng_, _מופצ
  { {0x27e900c6,0x8d930003,0x7469002d,0x2004003a}},	//   bkan_, المش, дрів_, yimi_
  { {0xd5c90044,0x4422120b,0xd36f0003,0x27e9006f}},	//   राउज, nok_, مهم_, ckan_
  { {0x2ca700b6,0xd3230800,0x5b230021,0x2d9e0248}},	//   _lpnd_, льши, льша, yfte_
  { {0x442201ea,0xc3330009,0x5a330024,0xcb070012}},	//   hok_, אוד_, гніт, عيون_
  { {0xf993000b,0x6722001e,0x25ac0030,0x3ea61c3b}},	//   ארו_, ļoju, vedl_, _spot_
  { {0x9f44004a,0x442400b6,0x69de1c3c,0x80a30012}},	//   yhmä_, _ukm_, _lope, امين
  { {0x6280000e,0xa6140001,0xd5b8001e,0x20041c3d}},	//   ámol, кмич, klāt_, rimi_
  { {0xdd90000a,0x0697000b,0xceb3000b,0x3c320029}},	//   جود_, עדים_, ריז_, váva_
  { {0xa37b0051,0xc5f3000b,0x2d9e0052,0xf9930009}},	//   lkõi, רדת_, rfte_, _תרע_
  { {0x44220642,0x2bc60037,0x3c320029,0x49170009}},	//   gok_, _रोमा, táva_, _אקבל_
  { {0xa2be0044,0xb21b0028,0x55e60063,0x8f750024}},	//   शिष्, sræm, _подб, _рухі
  { {0xc333000b,0x7c220070,0x3c320107,0xf7430024}},	//   טור_, hoor, ráva_, _сечо
  { {0x27e900c6,0xa3ce0011,0x690b0009,0x7c22154c}},	//   tkan_, राश_, ִּלְ, koor
  { {0x6fa60037,0xf7730003,0x629a000d,0x27e900b6}},	//   _कॉमं, طار_, ător, ukan_
  { {0xf6530003,0x7e64002c,0xa3ce0037,0x27e91c3e}},	// [44b0] ائر_, gpip, रार_, rkan_
  { {0x984b0098,0x27e91c3f,0x7c220227,0x6d5a1c40}},	//   _няма_, skan_, eoor, ncta
  { {0x27e900c6,0x7c220647,0x225f0070,0x629d09c5}},	//   pkan_, foor, _stuk_, ltso
  { {0x7c220051,0x96b10011,0x387e0025,0x63bd1c41}},	//   goor, _अनलॉ, âtre_, ndsn
  { {0x629d0272,0x32670046,0x7f76000b,0x93940003}},	//   ntso, хтев, _בערב_, اجما
  { {0x1e1a0044,0xc334000b,0xc9840001,0x44220fe1}},	//   नकोष_, נוס_, гући, zok_
  { {0x70b20003,0x70bd0037,0x7c220070,0xd3a71c42}},	//   لموض, ्मेल, boor, _прап
  { {0xc4d2000b,0x69d802a1,0x9c7c0004,0x46a5003c}},	//   _דגל_, ajve, tyčn, ваив
  { {0x75e0000f,0x0cc90037,0xdcee0066,0x22840055}},	//   _közp, िम्म, _odbě, _бухг
  { {0x63bb0132,0x628f00b8,0xfc3f0030,0x7ae60073}},	//   _haun, duco, emí_, vykt
  { {0x442209f9,0x90990015,0xa806003a,0xa3ce0037}},	//   tok_, _цвет_, lmış, राल_
  { {0x63bb0333,0x3f830010,0x3b0a0129,0x7bdf1274}},	//   _jaun, ėjus_, демо_, _coqu
  { {0xa806003a,0x21f40051,0x637a0009,0x629d0040}},	//   nmış, _lähe_, ונרד, gtso
  { {0x44221c43,0x63bb1520,0x26c000b8,0x21ef005e}},	//   sok_, _laun, vvio_, _püha_
  { {0x4127002d,0x21f40052,0x91030a15,0x44c10010}},	//   воро_, _nähe_, апре, _nė_
  { {0xb8da0044,0xe3b20003,0x63bb01ea,0xa8060060}},	//   _आई_, _ضرب_, _naun, kmış
  { {0x539b015a,0x7c2200bd,0xf7720009,0x69de1c44}},	// [44c0] _חיפו, voor, יקן_, _tope
  { {0x4d630098,0x7c2200bd,0x320701e9,0x26c01c45}},	//   икув, woor, jiny_, rvio_
  { {0x7c220647,0x320701bd,0xeb9a0357,0x26c00018}},	//   toor, diny_, дие_, svio_
  { {0xe727000a,0x31780002,0xd4670001,0x1bba0012}},	//   _نص_, larz_, тице_, بائع_
  { {0x7c220070,0x7f1a002d,0x92b30012,0xd3570009}},	//   roor, _ціну_, لحوا, דיני_
  { {0x5333004c,0x8afb0009,0x7c2217c9,0x645e0025}},	//   јешт, והני, soor, _épig
  { {0xc9530093,0xa37b0051,0xfc4a001a,0x63bd0058}},	//   סמה_, skõi, _hậu_, ydsn
  { {0x67f50026,0x63bb007a,0xb21b0058,0x7aa60012}},	//   _nájd, _gaun, træk, _لإطل
  { {0xef1f0051,0x4343003c,0x31780034,0xda080081}},	//   üüp_, _ветв, karz_, hỏi_
  { {0xe7310009,0xe8020011,0xfc4a0081,0xca970009}},	//   מֵי_, रोता_, _mậu_, _בדמי_
  { {0xdb0b000e,0xfc4a0081,0x31780034,0x7bdf0bf2}},	//   vegé, _lậu_, darz_, _poqu
  { {0xd5be001e,0x84a90009,0x09290012,0x547b0009}},	//   _šāda_, ׂיתִ, _أسكي_, וטטו
  { {0xf6d30003,0x7ceb000e,0xc7f70009,0x61e10248}},	//   _نزود, törö, _בזאת_, öllo
  { {0x7a3200c5,0xfc3f0066,0x16770009,0x7ae00248}},	//   sætn, smí_, _יגדל_, ämta
  { {0x86370009,0x6fb80011,0x7bcd0073,0x67f50031}},	//   _שרוב_, ्यपू, _tnau, _fájd
  { {0x58bb000b,0x3207055e,0x98140012,0xc864028b}},	//   ומלצ, ziny_, لبقا, ртри
  { {0x63bb0028,0x98a4001e,0x2caa00b6,0x62890004}},	// [44d0] _raun, āmā_, _apbd_, šeob
  { {0x21f4005e,0xfc670048,0xe5c40189,0x7e9b0009}},	//   _pähe_, въдн, исхо, וסמו
  { {0xdb510003,0x63bb002c,0xc952000b,0x32070042}},	//   مَا_, _paun, _למי_, viny_
  { {0x63a2000e,0x21f40051,0xa77403e1,0x8b940024}},	//   gfon, _vähe_, _ключ, иріч
  { {0xaa580109,0x20091c46,0xc9f50012,0xfaf00012}},	//   вичу_, miai_, ُستع, يثه_
  { {0x2009007a,0x2b83001a,0x443b001a,0x644d0573}},	//   liai_, ực_, _lhq_, _liai
  { {0x07a5002d,0xa4d4002d,0x78890012,0x7a2d0064}},	//   гайн, _корі, رَةِ_, núti
  { {0x2009007a,0x6280000e,0x0138000b,0x94b10037}},	//   niai_, ámok, כרות_, ीटीआ
  { {0xfc4a0020,0xa3d70037,0x5b150001,0xe3150001}},	//   _mật_, सान_, _смат, _смањ
  { {0x4d650015,0x7ae400ff,0xf9930012,0x2bd60011}},	//   ыков, äite, _خبر_, धाभा
  { {0x7e7b1c47,0xd1310003,0x240a0014,0x20090010}},	//   ssup, _اما_, енни_, kiai_
  { {0xb8f70037,0x1bba0003,0x67f50030,0x3c3206dd}},	//   ाम_, راجع_, _báje, rávo_
  { {0xe2c700b3,0x6da50001,0xada50223,0x31780034}},	//   гляд_, _била, _балл, tarz_
  { {0x61e10006,0xceb2000b,0x65750029,0x3c39000e}},	//   _joll, _ליד_, _nezh, véve_
  { {0xfc4a001a,0x859a0009,0x644d0031,0x20090031}},	//   _bật_, _נשקו, _fiai, fiai_
  { {0x31780002,0x20091c46,0xd3da0012,0x61e11c48}},	//   sarz_, giai_, _سببا_, _loll
  { {0x27ed00bd,0x64550bd3,0x8f750024,0x25f70011}},	// [44e0] iken_, _auzi, русі, एसपी_
  { {0xdd920003,0x442f0033,0xed580029,0xa2c20037}},	//   صوص_, elg_, odľa_, लिस्
  { {0x67f50066,0x299b000b,0x35c90037,0xa91c0029}},	//   _záje, _אסימ, राज़, _odľa
  { {0x27ed00bd,0x7c3b1a91,0xa3d70037,0xac25002d}},	//   jken_, _chur, साय_, афік
  { {0xab770003,0xddc40010,0x0cb00321,0xead40695}},	//   امها_, usių, _जन्म, роль
  { {0x27ed00bd,0x2d83001c,0xddc40010,0x4dd60024}},	//   eken_, _gdje_, rsių, _сімф
  { {0xf993000b,0xf969002d,0x7c261c49,0x90a60012}},	//   צרה_, трій_, kokr, احتم
  { {0xd6da0019,0xdb0b000e,0xc0340001,0x38340001}},	//   ето_, őnéz, јниј, јнир
  { {0x61e11c4a,0xc7d7000b,0x7ed60012,0xa3ce0011}},	//   _foll, רופי_, ازعا, राई_
  { {0x44290163,0xa96a0003,0xceb3000b,0x6442004a}},	//   _ska_, _أمام_, צית_, lmoi
  { {0x2ed10037,0xb4be0011,0x16370012,0xfcaa0012}},	//   _सप्त, ँटे_, دسية_, رادو_
  { {0x27ed041b,0x07b70003,0xab62003a,0xd91b000b}},	//   cken_, _مهمة_, şünd, _אובל
  { {0xa3d70037,0x61e1003a,0x20090010,0x2fc0000e}},	//   साब_, _yoll, viai_, ddig_
  { {0x5a34002d,0xd1260003,0x54e60003,0x8e831c4b}},	//   йнят, قم_, _مسبق, _الوه
  { {0xb21b0058,0xf55b000b,0x3ea01c4c,0xab5b0032}},	//   kræv, _אדומ, etit_, rdüb
  { {0xb8dd0044,0x9f40004a,0x2fc0002c,0x657a0b7c}},	//   _इन_, kkiä_, gdig_, lath
  { {0x33a80098,0x2009007a,0xfc4a0020,0x5575022a}},	// [44f0] _също_, riai_, _vật_, игат
  { {0x2009069c,0x78ba0027,0x8d740012,0x36040012}},	//   siai_, _ostv, ماما, موقف
  { {0x515a0093,0x2009007a,0x27ed003a,0x361b0009}},	//   _בכתו, piai_, yken_, עובד
  { {0x200c0061,0xce950014,0x61e11c4d,0xa3ce0011}},	//   édit_, _камъ, _soll, राए_
  { {0x0f7a0009,0x645a0025,0x8f7a0009,0x7afd1683}},	//   _בארב, _étin, _שנשק, nzst
  { {0x88c50003,0xfa780009,0x17ed0011,0x6442031c}},	//   لتعل, נעות_, जस्व_, amoi
  { {0x27ed0855,0x61e11c4e,0x28c50011,0xa156004c}},	//   tken_, _voll, विधि, шају_
  { {0x61e1008b,0x20c80003,0x5c070024,0x5ed50012}},	//   _woll, ابوي_, _сяга, لتخز
  { {0x63a9002c,0x61e11c4f,0x27ed1c50,0x657a0132}},	//   _iben, _toll, rken_, fath
  { {0x67ea0066,0x7afd0035,0x657a1c51,0x7555004c}},	//   _výji, dzst, gath, шњиц
  { {0x21f40051,0xcb6a0014,0xa8a70014,0xa3bc0037}},	//   _näha_, кане_, _щрак, _असम_
  { {0x787a0009,0x3ea0180e,0xdce80030,0xdc880009}},	//   _יָדו, ytit_, ladě, נְתָ
  { {0x66670015,0x6e67002d,0xb7bd000d,0x7c261c52}},	//   _съез, _стеж, ulţu, rokr
  { {0x7c26000e,0x4efa0009,0xfe700012,0x3cf90012}},	//   sokr, _שהסו, _رده_, _لعبد_
  { {0xab5d003e,0x26cf006f,0xd9460dc2,0xc0460012}},	//   _każd, ågon_, реви, لخرو
  { {0x2fc00070,0x90e70012,0x3ea01c53,0x1f66087f}},	//   udig_, جِّل_, ttit_, ркам
  { {0xa6650003,0x60230024,0xfe720012,0xed5a1003}},	// [4500] مطلو, ідуа, تدأ_, воз_
  { {0x63a9148a,0x8a7b0009,0xa3ce0011,0x3ea01c54}},	//   _aben, _שאית, राक_, rtit_
  { {0x7a2d0028,0x44260312,0x3ea01c55,0xb5fb1c56}},	//   nútu, too_, stit_, _itál
  { {0x87550014,0xb5fb000e,0xb4890003,0x25f70011}},	//   _гърц, _után, ائلك_, एसडी_
  { {0xdce30066,0x62880002,0x44261326,0xab270001}},	//   _peně, ądow, roo_, аоца_
  { {0x63a9008b,0x645a0025,0x2886004c,0x7a20008e}},	//   _eben, _étio, аћив, töty
  { {0xe466003a,0x44c5001e,0xec770024,0xb97b0009}},	//   önüş, _nē_, _впс_, דנצי
  { {0x4fc6004d,0xa8570009,0x4cbb0009,0x21ef005e}},	//   рска, סיפה_, _במלג, _rühm_
  { {0x657a0222,0x8f9b0009,0x7e6d0060,0x9ed70048}},	//   tath, דיפי, _çapl, имът_
  { {0x26c0007a,0xba9b0009,0x91780009,0x9c7c0073}},	//   _šios_, _בסמי, _תְּח, lyči
  { {0x78ba012e,0x7d7b000b,0x49060011,0x7bc01c57}},	//   _ustv, כניו, _हेलो_, _kamu
  { {0x7afd0052,0xb8dc0011,0x7bc003fe,0xa3ce0011}},	//   tzst, ेट_, _jamu, राग_
  { {0x6eb60012,0xc3340009,0xd6cf0012,0xbea30048}},	//   _خصائ, מוֹ_, _يقم_, _мацк
  { {0x2efb000b,0x6d5c003a,0xd6fb0009,0xa6fb0009}},	//   _שִׁב, ıras, _שִׁש, _שִׁי
  { {0xe63b000b,0x16b60037,0xf8070dc2,0xa63b0009}},	//   _שתוכ, _अनुब, ачан, _שגור
  { {0x7bc00807,0x69da0574,0x8c250012,0x87550024}},	//   _namu, öter, _دفعه, скає
  { {0x64580005,0x67ea0065,0x200c0054,0xdb23003a}},	// [4510] _huvi, _nýju, èdia_, ürül
  { {0x64580006,0x2ddb0012,0x9df8003c,0x7bc0008e}},	//   _kuvi, خبرة_, анут_, _aamu
  { {0xdcbb0014,0xd3710003,0x721a0009,0xcb550012}},	//   ъща_, كها_, _תותח, مناظ
  { {0xe3b30012,0xab950024,0x61e50032,0xdb0b0031}},	//   ترط_, сиді, _hohl, segí
  { {0x7bc00054,0x61e50052,0xdb06003a,0xe9ce0476}},	//   _damu, _kohl, rekç, пк_
  { {0xfc4a0020,0xa4d5002d,0x64580017,0x7ae40051}},	//   _lập_, _логі, _ouvi, äita
  { {0x601e001e,0x61e50107,0x490d0011,0xb868004c}},	//   zīme, _mohl, _डेमो_, ајње_
  { {0xe7390800,0xc918000b,0x43940015,0xc0540009}},	//   лей_, יחות_, _масс, חזק_
  { {0x1dd20011,0xef190034,0xed59054b,0xdb0b0032}},	//   तांत, każe_, лоп_, ndgü
  { {0x7c2d000f,0x07920066,0x92f40003,0x7bc0009b}},	//   _akar, _čímž_, _بأفض, _zamu
  { {0x645801b3,0x443f0020,0xf49401ec,0x442d0722}},	//   _cuvi, _khu_, оряю, _kke_
  { {0xfc4a0020,0x9cd6000b,0xb5fb0107,0x64581030}},	//   _cập_, צורה_, _stál, _duvi
  { {0xeb970098,0x9756000b,0xdce1001e,0x6d5c003a}},	//   щия_, _הינו_, talē, ırar
  { {0xbb3a000b,0x200d000d,0x8e560009,0xaf340012}},	//   טערי, liei_, _פיצג_, _برمت
  { {0x7c950003,0xa3da0011,0x291e0060,0xdce10035}},	//   _العص, ़ाम_, çta_, ralē
  { {0x200d007d,0x443f001a,0xab5b000e,0x4c050003}},	//   niei_, _nhu_, ldün, _وظيف
  { {0xe61a0047,0x0d560012,0x85560012,0x0d8605c8}},	// [4520] гда_, مخاد, مخاط, йлан
  { {0x8d56002d,0xab8c003a,0x38a10028,0xa7fc003a}},	//   стач, _çözü, kór_, _atıl
  { {0x75e0000e,0x3957000b,0x8b6a0014,0x31570009}},	//   _közz, _לשים_, гиев_, _ליין_
  { {0x037a0003,0x443f1c58,0x4fb60012,0xd8430030}},	//   احات_, _chu_, _اصدر, tačů_
  { {0x64460010,0x1db70011,0x2178003c,0x200d004b}},	//   imki, _असंत, айлы_, diei_
  { {0xe2a70028,0x8db60024,0x3ea0008e,0xed571c59}},	//   óðir_, _усмі, _äiti_, _гор_
  { {0xf1b30093,0x200d000d,0x91bb0009,0xf8aa0012}},	//   פסה_, fiei_, רמצי, ادته_
  { {0x5f940014,0x200d000d,0x0d170009,0xb8d00011}},	//   циит, giei_, _הקלט_, _ओह_
  { {0x64400006,0x9205001e,0xa3d70011,0xfc4a0081}},	//   _ihmi, _spāņ, सास_, _rập_
  { {0x22f70093,0xceb3000b,0x38a10002,0xf77f0017}},	//   _הזמן_, ליח_, bór_, _moça_
  { {0x11d70003,0x6ca30015,0x9cf40024,0x4bb50048}},	//   _دولة_, пряж, ізмі, ойнс
  { {0x69c1003e,0xb9370009,0x320e0132,0x200d004b}},	//   _zale, _פראג_, lify_, ciei_
  { {0xa3ce0037,0x61e500d9,0x80250012,0x6e280159}},	//   राज_, _pohl, _برلم, podb
  { {0x99830066,0x7afd003a,0x6458129d,0x7e9b0009}},	//   rojů_, _üste, _tuvi, _תסגו
  { {0xfc4a0020,0x27e6004a,0x2e370009,0x4d7b0009}},	//   _tập_, _koon_, _הרגש_, _גרוע
  { {0x61e50052,0x38350024,0xbc670012,0x2ef50024}},	//   _wohl, інар, _امين_, озбр
  { {0x63ad0101,0x44c8003a,0x6d480107,0x61e50066}},	// [4530] _iban, _ağ_, _údaj, _tohl
  { {0x2ba50037,0x442b0c72,0xef110009,0xaac70011}},	//   ग्रा, loc_, וּב_, लिसक
  { {0x2bdd0044,0xe7c40037,0x320e0431,0x54b9003c}},	//   यापा, _लोकप, dify_, ргея_
  { {0xb21b0058,0x43740001,0x6fb50003,0xdc9b0009}},	//   præs, пушт, _بمحا, ריאל
  { {0x92b70003,0x38a10034,0xb4d50011,0x4f9a0009}},	//   إحصا, wór_, _सप्_, _דברצ
  { {0x20b40037,0xda780015,0xe7a60037,0xa1350012}},	//   ंबंध, сяц_, क्सप, يرثش
  { {0x443f1c5a,0x80c00037,0x69c11c5b,0x80880012}},	//   _thu_, विगे, _vale, مضيف_
  { {0x442d0033,0x16650ec6,0xd0f80009,0x442b01a0}},	//   _uke_, овим, ממות_, joc_
  { {0x200d000d,0x27e6002c,0x6b89146f,0x2bdd0011}},	//   riei_, _doon_, _ideg, याना
  { {0x320e002a,0x200d000d,0xac850055,0x63ad1c5c}},	//   cify_, siei_, огол, _aban
  { {0xca48000a,0x044600be,0x98a50010,0xf2c90009}},	//   _الله_, женн, _bylą_, _שע_
  { {0xc1690093,0x38850039,0x2bcf0011,0xeb9a14bd}},	//   _יח_, mēr_, _सोमा, шим_
  { {0xe72e007c,0xce6b0014,0xa3da0037,0x645e0025}},	//   _це_, _сред_, ़ात_, _épin
  { {0x0dcb0046,0xd7f1001a,0x27e60070,0xc8660012}},	//   _људи_, ễn_, _zoon_, قطري
  { {0xa8890009,0x10890009,0x6b890034,0xdfd20012}},	//   יָּ֥, יָּֽ, _odeg, ويس_
  { {0xb4d50037,0x25f70011,0x33d60024,0x60970012}},	//   समी_, एसवी_, _фікт, تنفس_
  { {0x7e6d01e5,0x75d6000a,0x060a0046,0xa3d70037}},	// [4540] gpap, ييرا, анак_, सार_
  { {0x0d86002d,0x67f8000e,0x6b891921,0x99900034}},	//   ілен, _díja, _adeg, łała_
  { {0x2eb60044,0x78ad0066,0xad650003,0x7e6d002c}},	//   _अन्त, čová, ساله, apap
  { {0xd36f000a,0x2bdd0037,0x62820051,0xcdc9000b}},	//   نهم_, याया, tsoo, כך_
  { {0x320e1c5d,0x8c1b0009,0x7bc41c5e,0xda770048}},	//   tify_, סוני, _maiu, оящ_
  { {0x62820b7d,0x057a0003,0x27e6002a,0x7bc40051}},	//   rsoo, _خمسة_, _soon_, _laiu
  { {0x320e002a,0x2e2f0052,0x89db0009,0xa3da0011}},	//   rify_, rüft_, יחסי, ़ाद_
  { {0x657c1c5f,0xc953000b,0xa857000b,0x76aa0063}},	//   _herh, ומו_, חיקה_, атов_
  { {0xdefa0047,0xcf26000a,0xdde3000d,0x62650012}},	//   рый_, غربي, ârşi, _فالق
  { {0x645c1c60,0x50d60003,0x21ef0051,0xe4a604ba}},	//   _kuri, _وزار, _tühi_, ормо
  { {0x957c0002,0x657c003a,0xa3d70037,0xdb0f0164}},	//   ejąc, _merh, साल_, recí
  { {0x7a3f0061,0x2bb20037,0xd3660012,0x5f2a003c}},	//   rête, ज़गा, عه_, _коем_
  { {0x61e8003a,0x9d9a0012,0xdfcf0012,0x6813004b}},	//   _kodl, _ننشئ_, _جين_, gădu
  { {0xb5fb0064,0x67fc11e4,0x645c0018,0x073700af}},	//   _vták, _déje, _ouri, _ואדם_
  { {0xba3d0013,0x957c0002,0xf65f0058,0xc05b002d}},	//   _způs, ając, _træk_, ріг_
  { {0x68250002,0x6d580010,0x9f5f0028,0xcb0b004d}},	//   wódz, žval, nnuð_, _вход_
  { {0x657c00c6,0xba770003,0x35f5003c,0x03780009}},	// [4550] _berh, _باعت, ппар, _ותחת_
  { {0xdce1007a,0x645c1c61,0xdb0d005e,0xe2a70097}},	//   galė, _buri, _maaü, óður_
  { {0x91ba000b,0x61e10028,0x9f5f0028,0x19ba000b}},	//   _המתי, öllu, knuð_, _המתב
  { {0x645c0036,0x670c0037,0xf3ff0017,0x3c16001e}},	//   _duri, _सेवक_, nhã_, tāvi_
  { {0xb7da000b,0xa3bc0037,0x69c50051,0xdce10010}},	//   _הקרי, _असर_, _kahe, balė
  { {0xb7bd000d,0xeab00012,0x997e004b,0xceb20009}},	//   moţi, ضعه_, răşi_, _רים_
  { {0x67f5000f,0xb6070010,0x69c70027,0x7c2b1c62}},	//   _fájl, našū, idje, pogr
  { {0x69c50005,0xb5fb0066,0x96950055,0x997e000d}},	//   _lahe, _stáh, прош, păşi_
  { {0xab5b034f,0xef640009,0x99d70012,0xb4bb0011}},	//   rdül, וֹת֙_, _وتطا, _अनु_
  { {0xc9f70003,0x69c50052,0xddca003a,0x245a001e}},	//   _بسرع, _nahe, ğişe, _zīmi_
  { {0xc3290009,0xf6540009,0xd5e80012,0x27f70012}},	//   _עו_, וצץ_, تعين_, _وأصح
  { {0x113a000b,0xe672003a,0x98170003,0x7a320028}},	//   _התעל, _ölçü, _ببطا, hætt
  { {0xc5f50014,0x75f3003a,0x11d60024,0x28080012}},	//   _някъ, _kızı, півр, _بْنَ_
  { {0xee38002d,0x7e280003,0x7c27009b,0xcefd003a}},	//   _дні_, _وسوف_, čkra, ığın_
  { {0x31af00a2,0x69c5008b,0xf7720003,0x4dda000b}},	//   mızı_, _dahe, فاء_, _לחסו
  { {0x99870066,0x166602ac,0xb8e40011,0x8c43022a}},	//   konů_, звам, _एन_, _пеще
  { {0xa3df0044,0xdb9b000b,0x35d00037,0xa3da0037}},	// [4560] तान_, _הספר, _थोड़, ़ास_
  { {0x31af00a1,0x3c32014a,0x7ae40051,0xb21b0028}},	//   nızı_, rávu_, äitm, nsæl
  { {0xc1730093,0xe7bd0044,0x3b660014,0x5fbd0037}},	//   _אחת_, ्याप, пълв, ्याल
  { {0x2c61000e,0x60db000b,0xcc760009,0xb7bd004b}},	//   _mód_, _הקטנ, פענה_, boţi
  { {0x657c1c63,0x6456003a,0x83360003,0x61e81c64}},	//   _terh, _miyi, أراض, _podl
  { {0x645c039c,0xd259002d,0x26c70034,0x69c30097}},	//   _turi, іці_, łnoc_, _ónet
  { {0x645c0005,0x7af20066,0xc5ff001e,0x6e430024}},	//   _uuri, _řetě, ķēts_, _черз
  { {0xab660a25,0x351b000b,0xf8b3000b,0xc6f80339}},	//   _хвал, _הולנ, גשה_, жних_
  { {0xd5b00003,0x62861c65,0x95ca1896,0x4e960012}},	//   نفة_, jsko, буна_, أشعر
  { {0x27ff00b6,0x72060003,0x71a305fb,0xbafb0009}},	//   ahun_, _عوام, _пауз, _ההמש
  { {0xdc3f0066,0x67f50066,0x439514cf,0xef190034}},	//   síčn, _zájm, манс, raża_
  { {0xb9000037,0x62860027,0x69c51c66,0x6d3b0009}},	//   दम_, fsko, _sahe, מתינ
  { {0x90290003,0xc68f0012,0xa73a0012,0x62861a7f}},	//   _بألف_, _مِن_, _اثار_, gsko
  { {0x6f040002,0xa3b30037,0x26c3001e,0x765d0225}},	//   dzic, _जॉन_, ājot_, _rusy
  { {0x69c50005,0x28f80047,0x2bdd0011,0xab5b0060}},	//   _vahe, перь_, यादा, ndük
  { {0x999e007a,0x7537000b,0x2d81002c,0x104b002d}},	//   _kitų_, _מאוד_, wahe_, сяги_
  { {0x6b8d0101,0xdb080061,0x69c51c67,0x61470031}},	// [4570] _idag, _élèv, _tahe, félé
  { {0xe1750003,0x8afc000b,0xddc40027,0x5afc0009}},	//   _تُدخ, _להחי, tpiš, _ללחצ
  { {0x64570164,0x271e001a,0xd7590012,0xf9920009}},	//   _éxit, ịnh_, _ولدت_, _ברי_
  { {0xe3b3000a,0x7a320da6,0xa3d30037,0x44cc0066}},	//   عرض_, sætt, _होम_, _mě_
  { {0xa3df0037,0xb2ab0014,0x44391c68,0x38c70030}},	//   ताब_, стеж_, ils_, bírá_
  { {0x61470025,0x2c4d0030,0x44390032,0x3ea91c69}},	//   célé, _vědy_, hls_, mtat_
  { {0x63b9003e,0x44cc0066,0x4439001e,0xc5f20009}},	//   pewn, _ně_, kls_, _ידך_
  { {0xa0090003,0xbd440012,0xb4d90011,0x99870030}},	//   تقبل_, _سنقي, ़मी_, ponů_
  { {0xa3da0044,0x3ea91c6a,0x4f640012,0xa3d70011}},	//   ़ार_, ntat_, رايف, साई_
  { {0x3ea91c6b,0xcc89003c,0x44321c6c,0xef16003c}},	//   itat_, обое_, _sky_, ьмы_
  { {0xdb1d0058,0xc5f20009,0x442f0227,0x6ab80011}},	//   ndsæ, דדי_, oog_, ेट्र
  { {0x442f1c6d,0x62861c6e,0x2ef50109,0x2fc90227}},	//   nog_, tsko, _озер, jdag_
  { {0xe5a5010c,0x62861c6f,0x2c610034,0x9f580081}},	//   _жили, usko, _wód_, đrô_
  { {0xca96000b,0xc9760003,0x6b8d0010,0x7d28000e}},	//   ודשי_, باحث, _edag, épsé
  { {0x442f001c,0x2012003a,0xc7a60014,0x6be60012}},	//   kog_, tiyi_, мивк, _يكتم
  { {0x2fc90101,0x9426002d,0xdb160164,0x442000b6}},	//   gdag_, _імпе, _mayú, _uji_
  { {0xe7370047,0x2012003a,0x5bc50012,0x6df60012}},	// [4580] дет_, riyi_, _ستيف, وكرا
  { {0x6f041c70,0xfa970009,0x2bc60011,0xdb080025}},	//   rzic, _קדיש_, _रोजा, _élév
  { {0xdce1001e,0x8cd00037,0xddcb001e,0x89db0009}},	//   dalī, धियो, _atgū, _וחיי
  { {0xab5d003e,0x44201c71,0x442f0027,0xf77f003a}},	//   _ważn, õi_, gog_, _geç_
  { {0xbaba0003,0xc17a002d,0x3ea91c72,0xbb1b0025}},	//   تداء_, оїй_, ctat_, haîn
  { {0xbbca0037,0xb5fb05b1,0xc6930009,0x0dba0012}},	//   ियुक, _stáv, _באש_, _باحث_
  { {0xa2c20037,0xdcfa001e,0x6d5c013a,0xb1170012}},	//   लिङ्, katā, _igra, وقها_
  { {0x8fa30001,0xab2a0538,0xc0e70012,0x9b930012}},	//   ваће, _доба_, ظفين_, _للفت
  { {0x9f49003a,0x6d4707ef,0x000000c4,0x000000c4}},	//   rkaç_, ýjan,   ,
  { {0xdd900003,0xdb0f0017,0x2fc90031,0x2d9e0032}},	//   دود_, lecç, zdag_, ugte_
  { {0x0d970093,0xcd97000b,0xe415002d,0x5597000b}},	//   וכים_, ודית_, еднь, ודיע_
  { {0xa295002d,0x8c43003a,0xdddb0035,0x69c81c73}},	//   намі, _üşte, rsuš, _hade
  { {0x6594002d,0xb4bb0037,0x6ab90037,0x6d5c10c3}},	//   _залу, _अन्_, इबेर, _ogra
  { {0xb21b0065,0xf77f003a,0x4439001e,0x69c81c74}},	//   msæk, _seç_, sls_, _jade
  { {0xa93404b3,0x2db7000b,0xcec8001a,0x1e57000b}},	//   верш, _חלון_, _hộ_, _קשור_
  { {0x3ea90b35,0x44270012,0xe3b30012,0x6d5c1c75}},	//   ttat_, _ترتف, _شرع_, _agra
  { {0x442f001c,0x63bd10dc,0x3ea90137,0xe6990048}},	// [4590] vog_, mesn, utat_, яваш_
  { {0xcec8001a,0x63bd16db,0x69da00b0,0xc8670681}},	//   _mộ_, lesn, _nnte, _отми
  { {0xcec8001a,0x758801ec,0x9b950012,0xdb0f0018}},	//   _lộ_, ьств_, فلات, fecç
  { {0xf41f004a,0x63bd0010,0x3f8409d4,0xdb1d0040}},	//   nnä_, nesn, jamu_, rdsæ
  { {0xfc4a001a,0x442f1c76,0xa3e40011,0xf41f008e}},	//   _cậy_, rog_, पॉट_, inä_
  { {0xe29c000b,0xfc4a001a,0xc6920009,0xa9690fdf}},	//   קשור, _dậy_, _תאם_, чика_
  { {0x69c803eb,0xa8550001,0x20550104,0xb97c0009}},	//   _dade, нтиј, нтир, חרוז
  { {0xcec80020,0xb8d70037,0x16bc0037,0x79830052}},	//   _bộ_, _छह_, ्टूब, sanw
  { {0x15f301e1,0xdb1d0052,0xef190094,0x63bd1187}},	//   _आकार_, ndsä, ями_, desn
  { {0x11d70003,0xdcee0066,0xf41f004a,0x99d70012}},	//   _تترد, _nebě, enä_, _تترا
  { {0x4519003c,0x63bd0030,0x67f80031,0x27fe0035}},	//   яция_, fesn, _díjj, ūtni_
  { {0x9f4b05ab,0x69c81c77,0xf1a90009,0x3f840035}},	//   _você_, _zade, _לס_, camu_
  { {0x539a000b,0xe784002d,0x629d1c78,0x870400ae}},	//   הירו, _рухо, guso, _لبول
  { {0xfe700012,0x7c220035,0x1d090148,0x59e20011}},	//   _ضده_, čori, _нели_, पायर
  { {0x60260104,0xba3b0054,0x6e26000e,0xd8261c79}},	//   едва, duïd, ékbe, едви
  { {0x6d430027,0x3cf80012,0xbb460048,0xdee60560}},	//   _izna, _تعهد_, _пейк, ноби
  { {0x38550014,0xdcf8001e,0x65960003,0xdb061c7a}},	// [45a0] търс, _ievā, فجار, nekü
  { {0x20c6002d,0xab5d0002,0xee3705f0,0x2bac0011}},	//   _зйом, _inży, ену_, ट्रा
  { {0xdb060005,0x317b000b,0x417b000b,0x6d5c009b}},	//   hekü, _מאיד, _מניב, _vgra
  { {0x69c800a2,0xb4fa000b,0xb5fb1234,0xf7720012}},	//   _sade, הפעי, _stát, _حاد_
  { {0x7d06000f,0x26cf006f,0xc7b30009,0x69c81c7b}},	//   _kéré, ågot_, _גבר_, _pade
  { {0xfc4a0020,0x63bd0002,0x2d851c7c,0xa3be0011}},	//   _vậy_, zesn, jale_, ुएँ_
  { {0xc173000b,0xf41f004a,0xa3ea022a,0x6e430012}},	//   נחה_, ynä_, _едва_, _إنّم
  { {0xf093000b,0x2d851c7d,0xab690012,0x64430227}},	//   אנה_, eale_, _يحقق_, ïnit
  { {0x3a26002d,0x4226002d,0xdb06020b,0x24170009}},	//   _змаг, _здав, ämän, _נחמן_
  { {0x69da032b,0x48e6076c,0xbef70012,0xc6930009}},	//   _unte, _позв, عريض_, נאת_
  { {0x29180005,0x2907003e,0x63bd007a,0x1ac90011}},	//   _ära_, czna_, tesn, िट्ठ
  { {0x68f5007a,0x63a21b9c,0x3f820027,0x388c0066}},	//   vyzd, ngon, _neku_, měr_
  { {0xfbd30093,0x1dd10037,0xdcf80035,0x63a20073}},	//   אתר_, _सफलत, _devā, igon
  { {0xc333000b,0x7d060061,0x17570009,0xc1cb0011}},	//   רוש_, _céré, _נסגר_, ायेग
  { {0x6e2b0009,0x7e6d0060,0xadc30081,0xddc9004b}},	//   _מֵהַ, _çapr, _ngạc, speţ
  { {0x91f50020,0x653b000b,0x629d000e,0x5d3b000b}},	//   _kíc, _מעוד, puso, _מתוא
  { {0xa3da0037,0x20180012,0xdb0b01e3,0xc987004c}},	// [45b0] ़ाई_, رتفع_, segú, _пуни
  { {0x4df4002d,0x7c3d006f,0xfb1c0009,0x5f440012}},	//   ляєт, llsr, _מוחמ, انكل
  { {0xd371000a,0xe29f0028,0xd49b0d25,0x7e62008e}},	//   لها_, luð_, яра_, _luop
  { {0x2cb800b6,0x2d8502a1,0x3ce80011,0x6d5c0060}},	//   _dprd_, zale_, _छपने_, ıray
  { {0xe29f0028,0x2d851c7e,0xe1ee17de,0x94040012}},	//   nuð_, yale_, аг_, دونه
  { {0x63a2002c,0xda090012,0xb7bd004b,0x27e91c7f}},	//   agon, بيته_, inţe, ljan_
  { {0x2d851c7c,0xaa560012,0x9f400097,0x99830073}},	//   vale_, خلوا_, lkið_, _ųjų_
  { {0x27e90006,0xe29f0028,0x46cd0037,0xbd440012}},	//   njan_, kuð_, ़िलह, _إنفي
  { {0xa3e50011,0x43940048,0xe29f0097,0x32550bda}},	//   नान_, _щатс, juð_, _авар
  { {0x7c36007a,0x388c0066,0xe29f0028,0xa3df0011}},	//   _skyr, běr_, duð_, ताव_
  { {0x53dd0011,0xb7bd004b,0x2d830159,0x2d851c80}},	//   यांश, enţe, _meje_, rale_
  { {0x0f150015,0xe29f0028,0xf8680012,0x17fb0012}},	//   _имею, fuð_, _أمني_, _عرضة_
  { {0xa3b30044,0x7c3a0061,0x2d851c81,0x3f82001b}},	//   ज्य_, _être, pale_, _reku_
  { {0xaa460014,0xcb120009,0x7a360025,0xdb081087}},	//   тегл, שלך_, lâtr, élér
  { {0x6449004a,0x6d430a95,0xc2120009,0x994a0060}},	//   _ohei, _uzna, בהם_, _dışa_
  { {0x601b0006,0xe4c80003,0x4c9a0009,0xf0920009}},	//   vämä, _أبون_, _חבקו, ינל_
  { {0x9f4f0054,0xbf650012,0x8c370009,0xe5720012}},	// [45c0] _algú_, ادفو, _בטקס_, لطا_
  { {0x601b0006,0x3ead0052,0x27e9004a,0x6b841c02}},	//   tämä, itet_, ajan_, _heig
  { {0x26cf0163,0x7469002d,0x2d831c82,0xd00a096e}},	//   ågor_, ерів_, _deje_, _жене_
  { {0x644901b3,0x6b84007a,0xddc3000f,0xe8d70009}},	//   _chei, _jeig, _minő, _סוכר_
  { {0x09e6002d,0x2360009b,0xfbd3000b,0xa51e0011}},	//   кодн, žijo_, יתא_, _पश्च_
  { {0xc3330093,0x5a33002d,0x67f5000e,0xceb30009}},	//   בוד_, аніт, _máju, _דיש_
  { {0xf993000b,0xa3e50037,0xa0c30012,0x71890009}},	//   ברו_, नाम_, ليوو, תְנַ
  { {0x6b841c83,0x22960012,0x32960012,0x8c461c84}},	//   _neig, _للرس, _للرأ, _ребе
  { {0x3f9800a2,0xa3df0044,0x3ead0058,0x963400f5}},	//   ğru_, तार_, gtet_, лниц
  { {0xe29f0028,0x7ae4005e,0xa3da0011,0xa8060060}},	//   vuð_, äitu, ़ाक_, llığ
  { {0x6b8419a5,0xd59b000b,0x659b0009,0x859b0009}},	//   _beig, וביל, וייק, ושיו
  { {0xd7ef0003,0x91f5001a,0xa806003a,0xe29f0028}},	//   _وكل_, _tíc, nlığ, tuð_
  { {0x5187059a,0xa2d00037,0xadf30037,0x20140002}},	//   кува, दिष्, _आकलन_, ęcią_
  { {0x5cd40003,0x5a341c85,0x3ea01c86,0xe4d40012}},	//   _مقتط, инят, duit_, _مقتد
  { {0xc05b002d,0xa806003a,0xb65b000b,0xd7f8004b}},	//   діа_, klığ, _קדוש, _luăm_
  { {0x28d30037,0xb5fb0164,0xf8040001,0x2baa0037}},	//   थिति, _cuán, ачун, _काया
  { {0x3ea00054,0xc058002d,0xd6d00003,0x4ea70014}},	// [45d0] guit_, тір_, يقِ_, ърва
  { {0x6b84008b,0x9f400028,0x925b0012,0xdd940012}},	//   _zeig, rkið_, _تشعر_, لجمع
  { {0x290a003e,0xdce80010,0xa3df0037,0x65150012}},	//   czba_, radė, ताल_, دوائ
  { {0x200c03eb,0x3ea01c87,0x3ead1c88,0x7b080060}},	//   èdit_, buit_, ytet_, _örtü
  { {0xee840047,0x877a000b,0x60030051,0x8f9a0009}},	//   _высо, _ראשי, _tõmb, _אירי
  { {0x7d150029,0xc3340009,0x7c970012,0x785c001b}},	//   úzsk, סוס_, _لشرا, _učvr
  { {0x64490036,0x6280000e,0x89d60003,0xc8880012}},	//   _thei, ámoz, طوير_, نخيل_
  { {0xb4c10044,0xf7710003,0x6d47013a,0x515c0009}},	//   ्टी_, حاث_, _izja, וכוו
  { {0x6e920003,0x2a640133,0xdbdd0028,0xfc3f0066}},	//   مليا, _gumb_, _ráðs, dlí_
  { {0x6b840061,0x6f090002,0x67f5000e,0x41c00011}},	//   _seig, rzec, _ráju, _एसएस
  { {0xed580026,0x25a50028,0x3ea0000d,0xdcf8004b}},	//   teľa_, _öllu_, zuit_, _revă
  { {0x2d99003a,0x4c9a0009,0x9f4d008e,0xe29a0f21}},	//   şse_, עברו, tkeä_, нам_
  { {0xa806003a,0xa3ab0321,0xfbaa0011,0xb4360009}},	//   nlış, _खान_, _काठम, רָיו_
  { {0x6e92000a,0x5e920003,0x9f4d004a,0x98a600f5}},	//   _الوا, _الوط, rkeä_, лиге
  { {0x3e69001a,0x6b840010,0x63a90dba,0xa8060060}},	//   _hút_, _teig, _ocen, ylığ
  { {0xdcfc001e,0xd9c00037,0x3ea01c89,0x90e70012}},	//   _nerā, _एस्ट, tuit_, دِّل_
  { {0x66e3118d,0xfd9a0012,0xdee307e8,0x70530012}},	// [45e0] бота, فئات_, боти, إنقا
  { {0xfce60001,0x46130003,0xbe130012,0x8a7b0009}},	//   лозо, موقر, موقع, _ראית
  { {0x66fa0035,0xa8060060,0x645e1087,0x7c220d4c}},	//   _sākā, tlığ, _épit, tnor
  { {0xb09b0009,0xdde30035,0xab830a32,0x63a900b8}},	//   _איטר, āršo, бушк, _ccen
  { {0x3e690020,0xa3e50037,0x8c1b000b,0xa806003a}},	//   _nút_, नात_, עוני, rlığ
  { {0x20100034,0x7c221c8a,0xfa880081,0xe9180024}},	//   żnią_, snor, rừ_, колі_
  { {0xdb1d0272,0x67f50026,0xa8061c8b,0xab5b003a}},	//   resé, _nájs, alış, ndür
  { {0xa3d30044,0xb21b0058,0x3e691c8c,0x20021c8d}},	//   _हों_, lsæt, _bút_, óki_
  { {0x69960472,0x9196004c,0xc3260d21,0x7c460035}},	//   _брех, _бјеш, _смак, ārrē
  { {0x32070013,0x88c60003,0x91f5001a,0x60cd0034}},	//   chny_, _متصل, _hín, łama
  { {0xce37000b,0x7bcd03d3,0xd5b7003c,0x91f50081}},	//   ראית_, _paau, усы_, _kín
  { {0xdb550015,0x7bc2002a,0x63550015,0xac190109}},	//   ивны, neou, ивну, тому_
  { {0xb21b0058,0xa3d60011,0x98370009,0xa8370009}},	//   ksæt, _सफर_, _גראף_, _גראד_
  { {0xc3330093,0x2b95001a,0xfc3f05b1,0x6e180012}},	//   מור_, ục_, slí_, _جيتس_
  { {0xb21b00c5,0x5dfb0009,0x7bc20132,0x5ff50488}},	//   dsæt, _אפגנ, keou, азву
  { {0x8ae7002d,0x12e7002d,0xa2c50037,0x8d4b0009}},	//   _біол, _біог, िबद्, _אֲחֵ
  { {0x1de00037,0xa3e80037,0xa3f8000b,0xdd9b00f5}},	// [45f0] नांत, बान_, _תמחק_, еше_
  { {0x27330020,0x27210020,0x65950001,0xb7bd000d}},	//   ợng_, ẳng_, ражу, inţa
  { {0x61fa0051,0x645f0061,0xb4c10037,0x644c0034}},	//   ötle, _épis, ्टे_, łnił
  { {0x9cd70009,0xc3cb0012,0x907a0009,0x7bc20132}},	//   טובה_, عظام_, _שטרי, geou
  { {0x601e001e,0xe9ce010b,0xc7d80048,0x661a016d}},	//   nīmu, ок_, _смях_, kitk
  { {0x3e69001a,0xdce8001e,0x40951c79,0x80a50012}},	//   _rút_, gadī, арит, لمتن
  { {0xa3d60037,0xdb0b0060,0xb7bd004b,0x3e690081}},	//   _सफल_, legü, enţa, _sút_
  { {0xd7200011,0xb27510ef,0x66030064,0xe8890081}},	//   मपंथ_, _влаш, _slnk, rẻ_
  { {0x8a940003,0x628f0002,0x9e650001,0x6f0d0bd3}},	//   _هؤلا, jsco, јвод, nzac
  { {0x44291c8e,0xfe42002d,0x7af6004a,0x75ed000e}},	//   _aja_, жньо, äyte, _húzz
  { {0xe0050037,0x7c291c8f,0x9c26004c,0xc6480012}},	//   रसाद_, _kjer, идод, دجيل_
  { {0x3f890065,0x644d03b5,0x6b8b1c90,0xf3f20009}},	//   _þau_, _chai, nagg, ַ֣ר_
  { {0xeb970098,0x7c290027,0x4429000e,0xaa460063}},	//   шия_, _mjer, _dja_, иемл
  { {0x412a0094,0xcad60009,0x6da20048,0x44290018}},	//   вого_, בושת_, _диша, _eja_
  { {0xf7720003,0xc2120009,0xb4c10011,0x6f0d004b}},	//   قاء_, קהל_, ्टो_, ezac
  { {0xab5b003a,0xc003035c,0x27ff0577,0xa8030024}},	//   rdür, опск, nkun_, озсл
  { {0xd00f000a,0x0d861c42,0xbea601b6,0x2bbb0011}},	// [4600] ذلك_, илан, разк, ोजना
  { {0x6d5a0003,0xdcfc000d,0x2d870052,0xd5e00011}},	//   نجاح_, _neră, _jene_, नाइज
  { {0xdce80039,0x9178001a,0x27ff0028,0x299b000b}},	//   vadī, _lợi_, kkun_, _בסימ
  { {0xc5e9000b,0x661a009b,0xb21b0058,0x32050ec4}},	//   וד_, zitk, ssæt, _ally_
  { {0xb21b0058,0xead40055,0x7ad40012,0xe7fb0011}},	//   psæt, соль, إقتص, _एकता_
  { {0xc9a70001,0x7c291c91,0xdb1d0192,0xfad70009}},	//   авље_, _ejer, rdsø, יונך_
  { {0x91f50020,0xf9930093,0xdce8001e,0x7c29024c}},	//   _tín, קרה_, radī, _fjer
  { {0x61e103eb,0x44c800a2,0x7c290033,0xd6da00ac}},	//   _enll, _iş_, _gjer, вто_
  { {0x539b0093,0x6569003a,0x6fa70037,0xa3cf0037}},	//   _שימו, _şehi, _गारं, _वोट_
  { {0x644215cc,0xceb3000b,0xe8390066,0xc27b000b}},	//   lloi, קית_, ější, _סרבי
  { {0x35db0037,0x44261c92,0x6ca3003c,0x25e80011}},	//   बाज़, ono_, оряж, जाबी_
  { {0x44261c93,0xef1a0e0f,0x2d870070,0x661a004a}},	//   nno_, _име_, _eene_, sitk
  { {0xd7ef0003,0x82370003,0x5457000b,0x628f00c1}},	//   _تكن_, لرسا, יסטן_, usco
  { {0xedd30003,0x628f08de,0xd1260012,0xcce60012}},	//   _ويند, rsco, كم_, _نسبي
  { {0x0494000a,0x7c940003,0xaa5c002d,0x2d8c1c94}},	//   _البح, _البص, терi, made_
  { {0x6f0d03eb,0x44260470,0xdb1d000e,0xf55b000b}},	//   tzac, jno_, lesí, _בדומ
  { {0x60d30010,0x44c81c95,0x4426065f,0xb4c10011}},	// [4610] _žemė, _aş_, dno_, ्ट्_
  { {0xa3e50044,0xdb0b0002,0x7afd004a,0x2d8c1c96}},	//   नाव_, zegó, myst, nade_
  { {0x27ed0006,0x44390051,0x6b8b1c97,0x201e01a0}},	//   yjen_, oos_, tagg, ètic_
  { {0x2d98003e,0x44260fde,0x4424002d,0x2d870002}},	//   órej_, gno_, оєча, źne_
  { {0xf2c70098,0x7c29001c,0x6b8b01a2,0xe7e50037}},	//   рсен, _vjer, ragg, कासा_
  { {0x89a8007c,0x62400006,0xfa78000b,0x88c50003}},	//   иків_, töoi, סעות_, متعل
  { {0x2d8c05ab,0x27ff0065,0xc198002d,0x4998002d}},	//   dade_, tkun_, ртії_, ртія_
  { {0x44391c98,0x7c3b147f,0x2d8c005e,0x5c070198}},	//   jos_, _ukur, eade_, _тяга
  { {0xa9c70098,0xee390ac5,0x44391c99,0x27ff1c07}},	//   _всек, лни_, dos_, rkun_
  { {0xdb1d000e,0x7afd0ff7,0x27ff03b9,0x64990009}},	//   gesí, dyst, skun_, ְיָה
  { {0x27ed000f,0x6b890051,0x2d870051,0xddc60010}},	//   pjen_, _keeg, _vene_, _sukū
  { {0xc0b2001a,0xb8dd0037,0x3eb2008e,0x44391c9a}},	//   _lưới_, ेब_, ytyt_, gos_
  { {0x2d8c0051,0x1dc70011,0xcb020011,0x6b890227}},	//   bade_, रजात, रैंड_, _meeg
  { {0x49990047,0x5d850003,0x3dd10002,0x44260133}},	//   ится_, _الثل, _nazw_, zno_
  { {0x2000008e,0xe29f0097,0x44261c9b,0xa3e50011}},	//   tkii_, arð_, yno_, नाश_
  { {0xb4fa000b,0x7afd0066,0x6e3c009b,0x4439060e}},	//   _תפקי, byst, _skrb, cos_
  { {0x62920029,0x44261c9c,0xa3e50011,0x7bc6005e}},	// [4620] ýkoľ, vno_, नार_, meku
  { {0x4426003e,0x2ca5002a,0x7bc61c9d,0xc0b20081}},	//   wno_, ould_, leku, _cưới_
  { {0xc0b20020,0x4426048b,0x09f7000b,0x3eb2004a}},	//   _dưới_, tno_, _המים_, styt_
  { {0x7bc6044f,0x44d7000d,0x2d8c0017,0xdb1d0bb3}},	//   neku, _mă_, zade_, zesí
  { {0xa91c0029,0x73360012,0x321c0030,0x2d8c1c9e}},	//   _veľm, حرائ, tivy_, yade_
  { {0x2b98001a,0x3c320107,0x4426048b,0xa2d90011}},	//   ức_, rávy_, sno_, मित्
  { {0x7afd003e,0x44391c9f,0x2369080a,0xa3e80037}},	//   zyst, yos_, žaja_, बाद_
  { {0x4fc60015,0xc7c60021,0x2ca504a3,0xe8d70009}},	//   сска, сски, duld_, מוצר_
  { {0xdb1d000f,0x7e7b002c,0x44391ca0,0xf76f0012}},	//   tesí, gpup, vos_, راي_
  { {0x9e14002d,0xade60001,0x2737001a,0x63ad015c}},	//   ідні, сцик, ủng_, _scan
  { {0x44d701b3,0xd7ef0001,0x89db000b,0x2d8c1ca1}},	//   _că_, _еу_, _תחבי, rade_
  { {0x44d7000d,0xccf3000b,0x44390010,0x7afd1ca2}},	//   _dă_, לכת_, uos_, tyst
  { {0xdb1d000e,0xa3ab0037,0xa2d00037,0x44391ca3}},	//   pesí, _खास_, दिग्, ros_
  { {0xdb0f0061,0x17570009,0x7afd1ca4,0x2d9c0018}},	//   édér, _הסדר_, ryst, óvel_
  { {0xb5b7000b,0xdb0b0028,0x59f80014,0x60250010}},	//   _הלוח_, hegð, щеря_, lėmi
  { {0x98a90002,0xc4770009,0x8c190012,0x3ea01ca5}},	//   łać_, _פתחו_, _خيبر_, frit_
  { {0xbe19002d,0x6b890051,0xf41f004a,0x68e8006f}},	// [4630] ажає_, _reeg, miä_, äddr
  { {0xf41f0006,0x6b890051,0xd9f40011,0x7c2d0097}},	//   liä_, _seeg, _अवगत_, _hjar
  { {0x2d8a02d1,0xdfd10003,0x6b890051,0x69c7009b}},	//   _debe_, _قيد_, _peeg, meje
  { {0xab94002d,0xf41f004a,0x3d090011,0x6e3a016d}},	//   зиці, niä_, ानते_, hotb
  { {0x68e00039,0x7867000f,0xdefb0015,0x3ea008b9}},	//   āmde, _műve, _сын_, crit_
  { {0x7bc60002,0x62340024,0xdb040034,0x600a0064}},	//   zeku, печу, _zbió, _výme
  { {0xf41f0006,0xb5fb00f1,0xf1b4000b,0xe7e50037}},	//   kiä_, _otáz, פסק_, काला_
  { {0xdd0e003a,0xf41f004a,0x2ca50070,0xab5b005e}},	//   lışa, jiä_, vuld_, teül
  { {0x44d701b3,0x27f60003,0xaff60012,0xba740012}},	//   _să_, تفيد_, تفيا_, _فالت
  { {0x7c2d00b6,0x69bb0011,0xa1941271,0xe9db0012}},	//   _ajar, श्मी, _науч, _حذرت_
  { {0x442d009b,0xab5b005e,0xf1ad0011,0x20d80081}},	//   _kje_, seül, ञ्छन, _gĩi_
  { {0x44d701b3,0x60250010,0x9cd60009,0x7e7b008e}},	//   _vă_, bėmi, קורה_, ppup
  { {0x69c7000f,0x02f9000b,0x36050012,0x91d60024}},	//   feje, ׁלֹמ, _ووصف, оцві
  { {0x200c001e,0x66ba000b,0x201f0010,0x3ea014b0}},	//   īdim_, _כמנה, liui_, vrit_
  { {0x7c2d0065,0xdb200031,0x798e0032,0x395e1ca6}},	//   _fjar, _ötöd, rabw, äts_
  { {0x1dac0044,0xfc32000a,0x201f0010,0xac170001}},	//   _चाहत, _تحت_, niui_, _моју_
  { {0x7c570003,0xd0070014,0x69c717c7,0xe61a0276}},	// [4640] _بلير_, цете_, beje, ада_
  { {0xbb1b0061,0x64460051,0x3ea0000c,0xdcf80066}},	//   raît, llki, rrit_, _nevě
  { {0xa91c0026,0x2465001e,0x64c60012,0x201f0073}},	//   _veľk, _tēmu_, تيال, kiui_
  { {0x3ea00061,0xfe670003,0x2d8a0029,0x66e60209}},	//   prit_, _يد_, _webe_, _дома
  { {0x6e280028,0xf4130009,0xb4c60011,0x442d0c93}},	//   yndb, ופא_, _उन्_, _dje_
  { {0xed5a0003,0x20230002,0x6d43003a,0xddd5001e}},	//   _نشأت_, ąpił_, _oyna, _aizņ
  { {0xf1b20044,0xdcf80030,0xc0e70012,0x5bc60012}},	//   _जानन, _devě, قفون_, _وترف
  { {0x60250010,0xdfda0014,0x6d4e1ca7,0x69c71ca8}},	//   tėmi, рък_, _izba, zeje
  { {0xf41f004a,0x3b070014,0xc6f70015,0xc053000b}},	//   viä_, _дето_, жных_, וזה_
  { {0xab290003,0x22f70009,0xa3e80011,0xf426005e}},	//   _اسفل_, _וזמן_, बाव_, ääne_
  { {0xf41f0006,0xdb1d0066,0x6474002d,0xbdf70012}},	//   tiä_, desá, ягну, تريا_
  { {0x7ee6000a,0x69d50002,0x9f490028,0x60250010}},	//   _وكان, wdze, kkað_, pėmi
  { {0x9347000a,0xbfa3001a,0x6e3a000e,0xf41f004a}},	//   تخدم, _miề, potb, riä_
  { {0xf41f0006,0xd8770012,0x05b30012,0x41e40024}},	//   siä_, قارب, _يمنح, міса
  { {0x69c71ca9,0xf41f004a,0x22be001e,0x63ab0851}},	//   reje, piä_, lākā_, yggn
  { {0x9983007a,0x7a3f0061,0x7c2d00b6,0x60030051}},	//   tojų_, nêtr, _ujar, _tõmm
  { {0x799a0002,0xd1670014,0xfe700012,0x22be0035}},	// [4650] _odtw, _мъни, ندل_, nākā_
  { {0x067b0009,0xc4db004c,0x05b80012,0x41b20011}},	//   ינמל, иђе_, قدمت_, _जायस
  { {0xfa340003,0x6b8d00b6,0x442b0061,0xa2580012}},	//   _تريد, _keag, onc_, _بشيء_
  { {0x7c3d0006,0x645801a0,0xdfa70012,0x27e600b8}},	//   nosr, _èxit, _بحدي, _nnon_
  { {0x7f76000b,0x2369009b,0x80d30011,0x8c1c0009}},	//   _מערב_, žajo_, डिके, סודי
  { {0x3ea900b6,0xdcee0010,0x7e6b0010,0x245205b1}},	//   muat_, _nebė, _rugp, máme_
  { {0x3ea90006,0xc5f20093,0x245200d9,0xb7bd004b}},	//   luat_, _אדם_, láme_, hiţe
  { {0x97c5000a,0x6b8d000d,0x95f50011,0xa3b30011}},	//   ستعم, _neag, ेस्ट_, _जॉच_
  { {0xa3e80044,0x201f0010,0xa3e50037,0xdb25004a}},	//   बार_, riui_, नाई_, öpäi
  { {0x443d0036,0xee360015,0xc1740003,0x90e70012}},	//   low_, знь_, _قدمت, _وسان
  { {0xa7fb0164,0x044600b3,0x201f0010,0x24520030}},	//   _niño, зенн, piui_, háme_
  { {0x3897007d,0x6446004a,0x00ba0009,0x60ba0009}},	//   măr_, ulki, _למעמ, _לצעד
  { {0xe72e0019,0x6d430002,0x66e50294,0xcf270012}},	//   _че_, _wyna, _хола, _براي
  { {0xddc3001e,0x24520042,0xf67a0009,0x433a0009}},	//   _minū, dáme_, _האסמ, מערב
  { {0xaf9a0109,0xdb1d0042,0x69ad0011,0x753c0032}},	//   йтах_, resá, _जारी, ürzt
  { {0x24520066,0x4c9a0009,0xdb1d0058,0xab5b005e}},	//   fáme_, _השקע, desæ, keüh
  { {0xdfcf000a,0x443d1caa,0xe7ec0011,0x12aa0012}},	// [4660] ديق_, dow_, झाता_, _ادعى_
  { {0x273a0020,0xa3b80037,0x9f490028,0x6569003a}},	//   ừng_, घ्र_, rkað_, _şehr
  { {0x01fb000b,0x50461cab,0xc6890009,0x9f490097}},	//   _הפיל, _необ, רא_, skað_
  { {0x5bb8002d,0x68e10058,0x3ea900b6,0xa3e50011}},	//   ілля_, ælde, buat_, नाए_
  { {0x4422005e,0x3a730024,0x3f92016d,0xbfa30081}},	//   iik_, елір, mayu_, _viề
  { {0xceb3000b,0x7bd6002c,0x3f920c55,0x6b821cac}},	//   _איש_, _layu, layu_, sbog
  { {0xbfa30020,0x3d050037,0xddc20010,0xa3be0011}},	//   _tiề, शनों_, _nuoš, ीजा_
  { {0x4c9b000b,0x22be001e,0x44221270,0xdb060031}},	//   _לבלו, tākā_, jik_, egkí
  { {0x44221cad,0x28ce0011,0x78a30248,0xfaa31cae}},	//   dik_, _हैसि, arnv, _пато
  { {0xddcb00a2,0x4498002d,0xab5b000e,0x14ca003c}},	//   ğişt, овою_, lfüg, быми_
  { {0x61e800c5,0x25ed0037,0xb97b000b,0x6b8d0051}},	//   _indl, घाती_, _הנבי, _peag
  { {0xab5b03de,0x69ca004e,0x10160012,0x88c50012}},	//   nfüg, lefe, _عباد, _تتكل
  { {0xa3be0037,0xcff70009,0x41e70024,0xdcee0073}},	//   ीज़_, _מצאה_, піва, _tebė
  { {0x24520066,0x442200b6,0xaa64013b,0xcf250012}},	//   váme_, aik_, етск, _ترمي
  { {0x3cf80037,0x7c3d02a1,0x55bb0009,0xd5bb0009}},	//   ूनों_, posr, _למגו, _הזול
  { {0x7bd60101,0x99980066,0x24520066,0x3ea90cea}},	//   _gayu, borů_, táme_, tuat_
  { {0xdb1b0028,0xa857000b,0x6bd40012,0xc56b0012}},	// [4670] _nauð, לילה_, _ستير, محال_
  { {0x2d8e0164,0x92b40003,0x61fa004e,0x69ca140a}},	//   _jefe_, _أحيا, _notl, jefe
  { {0xf9fc000b,0x40950012,0x69ca1caf,0x91ba0009}},	//   _להזמ, _تلجر, defe, _ומתי
  { {0x7c2201a2,0x3897000d,0x4ab10011,0x69d81cb0}},	//   gior, văr_, _जमाव, edve
  { {0xf42a0006,0x3ea90054,0x63a4000e,0x61fa003a}},	//   ltää_, quat_, óina, _botl
  { {0xdb1b0028,0x44221cb1,0x7c220018,0x746b0024}},	//   _dauð, zik_, aior, _грав_
  { {0xf9900003,0x7c220002,0xf42a004a,0x61fe005e}},	//   ابه_, bior, ntää_, öpla
  { {0xb7bd000d,0xddc20010,0x63bd0070,0x69d80070}},	//   onţi, _ruoš, jfsn, adve
  { {0x3e72007d,0x6e211b0f,0xfc300012,0x44221cb2}},	//   _cât_, tilb, _صحف_, vik_
  { {0x7bcb05df,0x7bd600b6,0xe5710012,0x5e560012}},	//   legu, _sayu, خطة_, وليس_
  { {0x82340003,0xd5b80035,0x7bd6016d,0x45190357}},	//   _أرقا, enās_, _payu, юция_
  { {0xc209000b,0xb9010037,0x7bcb1cb3,0xea01001a}},	//   _דה_, दि_, negu, _đạt_
  { {0x15f50003,0x24800027,0xa3ab0011,0x60080009}},	//   _يستح, _čime_, _खाई_, _מִסְ
  { {0xa06a011f,0x7c220002,0xbbd90011,0x6d4b0034}},	//   жава_, zior, णयुक, ęgaj
  { {0xb7bd007d,0x2d851cb4,0x7e7d0f31,0x7d7a0009}},	//   enţi, mble_, _atsp, _ונצו
  { {0xd4360003,0x7b07000e,0xe3b20012,0x2be40011}},	//   _تعتب, örté, _شرب_, गाओं_
  { {0x6beb000b,0xdb9b0009,0x4b260024,0x16660048}},	// [4680] _וַיַ, _וספר, _імов, двам
  { {0xdb1b0028,0x2ca51cb5,0x92660012,0xeb9f0040}},	//   _rauð, orld_, _تدعم, nkøn_
  { {0xdd8f0012,0x5ce60012,0xb7bd004b,0x136a0254}},	//   شون_, بكال, anţi, ошли_
  { {0xf7670351,0x730a0003,0x69c10052,0x3f8f0010}},	//   _لا_, يقاف_, _able, _negu_
  { {0xab5b008b,0x69bb0037,0xbd8a0003,0x99870010}},	//   rfüg, श्वी, _ونحن_, jonų_
  { {0x99870010,0x3f8f005e,0x35f40009,0x7a890009}},	//   donų_, _aegu_, _אֶֽל_, פָנַ
  { {0x853c0010,0x38660017,0x6d47005e,0x246c0030}},	//   ngėt, _pior_, üjal, _těmi_
  { {0xd7f0000a,0xf8b30093,0x6f160002,0xc6f80339}},	//   اكة_, דשה_, ozyc, зних_
  { {0xa2d50037,0xf65f014f,0xdb1d0b11,0x28d50011}},	//   _मैप्, _især_, ldsö, _डैनि
  { {0xbafb000b,0xf42a004a,0x61e80058,0x8afb000b}},	//   _והמש, ytää_, _undl, _והמי
  { {0x62820005,0xe0d20003,0xd7f1001a,0x6aa60097}},	//   lpoo, _جزء_, _lũy_, erkf
  { {0x2fd70012,0xb5fb1be3,0xd2f20024,0x6c080012}},	//   _يولد_, _juár, _пiдр, ِيَّ_
  { {0x236d009b,0x27f701bd,0x6240008e,0x1b4b0012}},	//   žejo_, žená_, töop, تؤدي_
  { {0xf42a0006,0x7e7d0026,0x22440012,0x34940fbb}},	//   ttää_, íspe, َنَّ, _закр
  { {0xa3de0011,0xa2d50011,0x6e3b0009,0x6aa600b0}},	//   तया_, _मैन्, _ותגד, arkf
  { {0xf42a004a,0xa3b30037,0x7b67010c,0xe3f80012}},	//   rtää_, ज्ञ_, _отпе, _يعيش_
  { {0xf42a0006,0xcddb0001,0xa3e80011,0x9c580012}},	// [4690] stää_, жње_, बाई_, _تجوز_
  { {0x7bcb0052,0x5dd50012,0x9f591cb6,0xc6180024}},	//   wegu, عقائ, _josé_, мієш_
  { {0x7bcb1cb7,0x550e0011,0x6f160030,0x6282005e}},	//   tegu, ानिए_, azyc, epoo
  { {0x62840039,0xdb510003,0x515a000b,0x6d4701bd}},	//   ģion, هَا_, _מכתו, _vyja
  { {0x6284007d,0x6f160002,0x6d470002,0x645d0010}},	//   ţion, czyc, _wyja, imsi
  { {0x7bcb1cb8,0x5e450012,0x2cac00b0,0x20090073}},	//   segu, _أَسْ, kudd_, lkai_
  { {0x3ced0011,0xda62003c,0x7af600b0,0xedd400ae}},	//   _छपें_, ывши, øytr, _جيّد
  { {0x3ea60010,0x20090071,0x5c650012,0x99870073}},	//   šote_, nkai_, _أُرك, tonų_
  { {0x2009001e,0xe2350001,0xd7ba0009,0xdee50024}},	//   ikai_, _знањ, הֶיך, хопи
  { {0x273e008a,0x272c0020,0xe6160015,0x442f1cb9}},	//   ững_, ếng_, едь_, lng_
  { {0xdddd001e,0x3f8f0051,0x442f0062,0xc3290009}},	//   _atsū, _tegu_, ong_, _פו_
  { {0x672a000e,0xafdb0058,0x99870010,0xa1280012}},	//   ámjá, _skøn, ponų_, _تكمل_
  { {0xe2970047,0x8c1a000b,0x644b003a,0xb3b10037}},	//   ная_, פושי, ilgi, _झारख
  { {0x2fcd0070,0x6f1d0056,0xd2520012,0x4efa0009}},	//   leeg_, úscu, انس_, _מהנו
  { {0xe480003a,0xb5b60009,0xa856004c,0x20560a01}},	//   örüş, _נלקח_, етај, етар
  { {0xad1a000b,0xf3f9000d,0x251a000b,0x68e5008e}},	//   _מוצר, _fiţi_, _מוצא, ähdy
  { {0xddc6007a,0xe7370015,0xab660a2c,0x2d910030}},	// [46a0] _aukš, еет_, _явил, _beze_
  { {0x6e460003,0x6f160002,0x7c261cba,0x2bc10011}},	//   رنام, rzyc, likr, ष्ठा
  { {0x2d9101e4,0x6f16003e,0xb0af0011,0x546a003c}},	//   _deze_, szyc, जूदग, чаем_
  { {0xdb1d006f,0xe7df0037,0x69dc1cbb,0x601100b0}},	//   rdsö, _खोला_, ldre, _påme
  { {0x74130012,0xdb830048,0x61fe1cbc,0x539b0009}},	//   دونا, угчи, _kopl, פיסו
  { {0xf50a0001,0x442f1cbd,0x69ce1cbe,0x4a9b0009}},	//   _енгл_, ang_, nebe, לינג
  { {0x3ce90037,0x2452000e,0x62821cbf,0x30a3003c}},	//   टमों_, záma_, spoo, грыв
  { {0x69ce0052,0xd6d00012,0x7d120060,0xf9570009}},	//   hebe, لقب_, ıksı, עסקת_
  { {0x61eb0272,0xcf26000a,0x87e30047,0x69ce0033}},	//   állí, عربي, ующе, kebe
  { {0x5a9b0009,0x44261cc0,0x8b0b0009,0x4b550048}},	//   _משמא, lio_, _מִבֵ, _ръст
  { {0xf48e002d,0x54550083,0x69dc1cc1,0x20090073}},	//   алiв_, квот, ddre, ykai_
  { {0x8937000b,0x2cac0033,0x44261cc2,0x27fd0132}},	//   _ארבע_, rudd_, nio_, _gown_
  { {0xdfcf0003,0xdcfa001e,0x8c1b000b,0x57fb0009}},	//   _دين_, tatē, לוטי, _מלאו
  { {0x69ce008b,0x7ae40052,0x4426172a,0xd1260003}},	//   gebe, _drit, hio_, لم_
  { {0xdcfa001e,0x8ddb000b,0x7ae4015e,0xddcd0010}},	//   ratē, _זקוק, _erit, tpaž
  { {0x67d400b3,0x44260027,0x69da1cc3,0x69dc0486}},	//   лосу, jio_, _late, adre
  { {0x40340047,0xfe730003,0xb5a70109,0xe3b00012}},	// [46b0] уетс, ادر_, ерей, _ارى_
  { {0x69ce0149,0x8d740003,0x44260018,0x35b4004c}},	//   cebe, هاما, eio_, лбур
  { {0xdcf80039,0x2d910027,0xddd0000d,0xfe37000b}},	//   _ievē, _veze_, şeşt, ערבי_
  { {0x7ae40006,0xf1d90037,0x442f1cc4,0xc9520009}},	//   _yrit, _योजन, ung_, _כמי_
  { {0x539c0009,0x026b003c,0x3f890415,0x6e590012}},	//   ליאו, чшей_, mbau_, _يلجأ_
  { {0xddc6001e,0x6c850012,0x6abd0032,0x442f0fa5}},	//   _tukš, _للسم, itsf, sng_
  { {0x8c3d003a,0x6b750294,0x69da1cc5,0xe5880009}},	//   luğu, _албу, _date, _רָשָ
  { {0x3f890052,0x44261a00,0xf0940009,0x69da0132}},	//   nbau_, cio_, אנק_, _eate
  { {0x41b20037,0x6d4f0002,0x6d4a0060,0x2fcd0227}},	//   _जालस, ęcam, _ayfa, reeg_
  { {0x7d090046,0xdcf8001e,0xe7080012,0x49d90024}},	//   дног_, _nevē, عتين_, _ідею_
  { {0x7c26007a,0x27fd0036,0x7ae4007a,0xa0c40012}},	//   tikr, _town_, _srit, _ميلو
  { {0xe3b20003,0xa6db0028,0xab2a00fa,0x3ea91cc6}},	//   جرد_, _eyði, дома_, krat_
  { {0x765e004a,0x61fe1cc7,0x539a0009,0x7fb60012}},	//   ympy, _popl, וירו, _شهور_
  { {0x8c3d00a2,0x44261cc8,0x4a43010c,0xf1c40011}},	//   duğu, zio_, иняв, ल्पन
  { {0xe8000037,0x3e760058,0x3f890052,0x7ae41cc9}},	//   ैसला_, _sæt_, fbau_, _writ
  { {0xea010020,0x7bdb002c,0xa3b90011,0x69ce1cca}},	//   _đất_, _nauu, _चाय_, sebe
  { {0x61fe00a2,0xf62a0003,0xba3b1ccb,0x6d551161}},	// [46c0] _topl, وسطى_, tuït, _azza
  { {0xee371104,0x9f59000e,0x60db0034,0x4106028b}},	//   вну_, _alsó_, łuma, _азов
  { {0xe3ba0001,0x3ea90a4c,0x64420070,0x44261ccc}},	//   дбе_, arat_, tooi, tio_
  { {0x3ea90e7d,0x8c3d003a,0x3e760058,0xb4fa0009}},	//   brat_, buğu, _tæt_, ופעי
  { {0xc7b30093,0x69da1ccd,0x3ea91cce,0xbb770009}},	//   _דבר_, _pate, crat_, דענו_
  { {0x19580015,0x44261ccf,0xf2d30009,0xb0c6003c}},	//   налы_, sio_, יעד_, вщик
  { {0xc213000b,0x69da0052,0xa3dd0037,0x44261cd0}},	//   שהו_, _vate, _थोक_, pio_
  { {0xf093000b,0x7d03006f,0x69da0eaf,0x4fc6004d}},	//   בנה_, änse, _wate, тска
  { {0x15aa0048,0x62800132,0x8d860578,0xdb06005e}},	//   мъни_, _utmo, кунд, ngkä
  { {0xdb250066,0x531b0009,0x7c241cd1,0x7bc21cd2}},	//   ásít, _חומצ, _amir, lfou
  { {0x26180044,0x29070002,0xa8a50012,0x7ae21cd3}},	//   योगी_, cyna_, _مصنو, lvot
  { {0x3c3c0029,0xd91b0009,0x907b0009,0x7bc20132}},	//   tívy_, _קואל, _חטאי, nfou
  { {0x9f5901a2,0x6d5800d9,0x7bcf166e,0x7a290073}},	//   _così_, ývaj, recu, ežta
  { {0x65940177,0x9e34003c,0xecba0012,0xf7e10034}},	//   _саку, _щелч, _قطعت_, ążeń_
  { {0xef190002,0x06570009,0xe9190024,0x99280048}},	//   daży_, _שיוך_, хові_, вюта_
  { {0x80ba0037,0x01370009,0x60db0009,0xc8db0009}},	//   _एमने, דרלת_, וקלנ, וקלט
  { {0x9f55007c,0xd4380009,0x3f891b88,0x29070034}},	// [46d0] увач, _שטחי_, rbau_, zyna_
  { {0x8b080009,0x06140024,0x7bc20227,0x3ea91cd4}},	//   _יִתֵ, адую, efou, rrat_
  { {0xd371000a,0xd5b80014,0x14740012,0xac740012}},	//   مها_, ъст_, لانج, لانش
  { {0xa9240026,0xa50b0009,0xfbdf0018,0xab5d0034}},	//   ôžet, וּדִ, ndê_, _zaży
  { {0x41c00037,0x13c80009,0x8d770012,0xeabf00b8}},	//   श्वस, דּוֹ_, _لازا, ntù_
  { {0x26d90149,0x201e001e,0x4a440024,0x2b910081}},	//   _isso_, ītie_, анів, ạc_
  { {0xac19076b,0x9f400097,0x98e50012,0x7ae20073}},	//   _зову_, ljið_, اكبو, avot
  { {0x3158000b,0xdb1d03ee,0x29580009,0x29070034}},	//   כיון_, besø, כסוך_, ryna_
  { {0x2f5400be,0x60150029,0x6449008e,0xd00e0012}},	//   итьс, _náme, _ikei, ثلي_
  { {0xba550003,0x629d07c9,0xdcfa0010,0x8ca40011}},	//   _صناع, dsso, natė, _किशो
  { {0x38600028,0x629d1cd5,0xcb090009,0x25e80011}},	//   ymir_, esso, _צל_, जाजी_
  { {0x236900eb,0xde95004c,0x26d91cd6,0x6aab0032}},	//   žaju_, _бадњ, _osso_, orgf
  { {0x8f9a000b,0x8c1a000b,0xfbd20009,0x46a51cd7}},	//   _ניסי, תורי, צתך_, _салв
  { {0x2fc6001c,0xdcfa0010,0xddc3004b,0x2dd90012}},	//   _zbog_, jatė, _dinţ, _سبتة_
  { {0xf6520093,0x8fa61a44,0x35c60011,0x2b490034}},	//   _הצג_, лаве, र्फ़, żach_
  { {0xab5d0034,0x7c241cd8,0x200d0031,0x62861cd9}},	//   _waży, _umir, nkei_, ppko
  { {0x63a4002c,0x3ebf1cda,0x7f1a0024,0x64461cdb}},	// [46e0] _idin, ntut_, хіву_, moki
  { {0x64461cdc,0x64490073,0xa3be0011,0x628401e3}},	//   loki, _akei, ीजक_, _itio
  { {0x26d900c1,0x61fa0051,0xadb70003,0xf7690009}},	//   _esso_, ötlu, اهما_, פק_
  { {0x6446007a,0xdb190002,0x0ecf0037,0x19570009}},	//   noki, jewó, _सैकड, _תבטל_
  { {0x14170003,0xdcb1001a,0x539b000b,0x69c303c0}},	//   دينة_, hủ_, תינו, ffne
  { {0x8ca40037,0xcebf0066,0x5eeb0009,0x7bc20227}},	//   _किलो, ěřte_, _אַלְ, sfou
  { {0x14d8000b,0x26c0004a,0x64461cdd,0x27e01cde}},	//   _בַּמ, ltio_, koki, odin_
  { {0xc8c7000a,0xa6db0028,0xb4c20037,0x244e0042}},	//   اوين_, _eyðu, ्बी_, kými_
  { {0x6446007a,0xa0670001,0x60e00010,0x9f340024}},	//   doki, ћања_, _žymė, репі
  { {0x26c00164,0x6015015b,0x27e0008e,0x20021cdf}},	//   itio_, _ráme, hdin_, _loki_
  { {0x88860015,0xfdf70009,0x3d0e0011,0x1dc60011}},	//   _слеж, אצית_, ानें_, र्यत
  { {0xe8d7000b,0xc953000b,0x64460010,0x6ee60003}},	//   _תואר_, _המע_, goki, _مستل
  { {0x34d10044,0x6f1b0002,0x27e01ce0,0x90570009}},	//   _सन्द, czuc, ddin_, _עבדו_
  { {0x60180028,0xd5760015,0xdddb001e,0x63a41ce1}},	//   _límd, _судь, ppuš, _edin
  { {0x656f0066,0x4d7b0009,0xc9770009,0xcd970009}},	//   ěcht, _ארוע, רגלי_, _גדות_
  { {0xc2750046,0x6c830003,0xf7730003,0x6d581ce2}},	//   _клиј, _اليم, صار_, _izva
  { {0x69c8012e,0x47340003,0x25ab004c,0xa3cb0011}},	// [46f0] _obde, مركز, еђен_, _रॉय_
  { {0x60da0051,0x629b0010,0x442b1ce3,0xdd940012}},	//   _ostm, šuos, lic_, مجمع
  { {0x5c07002d,0xdcf5001e,0xb97a0009,0x63a4008e}},	//   ляда, _iezī, _בנתי, _ydin
  { {0x69de003e,0x78fa000b,0x442b1ce4,0xd5641480}},	//   _zape, _ספרו, nic_, ступ
  { {0x3ec40066,0x92b70003,0x8c1c0009,0x7f9a0009}},	//   ěstí_, احصا, עודי, _בברז
  { {0xa2ad0037,0x7bdf0061,0xca490003,0x8d740012}},	//   _जिन्, _laqu, خلته_, _هافا
  { {0x3d0e0044,0x6ce4002d,0xab95002d,0xbf0d0037}},	//   ानों_, _літе, _вибі, िन्न_
  { {0xdb1d0028,0x92b70003,0x06c90024,0x7bdf1ce5}},	//   efsí, _محطا, вгий_, _naqu
  { {0x7af60006,0xddcb0039,0xcdf50015,0x6f620048}},	//   äytt, _augš, ачны, овъз
  { {0x6f1b003e,0x244e0042,0x7c2b1ce6,0x7ae90018}},	//   rzuc, vými_, ligr, _iret
  { {0xd131000a,0xa8a40001,0x64461ce7,0x3ebf019a}},	//   _بما_, _грчк, toki, stut_
  { {0xe366069b,0x6b660014,0xa9040003,0x78fa000b}},	//   икни, икна, _ابْن, _בפעו
  { {0x7bdf0017,0x8bd60009,0x03d60009,0x64461468}},	//   _daqu, בורו_, בורם_, roki
  { {0xc3320093,0x245c0066,0x3ead1a7f,0x64461468}},	//   קום_, míme_, mret_, soki
  { {0xc8660003,0x77960001,0x3ead0058,0x98a30339}},	//   لطري, ијац, lret_, жисе
  { {0x69de0070,0x2eed001b,0x130600a6,0x290a13e7}},	//   _wape, _šefa_, _взим, ryba_
  { {0x5ea6000a,0xdce100a2,0xa0670de1,0x18670a76}},	// [4700] شمال, malı, рата_, рати_
  { {0x66030006,0x929b000b,0xba9b0009,0xaa9b0009}},	//   _jonk, _שיית, _שסיי, _שביכ
  { {0x8f76002d,0x26c01ce8,0xeb9a004d,0x66030534}},	//   _вугі, stio_, вие_, _monk
  { {0x7d030163,0xa2ad0037,0x5c73002d,0xdce1003a}},	//   änsa, _जिम्, іліт, nalı
  { {0x6018000f,0x24590061,0x3ead0058,0x73360003}},	//   _címe, néma_, jret_, جرائ
  { {0x5bd30044,0x7ae903eb,0x3ead024c,0xc333000b}},	//   _तस्व, _dret, dret_, חוד_
  { {0x8ccd0037,0xdce1003a,0xf993000b,0x1dc60037}},	//   _सहयो, kalı, חרו_, र्णत
  { {0x2d980036,0x3f800029,0x3ec6002d,0x6015022d}},	//   _here_, nciu_, асоб, _rámc
  { {0xdefa0015,0x2d980f5f,0x3ead1ce9,0xf76f0012}},	//   тый_, _kere_, gret_, واً_
  { {0x9a6a0003,0xa3b90037,0xe7310009,0x59b20011}},	//   _شمال_, _चाह_, לֵי_, _जागर
  { {0x2d9800c5,0x0577000b,0x3f800029,0xd9460001}},	//   _mere_, יגים_, kciu_, _тежи
  { {0xdcfa001e,0x245c0029,0x2d981cea,0xa08b0009}},	//   latī, bíme_, _lere_, _סְבִ
  { {0x6603003a,0x6ffb0009,0xc0530009,0x50650012}},	//   _fonk, _שהדפ, _וזף_, _اطلق
  { {0x5d840003,0x442b1ceb,0x2d981cec,0x5e9b0009}},	//   _الغل, sic_, _nere_, _יבדק
  { {0x60150065,0xe453000a,0x365b000b,0x6e3d000e}},	//   _háma, _وضع_, _שכונ, ésbe
  { {0x34fb0093,0xa2d70037,0x20d8001a,0xbeb70030}},	//   _יהוד, यबद्, _mũi_, šíře
  { {0xdcfa0039,0x78750010,0x44290082,0x8d770003}},	// [4710] katī, _išve, _ima_, لاضا
  { {0x2733008a,0x2d98000d,0x2ca70164,0x6018000e}},	//   ảng_, _cere_, ándo_, _címb
  { {0x7ae90027,0x2d981ced,0x245c01bd,0xf9920009}},	//   _sret, _dere_, zíme_, _מרי_
  { {0x7ae91cee,0x25fb0037,0xd8d60009,0x69d51cef}},	//   _pret, लॉजी_, _פורט_, leze
  { {0xf1ec0037,0x77f60009,0x3ea00031,0x7c2b1cf0}},	//   _छोड़_, _המרד_, csit_, rigr
  { {0x4224002d,0x2ba7001a,0xdcfa001e,0xdd2b0010}},	//   одів, ốc_, gatī, _lėša
  { {0x44290a77,0xb7bd000d,0x6b9d001e,0xdce1003a}},	//   _oma_, liţi, kasg, yalı
  { {0x01380093,0x2138000b,0xb938000b,0x8938000b}},	//   ירות_, יטול_, ירוג_, ירוע_
  { {0x69d5000f,0xe1f30003,0x0ab80003,0x60150164}},	//   keze, _وسط_, _نطلب_, _cáma
  { {0x245c0029,0x69d5000e,0x44291cf1,0x644d008e}},	//   ríme_, jeze, _ama_, _akai
  { {0xae1a000b,0x3f800002,0x245c014a,0x69d50222}},	//   רותכ, yciu_, síme_, deze
  { {0x3205002a,0x3ead0058,0x61e11cf2,0xc2090009}},	//   _holy_, pret_, _hall, _אה_
  { {0x20c1000f,0xa3b90037,0x8e851cf3,0xdce1003a}},	//   lói_, _चार_, _الته, ralı
  { {0x69d50358,0xb7bd000d,0xdb0e0025,0xfce90012}},	//   geze, diţi, édéc, _مفتي_
  { {0xfbdf0017,0xf7720003,0x61e11cf4,0xc1720009}},	//   glês_, كاء_, _mall, לחם_
  { {0x3ea00872,0x44291cf5,0x998c0034,0x60181cf6}},	//   tsit_, _gma_, ódł_, _símb
  { {0x8c1b000b,0x7d03006f,0xaf490003,0xee3a0867}},	// [4720] _תופי, änsn, لشكل_, гна_
  { {0xb5a90012,0xc1e10011,0x49960048,0xc3330009}},	//   لامك_, पयोग, _ушит, _מוח_
  { {0x8d5a0148,0x27ff0097,0xecba0012,0xad5a01c6}},	//   ушат_, kjun_, ططات_, урах_
  { {0x2d980274,0xdb0d0051,0xeb9a0012,0xa3cb0011}},	//   _were_, _ebaõ, اضات_, र्प_
  { {0x2d980051,0x6a600052,0xdcfa001e,0x1847000b}},	//   _tere_, röff, tatī, _לְךָ_
  { {0x61e11cf7,0x2d8100b8,0x60150064,0x6a600032}},	//   _call, cche_, _ráma, söff
  { {0x859b0093,0x61e101a2,0xdcfa001e,0x10e60048}},	//   _תשלו, _dall, ratī, сюлм
  { {0x9ee80003,0xc7b9000e,0x6c360003,0x68e10399}},	//   لفعل_, ggő_, _افرا, ældi
  { {0x91ba0003,0xa3cb0011,0xadd8004c,0xdcfa0035}},	//   _مطار_, र्फ_, ампу_, patī
  { {0xc27b000b,0x644d0113,0x442900b6,0x2d980029}},	//   _ערבי, _skai, _sma_, úre_
  { {0x7648039c,0xb7bd007d,0x35cf0037,0xd5b8001e}},	//   rody, ziţi, _सॉफ़, rgā_
  { {0x69d50070,0x6015000e,0x8066004c,0xd7f70048}},	//   weze, _táma, _увеж, _гуш_
  { {0xdb000013,0x69d51cf8,0x2d811cf9,0x6aa20602}},	//   _odmí, teze, yche_, nsof
  { {0xf8dc0011,0x98ac0011,0xbed70009,0xf8ac0011}},	//   _मनाय, _घटाए, _לודז_, _घटाय
  { {0x9583003e,0x5d9b000b,0xd59b000b,0x44291cfa}},	//   łącz, _גבוה, _גבול, _tma_
  { {0x442905ab,0xb9010037,0x0855002d,0xb7bd000d}},	//   _uma_, _धन_, іваю, tiţi
  { {0x2d9e007d,0xdb1d0002,0x8cd40037,0x44391cfb}},	// [4730] oate_, resó, यौरो, mns_
  { {0xdb040052,0xb7bd000d,0x7aed000e,0x7c291237}},	//   _heiß, riţi, _irat, _smer
  { {0xe4d50003,0x7c290070,0x22640066,0xfcd50003}},	//   تقاد, _pmer, řské_, تياج
  { {0x2d811bba,0x44391cfc,0x61e11cfd,0xb47c0024}},	//   sche_, nns_, _sall, укцi
  { {0x799a0036,0xa3cb0044,0x8ca50037,0x44391cfe}},	//   _betw, र्य_, _चटको, ins_
  { {0x20890014,0x20c1000e,0x929c0009,0x2d9e1cff}},	//   айки_, tói_, ניות, jate_
  { {0x600a0029,0x98ac0010,0xa9bc0009,0x27ff008e}},	//   _týmt, _dydį_, אזור, tjun_
  { {0xa3cb0037,0x6b8200c1,0x1e85046d,0xc9180009}},	//   र्म_, ccog, олим, מחות_
  { {0xd7060015,0x290e003a,0xd5c60037,0x61e11d00}},	//   жные_, ayfa_, र्वज, _tall
  { {0xf625007c,0xd0d50014,0xf9930003,0x442f1bf0}},	//   ідно, _мозъ, _ربط_, lig_
  { {0x63a40065,0x7aed007d,0x6d4600a2,0xa3cb0037}},	//   ðing, _arat, şkan, र्भ_
  { {0xd7e4002d,0xae1d0037,0x2d9e0051,0x6b9b0070}},	//   _нічо, योजन_, aate_, _jeug
  { {0xab5b0052,0x6a600032,0xd7f80081,0xda660012}},	//   nfüh, höfe, _đă_, قاسي
  { {0x2d810005,0xe81c0037,0x442f0052,0x44391d01}},	//   _ühe_, नसभा_, hig_, ans_
  { {0xab5b0052,0x7de40003,0x7d03006f,0xa96a00f5}},	//   hfüh, _رسوم, änsl, рива_
  { {0xdfd20003,0x6fb60003,0x442f009b,0x7aed1d02}},	//   بير_, تمرا, jig_, _frat
  { {0x245c0064,0x02460012,0xaa7b0064,0x562a0842}},	// [4740] jíma_, _وَبَ, jvýh, ажам_
  { {0x18160037,0x7e56002d,0x237f0029,0x75d60012}},	//   _तत्व_, ітац, ľuje_, تيطا
  { {0x442f008b,0x16000037,0xb5a90012,0x2bc10011}},	//   fig_, लॉगर_, صالك_, ष्का
  { {0x2d9e007d,0x3d0a0037,0xab5b0032,0x442f1d03}},	//   zate_, ाहते_, ffüh, gig_
  { {0x6d5c0034,0xdddc0031,0x63a900b8,0x6b9b0227}},	//   _wzra, őzől, _dden, _deug
  { {0xaab20037,0xf1ca0037,0xcb13000b,0x2d9e000d}},	//   _जिनक, िभिन, ולד_, xate_
  { {0xa3cb0044,0x6d5c001e,0x6114002d,0xb1170012}},	//   र्ड_, _uzra, ядку, يقها_
  { {0xd0070001,0x2d9e0002,0x644b0cd9,0xa2d50011}},	//   жеће_, wate_, cogi, _मैक्
  { {0x601c000e,0x2d9e1d04,0xdcfc0010,0xdb040032}},	//   _néme, tate_, _perė, _reiß
  { {0x70f60003,0x4439002a,0xd6260003,0x6b9b0052}},	//   _وسائ, wns_, تعبي, _zeug
  { {0x7d7b0093,0xd7fa002d,0xa1770009,0x5d540048}},	//   יניו, _вул_, _ועבד_, якот
  { {0xd7ef0003,0x69ca0032,0x2d9e1d05,0xb8650012}},	//   _لكم_, lffe, sate_, _فانو
  { {0xc2b8002d,0x78750010,0xc17b0024,0xc3340009}},	//   оляє_, _išva, иїв_, לוֹ_
  { {0x7aed0416,0xdb040052,0x442f0ad2,0x69d81d06}},	//   _vrat, _weiß, zig_, neve
  { {0xcf9b1154,0x69c300a2,0x60180028,0x7aed1d07}},	//   ија_, _önem, _síma, _wrat
  { {0x351b000b,0x442f006f,0x58d40024,0x57f4004c}},	//   _כוונ, xig_, ьост, мпст
  { {0xa3cb0044,0x69d81d08,0xfeb80012,0x66071d09}},	// [4750] र्ण_, keve, قالت_, _pojk
  { {0xa2d50011,0x442f1d0a,0x69d8021a,0x45d407ed}},	//   _मैग्, wig_, jeve, моус
  { {0xa3cb0037,0x61da0009,0x89da0009,0xa25b0025}},	//   र्थ_, _הקתד, _החתי, ntôm
  { {0x60181d0b,0x245c0028,0x3eb2021e,0xab940024}},	//   _tíma, tíma_, bryt_, диці
  { {0x386918f1,0x3ffa000b,0x7ccc001e,0x5db70012}},	//   mmar_, _הפרע, vērš, _وإسر
  { {0x69d801e4,0x867a000b,0xab5b0052,0xd2b8000b}},	//   geve, _לרשו, rfüh, קלות_
  { {0xb882022d,0xab5b0052,0xa96901ec,0x718c0009}},	//   žíva, sfüh, щика_, בְחַ
  { {0x97d9002d,0x63f70003,0x63a91d0c,0x113c0009}},	//   ську_, _بأسر, _uden, יתול
  { {0x6d46003a,0x442d048b,0xb6a3001a,0x57fc0009}},	//   şkal, _ime_, _giấ, שלחו
  { {0x60150c1f,0x69d80dc5,0x61e501bd,0x7c2d1d0d}},	//   _támo, ceve, _nahl, _amar
  { {0x2d9c1d0e,0x5dc80009,0xca4800ae,0x443f0ea4}},	//   _deve_, חֶרְ, _بلله_, _kju_
  { {0xca290093,0x2fe40012,0x43460048,0x78f80012}},	//   _גם_, _يكلف, земв, _بعكس_
  { {0x7e7d007a,0xb77a000b,0x442d1d0f,0x66160031}},	//   _nusp, _האנש, _mme_, ágkó
  { {0x7c2d0061,0x867a0009,0xa1870048,0x60180031}},	//   _emar, _פרצו, збра_, _címn
  { {0xe3b20003,0x8dfa000b,0xf8b10003,0x395e006f}},	//   _كرة_, _להסת, َةِ_, åts_
  { {0x7e75001e,0x443f0027,0xa3cb0011,0xa6860024}},	//   _aizp, _nju_, र्द_, злад
  { {0xdfcf0003,0x441b0009,0xf8b80011,0x3f67004c}},	// [4760] طيل_, _לוקס, _इम्प, зито_
  { {0x9f420066,0x7c2d0002,0x3eb2004a,0x443f005e}},	//   _jaké_, _zmar, rryt_, _aju_
  { {0xdcfc001e,0x397b000b,0x717b0009,0xb97b0009}},	//   _ierī, _לטינ, _לניס, _לניי
  { {0x69d80036,0x61e5008b,0x97da0003,0xe4520012}},	//   weve, _zahl, _ابدأ_, رضا_
  { {0x2bc10011,0x1e830adc,0x69d81d10,0x7f770009}},	//   ष्टा, _плям, teve, _מעכב_
  { {0x64a60dc2,0xdd920012,0xb33b1d11,0xdca6054b}},	//   _нага, _سور_, naça, _наги
  { {0x9f490028,0xdb060031,0x69ca0032,0x7e7d0032}},	//   ljað_, egkü, rffe, _zusp
  { {0xd010000a,0x853b000b,0xdfda0014,0xdc8b0009}},	//   ئلة_, _הגלי, сък_, _לְמָ
  { {0x8c430014,0xc6f70015,0xba3d0066,0x644308cf}},	//   _чете, зных_, _kvůl, énie
  { {0xab5b03eb,0xba090012,0x601a0030,0x1dcf0011}},	//   ngüe, _وتلك_, růmy, स्पत
  { {0x9f470066,0xcfaa0012,0x61e50159,0xc5f30009}},	//   ěné_, _هاشم_, _rahl, גדת_
  { {0x25a1008b,0x4917000b,0xbb940015,0x807b000b}},	//   zahl_, _מקבל_, нающ, _הנאצ
  { {0x2d9c0017,0x61e51d12,0xc34b0048,0x69c30060}},	//   _teve_, _pahl, сяне_, _önek
  { {0x58d5002d,0x26db0009,0x9f550025,0xbef70009}},	//   могт, _לקדמ, _âgée_, _מצדו_
  { {0xdcfc0039,0xee290003,0x26000037,0x2b520002}},	//   _derī, _بأنه_, रानी_, żych_
  { {0x8557000b,0x61e50052,0xab5b0054,0x653b000b}},	//   _משוב_, _wahl, egüe, _לעוד
  { {0xdce800a2,0x7bfa0009,0x2328004c,0x25a10032}},	// [4770] madı, _וִיה, _ноћи_, tahl_
  { {0x442d0a3d,0xdce8003a,0xf7700003,0x644f1d13}},	//   _sme_, ladı, طاق_, loci
  { {0xf650000a,0xdb09000e,0xb8830030,0x387401a0}},	//   ائق_, _ideé, říbr, çarà_
  { {0xd371000a,0x644f02d1,0xf77f0017,0x5335003c}},	//   نها_, noci, _faça_, меет
  { {0x27e91147,0x91e5022a,0x14740012,0x2d851d14}},	//   mdan_, доле, رامج, ycle_
  { {0x2d850005,0x200b0029,0x96fa0009,0x4efa0009}},	//   _üle_, _hoci_, _ולשת, _והשו
  { {0xa3dd0037,0xa4d4002d,0x6603004a,0x9f430066}},	//   ड़ा_, _порі, önku, ějí_
  { {0x27e91d15,0xd0f8000b,0x442d06c0,0x37390024}},	//   ndan_, למות_, _ume_, жчою_
  { {0x200b0013,0x27e9006f,0xdce80060,0x62670012}},	//   _moci_, idan_, dadı, _فائق
  { {0xa3cb0037,0x27e9004a,0xe6110003,0x63ad1d16}},	//   र्स_, hdan_, ئشة_, _adan
  { {0x4d65007c,0x1dcf0037,0x044600be,0xc1050003}},	//   ьков, स्यत, денн, _توضي
  { {0xa7150001,0xc2c60003,0x3f1500b3,0x3ed50012}},	//   _одељ, ويجي, _одес, _يقار
  { {0x0cba0044,0x9f420145,0xe2970015,0xc7b20009}},	//   _उम्म, _také_, мая_, _יבא_
  { {0x9e64002d,0x27e91d17,0x6e450012,0x75480031}},	//   _звід, edan_, _تنتم, épzé
  { {0x3cf90037,0x644f0034,0xb33b1d18,0x27e6020d}},	//   ूहों_, boci, raça, _yaon_
  { {0x1dbd0037,0x6f160002,0xa4b60009,0x037a0012}},	//   ्भवत, _życi, _חלקה_, _بحثت_
  { {0x6da60001,0xb33b1d19,0x63a2001b,0x1ea900ae}},	// [4780] диза, paça, vaon, كالي_
  { {0x6b8908cc,0x9f490028,0x67241d1a,0x60181d1b}},	//   _afeg, rjað_, rzij, _tímo
  { {0xa3cb0044,0x9f420029,0x614607e8,0x9be60024}},	//   र्व_, ľké_, _цена, ділк
  { {0xcdc90009,0x77830048,0xf77f0018,0xddc10031}},	//   יך_, _илюз, _taça_, illő
  { {0xda660003,0x0a6a04ac,0x69dc0227,0x7bc60e2a}},	//   واتي, орки_, oere, _ökum
  { {0x2bae0020,0x09e30001,0x66210002,0x408a004c}},	//   ộc_, вољн, ązkó, ољим_
  { {0x3a37000b,0x3d170011,0xdce80060,0xaa370009}},	//   ורסם_, दनों_, yadı, וטסק_
  { {0xa50b000b,0x7ae41d1c,0xb8d60011,0x2fc01d1d}},	//   _וּמִ, _osit, _जि_, ngig_
  { {0xa2890003,0xd6da002d,0xc5f8001e,0x6fd00037}},	//   _فضلك_, іти_, kmēt_, ड्यू
  { {0x27e900a2,0x7c220149,0x601c0061,0xda650003}},	//   zdan_, lhor, _déma, _كالي
  { {0xfe6f000a,0x45b7000b,0x27e6002c,0x2db7000b}},	//   جدي_, ופיל_, _taon_, ולין_
  { {0x78bc0065,0x7c221d1e,0x61e810ce,0x69ce0227}},	//   durv, nhor, _hadl, efbe
  { {0xa3cb0037,0x63a0003a,0x43940001,0x44250010}},	//   र्ष_, _memn, ђарс, ėl_
  { {0x69dc1d1f,0xdce80060,0x6d5c0097,0x99980073}},	//   gere, sadı, ýras, dorų_
  { {0x6ce6002d,0xdfd50015,0x7ae41d20,0x55bb0009}},	//   _ціле, новы, _esit, _ומוו
  { {0xb9070037,0xe3d0001a,0xa3cb0037,0x84470003}},	//   _मई_, _hằng_, र्श_, _تختل
  { {0xfc3f0013,0x200b01a2,0x61fa0227,0xf1ca0064}},	// [4790] mní_, _voci_, _ontl, _kráľ_
  { {0xfc3f0013,0xea010020,0xb33b0054,0x78650017}},	//   lní_, _đặt_, laço, móve
  { {0x26c90027,0xe5c40014,0xfa340003,0xdb1d005e}},	//   stao_, ъсто, _جريد, resõ
  { {0xfc3f0013,0xfbab002d,0xd3db0012,0x5695004c}},	//   nní_, ітей_, تبطا_, _памт
  { {0x2444003a,0xe29900de,0x320c1d21,0x63a01d22}},	//   nıma_, чал_, _body_, _demn
  { {0x11d9000a,0xaab20044,0xdb260031,0x6a600097}},	//   سوعة_, _जिसक, épér, höfn
  { {0xa99c0009,0x03c700b5,0x499c0009,0xfc3f0030}},	//   חבור, _осам, חשוב, kní_
  { {0x61fa0052,0xc5f8001e,0xfc3f0042,0x29160012}},	//   _entl, kmēs_, jní_, عقيد_
  { {0xfc3f0013,0xe3d00020,0xf771000a,0x7a220061}},	//   dní_, _bằng_, داث_, _hôte
  { {0x69dc00bd,0x6cea0037,0xfc3f0066,0x6abd005e}},	//   xere, टिंग_, ení_, dusf
  { {0x82340003,0x81bc001e,0xf6520009,0x8d55003c}},	//   _شركا, _slēg, רצי_, этич
  { {0xeb970047,0x9d1a000b,0x69c50e6a,0x351a0009}},	//   нию_, פורט, _ache, פורנ
  { {0xb4360009,0x4b550048,0x6d5c0097,0x386d1d23}},	//   תָיו_, върт, ýrar, mmer_
  { {0x3ea91d24,0xdca51036,0x78bc1d25,0xb33b0060}},	//   dsat_, _заки, turv, maçl
  { {0xfc3f0013,0xc212000b,0xb5fe001a,0x361a000b}},	//   bní_, נהל_, _khơn, _מוסד
  { {0x7bdd007d,0x7ae40051,0x44e10010,0x14d6000b}},	//   cesu, _tsit, _ių_, _נופל_
  { {0x4420077d,0xc43b000b,0xf43b000b,0x63a61d26}},	// [47a0] _ili_, _מתקי, _מתקש, makn
  { {0xa3c00037,0x63a0000d,0xf77f0017,0x386d0052}},	//   ुभव_, _semn, _faço_, hmer_
  { {0x44e1007a,0x399b000b,0x550f0037,0x386d0029}},	//   _jų_, _מייד, ाहिए_, kmer_
  { {0xf7670351,0xc5f80039,0x070a0012,0x98160012}},	//   _ما_, nmēr_, _فيجي_, _أبدا
  { {0xa3b80044,0xddcf0066,0xafdb00b0,0x3f7b0009}},	//   _चयन_, řeše, _kjøn, _מאכס
  { {0x35c60037,0xfc3f0066,0x25a50028,0x63a600b6}},	//   र्ख़, zní_, jall_, hakn
  { {0xe3d00020,0xe643002d,0x442002bd,0x61e8001e}},	//   _rằng_, _серп, _oli_, _vadl
  { {0x320c0002,0xc6f81846,0xf8b30009,0xfc3f0030}},	//   _wody_, дних_, אשה_, xní_
  { {0xfc3f0013,0x63a600b6,0xec37000b,0x25a51d27}},	//   vní_, dakn, _נאמר_, fall_
  { {0xceb30093,0x4420102c,0xcad70009,0x6abd005e}},	//   נית_, _ali_, _אומת_, vusf
  { {0x6018000f,0xfc3f0e7d,0x442007a8,0x43950ba0}},	//   _címk, tní_, _bli_, канс
  { {0x6376003a,0xc4d30009,0x7c670012,0x611b0009}},	//   _günü, נגר_, عادل, _מובה
  { {0xfc3f0145,0xee3f0066,0x601c0025,0x25a51d28}},	//   rní_, _svým_, _hémo, ball_
  { {0x4efb000b,0x7af6004a,0xfc3f05b1,0xc5f800cd}},	//   _מהדו, äyty, sní_, amēr_
  { {0x9f470013,0xb33b0c56,0xfc3f01bd,0x99840012}},	//   ění_, paço, pní_, الفو
  { {0x442001a2,0x601c0061,0xa157000b,0x155b0009}},	//   _gli_, _mémo, גבלה_, _מכוב
  { {0xfc400066,0x32070002,0xaae70003,0x69c50392}},	// [47b0] čít_, yjny_, _أسبو, _tche
  { {0x6ca7007c,0x63a40065,0x163b0012,0x92b40012}},	//   ердж, ðinn, أسرة_, _إحيا
  { {0xe1ff0020,0x4420004a,0xdcbb0014,0x3ea902bc}},	//   _đó_, _yli_, яща_, ssat_
  { {0x3ea90066,0x9f5f0028,0xb33b003a,0x43750012}},	//   psat_, kkuð_, yaçl, نهار
  { {0x2009000e,0xc43c0009,0xfbd30011,0x2bd30011}},	//   mjai_, התאי, ध्यम, ध्या
  { {0xdc130060,0x20090031,0xbcb40030,0x63a60031}},	//   rşıs, ljai_, ýším, zakn
  { {0x63a600b6,0x6d42000d,0x25a51d29,0xe9a80012}},	//   yakn, şoar, vall_, ردون_
  { {0x601c0108,0x8f75002d,0x7f75002d,0x6018000e}},	//   _démo, купі, купц, _címh
  { {0x25a51d2a,0x24590042,0x63a6012b,0xc7d80009}},	//   tall_, nému_, vakn, תוחי_
  { {0x273e001a,0xb33b003a,0x45850048,0x93780012}},	//   ắng_, raçl, ъгов, _أصفر_
  { {0xcec00066,0xb5fe001a,0xc5f20009,0x91f60009}},	//   ěřit_, _thơn, בדי_, _שמעו_
  { {0x24590042,0xd6b50048,0x69c3005e,0xe78701c6}},	//   kému_, _айдъ, lgne, _чужо
  { {0xe3b8003a,0x25a5005e,0x27ed1d2b,0x683a0030}},	//   ğı_, pall_, mden_, hůdc
  { {0x44e10010,0xc332000b,0x27ed1d2c,0xa96a0048}},	//   _tų_, שוך_, lden_, дига_
  { {0x205602ac,0xa0a30593,0x408c0009,0x3ebf0c44}},	//   втар, иард, ּאמְ, luut_
  { {0xf772000a,0x78480066,0x4420002c,0x2009000e}},	//   لاء_, pěve, _uli_, gjai_
  { {0x59e10037,0x7c650003,0x63a4001e,0x3ebf0070}},	// [47c0] फ़ार, _حاول, _iein, nuut_
  { {0x27ed0006,0xdb040017,0x200f1d2d,0x395a0032}},	//   hden_, _adiç, _logi_, _typs_
  { {0xe8760003,0x63a41d2e,0x60181d2f,0xd6e20034}},	//   _لاحظ, _kein, _lími, _siłą_
  { {0xb4d20037,0x7af60b32,0x44201d30,0x35c60011}},	//   _वही_, _kryt, ói_, र्ज़
  { {0xa3d40044,0x25a300c5,0x63a4008b,0x7ad40003}},	//   स्य_, _fejl_, _mein, اقتص
  { {0xbda50003,0xdb040017,0x6263002d,0x7ae20002}},	//   _محفو, _ediç, авча, rwot
  { {0x7d030163,0xadd7000b,0x27ed1d31,0x40340bda}},	//   änst, _שולח_, fden_, лекс
  { {0x6b850003,0x27e0027e,0x63a41d32,0xa3d40011}},	//   _مشكل, nein_, _nein, स्म_
  { {0x6a600028,0x2e4a0014,0x09e60015,0xcf930009}},	//   töfl, дяно_, _иоан, בטח_
  { {0x44260149,0x4b550098,0xa3c20037,0x601c1d33}},	//   lho_, _съст, ्भव_, _témo
  { {0x27e00006,0x55bb000b,0x63a41d34,0xe60f0012}},	//   kein_, ומיו, _bein, تشي_
  { {0x44260149,0x644215cc,0x3ebf0562,0x97c50012}},	//   nho_, nnoi, buut_, _متهم
  { {0x63a41418,0x539b0009,0x29180097,0xf1c90011}},	//   _dein, ויכו, eyra_, _रामन
  { {0x3eb90026,0x752d0066,0x24590042,0xe7170009}},	//   áste_, _řaze, vému_, _בחדר_
  { {0x301b0003,0x19580015,0xa15800b3,0x7865000e}},	//   وترة_, вары_, вару_, lóva
  { {0x44260026,0x7e7c1d35,0x63a40227,0x7c260032}},	//   jho_, _airp, _gein, chkr
  { {0x163b0003,0x245c0042,0x6d5c0060,0x62841d36}},	// [47d0] وسطة_, cími_, _ayra, _guio
  { {0x27ed00a2,0x8b58000b,0x2fdf0052,0x442601bd}},	//   zden_, _ביחס_, zeug_, eho_
  { {0x27ed1d37,0x2009000e,0x16050011,0xfba70011}},	//   yden_, pjai_, राबर_, _ख़ाम
  { {0x44391d38,0x88f60009,0x93940012,0xeab10012}},	//   nis_, _עזרו_, لجها, معت_
  { {0x67460026,0x1dc20037,0x8f9a000b,0x44390574}},	//   čujú, _शांत, _רישי, iis_
  { {0x78ba0027,0x7d03006f,0x44391d39,0x78750073}},	//   štve, änss, his_, _išvi
  { {0x69c30005,0x09f60012,0xa3d40011,0x1634003c}},	//   rgne, طفية_, स्ड_, _теря
  { {0x44390039,0x63ad0028,0xf094000b,0x27ed1d3a}},	//   jis_, ðand, בנק_, uden_
  { {0x27ed1d3b,0x4439016c,0xd7f8004c,0xa3c20011}},	//   rden_, dis_, туј_, ्भर_
  { {0x63a408fa,0xf9930003,0x67290002,0x7d090001}},	//   _sein, _ضبط_, rzej, еног_
  { {0xf992000b,0x63a405d1,0x61130066,0xdb001d3c}},	//   _הרב_, _pein, _dělá, _remé
  { {0x9ef50003,0xab2a004c,0x9cd60009,0x245c1d3d}},	//   _مستش, еома_, נורה_, tími_
  { {0x8c1a0093,0x63bb0028,0xdd030060,0x63a41d3e}},	//   גורי, óuna, ısıd, _vein
  { {0x44391d3f,0xceb20009,0xe6c20097,0xbb3a0009}},	//   ais_, _פיו_, _óháð, תעשי
  { {0x3d1d0044,0x63a40703,0x69a50037,0x3ead1d40}},	//   पनों_, _tein, _क़री, lset_
  { {0x7d1c038e,0x3f8d0d04,0x1dcf0011,0x2ca60048}},	//   ørse, nceu_, त्रत, _скъп_
  { {0x44260029,0x291e1d41,0x3ead1d42,0x1db70011}},	// [47e0] vho_, šta_, nset_, _आयात
  { {0x3ead0006,0x683e001e,0xee370430,0x61fe1d43}},	//   iset_, rīdi, гну_, _unpl
  { {0xa3cb0044,0x7ae903d5,0x7865000e,0x9f470066}},	//   र्क_, _aset, zóva, ěná_
  { {0x69c300a2,0x3ead1d44,0x7bc60807,0x44260066}},	//   _öner, kset_, ngku, uho_
  { {0x6d5c003e,0x28c60011,0x539b0009,0xa3cc0011}},	//   _wyra, रंभि, גינו, _लान_
  { {0xa3d40044,0x38601d45,0xf2d3000b,0xe2970001}},	//   स्त_, llir_, צעו_, ћај_
  { {0x7ae9000f,0x98a30046,0x60150028,0xe0cf0012}},	//   _eset, бије, _náms, كزي_
  { {0xb8140001,0xdfd00003,0xb4fb0009,0x78650031}},	//   рдиј, آية_, _אפלי, tóva
  { {0x63ad0028,0x74130012,0x44241d46,0x57f3003c}},	//   ðane, _اوقا, _ilm_, спыт
  { {0x68ed0002,0x7c2400b6,0x5a560014,0x1ed70012}},	//   łada, _alir, _събу, ابيب_
  { {0xd657000b,0x97c60003,0x29181732,0x50ba0012}},	//   ריית_, _مقاو, _æra_, _سداد_
  { {0x44391d47,0x7c24004b,0xb4270012,0x60150ca4}},	//   uis_, _clir, اعدو, _dáms
  { {0xa3cb0037,0x2bc60011,0x75d60012,0x23c60011}},	//   र्ग_, _वारा, _ميشا, _वारद
  { {0xf7730009,0x6594003c,0xa2cc0011,0xa2a90011}},	//   _פקס_, _таку, _समन्, _क़िस्
  { {0xa15903a8,0x361b0009,0x6e3a0031,0x439505c8}},	//   таву_, _אוגד, mitb, _кайс
  { {0x6d460060,0xdb060031,0xff070048,0x99630030}},	//   şkas, zaké, лязн, _tíži_
  { {0x245c0066,0x6c480012,0x9635054b,0xd5bb193d}},	// [47f0] nímu_, _حليف_, анац, есе_
  { {0xf2d40009,0x3d27003c,0xafdb00b0,0xa7740148}},	//   _העץ_, льев, _kjøk, случ
  { {0xa807003a,0x38600c23,0x33950012,0x9b950012}},	//   ngıç, blir_, للاز, للات
  { {0x69c70119,0xf41f004a,0xb89a000b,0x289a0009}},	//   lgje, nkä_, _שברש, _שירא
  { {0xf41f004a,0x83880024,0x9f420064,0x245c0030}},	//   ikä_, убів_, _taká_, jímu_
  { {0xa3cc0044,0x8d770003,0x3ead0051,0x76ba000b}},	//   _लाभ_, _مازا, vset_, _במשפ
  { {0x5a180009,0xdb060031,0x644a0fc0,0xa8020060}},	//   רקון_, raké, éfic, ğınm
  { {0xc888000a,0x0138000b,0xb8cd0037,0x3ead0038}},	//   دخول_, טרות_, _कब_, tset_
  { {0x78a40027,0x99830010,0x60060015,0x3cef0030}},	//   ćiva, nijų_, рным_, ťově_
  { {0xf41f004a,0x3f8d0017,0xab5b003a,0x63ab1359}},	//   ekä_, sceu_, rgül, lagn
  { {0x99840351,0xcb09000b,0x2369009b,0x9f420029}},	//   _المو, _קל_, _azaj_, ľká_
  { {0x69c7000f,0x61e30b51,0x8f750024,0x7bc60097}},	//   egje, lenl, _кулі, _ökut
  { {0xde05007c,0x60c300a2,0x501a000b,0x539a000b}},	//   _впли, lunm, _שונו, כירו
  { {0x7a2b00a1,0x8d87002d,0x672d04f4,0x99830073}},	//   _lütf, _судд, dzaj, dijų_
  { {0x70560012,0x505a003c,0x26090011,0xc87f0032}},	//   لنسا, вшая_, सानी_, _biß_
  { {0xdb0b0028,0x63ab0027,0x61e303de,0x201f0073}},	//   yggð, jagn, henl, nkui_

  { {0xe5a30020,0x8445000a,0x65960003,0x63ab00c1}},	// [4800] _điệ, _دخول, لجار, dagn
  { {0xbda50003,0xf98a0003,0xfd96003c,0x41aa0011}},	//   محمو, _جندي_, ршаю, _क़िस
  { {0x20d10020,0xdddd000d,0xcdb6000b,0x84e60083}},	//   _nơi_, _susţ, שפעה_, роеж
  { {0x6018000e,0x27ef002c,0xf1d20011,0x74690024}},	//   _címt, _nagn_, द्रन, грів_
  { {0xa3cb0044,0x9983007a,0x672d003e,0xf19408b0}},	//   र्ट_, cijų_, czaj, биль
  { {0x3ceb004a,0xca560001,0xd3570009,0x5a330024}},	//   äivä_, штењ, סיסי_, оніт
  { {0x03a6007c,0x68ed0002,0xf1b30009,0x22290012}},	//   _вибо, ładn, קסה_, دثني_
  { {0xdfda0014,0xf093000b,0xdb0b003a,0x60180028}},	//   тък_, חנה_, _çiçe, _tímu
  { {0x963402ac,0xe61f0081,0x7e2a0024,0x61e30032}},	//   йниц, _muôn_, віна_, benl
  { {0x20d6007c,0x60de0119,0xe61f0020,0x3eb8009b}},	//   _відс, _oppm, _luôn_, črt_
  { {0xf41f004a,0xac190635,0x6e3a1d48,0x2419003c}},	//   tkä_, гону_, ritb, гоны_
  { {0x493b0009,0x6ee60012,0x711b0009,0x35ca0011}},	//   _בגבו, _نستل, _שואפ, ़्ज़
  { {0x6e94000a,0xe6940003,0x5e940003,0x2aa8002d}},	//   _التا, _التد, _التط, итро_
  { {0xa3cb0037,0x26c40010,0x78af008e,0x94d40012}},	//   र्ज_, mumo_, _äivä, _هيتش
  { {0xe61f001a,0x15fb0009,0x97a71390,0x69c700b0}},	//   _buôn_, _שִׂמ, ирал, rgje
  { {0xcf981154,0x61e300a2,0x02a70047,0x5d7b000b}},	//   ију_, zenl, _кром, _באוק
  { {0x69d50052,0x7c3d0269,0x61e302f7,0xd7f8004c}},	// [4810] pfze, misr, yenl, јус_
  { {0x60c30101,0x7c3d0051,0x99830010,0x60180028}},	//   yunm, lisr, rijų_, _símt
  { {0x228b1a41,0x61e31d49,0x99830010,0x6018000e}},	//   _søk_, venl, sijų_, _címs
  { {0xa3cb0044,0x20d1001a,0x60c3003a,0xccf80001}},	//   र्च_, _rơi_, vunm, шћу_
  { {0xa3d90044,0x78480066,0xadf80037,0x1da70037}},	//   ठ्य_, těvn, ्ञान_, _ग़लत
  { {0xa802003a,0xff160009,0xdcee0030,0x09e10011}},	//   şılm, _הקשת_, áděj, फ़ेय
  { {0x61e31d4a,0xd24e0003,0x601805b1,0xe8f50012}},	//   renl, عنى_, _tímt, إستخ
  { {0x9f950005,0xdb000066,0x68ed0002,0x1ec90015}},	//   _nüüd_, _zemí, łado, глии_
  { {0x26c40010,0x7fe80012,0xa2940024,0x64590034}},	//   gumo_, شريف_, _маті, mowi
  { {0x2d8300c5,0x20d1001a,0x64591018,0x060900b3}},	//   øje_, _tơi_, lowi, унок_
  { {0x30850351,0xa0c40003,0x9099011d,0x20850012}},	//   _الصف, _ويكو, _свет_, _الصّ
  { {0x6459003e,0x1dd80037,0x2e240028,0x9ee90012}},	//   nowi, ब्बत, _nöfn_, _مفصل_
  { {0x7aed000f,0x0b430024,0x63a91cbf,0xa3cf0011}},	//   _csat, знян, _meen, _शान_
  { {0xa3d70037,0x2bb8001a,0x601c1d4b,0x645917e6}},	//   ़्त_, ọc_, _rémi, howi
  { {0x64590002,0x7aed1d4c,0x66031d4d,0x601c0025}},	//   kowi, _esat, _innk, _sémi
  { {0xdfd20003,0xdb06000e,0xc9520009,0x351a0009}},	//   ثير_, lakí, פמן_, _תוקנ
  { {0x64590002,0xa067010c,0x18670129,0x1ea90012}},	// [4820] dowi, сата_, сати_, لالي_
  { {0x6018000f,0x8337000b,0xdcfc001e,0xa3d40011}},	//   _címr, _לאפס_, _agrā, स्र_
  { {0x7afb0051,0x60de006f,0x63a90480,0xeb9a0015}},	//   _arut, _uppm, _been, гие_
  { {0xdc19003e,0x3ebf016d,0xf74604a5,0x64591d4e}},	//   _błęd, krut_, _гемо, gowi
  { {0xcf93000b,0x69ce003a,0x6d5c01bd,0x442209a1}},	//   _מטר_, _öbek, ýraz, ikk_
  { {0x765c1b2b,0xcad70009,0x41db0011,0xee3a003c}},	//   _ukry, מונת_, म्पस, _снг_
  { {0x64590002,0x50b70012,0xde880081,0x89d30012}},	//   bowi, مديد_, _cịn_, ستوط
  { {0x24b70093,0x26c4007a,0x3014002d,0x443d0002}},	//   _להלן_, tumo_, ідпр, ciw_
  { {0xaac5000a,0x8b260015,0xdb0e004a,0x501b0009}},	//   _وتكن, _удае, äjäl, טוקו
  { {0xa6340024,0xe2460012,0x2d9e0032,0xacb4004c}},	//   інні, _اخري, ubte_, обољ
  { {0xa3bc0037,0x8afd0066,0xa3cf0037,0x26c417d7}},	//   _आया_, _vyře, _शाम_, sumo_
  { {0x7f86000a,0x3eb2004a,0x2c270024,0x7d7b0009}},	//   _الإن, ksyt_, сьог, טניו
  { {0xb857000a,0xe0430047,0xb7db0009,0x25ac0030}},	//   _النص_, _энци, _תקדי, padl_
  { {0x2003001e,0x05c70037,0x64590002,0xc3330009}},	//   ējie_, _लाइब, zowi, לור_
  { {0xa3d505d8,0x7c221d4f,0x66151d50,0x765a0034}},	//   _дойч, kkor, _rozk, moty
  { {0x2c7b0039,0x17fb0012,0x988b0009,0x3ea60034}},	//   _līdz_, درسة_, טָמֵ, _kwot_
  { {0x7aed0850,0x98aa001e,0x442905a2,0xdd9b0024}},	// [4830] _usat, ākās_, _ila_, гше_
  { {0x644a1d51,0x45d4004c,0x64590034,0xf1a70681}},	//   éfin, зофс, wowi, _урин
  { {0x26c01d52,0x657a0028,0x4ddb000b,0x54a70003}},	//   ario_, _úthl, רחבו, صحاف
  { {0x237f0027,0x69ca000e,0xd9e10037,0xdb06000e}},	//   žuju_, egfe, फ़्ट, zakí
  { {0x63a90647,0x248d024e,0x64591d53,0x02c50024}},	//   _veen, _čemu_, rowi, ійко
  { {0xcad8000b,0x43740024,0x5ee80009,0xf6280024}},	//   צוות_, чуєт, _פַרְ, _ліси_
  { {0x63a90005,0x6459003e,0x7a2b0052,0x44220993}},	//   _teen, powi, _güte, ykk_
  { {0xe7390047,0x682a0066,0x2ca7000d,0x7afb0a5f}},	//   ией_, _týde, ându_, _trut
  { {0x7c29003a,0x63b40066,0x3ffa0009,0x56290048}},	//   _iler, řený, בִיא, ижим_
  { {0xc8ab0098,0xfe42002d,0x765a17b3,0xee39083a}},	//   _бъде_, дньо, goty, рно_
  { {0x67d5007c,0x51f40003,0x16c60037,0x240a0014}},	//   _можу, _عسكر, _लम्ब, анни_
  { {0xc2090093,0x7bcb0807,0x19560009,0x76480914}},	//   _בה_, nggu, _ובעל_, andy
  { {0x44290656,0x61e71c21,0xe80d0011,0x5ac70048}},	//   _dla_, fejl, हाना_, олям_
  { {0x44290149,0xa2cc0044,0xf6960012,0xdb0b0025}},	//   _ela_, _समस्, _بنوع_, gagé
  { {0x7c220002,0x7c660012,0xfc320012,0x71760012}},	//   ykor, _واعل, _يحب_, زهرا
  { {0xdfa6000a,0xf1db0037,0xfc3f015d,0x14760012}},	//   تحسي, म्बन, cií_, _باتج
  { {0x32050036,0xba760003,0x7aa60003,0xfe050037}},	// [4840] _only_, _واخت, _بإعل, रांस_
  { {0x6a600028,0x26c20027,0x63ad0028,0x26c00e2f}},	//   töfu, škog_, ðann, rrio_
  { {0x55ba000b,0x5ce60003,0x89db0009,0xd3020011}},	//   שמעו, تكال, _דחיי, लम्ब_
  { {0xf8b30093,0x26c01d54,0x6a600028,0xab660400}},	//   _קשר_, prio_, röfu, овел
  { {0x3ce60029,0xdb00000e,0x6da60012,0xe2f80024}},	//   ňov_, _bemá, _ومحم, селі_
  { {0xdca60c7b,0x5ba70011,0xfc3f009e,0xe8ea0012}},	//   _маги, _ख़्व, zií_, لربو_
  { {0xc27b000b,0x628f0061,0xdb000164,0x082a004d}},	//   ברסי, _écon, _demá, иции_
  { {0xdfd0000a,0xdb000054,0xd6da13e3,0x7c290097}},	//   ريخ_, _temà, ато_, _gler
  { {0x69960014,0x63a40028,0xaad10011,0x11d60024}},	//   _дрех, ðinu, _समयक, _міжр
  { {0x44290070,0x19c3002d,0xddd80604,0xcd2a0012}},	//   _sla_, _обум, _bivš, لسجن_
  { {0x61e70058,0x96170003,0x44290ce3,0xc27b0009}},	//   vejl, تغير_, _pla_, _כרמי
  { {0x2d870989,0x94bb0009,0xc0460012,0xbb94003c}},	//   _egne_, סמכת, _بخطو, мающ
  { {0xa3dc0037,0xfc3f01bd,0x28130012,0x765a0034}},	//   त्य_, rií_, _تونس, poty
  { {0x8ccb0037,0xe5340015,0x220a000b,0xfc3f0029}},	//   _हमलो, _нель, ׁפָּ, sií_
  { {0x307b0003,0x35dd0037,0x659b0009,0x63a21d55}},	//   لحرة_, न्फ़, _דיוק, kbon
  { {0xa3dc0037,0x1ddd0037,0x98be0073,0xdb0f0060}},	//   त्म_, न्नत, _lytį_, _çeçe
  { {0x36d40047,0x23280001,0xc987072b,0xc58b003c}},	// [4850] мотр, _моћи_, _муни, ащее_
  { {0x645d007d,0xccfb0001,0xdd9b0511,0x41c90011}},	//   losi, иће_, рша_, _राइस
  { {0x12780003,0x69c40011,0xbebd0cac,0x63ad1d56}},	//   _بحيث_, _राजी, nzūr, _kean
  { {0x515a0093,0x6908000b,0x4429001a,0x68ed0002}},	//   _לכתו, _וּשְ, óa_, ładk
  { {0x63ad0036,0xfaa5085b,0x93fc0009,0xaae70012}},	//   _mean, чало, ילאי, تساو
  { {0xa2cc0044,0x62850066,0x171a000b,0x78650164}},	//   _समर्, _jiho, _הושע, móvi
  { {0xa3cc0037,0x24840028,0x7d1c0260,0x69250024}},	//   _लाल_, _fimm_, ørsl, ямка
  { {0xe7cb0037,0x6fcb0037,0x60090ec6,0x1bb80012}},	//   िलिप, िलिं, сним_, _واقع_
  { {0xd7060015,0xee390a38,0xafdb0040,0x1ab40198}},	//   зные_, йни_, _imød, _обтя
  { {0xdb0000c5,0xf1a713f0,0xa90700ae,0x59d205f3}},	//   _bemæ, _фран, _وبان, _सायर
  { {0x80a4000a,0x1ddd0037,0x27e9004a,0x11d40012}},	//   _يمكن, न्यत, kean_, _تتقد
  { {0xf0f90037,0xb8ef0011,0x645d1d57,0x35cf0011}},	//   ्मीद_, वं_, gosi, त्ज़
  { {0xf1d201e1,0x2d870029,0x59d20011,0x644b1d58}},	//   _सामन, ľnej_, _सामर, ingi
  { {0xcb12000b,0x2d870029,0x4efa0009,0x52d60009}},	//   עלם_, žnej_, _להנו, הושע_
  { {0x16380012,0x52c80011,0x6285016d,0x76411d59}},	//   _بسنة_, _रम्स, _diho, mily
  { {0x7641004a,0x2c7b0010,0x63ad1d5a,0xc1720009}},	//   lily, _būdu_, _gean, תחל_
  { {0x6fad0044,0x99550066,0x6f160002,0x0cdb0037}},	// [4860] _ज़रू, _výši_, _życz, _बहुम
  { {0xc3330009,0x63bb1d5b,0xf3f80035,0x644b1d5c}},	//   _רוז_, _adun, ēģu_, engi
  { {0xd5b1001a,0x3a370009,0xcea90009,0xf6520009}},	//   iá_, _זרים_, רי_, עצב_
  { {0xae050011,0x546a003c,0x9f420064,0x05770012}},	//   राउन_, щаем_, ľkú_, سمنة_
  { {0x628f0061,0x76410028,0x57fb0009,0x69ce0897}},	//   _écol, kily, _הלכו, ogbe
  { {0x69d500a2,0x78480066,0xa8a60dc2,0x3ea01d5d}},	//   _özel, pěvk, прик, mpit_
  { {0x8afd0066,0x69dc1d5e,0x03a605fb,0x64a609cc}},	//   _vyřa, ifre, _ниво, _хаба
  { {0x7d1c0119,0x92c1003a,0xbbc60037,0x289b000b}},	//   ørsm, üğün, वलोक, זיקא
  { {0xafdb0119,0x6442004a,0xd5b8001e,0x69dc0910}},	//   _kjør, mioi, skām_, kfre
  { {0xd7370093,0x0f37000b,0x44261d5f,0x984e003a}},	//   פטית_, פריט_, lko_, rşın_
  { {0xa96a0003,0xc19b000b,0x442611d7,0xaa570012}},	//   _امام_, _השבי, oko_, _علما_
  { {0xb8650003,0x9f400164,0xdb0f0061,0x645d1d60}},	//   _قانو, ndió_, lacé, uosi
  { {0xe8090044,0x260c0011,0x291801a0,0xc0170009}},	//   वारा_, ़ादी_, _àrab_, _מקאו_
  { {0x4426066e,0xa3dc0037,0xc7450003,0xeb9f0033}},	//   hko_, त्त_, _تضمي, gjør_
  { {0x44261d61,0x69ce0037,0xd49a0001,0x4ddb0009}},	//   kko_, _तारी, _урл_, _החוו
  { {0xc5f80035,0x69ce020d,0x44261d62,0xa09b00af}},	//   ldē_, agbe, jko_, מילט
  { {0xb6a30020,0xa3c20044,0x3bbc000b,0xd3710003}},	// [4870] _nhấ, ूलन_, _המחד, _جهة_
  { {0x682a01bd,0xa3cf0011,0xc5f80035,0x26c40035}},	//   _výda, _शाह_, ndē_, irmo_
  { {0x61ea00a2,0xa3d40037,0xb8350015,0x40350a31}},	//   defl, स्क_, _женщ, _женс
  { {0x224301e4,0xc952000b,0x9203001e,0x7a2f0033}},	//   lijk_, _ימי_, žādi, _møte
  { {0xb6a30020,0x38691d63,0x57fa0009,0xdcfa0035}},	//   _chấ, mlar_, _ולרו, eatļ
  { {0xafdb0119,0xdd86000a,0x7c2d0054,0xc6920009}},	//   _gjør, _لو_, _llar, _באך_
  { {0x7c2d00a1,0x23bf0037,0xfbbf0037,0x2c56001e}},	//   _olar, ्लाद, ्लाम, lāde_
  { {0xccf20093,0x386900a2,0xb69b0108,0x6b89005e}},	//   _בכל_, nlar_, _grâc, _ugeg
  { {0x997e007d,0x22430070,0x442d1d64,0xd6ce0003}},	//   tăţi_, kijk_, _ile_, لقي_
  { {0xd5b1001a,0x20d7003a,0xba740012,0x7af40024}},	//   uá_, kçi_, _كالت, _язує
  { {0xa25b0017,0x7a30004a,0x1bea00f5,0x38691d65}},	//   trôn, _jäte, одни_, klar_
  { {0x3869003a,0xca29000b,0x3ea0004a,0x3e740029}},	//   jlar_, _דם_, ypit_, mäte_
  { {0xdb000052,0xfbb60009,0xbfd20012,0xb0dd0011}},	//   _gemä, ופרת_, _شيوع, _महँग
  { {0x14c50037,0xb77a0009,0xde940012,0x877a0009}},	//   _विपण, _ואנש, _أجنب, _ואני
  { {0x7a30006f,0x44260010,0x38691d66,0x442d1d67}},	//   _näte, yko_, flar_, _ole_
  { {0x98a7003e,0xdbcc0097,0x68311d68,0x69dc18d8}},	//   czną_, jóðk, _nådd, sfre
  { {0x64420006,0x7ae40027,0x3ea00066,0x93130012}},	// [4880] vioi, _upit, upit_, _لويش
  { {0x44260002,0xae0e0037,0xb0dd0037,0x69c00010}},	//   wko_, साधन_, _महंग, ėmes
  { {0x442d0119,0x3ea0003a,0x6442004a,0x84ea0003}},	//   _ble_, spit_, tioi, تفاق_
  { {0x5fb20037,0x6fb20037,0xc32a0012,0x0b4607eb}},	//   _ज़िल, _ज़िं, يكان_, мнен
  { {0x8db6007c,0x442d0066,0x6442004a,0x25ee0011}},	//   _осві, _dle_, rioi, _असली_
  { {0x20ee0013,0x38600061,0x6442004a,0xc5f50014}},	//   _při_, loir_, sioi, _пясъ
  { {0xafdb0119,0x26110037,0xda650003,0x6442004a}},	//   _kjøp, तानी_, راهي, pioi
  { {0xd0100351,0xb6a30020,0x7d0300c5,0x68e310cc}},	//   الة_, _thấ, ænse, _ände
  { {0x78ad0027,0xc6f70015,0x661c1d69,0x5fbf0011}},	//   ćava, дных_, _kork, _एयरल
  { {0x20ee0066,0x3869003a,0x1be10011,0x9d14004c}},	//   _tři_, zlar_, ग्नल_, едоч
  { {0x44fe007a,0x6e20007d,0x3869003a,0xc5f30009}},	//   _jį_, _îmbu, ylar_, דדת_
  { {0x26050037,0xdb06004a,0x69da0037,0x3869006f}},	//   _होनी_, kakä, प्री, xlar_
  { {0xdb06004a,0x3ed40012,0x661c0227,0x98a70034}},	//   jakä, _أقتر, _oork, rzną_
  { {0x20d7003a,0x7d27000e,0x68310058,0x88c70066}},	//   tçi_, össé, _måde, spěš
  { {0x224300bd,0x6d4f000d,0x30850012,0x2b5a0034}},	//   rijk_, şcar, فلسف, ępcy_
  { {0x4ea70046,0x6ce3007c,0x6c180003,0x1eab0003}},	//   држа, _ріше, _يتيح_, قائي_
  { {0x7a300005,0x38691d6a,0x501b000b,0x682a0066}},	// [4890] _säte, rlar_, קומו, _týdn
  { {0x7c3a007a,0x644001a2,0xcb12000b,0xff040015}},	//   _įtra, _ammi, _עלי_, ъясн
  { {0x386900a2,0x92580003,0x442d1d6b,0x80dd0011}},	//   plar_, _تشير_, _ple_, _महें
  { {0xdfa7000a,0xdddc007a,0x2c080037,0xdcfa003a}},	//   _تحدي, _virš, षाएं_, natı
  { {0xa3d40044,0xd6c60003,0xa294002d,0x661c00e2}},	//   स्ट_, _حق_, вачі, _fork
  { {0x9f420066,0x7dc70003,0x7a3003d7,0xa4d50024}},	//   _jaký_, _تتحك, _täte, _погі
  { {0x9f400065,0x62880922,0xb1160012,0xd9960012}},	//   ldið_, _dido, فقوا_, رنيت_
  { {0xf42a004a,0x443f0027,0x3e740052,0xb066008e}},	//   isää_, _umu_, räte_, _isää
  { {0x9f400065,0x3eb91d6c,0xf6250104,0xdcfa003a}},	//   ndið_, ést_, едпо, datı
  { {0xa3e20044,0xee3600be,0x69de0051,0xb1d50012}},	//   न्न_, ень_, õpet, _سيؤث
  { {0xa3dc0037,0x1d09029b,0xb8d40003,0xe4790009}},	//   त्व_, чени_, _لتنش, ּרָכ
  { {0xce950098,0x8cc00037,0xfc320003,0xde950001}},	//   _задъ, _विरो, احد_, _задњ
  { {0x38600108,0xe72e1d6d,0x248900b6,0x57270003}},	//   voir_, _се_, _diam_, _تراق
  { {0xc332000b,0x27ed0251,0x171a000b,0x471a0009}},	//   רוך_, leen_, _מונע, _מונג
  { {0xafe6064f,0x50b50001,0xc0760001,0x9f470066}},	//   новл, ксту, ећањ, ěný_
  { {0x27ed021d,0xdfd20003,0x2489001a,0xa8870063}},	//   neen_, طيط_, _giam_, ейса_
  { {0x644600c6,0x38600025,0xd00f0012,0x50590024}},	// [48a0] miki, roir_, حلق_, єшся_
  { {0x67360002,0xe0da0001,0x27ed1d6e,0xdb370009}},	//   rzyj, _ево_, heen_, _נניח_
  { {0xf1c90044,0x27ed004a,0xd8ba0003,0x41c90037}},	//   _राजन, keen_, _عددا_, _राजस
  { {0x661c0036,0x62881d6f,0xe3b20003,0x1e1c01e1}},	//   _work, _sido, ارا_, _पक्ष_
  { {0xa3e20044,0x59f8010c,0x248401bd,0x6446005e}},	//   न्य_, деля_, íjmy_, iiki
  { {0x8cc00037,0x64460051,0xa2bb0009,0xbb470012}},	//   _विलो, hiki, למנט, علون_
  { {0x64460101,0xdcfa003a,0xa2cc0011,0xdb040018}},	//   kiki, yatı, _समक्, _feiç
  { {0x683e0039,0x628816f8,0x61ee0052,0xa3e20011}},	//   līdz, _wido, hebl, न्म_
  { {0xc5f80039,0x64460e9e,0xe7970012,0x4ac60012}},	//   klēt_, diki, رخيص_, _سياق
  { {0xa3dc0044,0x6018000e,0x64460010,0xab090003}},	//   त्र_, _címz, eiki, _تتفق_
  { {0x2459002d,0xa3cc0037,0xc04f002d,0x6f020002}},	//   дань_, _लाख_, _бі_, _wroc
  { {0xd314002d,0x78480066,0x27ed0feb,0x61fa15ef}},	//   _пiдт, těvu, ceen_, _hatl
  { {0xdcfa00a2,0x6f020002,0x63ad0028,0x3866000e}},	//   ratı, _uroc, ðani, _ikor_
  { {0xaf490003,0x61ee1d70,0xdf490012,0xe6170472}},	//   _تشمل_, gebl, _تؤمن_, _пдч_
  { {0x2bd10037,0xdcfa003a,0x8dfb000b,0x28c60011}},	//   _हाला, patı, _זהות, रंटि
  { {0xb909015f,0x9cd70009,0xd468004c,0x99840012}},	//   _यह_, _נוחה_, _пије_, طلقو
  { {0x9f420029,0x0c740012,0xa2cc0011,0xc275004c}},	// [48b0] _taký_, _حدود, _समग्, _илиј
  { {0x27f90132,0x6b9b00b8,0xb69b004b,0xa6e20097}},	//   _wasn_, _sfug, _frân, æðan
  { {0x5996000b,0x6823005e,0x61e1005e,0x6d350012}},	//   _בכתב_, _sõdu, õllu, خفاض
  { {0x683e0010,0xbca40012,0xd1160009,0x320c1d71}},	//   būdi, امني, _סקרה_, _andy_
  { {0x2c56001e,0x321e1396,0xdb0f00d9,0x61fa1d72}},	//   nāda_, _boty_, kací, _batl
  { {0x7db40003,0x64460a05,0x314b0009,0x02fc0009}},	//   _مصفا, ziki, ּתֵּ, פלומ
  { {0x27ed1d73,0x7a300051,0x20550104,0x9f420029}},	//   teen_, _jäta, ктир, ľký_
  { {0x26050044,0xc5f8001e,0x2c56001e,0xd709003c}},	//   _होती_, klēs_, kāda_, дние_
  { {0xa295002d,0xf1a70063,0x644600ff,0x92950048}},	//   _разі, _зрен, viki, _разц
  { {0x27ed0006,0x26c3012e,0x386600b6,0xbcd90012}},	//   seen_, čjo_, _ekor_, وذجا_
  { {0x6446007a,0x7e610058,0x88c70012,0x61ee0227}},	//   tiki, rolp, _ستال, vebl
  { {0x61aa0011,0xeb9a003c,0x7a220025,0xa3cc0011}},	//   कर्ष, ьим_, _nôtr, _लाओ_
  { {0x386d1d74,0x26cd01e3,0x263d0064,0x387f0097}},	//   mler_, queo_, dňov_, mmur_
  { {0x61ee01e3,0x7ae60248,0x1f360009,0x64461d75}},	//   uebl, _äkte, _ברנר_, siki
  { {0x64d00037,0xa06a0014,0xa96705fb,0xd9590024}},	//   _हमेश, дава_, вира_, ешті_
  { {0x386d00a2,0x2c080037,0x7ae9173a,0x9cd60009}},	//   nler_, षाओं_, _opet, _סופה_
  { {0xa0670247,0x60ce0431,0x1867062c,0xd36f0012}},	// [48c0] тата_, subm, тати_, _وهى_
  { {0x8ab7000b,0x386d1d76,0x8d2a0024,0x7e7e008e}},	//   _שהיו_, hler_, мозв_, umpp
  { {0xd499007c,0xa7aa0015,0xdd8f0012,0x0d0a0012}},	//   ері_, _окна_, زون_, بقاً_
  { {0xfbdf0020,0x82a6002d,0x68e3006f,0x386d0144}},	//   hiên_, вадж, _ända, jler_
  { {0x44201d77,0x80e20037,0x73360003,0x6af30012}},	//   _moi_, _पहुं, خرائ, لثور
  { {0x6da3002d,0xa3e20037,0x78750010,0x44200e67}},	//   _вира, न्त_, _išvy, _loi_
  { {0x61e3003a,0xf993000b,0x386d003a,0xdb0f0107}},	//   _önle, סרה_, fler_, vací
  { {0x44201d78,0xc953000b,0xc6f81104,0xf8b3000b}},	//   _noi_, ימו_, ених_, בשה_
  { {0xf76f0003,0xca48001a,0x11ea0003,0x61fa0115}},	//   ياً_, hời_, _يعطي_, _tatl
  { {0xceb3000b,0x35e3002d,0xba0a0012,0x0f7b0009}},	//   סית_, ацюв, _تترك_, ורפל
  { {0x2c75006f,0x2fe60012,0xdb0f0030,0x68310248}},	//   låda_, _لكاف, rací, _låda
  { {0x07a6111e,0x44201d79,0xc4d30009,0x853c0073}},	//   _радн, _coi_, סגר_, lbėk
  { {0xa3e20037,0x44201cce,0xa3d70011,0x7ac70048}},	//   न्ध_, _doi_, ़्ट_, ъсне
  { {0x2c560039,0xa4d40024,0xd0d50048,0xa9c4003c}},	//   rāda_, _бокі, логъ, исск
  { {0x442005ab,0x29051a98,0x6d450030,0xe9b40024}},	//   _foi_, íla_, _žhav, рбсь
  { {0xa3e20037,0x26c9001b,0x44201d7a,0xf77300ae}},	//   न्द_, trao_, _goi_, لاذ_
  { {0xcddb0001,0x41d20037,0x7a220025,0xdb1d0032}},	// [48d0] дње_, _सांस, _vôtr, ngsü
  { {0xe7e20044,0x386d003a,0x645d0061,0x0e340024}},	//   क्ता_, zler_, érif, аную
  { {0x7ae91d7b,0x386d1783,0x2d871121,0xcd780009}},	//   _spet, yler_, äne_, תְּכ
  { {0xa2c40037,0xb7e20037,0x7c200132,0x7a30005e}},	//   _रिश्, _कॉलम_, _comr, _jätn
  { {0x3e790061,0xdd1c0029,0x69c10002,0xeb920009}},	//   lète_, _vášm, ólew, צָא_
  { {0x1fbd0037,0x853c0010,0x62640024,0x386d1d7c}},	//   ोल्ड, rbėj, авіа, wler_
  { {0x386d1d7d,0x18690055,0xa0691496,0x3e790025}},	//   tler_, наки_, нака_, nète_
  { {0xb8db0044,0x386d0025,0xac7400ae,0xd00e00ae}},	//   _अब_, uler_, _ناقش, كلى_
  { {0x44200108,0x386d1d7e,0x63ad0028,0x3b5504ad}},	//   _roi_, rler_, ðanu, _скар
  { {0x7c3f0010,0x96d50037,0x95c50012,0x44201d7f}},	//   _įpra, यूयॉ, ديده, _soi_
  { {0x442001a2,0xb7d50003,0xc3290009,0x48e40024}},	//   _poi_, _مقاب, _צו_, _воєв
  { {0x98aa003e,0x889a0009,0x41df0011,0x263d0064}},	//   czbę_, _טבעי, प्रस, vňou_
  { {0x44201d80,0x76890073,0xe29704ac,0xeab10012}},	//   _voi_, _ažym, лая_, ْعِ_
  { {0x628f0061,0xed590a31,0x42550662,0xa3e50011}},	//   _écou, _пол_, атст, _बॉस_
  { {0x68fb0002,0x683109c9,0x7d1c0260,0x44201d81}},	//   łudn, _såda, ørst, _toi_
  { {0xf772000a,0x69cd0037,0x6444002c,0x96ba0012}},	//   ماء_, _साझी, _umii, فائز_
  { {0x63b90002,0x7d030058,0x95fd0011,0xdb0f0018}},	// [48e0] dawn, ænsn, ॉफ़्ट_, racã
  { {0xc3330093,0x9f400025,0x27fd05a4,0x89aa0357}},	//   _לוח_, nfié_, _lawn_, _яков_
  { {0x200f0051,0x661c0028,0xfd950024,0xa37b005e}},	//   _ongi_, örki, ршую, leõp
  { {0x44200065,0x98160012,0x25a70060,0x7aeb0031}},	//   ði_, _إبدا, ınla_, _ímtá
  { {0x75280002,0xe2f8002d,0x4af80686,0x8bd70009}},	//   zydz, телі_, телю_, רונו_
  { {0x200f0119,0x673b0029,0x63b60028,0x2ee0016d}},	//   _angi_, dzuj, _leyn, mtif_
  { {0x90e60003,0x7cf80009,0xa9340198,0x63b90034}},	//   استن, _בִּק, рейш, bawn
  { {0x76aa0047,0x20001d82,0x76480002,0x26c200eb}},	//   нтов_, ndii_, widy, škom_
  { {0x2ee00cf1,0x59d60012,0x27fd1d83,0xdb0e008e}},	//   ntif_, _مغار, _dawn_, öjäm
  { {0x14ca0047,0xa3e20037,0x61fe09b5,0xf2970009}},	//   ными_, न्स_, _napl, _עכבר_
  { {0xb993000a,0x51930003,0xd7e6002d,0xc9930003}},	//   _المب, _المذ, _біло, _المظ
  { {0x2ee0046c,0xc0a90003,0x35d80011,0xe73a0048}},	//   ktif_, _شامل_, ब्ज़, _пее_
  { {0xfe040044,0x26170037,0x62960164,0x74c00011}},	//   रयास_, नामी_, _cuyo, _विकृ
  { {0x69d500a2,0xa159002d,0xa2940024,0xdb0f01a0}},	//   _özet, вагу_, сарі, racà
  { {0xd5b80039,0xa3e20037,0xd59b0009,0x3cfe0011}},	//   skās_, न्ह_, _אבול, ईटों_
  { {0x3e790025,0x5b250012,0x69db0011,0x645d032f}},	//   rète_, _نفعل, _नाभी, érid
  { {0x2dcb0001,0x69da0830,0xd6970012,0x36d5028b}},	// [48f0] ећен_, _octe, اشرة, розр
  { {0x26c7048b,0x7aed18cd,0x2d9e08ac,0x3b091d84}},	//   čno_, _ipat, ncte_, _iraq_
  { {0xfbdf001a,0x248d001e,0x2ee000b6,0x68380028}},	//   hiêm_, _piem_, atif_, _bídd
  { {0x3e970003,0xe44e002d,0x81bc001e,0xe3b00012}},	//   _مؤسس, іж_, _slēp, كره_
  { {0x2ee00061,0x63b90002,0xf7d6000b,0x3d95002d}},	//   ctif_, rawn, _דורש_, _вигр
  { {0x3ea900c6,0x329c000b,0x248d0002,0xe7e20011}},	//   mpat_, עבוד, _wiem_, क्सा_
  { {0x248d0039,0x2c4f0034,0x81f60012,0x27fd0132}},	//   _tiem_, lędu_, شفير_, _pawn_
  { {0x2d9e000d,0x63ad01e3,0x27ff008e,0xdcee0035}},	//   ecte_, ñand, udun_, _uzbā
  { {0x63b60065,0x20030013,0xa3d90037,0x644b002c}},	//   _reyn, ěji_, ालन_, migi
  { {0x7d090001,0x673b0066,0xcee80003,0xdb0b006f}},	//   вног_, rzuj, ارين_, gagå
  { {0x245b0010,0xa8cb0003,0x3cc90048,0x61fe005e}},	//   kšmę_, _سباق_, ълно_, _rapl
  { {0x638602ac,0x61fe1d85,0x07d80012,0x97d80012}},	//   игна, _sapl, _مذهب_, _مظهر_
  { {0x63bb0065,0x644b0051,0x4376002d,0x628f0061}},	//   ðuna, iigi, рунт, _écos
  { {0x644b002c,0x9756000b,0xa2cd0011,0x26050011}},	//   higi, _דינו_, _सिन्, _होली_
  { {0x69d70037,0x60860003,0x2ba70011,0xd7f20012}},	//   _बारी, لشرك, _क्वा, يكس_
  { {0x3204003e,0x7afb0005,0xf55a000b,0xdfd20003}},	//   śmy_, _osut, _בדצמ, تير_
  { {0x644b1d86,0x6aa4006f,0x645d0e90,0x78a50260}},	// [4900] digi, _utif, érie, _ethv
  { {0xb2bb000b,0x3abb0009,0xa2bb0009,0x35dd0011}},	//   _שמיר, _שמינ, _שמיט, _माफ़
  { {0x7afb0005,0x1ddd0037,0x7a300051,0x7c24004a}},	//   _asut, _मानत, _jätm, _koir
  { {0x644b0101,0xa3d90037,0x3ebf004a,0x115b000b}},	//   gigi, ालय_, ksut_, _ידיע
  { {0x539b000b,0xa3e50037,0x69c10028,0x7a2b146f}},	//   דינו, ब्ध_, ðleg, _süti
  { {0x12a90003,0x26c20073,0x49d70024,0xda190011}},	//   ادنى_, škok_, идію_, दायत_
  { {0xf1b30009,0x00d70012,0x26c00073,0x6fca0011}},	//   חסו_, لبيت_, lsio_, िणपं
  { {0xa3e5015f,0x7c240061,0xa5d80037,0xacfb0009}},	//   ब्द_, _noir, _माहौ, _בהלכ
  { {0xfba70044,0xe7e20037,0xd0070001,0xe29a04b3}},	//   _क्षम, क्षा_, рење_, _раз_
  { {0x44241d87,0x42db0009,0x6dc30842,0x79b800af}},	//   _hom_, _בקמע, осюж, _תֶּה
  { {0x0d97000b,0xcd97000b,0xaa3b000b,0xde88001a}},	//   יכים_, ידית_, _שתבח, _dịp_
  { {0x66e60373,0x04590012,0xa2cd0011,0x628f0025}},	//   _вода, الحة_, _सिम्, _écor
  { {0x44241d88,0x7ae21d89,0x883b0009,0xc458003c}},	//   _mom_, ntot, _בתאו, риях_
  { {0xfba70044,0xb7e20037,0x644b0070,0xe7f90037}},	//   _क्रम, क्रम_, zigi, ्यथा_
  { {0x661c0065,0xd258002d,0x3895001e,0x7ae20269}},	//   örku, рця_, _pāri_, htot
  { {0x442404b8,0x351b000b,0xdb000052,0x5f450012}},	//   _nom_, _יוונ, _bemü, منزل
  { {0x7ae2000e,0x69c10002,0xdb0009f1,0xe7f90011}},	// [4910] jtot, óles, _memó, ्यता_
  { {0xf41f004a,0x63bd1d8a,0x313516a9,0x8e1400f5}},	//   ljä_, lasn, _геор, одуц
  { {0xdd98002d,0x7ae2001e,0x9b950003,0xd919000b}},	//   ршу_, etot, ملات, _עוֹל
  { {0x44241d8b,0x511a000b,0x3ea600b6,0x3ea90248}},	//   _com_, _עֵינ, _otot_, ppat_
  { {0xee870015,0x15ff0011,0x13c80009,0xdb000032}},	//   _выво, _उसपर_, בּוֹ_, _gemü
  { {0xf41f004a,0xc244002d,0xdb0605b1,0x4b380009}},	//   hjä_, онік, jaký, סרגל_
  { {0x644b002c,0x261a0011,0xc27c0009,0xd4980024}},	//   pigi, बानी_, דרגי, _вру_
  { {0x3958000b,0x2ba70037,0xf958000b,0x3ebf019a}},	//   ישום_, _क्ला, יסות_, tsut_
  { {0xfbd2000b,0xf1c00029,0x672d00b6,0x86450024}},	//   _מתן_, žšiu_, nyaj, йниж
  { {0x30e7007c,0x26cd02d1,0x63bb0065,0xa2ce0037}},	//   _відб, rreo_, ðunn, _तिब्
  { {0x2fd90003,0x2c72000e,0xd5490ec6,0xd6240012}},	//   _مواد_, ládi_, упне_, تعيي
  { {0xca29015a,0xd7950003,0x6f950003,0x63bd051f}},	//   _אם_, _الإخ, _الإض, gasn
  { {0x7c240061,0xf7850012,0x5ea50012,0x7f850012}},	//   _voir, _الشَ, _امتل, _الشن
  { {0xa2da0037,0x6e3a01e0,0x63bd005e,0x5f740012}},	//   _नमस्, chtb, aasn, _بامر
  { {0xe8560003,0xcdb6000b,0x3243002d,0xfbd80011}},	//   منسد, _הפצה_, черг, _डालम
  { {0xccf2000b,0xdb000054,0x7f1a0024,0x7a30079f}},	//   _זכה_, _memò, лізу_, _kätk
  { {0x7a300005,0x26c00010,0x2498005e,0xd0070148}},	// [4920] _jätk, usio_, _surm_, щете_
  { {0x26c00006,0x60c9001e,0xf7720009,0x4424005b}},	//   rsio_, ņema, לקן_, _som_
  { {0xfc460066,0xdd8f0012,0xdcea001b,0xbda50012}},	//   římo_, فوك_, čiće, تحقو
  { {0x7469002d,0x7ae208be,0xc3d60012,0xd00f0012}},	//   арів_, ttot, إغاث, _كلٍ_
  { {0xa3d90037,0x853c0010,0x44241d8c,0xa2cd0011}},	//   ालत_, lbėt, _vom_, _सिण्
  { {0xc5d5007c,0xbea3007c,0x78a20027,0x7ae21d8d}},	//   _місь, _харк, _čovj, rtot
  { {0x28cf0044,0xf41f0006,0xa2c40037,0x200200b6}},	//   संगि, yjä_, _रिक्, _kaki_
  { {0x50b70003,0x20020002,0xdd8f0003,0x85570009}},	//   حدود_, _jaki_, _أوف_, _השלב_
  { {0xa0670001,0x501b000b,0x63bd000e,0x7a2b0051}},	//   љања_, רופו, vasn, _kütt
  { {0xa3c20044,0x20020a26,0x2a6a1d8e,0xd3370009}},	//   ूलक_, _laki_, jobb_, _הרמה_
  { {0x40960003,0xb8960003,0x63bd00b6,0xdb1d02f1}},	//   _الصر, _الصع, tasn, ngsö
  { {0x49170093,0x7e68000e,0xd6da0014,0x2480001a}},	//   _לקבל_, sodp, _бтк_, _chim_
  { {0xb8650003,0x7e680b16,0x63a21d8f,0x63bd1d90}},	//   _بالو, podp, icon, rasn
  { {0x7d030028,0x9f4b0031,0x63bd1d91,0x26db0009}},	//   ænsk, ámít_, sasn, _עקומ
  { {0x28d90044,0x61f5003a,0x48770003,0x25dd0037}},	//   बंधि, rezl, مدرس, _खाती_
  { {0x98a5003a,0x8557000b,0x65570009,0xa0750024}},	//   çlı_, _לשוב_, _לבוא_, ігач
  { {0x59c80037,0x2002003a,0x7a2b003a,0xdb1f004a}},	// [4930] रणार, _daki_, _sütu, äväl
  { {0x20070034,0x7853004b,0x0587003c,0x63a21d92}},	//   śni_, răvi, буем, econ
  { {0x3cf50011,0xe9190024,0xdb1d0248,0xdb061654}},	//   ीटें_, _тоні_, ggsö, zakü
  { {0x69d80163,0xa2cd0037,0xfbd00003,0xd3750001}},	//   _över, _सिद्, فته_, олећ
  { {0x387e0108,0xcb69004c,0x44fa0035,0x7a2b0032}},	//   ître_, јале_, _lū_, _fütt
  { {0x6448007a,0xcad80009,0x7abc01b0,0x8cd60011}},	//   _įdie, מודת_, רצגו, मूहो
  { {0xa3d90037,0xdbf20030,0x6f090030,0x2bbe0011}},	//   ाला_, _zříz, _šech, ्णमा
  { {0x2bdb0044,0x01380093,0x63a200c1,0xd825002d}},	//   _भाषा, מרות_, ccon, ідпи
  { {0xcdf50015,0x2904001e,0xee391d93,0x35d40011}},	//   очны, āmai_, ини_, _दाख़
  { {0xa6e20065,0x0a6b0001,0xfe45002d,0x926b0001}},	//   æðin, _срби_, інно, _срба_
  { {0xcb09015a,0x24800020,0x2c56001e,0x63bb00b6}},	//   _של_, _phim_, lādi_, _keun
  { {0x63bb0108,0x59dc0037,0x546a0015,0x2003001e}},	//   _jeun, _बाहर, рамм_, ējis_
  { {0xa3e101e1,0x67d4002d,0x2c560035,0xf8680012}},	//   _दान_, _хочу, nādi_, _امني_
  { {0xa5090d93,0xdb020018,0xaa7b0030,0x1d090306}},	//   _века_, sboç, stýn, _веки_
  { {0x20020101,0xf41f0006,0xfe790066,0x6e2e000e}},	//   _paki_, mmän_, ntům_, öbbe
  { {0xdbf20066,0xf41f1330,0x16110037,0x660303d5}},	//   _příz, lmän_, ़ाकर_, _hank
  { {0x2c560039,0x1ea90003,0x26c2009b,0x464a020e}},	// [4940] jādi_, مالي_, škov_, азан_
  { {0x62920029,0xe61706da,0xfe790030,0x7bc90420}},	//   úkoľ, оду_, ktům_, _adeu
  { {0x69dc0065,0xd4c60012,0x73c60012,0xa5070048}},	//   mgre, تغذي, قيام, жеха_
  { {0x717b0093,0xf41f0006,0x69dc10c7,0x87d60003}},	//   _כניס, hmän_, lgre, _بغدا
  { {0xda661d94,0x2c56001e,0x44220227,0x24800035}},	//   овди, gādi_, ijk_, ķim_
  { {0x683c0061,0x316d000d,0xc3330009,0xa5d80009}},	//   _méde, şeze_, ווד_, _לַֽי
  { {0x644f003a,0x63a20070,0x2d98017b,0x08f70012}},	//   yici, pcon, _igre_, قريب_
  { {0x2120001c,0xf993000b,0x66030070,0xad1b0009}},	//   ćih_, ורו_, _aank, _דולר
  { {0x3169003a,0x1eaa0012,0x2be10011,0xd80b0009}},	//   ğaza_, جابي_, _काबू_, בִיָ
  { {0x644f0002,0xf7730009,0x6df40012,0xfe720012}},	//   wici, וקח_, أكدا, بدع_
  { {0xafe6007c,0x859b000b,0xa3e10037,0xe5f7000b}},	//   _можл, ישיו, _दाम_, חזיר_
  { {0xd6d90002,0x61f80060,0x7c221d95,0x644f1d96}},	//   szła_, levl, njor, uici
  { {0xfad80014,0x69dc0068,0xb8650012,0x683c0025}},	//   одящ_, fgre, _عامو, _céde
  { {0x7e040044,0xfc461d97,0xa2cd0037,0x644f1d98}},	//   रयोग_, _þína_, _सिस्, sici
  { {0x26050044,0x7a3f0013,0xe4530012,0x59df0011}},	//   _होगी_, vště, _يضع_, प्टर
  { {0x2d980033,0x20c5001e,0x60c9001e,0xa158002d}},	//   _agre_, rķi_, ņemo, іату_
  { {0xc3b8000b,0x6be80009,0x13b80009,0xdd9b0c1e}},	// [4950] _ולחץ_, _וַתַ, _והחל_, аше_
  { {0x44290020,0x7a3f0066,0xbe18002d,0xddab0dfb}},	//   _hoa_, uště, ожує_, ртал_
  { {0x20160026,0x765a004a,0xf9fa000b,0x68ed0002}},	//   ácií_, inty, _ההתמ, ładz
  { {0x26c40010,0x2c56001e,0x7afd0002,0x7bdd1d99}},	//   ksmo_, tādi_, owst, ngsu
  { {0xe2a3001a,0xf41f004a,0x501a0009,0x3b090264}},	//   _giữ_, ymän_, _הורו, село_
  { {0xceb20093,0x2c56001e,0xddda0066,0x44291d9a}},	//   _איך_, rādi_, potř, _loa_
  { {0x26c40017,0x88c50012,0x63f70012,0x10a20048}},	//   esmo_, ستغل, _وأرر, нищн
  { {0x6f09006f,0x895c0009,0x9b450012,0x59d70011}},	//   tvec, ידות, _فنزو, _ठाकर
  { {0x6603015e,0x36350012,0xed630030,0xfe790030}},	//   _pank, كردس, _mužů_, stům_
  { {0x7a300052,0xfe420014,0x6f091d9b,0xee39102d}},	//   _täti, еньо, rvec, сно_
  { {0x44290017,0xe9380003,0x7c2909de,0xfbdf0081}},	//   _boa_, _وسمت_, _koer, hiêu_
  { {0x71880009,0x397a0009,0xe97a0009,0xb97a0009}},	//   _וְנַ, _הטענ, _הנעש, _הנעי
  { {0x987a000b,0x442900b6,0xd8740012,0x7c291d9c}},	//   _פרנק, _doa_, _غامب, _moer
  { {0x412a0015,0x683c000e,0x7bdd002c,0x7c3b01a0}},	//   бого_, _véde, agsu, _llur
  { {0x55ba000b,0x7c3b003a,0x69dc1d9d,0xe7e20011}},	//   _המצו, _olur, rgre, क्का_
  { {0x7a300163,0xb8f40011,0x44291d9e,0x7d760012}},	//   _nätv, _हट_, _goa_, _عمير_
  { {0xfc57000b,0xf43b0009,0xfd9a0012,0xe7e30011}},	// [4960] _מבקש_, _לתקש, مئات_, _गाना_
  { {0xd6cf0003,0x9f4b000e,0x2fc001a0,0x68ed0034}},	//   اقل_, ámát_, saig_, łady
  { {0xb3a900a2,0x999b000b,0x399b000b,0x299b000b}},	//   ğını, _לביט, _לייד, _לסימ
  { {0xd6d90002,0xb3a9003a,0x91dc0011,0xaae60012}},	//   kuł_, şını, _बाँई, كستو
  { {0x7d060035,0xd46700b5,0xca0a0048,0x765a0ae1}},	//   āksi, чице_, йндж_, ynty
  { {0xa2cd0037,0x68310058,0x38a3003a,0x7c3b0051}},	//   _सिर्, _rådi, _sıra_, _elur
  { {0x490f0044,0x61f802f7,0xdb1d0025,0x32051b91}},	//   डियो_, revl, rasé, _daly_
  { {0x8d5b0093,0x8f460098,0xd6da002d,0xf993000b}},	//   _הכלי, зход, бто_, ערה_
  { {0x141b000b,0x2c560035,0xb69b004b,0xd6d90034}},	//   _פומב, nādu_, _urât, guł_
  { {0xba29000a,0xceb3000b,0xa534002d,0x2d98038e}},	//   _وسلم_, עית_, дноч, øre_
  { {0xdd900003,0xfe370009,0x05780012,0x26110011}},	//   ضوح_, פרטי_, تمدة_, ताजी_
  { {0x889b0093,0x2fc00065,0x7d7b000b,0x2c56001e}},	//   _הבאי, _þig_, מניו, kādu_
  { {0x64830051,0x7afd0070,0x6137000e,0x82a7003c}},	//   sõig, uwst, külö, яшне
  { {0x26c2007a,0x5ef20011,0xd3540012,0x4efb00af}},	//   škos_, ुबन्_, رَّة, _להדו
  { {0xfa77000b,0xd5cb0009,0xa87b0012,0x68380030}},	//   פעלת_, _הֶחָ, محرر_, _vídn
  { {0xa2cd0011,0x04db0009,0x6e2a0032,0x55770009}},	//   _सिल्, _הקהל, _hofb, _מעון_
  { {0xdef10003,0x387e0061,0x539c0009,0x1be70011}},	// [4970] ضًا_, îtra_, _פיזו, _टॉगल_
  { {0xd358000b,0xb2bc000b,0xbb3c0009,0xc58b003c}},	//   _משחק_, _המזר, _לתחז, бщее_
  { {0x6a720058,0xa8a40014,0xfe700012,0x7a2f00b0}},	//   ræft, _пряк, ادق_, _møtt
  { {0x4429014d,0x98c40030,0x68380030,0x628a0834}},	//   ða_, štěn_, _jídl, emfo
  { {0xa3e20044,0x7c2900bd,0x25dd01e1,0xfe780010}},	//   न्ट_, _voer, _खाली_, klį_
  { {0x645d0032,0x20090073,0x6d580064,0xd49b07a7}},	//   hnsi, ldai_, úvac, _гра_
  { {0xdb040065,0x2ee90065,0xe8f9002d,0x9f400028}},	//   _leið, ltaf_, іли_, leið_
  { {0x77f90044,0x7a300052,0xd6d90002,0xc918000b}},	//   ्येक_, _hätt, tuł_, לחות_
  { {0xfaf0000a,0x7a300005,0xd7060015,0xdb23004a}},	//   _مثل_, _kätt, дные_, äräl
  { {0x7bcd000d,0x64830051,0xd6d90002,0xf1a71ad6}},	//   _adau, sõid, szło_, _хран
  { {0xb925000a,0x66070027,0x69c31d9f,0x645d0097}},	//   _تفضي, _majk, mane, fnsi
  { {0xdb040065,0x7a30006f,0x6285000e,0x01640012}},	//   _beið, _lätt, _ahho, _ثُمَ
  { {0x15ff0037,0x20240029,0x69c3004b,0xa01b016a}},	//   ैयार_, úsiť_, oane, _phön
  { {0xd295002d,0x27ed0052,0x20090010,0x6f0d0030}},	//   ерсь, lfen_, edai_, dvac
  { {0xafe6007c,0x261a0037,0x8fa60001,0xd00a0048}},	//   мовл, बारी_, дабе, оеве_
  { {0xf772000a,0x9cd60009,0x2fda0012,0x69c31da0}},	//   ناء_, _חוקה_, تورد_, hane
  { {0x2fc00051,0x27ed0052,0x7a30006f,0xd1380010}},	// [4980] _õige_, ifen_, _bätt, šą_
  { {0x683c0061,0xb3a9003a,0x7b04001e,0x0dca0024}},	//   _méda, şılı, ēttī, ілей_
  { {0x29040333,0x621b000b,0xe4a5002d,0x61fc1da1}},	//   āmas_, _וויק, еріо, merl
  { {0x25fa0037,0x61fc1da2,0xc5e90009,0xa3e20011}},	//   _उसकी_, lerl, יד_, न्च_
  { {0xdb000026,0xaa460015,0xd7fb0009,0xf2360009}},	//   _nemô, медл, _והכל, ֽרֶץ_
  { {0x6df60012,0x6e960012,0x4dd60012,0x63a9067a}},	//   _تكسا, _زلزا, _تتحس, _efen
  { {0x26f80037,0x27ed0358,0x2c0e0037,0x99850066}},	//   ्ट्र_, ffen_, ियां_, _dolů_
  { {0xd007004c,0x683e0035,0xc7b00012,0x2bd80011}},	//   деће_, lūdz, دّة_, _डाटा
  { {0x61fc1da3,0x7a30005e,0x27e00097,0x683c0025}},	//   kerl, _jäts, igin_, _céda
  { {0x4426012e,0xddc81da4,0xdb040028,0x38690027}},	//   ljo_, widł, _reið, čara_
  { {0x828b0093,0x7bc01da5,0x7af60010,0x25d7000b}},	//   _וְאֶ, _kemu, _apyt, ווין_
  { {0xb8650003,0xbc4b002d,0x6442004a,0x25b1003a}},	//   _كانو, ічне_, nhoi, ızla_
  { {0x7bc0046c,0x5e260003,0xc2b8002d,0x28130003}},	//   _memu, _يعتق, мляє_, _جونس
  { {0xc333000b,0xd1260003,0x76410064,0xdb040097}},	//   דוש_, هم_, chly, _veið
  { {0x7a300163,0xe5f7000b,0xa294002d,0xdb1d0028}},	//   _rätt, _חזור_, тарі, masí
  { {0x6018002d,0xb8f70011,0x7a301da6,0x69c31da7}},	//   мося_, _सि_, _sätt, zane
  { {0xf7700003,0x20090645,0x61fc1da8,0xe2ab0012}},	// [4990] لاك_, rdai_, berl, _بابن_
  { {0xab5d003e,0x61fc0164,0xb3a9003a,0x2ddb0012}},	//   _jeże, cerl, ğımı, تبرة_
  { {0x7bc0000e,0xb3a9003a,0x7c2d1da9,0x69c31daa}},	//   _bemu, şımı, _koar, vane
  { {0x69c3003e,0x70550003,0xfd570009,0x6d45192a}},	//   wane, _أنحا, ושבי_, rzha
  { {0x7c2d000d,0x160a0037,0x6d45000e,0xc7d60009}},	//   _moar, _होकर_, szha, _אורי_
  { {0xdeba000b,0x1308002d,0xa2d70037,0xd338000b}},	//   _ממשל, ьній_, _बिन्, ורדה_
  { {0x27ed00a1,0x3e74006f,0x44390028,0x69c31dab}},	//   tfen_, rätt_, kks_, rane
  { {0xb9070037,0x3e74006f,0x44390070,0x27ed0052}},	//   _बम_, sätt_, jks_, ufen_
  { {0x27ed03de,0x97a80009,0x8e550024,0xf7080081}},	//   rfen_, וֹתֵ, етні, _củ_
  { {0x442d00bd,0x7bda0010,0xe5250063,0xab840294}},	//   _hoe_, ėtum, едоп, _руск
  { {0x27ed0052,0x63a40010,0x7c2d1dac,0xc5f20009}},	//   pfen_, žine, _boar, נדט_
  { {0x29051dad,0x78f80003,0xa0080012,0x644a0025}},	//   _isla_, _تعكس_, _يقلل_, éfix
  { {0x7ee40003,0xfbd2000b,0x69c11dae,0x929d0034}},	//   _لكنن, נתך_, _kele, _ysła
  { {0x69c10272,0x97560093,0x442d0005,0x0f560093}},	//   _jele, _אינו_, _loe_, _אינם_
  { {0x3da6007c,0x7c2d007d,0x69c11daf,0x29550048}},	//   _якщо_, _foar, _mele, вътр
  { {0x442d0119,0x02df0037,0x7b05004a,0x44391db0}},	//   _noe_, _नमून, ättä, cks_
  { {0xdfcf0003,0x2e360028,0x2c640060,0x61fc1db1}},	// [49a0] صيل_, _hæfi_, cıda_, perl
  { {0x7bc600c6,0x7bc000c6,0x4aa50037,0x9f400070}},	//   laku, _semu, _गंतव, lgië_
  { {0x41bb000b,0x71bb000b,0x7bc000b6,0x443f00c1}},	//   _מציע, _מציג, _pemu, _blu_
  { {0xeb3a0009,0xcdc90009,0x8ac60048,0xab5b005e}},	//   ּעַש, מך_, ейдж, kaül
  { {0x68e301ab,0x2905003a,0x628e1db2,0xa3de0011}},	//   _ändr, _asla_, ombo, _ढाई_
  { {0x5eeb000b,0x443f0051,0x64420051,0x237a001e}},	//   _מַלְ, _elu_, shoi, āpj_
  { {0xf1b3000b,0x7bc6010e,0x7bc00b43,0x443f041e}},	//   נסה_, kaku, _temu, _flu_
  { {0x2c64003a,0x38601db3,0x17fa0012,0x571805c8}},	//   yıda_, nnir_, سرعة_, джия_
  { {0xdb1d02b2,0x69c116ba,0x8c430015,0xcee70001}},	//   tasí, _fele, _сете, едње_
  { {0x60c9001e,0x69c11db4,0x7c2d177c,0x6e2e1db5}},	//   ņemi, _gele, _soar, _jobb
  { {0x38600028,0x7c2d000d,0x3ea2046f,0xc5f30009}},	//   knir_, _poar, _lukt_, אדת_
  { {0x61e5008b,0xf5370009,0xf7080081,0x46a605d8}},	//   _schl, גנטי_, _tủ_, _задв
  { {0xa3e70044,0x629a007a,0xdd2d0029,0xbb940015}},	//   _पाठ_, _kito, hŕňa, лающ
  { {0x171b015a,0x96060003,0x2c64003a,0xaf070003}},	//   _מודע, _سبتم, rıda_, _أقوم_
  { {0x6e35000e,0x2887004c,0x38600097,0x3168004c}},	//   özbe, ећав, fnir_, ешто_
  { {0x6d7b0093,0xc6a708b0,0x4ea700be,0x38600028}},	//   _מאוח, ержи, ержа, gnir_
  { {0x63bb0028,0xd6d8004c,0xe9f90081,0xe6990048}},	// [49b0] ðunu, етх_, _cuả_, дваш_
  { {0x629a002c,0xa3d90037,0x64401db6,0x6e2e0a0c}},	//   _nito, ालक_, _almi, _cobb
  { {0xad670003,0x3eaf0035,0x6e2e1db7,0x443f116b}},	//   رائه, ūgt_, _dobb, _plu_
  { {0xe3b30003,0x44ea00c1,0x63a50066,0x54550048}},	//   ارض_, iù_, ěhno, ъвет
  { {0x09e50083,0x6e950012,0xe6950012,0x91e50511}},	//   волн, _للحا, _للحد, воле
  { {0xa0c50012,0xa2940024,0xff560009,0xab5b005e}},	//   نيتو, гачі, _יברך_, vaül
  { {0x90890003,0x442d0eaf,0x784c003a,0x0218000b}},	//   ونتك_, _toe_, aşvu, תחום_
  { {0x62880006,0x64580025,0x69c1076e,0x683c0025}},	//   _ehdo, évit, _wele, _dédo
  { {0x60060015,0xdcfc001e,0xfae00030,0xdb00068a}},	//   тным_, _izrā, íště_, _afmæ
  { {0x0b880024,0x21a40012,0xeb980012,0x9985004b}},	//   _їсти_, _ممكّ, _أضفت_, _colţ_
  { {0x04460047,0xd46a0046,0x0d82064f,0x6b84000e}},	//   венн, дине_, ильн, _szig
  { {0x9ee90012,0x200b001b,0x69d80031,0x7d1c0474}},	//   _يفضل_, _naci_, _övez, årsa
  { {0xde050001,0x1de20011,0xdb1d0018,0xe72e083a}},	//   _апли, _पालत, vasã, _те_
  { {0xc3320093,0x2d9c0026,0xe2970047,0x7a3d03eb}},	//   סום_, ľvek_, кая_, _mèto
  { {0x6443001e,0x38600028,0x20d50024,0x929d0034}},	//   īnij, tnir_, літс, _osło
  { {0xdfd2000a,0x69c7004a,0x38600028,0x4d7a0009}},	//   شيط_, aaje, unir_, _קרקע
  { {0xe9f90020,0x38600325,0xa2cd0011,0xaf060048}},	// [49c0] _quả_, rnir_, _सिग्, ъпал
  { {0x68380017,0x6d960012,0x38600097,0x65960012}},	//   _mídi, نشائ, snir_, نجار
  { {0x629a00c1,0x200b0cea,0x9596004c,0xf866004c}},	//   _rito, _faci_, траљ, _авно
  { {0xb2c60003,0x69c50028,0x629a1db8,0x7f860012}},	//   نغتو, ðhen, _sito, _للجن
  { {0x7c650003,0x6aa40061,0x031a0012,0x63a90073}},	//   دالل, _juif, بتات_, ženg
  { {0x9cb60003,0xda660003,0x7bc40051,0x53330447}},	//   _لمست, خاصي, _leiu, решт
  { {0x63a10002,0x64580061,0xa3ea0011,0x9c7d001b}},	//   ślni, évis, _माप_, luče
  { {0xdfd00003,0x69c70102,0x6d480004,0x8d4b0009}},	//   حية_, zaje, vzda, _חֲמֵ
  { {0x629a1db9,0xc053000b,0x807b000b,0x6d67000d}},	//   _tito, יזה_, ונקצ, ăraţ
  { {0x75d40003,0x14ca0015,0x35b4003c,0x200d004b}},	//   ديدا, мыми_, ыбор, adei_
  { {0x7bcd0028,0xd5b8001e,0x4ddb0009,0xa3e70011}},	//   ðaug, rbā_, וחיו, _पाद_
  { {0x26cf000e,0xa3ea0011,0x5fe10011,0x195700af}},	//   ágok_, _माफ_, _फाइल, _בבבל_
  { {0xa3ea0037,0x9c7d017b,0x4fd70009,0xf7d70009}},	//   _मान_, juče, _יואב_, _יואש_
  { {0x7df30013,0x07370009,0x96f70024,0xaa640c80}},	//   _měsí, _באדם_, _решт_, атск
  { {0x24890020,0xdb0f0164,0xfe9b000b,0xdfd50015}},	//   _tham_, tacó, _קיומ, ловы
  { {0x44ce003e,0x69c7041f,0x6ebf0037,0x320c1a48}},	//   mę_, saje, लीवु, _lady_
  { {0x2284006f,0x44ce09bb,0xf1b40011,0x613c008e}},	// [49d0] söka_, lę_, ुरान, tälö
  { {0xf1b70037,0x9f040003,0x2cb30030,0x7c3d1dba}},	//   _अभिन, ؤولو, řadů_, lksr
  { {0x44ce0916,0x72340003,0x3cd5010c,0xb4d50048}},	//   nę_, _خريط, ужес, ужещ
  { {0x44ce003e,0x8d5b000b,0x7a2b0052,0xfbd00012}},	//   ię_, וכבי, _nütz, قته_
  { {0x64580054,0x69c500b6,0x623500de,0xa01b0032}},	//   èvia, _kehe, леду, _rhöh
  { {0x11d90003,0xbb3c000b,0x6d410051,0x01650345}},	//   روعة_, ועדי, _ülao, лкло
  { {0xe8f50003,0x41e4002d,0x44ce0d30,0x69c5026e}},	//   استخ, річа, ję_, _mehe
  { {0xd7091dbb,0x69c51dbc,0xdcfc001e,0x999c000b}},	//   ение_, _lehe, _uzrā, ובוט
  { {0xab940024,0xcf250012,0x27ff004b,0x23770012}},	//   _виті, ارعي, reun_, _شارح
  { {0x41c70011,0x64590034,0xe7080012,0x9a871707}},	//   _रजिस, liwi, ئتين_, _рубл
  { {0xdb1d000e,0x44ce0455,0x22581dbd,0xf1b20009}},	//   vasá, gę_, virk_, _הסב_
  { {0xc2090093,0xb809000a,0xe572000b,0x9f050003}},	//   _מה_, _سيتم_, מַר_, _موصو
  { {0x69c50369,0xc0b90066,0xeb97003c,0x387f0097}},	//   _behe, žádá, лию_, mlur_
  { {0x387f0028,0x44ce0002,0x9c7d0027,0xfce50760}},	//   llur_, bę_, vuče, _боко
  { {0xd9430a1a,0xc5f2000b,0x44ce0002,0xf2190037}},	//   бери, _הדו_, cę_, दाज़_
  { {0x6f04008b,0x2c1a0037,0xa7b50001,0xf8b2000b}},	//   twic, धाओं_, исуј, משל_
  { {0x442000ec,0x644407d0,0x1786026d,0x9f860148}},	// [49e0] _ini_, _ilii, угам, угад
  { {0xceb20093,0x44320164,0x69c51dbe,0x1a060103}},	//   ציב_, _hoy_, ðhel, _спом
  { {0x6d410051,0x66010002,0x3f860029,0x64440574}},	//   _ülal, ielk, ťou_, _klii
  { {0xdd8f0003,0x0b460406,0x320c01e9,0x44321dbf}},	//   سون_, лнен, _sady_, _joy_
  { {0xa3e70044,0x60c90039,0xf41f004a,0x44ce09bb}},	//   _पास_, ņemt, mmät_, zę_
  { {0xf41f004a,0x93590014,0xc2c30012,0xa2d70011}},	//   lmät_, ърху_, حيوي, _बिस्
  { {0x66011dc0,0x44201dc1,0x4e7b0009,0x69c10097}},	//   delk, _oni_, _נאלצ, ðlei
  { {0x387f0065,0xc6f81104,0xc0340001,0x0443010c}},	//   glur_, вних_, рниј, _лесн
  { {0x44ce0002,0x320c0066,0x627b0002,0xab6600a6}},	//   wę_, _tady_, _słoń, _свал
  { {0x1ef7000a,0x26f7000a,0xf41f004a,0x7ae20757}},	//   اعية_, اريخ_, hmät_, muot
  { {0x44ee00f1,0x2fe60003,0x9e77000b,0x442000b6}},	//   ný_, _مكاف, רגיה_, _bni_
  { {0xa2db0044,0xc94b000b,0x69c50052,0x44ce07ff}},	//   _निम्, _אֲדֹ, _sehe, rę_
  { {0x98aa007a,0x7ae20010,0x44ce09bb,0x44ee0042}},	//   mybę_, nuot, sę_, hý_
  { {0x44ce0916,0x44201dc2,0x78a5005e,0x44ee01e9}},	//   pę_, _eni_, _puhv, ký_
  { {0x19950014,0x8e570009,0x629e1dc3,0x69c511b7}},	//   равя, _תיוג_, _dipo, _vehe
  { {0x7ae2007a,0x36d50015,0x765a0c88,0x57b500ac}},	//   kuot, иобр, lity, рбат
  { {0xcddb0046,0x2fc90070,0x7ae20010,0xf3f00012}},	// [49f0] ење_, raag_, juot, _رأي_
  { {0x59e00037,0x7ae20010,0x81c2001e,0x92b40012}},	//   _नागर, duot, šēja, _احيا
  { {0x98aa0010,0x3ea6004a,0xd6780012,0x683c0031}},	//   kybę_, _luot_, احقا_, _védj
  { {0x60c90039,0x66010002,0xe3150001,0x765a004a}},	//   ņems, zelk, имењ, hity
  { {0x34c10044,0x7ae2007a,0x61fc000e,0x645900b6}},	//   _शब्द, guot, _űrla, riwi
  { {0x08d5085b,0x7c240035,0xa2c10011,0x683503a7}},	//   ация, ķira, रीष्, _nádr
  { {0x90c2005c,0x32380009,0x66011dc4,0xda6e0012}},	//   обще, רטון_, velk, بُو_
  { {0x44d1039c,0xc0a80003,0x60c8000b,0x68380028}},	//   mą_, داول_, נּוּ_, _fídu
  { {0x7afb001c,0xeab00003,0x41e70003,0x3f990051}},	//   _uput, _فعل_, _مساف, äsu_
  { {0x387f0065,0xee360047,0xe6160015,0x44321dc5}},	//   slur_, ины_, адь_, _soy_
  { {0xdb020065,0xc329000b,0x44d105a9,0xf41f004a}},	//   lboð, _קו_, ną_, ymät_
  { {0x2aab0058,0xfae70003,0xed5600b3,0x44d10914}},	//   _køb_, يث_, рою_, ią_
  { {0xa3e70037,0x68e31dc6,0x58040012,0x765a0034}},	//   _पार_, lund, _دونك, bity
  { {0x44d106d4,0x7f840003,0xf6b20003,0x6383002d}},	//   ką_, _الهن, _بموج, ігра
  { {0x7ae2007a,0x44d113f4,0x442000b6,0x4255002d}},	//   zuot, ją_, _tni_, стят
  { {0xe80d0037,0x44ee00f1,0xb8ce0037,0x44d109bb}},	//   ाएगा_, vý_, _ओं_, dą_
  { {0xe7370047,0x7bcb0f0b,0xdfcf0003,0x68e31dc7}},	// [4a00] ает_, dagu, بيق_, hund
  { {0x200f0535,0x7ae21dc8,0x2ca7006f,0x7e230001}},	//   _lagi_, vuot, _kund_, одуж
  { {0x68e30051,0x89db000b,0x8c96002d,0x9c7d0027}},	//   jund, _בחיי, арді, luča
  { {0x04460046,0xf09f1dc9,0x44ee0107,0x9c7d0066}},	//   једн, _già_, rý_, ouča
  { {0x63a4007a,0x6b890002,0x98aa0010,0x6da60024}},	//   žino, _czeg, vybę_, _вига
  { {0x7ae2007a,0x3253002d,0xc5f8001e,0x44d10455}},	//   ruot, овір, tnēm_, bą_
  { {0x200f00c6,0x765a0006,0x3d1f0037,0xa3ea0014}},	//   _bagi_, vity, यमों_, _идва_
  { {0xa2d70037,0xd7fa0014,0x7ae20010,0xf8b30009}},	//   _बिल्, тук_, puot, חשה_
  { {0xb3a900a2,0xe786002d,0x765a004a,0x98aa0010}},	//   ğıtı, шуко, tity, rybę_
  { {0x68fe0119,0xee310009,0x6379085f,0x683c1dca}},	//   _oppd, ִֽי_, _ссср_, _médi
  { {0x244202d1,0x765a0006,0x4806002d,0x8a59001e}},	//   _cómo_, rity, _впев, ķētā
  { {0x69c800a2,0x765a0006,0x515b000b,0x20330012}},	//   _hede, sity, _בכבו, _وفلس
  { {0xba770003,0xab87002d,0x69c806d2,0xc7f70009}},	//   لاست, рунк, _kede, _כזאת_
  { {0x64830051,0x22450028,0x20041407,0x8e730012}},	//   võim, ólk_, lemi_, _واوض
  { {0x645d0061,0x22890029,0xac95046d,0xa2a70011}},	//   éris, núka_, _лакш, _टूर्
  { {0x44d10010,0xdff80037,0x759b000b,0x859b0009}},	//   vą_, ्जिद_, _בסוג, _בשוו
  { {0x44d1003e,0x85a70001,0x8cc90011,0x20040997}},	// [4a10] wą_, ајед, हीनो, iemi_
  { {0x74bd0044,0x44d10915,0x38690027,0x63a40002}},	//   वीकृ, tą_, čari_, _zgin
  { {0x7bcb0101,0x6b89000e,0xe7ef0011,0xe4e70024}},	//   tagu, _szeg, _छापा_, різн
  { {0xdcef0027,0x44d1044c,0x2f210097,0x68e31dcb}},	//   žeći, rą_, nægð_, vund
  { {0x77640098,0xfc18000b,0x68e30052,0x44d109bb}},	//   _държ, יקאי_, wund, są_
  { {0x7bcb002c,0x44d107ff,0x539c0009,0x10a50048}},	//   sagu, pą_, דידו, бикн
  { {0x248d0036,0x200f00b6,0x09f60012,0x69ba0011}},	//   _them_, _pagi_, صفية_, ्रती
  { {0x27e91dcc,0xccf2000b,0xb8ff0037,0x2ca70052}},	//   ngan_, _מכל_, _ति_, _rund_
  { {0xa2a70011,0xe7f80011,0x200f01a0,0xe7ef0011}},	//   _टूल्, ्ज़ा_, _vagi_, _छाना_
  { {0x69c80369,0x645d1dcd,0x6483005e,0xd2510012}},	//   _gede, eisi, kõik, _عنا_
  { {0x81c20035,0xc5f20009,0x645d1dce,0x200f1dcf}},	//   ģēta, הדי_, fisi, _tagi_
  { {0x6aa1008b,0x20040066,0x98140012,0xf1a90009}},	//   _hilf, cemi_, _وبنا, _טס_
  { {0xd874000a,0xe8740003,0x69c8003a,0x70740003}},	//   _بالب, _بالظ, _yede, _بالذ
  { {0x4b7a000b,0xe5a50014,0x683c0061,0xceb6000b}},	//   ראשו, _уики, _rédi, _הפסק_
  { {0x6e23047d,0x64b50003,0x645d0532,0x6e3c17d4}},	//   _innb, _احتر, bisi, örbe
  { {0xc7a6003c,0x2a780132,0x683c0025,0x6f160064}},	//   сиак, sorb_, _pédi, tvyc
  { {0x64ac003a,0x7c24002c,0x86c60012,0x9eea0012}},	// [4a20] _eğil, _inir, صيان, طفال_
  { {0xa3ea0037,0x2d96003c,0x44f10081,0x7ae6016d}},	//   _माह_, брес, oá_, mukt
  { {0x68fe0163,0x69ce0028,0xcea9000b,0x3a37000b}},	//   _uppd, mabe, תי_, _הרים_
  { {0x44f1001a,0x032604ac,0xe5880009,0xe7ef0011}},	//   iá_, йден, בָנָ, _छाया_
  { {0x26cf000e,0xfbd3000b,0xda34003c,0xb8eb0011}},	//   ágot_, לתא_, желы, री_
  { {0x9c7d0331,0xfe670003,0x645d1136,0xcb130009}},	//   jučn, _رد_, zisi, פלו_
  { {0x44f10028,0x61ea0028,0x69c81dd0,0xeb9f0262}},	//   já_, _öflu, _vede, ndør_
  { {0xdd8f0003,0x30130014,0x69ce07a4,0x69c80832}},	//   _سوق_, здър, habe, _wede
  { {0x26d2002c,0x17f70003,0x20040864,0x2fc0002c}},	//   nsyo_, صرية_, remi_, ibig_
  { {0x0737000b,0x6442004a,0x9c7d0027,0x20041dd1}},	//   צאים_, lkoi, gučn, semi_
  { {0x9986000a,0x38ae0028,0x78bc0066,0x69ce0027}},	//   _الاو, _nýr_, jprv, dabe
  { {0x3d000037,0xdee61dd2,0x66e61c84,0x69ce005e}},	//   _रहने_, _годи, _года, eabe
  { {0x073a000a,0xd796000a,0xf1ac0037,0x645d1dd3}},	//   _حساب_, _الشخ, _चलान, ériq
  { {0x69ce008b,0xdb1d000e,0x38ae0028,0xb9c50012}},	//   gabe, nbsé, _býr_, تقسي
  { {0x365b0093,0xd258002d,0x30d8000b,0x6442004a}},	//   _תכונ, сця_, יַּע, kkoi
  { {0xdbf10013,0x8c3d000d,0x98610002,0x96bf0011}},	//   _přík, _mişc, róć_, लीकॉ
  { {0xbda70003,0xc43c000b,0x9c7d01e9,0x4c3c0009}},	// [4a30] محاو, _תתחי, lučo, _תתחב
  { {0x31b40037,0x7bcf00b6,0xdd040011,0x0ab80012}},	//   ुरोध, lacu, रबंध_, _اطيب_
  { {0x9f590164,0x6f0912a3,0xdb0f0018,0xe5c40365}},	//   _pasó_, zwec, racõ, ясто
  { {0x26cf000e,0x515a0009,0xe58b01b0,0x91a60081}},	//   ágos_, _ככתו, אָדָ, _đỏ_
  { {0xa3ea0037,0xa3e70037,0xab2900f5,0x38691dd4}},	//   _मार_, _पाई_, рола_, mnar_
  { {0x41e7007c,0x6ca70104,0x93940012,0x7bcf0025}},	//   сіда, _граж, سجنا, hacu
  { {0xaa560012,0x38691dd5,0x2fcd005e,0x44f10018}},	//   تلوا_, onar_, taeg_, xá_
  { {0x38690065,0x44f10628,0x5d540015,0x07090012}},	//   nnar_, vá_, _экст, ليبي_
  { {0x6aa116a6,0x38691dd6,0xdb1d000e,0x62830004}},	//   _tilf, inar_, bbsé, plno
  { {0xc0cb17fe,0x3f83001e,0x6f090052,0x959902e3}},	//   _буде_, āju_, rwec, итну_
  { {0xdbc70028,0x44f1001a,0x386913bc,0x9c7d08ff}},	//   töði, uá_, knar_, ručn
  { {0x7f19002d,0x78a21dd7,0x32071396,0xe0d00012}},	//   _віку_, _giov, leny_, _أزل_
  { {0xe042007c,0x44f11dd8,0x4e29003c,0x69ce1dd9}},	//   _інши, sá_, _волн_, tabe
  { {0x64490054,0x9dab0014,0x539a000b,0x15ab0048}},	//   _llei, _съда_, יירו, _съди_
  { {0x3ce00044,0x38690028,0xa7aa0014,0xd946057e}},	//   _किये_, fnar_, иква_, цеви
  { {0x44d50039,0xe3b20003,0xa3e70037,0x6498004b}},	//   mā_, _غرب_, _पाए_, _pţiu
  { {0xa2db0044,0x44d5001e,0x05ba0003,0x44c7000e}},	// [4a40] _निष्, lā_, لدات_, lő_
  { {0x65ba0001,0x32070066,0x22570012,0x26d2020d}},	//   руар_, jeny_, _وليد_, rsyo_
  { {0x44d50039,0x6f1d008b,0x64490052,0x32070066}},	//   nā_, _ersc, _blei, deny_
  { {0xa2db0037,0x984c0066,0x9c83022d,0x23d60024}},	//   _निश्, věď_, _účto, іцер
  { {0x64420006,0xb6050159,0x74130012,0x56f60012}},	//   rkoi, _kršč, بونا, _بأجز
  { {0xa2db015f,0x44d50039,0x64490149,0xb2370012}},	//   _निर्, kā_, _elei, يكنا_
  { {0x44d50039,0x644900a7,0xf65f0028,0x8c460294}},	//   jā_, _flei, _tvær_, _деве
  { {0x6449008b,0x44d50039,0x30770003,0x44c7000e}},	//   _glei, dā_, يحية_, dő_
  { {0xf093015a,0x7bc21dda,0x32071ddb,0xb6061ddc}},	//   ונה_, mbou, beny_, оянк
  { {0x24860119,0x683c0061,0xa3ea0037,0x7cdc000d}},	//   llom_, _rédu, _माँ_, pără
  { {0x64490006,0x44d5001e,0xc0460012,0x24861ddd}},	//   _ylei, gā_, _وخصو, olom_
  { {0xa2c10037,0x9c7d00d9,0xd8170024,0x14190012}},	//   रीक्, ručo, _моєї_, حيحة_
  { {0xfbd30093,0x24860b31,0x63a90e6e,0x7e7a001b}},	//   ותר_, ilom_, ženo, potp
  { {0x768f0033,0x2480003a,0x28d10037,0x7d170028}},	//   tøye, _ekim_, _सबमि, ðasí
  { {0xa2d70037,0x394501cf,0xa935004c,0x38690097}},	//   _बिक्, áls_, чевш, tnar_
  { {0x2c210037,0x64830051,0x32070066,0x1eab0003}},	//   याओं_, lõiv, zeny_, لائي_
  { {0xddab0014,0x25ab0001,0x24860029,0x38691dde}},	// [4a50] ател_, ађен_, dlom_, rnar_
  { {0xab5b00a2,0x3255002d,0x291e003a,0x8f9b0009}},	//   saüs, _хвор, _orta_, שימי
  { {0x32070066,0x62870027,0x3869006f,0x64491ddf}},	//   veny_, mljo, pnar_, _plei
  { {0x5996000b,0x44270003,0x24861de0,0x6e38162e}},	//   _מכתב_, غراف, glom_, _lovb
  { {0x44c7000f,0x44d50035,0x291e1de1,0x7ae21de2}},	//   ző_, zā_, _arta_, grot
  { {0x7f3a0009,0x4f3a0009,0xc73a0009,0x8f9a0009}},	//   _העשו, _התשע, _התשת, _לירי
  { {0xa3eb0037,0x768b003a,0x9f400028,0x11d60012}},	//   मला_, lüyo, lfið_, سوية_
  { {0x3d000037,0x44c7000e,0xaadc0011,0x44d50035}},	//   _रहते_, vő_, _बिलक, vā_
  { {0x768b003a,0x78ba0033,0x1f650024,0x63a91de3}},	//   nüyo, _ettv, яким, _igen
  { {0xfe71000a,0x44c7000f,0x44d50039,0x5bb60037}},	//   عدة_, tő_, tā_, ूर्व
  { {0x6f0d0052,0x3eb9001e,0x69c3009b,0x7bcd1de4}},	//   hwac, ūst_, mbne, _beau
  { {0x44d50039,0x78fa000b,0x8014002d,0xeb870012}},	//   rā_, _לפעו, _офіц, فظ_
  { {0x44d5001e,0x934302ad,0x0b430048,0xd6d90034}},	//   sā_, еняе, енян, była_
  { {0x76ba000b,0xc3320009,0x44d5001e,0xdeba0009}},	//   _המספ, תוך_, pā_, _המסל
  { {0x929d003e,0x63a91de5,0x6f020030,0x24860064}},	//   _usłu, _ogen, _zpoc, ylom_
  { {0x38b1000f,0xfc320003,0x644f0002,0x63a40cf9}},	//   _már_, _سحب_, chci, žini
  { {0x2bcf0037,0x62810027,0x27ed0832,0x07b70012}},	// [4a60] _हज़ा, _oklo, igen_, سهلة_
  { {0xa5960015,0x6446004a,0x2d960281,0xf8ab0081}},	//   прещ, lkki, прес, _ưới_
  { {0x60260014,0x7ae20002,0x75560001,0x823b000b}},	//   _една, wrot, чњац, _העיצ
  { {0x64460006,0x27ed0070,0xd6d90002,0x718b0009}},	//   nkki, jgen_, zyła_, _לְכַ
  { {0x937a0012,0x289b0009,0xa2b30024,0x24070048}},	//   حصار_, _ליטא, ебіч, янци_
  { {0x26c001a2,0x6d410010,0x38b1000e,0x27ed0832}},	//   mpio_, kyla, _bár_, egen_
  { {0x4034005c,0x7e7e00b0,0x7bc20227,0x999a0034}},	//   дейс, mopp, pbou, _żyły_
  { {0x98a30001,0x7e7e1de6,0x18a3004c,0x3a3a0248}},	//   није, lopp, најм, _lopp_
  { {0xf7720012,0xf0930009,0xf34a003c,0x69c30031}},	//   عاع_, ענח_, _упал_, bbne
  { {0x0f57000b,0x7e7e1de7,0xcf570009,0x22570012}},	//   פיים_, nopp, פבית_, _فلقد_
  { {0xc04f007c,0x41bb000b,0xb5f7000b,0x66080d09}},	//   _зі_, _הצבע, הציג_, redk
  { {0x53cc0037,0x6f0d0034,0xd6d90034,0xddc80031}},	//   ारिश, ywac, syła_, ridő
  { {0x6d41003a,0x7e7e1de8,0xa3ea0011,0xa85700af}},	//   ayla, kopp, _माई_, _צידה_
  { {0x56b7000b,0x8f9b0009,0x4eb70009,0x7ae00031}},	//   _צפון_, _הידי, _צהוב_, ámta
  { {0xc5fb000b,0xd5fb000b,0x8ca60037,0x6615009b}},	//   _הפוט, _הפור, _घंटो, _razk
  { {0xd4680046,0xb9050037,0xf1bf001a,0x44f5013e}},	//   _није_, _नि_, _đám_, vå_
  { {0x2bc30302,0x59bf0037,0xb8f40037,0x7a3d020c}},	// [4a70] _व्या, ्रदर, _सौ_, _mètr
  { {0xe2a30020,0x929d003e,0x768b0060,0x9f400028}},	//   _chữ_, _opła, rüyo, rfið_
  { {0x58d40047,0x644d0f68,0x9c7d02a1,0xf9fa0009}},	//   _поэт, _klai, jučk, _והתמ
  { {0x26d9000f,0x9f9d0149,0x60d6000b,0x99750034}},	//   ások_, nção_, _קורא_, _męża_
  { {0xe46a0006,0x9f9d0017,0x8bd8000b,0xc9a9003c}},	//   ltöä_, ição_, לואו_, овле_
  { {0x41bf0011,0x7e7e00b8,0x6e950148,0xea170009}},	//   ्रिस, copp, _цигу, לַ֔י_
  { {0x64460065,0x6281009b,0xa3bf0037,0xe46a004a}},	//   ykki, _vklo, ेरा_, ntöä_
  { {0xccf2000b,0x320a0002,0x63a91de9,0x38b1000e}},	//   _שכן_, zeby_, ženj, _vár_
  { {0x59bf0037,0x41bf0037,0x5fc00037,0x25fd0011}},	//   ्रार, ्रास, ौरतल, र्थी_
  { {0x6281001c,0x44291dea,0x06960003,0xcb680003}},	//   _uklo, _ana_, ونية_, _عمله_
  { {0x240a0014,0xac0a0d60,0x7de80031,0xae1c0009}},	//   онни_, онна_, lésü, מוזכ
  { {0x64830051,0x33200573,0x7c3b1deb,0x7ae41dec}},	//   mõis, _prix_, _jour, šite
  { {0xf1060044,0x64460006,0x4e350012,0x6b890034}},	//   शब्द_, rkki, _يعتز, żegn
  { {0x9f9d0017,0x387f002a,0xeaa70003,0x64460051}},	//   ação_, lour_, ضع_, skki
  { {0x703a002d,0x320a0d57,0x55ba0009,0x386d1ded}},	//   очас_, reby_, _ומצו, oner_
  { {0x9f9d0017,0x387f002a,0x7c3b1dee,0x436a0472}},	//   cção_, nour_, _nour, _майн_
  { {0xd7ef0003,0xdbc70028,0x386d1def,0x9e660012}},	// [4a80] شكل_, _röðu, iner_, واطن
  { {0xb9c6000a,0xa5f70046,0x2fcf1a41,0xc1ac0037}},	//   _تقدي, међу_, _legg_, _चलेग
  { {0x3ea71df0,0x7c3b1abc,0x7e7e1df1,0x386d1df2}},	//   _mint_, _bour, ropp, kner_
  { {0x7c3b1143,0x26c000c1,0xdd8f0003,0x7e7e1df3}},	//   _cour, ppio_, جوم_, sopp
  { {0x6e49000e,0x17c7002d,0x14170012,0x6483005e}},	//   ásbó, _ігри_, بينة_, võit
  { {0x2d8b003e,0x93430014,0xf6470003,0xc3330009}},	//   ęcej_, ънче, _شئ_, כוד_
  { {0x7c3b03f6,0x20d30003,0xdbc70097,0xdfd00012}},	//   _four, نتيج, _töðu, هيث_
  { {0xd6da0019,0xd7e6002d,0xf993000b,0x386d1df4}},	//   ото_, фіко, כרו_, gner_
  { {0x929d0002,0x6e3c1110,0x30830012,0xceb30009}},	//   _wpła, _korb, خليف, ֣ית_
  { {0x7bc6001e,0x8b3b0009,0x6483005e,0x2bcc0011}},	//   ebku, _ותמצ, sõit, ारवा
  { {0x7c3b0a5f,0x9c7d0ecf,0x644d0440,0x387f1df5}},	//   _your, luči, _plai, bour_
  { {0xccf80066,0xac19002d,0xc5f8001e,0x5f2a0015}},	//   rtě_, чому_, tnēs_, _моем_
  { {0xccf80013,0x9c7d007a,0x9f9d0017,0x6e3c0070}},	//   stě_, nuči, rção_, _oorb
  { {0xcd360012,0xe46a008e,0xfe430048,0x5e440012}},	//   _يرغب, ttöä_, _инчо, _سَعْ
  { {0x9f9d0017,0x7de8000e,0xda0e0011,0xd83f0064}},	//   pção_, zésü, ाज़त_, áčov_
  { {0x3cf20037,0xdb25000d,0x44f81df6,0x86c50012}},	//   ँढने_, ăpân, mé_, فيرن
  { {0x9c7d080a,0x6e3c1df7,0xdef8003c,0xe46a008e}},	// [4a90] juči, _borb, дых_, stöä_
  { {0xb6a5008a,0xed8b0001,0x7c3b1df8,0xb2bc0009}},	//   _nhậ, осек_, _sour, _ומזר
  { {0xdcf80333,0x7c3b0108,0x67d50046,0x69d50017}},	//   _izvē, _pour, _пону, maze
  { {0x442902d1,0x7de8000e,0x299a0009,0xc19a0009}},	//   ña_, tésü, _מסתמ, _משתי
  { {0x6e3c024c,0xb30b0003,0x387f1df9,0x9c7d001b}},	//   _forb, تغال_, vour_, guči
  { {0xa2b20037,0xb6a5001a,0x66180159,0x386d1dfa}},	//   _इंस्, _chậ, _navk, wner_
  { {0x387f0108,0x7d1c0028,0x7c3b1de4,0x3a380009}},	//   tour_, ærsl, _tour, ורגם_
  { {0x6722001c,0xbca5000a,0x7c290052,0x7ae60028}},	//   _broj, _أمري, _uner, yrkt
  { {0xd706003c,0x69d508e1,0x6d450064,0xdb160097}},	//   еные_, kaze, lyha, _neyð
  { {0x77eb0011,0x69d51dfb,0xdd010073,0xce490024}},	//   टलुक_, jaze, žuči, їзне_
  { {0x63a4007a,0x7690004a,0x6618009b,0x44f80061}},	//   žint, käyn, _davk, gé_
  { {0xa01b0851,0x20191dfc,0x3ea70227,0xdd0c0034}},	//   _skön, _nasi_, _wint_, _róża
  { {0x63ad0058,0xe4520009,0xadf00011,0xe7e30011}},	//   _dgan, רֶת_, _चालन_, गणना_
  { {0x7f5d0164,0xe605004a,0x7f3a0009,0x4f3a0009}},	//   úsqu, ärää, _מתנג, _מתנע
  { {0x7d02003e,0x50960001,0x44f80061,0x2d870002}},	//   łosz, ерађ, cé_, żnej_
  { {0xf7720003,0x9873001e,0x20191dfd,0x6e3c1dfe}},	//   هاء_, mžēl_, _casi_, _sorb
  { {0xc052000b,0xe7290012,0xd6d20012,0x66060031}},	// [4aa0] אזן_, وسكو_, اقط_, őkke
  { {0x38b507d3,0xe6170bd8,0x69de0040,0x69d50018}},	//   _får_, нду_, _udpe, caze
  { {0x04460015,0x201900c1,0x38b51dff,0x6e3c0bc4}},	//   нежн, _fasi_, _går_, _vorb
  { {0xeb9a0014,0x6aa8006f,0xfbd20012,0x4c160012}},	//   пие_, _sidf, اتا_, عباس
  { {0x76480010,0xb6a5001a,0x33830048,0x6e3c1e00}},	//   ykdy, _phậ, лушв, _torb
  { {0x44f80061,0xfaa30560,0xf2d30009,0x68fc0159}},	//   yé_, гачо, נעו_, otrd
  { {0xed140009,0x7c660012,0xa9340306,0x7ea90073}},	//   _בַּת_, _كارل, тейш, _užpa
  { {0xdfd00003,0xb9080037,0x44f81e01,0xacfb0009}},	//   جية_, _बि_, vé_, _מהלכ
  { {0xd5bd0044,0x64ac003a,0xb6a5001a,0x25fd0037}},	//   ोरंज, _eğit, _thậ, र्वी_
  { {0x28e10037,0xf1c30029,0x44f81e02,0x63a40a05}},	//   _फिलि, čší_, té_, žins
  { {0x4d98002d,0xd657000b,0x44f81e03,0xb5fb0009}},	//   ькою_, גיית_, ué_, הליכ
  { {0xe73a0015,0x44f81e01,0xe7ea0011,0x65570009}},	//   _нее_, ré_, _टाटा_, תבטא_
  { {0x91a60020,0x44f80061,0xdb1d000e,0xa2d40037}},	//   _đó_, sé_, vasó, _बौद्
  { {0x8fa30001,0x63ad01e3,0xc7a30048,0x79a7054b}},	//   _саче, ñanz, _сичк, ербе
  { {0xdfd50047,0x361b000b,0x3d1a0037,0x67d501d4}},	//   ковы, _מוגד, नटों_, кову
  { {0x38b51204,0x69d50066,0x69da0031,0x8c3d0060}},	//   _vår_, saze, óter, _pişm
  { {0x17f80003,0x16020037,0x02a70de2,0x7c2d1e04}},	// [4ab0] عرفة_, र्भर_, _пром, _inar
  { {0xb7140015,0x4439006f,0x2b530060,0x7afd0032}},	//   ыдущ, ljs_, ıncı_, mtst
  { {0x2419002d,0x2476001e,0xbc190024,0xbca50012}},	//   ділю_, lāma_, ділі_, نمطي
  { {0x7af20066,0xe3b00003,0x7afd1e05,0x44390248}},	//   šetř, مره_, otst, njs_
  { {0x7de7002d,0x2476001e,0xb8f40011,0xf5e70024}},	//   _півд, nāma_, सी_, _півм
  { {0x3eaa008b,0xd2b80093,0x98be0010,0x0a480024}},	//   _gibt_, עלות_, štą_, нзій_
  { {0x99d40003,0xf1b40009,0x9c7d1e06,0x6d430248}},	//   اتها, נסק_, luču, änad
  { {0xd9bf0037,0x63a10002,0x3eb90066,0x63bb0034}},	//   ्रुट, ślny, ísto_, _ufun
  { {0x39490333,0xc2210011,0xd215004c,0x1e95020f}},	//   ņas_, मयाब_, _имаћ, крор
  { {0xc2c40003,0x52140024,0xada5003c,0xa01b0248}},	//   _إيلي, _йдут, капл, _sköl
  { {0xc692000b,0x2bc30321,0x4d8c0009,0x2d950048}},	//   שאי_, _व्हा, ּאכַ, ърис
  { {0xa3e70037,0xf532000b,0x443f123a,0x442d01a3}},	//   पलट_, ׁ֥ר_, _jou_, _jne_
  { {0x9c7d00eb,0xae020011,0xc1bf0011,0x16020011}},	//   juču, र्डन_, ्रूग, र्डर_
  { {0x97560009,0x0f560009,0x62831e07,0xdddc09ef}},	//   _בינו_, _בינם_, nono, _okrš
  { {0x442d1e08,0xd1790024,0x7afd1e09,0x62830997}},	//   _one_, есті_, atst, iono
  { {0x443f1e0a,0xb3a9003a,0x63ad017b,0xa2d20011}},	//   _nou_, şıyı, žanj, _डबल्
  { {0xdfcf0003,0xd6d90024,0xf1d10011,0x98a3137f}},	// [4ac0] زيل_, етє_, हरान, рите
  { {0xc333000b,0x12aa0012,0x95fe0011,0x39470097}},	//   _כוח_, _تدعى_, ैजेट_, kyns_
  { {0x64a6002d,0x30860003,0xca370009,0xea890012}},	//   важа, _للدف, _סנטה_, _ثخين_
  { {0x3d190037,0x0b46002d,0xb609001e,0xd6d90002}},	//   _बनने_, кнен, _atšķ, szły_
  { {0x768f0119,0xd36f0003,0x442d095d,0xbab30012}},	//   tøyl, يهم_, _dne_, لمنب
  { {0xfe67000a,0xcb130009,0xd9180012,0x11d80012}},	//   _ضد_, ילד_, فيتش_, روبة_
  { {0xd1300003,0x443f1e0b,0x9e630001,0x628e0028}},	//   صمة_, _fou_, _тврд, ilbo
  { {0x44fc0145,0xb8140001,0xa927002d,0xc173000b}},	//   mí_, удиј, тіше_, יחו_
  { {0xae020037,0xc6f70015,0xd0070001,0xdb000028}},	//   र्थन_, вных_, тење_, _afmö
  { {0x22f70093,0x443f00bd,0x7690008e,0x62831e0c}},	//   _בזמן_, _zou_, käym, cono
  { {0x443f0274,0x44fc0382,0xc5f3000b,0xa01b0097}},	//   _you_, ní_, בדת_, _sköm
  { {0xae020044,0x443f0065,0x98aa0010,0x7afd1e0d}},	//   र्तन_, ðu_, mybė_, ttst
  { {0x38b80065,0x44fc1e0e,0xc458003c,0x5b14003c}},	//   _hér_, hí_, тиях_, амят
  { {0x61bf0037,0x38b8000e,0xdb090025,0x32050064}},	//   ्रेष, _kér_, énég, ýly_
  { {0x44fc0013,0xadf70003,0x443f001a,0xc0d40009}},	//   jí_, _شروط_, ưu_, טֵּה_
  { {0x38b80028,0x628e0010,0x7afd0052,0x62831e0f}},	//   _mér_, albo, ptst, zono
  { {0x2d8e0052,0xa3e60037,0xf3ff0018,0xf699004c}},	// [4ad0] üfen_, पणन_, lião_, евај_
  { {0x8fa40001,0x98aa0010,0xa2b00011,0x1d6b0012}},	//   рађе, kybė_, ंदर्, وصاً_
  { {0x69d80013,0x442d001c,0x99350003,0xf3ff0017}},	//   dave, _pne_, _صفحت, nião_
  { {0x8c3d00a2,0x3035003c,0x63bd0031,0x62830034}},	//   _kişi, _семё, ncsn, wono
  { {0x661c00a2,0x443f0017,0x38691e10,0x7dc70012}},	//   _fark, _vou_, miar_, _لتأك
  { {0xf41f0006,0x6d480010,0x4374002d,0xaa670048}},	//   hdä_, kyda, шуєт, ътек
  { {0x44fc0013,0x64ac003a,0x98aa0073,0x9c7d001b}},	//   cí_, _işin, gybė_, grčk
  { {0x442d02b5,0x629a004a,0x6d480914,0xef190fa4}},	//   _une_, _ehto, dyda, еми_
  { {0xe7310003,0xfc640014,0x69ca000e,0x07090012}},	//   صصة_, _търн, bbfe, ريدي_
  { {0x91ca0037,0xab5b000e,0x3869000d,0x69ca0321}},	//   _स्पै, baüz, hiar_, _स्पी
  { {0xf3ff0149,0xdfd10012,0x3ff50012,0x04461e11}},	//   gião_, _هيا_, _مكار, генн
  { {0x8c560012,0x26d90031,0x36d51e12,0xf99200af}},	//   ائدا, ásos_, _бодр, _פרא_
  { {0x44fc0107,0xf74b0003,0x6f070035,0x387a0031}},	//   zí_, _تجاه_, nībā, épre_
  { {0xc1780010,0x8c3d0060,0x2cad0aa7,0xbcd900ae}},	//   _odėl_, _dişi, _lied_, _كذبا_
  { {0xe2970046,0x2d940014,0x50b505f0,0xc8b5003c}},	//   уар_, _кръс, исту, исты
  { {0x8c3d007d,0xdd3b0034,0x44fc1e13,0x205508e0}},	//   _fişi, _dąże, ví_, атур
  { {0x290500a2,0x5baa002d,0x6fb30003,0xcc57000b}},	// [4ae0] çlar_, _яким_, إمكا, _תספק_
  { {0x2bcc0037,0x64400778,0x44fc1e14,0xbbcc0011}},	//   ार्थ, _somi, tí_, ार्क
  { {0x01fb000b,0x216a0001,0xdd8f0003,0x69d81e15}},	//   _אפיל, _чини_, كوك_, vave
  { {0x98aa0010,0x3ce60d1f,0x44fc1e16,0xc3d60012}},	//   vybė_, čov_, rí_, اغاث
  { {0x201200a2,0x38b80065,0x661c1e17,0x2cad002a}},	//   meyi_, _sér_, _tark, _died_
  { {0x7f2b000b,0x98aa0010,0xa2260012,0x64400032}},	//   _אֵלֶ, tybė_, طرته, _womi
  { {0xf41f004a,0xda650012,0xdd920012,0x69d81e18}},	//   ydä_, جاني, _طور_, rave
  { {0x6f160002,0x64560010,0x6d5a0066,0x64401e19}},	//   owyc, ūzij, vzta, _uomi
  { {0xc9f6000a,0xd5b0000a,0x61f60003,0x6f07001e}},	//   _مساع, يفة_, _مساء, cībā
  { {0x715a022e,0x98be0010,0x42db000b,0x6d481e1a}},	//   _прес_, štę_, _נקבע, tyda
  { {0x2459002d,0x2012003a,0x8b020034,0xdcee0073}},	//   вань_, keyi_, łędn, _vybė
  { {0xf993000b,0xc0ff001a,0xcf260012,0x87260012}},	//   _הרע_, _lướt_, _مرتي, _معتم
  { {0x6d5a0d27,0xf3ff0017,0xe4510009,0x4e140011}},	//   szta, sião_, חֶם_, ड़ाई_
  { {0xd6270001,0x28b60011,0x36f70009,0xa5460012}},	//   _боље_, _आंशि, _עצום_, _مضبو
  { {0xe0d50001,0x6724001e,0x54e60012,0xaa7b0042}},	//   робњ, evij, _إستق, krýv
  { {0x6018002d,0x83670012,0x20120060,0x3d190011}},	//   лося_, _مدخل, geyi_, _बनते_
  { {0x2dd50014,0x3eae0040,0x9df90048,0x38691e1b}},	// [4af0] ижар, _kift_, кнат_, riar_
  { {0x539c000b,0x877b000b,0x63a90042,0xd3380009}},	//   _איחו, תאמי, žens, _תרזה_
  { {0x2cad0061,0x867b0009,0xe89505d8,0x38691c75}},	//   _pied_, ערבו, _вань, piar_
  { {0x6f07001e,0x69d70052,0x3d050011,0xa4d40024}},	//   tībā, _hexe, _रहीं_, соці
  { {0x16140037,0xb7da000b,0x3fda000b,0xe3b80024}},	//   तजार_, _בקרי, _בקרב, убі_
  { {0x628709d4,0x9aa40012,0xe299004c,0x6f070035}},	//   nojo, ممنو, њак_, rībā
  { {0x6f07001e,0x3d140037,0x321e0b32,0xb1160012}},	//   sībā, _फैले_, _daty_, لقوا_
  { {0xdb1d0051,0xa6e50538,0xaae70012,0xc0c8004c}},	//   lasõ, ажил, _مسئو, ћује_
  { {0x62871e1c,0x61e50042,0x64560035,0x7cc10035}},	//   kojo, _odhl, ūzik, _mēre
  { {0x67260028,0x7690004a,0xe7080012,0x9e650365}},	//   ækja, väyk, اتين_, рвод
  { {0x6f160002,0x2012003a,0x2d82003a,0x481502ad}},	//   zwyc, yeyi_, şken_, _вмес
  { {0xd46a002d,0x63ba0066,0xe58c0009,0x38690248}},	//   тиме_, ětno, עָזָ, _öar_
  { {0x3084000a,0x20d3007d,0xe81e0011,0x20840012}},	//   _النف, lţi_, _मोटा_, _النّ
  { {0xca35000b,0x2ba70011,0x20d3004b,0xdb1d005e}},	//   ׁנָה_, _गणरा, oţi_, jasõ
  { {0x20d3007d,0x2012003a,0x290c0054,0x68460014}},	//   nţi_, teyi_, ïda_, анва
  { {0x20d3000d,0xe8e0001a,0x70560003,0xd7f20012}},	//   iţi_, _liệt_, جنرا, تكر_
  { {0x2012003a,0xa6aa0003,0x6ec50012,0xe7aa0048}},	// [4b00] reyi_, ناطق_, متلق, твал_
  { {0xd5eb0020,0xcb9b000b,0xdb9b000b,0x44201e1d}},	//   _địn, _בספט, _בספר, _hai_
  { {0x4420007a,0x69dc1e1e,0x3f8f0073,0x73c60012}},	//   _kai_, mare, _lygu_, ليام
  { {0x4420052d,0xabaa0012,0x0326073e,0x2eed0097}},	//   _jai_, نهام_, иден, kref_
  { {0xe8e00020,0x44201e1f,0x20d3000d,0x2b160015}},	//   _biệt_, _mai_, eţi_, рьер
  { {0xae020044,0x44201e20,0x6ce50011,0xdb1f0018}},	//   र्शन_, _lai_, _किंग_, _reqü
  { {0xe8e0001a,0xfce30055,0xdb1f01d7,0x6a130012}},	//   _diệt_, _моро, _seqü, زبور
  { {0xc0340046,0x9d1b000b,0x645900f7,0x44201e21}},	//   сниј, _בולט, chwi, _nai_
  { {0x20d3007d,0xa2b20037,0x25fd0037,0x2ee00cf1}},	//   aţi_, _इंग्, र्की_, nsif_
  { {0x44321e22,0xbafb000b,0xfe720003,0x7e540024}},	//   _any_, _בהמש, تدع_, своє
  { {0x2d980033,0x0e33002d,0x2db70009,0x69dc1e23}},	//   åre_, інюю, ילין_, dare
  { {0x98be0013,0x69ce1e24,0x26060011,0x60ca0032}},	//   ště_, ebbe, स्ती_, mpfm
  { {0x53440015,0x44320066,0x6287001e,0x44201e25}},	//   охра, _dny_, tojo, _dai_
  { {0x86c30012,0x44250034,0xdb1d0031,0x38bc0031}},	//   _بيون, śl_, ncsé, _bír_
  { {0x442001a2,0x3d050037,0x6456002a,0x0e9b000b}},	//   _fai_, _रहें_, _flyi, _ששול
  { {0x0854002d,0x653b0009,0xdd3b0009,0x7f070024}},	//   овсю, _יעוד, _יעוכ, иїзд
  { {0x57a70014,0x7bdd01b7,0x53f80012,0xe7300012}},	// [4b10] ршва, masu, _ضريح_, وصك_
  { {0xe3b00003,0x0e34002d,0x7d01006f,0x831c0009}},	//   _ترى_, оную, _älsk, _יוחז
  { {0xa3bb0003,0xc27c000b,0x74a70001,0xd5b80400}},	//   ناشر_, _ברזי, ајде, рсу_
  { {0x4c950015,0x8c3d000d,0x68f5003a,0xd0060012}},	//   щиес, _nişt, muzd, _عل_
  { {0x69c10052,0x2903000e,0xda040011,0x289a0009}},	//   _pfle, ltja_, श्वत_, _תירא
  { {0xdb06000e,0xd264002d,0x7bdd0cb1,0xf2070055}},	//   ámán, окій, hasu, рядо
  { {0x2a58015a,0xe8e00020,0x68f500a2,0x999a001e}},	//   שבון_, _việt_, nuzd, _kopš_
  { {0x20d3007d,0x69dc041f,0x94050003,0x21780009}},	//   rţi_, zare, _دوره, יתור_
  { {0x69dc00a2,0xf5b5002d,0x3eb91e26,0xc8640012}},	//   yare, йсню, _just_, تطوي
  { {0x3eb90666,0x7c20009b,0xee390001,0x8e740024}},	//   _must_, _zamr, уно_, жуюч
  { {0xb9950003,0x671c0037,0x99850003,0xac86002d}},	//   _الاب, _बैठक_, _الضو, йгол
  { {0xf09f0020,0xed56002d,0x645d0010,0x7d1a0009}},	//   _nhà_, сою_, ūrin, נֵיה
  { {0x44201e27,0x29030028,0x386d1e28,0x69dc1e29}},	//   _vai_, etja_, mier_, tare
  { {0x386d1e2a,0x11da0012,0xd2520012,0xfc3f0030}},	//   lier_, طورة_, أنس_, ají_
  { {0x44201e2b,0x69dc1e2c,0x7d1c0097,0xf1a90012}},	//   _tai_, rare, ærst, لافه_
  { {0x44e300a2,0xe3b20012,0xdfcf0012,0x3859003c}},	//   mı_, _عرب_, فيف_, арую_
  { {0xfc57000b,0xf5b60003,0x44e3003a,0x2fc0000e}},	// [4b20] _לבקש_, مصاد, lı_, rcig_
  { {0x7c200065,0x386d01da,0x3eb90132,0xcf920009}},	//   _samr, hier_, _dust_, לטן_
  { {0x44e300a2,0xf1bf001a,0x7ae40033,0x2ee00061}},	//   nı_, _đáp_, _hvit, ssif_
  { {0xaae60003,0x7bcd0097,0xdd3b0034,0xc5090012}},	//   مستو, ðaup, dąża, شتمل_
  { {0x6d5e0002,0x9f4001e3,0x765a008e,0xf7720012}},	//   szpa, rgió_, yhty, _راح_
  { {0x4df50098,0x46a3002d,0xd6cf0003,0x7d250028}},	//   _мяст, _наяв, _سقف_, ðusí
  { {0x386d02b5,0x05db0037,0x8d6302ad,0xa3d80011}},	//   fier_, _मज़ब, _евре, िरा_
  { {0x44e300a2,0x8cd20037,0xd1380002,0xc563003c}},	//   dı_, _भौगो, _rząd_, _экск
  { {0x22451e2d,0x10470048,0x76aa0148,0x29030031}},	//   _folk_, сящи_, лтов_, ztja_
  { {0x29030028,0x4357000b,0x44e3003a,0xee310009}},	//   ytja_, _הסמל_, fı_, ֵֽי_
  { {0x69da0039,0x25fd0044,0x7bdd1e2e,0xe4150024}},	//   _iete, र्टी_, tasu, однь
  { {0x0d97000b,0xb606001e,0x386d1e2f,0xab950024}},	//   מכים_, lašā, cier_, жимі
  { {0x69da00c6,0x3f670015,0xdc8b0009,0x889b0009}},	//   _kete, _лицо_, רְיָ, _עבדי
  { {0x44e3003a,0x7bdd00ff,0x69da0d29,0xf1c90012}},	//   bı_, sasu, _jete, شورى_
  { {0x915f0020,0x44e300a2,0xd4c60003,0x7ea90010}},	//   _bắt_, cı_, _اغتي, _užpi
  { {0x2903000e,0x2ca0000d,0x4cf70009,0xa2d40011}},	//   rtja_, _ghid_, _הזהב_, _बौक्
  { {0xaae70003,0x29030e42,0x95d9034d,0x9f340024}},	// [4b30] _اسبو, stja_, идат_, петі
  { {0xceb30093,0x69da1e30,0xd3580009,0x291e182a}},	//   פיע_, _nete, _לשחק_, _osta_
  { {0x2457003a,0x65150012,0xf5790012,0x6fb50012}},	//   _açma_, توائ, جماع_, _ومدا
  { {0xd3710003,0x25fd0011,0x62950032,0xa01b0248}},	//   وها_, र्जी_, llzo, _sjöf
  { {0x291e0d41,0xa3ac0011,0x923903a8,0xc2c40012}},	//   _asta_, केप_, ичку_, كيني
  { {0x44e300a2,0x672d001e,0xa229003c,0x1a29003c}},	//   yı_, _šajo, ржка_, ржки_
  { {0xd9420014,0xa8590001,0xa1560001,0x61420048}},	//   дещи, ијих_, жају_, деща
  { {0xd6d1000a,0xdb210029,0x7bc21e31,0x31580009}},	//   وقع_, _štýl, ccou, מיון_
  { {0x69ca0044,0x9f400065,0x291e1e32,0x0ee20011}},	//   _स्वी, ngið_, _esta_, _पिछड
  { {0x7d090001,0x44e3003a,0x3eb1000e,0x63ad0604}},	//   аног_, tı_, özt_, žans
  { {0xc5f20093,0x1d09057b,0xca840012,0xc3290009}},	//   ודי_, шени_, _علمً, _שו_
  { {0x44e300a1,0xb4fa000b,0x69c502d2,0x935a0024}},	//   rı_, ספרי, _afhe, аргу_
  { {0x44e300a2,0x69da00a2,0x8c1a000b,0x24760035}},	//   sı_, _yete, בורי, nāmi_
  { {0x7690004a,0x59cf0321,0x5ee80009,0xd6e80009}},	//   näyt, _स्मर, _הַקְ, _הַקָ
  { {0x54e40012,0x602606bd,0xd82604ac,0x67291489}},	//   _فسيق, одва, одви, lvej
  { {0x6f041e33,0x645d0052,0xa9270010,0x3ff60012}},	//   ttic, chsi, mažė, تكرر
  { {0x76900006,0x39a3000e,0x67290058,0x9f400028}},	// [4b40] käyt, tésé_, nvej, ggið_
  { {0xa01b006f,0x7c240132,0xa5960048,0xe5720012}},	//   _sköt, _hair, орещ, وطا_
  { {0x915f001a,0x7c241e34,0xa7d60012,0x0c260024}},	//   _tắt_, _kair, _وتحص, жмен
  { {0x7bc20061,0x7ae2004a,0x87b9002d,0x69da1e35}},	//   ucou, tsot, _гурт_, _sete
  { {0xbb430015,0x7c241e36,0x7bc20ebe,0x78ba0073}},	//   мецк, _mair, rcou, _sutv
  { {0xdbd90028,0x6729078d,0x98c60400,0xe7310009}},	//   hæði, dvej, осил, _אֵל_
  { {0xd5b8001e,0x115a0009,0xafb90097,0x628a1e37}},	//   udām_, ידַע, _áááá_, rofo
  { {0xe8e00020,0x6e2300bd,0x69da00bd,0x30130014}},	//   hiệp_, _aanb, _wete, ддър
  { {0x69da0ff4,0x44240018,0x32181e38,0xc64a00ae}},	//   _tete, _iam_, kery_, لجدل_
  { {0x78ba0005,0x0737000b,0xe7310051,0xa5f80001}},	//   _tutv, קאים_, _tööü, љену_
  { {0x645d0010,0xd7e6002d,0x55bb000b,0x68020030}},	//   ūrim, _діло, ימיו, _půjč
  { {0x64420006,0xfe78007a,0x2bb10037,0x44261e39}},	//   njoi, snį_, ुँचा, ndo_
  { {0x44240002,0x6442008e,0xf8b30009,0x27e01e3a}},	//   _mam_, ijoi, _חשף_, dain_
  { {0xfe6f000a,0x6442004a,0x539b000b,0xcdb80024}},	//   _لدى_, hjoi, ייכו, _угкц_
  { {0x7c241cb4,0x306b0001,0x8cc10037,0x32280024}},	//   _fair, ајан_, _रूपो, ціям_
  { {0xa8a4002d,0x7c240054,0x27e000a5,0x91cb0011}},	//   друк, _gair, gain_, _त्रै
  { {0xf7700003,0xb9020037,0x501b000b,0x7de70012}},	// [4b50] ناك_, _नौ_, סומו, قسام
  { {0x551e0037,0xe6130003,0x91ca0011,0x68e10097}},	//   _बनाए_, بشر_, _स्लै, álds
  { {0x59de0037,0x621a0009,0x78a20064,0xbd680189}},	//   _नज़र, _הותק, _ohov, орце_
  { {0x44241e3b,0xe58b0009,0x27e01e3c,0x24760035}},	//   _cam_, בָדָ, cain_, tāmi_
  { {0x7690004a,0x883a000b,0x403a000b,0x103a0009}},	//   täyt, _התרו, _הגרג, _הגרע
  { {0x4426084f,0x76ba000b,0x08d50014,0x4a44002d}},	//   ado_, _למשפ, пция, мнів
  { {0x76b20002,0xf5590012,0xa3d5004c,0x645d0035}},	//   _płyn, _الأب_, _новч, īrij
  { {0xb97c0093,0x787e0039,0x7690004a,0xb17c000b}},	//   ינוי, tīva, säyt, יטור
  { {0xdbd90065,0xf7710003,0xa3ca0011,0x883c0009}},	//   væði, عاب_, ोरर_, שתחו
  { {0x67291e3d,0x4d6501ef,0x05650021,0xf9930012}},	//   rvej, зков, звон, _قبض_
  { {0x32181e3e,0xfc3f00d9,0xceb40009,0xa3d70011}},	//   very_, rmín_, ויץ_, ाऐं_
  { {0xfd56000b,0x59cf0037,0x399a0009,0xc19a0009}},	//   פשרי_, _स्तर, _היעד, _השעי
  { {0x7c240333,0xeb9f00c5,0xdbd90065,0x8c1a000b}},	//   _vair, lføj_, ræði, זורי
  { {0x19b9007c,0x4426007a,0xd0190002,0x27e0002c}},	//   жуть_, zdo_, leń_, wain_
  { {0xc6920093,0x10a61e3f,0x00c90009,0x2056004c}},	//   _ראו_, зивн, מֶּֽ, птар
  { {0xd6d20012,0x649d0018,0xb3420060,0x32181e40}},	//   فقر_, péia, şçil, sery_
  { {0x33fb000b,0xabfb0009,0x27e01e41,0xe737176d}},	// [4b60] _ההפנ, _ההפר, rain_, пет_
  { {0x1779007c,0x44241e42,0x8ca00011,0x7690008e}},	//   ість_, _sam_, _गीतो, väys
  { {0x91bb0009,0xc1bb0009,0xf7690009,0x0dc90012}},	//   _למיי, _למיש, נק_, تبقى_
  { {0x7469007c,0xd326002d,0xdd8f0012,0x628e1e43}},	//   орів_, зьки, دوم_, lobo
  { {0x64420006,0x69de00c6,0x4424048b,0x27f701bd}},	//   rjoi, _kepe, _vam_, šené_
  { {0x19940014,0x26c20029,0x44240034,0x5eeb0009}},	//   маля, íkom_, _wam_, _לַלְ
  { {0x24760039,0xa3ac0037,0x7690004a,0x621b0009}},	//   lāmu_, केत_, säys, מוסק
  { {0x757b000b,0x5d7b000b,0xc8630015,0xc866002d}},	//   _הטלפ, _האלק, етьи, ятли
  { {0xa411003a,0x2476001e,0x59be0011,0x41b60048}},	//   lığı_, nāmu_, ्डार, _есет
  { {0x69de1e44,0x7ae90b9c,0xab770012,0xdbe50011}},	//   _nepe, šetk, _عملا_, कण्ड_
  { {0x386000c6,0x186a004c,0x628e1e45,0xd7ef064d}},	//   khir_, _лажи_, dobo, _пу_
  { {0xf8aa0046,0x6ab50037,0x38a10002,0xd0190002}},	//   _увек_, ंद्र, tóre_, ceń_
  { {0x69de00bd,0xa3be0037,0x93270012,0xdb240097}},	//   _bepe, ेड़_, أرجن, ýrðu
  { {0x69de0061,0xd3570009,0x6722008e,0x07370009}},	//   _cepe, ליכי_, _isoj, _מאדם_
  { {0x06b10066,0xc5eb0009,0x609b0012,0x7e9b0009}},	//   řící_, _הַחֹ, مخرج_, _הסגו
  { {0xa41100a2,0x5597000b,0xf0b4002d,0x7d7b0009}},	//   dığı_, _מדוע_, ейсь, _לנוו
  { {0xf773000a,0x3d180037,0x33750024,0xd7c80012}},	// [4b70] رار_, यौरे_, _ігор, سوله_
  { {0x645b00bd,0x0378000b,0xd0190002,0xaadc000b}},	//   _slui, _מתחת_, zeń_, _החזר
  { {0xa25b0026,0x3cf70037,0x55bb000b,0x64490018}},	//   spôs, ँढें_, צמאו, _poei
  { {0xfc640014,0x38810010,0x69c80910,0x84640048}},	//   нъчн, bėra_, _afde, нъче
  { {0x3ce90037,0x3c78000b,0xeb8e0021,0x0dcb1e46}},	//   _चटके_, התאם_, ти_, _губи_
  { {0x7bdf0061,0x22960028,0x539c0009,0xd5e10011}},	//   _lequ, tæki_, ציגו, _फ़िज
  { {0x661a012e,0xba080012,0x2bce0011,0x64ac0060}},	//   detk, ستوك_, _ह्वा, _rşiv
  { {0x97d9002d,0x11280024,0x06c90223,0x92f20060}},	//   цьку_, яючи_, огий_, üğüm
  { {0x26010037,0x649d0025,0x29071e47,0xf7710012}},	//   _शादी_, téin, stna_, ضاة_
  { {0x43280009,0xfe450024,0x916c0081,0x661a016d}},	//   _מֵעֲ, єнно, uộc_, getk
  { {0x16020037,0x7ae90028,0x7cc1001e,0x61e31e48}},	//   र्टर_, _hvet, _vēro, manl
  { {0x69de00c6,0x7ae9119d,0xc9520009,0x909b0012}},	//   _sepe, _kvet, _שמא_, _اضطر_
  { {0x7ff40003,0x0b43002d,0x44630014,0xe8e00081}},	//   _أسما, внян, твяв, _thịt_
  { {0x76ba000b,0x3ab50001,0x672d02a1,0x01da0012}},	//   _ומספ, ељст, dvaj, توسع_
  { {0x661c005e,0x62720034,0x27ff0097,0x38601e49}},	//   õrke, kłon, ogun_, thir_
  { {0x63bb0101,0x27ff00c6,0x10a30046,0x7ae91e4a}},	//   _ngun, ngun_, висн, _ovet
  { {0xe64a00b3,0x61e31e4b,0x4a760012,0x69de1e4c}},	// [4b80] опад_, kanl, _يُعر, _tepe
  { {0xa411003a,0x63bb003b,0x61e30028,0xe2920012}},	//   tığı_, _agun, janl, _جذب_
  { {0x8c46002d,0xdbc60051,0xd23b0009,0x9a3b0009}},	//   меже, _mööd, _וגיל, _ותיק
  { {0xed57002d,0x2bd50037,0x69b30037,0x6f091e4d}},	//   ьох_, दरगा, ेखनी, ktec
  { {0x671c0044,0xe7e10011,0x6e390031,0x290a0031}},	//   _बैंक_, _गज़ा_, ábbí, ltba_
  { {0x787e001e,0xf773000b,0xc4c60012,0x61e3140e}},	//   tīvo, _יקר_, _يتزو, ganl
  { {0x661a000f,0xc1030003,0x2476001e,0x290a000e}},	//   vetk, نووي, nāms_, ntba_
  { {0xdfd0000a,0x20020051,0x787e0035,0x88bb0009}},	//   دية_, üki_, rīvo, חזקי
  { {0xf093000b,0xf1cf0037,0x59cf0037,0x61e3003a}},	//   כנה_, _स्वन, _स्वर, banl
  { {0x3f98001e,0x20020002,0x64ac0060,0x7afd0248}},	//   āru_, żki_, _eşit, _åsta
  { {0xe01e0037,0x984c0002,0x672d009b,0x7bdf01c5}},	//   _पसंद_, jść_, zvaj, _pequ
  { {0x83fd000e,0xacc70009,0x84340024,0x3d1e0011}},	//   _előf, וּךְ_, внює, _बनीं_
  { {0x984c0002,0xe666010c,0xfbd30009,0xa08b0009}},	//   eść_, _отко, כתר_, _וְגִ
  { {0x62720002,0x8f9b0009,0x179b0009,0xa37b005e}},	//   złon, _וידי, _וידב, baõn
  { {0x19940014,0x38a1000e,0xd5fb0009,0x45fb0009}},	//   варя, lóra_, _ופור, _והוג
  { {0x27e4006f,0x9c870012,0xa3ea05f3,0x61e309b8}},	//   namn_, _تشته, मणः_, zanl
  { {0x3eb80065,0xe8940015,0x61e3003a,0x59d00011}},	// [4b90] _birt_, тать, yanl, _त्वर
  { {0xc5fb0003,0x7afd1e4e,0x42550012,0x321c0030}},	//   تعرض_, must, _أندر, jevy_
  { {0x27ff003a,0x7ae91e4f,0x3eb80132,0x88c70012}},	//   ygun_, _svet, _dirt_, _تتخل
  { {0x859b0093,0xfbd00003,0x6f090002,0x4429019a}},	//   חשבו, لته_, ytec, _jaa_
  { {0x38a10028,0xdee70003,0x7afd1e50,0x44291e51}},	//   jóra_, _تأجي, nust, _maa_
  { {0x62720002,0x23760012,0xcb580009,0x5ee80009}},	//   słon, عمود_, וסדה_, _קַרְ
  { {0x7afd0005,0x90e40012,0x7bc10030,0x2d980060}},	//   hust, نسين, ěluj, ürel_
  { {0xc9b8000b,0x98a20014,0xdbc60051,0x2c620029}},	//   והות_, лище, _sööd, _kóde_
  { {0xef160047,0xfe0e001a,0x91ca0037,0xe7310003}},	//   емы_, _vững_, _स्कै, اصب_
  { {0xd1c50003,0x8a370003,0x984c0002,0x6f091e52}},	//   _أيضً, _تعرض, yść_, rtec
  { {0xc6920093,0xb5790109,0x6f091e53,0x7e60004b}},	//   ראי_, ящих_, stec, _împe
  { {0x3d070044,0xc209000b,0x68fc0262,0x9d520012}},	//   _हमने_, _לה_, vurd, انَت
  { {0x9f050003,0xdbc60051,0x61e11e54,0x44291e55}},	//   _أوتو, _tööd, _kell, _daa_
  { {0x66f60093,0x44290006,0x61e114d4,0x68fc1e56}},	//   _נמצא_, _eaa_, _jell, turd
  { {0x644d000d,0x68fc0051,0xf9870012,0x2aa40031}},	//   _foai, uurd, اب_, több_
  { {0x387f0065,0x290a000e,0x7c290051,0x984c0034}},	//   nnur_, rtba_, _naer, rść_
  { {0x3f860017,0xa5da0012,0x18670024,0xa3ac0011}},	// [4ba0] çou_, كبار_, хати_, केश_
  { {0x61e1034e,0xab5b003a,0x63a4003a,0x31260024}},	//   _nell, zcük, _izin, _здог
  { {0x89db000b,0x38a1000e,0x41760012,0xdb0a0064}},	//   _מחיי, zóra_, _سادس, čnít
  { {0xf4960003,0xc5e90009,0x3eb80032,0x64ac0060}},	//   رشاد, מד_, _wirt_, _aşir
  { {0x7c2900c6,0xc477000b,0x321c0029,0xe29a0578}},	//   _daer, עתנו_, tevy_, пад_
  { {0x60c100a2,0x61e11e57,0x75d60012,0xb97a0009}},	//   _bulm, _cell, _سيرا, ּנֵי
  { {0x61e1034e,0x6da3035c,0x7afd031f,0x3d1e0011}},	//   _dell, _бира, zust, _बनें_
  { {0xc0340001,0x61e1005e,0xc1730009,0x8f4609c2}},	//   тниј, _eell, טחו_, еход
  { {0x501b0009,0xcb670024,0x80a30012,0x200a0034}},	//   לוקו, _зате_, دمين, ębi_
  { {0xb6020013,0x7afd1e17,0x44291e58,0x9a6a0012}},	//   _část, vust, _saa_, _عمال_
  { {0xa3d50015,0x44290192,0x2d980260,0xfcaa0009}},	//   конч, _paa_, ære_, ּיָּ
  { {0x61e10052,0x7afd15ae,0x5b27003c,0x7d7b0009}},	//   _zell, tust, ньга, לניו
  { {0x291e003a,0x61e11e59,0xa3ac0011,0x80d90011}},	//   çtan_, _yell, केल_, _फौजे
  { {0x3885001e,0x67260028,0x7afd1e5a,0x764e020d}},	//   mēra_, ækju, rust, _noby
  { {0x7afd1a9f,0x19950014,0x30a70001,0x929b0009}},	//   sust, тавя, ерав, פילת
  { {0x759b0214,0xbca50003,0x859b000b,0x2d820060}},	//   _מיוח, _جمعي, _משוו, şkes_
  { {0x187b000b,0xf41f004a,0x81c20035,0xa08b0009}},	// [4bb0] פטמב, meä_, ģēja, לְמִ
  { {0x765a0010,0x4b7c000b,0x38a10028,0x26cf001e}},	//   nkty, _מאחו, jórn_, īgo_
  { {0x61e11ace,0x63a4001e,0x40950012,0xb8950012}},	//   _rell, _zzin, _للدر, _للدع
  { {0x61e11e5b,0x999a0013,0x43750294,0x9cd70009}},	//   _sell, _např_, култ, גואה_
  { {0x44290029,0x65640066,0x765a00b0,0x83c40024}},	//   ľa_, _řihl, kkty, убіж
  { {0x764e002c,0x4429013a,0xe3b00012,0x2f5a0009}},	//   _goby, ža_, حرم_, _חדשנ
  { {0x3a380009,0xddda0030,0xf41f008e,0x63730031}},	//   תרום_, entů, keä_, _bűnö
  { {0xf9900012,0x765a0034,0xb8db0011,0x7aed1e5c}},	//   حبه_, ekty, _ें_, _ovat
  { {0xef19007c,0xd7060015,0x387f00b6,0x64960031}},	//   ємо_, вные_, rnur_, káir
  { {0x2ca900b6,0x9f5f0f4c,0x92b70012,0x61e11e5d}},	//   _ahad_, ngué_, _أحرا, _uell
  { {0x63a4000f,0x26060037,0x69ca0011,0x7aed1e5e}},	//   _szin, स्टी_, _स्टी, _avat
  { {0xed56007c,0x765a0002,0x6f0d0002,0x2d870060}},	//   тою_, akty, ktac, üney_
  { {0xa3ac0044,0x0323007c,0xa8560009,0xd7f80048}},	//   कें_, адян, _שינה_, _чух_
  { {0x9987000e,0x26c2016d,0x877a00af,0xa77a00af}},	//   lenő_, _ruko_, _קאסי, _קרספ
  { {0x26c20026,0x91e305f7,0x40960578,0x20c70081}},	//   íkov_, росе, врат, _cõi_
  { {0x20c70020,0x7eab0052,0x26140011,0xdfcf0012}},	//   _dõi_, nüpf, न्नी_, قيف_
  { {0x6ca50012,0x6fb30012,0x47c30adc,0x63a41e5f}},	// [4bc0] _حصول, لمفا, рбув, _uzin
  { {0x787b0006,0x645d0073,0x3f9c0035,0x833700af}},	//   tävä, ūrit, āvu_, _יאפס_
  { {0x09f70009,0xf8b30011,0xa01b0097,0x6f0d0034}},	//   _במים_, ुदाय, _kjöl, atac
  { {0x97da0003,0xaae60003,0xfd950024,0x25a90012}},	//   _تبدأ_, نستو, ушую, ردلي_
  { {0x77830014,0x27fd0002,0xbc670012,0xa01b0248}},	//   _вляз, ówne_, ضمون_, _mjöl
  { {0xdce90030,0xf2d30009,0xbb4700ae,0x68f80ea4}},	//   áněn, סעו_, ئلون_, trvd
  { {0xda650003,0xc27b0009,0xca7b0009,0x1543091c}},	//   داني, ורסי, ונסט, _керм
  { {0xc9530093,0x628f0017,0x98be0010,0x83fd000e}},	//   שמה_, _ícon, štė_, _előb
  { {0x9f490028,0xbbde0037,0x67240070,0x799a0002}},	//   ngað_, मरीक, nwij, _wytw
  { {0x672b0097,0x8fa3004c,0x000000c4,0x000000c4}},	//   ægji, шање,   ,
  { {0x765a01ab,0x7aed024e,0xa3c90011,0xc27b0009}},	//   rkty, _svat, लुक_, _קרבי
  { {0x67240227,0xa1570009,0x6f0d1e60,0x765a0248}},	//   kwij, _שבאה_, ytac, skty
  { {0xcff70009,0xab870024,0x2ef30024,0x61e71e61}},	//   _יצאה_, тунк, _взір, tajl
  { {0x07a30001,0xc333000b,0x67240070,0x1757000b}},	//   _тачн, בוש_, dwij, _בסדר_
  { {0xa01b0065,0x0c7b0012,0x67240227,0x644d008e}},	//   _fjöl, _يصعب_, ewij, öaik
  { {0x20c703fb,0x260e0044,0x61e700a2,0x9f9d0065}},	//   _või_, त्री_, sajl, _bæði_
  { {0x5335011f,0xb2ab0024,0x9f490097,0x26170011}},	// [4bd0] _септ, _отож_, ggað_, _बॉडी_
  { {0x07080003,0x752f0002,0x20c7005e,0xfe700012}},	//   ئيلي_, łcze, _tõi_, يدل_
  { {0x20160029,0xdd910012,0x7c2d1e62,0x8cf5004c}},	//   ícií_, حوا_, _kaar, узец
  { {0xda050037,0xbc18002d,0x7c2d0c42,0xc6d70012}},	//   _राहत_, віші_, _jaar, _لتست
  { {0x7c2d01e5,0x9f9d0028,0x27e91e63,0xc2c40012}},	//   _maar, _gæði_, maan_, ليني
  { {0xdd86000a,0xdb1d0248,0x27e91e64,0x45d40198}},	//   _هو_, bbsö, laan_, _ворс
  { {0xc6920093,0x7cc1001e,0x7e60000d,0xf2040024}},	//   _האם_, _tēri, _împa, рячо
  { {0xccf20093,0x27e90947,0x7af60010,0x6295000e}},	//   _לכל_, naan_, šyta, hozo
  { {0xdd2e0066,0x6295000e,0xe3b30012,0x443f1e65}},	//   měře, kozo, _ضرر_, _inu_
  { {0x27e900c6,0x442d004a,0x2f0b0058,0x7c2d002c}},	//   haan_, _hae_, røg_, _aaar
  { {0x2f0b00c5,0x27e91e66,0x69c10164,0x67240002}},	//   søg_, kaan_, _igle, zwij
  { {0x27e90577,0x97250012,0xd6d90034,0xa158004c}},	//   jaan_, _مفصو, zyły_, _шаху_
  { {0x7c2d00bd,0xc87900a2,0x27e91e67,0x5ac70024}},	//   _daar, miş_, daan_, ллям_
  { {0x412a0625,0xf1bf0029,0x6295000e,0x43750109}},	//   ного_, ášho_, gozo, руют
  { {0x8cca0037,0x395e0028,0xa96a00db,0x62720034}},	//   _संयो, áts_, хива_, włok
  { {0xc879003a,0x787e001e,0x645d031d,0x91d40011}},	//   niş_, tīvi, cksi, _ब्रै
  { {0x61e5008b,0x69c10470,0x44221e68,0x7ae90029}},	// [4be0] _fehl, _ogle, mek_, šetr
  { {0x672400bd,0x3a260015,0x9f490028,0xcec10002}},	//   rwij, _смог, rgað_, mięć_
  { {0xdca60014,0xde51001a,0x67240070,0x2d9c0058}},	//   гажи, _đặc_, swij, æve_
  { {0xcdc90093,0x16130037,0x44221e69,0x27e90631}},	//   לך_, त्तर_, nek_, caan_
  { {0x68e30e46,0x6e21007a,0x98b30037,0x442209d4}},	//   _ændr, kelb, ूआरए, iek_
  { {0xab77000a,0x69dc04a3,0x11540264,0xcb130009}},	//   دمها_, nbre, иклю, צלו_
  { {0xd1300003,0x645d004a,0x6e211e6a,0xa227004c}},	//   زمة_, yksi, delb, ужја_
  { {0xb6f40001,0x78630051,0x44221e6b,0x8cca0011}},	//   азиј, _kõva, jek_, _संबो
  { {0xa857000b,0x6a660028,0x3b861a44,0x24530012}},	//   טיקה_, _aðfe, _слаг, _انقس
  { {0xd3370009,0x91d40011,0xdce30060,0x6e2118e6}},	//   _גרמה_, _ब्लै, _aynı, gelb
  { {0xf67b000b,0x0697000b,0x27e90a26,0x629519d5}},	//   תאימ, רדים_, yaan_, vozo
  { {0x3d070044,0x4422000f,0x645d0006,0xa37b005e}},	//   _हमसे_, gek_, uksi, laõi
  { {0x6295000f,0x27e90006,0xeb070015,0x40930003}},	//   tozo, vaan_, ычно, _النر
  { {0x7c2d01e4,0xae030037,0x27e90a60,0x442d1e6c}},	//   _waar, _लाइन_, waan_, že_
  { {0x7c2203a0,0x64400070,0x27e91e6d,0xd49b1e6e}},	//   keor, _onmi, taan_, _при_
  { {0x442200a2,0x4fd50086,0x20ca0081,0xddc10073}},	//   cek_, ржат, _mùi_, bilų
  { {0x62830002,0x6276001e,0xf3ff0017,0xdd2e0066}},	// [4bf0] ynno, iņoj, lhão_, věře
  { {0xa37b0051,0x27e91e6f,0x6abe0032,0xfe730012}},	//   jaõi, saan_, _gipf, حدر_
  { {0x26140037,0x2aba0009,0xb2ba0009,0xf3ff0018}},	//   न्धी_, _שמתא, _שמתר, nhão_
  { {0x7c221e70,0xd0060003,0x50da0009,0x4c95003c}},	//   geor, _ظل_, _שקרא, шиес
  { {0x7dc70003,0x2903004a,0x6e2e00c1,0xbb450063}},	//   _متأك, luja_, _fabb, релк
  { {0x2bd50037,0x26140037,0x38690017,0x6d5a0010}},	//   _ड्रा, न्दी_, lhar_, kyta
  { {0x3258015a,0xaa560001,0xc879003a,0x2903009b}},	//   רסום_, рију_, tiş_, nuja_
  { {0x5d84000a,0x38690017,0x7ccc003a,0x6d5a0911}},	//   _الفل, nhar_, _uğra, dyta
  { {0xc87900a2,0x7b67002d,0x57460014,0xaa070003}},	//   riş_, _стве, изъм_, _مظاه
  { {0x7e550046,0x6272003e,0xee3600c0,0x2903004a}},	//   ртиц, dłow, ань_, kuja_
  { {0xc05b007c,0x8d75000a,0x6f1c007d,0x32cb0033}},	//   _під_, شادا, ărca, _høy_
  { {0x6e210052,0x76b20002,0x0d960009,0x95960009}},	//   selb, _błys, יכתם_, יכתו_
  { {0xdee50001,0x76b20002,0x69dc08de,0x44221e71}},	//   _толи, _płyt, tbre, rek_
  { {0x44221e72,0x9f840024,0xd5490012,0x368b05d8}},	//   sek_, _угід, _للتو_, _ясен_
  { {0xc0760046,0xdca60047,0xcec8001a,0x38760001}},	//   аћањ, _каки, _tộc_, аћат
  { {0xad1a0093,0xe7ac0037,0x251a000b,0x2087002d}},	//   _יוצר, _चरमप, _יוצא, айси_

  { {0x27fd003e,0x929d003e,0x29030010,0x34b30012}},	// [4c00] ówna_, _wpły, auja_, _بميز
  { {0x64410039,0x7df30037,0x2bde0037,0x05ba0012}},	//   ēlie, _आयोग_, मर्थ, ندات_
  { {0x929d0002,0x10a600b3,0x98a604ad,0x716a00db}},	//   _upły, _винн, _вине, _ранг_
  { {0x38691e73,0x7ae41e74,0x3d0705f3,0xe3bf107f}},	//   char_, _kwit, _हमरे_, señe_
  { {0x7e60000d,0x6e2e1e75,0x7bf70024,0xcb340048}},	//   _împo, _tabb, рнір_, селъ
  { {0x6a830047,0xcb37000b,0xb8f40003,0x64580002}},	//   олча, יאני_, مكتب, _ścią
  { {0x63a9000e,0x8cc10037,0x61ea1e76,0x58f60009}},	//   _ezen, _रंगो, rafl, ׁמַע_
  { {0x14d70093,0x9cd7000b,0x64401763,0x97240012}},	//   _כולל_, _כולה_, _unmi, مفعو
  { {0x76aa0015,0xa857000b,0x93fb0009,0xc9f60012}},	//   ктов_, שיפה_, _שלמי, _نساع
  { {0x6d5a0010,0x1daa0037,0x248605dd,0x7afd02a1}},	//   tyta, _करात, lnom_, vrst
  { {0x38600028,0x44e3000e,0x160b0037,0xc5f3000b}},	//   kkir_, gű_, स्टर_, חדת_
  { {0x24861e77,0x2903004a,0x7d030054,0xdfcf0003}},	//   nnom_, vuja_, ànsi, _قيم_
  { {0x3ed4000a,0xe451000b,0x6f041e78,0xc0450012}},	//   _اقتر, הֶם_, juic, _دخلو
  { {0xf20e0044,0x6d5a003e,0x3d070037,0xde57002d}},	//   _साफ़_, pyta, _हमले_, _ваші_
  { {0xadd7000b,0x62720002,0x31350014,0x07e7011d}},	//   _דווח_, słow, щевр, ицам
  { {0x7cc10039,0xdda9002d,0x7bc400c1,0xfc3f0054}},	//   _vērt, _стіл_, _ggiu, rmís_
  { {0x395f001e,0x248609b5,0x62980fa8,0x2903079b}},	// [4c10] ņus_, dnom_, kovo, suja_
  { {0x2486006f,0x386900b6,0xcfb70009,0x2cad0132}},	//   enom_, shar_, שלמי_, _shed_
  { {0x91fc001e,0x63a91e79,0x7ae400c7,0x7d790012}},	//   _plān, _szen, _zwit, دمار_
  { {0xef1f003a,0x83fd000e,0x62800042,0xbd440012}},	//   çük_, _előn, émov, تنمي
  { {0x2418002d,0x53980024,0x28c00011,0xd4380009}},	//   рією_, авця_, _शूटि, יראק_
  { {0xa3ac0044,0x6298048b,0xe1f10012,0x20f3001b}},	//   केट_, govo, سست_, oći_
  { {0x25a5000e,0x721c0009,0x248612f1,0xa3d70011}},	//   _áll_, דווח, bnom_, िडा_
  { {0x6c850003,0x200919ba,0x38290001,0xc2c50012}},	//   _الرم, ngai_, ужио_, _هيري
  { {0x7cd3000d,0x62980042,0xdd380035,0xa7120012}},	//   _măre, bovo, māša, كِيع
  { {0xf7720009,0x36180024,0xd4d90024,0x44e30031}},	//   פקי_, ацюю_, льмі_, tű_
  { {0x62870027,0xd1080012,0xc1040012,0x7ae41e7a}},	//   dnjo, _نقله_, _ووكي, _swit
  { {0xdd380039,0x44e3000e,0x15f30011,0x6287008e}},	//   nāša, rű_, _आयकर_, enjo
  { {0xc43a000b,0x38a10028,0xa3d70037,0x20f3001b}},	//   אתרי, jóri_, िड़_, eći_
  { {0x539a000b,0xfbd80037,0x8f9a0009,0x24860220}},	//   רישו, _भ्रम, _גיני, znom_
  { {0x7643003e,0xa06a0098,0x291e0054,0xa9670345}},	//   _inny, гава_, ïta_, бира_
  { {0x320c0002,0x7cd3000d,0x62981e7b,0xf9920009}},	//   żdy_, _căre, zovo, פרן_
  { {0xcf250003,0x6444002c,0x24861328,0x38601e7c}},	// [4c20] يركي, _inii, vnom_, rkir_
  { {0x44321e7d,0xf41f004a,0x1a0600de,0x7c260102}},	//   _hay_, nnän_, _упом, lekr
  { {0x61ee0f52,0x5bc60003,0x44321e7e,0x27ed004a}},	//   mabl, مقال, _kay_, kaen_
  { {0xdd8f000a,0xd499007c,0xe3bf01e3,0x61ee1e7f}},	//   رون_, арі_, leña_, labl
  { {0x44321e80,0xa3c90037,0x33170012,0x389b0009}},	//   _may_, ोड़_, مزود_, _תיכנ
  { {0x248605dd,0xb2ba0009,0x44321e81,0x1958003c}},	//   snom_, אמְר, _lay_, иалы_
  { {0xdd38001e,0x6a130003,0xc5e40011,0xe2130012}},	//   bāša, سبور, गरीय_, سبوع
  { {0x44321e82,0xc6f81104,0x27e001ea,0x74160012}},	//   _nay_, аних_, nbin_, _دورا
  { {0x3366007c,0xe5c60024,0x62980ba5,0x6d5e16d5}},	//   _уваг, йсно, povo, lypa
  { {0x1757000b,0x70b40037,0x5757000b,0x78a400d9}},	//   מספר_, ंगुल, צביע_, hliv
  { {0xe0da0046,0x44321e83,0x9a3b000b,0xb9960012}},	//   _све_, _bay_, _תתבק, _الضب
  { {0x7cd3000d,0x629e016d,0x44261e84,0xb7bd004b}},	//   _bărb, _akpo, neo_, seţa
  { {0x443203f2,0xddc80027,0x389b0009,0x3ed70012}},	//   _day_, midž, _גיאנ, _هونج_
  { {0x6fa5000a,0x4426001a,0xa6b60014,0xd1260003}},	//   _بإمك, heo_, _усещ, وم_
  { {0xa617000b,0x7cd3000d,0xacf30003,0x4e17000b}},	//   _הקוד_, _păre, _فسيت, _החוב_
  { {0x20090010,0xc7d901c6,0x7c261e85,0x7bc40073}},	//   ugai_, рмах_, cekr, žiuj
  { {0x7655003e,0x2009055c,0x62350b05,0x66d50012}},	// [4c30] _pozy, rgai_, _депу, زيائ
  { {0x63ad001e,0xf1c70066,0x83fd000e,0x6dc701ec}},	//   _izan, část_, _elől, ссаж
  { {0x44320060,0x60191612,0x78a41e86,0x44261e87}},	//   _yay_, _коня_, bliv, feo_
  { {0x442600c1,0xac1919fc,0x2419003c,0xd5b80223}},	//   geo_, роду_, роды_, ссу_
  { {0x7eaf0119,0xa3ea0011,0x36d50a36,0x6d5e1e88}},	//   løpe, यरत_, _фогр, aypa
  { {0x7c260002,0x388500cd,0xddc80071,0xdd380035}},	//   zekr, mēri_, eidž, sāša
  { {0x7cd3000d,0x46ce0037,0xa3d50024,0xa9250024}},	//   _mărc, _हूबह, _мовч, ідил
  { {0x26c30164,0x5f450012,0x317c0009,0x1f650024}},	//   _hijo_, قنبل, טרומ, жким
  { {0x62720002,0x53470339,0x44321a48,0x7c261e89}},	//   głos, _ухва, _ray_, vekr
  { {0x0696000a,0x8cca0037,0x44321e8a,0xb65901ef}},	//   ينية_, _संशो, _say_, рших_
  { {0xf3f9000d,0x7cd3000d,0x5c8a002d,0xbc790009}},	//   _alţi_, _sărb, ийом_, ֹנָת
  { {0x16190037,0x75360009,0x61ee0132,0x29071e8b}},	//   न्तर_, קארד_, wabl, muna_
  { {0x6d5e003e,0xd6db011f,0x78a40066,0xa3af0011}},	//   zypa, _сте_, vliv, _करण_
  { {0x7fb6000a,0x44320036,0x11da000a,0x386d0149}},	//   _ظهور_, _way_, شورة_, lher_
  { {0x4432001a,0x61ee1e8c,0x29071e8d,0x26d9008e}},	//   _tay_, rabl, nuna_, _atso_
  { {0xe3bf02d1,0x248d09d2,0x54730012,0x386d0032}},	//   seña_, _njem_, _يهوذ, nher_
  { {0xa0670098,0x8fa305cc,0x07a302e2,0x98be0010}},	// [4c40] цата_, дате, датн, štį_
  { {0x96b90024,0x95e40011,0x6d5c005e,0xa3af0610}},	//   буху_, गरेट_, ärag, _करत_
  { {0xae190037,0x26c30164,0x052a0015,0x78a409d2}},	//   न्धन_, _dijo_, роек_, pliv
  { {0xcea90093,0x14170003,0xa5da0011,0xf7461e8e}},	//   די_, قيمة_, _प्रौ, _демо
  { {0x8c1b000b,0xc053000b,0x44261e8f,0xa22a0048}},	//   שוני, _חזר_, reo_, ижда_
  { {0x29070028,0x6f1617b3,0x44261e90,0xe2460012}},	//   funa_, mtyc, seo_, تخصي
  { {0xed5a002d,0x63a4002a,0x29071e91,0xb4260012}},	//   _тов_, _lyin, guna_, _وعرو
  { {0x386d002a,0x6f160002,0x3ea5006f,0x9f54002d}},	//   gher_, otyc, ellt_, звич
  { {0xf8b3000b,0x6f160002,0x29071092,0xcb6706fd}},	//   ושה_, ntyc, auna_, _дате_
  { {0xda660003,0x29071e92,0xbbe30011,0x386d0032}},	//   _باري, buna_, पर्क, aher_
  { {0xa06a0014,0x63ad0053,0x29071e93,0x186a0646}},	//   _кажа_, _szan, cuna_, _кажи_
  { {0x6f160002,0x386d1055,0xac190024,0x248d0018}},	//   ktyc, cher_, щому_, õem_
  { {0x8c1b0009,0x20e8004b,0xe3b00012,0x629c1e94}},	//   בוכי, eşi_, َرُ_, foro
  { {0x63a40132,0x32d00081,0x6f160248,0x629c1e95}},	//   _dyin, _mày_, dtyc, goro
  { {0x30d80009,0xaffd0024,0x628a1e96,0x6d5c03bd}},	//   מַּע, ловi, info, ärad
  { {0x4395002d,0x200f0051,0x62800025,0xa2f50048}},	//   _найс, ügi_, émor, _епич
  { {0x32d0008a,0x20e8000d,0x63ad003a,0x96eb003c}},	// [4c50] _này_, aşi_, _uzan, рьба_
  { {0xe3b00003,0xcddb0001,0x85a70001,0xe3bf01e3}},	//   _جرى_, рња_, ојед, leño_
  { {0x8fe70012,0x69d50034,0x7d080040,0x6f161804}},	//   _وأحم, mcze, nuds, atyc
  { {0x32d0001a,0xa3af0321,0xd3b90024,0x228d0064}},	//   _bày_, _करा_, блеї_, oľko_
  { {0x1308002d,0xd5b1001a,0x9991000e,0xcfab0003}},	//   жній_, hép_, mező_, _خادم_
  { {0x9991000e,0x69d50002,0xe2990001,0x77ba0009}},	//   lező_, ncze, љак_, _למרח
  { {0x386d1e97,0x82340003,0x81f60003,0xd24e0012}},	//   ther_, برنا, سفير_, انى_
  { {0xbd440003,0x1128002d,0x45440012,0x6bd40012}},	//   _تنفي, юючи_, _تنفق, _يتقر
  { {0x7eab000e,0x386d0052,0x2907045a,0xa3ea0011}},	//   nüpo, rher_, suna_, यरस_
  { {0x32640014,0x313515db,0x22580012,0x7d09004c}},	//   _отхв, _незр, _وجلب_, бног_
  { {0xcb09000b,0x9991000e,0x69d50002,0x99830066}},	//   _תל_, kező_, dcze, dejů_
  { {0x69d50002,0x6f160002,0x9991000e,0x89340003}},	//   ecze, ytyc, jező_, _زعما
  { {0x70520003,0x87040003,0x290300b6,0x5f280024}},	//   _سنوا, _قبول, erja_, _моїм_
  { {0x70b40037,0x7d080033,0x7f3a000b,0x629c03ec}},	//   ंग्ल, buds, _לענו, uoro
  { {0x7e60000d,0xe5a206fd,0xc8c70012,0x3e320012}},	//   _împi, _пиши, كوّن_, _سفير
  { {0x629c029d,0x20d1001a,0x786a0042,0xf55a0009}},	//   soro, _mái_, _býva, _לדצמ
  { {0x629c012e,0x83fd000e,0x20d1001a,0xa6db0097}},	// [4c60] poro, _elők, _lái_, _arðb
  { {0x69d50066,0x673b004a,0x6f160002,0x3885001e}},	//   ccze, ivuj, rtyc, mēru_
  { {0x6f16003e,0x4a5b000b,0x725b0009,0xb91a0012}},	//   styc, _הדיו, _הכיפ, _اتخذ_
  { {0x3d1c015f,0x136a002d,0x9b6a002d,0xc20e0011}},	//   _नहीं_, йшли_, йшла_, _साहब_
  { {0x7c360101,0x883b000b,0xcf3a0024,0x73360012}},	//   _mayr, _התכו, _учні_, ثرائ
  { {0x60c6047b,0xbb830012,0x27f2020d,0x20d10081}},	//   _hikm, علوي, layn_, _bái_
  { {0x20d10020,0x67221e06,0xe467005e,0x6e281e98}},	//   _cái_, _spoj, ööks_, vedb
  { {0x69d50002,0x7d08006f,0xdfd00003,0x64a3024d}},	//   zcze, vuds, خية_, _заса
  { {0x07f70003,0x6f041e99,0x17f70012,0x74130012}},	//   سريع_, nric, سرية_, _سولا
  { {0xe678002d,0x60c6001e,0x29030028,0x20d10028}},	//   ійні_, _likm, yrja_, _fái_
  { {0x6e280027,0xceb80002,0x20d1001a,0x29180029}},	//   redb, rmę_, _gái_, jtra_
  { {0x2b200044,0x672d0002,0x7d080058,0xe50d0011}},	//   _यहाँ_, ywaj, ruds, ांति_
  { {0xa5f8011d,0x883b0009,0xf7490012,0xdfcf0012}},	//   _делу_, _לתאו, _وجهه_, _إيه_
  { {0xfe6f0003,0xe3bf0164,0xf7bb000b,0xa2c40001}},	//   _مدى_, seño_, _הזדמ, ељск
  { {0x69d50002,0x9991000e,0x67d5002d,0xce370012}},	//   rcze, tező_, добу, _رأوا_
  { {0x7ceb000b,0x6e35015b,0x30a40024,0xb8e70011}},	//   _הַזֶ, _sazb, ерув, _ों_
  { {0xbfab0047,0xcc340003,0x93fc000b,0x3ed90012}},	// [4c70] стве_, _سريع, _הלחי, زواج_
  { {0x442b1e9a,0x9df90024,0x5e780009,0x629a0064}},	//   lec_, інет_, קָּד, čtoc
  { {0x6e350066,0x6f0400c1,0x44391e9b,0x7863005e}},	//   _vazb, aric, ods_, _lõvi
  { {0xc0ab0003,0xf9920009,0x442b0ac6,0x44391e9c}},	//   _داخل_, _ירי_, nec_, nds_
  { {0x9f59003a,0x90560009,0xe3b00012,0x883a0009}},	//   üsü_, _חברו_, هره_, _ותרו
  { {0x442b0061,0xa021003a,0xa01b0028,0xbb42046d}},	//   hec_, _çöze, _gjör, тешк
  { {0x63a80002,0x90b50001,0x659417af,0xe1f00012}},	//   ędni, мљиш, _зару, اسه_
  { {0xf1b4000b,0x44391e9d,0x260b0011,0x673b1e9e}},	//   עסק_, jds_, ालवी_, tvuj
  { {0x64c40012,0xfb150012,0x521500b5,0x25d50009}},	//   _سيكل, _زواج, _одат, ֽוֹן_
  { {0x20d1001a,0xda1f0037,0x44390644,0x4d650695}},	//   _tái_, म्मत_, eds_, дков
  { {0xb5790015,0xc5f2000b,0x316b004c,0x7c390034}},	//   ющих_, כדי_, _ушао_, odwr
  { {0x645b0061,0x947a0024,0xa99a0009,0x7c390132}},	//   _joui, існу_, _ובער, ndwr
  { {0xe738002d,0x3862000e,0x6f090e0a,0x8c1a0009}},	//   _неї_, ökre_, quec, חורי
  { {0x7e660039,0x78a91e9f,0x290a1ea0,0x78bb005e}},	//   ūkpr, llev, tuba_, lmuv
  { {0x3d0c0044,0xc05a004c,0x29181ea1,0x83fd0031}},	//   _हमें_, орац_, utra_, _elői
  { {0x3885001e,0x29180074,0x8c3b0052,0xceea0048}},	//   mērs_, rtra_, toße, ждае_
  { {0x62831082,0xaec60538,0x29181ea2,0x98a303e2}},	// [4c80] kino, дбал, stra_, тите
  { {0x8c3b0052,0xda0a0012,0xa50a0024,0x8cd90009}},	//   roße, _بيده_, жежа_, ַחְת
  { {0x6f040052,0xf7690009,0x645b12f3,0x6cd30012}},	//   sric, סק_, _boui, نقلا
  { {0xbb86000a,0x50b6007c,0x32d4004a,0xc689000b}},	//   ولاي, _існу, _käy_, בא_
  { {0x23ba0012,0x5bba0011,0xa01b0991,0x62831032}},	//   آداب_, ेशेव, _tjör, fino
  { {0x539b0009,0x03770009,0xa3bf0011,0xa3de0011}},	//   חינו, ותנת_, ुख़_, _द्र_
  { {0x7c2b1ea3,0x645b0025,0x94d60012,0x44391ea4}},	//   begr, _foui, _آيرش, yds_
  { {0xcec80020,0x62831082,0x2c62022d,0x29001844}},	//   _hội_, aino, _kódu_, čia_
  { {0x32d4004a,0x3885001e,0xe80f0011,0x442b1ea5}},	//   _näy_, vērt_, िलता_, vec_
  { {0x7cd3000d,0x98ae003a,0x26cf1ea6,0x7ae21ea7}},	//   _căro, ınır_, _dugo_, mpot
  { {0x8916000a,0x7ae21ea8,0x7e60004b,0xcec80081}},	//   _زبائ, lpot, _împu, _mội_
  { {0x27ef0028,0x3888003a,0x7af60010,0xc9530009}},	//   _gegn_, oğru_, šytu, _במע_
  { {0xa6db0065,0x26c701a2,0xe29f0028,0x00bb0009}},	//   _orða, _fino_, erða_, _ומאמ
  { {0x28a70037,0x99580066,0x6d410010,0x7c2b0002}},	//   _कीजि, láře_, _šlam, zegr
  { {0xcec80020,0x7e9b0009,0x6d581ea9,0x95530012}},	//   _nội_, _וסגו, äval, _لخيا
  { {0xb4fb0009,0xa9370009,0x3cfb0009,0x99580030}},	//   _ולהר, וטלה_, _ולהנ, náře_
  { {0xeb0d0037,0x69da1e2d,0xb8d60011,0x765c0034}},	// [4c90] _समेत_, _ofte, _ची_, _bory
  { {0xff17000b,0xfc4600d9,0x2bb80012,0x76ab0024}},	//   וקמת_, šíte_, _غاية_, ітав_
  { {0x61f5003a,0xfbd30012,0x8c3d0060,0x7dd10031}},	//   mazl, نتش_, _akşa, _hűsé
  { {0x1ddf015f,0x05df0044,0x69da0036,0x91ba000b}},	//   _प्रत, _प्रब, _afte, _ממתי
  { {0x3c78000b,0xb7da000b,0xf3f00003,0xe8df001a}},	//   ותאם_, _מקרי, شأن_, _khỏe_
  { {0xb062005e,0x38691eaa,0xc1c90011,0xdb1e0031}},	//   ääva, lkar_, िखेग, évág
  { {0x64ca0037,0x236900eb,0x10a50511,0x6f0d0a04}},	//   िदृश, šaj_, никн, luac
  { {0x69da1eab,0x38691cfc,0xc5f90037,0x442b001a}},	//   _efte, nkar_, ूल्य_, _úc_
  { {0x6f0d0e8c,0x38690028,0xb9060011,0x26c71eac}},	//   nuac, ikar_, _बढ़_, _pino_
  { {0xf6510003,0x5eec0009,0x5334004c,0x2f230035}},	//   ائة_, קַחְ, _јефт, mīgā_
  { {0x38690065,0x27ef0989,0x26140011,0xf6520009}},	//   kkar_, _tegn_, न्टी_, אצי_
  { {0x3e690026,0xbc19000b,0x113a0009,0x8c190009}},	//   _túto_, הוֹש, _מתעל, הוֹי
  { {0x3ea10005,0x2f23001e,0x90560009,0xbf670012}},	//   koht_, nīgā_, _רבנו_, _تداو
  { {0xd7740003,0x64620002,0x29071ead,0x78f90009}},	//   _جامع, _świą, orna_, ּפּו
  { {0x628e09d8,0x36e80011,0x71660012,0x60260048}},	//   rnbo, _चौड़ी_, راسك, ндва
  { {0x786a022d,0x244a0012,0x69d80159,0x66150034}},	//   _vývo, _رجعي_, zcve, _aczk
  { {0x62811eae,0x2d1f0011,0x91fc0035,0x6e260031}},	// [4ca0] _omlo, _बहुल_, _klāt, őkbe
  { {0xdb9b000b,0xee3700b3,0x539b0009,0xa2d50011}},	//   _מספר, нну_, _מיפו, _यंत्
  { {0x9f420006,0x8a17000b,0x7afb1017,0xceb20009}},	//   _sekä_, _אחיו_, _avut, ניב_
  { {0x38690163,0x78710655,0x63a90262,0x59dd0011}},	//   ckar_, _påve, _byen, नुसर
  { {0x7ae212ff,0x52d70024,0x3e720025,0xcb340048}},	//   upot, емію_, _hâte_, телъ
  { {0xcec8001a,0x69c10097,0x7ae21eaf,0x6d431eb0}},	//   _tội_, ýleg, rpot, _orna
  { {0xdd920003,0x3a3a006f,0xfd070012,0x66c90073}},	//   _صور_, _mapp_, _حج_, _užka
  { {0xc953000b,0x98a30001,0xb9230012,0x9d1b0009}},	//   רמה_, лије, افيي, _מולט
  { {0xdb1d000e,0x2f23001e,0x57b40048,0x78a00d4c}},	//   lcsö, cīgā_, ъбит, romv
  { {0x9b93000a,0xff7b000b,0x8afb000b,0x99580066}},	//   _إلكت, פטימ, _מהמי, sáře_
  { {0xc58a0015,0x83fd000e,0xfc3f05b1,0x6d43001b}},	//   ящие_, _előu, slím_, _crna
  { {0xead50015,0x24860002,0x26ca020d,0x7f421030}},	//   комь, niom_, _libo_, _troq
  { {0x291c000e,0xfbab0015,0x3869009b,0xae100011}},	//   ltva_, ятой_, vkar_, ालान_
  { {0xc2c5000a,0xcf890003,0x07370009,0x2ba50011}},	//   ئيسي, _تضمن_, _נאום_, _गुणा
  { {0x3e72000d,0x291c000e,0xe29f0028,0xe4a703e2}},	//   _câte_, ntva_, nuði_, _прио
  { {0x35aa0011,0xbb850012,0xd92b0009,0x43850012}},	//   _करज़, _للعي, הֵמָ, _للعق
  { {0x9e070014,0x38690395,0x644d000d,0x7c2f01a0}},	// [4cb0] ечел, rkar_, _inai, mecr
  { {0x9f040003,0x7c2402a1,0x7c3d0262,0xc7c4003c}},	//   اولو, _zbir, ldsr, усси
  { {0x3eaf0039,0xf77f0061,0x442400b6,0xa3d60037}},	//   ēgt_, _reçu_, _bbm_, ाँच_
  { {0xfbd00003,0x62810066,0x6f1b0002,0x6fb50012}},	//   مته_, _smlo, ytuc, _لمجا
  { {0x27e90642,0xab9b0012,0x4ca80012,0xa2b70011}},	//   mban_, أخضر_, رُهُ_, ोगप्
  { {0x6287007a,0x82180014,0x7cc90002,0x2f230035}},	//   nijo, ецът_, _ośro, rīgā_
  { {0x3a38000b,0x409514a1,0x99320012,0x32380009}},	//   גרום_, крит, لفوت, גטון_
  { {0x27e9000f,0x7e60000d,0x6bd40003,0xdb08003a}},	//   nban_, _împr, _متكر, _ölçm
  { {0x7eab003a,0x7cc2001e,0x2ba80037,0x93970003}},	//   tüph, _tērz, _छुपा, _أجزا
  { {0x7c3b03eb,0x83fd000f,0x7bd2001e,0x78ad0042}},	//   _haur, _előt, ājuš, hlav
  { {0x27e9000f,0x26190037,0x6287078d,0x61550012}},	//   kban_, _पानी_, dijo, _جنائ
  { {0xddce0066,0x442401bd,0x9f520025,0x20030073}},	//   _dobř, ým_, sayé_, ėjis_
  { {0xe7390014,0x93fa000b,0x907a000b,0x27e9000e}},	//   _цел_, ולרי, _קטני, dban_
  { {0x24860002,0xd2520003,0x628704cf,0x412a027f}},	//   ziom_, جنس_, gijo, мого_
  { {0xc2120093,0x7fd6002d,0xc616000b,0xf9830198}},	//   יהם_, візі, _יחסי_, агро
  { {0x442f001c,0x29040029,0x27e9000e,0x6f09000d}},	//   jeg_, čma_, gban_, orec
  { {0x98450039,0xbc1b000b,0x2ee0003a,0xb4ae0037}},	// [4cc0] dēļ_, _חופש, _çift_, कती_
  { {0x62871eb1,0x6aa30033,0x78ad0017,0x27e901e3}},	//   cijo, jonf, alav, aban_
  { {0x27e9000f,0x6f090052,0x7c3b1eb2,0xda4b0009}},	//   bban_, hrec, _baur, _חֲכָ
  { {0x2541007a,0x7c3b1eb3,0x6faa0012,0xd4090012}},	//   _dėl_, _caur, _يهدف_, فتهم_
  { {0xb2d30003,0xa2d30012,0x3eac07c2,0x8bd70009}},	//   لينغ, لينت, yldt_, דונו_
  { {0x442f0051,0xc333000b,0xe5060012,0x26190011}},	//   aeg_, יוד_, _لبري, _पायी_
  { {0xcec8008a,0x764e006f,0xe2a90012,0x89130012}},	//   _một_, _inby, راهن_, لبيئ
  { {0xf993000b,0xf41f004a,0x291c000e,0x628704cf}},	//   ירו_, nnät_, rtva_, zijo
  { {0x83fd000e,0x8c1b0009,0x18330012,0xadd4004c}},	//   _elős, _קומי, شريح, лопљ
  { {0xa80600a2,0x09ba0003,0xddce0066,0x6aa31eb4}},	//   ldığ, _قطاع_, _pobř, conf
  { {0x6f09007d,0xb7bd000d,0xa96a0012,0x78a4008e}},	//   arec, deţu, _تمام_, koiv
  { {0xa80600a2,0xb4fb0009,0x4917000b,0x9ffa0012}},	//   ndığ, ופטי, _יקבל_, _آراء_
  { {0x63b6003e,0x9b580014,0x62870d66,0xeb070048}},	//   _czyn, вият_, tijo, ъчно
  { {0x8673002d,0xcec8001a,0x442f0123,0x61f81eb5}},	//   _кліє, _cột_, zeg_, navl
  { {0x236d0026,0x27e9000f,0x6287180f,0xeb9f0058}},	//   šej_, tban_, rijo, ggør_
  { {0x85570009,0x65570009,0x493b0009,0x62871eb6}},	//   _ישוב_, _יבוא_, וגלו, sijo
  { {0xdef80047,0xcaa7000a,0xf1a90037,0xd498000b}},	// [4cd0] вых_, _لصدي, _चुनन, _שכחת_
  { {0xe4e7002d,0xb0620051,0x61f80082,0x27e9000e}},	//   відн, äära, javl, sban_
  { {0x6e3c156c,0x27e9000e,0x5bcb0037,0x88c70012}},	//   _darb, pban_, िश्व, _لتحل
  { {0x25410010,0x2911003a,0xd7e40024,0xd5770009}},	//   _vėl_, muza_, _віро, כתבה_
  { {0xd5bf001e,0x6e3c1eb7,0xe73d0030,0xfc3f0030}},	//   _šādi_, _farb, _kříž, idí_
  { {0xd2510003,0x442f017b,0xddde004b,0x752a0032}},	//   صنع_, seg_, ripţ, _opfz
  { {0x2911003a,0x68e20034,0x6d5c005e,0x6aa30032}},	//   nuza_, _łodz, äral, ronf
  { {0x83fd000f,0x6d47004a,0xc9840024,0x7afd1eb8}},	//   _előr, _irja, шучи, ksst
  { {0x62850070,0x61f80604,0x7c8401d4,0xb4bf0011}},	//   _omho, bavl, _туре, ँगी_
  { {0xa806003a,0xb062008e,0x2ca91719,0x7afd1eb9}},	//   mdış, _äänt, _akad_, dsst
  { {0x63ad0061,0xcc8a0001,0x6f090832,0x19940048}},	//   _ayan, ебне_, srec, _кафя
  { {0xb4ae0037,0x67030037,0x29110017,0x6f091eba}},	//   कते_, _लिंक_, duza_, prec
  { {0x7cd3007d,0xd7f8002d,0x4c8300ac,0xa8060060}},	//   _mări, _рух_, сляв, ndış
  { {0xd295007c,0xa806003a,0x2911000d,0x45450012}},	//   арсь, zdığ, fuza_, _منتق
  { {0x50960001,0xb7bd004b,0x78a4008e,0x2d870034}},	//   грађ, reţu, toiv, źnej_
  { {0x388c0066,0xdfcf0012,0x2ba50011,0x69dc1ebb}},	//   běru_, كيف_, _गुवा, scre
  { {0x386d00bd,0x3ea50051,0x2911004b,0xdfa50012}},	// [4ce0] iker_, oolt_, auza_, لحكي
  { {0x66c9007a,0x44f10604,0xa3c90011,0x7ae4020d}},	//   _užkl, oš_, ैशन_, _itit
  { {0x04460ae9,0x386d14fb,0x6e3c1ebc,0x5d860012}},	//   лежн, kker_, _varb, دلال
  { {0xeb9a1dbb,0xb8f80037,0x386d0070,0x33f60003}},	//   ние_, ाद_, jker_, اساس
  { {0x6e3c0005,0x61f8048b,0xa806003a,0x57fb0009}},	//   _tarb, tavl, rdığ, _אלכו
  { {0xd13a010c,0xbb470012,0x386d1ebd,0x68e20034}},	//   ехи_, الون_, eker_, _łody
  { {0x61f8048b,0x14cf01c7,0x26190011,0xa9260012}},	//   ravl, _संगण, _पाती_, اعته
  { {0x63a9003e,0x6d5c0051,0xf5930012,0x8d930012}},	//   żeni, äram, _الفج, _الفش
  { {0x44f1007a,0x6a160003,0x883b000b,0xa8570009}},	//   eš_, _مبار, תתפו, ריפה_
  { {0x07370093,0xd737000b,0x388c0066,0xd3b90024}},	//   נאים_, נטית_, věru_, _русі_
  { {0x7ae4007a,0xf1a40011,0xa196004c,0xd5b00012}},	//   _atit, _खुलन, _сјај, تفد_
  { {0x2ca60e10,0x386d1ebe,0x399b0009,0x43750012}},	//   nood_, cker_, _איבד, لهجر
  { {0x657a000f,0x2f1801d4,0x44f1013a,0x7afd03d7}},	//   szth, _роль_, aš_, usst
  { {0x2ca6002a,0x7ae00097,0x99850073,0x628a1ebf}},	//   hood_, ímta, _galų_, nifo
  { {0x2ca60051,0xd5eb001a,0xe5f70009,0xa9350024}},	//   kood_, _đìn, _גזור_, шевш
  { {0xdd01001e,0x91bb0009,0xb5a50024,0x7afd1ec0}},	//   ūtīt, תמלי, _трій, psst
  { {0x44291ec1,0x14b80003,0x20980015,0x804b0009}},	// [4cf0] _iba_, _حدوث_, укты_, עֲלֶ
  { {0xdd9b002d,0x11d90003,0x7cd3004b,0xe29f0097}},	//   нше_, _جودة_, _sări, tuðu_
  { {0xfbdf0149,0xceb3000b,0x7cd3000d,0x89da0009}},	//   ocê_, ציע_, _pări, _בחתי
  { {0xd371000a,0xb4bf0037,0x63050003,0x6dc4003c}},	//   يها_, ँगे_, لوصل, ссуж
  { {0x6d5c0872,0xd7fa0009,0x6ffa0009,0x57fa01b0}},	//   äraj, _שהשל, _שהשפ, _בלרו
  { {0xc2c40003,0x45d40229,0x89350012,0x32bb0012}},	//   ميني, _горс, لعبا, ردشة_
  { {0xc692000b,0xe5090037,0xfe9a000b,0x7cd3000d}},	//   _ואם_, _विधि_, _יישמ, _tări
  { {0x7c870001,0x20190051,0xaf0501b6,0x31580009}},	//   _суге, üsi_, апил, ריהן_
  { {0x8e55002d,0x7eaf0033,0x2ba50011,0x443f1ec2}},	//   атні, løpi, _गुला, _iau_
  { {0x386d024c,0x92b70012,0x8d750012,0xa52509c2}},	//   sker_, _إحرا, لاجا, амод
  { {0xb0350015,0x3ea5000e,0xc1040012,0xc2c40012}},	//   _внеш, rolt_, _هولي, _ايلي
  { {0xcb6a0098,0x3ea5000e,0x443f13be,0x60cf0066}},	//   ваме_, solt_, _jau_, _nicm
  { {0x443f1395,0x7aa60003,0xe3b20012,0xce950048}},	//   _mau_, لإسل, ترد_, _кадъ
  { {0x27ed1ec3,0xd3780002,0x6f0d1ec4,0x8f7a0009}},	//   lben_, ąć_, drac, _שנסק
  { {0x7c291ec5,0xa7fb01e3,0x2eff016d,0x045a0012}},	//   _ober, _soña, lsuf_, _للغة_
  { {0xcec80020,0xd5eb001a,0xad1a000b,0x6140000e}},	//   _hộp_, _đín, _סופר, lálá
  { {0x78780149,0x7eb0004a,0x4c3b000b,0x8e8600de}},	// [4d00] _níve, läpi, _יתקב, агае
  { {0x6140000f,0x7e970003,0x8afb000b,0x63a60033}},	//   nálá, لنقر_, _שהיי, _økni
  { {0x27ed000f,0x6be60003,0x2ca6002a,0x443f0bc7}},	//   kben_, لكام, tood_, _bau_
  { {0x499b000b,0x6563004a,0x443f1ec6,0xc7a60024}},	//   _ישיב, änha, _cau_, _вимк
  { {0x43730001,0x443f1ec7,0xa01b0248,0x27ed0031}},	//   жујт, _dau_, _omöj, dben_
  { {0x27ed008b,0x93b7000b,0x443f0061,0xcec8001a}},	//   eben_, בלנו_, _eau_, _nộp_
  { {0x52750046,0xe611000b,0xd1300003,0xa81a0012}},	//   ључу, _מִן_, سمة_, نتظر_
  { {0x91790020,0xd0100003,0xfbc70037,0x20540014}},	//   _hợp_, ألة_, रेडम, ския
  { {0xcee70001,0x98730024,0x98be004b,0x61fc1ec8}},	//   адње_, ільц, _artă_, karl
  { {0xa3bd0037,0x27ed0052,0x6140000e,0xa9f80009}},	//   _अरब_, aben_, gálá, _תִּת
  { {0x27ed060c,0xa9a6002d,0x627b0009,0xc27b0009}},	//   bben_, _тижд, _שנבנ, _שרבי
  { {0x746b005c,0x2b490002,0x64401ec9,0xf5370009}},	//   тров_, _prac_, _jami, בנטי_
  { {0x64400101,0xdd39000d,0x6140000e,0x7b640e5f}},	//   _mami, păşe, bálá, отре
  { {0x28db0037,0x6442004a,0x4efb000b,0x7d030042}},	//   _मंदि, hdoi, _יהדו, ánsk
  { {0xb6bb000b,0x6f0d0002,0x76bb000b,0xa2940024}},	//   _שצוי, wrac, _שמופ, царі
  { {0x44a4000a,0x38a1003e,0x7cd3000d,0x64401eca}},	//   _وموق, wórz_, _căru, _nami
  { {0xe2ab0003,0xdc9c000b,0xe7190012,0xc6a70024}},	// [4d10] _لادن_, _שיחל, طيات_, аржи
  { {0x443f1ecb,0x27ed000f,0x7e54002d,0xe6130003}},	//   _sau_, zben_, овує, تشر_
  { {0xba9a0009,0xcdd8004c,0x443f1ecc,0x44261ecd}},	//   _תסתי, рњу_, _pau_, ffo_
  { {0x6140000f,0xa136000b,0x70550012,0x6440040f}},	//   zálá, _פארק_, _انحا, _cami
  { {0x64401ece,0xa6db0028,0x443f0054,0x0056000b}},	//   _dami, _orði, _vau_, _השרת_
  { {0x1bb80012,0x7dc70012,0x7b380009,0xf2e40024}},	//   جامع_, _نتأك, שָׁע_, іючо
  { {0x27ed000f,0x6140000f,0xfa78000b,0xaa560001}},	//   tben_, válá, שעות_, сију_
  { {0x64400101,0x26d10164,0xd198000b,0x27ed0052}},	//   _gami, _hizo_, יכוי_, uben_
  { {0xbb85000a,0x61fc003a,0x6140000e,0x33750001}},	//   _الذي, yarl, tálá, _угар
  { {0x27ed000f,0x6f020029,0xf1a70001,0x6d41000e}},	//   sben_, _dvoc, _крен, _álas
  { {0x63be0002,0x6140000e,0x7fd50024,0x0446003c}},	//   ępne, rálá, _лілі, бенн
  { {0x672f003e,0x25450039,0xfc320003,0xf8bf001a}},	//   _opcj, _vēl_, أحد_, _nhé_
  { {0xd36f0003,0x9f400028,0xb7d20003,0x2d8b0002}},	//   ّهُ_, _þið_, _عقوب, ńce_
  { {0x7cd3004b,0xa2d80011,0x61ee1ecf,0x7e7a1367}},	//   _săru, मदत्, ubbl, chtp
  { {0x55f6000b,0x6a6b003a,0x95c80001,0x787505b1}},	//   _המצב_, _nüfu, _кућа_, _záva
  { {0x38a10002,0x34930001,0xb8660012,0xdfd20012}},	//   tóry_, _најр, حاسو, سيط_
  { {0x44f50026,0x63a90d04,0x64401ed0,0x61fc1ed1}},	// [4d20] eť_, üent, _rami, parl
  { {0x3e760065,0x77c700c0,0x6b5b000b,0x05ba0012}},	//   _bæta_, слуг_, _עדיפ, هدات_
  { {0xd6cf0003,0x26190037,0xa5c60002,0x64401ed2}},	//   رقم_, _पारी_, _opóź, _pami
  { {0xf8bf001a,0xab62003a,0x8c95002d,0x26d91ed3}},	//   _ghé_, şüml, орчі, _fuso_
  { {0x8c1b0093,0x44f50029,0x28b50037,0x78a91ed4}},	//   רוני, ať_, ंतरि, doev
  { {0x66e30098,0x38600065,0x8b060002,0xdee30ad3}},	//   _хора, ljir_, częś, _хори
  { {0xb5090044,0x88bc0066,0x5ba50011,0x3e760097}},	//   _विषय_, _opět, _ऐड्व, _gæta_
  { {0x04960003,0x7c960003,0x386000b6,0xc953000b}},	//   _الرح, _الرص, njir_, למו_
  { {0x6d46001e,0xe8190011,0x1ddc0011,0xa8570009}},	//   ākam, _धारा_, _बलात, מיקה_
  { {0x62650003,0xa3e40037,0x8c44000d,0xda650003}},	//   _والق, पुर_, ăşur, _والي
  { {0x67240027,0x499a0014,0x4499002d,0x915f001a}},	//   htij, _стая_, ивою_, _mặt_
  { {0xac19002d,0x67240562,0x23e40024,0xd8d70009}},	//   шому_, ktij, зірв, _הואט_
  { {0x7eb0008e,0xdfcf0012,0x938b0488,0x0b8b0681}},	//   läpu, _كيم_, усна_, усни_
  { {0xb69b000d,0x44f50029,0x0737000b,0xaf070012}},	//   _avân, yť_, _לאדם_, _اقوم_
  { {0x54e6000a,0xcce60003,0x91780009,0xbe850012}},	//   _استق, _استي, בְּח, _بجنو
  { {0x9985000f,0x63ad0002,0x76020066,0x67240070}},	//   ülő_, żani, bízí, ftij
  { {0x5b040012,0x67240227,0x3ef80009,0x1eab0012}},	// [4d30] _فِيم, gtij, שִֽׁ, هائي_
  { {0x88bc0066,0x1af80009,0xb5950048,0x32f60034}},	//   _zpět, _המזל_, оизш, dły_
  { {0x6d350012,0xbfd50012,0xf8bf0025,0x63bb0031}},	//   تفاض, _ويدع, _thé_, _szun
  { {0x9d1b0009,0x3866005e,0x95c40012,0x351b0009}},	//   רואט, _noor_, سينه, רואנ
  { {0x44f50026,0x32f60002,0x2418002d,0xbca40003}},	//   sť_, gły_, сією_, أمني
  { {0x6d46001e,0x13180009,0x8de50012,0xe9390012}},	//   ākaj, מחדל_, _ذكره, لسبت_
  { {0x48790014,0x32f60002,0xeab00012,0x787506dd}},	//   исия_, ały_, رعه_, _dávn
  { {0xd7091438,0x2cbf016d,0xa6e51ed5,0x4f091ed6}},	//   ание_, _uhud_, ожил, анин_
  { {0x386606a0,0x63bb003a,0xc0c80001,0x78a90227}},	//   _door_, _uzun, љује_, roev
  { {0x78a40027,0x29030a6e,0xeb980012,0x17580009}},	//   čiva, ksja_, _اضفت_, מסחר_
  { {0xad51002d,0xbc6a0012,0x3f740081,0xb9950012}},	//   здiл, لمدن_, àu_, _بلاب
  { {0xe0ce0024,0x0f550012,0xc3560048,0xac970012}},	//   _ів_, _وَاح, оъгъ, ْنَا_
  { {0x628e0101,0x3b83002d,0x63ba0002,0x28df0011}},	//   tibo, дляг, ętno, _पंडि
  { {0x7d02001e,0x3e7b0025,0x8f9a0009,0xf7480012}},	//   ņosi, _bête_, _דיני, _دلهي_
  { {0x628e1ed7,0x32f60034,0x38600097,0xc0e30adc}},	//   ribo, zły_, tjir_, доск
  { {0x764300c6,0x7ae9004a,0xf7720003,0x32f60002}},	//   _hany, _otet, واء_, yły_
  { {0x44200108,0x76430101,0x9e66002d,0xa6db0028}},	// [4d40] _ici_, _kany, овад, _orðu
  { {0xaec3002d,0x27ff004a,0x3e7b043d,0x3f801ed8}},	//   дбул, haun_, _fête_, rziu_
  { {0x2a57000b,0xc68f0003,0x7eaf0033,0x787500d9}},	//   _ובין_, خِل_, løps, _návo
  { {0x61430013,0xd4990024,0x61fa15ef,0x29181ed9}},	//   sílá, брі_, _setl, mura_
  { {0x8336000a,0x6444002c,0xe29f0028,0x6aaa17f7}},	//   تراض, _maii, arðu_, toff
  { {0x32f60034,0xa6e20097,0x179b0009,0x764303fe}},	//   rły_, áðun, _כיכב, _nany
  { {0x3866002a,0x2714001a,0x32f60002,0xa507026d}},	//   _poor_, òng_, sły_, _мера_
  { {0x58d30014,0x64440532,0xc6f80339,0xb8660012}},	//   мощт, _naii, бних_, تاتو
  { {0x386601e4,0x764300c6,0x787c000e,0xf2200037}},	//   _voor_, _bany, _néve, _बाढ़_
  { {0x35af0044,0x0f57000b,0xf76f0003,0xcdda0001}},	//   _जुड़, קיים_, ضاً_, шњи_
  { {0x2fc7008a,0x76431eda,0xc05a002d,0x3fe60048}},	//   ̀ng_, _dany, _віл_, _джев
  { {0xb4b50037,0x2c6200d9,0x29181bb3,0x7d000031}},	//   झते_, _kódy_, dura_, _zárá
  { {0x8ae4002d,0x787500d9,0xfbca0011,0x926b0048}},	//   дісл, _závo, िधिम, арва_
  { {0x787c0108,0x7643002c,0xcb130009,0x29110034}},	//   _déve, _gany, ולש_, trza_
  { {0x20670001,0x867b0009,0x89780009,0x29050097}},	//   ођав, _דרגו, זָּה, éla_
  { {0xa2bb0044,0x2903003e,0xda170011,0x6f040032}},	//   _शीर्, rsja_, _ताकत_, fsic
  { {0xcddb1154,0x2fcf006f,0xbca40012,0xa3f80009}},	// [4d50] ање_, ägg_, _تميي, _ומחק_
  { {0x3e7b0061,0x2714001a,0x2918002c,0xc334000b}},	//   _tête_, àng_, bura_, _חוץ_
  { {0xc4f80003,0x7ae90778,0xe4a70dc2,0x44390132}},	//   قعنا_, _stet, ордо, oes_
  { {0xe7870177,0xf9920009,0x6f040032,0x78780031}},	//   _дуго, _טרי_, bsic, _hívn
  { {0x09e500e3,0xa85a000b,0x6d4e1edb,0xfbd00012}},	//   полн, _הדרכ, _erba, نته_
  { {0x3897000d,0x42d40024,0x72880024,0x44391edc}},	//   mări_, міщу, обіг_, hes_
  { {0xc27c0093,0x010b0009,0xceb20009,0xd24e0012}},	//   שרוי, ׁלַּ, _ניל_, طني_
  { {0xa99c000b,0xd12e0003,0x44391edd,0x499c0009}},	//   יבור, امي_, jes_, ישוב
  { {0x3897000d,0xaa0b0012,0x57b90011,0x64960064}},	//   nări_, _نزال_, _आरोह, nšie
  { {0x7875000e,0x1b780003,0x787c0061,0x673b0a83}},	//   _távo, _بصفة_, _réve, rwuj
  { {0x3eb90039,0x649f0066,0x3a3a0051,0xc6920009}},	//   ēst_, zšiř, õppe_, תאי_
  { {0x644b0065,0x32cf0002,0x19ba000b,0x6f040503}},	//   _ógil, _użyj_, _המעב, ysic
  { {0xf092015a,0xb7da000b,0x76430f50,0xeb97022a}},	//   _אנא_, _הקני, _tany, зия_
  { {0x11da000a,0x60c9003a,0xb6cc003a,0x3897004b}},	//   صورة_, lmem, şürü, dări_
  { {0x6d5c0005,0x15fa0093,0x0dcb0024,0x45fa0009}},	//   ärat, _ההצע, _туди_, _ההצג
  { {0x53a6007c,0x83fd000f,0x2714001a,0x47d60003}},	//   _найб, _előz, ùng_, سيطر
  { {0x8c1b000b,0x6016003a,0x3897000d,0x441b000b}},	// [4d60] _הופי, lümü, gări_, _הופס
  { {0x59cb0037,0xa6db0028,0x6f041ede,0x29181edf}},	//   ाधार, _arðs, rsic, pura_
  { {0x89db000b,0x78b60029,0x6016003a,0x44e1000e}},	//   _לחיי, plyv, nümü, _jó_
  { {0x3897007d,0xcea90009,0x60c90737,0x7eb0005e}},	//   bări_, אי_, jmem, täps
  { {0x3897007d,0x22450227,0x6d460035,0x44200035}},	//   cări_, _balk_, ākai, ļi_
  { {0x63b61ee0,0x912a0003,0x6b820052,0x06390012}},	//   _myyn, مسبق_, rzog, _وسّع_
  { {0x44e10020,0xa9670001,0x7871006f,0x21670001}},	//   _nó_, зија_, _såvi, зији_
  { {0x859b000b,0x8c43022a,0x78710623,0x88560009}},	//   _השלו, _песе, _påvi, לֹ֥א_
  { {0x76aa0047,0x6beb000b,0x9b930012,0x2bcb0011}},	//   йтов_, _הַבַ, _كلفت, ़ेदा
  { {0x4b7b000b,0xe72f0003,0x660110fc,0x61fe1ee1}},	//   _האמו, اصي_, galk, _nepl
  { {0x44e1008a,0x70f6000a,0x3897000d,0x290c08ca}},	//   _có_, _رسائ, zări_, ádal_
  { {0x1bf50044,0x515b000b,0x66010051,0x0d97000b}},	//   आरएल_, _לכבו, aalk, לכים_
  { {0x7680003a,0x7d02000e,0x60630012,0x23c70011}},	//   _köyd, _bírá, _سهول, रेंद
  { {0x6d5c0051,0x17570009,0x60160060,0x7c390034}},	//   äras, _מסדר_, bümü, zewr
  { {0xa5d70012,0x2dd70012,0xf1a402ab,0xda700012}},	//   _عبور_, _عبوة_, ертн, دُّ_
  { {0x3897007d,0x76800006,0xf3f9000d,0x58d40001}},	//   tări_, _löyd, _toţi_, еост
  { {0x2726001a,0x7af00042,0xe81d0011,0x7d1a1ee2}},	// [4d70] gôn_, čitý, फलता_, luts
  { {0xfbd0000a,0xf770000a,0xdcfc00a2,0x1bf50044}},	//   _حتى_, داف_, _ayrı, आरऍल_
  { {0x3897004b,0xfd390012,0x7d1a1ee3,0x65940a36}},	//   sări_, تكاب_, nuts, нафу
  { {0xb9010044,0x254c0013,0x9b950012,0x7c2b0032}},	//   दद_, _měl_, ولات, ufgr
  { {0xdb1b001a,0xceb80010,0x22450051,0xe28e05c6}},	//   _nguô, klę_, _palk_, ва_
  { {0x60160060,0x7d1a1ee4,0x64960919,0x6748068e}},	//   yümü, kuts, ošic, űrjü
  { {0xa1560001,0x6d3405fb,0x66011ee5,0x69440012}},	//   дају_, _перф, valk, فضيل
  { {0x443903eb,0x31580093,0xb97c000b,0x46e90229}},	//   _ús_, ליון_, מנוי, один_
  { {0x44e10149,0x27fd0002,0x7d1a1ee6,0x60c91ee7}},	//   _só_, ówny_, euts, rmem
  { {0x3e89007c,0xfe710003,0x22950003,0x3e7b1ee8}},	//   ійно_, ئدة_, _غلاس, _bêta_
  { {0xa2aa0044,0x7d1a0005,0x8ca40037,0x98bf0037}},	//   टवर्, guts, _कदमो, ्षाए
  { {0xc2090093,0x63b60006,0xa0c40003,0x69c11ee9}},	//   _כה_, _pyyn, _كيلو, _izle
  { {0x66010006,0xe5090037,0xae1e01e1,0xb05b0052}},	//   palk, _विकि_, _पालन_, _phän
  { {0xaec4002d,0x201f0054,0x5ea50012,0x36c40024}},	//   _збіл, lgui_, _تمتل, _збіг
  { {0x2d940014,0xafe607a7,0x82880009,0xddd30034}},	//   _пръс, добл, פְשֶ, łałe
  { {0x201f092f,0xb4fa0009,0x63b6008e,0x34fa0009}},	//   ngui_, _ולקר, _tyyn, _והקד
  { {0xdfcf000a,0xc1780010,0x649601bd,0x61fe0042}},	// [4d80] ليف_, šė_, ašic, _tepl
  { {0x78a9012e,0x80be0011,0xef170198,0xb8810030}},	//   čeva, _वीरे, ьму_, _šíle
  { {0xa06a0046,0x2905000f,0xc1060003,0xf2d3000b}},	//   _дана_, álat_, _توجي, _שעת_
  { {0x6e3a000e,0xe3ba096e,0x60dc01e3,0x3f840034}},	//   zetb, обе_, _érmi, yzmu_
  { {0x7c650003,0x63be0002,0x883b0009,0x6b560012}},	//   عامل, ępno, _ותכו, بضائ
  { {0x752f0002,0x9f400004,0x463a0012,0x8f8b0009}},	//   łczy, ncií_, _بأحد_, _וְלֵ
  { {0x28c30037,0x12a90003,0x29070248,0x69090009}},	//   _वीडि, أدنى_, gsna_, ִּקְ
  { {0x66c90010,0xc6f80339,0xac7a0012,0xa3ae0011}},	//   _užkr, пних_, _بمرض_, कथा_
  { {0x9f40119d,0x17f70012,0x4226004c,0xba26004c}},	//   kcií_, ذرية_, _одав, _одак
  { {0x7d1a0051,0xb95a0003,0x4424001a,0x44321eea}},	//   tuts, _وجاء_, _hcm_, _aby_
  { {0xb80e0044,0xc58a0015,0x98be0030,0xdddc0035}},	//   िणाम_, ющие_, ítě_, _torņ
  { {0x6f160002,0x7d1a079d,0x291c005e,0x9b4b0034}},	//   kryc, ruts, muva_, ółgł
  { {0x6d43003a,0xc0a90012,0x6f1608ca,0xdf760012}},	//   _esna, _عامل_, jryc, _تداب
  { {0xf7d7000b,0x20041eeb,0x7d1a1eec,0x6f161eed}},	//   _חודש_, lami_, puts, dryc
  { {0x5d830003,0xdcf70012,0x306b004c,0x99830073}},	//   _للول, _قريش_, ојан_, vejų_
  { {0xd5f40020,0x030e0044,0x54a70003,0x7878000e}},	//   _đán, _सिंह_, _تحتف, _hívj
  { {0x93fc0009,0x2bd00011,0x4bfc0009,0xc3fc0009}},	// [4d90] _ולחי, तेमा, _ולחס, _ולחש
  { {0x752f003e,0x645a001e,0xfe780010,0x200400b6}},	//   ńcze, ētie, nkį_, hami_
  { {0xdd910003,0x7eb0006f,0xe4e4002d,0x6ce40024}},	//   دوا_, räpp, вічн, віче
  { {0x711a0009,0x6f160034,0x62951eee,0x7c3d1eef}},	//   _צורפ, bryc, lizo, nesr
  { {0x20041ef0,0xf8b20009,0x92950109,0xceb90030}},	//   dami_, _תשכ_, надц, stři_
  { {0x539c000b,0x65950662,0x4efa0009,0xbb780009}},	//   חידו, _загу, _מהשו, ועדו_
  { {0x63ba0002,0xf204002d,0x69fc000b,0x660500b6}},	//   ętni, тячо, חלוק, mahk
  { {0x40940047,0x60cd00a2,0x660500b6,0x6729019a}},	//   крыт, nmam, lahk, ttej
  { {0xb9060037,0xd426003a,0x82f80012,0x29071ef1}},	//   _यू_, ıştı_, _يركز_, ssna_
  { {0x443200b6,0x7a540003,0x443d01f6,0x8d65003c}},	//   _sby_, _لضما, lew_, евое
  { {0x5067004d,0x21580012,0xceb20009,0xc8670048}},	//   _отда, _يجمع_, ריי_, _отди
  { {0x4424003a,0x58f60009,0x20041ef2,0x60cd0064}},	//   üm_, _נמנע_, cami_, jmam
  { {0x78bb0042,0x8c1a0009,0x97250012,0xa3e40011}},	//   mluv, הורי, _أفتو, पुट_
  { {0xddc3007d,0x4375002d,0x62951ef3,0x443d18bb}},	//   _conţ, туют, gizo, hew_
  { {0x19b9007c,0xa5640003,0x660500b6,0x6d431ef4}},	//   дуть_, _لدين, dahk, _usna
  { {0x60cd002c,0xdb0f000e,0x46ea00bb,0x6f1619b1}},	//   gmam, őjár, здан_, tryc
  { {0x91e600c0,0xaec60001,0x29050028,0xfd65001a}},	// [4da0] _попе, ебал, álar_, _nhuậ
  { {0x98c0003a,0x7a33003a,0x1ea90012,0xc3330009}},	//   ırır_, nıtı, والي_, _עות_
  { {0xf9fb0009,0xe2a90012,0xbd8a0012,0x26d8008e}},	//   _מהימ, _تاين_, أخذك_, _viro_
  { {0x388c0030,0x27e91dfa,0xc486003c,0x99980030}},	//   běry_, ccan_, элек, lerů_
  { {0x8b660003,0xfe780010,0x28bf0037,0x25860030}},	//   عاصم, ykį_, ्षरि, _bílé_
  { {0x20040002,0x68e1003a,0x660500b6,0x599a0009}},	//   wami_, _buld, cahk, ּשֵׁ
  { {0xa3d00037,0x78750042,0x25be0031,0x2002016d}},	//   वेत_, _závi, _átl_, _keki_
  { {0xf993000b,0xbf340014,0x291c0c8e,0xb5090011}},	//   טרו_, внищ, ruva_, _विजय_
  { {0x9f401ef5,0x20041ef6,0x03a307e8,0x8fa3004c}},	//   ncià_, rami_, _бито, лаће
  { {0x68e100c5,0x27e90164,0x20020034,0x7a330060}},	//   _fuld, zcan_, _leki_, gıtı
  { {0x867b000b,0x20041ef7,0x99330012,0xfe780073}},	//   פרטו, pami_, _مفلت, rkį_
  { {0xdee60083,0x20021ef8,0x62950034,0x78780030}},	//   _зоди, _neki_, wizo, _dívk
  { {0x9f49014d,0xcfaa0012,0x5c7404a5,0x62951ef9}},	//   _það_, _عاصم_, улят, tizo
  { {0x752b000e,0x7878000e,0xa6c80012,0x443d0034}},	//   élzá, _hívh, _غوغل_, zew_
  { {0x3e760065,0x60cd003a,0x38c70083,0xa15802e3}},	//   _gæti_, tmam, ещав, нару_
  { {0x5dbb000b,0x25bb0009,0x60cd020d,0xdc310034}},	//   _מזוה, _מצומ, umam, ożąd
  { {0x2002003a,0x2bc70011,0xa3d00011,0x2bd00011}},	// [4db0] _deki_, रेखा, वेद_, सेदा
  { {0xdb9c000b,0xa01b0032,0xd3380009,0x649606dd}},	//   _מסחר, _blöc, _טרחה_, nšin
  { {0x9873007d,0x660500b6,0xddc30029,0x60cd003a}},	//   nţă_, rahk, _konš, pmam
  { {0x660500b6,0x6ac90011,0x84640048,0x68e10097}},	//   sahk, िग्र, лъче, íldu
  { {0xbb450014,0x387e0061,0x443d1efa,0xfa6b0009}},	//   телк, être_, rew_, ּכֶּ
  { {0xff160093,0x672d001e,0xc334000b,0x12fc0009}},	//   _בקשת_, mtaj, רוס_, להדב
  { {0xaa56004c,0x62830030,0xb08b0009,0x99800060}},	//   тију_, rhno, ּנִ֖, ğiş_
  { {0xfd650020,0xccf2000b,0x787c0061,0x64960010}},	//   _thuậ, _ככל_, _dévo, ešin
  { {0x6615000e,0x2bd00011,0x672d1efb,0xf7710012}},	//   ózko, तेदा, ntaj, شاة_
  { {0x78bb18c7,0x02dd0011,0x6d550034,0x63bb020d}},	//   sluv, मदीन, _krza, _iyun
  { {0xf652000b,0x672d015e,0x32071efc,0x6da51efd}},	//   בצי_, htaj, many_, тина
  { {0x32070002,0x672d001e,0x1ae601ec,0x6abc0011}},	//   lany_, ktaj, комм, ोग्र
  { {0x93430015,0x9873000d,0xe3b20012,0xe0d00012}},	//   аняе, aţă_, شرح_, _ازل_
  { {0x32070002,0xf7700012,0xfc470031,0x67d4003c}},	//   nany_, _دام_, áírt_, _сочу
  { {0x9987007a,0x2b91001a,0x91030001,0xa0b60001}},	//   menų_, ạch_, ипре, вљај
  { {0x66030006,0x63bb003a,0xbb860003,0x63b60002}},	//   _henk, _oyun, _للبي, żyni
  { {0x6d470005,0xb6070020,0x52aa0046,0xb8e90037}},	// [4dc0] _asja, _thờ, _овим_, _ली_
  { {0x7d1a0248,0x7be30035,0x32070929,0xe8e00081}},	//   _åtsk, āvuš, jany_, _chợt_
  { {0x32070002,0x6603055c,0x627b0009,0xc7a90009}},	//   dany_, _menk, _חנינ, קב_
  { {0x7413000a,0x7ae40006,0x0fda0003,0x787c0061}},	//   لوما, _kuit, _يبحث_, _révo
  { {0x4fa3007c,0x7c221efe,0x6d551eff,0x23bd0031}},	//   _вияв, rgor, _erza, májú_
  { {0xc7b30093,0x7ae41f00,0xcb670001,0x32071f01}},	//   _כבר_, _muit, таље_, gany_
  { {0xce37000b,0xb7e60011,0xba9b0009,0x30a61f02}},	//   _שאלת_, _कलाम_, וססי, крив
  { {0x628102d1,0xd0100003,0x44220033,0x787c0030}},	//   _ello, حلة_, _øk_, _vévo
  { {0xf0930093,0x1ae6007c,0xa2e6007c,0x3ce60037}},	//   ינה_, _розм, _розд, _जूते_
  { {0x78ad0027,0xb061004a,0x78780017,0xf3c90012}},	//   čava, _ääne, _dívi, _سبقه_
  { {0xc693000b,0x38690028,0x7e7a0ad2,0x361b0009}},	//   שאת_, yjar_, rktp, וויד
  { {0x9873000d,0xb8e80037,0x4f660003,0x7ae40cec}},	//   rţă_, ोग_, _لاتف, _buit
  { {0x6298008e,0x93fb0009,0x64960073,0x0f130024}},	//   oivo, ולכי, pšin, _вмію
  { {0x7ae40070,0x66030058,0xfbd30009,0x62981f03}},	//   _duit, _genk, יתר_, nivo
  { {0xfce30046,0x38690054,0xd7e7002d,0x99d40003}},	//   _којо, tjar_, візо, لتفا
  { {0x672d0006,0x2db7000b,0x32070002,0x7ae40025}},	//   ttaj, _שלהן_, zany_, _fuit
  { {0x38690395,0x80da0037,0x44291f04,0x3d050011}},	// [4dd0] rjar_, _पूछे, _ica_, हीने_
  { {0x6298013a,0x24991f05,0x672d1f06,0xc3b80009}},	//   jivo, lism_, rtaj, _בלחץ_
  { {0x98c20011,0x84670048,0x66080064,0xdc430030}},	//   शताए, къде, iadk, _léčb
  { {0x3207003e,0xa156000b,0x859b0009,0x93e90012}},	//   wany_, _עברה_, ושבו, رفتك_
  { {0x501a000b,0x09cb0037,0x644d00b9,0xd3d80012}},	//   _אורו, ाध्य, _maai, نبها_
  { {0x6e950e0f,0x24991be7,0x4fd60009,0xb2240024}},	//   _сигу, hism_, _תושב_, иміл
  { {0xceb2000b,0x9998000d,0x44291f07,0x3a380009}},	//   _הים_, merţ_, _oca_, דרום_
  { {0xa2bb0037,0x32070002,0x63050012,0x64c50012}},	//   _शीघ्, sany_, _مورل, _إيرل
  { {0x66030010,0x7c2900c1,0x60dd1f08,0xa7120012}},	//   _penk, _icer, _mism, مِيع
  { {0x225b0003,0xf7720009,0x7ae41f09,0x66080034}},	//   _تجرب_, צקי_, _ruit, gadk
  { {0x3e760028,0x7ae41f0a,0x20c10031,0x518400b5}},	//   _gætu_, _suit, lóim_, _куца
  { {0x3e760028,0x44e80061,0x394e000e,0x60dd013a}},	//   _hætt_, _dû_, ülső_, _nism
  { {0xbf670003,0xddce0010,0xe73900de,0xff280012}},	//   _جداو, _pobū, _чел_, _لكني_
  { {0x1e84002d,0x479a0009,0x7ae401a0,0x787c0031}},	//   _клім, _אינס, _vuit, _névj
  { {0x63be003e,0x6e34000e,0x60dd1f0b,0x76411f0c}},	//   ępni, égbő, _bism, mely
  { {0x249912c5,0x629800eb,0xf9920009,0x27ed1f0d}},	//   cism_, zivo, צרן_, ncen_
  { {0x9b46000a,0xa3d00037,0x47c60451,0x64960073}},	// [4de0] _صندو, वेश_, убав, nšim
  { {0x7c290844,0x4a460015,0x064a0012,0x60dd1f0e}},	//   _acer, _снов, علاً_, _eism
  { {0xd6cf0003,0x29560014,0x24860054,0x96b90560}},	//   أقل_, _съпр, thom_, туту_
  { {0xac25002d,0xadb70003,0xa3e80037,0x7641000e}},	//   ифік, دهما_, मुच_, hely
  { {0x3e760065,0x76410010,0x7f760001,0xe29a0129}},	//   _bætt_, kely, _сунц, над_
  { {0xf773000b,0x6f1b0432,0x7b060035,0x7c29016d}},	//   _הקש_, druc, _ērtī, _ecer
  { {0x78a4005e,0x6608005e,0x64960073,0xdca60430}},	//   oniv, vadk, ešim, _бави
  { {0xe45f0028,0xfe210011,0x31570009,0x0edf0011}},	//   mlög_, _माउस_, ריקן_, नदंड
  { {0xb60601b6,0x7e2a0024,0x18330012,0xc8c70012}},	//   лянк, ніна_, صريح, دوين_
  { {0x2f370003,0x961e0011,0x76410073,0x99980073}},	//   اثية_, पलेट_, gely, ndrų_
  { {0x644d0010,0xfe9b000b,0x2d810051,0xa1130012}},	//   _paai, תיימ, _ühel_, _هولت
  { {0x69c81f0f,0x66cb000e,0x04671f10,0xd327003c}},	//   _izde, müke, утом, льги
  { {0x6608003e,0xe6c40028,0x46f6035b,0xa3d00037}},	//   padk, þjóð, _счет, वेल_
  { {0x68e5008e,0x753c0034,0x764e1f11,0xd1260012}},	//   _puhd, _oprz, _naby, يم_
  { {0x067b000b,0x867b000b,0x6d5a0029,0xb6bb000b}},	//   _אנגל, _ארגו, _štan, _רצוי
  { {0xd5cb000b,0x5c070014,0x57f501b6,0x6f0d03de}},	//   _אֶחָ, _сяка, рпат, tsac
  { {0x60dd0039,0x6d580416,0x2f18003c,0x53f80012}},	// [4df0] _vism, _hrva, лоть_, _صريح_
  { {0x442605bd,0xe4e7002d,0x51870015,0x60dd1f12}},	//   ego_, гідн, _бума, _wism
  { {0x9848003a,0x32050132,0x290c1f13,0x657a0132}},	//   aşı_, _rely_, ádat_, nyth
  { {0x24190015,0x6f020002,0x64420025,0x6f0b0031}},	//   тоды_, _owoc, geoi, ágcs
  { {0x7680003a,0x44290035,0x6cac00af,0xeab100ae}},	//   _köyl, ļa_, עֹבְ, يعت_
  { {0x44290002,0x787500f1,0xfaa70015,0x272f003a}},	//   ża_, _návr, ышен, mün_
  { {0xfa78000b,0x272f0060,0x66cb0031,0xe9690148}},	//   רעות_, lün_, güke, тайл_
  { {0x7af5002d,0x69c80002,0x764e0002,0x69d50042}},	//   _взає, żdeg, _zaby, _územ
  { {0x6d580005,0x272f00a2,0x62850017,0x1e850001}},	//   _arva, nün_, _olho, илим
  { {0xbb840003,0xf1fb0037,0xd6ce0012,0x2ca9005e}},	//   _الكي, ्रफ़_, وقي_, _ajad_
  { {0x18370012,0xddc50024,0x26c10018,0x661c0591}},	//   _مرشح, рбни, ilho_, órka
  { {0x76410006,0x752f0002,0x6f1b0052,0x62851f14}},	//   sely, ńczo, pruc, _alho
  { {0x386d001c,0x7680003a,0x6d580070,0x69c1003a}},	//   mjer_, _böyl, _erva, ülen
  { {0x36690001,0x386d1f15,0x8f1a0009,0x66070030}},	//   _јако_, ljer_, _יונת, _nejk
  { {0xc8960001,0x26c10029,0x62850064,0x3aeb00b0}},	//   арањ, dlho_, _dlho, _løp_
  { {0x7d560093,0xe0df00c1,0x64a30014,0xfc3f0029}},	//   _כיצד_, _ciò_, _маща, rníc_
  { {0x753c003e,0x272f003a,0x6cd30003,0xade90011}},	// [4e00] _sprz, gün_, _بقيا, _ऐलान_
  { {0x9848003a,0x22930003,0xb5da0012,0x66cb0060}},	//   rşı_, _وليس, نباء_, yüke
  { {0x387f0065,0x9202001e,0x621b0009,0x859c0009}},	//   kkur_, šāka, _בויק, ֲשׂו
  { {0x44260010,0x718b0009,0x334a0012,0x66cb0031}},	//   ugo_, _יְכַ, َلاَ_, vüke
  { {0xcb540003,0xab270001,0x44261f16,0x2327004c}},	//   إنتظ, иоца_, rgo_, иоци_
  { {0x44260164,0xc2b60001,0xd357000b,0x291c0027}},	//   sgo_, шљењ, ייני_, trva_
  { {0x753c0002,0x64961187,0x55780009,0xadba0012}},	//   _uprz, ršij, _גְּד, _شهرا_
  { {0xbf660003,0xe0cf0003,0x69c8025e,0x9f4f01e3}},	//   لدخو, وزي_, _vzde, _negó_
  { {0xe6660731,0xc7c6003c,0x66cb0031,0xdceb0073}},	//   атно, шски, süke, čiąj
  { {0xd737000b,0x0f370009,0x78a90412,0x2ca60031}},	//   סטית_, סריט_, čevi, lnod_
  { {0x69c8001e,0xd7ef0ed0,0xd6570009,0x272f0060}},	//   _uzde, _му_, ביית_, zün_
  { {0x768000a2,0xc19b000b,0x657a002a,0x272f003a}},	//   _söyl, _בשבי, ryth, yün_
  { {0x92b70003,0x9fe50012,0x9cd70009,0xa3b40011}},	//   لحسا, _اسمه, יוטה_, _जुआ_
  { {0x6d580107,0xa01b000e,0xf1a70024,0x629c1f17}},	//   _trva, _elöl, арбн, giro
  { {0xa3b80011,0xcdf70009,0xf8070229,0xd8bb0012}},	//   _घुस_, _דמוי_, ичан, ندرا_
  { {0x272f00a2,0x2730001a,0x61fa003a,0x4ddb0009}},	//   tün_, oàn_, ıtla, _בחוו
  { {0x0eeb002d,0x96eb002d,0xe45f0031,0xa6f80009}},	// [4e10] тьби_, тьба_, rlöd_, רִֽי
  { {0x272f003a,0xc7d7000b,0xbebd0213,0x9f040012}},	//   rün_, שומי_, ltūr, توكو
  { {0xab62003a,0xceb3000b,0x272f0060,0x6d5a0031}},	//   _şüph, קיע_, sün_, _átal
  { {0xe4a4002d,0x8d28002d,0xbebd0213,0x661d0073}},	//   орчо, роїв_, ntūr, ėski
  { {0xb4c70037,0x8b640012,0x64860018,0x6d4a0097}},	//   _उठी_, قاوم, _jóia, æfar
  { {0x8e850003,0xc51b0012,0x1df8003c,0x06850012}},	//   _السه, _لغرض_, _веры_, _السُ
  { {0x3cf00029,0xbebd134f,0x42380009,0x82340012}},	//   ľové_, ktūr, ינגל_, ترنا
  { {0x7b00000f,0x3f8d03eb,0xbca50003,0xfbdf0017}},	//   öztá, tzeu_, _امري, ndês_
  { {0x387f0028,0x7e75000e,0x501c000b,0x442d108e}},	//   rkur_, özpo, דוחו, _ice_
  { {0xba74000a,0xe1f00003,0x628a0052,0x2714001a}},	//   _والت, _قسم_, chfo, ình_
  { {0x7af60028,0xc212000b,0xbc83001a,0x29110002}},	//   _styt, _זהב_, ượn, jsza_
  { {0x853a000b,0xcb6a0014,0xe3a70012,0x98770060}},	//   נגרי, гаме_, كر_, kçı_
  { {0x929d0002,0xc8b40003,0x6b560009,0x27ff016d}},	//   _zwła, _بإلغ, ֖ישׁ_, mbun_
  { {0x26d90066,0x6d5a0027,0x787c0061,0x412a0055}},	//   ůsob_, _štam, _révi, лого_
  { {0x7ae90006,0xd179002d,0x3979002d,0xbcf50003}},	//   _luet, асті_, астю_, _استغ
  { {0x629c007a,0xad1a0009,0x63ad0034,0x0dc803d2}},	//   siro, _עופר, żany, _тучи_
  { {0x64460005,0xee3a0146,0xa01b006f,0xd00f0012}},	// [4e20] meki, лна_, _glöm, علك_
  { {0xb2260047,0xdfcf0003,0xcf250003,0x644619a3}},	//   _умол, ريل_, ترفي, leki
  { {0xa3da0037,0x64a6002d,0x42db0009,0x27140081}},	//   डेन_, бажа, _תקיע, ành_
  { {0x75d30003,0xa507029b,0x1d0705fb,0x7fd60024}},	//   سينا, сеца_, сеци_, _гігі
  { {0x2057000b,0x4373004c,0x68e81f18,0x2ca60031}},	//   _היכל_, зујт, _sudd, rnod_
  { {0xdd200013,0xbae5002d,0x60c41f19,0x2aad0064}},	//   může, іцій, llim, oľba_
  { {0x5d860003,0x60c40027,0x6446004a,0xd1300012}},	//   _الأل, olim, keki, ذمة_
  { {0x91bb0011,0xb6f4004c,0x7ae10032,0x2ef41f1a}},	//   _एडसै, озиј, _eilt, озир
  { {0x69c1003a,0x3f820066,0xc6f70015,0x3b860001}},	//   _eyle, áku_, бных_, _улаг
  { {0x7ae10163,0x86980001,0x787c000e,0x7c2d1f1b}},	//   _gilt, ркос_, _névv, _scar
  { {0x245f0006,0xe6d90097,0x3f821f1c,0xb6bb0009}},	//   _nämä_, ðráð, šku_, רציי
  { {0x69c1003a,0x64460051,0xf9930009,0xab5d0034}},	//   ülem, geki, _צרף_, _wyże
  { {0xdc9b000b,0xd00b0009,0x00570009,0x29110034}},	//   ריכל, _גּוֹ, _לשאת_, wsza_
  { {0x99640013,0x60c400a2,0x442d0002,0xbebd001e}},	//   _může_, elim, że_, stūr
  { {0xce37000b,0xc2c40003,0xc27b0009,0x04950012}},	//   _האות_, سيفي, נרלי, _ولتح
  { {0x64a40001,0x29110002,0xd8770012,0xb4c70011}},	//   _наја, rsza_, حاسب, _उठे_
  { {0x2911000f,0xe7300003,0xe6990014,0xe7190012}},	// [4e30] ssza_, فصل_, аваш_, شيات_
  { {0xeef7000b,0xf7700003,0x29110002,0x44391f1d}},	//   צמבר_, راق_, psza_, lfs_
  { {0x7afd0035,0x9f590097,0x69dc0034,0x27e60034}},	//   lpst, _jesú_, _źren, _ogon_
  { {0x106b0003,0x799a0009,0xa3d00011,0x7ae10282}},	//   _إحدى_, _כשתס, वेक_, _silt
  { {0xa3d30044,0x7ae10005,0xe3b30003,0xcb6911ed}},	//   हें_, _pilt, أرض_, рале_
  { {0xd9fb0037,0x82370003,0x64460002,0x4aa80024}},	//   ्रित_, إرشا, zeki, бкін_
  { {0xd12e0003,0x7ae11f1e,0xb145002d,0x68e20cb2}},	//   نمو_, _vilt, інил, _biod
  { {0x7ae9004a,0x69c1014a,0x58d20001,0x2eb30037}},	//   _tuet, _vyle, мојт, ुत्त
  { {0xa4d4002d,0x7b670021,0x70760012,0x02450012}},	//   _хоті, _утве, تميز_, _وَرَ
  { {0x24890a26,0x273b000d,0x5eec0009,0xcee80012}},	//   _alam_, mână_, נַחְ, حرين_
  { {0xd019000a,0x8c4604ad,0x04460063,0x64461f1f}},	//   _نقاش_, оене, оенн, teki
  { {0x2d8b003e,0xf992000b,0x8c96002d,0x7d1c000e}},	//   ące_, _קרא_, ірні, ársa
  { {0xe60e1154,0x25c60044,0x2d83012e,0x64461112}},	//   _од_, _वर्ण, šje_, reki
  { {0x78bb0013,0x09fa0003,0x78a90051,0x2b40003a}},	//   louv, شفرة_, lnev, çici_
  { {0x2cbf0066,0x60c400c7,0x55f60009,0xc4c60012}},	//   _okud_, tlim, _ומצב_, _وتعو
  { {0x53a6002d,0x200b0061,0x78bb0061,0xe4d60012}},	//   _майб, _ceci_, nouv, _بتتب
  { {0x200b000d,0xe1ff001a,0xf1b60011,0x34b30012}},	// [4e40] _deci_, _đón_, _आँकन, _تميز
  { {0x245f0006,0xd6260003,0x5d5a0001,0x66cf00b0}},	//   _tämä_, تعري, ијер_, bøke
  { {0x60c4007d,0x45460012,0x224701cb,0xa96a06bd}},	//   plim, تناق, denk_, _тина_
  { {0x0b1a0012,0x67df0073,0x62831f20,0x6abc1f21}},	//   لقصة_, _sąjū, ekno, lorf
  { {0x69c50154,0x78a900eb,0xc43b0009,0x7fd60024}},	//   ühen, dnev, שתני, _фіні
  { {0x27341f22,0xdce90066,0xed5a0001,0xda0a0011}},	//   män_, íněn, _ког_, वरित_
  { {0xe57a0001,0x2734008e,0xed580064,0x67361f23}},	//   _тзв_, län_, _éľ_, ltyj
  { {0xd8b7000a,0xacfb000b,0x787c000e,0xb97b0009}},	//   يديا_, _כהלכ, _névt, ינצי
  { {0xa01b0065,0x228b0119,0x03a3002d,0xeeaa00b3}},	//   _slök, _søke_, _жито, иток_
  { {0x69c10051,0xd6d00003,0x67360010,0x8c49003a}},	//   ülek, عقد_, ityj, arşı
  { {0x994a000a,0x27340006,0xc5f3000b,0x286a0001}},	//   _خلال_, hän_, ודת_, _врло_
  { {0x66e60a24,0x78bb0061,0xe3b8003a,0x351b0009}},	//   _дода, couv, ğın_, סוכנ
  { {0x27340006,0xe3b800a2,0xf413000b,0xc87f0052}},	//   jän_, şın_, ופר_, öße_
  { {0x27340006,0x628e002a,0xfc3f0066,0x9f5900c1}},	//   dän_, ghbo, mním_, _gesù_
  { {0xfc3f0066,0xf6b70009,0x50f80009,0x31c409c2}},	//   lním_, _והגש_, מִּד, дств
  { {0x5b15035c,0x38d40009,0x76481f24,0xda7806dd}},	//   _емит, לֵּל_, ledy, _loď_
  { {0x66cf0119,0xfc3f0066,0x9f34002d,0x41e70024}},	// [4e50] søke, nním_, меті, _міна
  { {0x07080003,0x16380012,0x20c10031,0x76480034}},	//   تيكي_, قسمة_, lóit_, nedy
  { {0x2ee30070,0x9cf50024,0x92b40012,0x64a4001b}},	//   _vijf_, їзді, _تحيا, rđiv
  { {0x7aed016d,0xc3550048,0x7648020d,0xf4840048}},	//   _kuat, зъкъ, hedy, мучн
  { {0xfb68000a,0xeaae00b3,0x395e1f25,0xd5d10011}},	//   قصوى_, ей_, _arts_, _हरभज
  { {0xb7da000b,0xfc3f0066,0x76480002,0xe1f10012}},	//   _לקרי, dním_, jedy, رست_
  { {0x7aed000d,0x91e21f26,0xec6b06bd,0x787c0031}},	//   _luat, ноше, _крак_, _névs
  { {0x7ae50005,0x62831f27,0x08c5004c,0x61fe0060}},	//   _liht, skno, џбин, ıpla
  { {0x443f00c6,0x78bb0061,0x69c5004a,0x60060015}},	//   _ibu_, rouv, _lyhe, чным_
  { {0x765500f1,0x78bb1f28,0x78a91f29,0x26c500b8}},	//   _jazy, souv, snev, ullo_
  { {0xc8ab0014,0xc3290009,0xc6920009,0x27340032}},	//   _къде_, _תו_, גאי_, zän_
  { {0xfc3f0066,0x7aed00b6,0xc864010c,0x6abc0052}},	//   bním_, _buat, _отчи, worf
  { {0x69c700c5,0x7aed0164,0xd8b80003,0x4b550048}},	//   _øjeb, _cuat, _بدلا_, мърт
  { {0x27340006,0x76550002,0xddc8001e,0x5efa0009}},	//   vän_, _nazy, ņoša, _הפסד
  { {0x186a029b,0x45d20001,0xd1320003,0x443f0002}},	//   бави_, _пољс, عمر_, _obu_
  { {0x67360006,0xe45f004a,0x38660164,0xd5b8001e}},	//   ttyj, llön_, ñor_, rgāt_
  { {0xd0070015,0x7ee60012,0x2c020011,0xf74304ba}},	// [4e60] яете_, سكان, _व्यू_, нето
  { {0xdce20010,0xdb9b000b,0xc50a0012,0xef170024}},	//   tylė, _לספר, متصل_, яму_
  { {0xf27b000b,0x4a7b000b,0x3f860004,0xc27b0009}},	//   _הריש, _הריב, šou_, _הריי
  { {0xd499002d,0x66cb0060,0xef190034,0xf7670012}},	//   орі_, lükl, zyża_, _كا_
  { {0x69c0003a,0x7f190024,0x833a003c,0x6f630024}},	//   şmed, _міру_, счет_, _звяз
  { {0xfc3f0013,0x753d0002,0x6d431f2a,0xd30c0011}},	//   vním_, łszy, _opna, _हबीब_
  { {0x6a130012,0x67240227,0x320c0064,0xadc30081}},	//   ربور, lrij, _vedy_, _trạc
  { {0xd601001a,0xfc3f0066,0x251b0009,0x20120060}},	//   _đún, tním_, _לולא, nayi_
  { {0x7e78012e,0x67240070,0x49080037,0x320c0975}},	//   _povp, nrij, _सबको_, _tedy_
  { {0x9f97015a,0x660e0039,0xbafb0093,0x8b030066}},	//   פדיה_, _jebk, _להמש, ářen
  { {0x2fc7008a,0x672400bd,0x7aed00c6,0xae5b0009}},	//   ́ng_, hrij, _suat, זכיר
  { {0x7ae50005,0x3866007d,0x68e60042,0x6724013a}},	//   _siht, _unor_, _nikd, krij
  { {0xe451000b,0x787c0061,0x32110145,0x75280029}},	//   כֶם_, _févr, tazy_, sudz
  { {0xdfa5000a,0x67241f2b,0xb7db0009,0x2fc6020d}},	//   _تحمي, drij, _הקדי, _iyog_
  { {0xe63b0093,0xe2c80003,0xa63b000b,0xfc3f0029}},	//   _התוכ, سوفو_, _הגור, nník_
  { {0x3ebe000e,0xa2cd0037,0x2ec50011,0x67240035}},	//   lott_, _दीर्, वत्त, frij
  { {0x7ae50051,0x24860029,0xe7330003,0xa2b50103}},	// [4e70] _tiht, dkom_, عصر_, _обич
  { {0xcb120093,0xdd210010,0x66cb0060,0xb6980009}},	//   _שלי_, rįžt, cükl, קֹּת
  { {0x64960029,0x7afb1f2c,0x9a3a0009,0x53fb0012}},	//   pšit, _stut, _ותתק, مرشح_
  { {0xa3f4002d,0x317e0052,0xfc3f00d9,0x60c21f2d}},	//   епці, ätze_, dník_, _nkom
  { {0x61ec000e,0xc43c000b,0xa85a0009,0x5fb80011}},	//   _állá, מתאי, _ודרכ, _उँगल
  { {0x9f040012,0xcb140009,0x78ad1f2e,0x5e450012}},	//   _سوفو, גלס_, lnav, _تَسْ
  { {0x3ebe000f,0xc5f20009,0xa2a00610,0x6d5a001b}},	//   dott_, _ידם_, _ऑगस्, _štav
  { {0x40940015,0x24860d1f,0x78ad1ada,0xa7650024}},	//   ерьт, ckom_, nnav, дкид
  { {0x66cb003a,0x60080009,0x6605005e,0x999e0073}},	//   yükl, הִתְ, _õhkk, _batų_
  { {0x45850001,0x64560a39,0xfbd20009,0x6459041a}},	//   дгов, _sayi, _יתן_, ldwi
  { {0xe3b8003a,0x442f0033,0xfc3f0029,0x1fda0011}},	//   ğım_, ogg_, cník_, _भण्ड
  { {0xe3b8003a,0xc058002d,0x3eb8009b,0x19ba0009}},	//   şım_, _ніч_, črta_, _ומעב
  { {0x67290054,0xeb9705cc,0x3ebe14d4,0x6e890012}},	//   quej, дия_, bott_, _ونصف_
  { {0x23600070,0x60c20030,0x24860064,0x60db005e}},	//   _vrij_, _zkom, zkom_, lmum
  { {0xb9b50014,0x15fa000b,0x66cb003a,0x2d1c0011}},	//   естъ, _והצע, rükl, _पटेल_
  { {0x76800006,0x60c900a2,0x3f89001e,0x64b60012}},	//   _löyt, nlem, _ļauj_, _تحتر
  { {0x8fa3035b,0xc7a3002d,0x59c00037,0xfc3f01bd}},	// [4e80] вате, витк, _एडवर, zník_
  { {0x2d810051,0x442f0033,0x78ad004a,0xc3c90012}},	//   _ühes_, egg_, anav, _عظيم_
  { {0x60c900a2,0x644b0054,0xfe79003c,0x6aa31f2f}},	//   klem, fegi, чёты_, dinf
  { {0x3ebe000f,0x44f30020,0xc173000b,0xcea90009}},	//   zott_, _mã_, _סחר_, בי_
  { {0xcce50003,0x69c1005e,0x27f80034,0x60c9005b}},	//   رسمي, ülev, ągną_, dlem
  { {0x44320002,0x248d000e,0x24861833,0x3945016d}},	//   ży_, _elem_, skom_, _bpls_
  { {0xa9670046,0x60c900a2,0x21670001,0x3ebe000e}},	//   дија_, flem, дији_, vott_
  { {0x30a30015,0x649617a3,0x212004d2,0x60db002c}},	//   крыв, zšir, čih_, gmum
  { {0x3ebe000f,0xb05b006f,0xab65001e,0x200f0028}},	//   tott_, _okän, _peļņ, _degi_
  { {0xda66000a,0x60c90061,0x78a40da7,0x78ad017b}},	//   _تاري, alem, hiiv, znav
  { {0x98a70030,0x3ebe1f30,0x60c91f31,0x7e7c1f32}},	//   ntně_, rott_, blem, _morp
  { {0x25fe0037,0x9f401ace,0xc0aa0012,0x09290012}},	//   _श्री_, nció_, _باطل_, _رسمي_
  { {0x3ebe000e,0x78ad04d2,0xddce0034,0x7c3d0097}},	//   pott_, vnav, _jabł, rfsr
  { {0x60c00322,0x44f30018,0x98a70030,0x644b0034}},	//   lomm, _fã_, ktně_, zegi
  { {0x9f40000e,0xba9b000b,0x28f80015,0x7ae80623}},	//   kció_, קסלי, десь_, _midt
  { {0x60c00022,0x442f0058,0x58d41f33,0x39570009}},	//   nomm, _øg_, вост, ושלם_
  { {0xddd50030,0x2484008e,0x78ad1f34,0x0b190012}},	// [4e90] _pozů, ömme_, rnav, _عقدة_
  { {0x0f37000b,0x7e550003,0x644b0070,0x60c91f35}},	//   ורמט_, عناص, wegi, zlem
  { {0x44f30020,0x60c9003a,0xab620051,0xaab80012}},	//   _xã_, ylem, _üürn, _تدير_
  { {0x6ab90037,0xa2a10011,0x7d0d0034,0x3f840073}},	//   ेत्र, कोन्, _łask, kymu_
  { {0x6d5a1f36,0x1308002d,0x90980014,0xe3ae002d}},	//   _štat, дній_, _цвят_, уб_
  { {0x9f4003eb,0x76580004,0x02440012,0x200f1f37}},	//   ació_, _navy, ََنَ, _segi_
  { {0x3495057b,0x09f60003,0x60c91f38,0xa3d30011}},	//   _завр, رفية_, tlem, हेज_
  { {0x45d40047,0x9f4003eb,0xc052000b,0x249f06db}},	//   _росс, cció_, ָ֖ה_, _umum_
  { {0xe7a90063,0xf41f008e,0xb6cc0060,0x200f01a0}},	//   явил_, tkän_, ğünü, _vegi_
  { {0xfe71000a,0xb6cc00a2,0x60c9003a,0xe3b8003a}},	//   ادة_, şünü, slem, şık_
  { {0x200f0051,0x9f4000c1,0x89340012,0x2ca01f39}},	//   _tegi_, nciò_, _لعنا, _pmid_
  { {0xb05b006f,0x91a80012,0x60c01f3a,0xed560024}},	//   _skän, _تهمك_, comm, хою_
  { {0xf7450047,0x7dee000e,0x78a4019a,0x26c100d9}},	//   _чело, nősí, viiv, koho_
  { {0x877a000b,0x6d550002,0xb77a0009,0x69c81819}},	//   _מאני, _osza, _מאנש, żdem
  { {0x78a407f6,0x3ea90066,0xc5080012,0x7cff004b}},	//   tiiv, čitě_, _قتيل_, fârş
  { {0xa0b50046,0x05740012,0x3ea5005e,0x645a0035}},	//   вљуј, _جاهد, lilt_, ētis
  { {0xdbd20051,0x3cff001b,0x29030031,0x44201f3b}},	// [4ea0] nüüm, _čuva_, apja_, _idi_
  { {0x78bb001c,0x3ea50051,0x673b12ab,0x47d30012}},	//   čuva, nilt_, ituj, ايكر
  { {0x69c1000e,0xd6cf0003,0x5cf50024,0x4420016d}},	//   ület, حقل_, вячу, _kdi_
  { {0x44200030,0x673b170c,0x7ae80248,0x60fb0009}},	//   _jdi_, ktuj, _sidt, _מהטק
  { {0x80630015,0x98a70066,0x60c0004a,0x9f401ef5}},	//   _свяж, stně_, vomm, rció_
  { {0xada60c1e,0xd1300012,0x66d0008e,0x7d1c009e}},	//   _загл, لمت_, mäko, ársk
  { {0x9f401f3c,0x6ee90010,0x3ea50051,0xd5b20003}},	//   pció_, _užba, dilt_, _صفر_
  { {0xd010000a,0x76580010,0x81430003,0xd7fa00fa}},	//   جلة_, _savy, انين, чук_
  { {0x7658007a,0x64a4000e,0xf093000b,0x9ed8003c}},	//   _pavy, tőin, טנה_, ммит_
  { {0x69960345,0x72060012,0x6444005e,0xddc70034}},	//   _прех, _أوام, _abii, _najś
  { {0x291e001c,0xc693000b,0x765a0722,0x06970009}},	//   štaj_, ראת_, rdty, גדים_
  { {0x2ebe0037,0xc9b70009,0x66cb005e,0xe1ff0081}},	//   ्तुत, _אהבת_, tükk, _đói_
  { {0x9f34002d,0xab87002d,0x366a0015,0x832a000b}},	//   _релі, хунк, _надо_, הוָ֖
  { {0xdfcf0012,0xfe6f0012,0xafe3003c,0xeb910009}},	//   _ايه_, _هدى_, _сочл, בָל_
  { {0xe5f70093,0x3cea0037,0x7c20009b,0x865b0009}},	//   _אזור_, _घंटे_, _odmr, _מדגי
  { {0x67d50024,0xf8b20011,0x30a40024,0x9b950012}},	//   вобу, ुकिय, грув, _للبت
  { {0x6d470065,0x16be0037,0x66d0006f,0x752f0002}},	// [4eb0] _spja, ्तूब, räkn, ącze
  { {0x644f16e9,0x69c10051,0x44201f3d,0xaa47008e}},	//   leci, üles, _zdi_, ätää_
  { {0x6d5a0d09,0x64ab0030,0x21270081,0xddc305be}},	//   _štar, přid, _ính_, _manş
  { {0xe4e4007c,0x2bde0037,0x9f4000c1,0x95c40012}},	//   гічн, नेवा, rciò_, ديمه
  { {0x60cd003a,0x69d8018a,0xc0160009,0x8c1c0009}},	//   mlam, _úver, _בקרו_, לואי
  { {0x7dee000f,0x20090010,0x8d770012,0x644f0018}},	//   rősí, lbai_, _كازا, heci
  { {0x45d40014,0x6d550034,0xbdd40198,0x644f016d}},	//   _борс, _usza, _борщ, keci
  { {0x673b0006,0xa4d5002d,0x60cd1f3e,0xd5b1001a}},	//   ttuj, _робі, nlam, hác_
  { {0x91f50020,0x7528003e,0x3f8b0029,0xd2290012}},	//   _các, erdz, ácu_, _يكره_
  { {0x2d851f3f,0xf41f006f,0x645b1f40,0xc7440012}},	//   _üles_, skäl_, _haui, اضيي
  { {0xc5f2000b,0x3ea50051,0x673b1f41,0x45d50048}},	//   ידי_, rilt_, stuj, ъцит
  { {0x27390054,0xe20a0011,0x3ea5005e,0x673b08f2}},	//   pèn_, वर्ण_, silt_, ptuj
  { {0x96b50046,0x75281f42,0x60cd1f43,0x8c1a0009}},	//   _искљ, ardz, dlam, וורי
  { {0xcb12000b,0x60cd0190,0xc3320009,0x66d0008e}},	//   שלם_, elam, בוך_, väko
  { {0xa564000a,0xc6920009,0x78bb001b,0x67290031}},	//   _مدين, _דאג_, čuvn, lrej
  { {0x68fc000f,0x999e0031,0xb5b60009,0x60cd1f44}},	//   _érde, ütő_, _שלקח_, glam
  { {0x44f7003a,0xbc790029,0xc0e301d4,0x69c1004e}},	// [4ec0] _aç_, úšťa, ротк, üler
  { {0xaefb001a,0xe1fa0593,0x6aa70227,0x99d60012}},	//   _trùn, _юго_, cijf, _لتجا
  { {0xe0da0046,0x6f1b0052,0x98ad003a,0x32180bad}},	//   _ово_, hsuc, _çoğu_, mary_
  { {0x60cd01b3,0x68eb0404,0x79b70009,0x6aca0011}},	//   clam, _nigd, _יליד_, ित्र
  { {0x60c4004a,0x24800002,0xe3b20012,0x2ca61f45}},	//   moim, _moim_, جرا_, riod_
  { {0x644f003e,0xba180003,0x3218002a,0x66030109}},	//   zeci, ريبا_, nary_, _впра
  { {0x91f5008a,0x6f1b0052,0x7d1c02a1,0x76411899}},	//   _sác, esuc, _uvrs, dfly
  { {0x8557000b,0xf1b30009,0x60c4008e,0xbf340024}},	//   _בשלב_, יסו_, noim, гнищ
  { {0x765c00c6,0xf62a002d,0x7e2a0024,0x30770012}},	//   _kary, міни_, міна_, ضحية_
  { {0xd337000b,0x66cb0051,0x539b0009,0xba6a0012}},	//   _ברמה_, tüki, _חימו, _تحرك_
  { {0xd5b00003,0xf297000b,0x60cd003a,0x24550003}},	//   صفح_, _שכבר_, ylam, هندس
  { {0x91f5001a,0x9169001a,0xa3d60011,0x52bd0011}},	//   _tác, hực_, _हरा_, ोत्स
  { {0x7d1a0052,0x645d1e5a,0x98a30034,0x5f730012}},	//   ssts, rdsi, nują_, _ناور
  { {0xc7d7000b,0x765c0010,0x46a30014,0xa9350024}},	//   _סוגי_, _nary, _качв, легш
  { {0x63be0002,0x60cd003a,0x59f8002d,0x69c0003a}},	//   ępny, tlam, теся_, şmen
  { {0x515b000b,0x2aad0027,0x98a30002,0xf0b40024}},	//   וכלו, džbe_, kują_, айсь
  { {0x9ed90014,0xd7d50001,0x6d5a001b,0x20090073}},	// [4ed0] емат_, ужањ, _štap, rbai_
  { {0xba550046,0xe7300003,0x98a30002,0x64420061}},	//   _свој, تصف_, dują_, efoi
  { {0x765c007b,0x60cd1f46,0x67290064,0xdcf40012}},	//   _dary, plam, zrej, لأنب
  { {0x6f020eb3,0xa31902ad,0xbb950048,0x1b19003c}},	//   _otoc, ежду_, лаещ, ежды_
  { {0x0c24002d,0x289a0009,0x9b450012,0x98a30034}},	//   рмін, _נישא, انتو, gują_
  { {0xbbd30044,0xdb0e000e,0x6d4a0058,0x67290027}},	//   _तरीक, ókér, _opfa, vrej
  { {0xc27c000b,0x98a30010,0xda7c000b,0x3cf80012}},	//   ורגי, aują_, ונגר, _لعقد_
  { {0x88c50013,0xc174000b,0x30190012,0x14190012}},	//   _ověř, שחק_, رتبة_, _سيئة_
  { {0xf094000b,0xd6390024,0x98a30034,0x67291f47}},	//   ינק_, няні_, cują_, urej
  { {0x6f1b008b,0xb2d50012,0x64ab0030,0x67291f48}},	//   rsuc, _صياغ, yřic, rrej
  { {0x273d001a,0xe1390024,0x98a70035,0x32360009}},	//   hìn_, _їзді_, aunā_, _תטען_
  { {0x7f19002d,0x32180b2c,0x67291f49,0x62811f4a}},	//   _зіку_, wary_, prej, _holo
  { {0x4fa4007c,0x32180036,0x6d5e0066,0x60c4004a}},	//   _київ, tary_, _špat, voim
  { {0x78a91f4b,0xb6070d60,0x539a0009,0x471a0009}},	//   liev, _рядк, גישו, _טונג
  { {0x60c4015e,0xd6e4002d,0x98a30002,0xdcfa0010}},	//   toim, пiюв, zują_, tytą
  { {0x88e60001,0x628102a0,0xd0190034,0x2167004c}},	//   ужбе, _lolo, nań_, ћити_
  { {0x0ab60003,0xddd500f1,0x765c09bb,0x1f66003c}},	// [4ee0] _محدد, _rozš, _pary, ыкам
  { {0xee370001,0x6ee90010,0x78a9051c,0x55170011}},	//   лну_, _užbl, hiev, _दबाए_
  { {0x60c40017,0xcd360003,0x765c1f4c,0x91690081}},	//   poim, طراب, _vary, rực_
  { {0x20560094,0xa8560001,0x98a30034,0x2aad0064}},	//   _стор, _стој, tują_, ržbe_
  { {0x8c1b0093,0x64420061,0xd0190002,0x38601073}},	//   תוני, rfoi, dań_, mdir_
  { {0xc3330093,0x6442000d,0x38601f4d,0x98a30002}},	//   מוד_, sfoi, ldir_, rują_
  { {0x6281012e,0x98a30002,0x26c51f4e,0xddc30025}},	//   _dolo, sują_, dolo_, _manœ
  { {0xf993000b,0x6b8d000e,0x38601f4f,0xdd00001e}},	//   מרו_, öngé, ndir_, ūtīj
  { {0x628101b3,0xc32a0003,0xa3cb0037,0x8c1b0009}},	//   _folo, _سكان_, _रुप_, _רומי
  { {0xa2e60047,0x0f570093,0x9b93000a,0xfb1b000b}},	//   _созд, ניים_, _الكت, _נובמ
  { {0x6475002d,0x29d30012,0x88c50030,0x45d4054b}},	//   агну, _هيكس, _svěř, ронс
  { {0xd00f0003,0x69c0003a,0x41bb0009,0xc985004c}},	//   _فلم_, ğmel, _אצבע, _туђи
  { {0x69c0003a,0x752f0002,0x26c51f50,0x38600097}},	//   şmel, ącza, bolo_, ddir_
  { {0x2eb10037,0x26c51f51,0x1af40198,0xb05b008e}},	//   ीकृत, colo_, спря, _ikäi
  { {0x828b000b,0x11280024,0x6d581f52,0xd5fb0009}},	//   תְכֶ, люти_, _usva, _אפור
  { {0x69470027,0xd5b1001a,0x88bc0066,0x6aaa0e56}},	//   jčeš, oán_, _uvěd, hiff
  { {0xb4c30037,0x3f8f0028,0x06150021,0xa5f9004c}},	// [4ef0] ्ती_, águ_, идаю, везу_
  { {0x661a000f,0xd5bb096e,0xc7d70009,0x85050012}},	//   natk, нсе_, רומי_, لوطن
  { {0xf9fa0009,0x91f50081,0x3ced0035,0xb6bb0009}},	//   _בהתמ, _bán, _piev_, עצבי
  { {0x661a1f53,0xad1b0009,0x297a0009,0x23691f54}},	//   hatk, תואר, _סטרא, _kraj_
  { {0x661a0fa6,0x501a0009,0x4c9c0009,0x09dd0011}},	//   katk, _בורו, עבדו, मध्य
  { {0xb4c30044,0xd0190002,0xe8e0001a,0x6b9d0031}},	//   ्तु_, wań_, _đức_, izsg
  { {0x70b20044,0x78a900bd,0x82340003,0xd0190002}},	//   ुकूल, tiev, إرها, tań_
  { {0xd00e0003,0x5f750012,0x672d02a1,0x661a0035}},	//   ولى_, لاخر, oraj, eatk
  { {0x26c501a2,0x6c840003,0xef160015,0x98b8001e}},	//   tolo_, _القم, амы_, ntrā_
  { {0x672d0027,0x3860003a,0x9998000e,0x26c500b8}},	//   iraj, zdir_, zerű_, uolo_
  { {0x78a9001e,0x672d00d9,0xfe360009,0x66cb005e}},	//   piev, hraj, ברתי_, lüks
  { {0xe3660001,0x397a0009,0x0d820024,0xfbc70012}},	//   акми, _בטענ, ілян, قت_
  { {0x7ff40003,0x661a00b6,0x26c500c1,0x21f6002d}},	//   _اسما, batk, polo_, иївс
  { {0x412a0094,0x8f9a000b,0xb69b000d,0xee0f0011}},	//   кого_, _ביני, _stân, िरोध_
  { {0xe5a20001,0x6b8b00d2,0x7c3b1f55,0x200d0032}},	//   _миши, hygg, _ocur, obei_
  { {0xf7720003,0x7bcd001e,0x55ba007e,0x6fb60012}},	//   ياء_, ļauj, _שמקו, لمزا
  { {0xb4d20037,0x3860003a,0xa3e50037,0x672d0791}},	// [4f00] वती_, rdir_, भेद_, graj
  { {0x91f50020,0x442400b6,0x7e610028,0x8e070198}},	//   _sán, _sdm_, ndlp, инув_
  { {0xc27b000b,0x2baa0037,0x64bc001b,0x98b80035}},	//   _סרטי, _चेता, jčic, atrā_
  { {0x8c4605cc,0xdd8f0003,0xd91b000b,0x91bb0009}},	//   реде, بوم_, _בוטל, _ימיי
  { {0x68e40051,0xbcb70009,0x833a00de,0x6d41005e}},	//   mmid, ספנו_, тчет_, htla
  { {0x68e40051,0xa1760009,0x8bd70009,0xcb070012}},	//   lmid, ֹעֵד_, בונו_, جيون_
  { {0x649300a2,0x5bd30796,0x661a1f56,0xbbd30037}},	//   _için, _सर्व, vatk, _सर्क
  { {0xddd80029,0x8f460055,0x8d5b0009,0x6aaa0248}},	//   _novš, аход, _בכלי, siff
  { {0x6d41003e,0xd6da085b,0x6e440003,0xa0670001}},	//   etla, кто_, منظم, рања_
  { {0x26c70027,0x752f0002,0x7afd0164,0x200d0052}},	//   čnog_, ączn, _ésta, abei_
  { {0x20000029,0xfdf70009,0x2419003c,0x661a17f1}},	//   kcii_, יצית_, лоны_, ratk
  { {0xb4c30037,0x20d7003a,0xd7e6002d,0x661a00b6}},	//   ्ते_, eçin_, _кіло, satk
  { {0x661a00c6,0xcf770003,0x600b0009,0x98a70035}},	//   patk, _نصوص_, _יִגְ, atnē_
  { {0x171b000b,0x68e40647,0x98a7000d,0x6fb30012}},	//   _יודע, emid, pună_, _بمها
  { {0x2bd30044,0x66cb01c4,0x067b0009,0xd6db0009}},	//   _सरका, züks, _בנגל, _שחול
  { {0x88940015,0x14100037,0x6d7b0009,0x2366001b}},	//   оисх, ारोह_, _יאוח, kvoj_
  { {0xe3b8003a,0xa8570009,0xb4b50011,0x6d4e0035}},	// [4f10] şır_, סימה_, ड़की_, _apba
  { {0x68e40005,0xde190003,0x7c3b0d41,0x8f9b0009}},	//   amid, اقات_, _scur, דימי
  { {0xc212000b,0xb2bc000b,0x672d019a,0xd6570009}},	//   _מהי_, _במזר, sraj, שיבת_
  { {0x67200035,0x321c1f57,0x6f091f58,0x672209df}},	//   ksmj, eavy_, ypec, _ovoj
  { {0xe3b00003,0x9cd80009,0x6f09036c,0xe3650306}},	//   وره_, בואה_, xpec, скли
  { {0x78ad0010,0x628511d7,0x6b8b09d8,0xd3580009}},	//   liav, _joho, rygg, יידי_
  { {0x8d950003,0xf5950003,0x69da0002,0xd1c90015}},	//   _الأش, _الأج, _czte, ылке_
  { {0x19b8000b,0x96010037,0x2d9e0029,0xf3f9000d}},	//   יפור_, ोर्ट_, dzte_, _faţa_
  { {0xb8fe0044,0xff510003,0x201900c1,0x200d0052}},	//   _दी_, سخة_, _mesi_, rbei_
  { {0x78ad00c1,0x27ff1aa1,0x44391f59,0x6f091f5a}},	//   hiav, scun_, egs_, rpec
  { {0x752f0002,0x2d9105b1,0xdff50024,0xfe9a0009}},	//   ączo, áze_, _ляль, ריתמ
  { {0x6d4112ac,0x41740003,0x69c0003a,0xf9920009}},	//   rtla, _باكس, şmek, _מרב_
  { {0x64bc007a,0x26d903eb,0xc7f6000b,0x9f050003}},	//   nčia, ïsos_, _הזנת_, _اوتو
  { {0xcb120093,0x64bc007a,0xd295002d,0x6ec40003}},	//   הלך_, ičia, орсь, _وتوق
  { {0xf2d2000b,0xc8960001,0x201900b6,0x409600dc}},	//   פעל_, брањ, _besi_, брат
  { {0x60c90070,0x98a301ec,0x64bc0010,0x68e41f5b}},	//   noem, писе, kčia, umid
  { {0xa0670098,0x15f60003,0x3f8d0054,0x18670024}},	// [4f20] щата_, مساح, nyeu_, щати_
  { {0x1fb5007c,0xdc100037,0xe6290012,0x64bc0064}},	//   істр, ार्ड_, لثمن_, dčia
  { {0x387f0028,0x64bc0010,0x09f70009,0xcf890009}},	//   kjur_, ečia, _למים_, עט_
  { {0x291e007a,0xeb9a022a,0xd4090012,0x6ca50024}},	//   štas_, лие_, لتهم_, оріж
  { {0x387f006f,0x321c0042,0x64ab0030,0xe29a0081}},	//   djur_, tavy_, dřil, thư_
  { {0x6e96000a,0x5e960003,0x20100002,0xe6960003}},	//   _السا, _السط, łnić_, _السد
  { {0x7229002d,0x361b000b,0x321c022d,0x64bc0cf9}},	//   рців_, _תולד, ravy_, ačia
  { {0xb97b000b,0xc173000b,0x387f0028,0x6618003a}},	//   טנצי, לחו_, gjur_, _sevk
  { {0xdfd0000a,0x7f440061,0xdddc000d,0x93fb000b}},	//   بية_, ntiq, _forţ, _תלמי
  { {0x2d9e008b,0xf773000b,0xb87b001a,0xa7fb0164}},	//   tzte_, פקת_, _khíc, _maña
  { {0x6996002d,0xda650003,0x984a0014,0x3eac014f}},	//   _урах, _باقي, _бяла_, ridt_
  { {0xc9770093,0xa177000b,0xc8650012,0xfbdc0011}},	//   _לגבי_, _לעבד_, _وطني, _बराम
  { {0x661e00b6,0xc5f8001e,0x20191f5c,0x66d0008e}},	//   kapk, ldēm_, _resi_, läku
  { {0x17570009,0xdd94003c,0x6d5c0097,0xff570009}},	//   _לסדר_, _малы, æras, _לבדך_
  { {0xc1050003,0x55060001,0x66d0004a,0x20d70012}},	//   توزي, _учла, näku, مترج
  { {0xb5b7000b,0xb7150014,0x3eb80159,0x64bc0073}},	//   _ללוח_, ждащ, črtu_, yčia
  { {0x62850145,0x78ad1f5d,0xa7fb01e3,0x44291f5e}},	// [4f30] _toho, riav, _caña, _ida_
  { {0x43d40012,0x41550339,0xa7fb01e3,0x9b180009}},	//   _عزيز, _двос, _daña, _החזה_
  { {0x7bf901ec,0x2737015b,0x35550012,0x25b90012}},	//   анер_, ožná_, تناز, جهاد_
  { {0x3e850066,0x9b950012,0xe5700012,0x81c70035}},	//   _sítě_, يلات, عطل_, nzēš
  { {0x98b8007d,0xdddc000d,0xdfc60012,0x7f441f5f}},	//   stră_, _porţ, _آي_, ctiq
  { {0x161d0037,0x64bc0010,0x661e00b6,0xceb80034}},	//   _फ़िर_, rčia, capk, jnę_
  { {0x91e2007c,0x64bc1f60,0xfce90012,0x64ab0030}},	//   моше, sčia, _نفسي_, třil
  { {0x3f420065,0x7afd0164,0x64bc0029,0x44291f61}},	//   fðu_, _ésto, lčin, _nda_
  { {0x3f420028,0x81c7001e,0x8e55002d,0xb4d50037}},	//   gðu_, dzēš, отні, हती_
  { {0x442900ec,0x644d1f62,0xda020037,0xab5d0002}},	//   _ada_, _abai, रुआत_, _wyżs
  { {0xa2c60044,0x98b80010,0x22640066,0xe4520003}},	//   िवर्, ltrą_, řská_, وضح_
  { {0x25e10037,0xceb80002,0x2caf0070,0xc209000b}},	//   _करनी_, anę_, nigd_, _יה_
  { {0x98b80010,0xe79c003a,0x7afb019a,0x29180097}},	//   ntrą_, düğü, _juut, _ærar_
  { {0x7afb0b38,0x2bdc0011,0xbebd0035,0xfe710012}},	//   _muut, _बरसा, grūt, _زدت_
  { {0x04460098,0xe81a0001,0xada5048c,0xc4c90011}},	//   _дейн, ицај_, _файл, िकाओ
  { {0x64bc18b7,0xdddc0030,0x100a0012,0x838a0024}},	//   ečin, _norš, شترى_, _вбив_
  { {0xdfcf000a,0x3f670014,0xa2d60003,0x2caf0070}},	// [4f40] نيف_, оито_, _ويعت, digd_
  { {0x4429095d,0xcdd60001,0x443f1f63,0xdb0a0031}},	//   _zda_, оцењ, _acu_, önít
  { {0xbfa30020,0x661e00c6,0xed5a0075,0x7f4404b8}},	//   _hiể, rapk, рое_, stiq
  { {0xbfa30020,0xa3be0037,0xe73a003c,0xceb80034}},	//   _kiể, _आशा_, _кем_, znę_
  { {0xdee60014,0xceb80002,0x5b130024,0x9be30024}},	//   _моми, ynę_, дміт, мішк
  { {0xb87b0020,0x7c2900a2,0x752f003e,0x236d0058}},	//   _thíc, _eder, ńczy, _drej_
  { {0xd1300003,0xca7b0009,0xb05b1f64,0x599a0009}},	//   رمة_, ינסט, _fjäd, ישַׁ
  { {0x7e630070,0xc0e70012,0x228b00b0,0x63b50097}},	//   _aanp, يفون_, _søkt_, éfnú
  { {0x66d0004a,0xda0b0321,0xa09b0009,0xdfda0048}},	//   säku, _स्वत_, ייקט, шък_
  { {0x3f420065,0x67240006,0xe7e00037,0x52a70015}},	//   rðu_, isij, खेगा_, _двум_
  { {0x7c2900c5,0x64bc007a,0x5dfb0009,0xd6570009}},	//   _yder, nčio, יפינ, חיית_
  { {0xbfa30020,0xe4a7002d,0xceb80914,0xc87f0032}},	//   _biể, ірно, snę_, ößt_
  { {0x443f001e,0x81c7001e,0x7d0d0066,0x63a214f5}},	//   ļu_, rzēš, _čase, nzon
  { {0x443f0002,0x7c3a0073,0x661c0034,0xccfa004c}},	//   żu_, ėtra, _nerk, _кћи_
  { {0x2d8300c5,0x7dc60003,0x67260033,0x34950264}},	//   øjet_, _بتشك, _avkj, _накр
  { {0xd5b9002d,0x66cf0033,0x212d0159,0x859b0009}},	//   _усі_, søkt, čeh_, _כשוו
  { {0x661c00c6,0xe7190003,0x63a20070,0x66d0004a}},	// [4f50] _berk, صيات_, jzon, jäks
  { {0x63a205a8,0x62880039,0xa2b40047,0x7bdf0164}},	//   dzon, _nodo, _обыч, _izqu
  { {0x7afb00ff,0x68e201e9,0x2caf0227,0x4a5a0009}},	//   _suut, _ohod, tigd_, _הדתו
  { {0xb4d50044,0x236d009b,0x7afb0038,0x55bb0009}},	//   हते_, _prej_, _puut, סמאו
  { {0x9cd8000b,0x66d0006f,0x907a000b,0x60cd008e}},	//   קודה_, täkt, _הטרי, moam
  { {0x5338000b,0x4efa0009,0xdaa80024,0xd36e0012}},	//   קנון_, _להשו, овід_, اهو_
  { {0x45d4002d,0x62881f65,0x66f20034,0xdcff0035}},	//   _жорс, _dodo, _ałko, ēvēt
  { {0x69c100a2,0x41bc000b,0xc1bc000b,0x77850014}},	//   üley, יצוע, ימוש, злиз
  { {0x63a2003e,0x4e790003,0x64ab0066,0xe7310012}},	//   czon, محدد_, přij, رصة_
  { {0x479c000b,0x64590002,0x60cd1f66,0x7c3d0032}},	//   ייחס, lewi, hoam, egsr
  { {0xfbc90093,0x22580f33,0x9e480009,0x8d750012}},	//   _עת_, verk_, חֲרִ, سادا
  { {0x2258036a,0x757a000b,0x62830604,0x62880227}},	//   werk_, צטרפ, ljno, _zodo
  { {0x7e6300c6,0x26cc009b,0x5ffa0009,0xee2e0695}},	//   _tanp, bodo_, _ההנה, _пн_
  { {0x68e20485,0x8e490003,0x2d830058,0x98a00010}},	//   _zhod, _طلبك_, øjes_, čią_
  { {0x40960098,0x66cf0033,0x63a200c1,0xa6960009}},	//   прат, søks, zzon, _מכסה_
  { {0xb05b0163,0xbfa3001a,0x03260104,0xfc2b0066}},	//   _skär, _tiể, _един, íští_
  { {0x44221f67,0xdfd20003,0xcce50003,0x661c0607}},	// [4f60] mak_, ريط_, _تسوي, _perk
  { {0x66d00006,0xddc1000f,0x672413be,0x2216003c}},	//   väks, lelő, rsij, _эфир
  { {0x6288007a,0xf9fb000b,0x2cbf006f,0x81fb0009}},	//   _rodo, _להימ, _bjud_, _להיז
  { {0x661c036a,0x6ba1003a,0x66d0004a,0x44221f68}},	//   _werk, _özgü, täks, nak_
  { {0x6e21007a,0x661c00c6,0xddc1000e,0x44220031}},	//   kalb, _terk, ielő, iak_
  { {0x442200c6,0x68e20013,0x63a21f69,0xf655003c}},	//   hak_, _shod, rzon, _отсю
  { {0x2007003e,0xda650003,0x66d0004a,0x32030003}},	//   śnie_, باني, säks, رِيق
  { {0x25e10044,0xc953000b,0x7ce30051,0x55bb000b}},	//   _करती_, גמה_, võrg, _המלו
  { {0x442200ec,0x62880583,0xd0070001,0xa857000b}},	//   dak_, _todo, чење_, ליקה_
  { {0x6e21007a,0x7bcd0039,0x539b0009,0x9e660012}},	//   galb, ļaut, _הימו, ساخن
  { {0x1dbe0037,0x26cc0010,0x68e90029,0x68360060}},	//   ्थित, rodo_, bmed, güdü
  { {0xd197000b,0x2cbf0051,0xddc1000e,0x442202a0}},	//   _מכבי_, õud_, gelő, gak_
  { {0xa0c90003,0x2d830058,0x30830012,0x9f42008e}},	//   _بذلك_, øjer_, _سلوف, äkä_
  { {0xb87b008a,0x64590002,0x44220070,0x35b40024}},	//   _chín, zewi, aak_, _облр
  { {0x31c407ae,0xa9c40223,0x44221f6a,0x64bc0412}},	//   еств, естк, bak_, ečim
  { {0x442200a2,0x321e05b1,0x55bb0009,0xc8d90024}},	//   cak_, _lety_, _למוו, імає_
  { {0xb9040037,0xd3710012,0x62830034,0x7ff40012}},	// [4f70] _पी_, _شهد_, yjno, فسكا
  { {0xfb1c000b,0x4bd80003,0xd6db003c,0x6d480227}},	//   _הוזמ, _عبيد_, ёта_, otda
  { {0x753a008b,0x64bc009b,0x765a004a,0xaff90012}},	//   nutz, mčij, iety, _وفدا_
  { {0x765a004a,0x23b50012,0xb4c70011,0x66051f6b}},	//   hety, وماس, ईके_, schk
  { {0x753a0052,0xa3bb0012,0x84360012,0xe3f80012}},	//   hutz, حاضر_, ذكور_, أعمش_
  { {0x9f960093,0x38690de9,0xddc1000e,0x88bc0066}},	//   _חדשה_, ldar_, zelő, _dvěm
  { {0x442213b9,0xbd450003,0x98e50012,0xaa56004c}},	//   yak_, _تنزي, وكتو, фију_
  { {0x1dd00037,0xa99c0009,0x219c0009,0xc19c0009}},	//   _हड़त, מבור, מבוא, משוי
  { {0xcb340014,0x44221f6c,0x442d1f6d,0x53340048}},	//   _петъ, vak_, _ide_, _петт
  { {0x44220101,0x9ea9002d,0x9758000b,0xdd1b01e9}},	//   wak_, івна_, ליחו_, _váže
  { {0x442d014a,0xc692000b,0xe5a505fb,0xddc10031}},	//   _kde_, דאי_, фини, telő
  { {0x442d0066,0x71880009,0x6ac60011,0x929d0034}},	//   _jde_, _מְנַ, लक्र, _bułg
  { {0xd6290001,0x44221f6e,0x386913bc,0xcf240012}},	//   _доле_, rak_, ddar_, _كروي
  { {0xddc1000e,0x7ea01f6f,0xebf70012,0xd3360009}},	//   selő, _köpe, بُّع_, ורשה_
  { {0xaca3001a,0xa3d40011,0xa9671884,0x99980034}},	//   _chừn, _सुन_, мира_, warł_
  { {0x98a00027,0xc5f20009,0xe0da0024,0xf8dd0011}},	//   čić_, _בדו_, іва_, मतिय
  { {0xd6d2000a,0x290c0039,0xbbea0012,0xb87b0081}},	// [4f80] نقر_, ūda_, _برغم_, _thín
  { {0x64b80037,0x44201f70,0xfd9a0012,0x442d1f71}},	//   ेक्श, _hei_, يئات_, _ade_
  { {0x69c000a2,0xb9260003,0xf27b0009,0x546a0306}},	//   ğmes, _تفجي, _וריש, жаем_
  { {0x4420039c,0x69c0003a,0x99980034,0x23720034}},	//   _jei_, şmes, parł_, _kryj_
  { {0x44201f72,0x6b760012,0x7c221f73,0x00770009}},	//   _mei_, بطاط, raor, _חתכי_
  { {0x34bb0037,0xe297064d,0x06560012,0x44201f74}},	//   _उद्द, мач_, _تنسح, _lei_
  { {0x2f04006f,0x6d480032,0x321e0064,0x38c30073}},	//   _hög_, xtda, _vety_, kūrę_
  { {0x442d0027,0xd0100003,0x2c760012,0x44201f75}},	//   _gde_, دلة_, _تُرس, _nei_
  { {0x765a0006,0xb6f40001,0xc2460001,0x60d70009}},	//   tety, нзиј, _онак, ווקא_
  { {0x442d0013,0x6d480033,0x24860027,0xa77b0009}},	//   _zde_, ttda, ljom_, קריפ
  { {0x44201f76,0x2d980029,0x2f040028,0x79fb0009}},	//   _bei_, áre_, _lög_, _ולבח
  { {0x4420007d,0x24860027,0x7af70503,0x15e30011}},	//   _cei_, njom_, _sixt, केटर_
  { {0x44201f77,0xd7e20037,0x69da0032,0xf4130009}},	//   _dei_, _परिच, üten, כפר_
  { {0xda7b002d,0x6298016a,0x7d031f78,0x0aeb00ae}},	//   цям_, nkvo, ínsk, ترجي_
  { {0xa2b10037,0xe63b000b,0xd657000b,0xd4db0003}},	//   _अगस्, _ותוכ, _חיות_, _وبعض_
  { {0x7c200bb3,0x83aa0011,0x7c2d1f79,0x629e0035}},	//   _nemr, _चेकआ, _udar, _elpo
  { {0x645d1f7a,0x9bf50024,0x98aa0030,0x38691f7b}},	// [4f90] mesi, _язич, lubě_, rdar_
  { {0x76d5000a,0xd6db002d,0x62980227,0x98b1004b}},	//   رياض, іта_, jkvo, fuză_
  { {0xd5b10012,0xf1ae0011,0x21270081,0xe8950024}},	//   دفا_, _झेलन, _ình_, _зань
  { {0x8b6b0039,0x645d1f7c,0x64c90037,0xb69b000d}},	//   ņēmē, nesi, िकेश, _atât
  { {0xe452000b,0x42d50024,0x645d1f7d,0x68ed1f7e}},	//   רֶב_, ніку, iesi, mmad
  { {0x471a000b,0x216900b3,0x91e516e6,0x68ed1f7f}},	//   _מושג, зики_, ноле, lmad
  { {0xac190731,0x25a50248,0x68ed1f80,0x645d1f81}},	//   _нову_, _åll_, omad, kesi
  { {0x68ed003a,0xe3b8003a,0xa7650294,0x442d0040}},	//   nmad, ğız_, екид, _ude_
  { {0x59e10037,0xe4480003,0xd5b1001a,0x442008bf}},	//   _फरवर, _تلقى_, hát_, _rei_
  { {0x39640006,0xe6110003,0x8e74002d,0x44201f82}},	//   ässä_, دشة_, вуюч, _sei_
  { {0x044600be,0xa6e20028,0xdd2e0030,0xa81504a5}},	//   ненн, íðin, těše, _здеш
  { {0x859a0093,0xf7710003,0x64ca0011,0x657a0031}},	//   פשרו, _مات_, रवेश, _áthe
  { {0xe72e1f83,0xaca30020,0xe3b20012,0x33d50024}},	//   _ще_, _chứn, ارج_, вірт
  { {0x60db0cf4,0xa764002d,0x249f0054,0x69da005e}},	//   llum, _шкід, _llum_, üteo
  { {0xf3f9007d,0x940a0011,0xdd030035,0x67290fd2}},	//   _daţi_, हुँच_, ērēt, lsej
  { {0xd5b7001a,0x645d1f84,0xd70a0048,0xf41f008e}},	//   _ứng_, cesi, знае_, ljän_
  { {0x67290164,0x17c7002d,0x96a60011,0x8fa3056f}},	// [4fa0] nsej, егти_, टोकॉ, гате
  { {0x7c2612b8,0xe5a6022a,0xe61a0024,0x6da60909}},	//   lakr, низи, їде_, низа
  { {0xe45a0015,0x20070002,0xfd120012,0x7d0b004b}},	//   зже_, śnia_, اجئ_, _însă
  { {0x0ca90003,0x99620066,0x61e10d33,0x240700f5}},	//   وطني_, tíže_, ülle, енци_
  { {0xeb970047,0xc5f8001e,0x57fb000b,0xe3b20012}},	//   ниц_, ldēt_, _מלכו, درا_
  { {0x29660001,0x645d0a99,0x67290040,0x99660c80}},	//   ењив, zesi, dsej, етил
  { {0x2ca00051,0x645d003a,0xed5701ec,0x672b00ad}},	//   _olid_, yesi, _пор_, _avgj
  { {0xa3cb0011,0x31570009,0x49b70012,0x6ee60097}},	//   _रुक_, תיקן_, عاود_, iðbe
  { {0xb4be0037,0xb9070037,0x4426001b,0x79950034}},	//   ीकी_, _मी_, mao_, zyzw
  { {0xddd80066,0x67530003,0x60db1f85,0xe3570009}},	//   _zavř, اخير, alum, _אשמח_
  { {0x7d090145,0x645d1f86,0x24ea0009,0x01360012}},	//   _česk, tesi, ּקָּ, _سعاد
  { {0x7afa0163,0x64420258,0xc19b0009,0xddc70035}},	//   _hitt, ngoi, _משבי, _sajū
  { {0x44261f87,0x645d1f88,0xdc340042,0xd3660012}},	//   iao_, resi, júči, جه_
  { {0x539b0009,0xf7730009,0x877b0009,0xad260012}},	//   ליכו, _תקס_, _מאדי, _كربو
  { {0x44260bec,0x7afa1f89,0x68ed0225,0x81d50024}},	//   kao_, _mitt, tmad, товх
  { {0x7bde003e,0x44260027,0x26c71774,0x7afa1f8a}},	//   ępuj, jao_, čnom_, _litt
  { {0x44260027,0x9f340024,0xc6f9052c,0x248d0227}},	// [4fb0] dao_, леті, днах_, _roem_
  { {0x3f87001b,0x7c240097,0x1bf60011,0x7b070035}},	//   ćnu_, ðirn, ेशनल_, ēptā
  { {0x68ed003a,0xe5ab0001,0xceb30009,0x248d0945}},	//   pmad, чњак_, ניע_, _poem_
  { {0x44260027,0x78a41f8b,0xc5f8001e,0x7c8400dc}},	//   gao_, chiv, ldēs_, луче
  { {0x69da002c,0x5fe4002d,0x7afa1f8c,0x13080024}},	//   _ayte, _бірж, _bitt, еній_
  { {0x7afa01a2,0x7c261f8d,0x6d581e9d,0xc5f80035}},	//   _citt, zakr, _opva, ndēs_
  { {0xa1560046,0xba280003,0xa96601b6,0x44261ea6}},	//   вају_, رسوم_, вища_, bao_
  { {0x67290051,0x7afa0028,0xc174000b,0xa3c30037}},	//   tsej, _eitt, רחק_, ्था_
  { {0xa858000b,0x7c26000e,0xb7c8000d,0x7afa1f8e}},	//   תיחה_, vakr, miţâ, _fitt
  { {0x60db0065,0xe3b00003,0xd6ce0003,0x7ea0006f}},	//   slum, _طرق_, يقي_, _köpa
  { {0x60db003a,0x4df4027f,0x7c2606c4,0xdca603e1}},	//   plum, ляют, takr, вани
  { {0x6609003a,0x6f0200c1,0x69b70011,0x7afa1f8f}},	//   _şekl, _fuoc, ोपनी, _zitt
  { {0x26c70027,0xe3bf01e3,0x7ea00248,0x386d0d4c}},	//   čnoj_, taña_, _löpa, mder_
  { {0x6e440003,0x44260027,0x64410010,0x7c261f90}},	//   _منهم, zao_, ėlia, sakr
  { {0xaca3008a,0xe5a2002d,0x2d8a0058,0xf2d20009}},	//   _nhữn, _вищи, øbet_, יעך_
  { {0x6e230058,0x2aad001b,0xd943004c,0x26c10018}},	//   _henb, džbu_, јети, enho_
  { {0xb05b0163,0x4426001c,0xe3bf0164,0x7d030028}},	// [4fc0] _tjän, vao_, paña_, _huns
  { {0xb05b0163,0x7c240e22,0x05ba0012,0xeb970009}},	//   _hjäl, _heir, ودات_, _סדיר_
  { {0x44320013,0x95860014,0x2d9c0029,0x44261f91}},	//   _kdy_, ълже, áve_, tao_
  { {0xb4be0037,0xb4cc0037,0x7afa1f92,0x386d0910}},	//   ीके_, रके_, _sitt, jder_
  { {0x7c240065,0xef170047,0xcb540003,0x44260027}},	//   _meir, _имя_, انتظ, rao_
  { {0x44260027,0xe8e0001a,0xdb11000e,0xcb13000b}},	//   sao_, _độc_, ágáb, סלו_
  { {0xa6e20065,0x75d60012,0x7afa1f93,0x4426001b}},	//   íðun, _شيرا, _vitt, pao_
  { {0xf993000b,0xe0cf0003,0xfce608d6,0x3ea50052}},	//   שרה_, يزي_, _робо, ehlt_
  { {0x47340046,0xf8b30093,0xc6f806e6,0x7afa07a8}},	//   ћнос, ישה_, нних_, _titt
  { {0x3860002a,0xd1320003,0x15e60037,0xda660003}},	//   heir_, _نمط_, _करार_, _جاري
  { {0xceb30093,0x0697000b,0x22940051,0x6db40024}},	//   שית_, דדים_, _läks_, уйну
  { {0x79b70093,0x6fb40037,0x44241c8f,0xa9230064}},	//   _בלבד_, ूपां, _jem_, ôžem
  { {0xa3e80037,0xd00705fb,0xf7430024,0x661d0073}},	//   _भरण_, _рече_, _вечо, ŕska
  { {0x0f57000b,0x6e930024,0x3cfd0011,0x6e230040}},	//   _סיום_, _вишу, _रूके_, _genb
  { {0x7c240149,0xceb80002,0xe2f8002d,0xd9f40011}},	//   _feir, mię_, тері_, ेखित_
  { {0x44241f94,0x4432003e,0x61e50066,0x30a401ef}},	//   _nem_, _gdy_, _vzhl, арув
  { {0x64bc007a,0xe3bf0164,0xf7730003,0x26de0a17}},	// [4fd0] nčiu, maño_, جاز_, olto_
  { {0x64bc007a,0xd6280046,0xceb8003e,0xa01b0070}},	//   ičiu, кође_, nię_, _coör
  { {0x44240149,0xa9c41f95,0x386d0572,0x84390012}},	//   _bem_, _всяк, yder_, فكار_
  { {0x6ba8003a,0xd4e4002d,0xe534002d,0xe7e20011}},	//   _örgü, аючи, рець, _परंप
  { {0x83640003,0xb8f70037,0x44241f96,0xa295002d}},	//   لدول, ाक_, _dem_, ладі
  { {0x539c0009,0xab760012,0x386d0132,0xdce40030}},	//   וידו, اموا_, wder_, _brně
  { {0x79a70014,0x27e6000e,0x91280003,0x2bda0011}},	//   ърде, _azon_, نسيق_, _युना
  { {0x44241f97,0x01fc000b,0x2ca60042,0xa4d50024}},	//   _gem_, ופול, chod_, _собі
  { {0x672d02d1,0xfeb90012,0xceb80034,0x6e230227}},	//   nsaj, فادت_, fię_, _penb
  { {0xb05b0163,0x672d001e,0xceb80002,0x44241f98}},	//   _själ, isaj, gię_, _zem_
  { {0x69c4007d,0x99830066,0xd6d90034,0xc115004c}},	//   şier, dajů_, guła_, _смеј
  { {0x44241f99,0x98b8001e,0x3a2502e8,0x909b0012}},	//   _xem_, kurā_, _help_, _تضطر_
  { {0x20070066,0xceb80002,0x2905002c,0x7d030052}},	//   ěnil_, bię_, _hula_, _wuns
  { {0x2ebf0037,0xb3ba0009,0x8bd60009,0x3a2500b0}},	//   ्वोत, תמשכ, רושו_, _jelp_
  { {0x672d0b71,0x19b90024,0x2905001b,0x7c240073}},	//   esaj, вуть_, _jula_, _teir
  { {0xa0670046,0x18670046,0x29051f9a,0x64bc0029}},	//   ласа_, ласи_, _mula_, nčit
  { {0x3fe60345,0x46ea0863,0x29051af4,0x87250012}},	// [4fe0] ужав, едан_, _lula_, لعلم
  { {0x44241f9b,0x644913d1,0xda66005c,0x7e23002d}},	//   _sem_, _acei, _свои, йдуж
  { {0x88bc0066,0x2ca61f9c,0x22f70009,0xa0c60012}},	//   _květ, thod_, _תזין_, _ميدو
  { {0x64460a26,0xa3e80037,0xdd8f0012,0x7cfe0e38}},	//   ngki, _भरा_, ثوم_, _jūra
  { {0x8c1b000b,0x7e610b0d,0x6d411f9d,0x44241f9e}},	//   גוני, kelp, hula, _vem_
  { {0x6d260003,0x7e610033,0x6ffb001e,0x60c41f9f}},	//   _معرك, jelp, _mācī, lnim
  { {0x44241fa0,0xc5f50014,0x7d030028,0x24800027}},	//   _tem_, _вятъ, ínst, _onim_
  { {0x7d7b0009,0xceb80034,0x60c41fa1,0x61e40030}},	//   _אנלו, wię_, nnim, řilo
  { {0x7c93000a,0xf093000b,0x86260109,0xc0e70012}},	//   _القص, מנה_, льне, دفين_
  { {0x05b20037,0xe3b7002d,0x2480002c,0x6d54004c}},	//   ुपलब, _сбу_, _anim_, акођ
  { {0xceb80002,0x64bc0010,0x68460003,0xac190188}},	//   rię_, sčiu, _مَال, кону_
  { {0xa3c30037,0x13f5002d,0x64460033,0x7e6e001e}},	//   ्थल_, изня, ggki, _labp
  { {0xceb80002,0x52b50012,0x60c41fa2,0x3eba0097}},	//   pię_, لمحذ, dnim, kipt_
  { {0x2369012e,0x7afe00b6,0x3ffb0009,0x91d60011}},	//   _vsaj_, _cipt, _נפגע, _मुहै
  { {0x6eeb1088,0x86c30012,0x60c40032,0x30eb038f}},	//   nübe, _ديون, fnim, ефан_
  { {0x60c41483,0x98b80035,0x69de00b0,0x3015104f}},	//   gnim, turā_, _dype, рдар
  { {0xe4500003,0x6d5c1fa3,0xdc3c0009,0x29180031}},	// [4ff0] _رضي_, _apra, _נעזר, apra_
  { {0xba550001,0x68fd002a,0x88bc0066,0x32550b05}},	//   _твој, _wisd, _zvět, _твор
  { {0x66d0004a,0xbafa000b,0x60c4009b,0x26140037}},	//   näky, _שהתש, bnim, धड़ी_
  { {0x48670098,0xb19a0093,0x2905000d,0xc86702ad}},	//   _съоб, _ייתכ, _rula_, _стои
  { {0xcb690001,0x442b1356,0x765800d9,0x7ea00248}},	//   тале_, iac_, _obvy, _köpl
  { {0x82370003,0x5fba000b,0x290506db,0x6d411147}},	//   ارشا, _יצרנ, _pula_, yula
  { {0x0dc8007c,0xe5090020,0xa2d60037,0x21a5002d}},	//   _бути_, _mặc_, णवत्, рийм
  { {0x27e60002,0x38ba0f31,0x64bc0604,0xb8f20012}},	//   żone_, tūra_, učit, يكوب
  { {0x6d5c0013,0x8b580003,0x2d980623,0x64bc0042}},	//   _zpra, _مجلس_, øren_, rčit
  { {0xcdf50047,0x88bc0013,0x60c4009b,0x55f5003c}},	//   ичны, _svět, znim, ичну
  { {0x62810163,0xda7a000b,0xd5e5002d,0x6d410532}},	//   _inlo, _שנער, ржни, uula
  { {0x20070002,0x6d411fa4,0x7e610032,0xe5880009}},	//   śnij_, rula, selp, אָשָ
  { {0x60c4009b,0x9cd6000b,0x6d411fa5,0x889a0009}},	//   vnim, שורה_, sula, _שבני
  { {0x6e270066,0xa2f50009,0x7ea00060,0xee391fa6}},	//   _nejb, ימָה_, _röpo, _рнк_
  { {0x76ba0009,0x6f060002,0x60c4009b,0x48b6010c}},	//   _במספ, _sukc, tnim, ащат
  { {0x6cd30003,0x80660001,0x661c003a,0xfcd30012}},	//   _وقوا, јваж, ırke, _ويوج

  { {0xa0670098,0x69de0002,0x186702e3,0x98a300f5}},	// [5000] шата_, _wype, шати_, ците
  { {0x6111001e,0x2d9a1fa7,0xdddc0034,0x60c41fa8}},	//   _zāle, type_, _garś, snim
  { {0x98b8000d,0x9a3b000b,0xd23b0009,0x823b0009}},	//   gură_, _בתיק, _בגיל, _בעיצ
  { {0xeb9a0047,0xc689000b,0xfce3002d,0x6d5c0ba1}},	//   кие_, וא_, оохо, _vpra
  { {0x6d5c0034,0x78a3004b,0x62050031,0x8c290009}},	//   _wpra, _înva, _átlá, רֵעֵ
  { {0xba170003,0x442b0027,0x6eeb0052,0x03770009}},	//   ليها_, zac_, tübe, יתנת_
  { {0x6722003e,0xe2970001,0x00760009,0x98b8004b}},	//   _swoj, рај_, ֹתִי_, cură_
  { {0x2d68003a,0x8c430ac5,0xea00001a,0x6eeb07a4}},	//   _işe_, _месе, _giấu_, rübe
  { {0x660900a2,0x442b1fa9,0xf43b0009,0xdfd00012}},	//   _şeki, vac_, _שתמש, ثية_
  { {0xf708008a,0x7d000036,0x0f57000b,0x64410010}},	//   _của_, _hims, סיים_, ėlim
  { {0xa0a60047,0x1ef70003,0x7d00003a,0x75d40012}},	//   _кажд, جعية_, _kims, إيجا
  { {0x67220656,0x41bb0009,0xa99b0009,0x78a91e2f}},	//   _twoj, _בצבע, _שבאר, chev
  { {0xbf9b0017,0x9be7002d,0x32bb0012,0x66d0008e}},	//   _agên, рінк, ندسة_, säky
  { {0x8f9b000b,0x673d000e,0x5ed30012,0x1bee0011}},	//   _בידי, ásje, _وتوز, _जरनल_
  { {0xc6170009,0x361b0009,0x45440012,0xb9250012}},	//   _דחוי_, _יוגד, _انعق, إفري
  { {0xd5fb000b,0x5dfb0009,0x48a80ce1,0xaff80009}},	//   _בפור, _בפונ, атум_, ָּֽי
  { {0x28f80015,0xc0f80024,0x9e0700b5,0x7d0d0159}},	// [5010] реть_, ретє_, ачел, _časi
  { {0x98b8007d,0x44290005,0xc7c4002d,0x4fc4002d}},	//   tură_, _hea_, істи, іста
  { {0x5dd50012,0xa2b70011,0x59670048,0x9539004c}},	//   حقائ, ्चस्, _тъпа, узет_
  { {0x5b250012,0x5b350012,0x61e8005e,0xf5040024}},	//   مفصل, معتر, üdle, ізіо
  { {0x98b8000d,0xd7fb0001,0xbebd001e,0x4429166e}},	//   sură_, _јун_, osūt, _mea_
  { {0x3e570066,0x59550012,0xe6950012,0x0b88004c}},	//   _dětí_, مخبأ, _الآد, јсци_
  { {0xb7bd000d,0x7c2b0b02,0xe50b0011,0xda640012}},	//   maţi, pagr, _संधि_, زاوي
  { {0xb7bd000d,0xe4a70001,0x26c700d9,0x6d450532}},	//   laţi, _трго, čnou_, muha
  { {0x3c440003,0x6d451642,0xaa670024,0x6006003c}},	//   _ذَلِ, luha, _втек, щным_
  { {0xb7bd007d,0x91fc001e,0x62810132,0x7c291faa}},	//   naţi, _paāt, _unlo, _heer
  { {0x7c2909de,0xba740012,0x78a900b0,0xed59004c}},	//   _keer, _باقت, phev, ћом_
  { {0x4429007d,0x443e0052,0x19560009,0xb4c40011}},	//   _cea_, ßt_, _לבעל_, ्वे_
  { {0x6abc0065,0x7c290369,0x547a000b,0x7ce30051}},	//   tirf, _meer, אטרו, tõrj
  { {0x61e1004a,0x6f1b1403,0xbda90012,0xb7bd004b}},	//   _kyll, mpuc, _مطعم_, jaţi
  { {0x6abc0065,0x4999002d,0xd24f0003,0x6d450051}},	//   rirf, аття_, عنف_, juha
  { {0xa928022d,0xdfd20003,0x6d4500b6,0x3eb81fab}},	//   _nižš, كيز_, duha, _smrt_
  { {0x7f4a0003,0x7d00013a,0xc4d30009,0x8c1b0009}},	// [5020] طلاق_, _rims, _מגה_, _גופי
  { {0xb7bd000d,0xe45f004a,0xe7ee0011,0xd7ef0012}},	//   gaţi, nnön_, चेगा_, ركل_
  { {0x8afb0009,0xf2970009,0x7dc50012,0x44290132}},	//   _תהיי, _הכיר_, يتمك, _yea_
  { {0x30860003,0xf1c405b1,0xad250012,0xe5f30012}},	//   _الحف, alší_, تركو, سكند
  { {0x68e4003a,0x98b8001e,0xe29a0ae9,0xfb130012}},	//   mlid, strē_, лад_, كونج
  { {0xb7bd007d,0x29020028,0xdce8003a,0x6d45060b}},	//   caţi, _hika_, ılır, buha
  { {0xddda0002,0xf5960012,0xc27b0009,0x68e41fac}},	//   zetł, _الزج, טרסי, olid
  { {0x29020535,0x6537000b,0xbebd001e,0x8f460063}},	//   _jika_, _לאלף_, zsūt, бход
  { {0xa0670001,0x69c0003a,0x289b0009,0xf62a0024}},	//   сања_, ğmey, טיקא, ліни_
  { {0x6b7b000b,0x44291fad,0x69c0003a,0x29021fae}},	//   _גרמנ, _sea_, şmey, _lika_
  { {0x2fc70020,0xac990003,0x44290051,0xe0d601d4}},	//   ̃ng_, لندا_, _pea_, _людь
  { {0xb7bd000d,0xf1c0001a,0x90e60012,0x7ce3005e}},	//   zaţi, _ương_, _اسطن, võrk
  { {0xdd39000d,0x5f9405fb,0x44291faf,0x9e3406bd}},	//   tăţe, _филт, _vea_, _делч
  { {0x46f60047,0x2902004a,0xcef60001,0x77f70009}},	//   _учет, _aika_, _учењ, _המדד_
  { {0x32110002,0x44290b7b,0xd657007e,0xbebd001e}},	//   rczy_, _tea_, _היות_, rsūt
  { {0xfd4d001a,0xc5f30009,0x25ef0011,0x2bda0011}},	//   _thoạ, _צדק_, _अरबी_, _युवा
  { {0x59df0044,0xb7bd007d,0xe89401ec,0xec380009}},	// [5030] _पुनर, taţi, чать, _האחר_
  { {0x2fc70020,0x8f9b000b,0xaca3001a,0x6d450807}},	//   ăng_, אימי, _khủn, tuha
  { {0x628500bd,0xb7bd007d,0x7a880009,0xa3c30011}},	//   _inho, raţi, _הָרַ, ्थक_
  { {0x3c470003,0x27e60002,0x44290028,0x6d45010a}},	//   إضاف, żona_, úa_, ruha
  { {0x6eef0058,0xb7bd000d,0xa3d40011,0x7c291cbf}},	//   løbe, paţi, सॅल_, _veer
  { {0x7c2901e4,0xfbd00012,0x236d0159,0x26da1fb0}},	//   _weer, رتن_, _vsej_, copo_
  { {0xd9f90044,0xa2d20003,0x3ebe0033,0x929c0009}},	//   ंधित_, بيوت, ditt_, ריות
  { {0xbf590024,0x49bc0009,0x78ad1fb1,0x6aa81fb2}},	//   арої_, טמוס, nhav, _eldf
  { {0xdddc00a2,0xb4d50037,0x7d0a0052,0x3ebe0028}},	//   _karş, सकी_, _aufs, fitt_
  { {0x3ebe0119,0x8f9c0009,0x2bb80012,0xe7080012}},	//   gitt_, טיחי, _طاقة_, حتين_
  { {0xaca3001a,0x25a3000e,0xf3e90009,0xa05b0012}},	//   _chủn, ájl_, _סף_, _مؤشر_
  { {0x442f0101,0x644b13b9,0x39471c05,0xe7590024}},	//   nag_, nggi, muns_, _виді_
  { {0x7cd20333,0xee2e04f0,0xda660003,0x7d18005e}},	//   vārd, _он_, ياسي, _etvs
  { {0xe8e0001a,0xeff60009,0x60c91fb3,0xcb120009}},	//   _đốc_, _ומנכ_, lnem, ולך_
  { {0xc6160009,0xed560024,0x4096034d,0xcce60012}},	//   _וחצי_, _дощ_, орат, _وسعي
  { {0x6ab60037,0x442f001e,0x60c91fb4,0x02b60011}},	//   _अग्र, jag_, nnem, _अग्न
  { {0xa61a0003,0x68e4003a,0x3f8d0054,0x60c90061}},	// [5040] لغاء_, rlid, nxeu_, inem
  { {0x29020101,0x1eaa0003,0xc966004d,0xf6290012}},	//   _wika_, جاري_, _двой, مسمى_
  { {0x29020039,0xa2d80037,0x55660003,0x7cd2001e}},	//   _tika_, यवस्, تهاك, pārd
  { {0xbc0d000b,0xd4090012,0x7be60024,0xb40d0009}},	//   ְהוָ, متهم_, ожеж, ְלוֹ
  { {0x845b0009,0x60db001b,0x78a4005e,0xa3d40011}},	//   שכנז, doum, mkiv, _सुख_
  { {0x6f03000f,0x644b00c1,0x7d040574,0x5f2701d4}},	//   _ninc, aggi, _liis, _форм_
  { {0xa2cd0796,0xda650003,0xeb9f0058,0x442f002c}},	//   _सदस्, ثاني, ncør_, bag_
  { {0x29020163,0x0b1a0003,0x2240003a,0xc0340001}},	//   öka_, _نقرة_, şik_, чниј
  { {0x78a400c1,0x3947001e,0x24530012,0xbe8a10ef}},	//   ikiv, auns_, _تنقس, асне_
  { {0x39470392,0xb50b0011,0xc2430024,0xf41f008e}},	//   buns_, _संशय_, _онук, hjät_
  { {0x767b0009,0xb9c60012,0x291a00d9,0x867b0009}},	//   בטיח, _بقاي, ípad_, בריו
  { {0x7d0d1459,0xf1e40011,0xd7fa004c,0x8afd0030}},	//   _čast, _गरज़_, _кул_, _vpře
  { {0x7d040190,0x6f031e93,0xeb070024,0xb4fb0009}},	//   _diis, _finc, ючно, יפטי
  { {0x60c0020b,0x8e770012,0x290c1aa7,0x442f0227}},	//   limm, _ومنذ_, _kuda_, zag_
  { {0x644b0065,0x442f0101,0x59db0037,0x8afd0066}},	//   yggi, yag_, _मुशर, _upře
  { {0xa3aa0037,0x6d4800b6,0x929d0002,0x290c02a5}},	//   खना_, muda, _pułk, _muda_
  { {0x9f59045d,0x23280001,0xab280001,0x7c9c0009}},	// [5050] _også_, _доњи_, _доња_, _כשהג
  { {0x442f0101,0x7c2d0036,0xc9870014,0x60c01fb5}},	//   wag_, _hear, _думи, himm
  { {0xd6d8002d,0x78ad0722,0xbc190024,0x25570030}},	//   іту_, phav, білі_, dělá_
  { {0xb4d50037,0x3ce6009b,0x71880009,0xfbd30012}},	//   सके_, glov_, _וְשַ, وتش_
  { {0xdfc6000a,0x38690017,0x547c0009,0x60c0008e}},	//   _أي_, mear_, יטאו, dimm
  { {0x8f9a000b,0x7c2d1e83,0x442f1fb6,0x220b0009}},	//   _הישי, _lear, sag_, ׁפְּ
  { {0x442f01e5,0xd5540014,0x20070034,0x22580012}},	//   pag_, _окръ, śniu_, تجنب_
  { {0x7c2d002a,0x290c0164,0x6d481ea6,0x20f70037}},	//   _near, _duda_, duda, ुदेश_
  { {0xddc10013,0x7d0400ff,0xea000081,0x6f031af6}},	//   telů, _riis, _phẫu_, _pinc
  { {0x0ea90047,0xe3b00003,0xfe42002d,0x98a30002}},	//   ской_, _شرق_, нньо, rsję_
  { {0x7d0400ff,0x7c2d132a,0xceb20009,0x99480012}},	//   _piis, _bear, גיי_, _ولكل_
  { {0x895a000b,0xed560024,0xdbd7008e,0x95960009}},	//   _לדעת, чою_, kääm, לכתו_
  { {0x442d0070,0x70760003,0x78a40051,0x6d4803d3}},	//   _mee_, _رموز_, vkiv, auda
  { {0xb77a000b,0x6d4800b6,0x7c220864,0x290c01e3}},	//   _לאנש, buda, zbor, _yuda_
  { {0xd17900bc,0xea000020,0x703a0047,0x7c2d0daa}},	//   ості_, _khẩu_, йчас_, _fear
  { {0x7c2d1fb7,0x6d3a000b,0x442d0070,0xa6e20028}},	//   ðarl, _התקנ, _nee_, öðvu
  { {0x7c22006f,0x7cd2001e,0xb6a6003c,0xee3a065d}},	// [5060] vbor, pārb, пиал, йна_
  { {0xd37b000b,0xd7ef0003,0x9f4b000e,0x6b7b0009}},	//   _פריט, اكك_, émát_, _פרינ
  { {0x7c2d0036,0x6a9b0093,0x929b0093,0xe29b0093}},	//   _year, _השינ, _היית, _השיר
  { {0xdcb9002d,0x7e680002,0x75d30012,0x2a6a0031}},	//   ощі_, zedp, رينا, lebb_
  { {0x20070013,0x752f0002,0x3958001e,0x03a30001}},	//   ěnit_, ączy, ltrs_, ницо
  { {0x3f80007a,0x3ce60133,0xcb13000b,0x6d481fb8}},	//   _šiuo_, slov_, עלו_, yuda
  { {0x3958001e,0x60c01fb9,0xba570009,0x11d80012}},	//   ntrs_, timm, פסקו_, غوبة_
  { {0x6e2e00bd,0xfd57000b,0xb05b006f,0x25ae003a}},	//   _hebb, _משלי_, _hjär, ıklı_
  { {0xd6da0098,0xfbb60037,0x60c0004a,0xbb4300f5}},	//   йто_, _आइटम, rimm, _петк
  { {0x60c00006,0x442d0070,0x7b0b001e,0xa79b0009}},	//   simm, _zee_, _kļuv, משפח
  { {0x628800ec,0x6d480051,0x7e68179a,0xd6570009}},	//   _indo, uuda, redp, היית_
  { {0x7cff007a,0x0cab0014,0x629a01bd,0xc8b60012}},	//   _kūri, стои_, _hoto, _عصاب
  { {0x63a201e5,0xd7e3002d,0xe45f000e,0xf8b30009}},	//   nyon, _пішо, lnök_, _אשף_
  { {0x27e60101,0x7c2d002a,0x3ed40012,0x6ffb0009}},	//   _iyon_, _wear, _تقتر, _ההדפ
  { {0x7e750d6c,0xceb3000b,0x7c2d0f66,0x38690b45}},	//   _razp, _ריצ_, _tear, tear_
  { {0x25e00044,0x6abe008b,0x61e50145,0xc7b9000e}},	//   _कड़ी_, _empf, _vyhl, kből_
  { {0x4c3c000b,0xc43c000b,0x4cbc000b,0xb4d90037}},	// [5070] _התחב, _התחי, _לזהו, ़की_
  { {0x442d1fba,0xdbd7004a,0x9bf4003c,0x26de1fbb}},	//   _see_, rääm, _языч, noto_
  { {0xdbd70006,0x3869002a,0x26cc0017,0x6ce70024}},	//   sääm, pear_, indo_, піде
  { {0x26de0145,0x106b0003,0x7f440007,0x7d0e1fbc}},	//   hoto_, _احدى_, briq, _dubs
  { {0xb05b006f,0x6e2e00c1,0x69d800e2,0x442d0647}},	//   _fjär, _febb, _øver, _vee_
  { {0xc3340009,0x91e508d1,0x7dc70012,0x010b0009}},	//   גוס_, моле, _فتأك, ֖לֶּ
  { {0x27e60101,0x63a2002c,0xac19002d,0x442d00b9}},	//   _ayon_, ayon, _мову_, _tee_
  { {0x6aba0037,0x26cc18ec,0x645d0227,0x2a6a0031}},	//   _उग्र, endo_, jfsi, zebb_
  { {0x4f320012,0x2d981afb,0x7ead054f,0x73c40012}},	//   نفيذ, ären_, _núpc, _كيفم
  { {0xddc80f31,0x6d45086a,0x60cd0e00,0x629a1f54}},	//   cedū, orha, hnam, _goto
  { {0x8c46035b,0x60cd006f,0x02440012,0x5184004c}},	//   мене, knam, _أَمَ, _пуца
  { {0x89340003,0x4c83002d,0x98bc0073,0x26cc1fbd}},	//   _أعلا, влюв, tuvą_, ando_
  { {0x4e950003,0x68e90192,0xbbc80011,0x68fb005e}},	//   _يشتر, mled, रपेक, mmud
  { {0x68e9049a,0xda0d0037,0x2489093d,0xa6840024}},	//   lled, िखित_, _enam_, _плід
  { {0x2cad0005,0x09e3011f,0x63a2003a,0x91e31fbe}},	//   _oled_, ворн, zyon, воре
  { {0x20fa0044,0x2a6a000f,0x6e2e00c1,0xe4d60012}},	//   ्देश_, sebb_, _sebb, _تتتب
  { {0xdc8b000b,0x68e90033,0xba760012,0xc43b0009}},	// [5080] _וְיָ, iled, _قادت, _ותפי
  { {0x68e906bc,0x9e660003,0x290c0056,0x44380002}},	//   hled, بارن, ídas_, _śr_
  { {0x602604b3,0xd82601d4,0xd00a0829,0xad3a0024}},	//   _одна, _одни, _мене_, ючає_
  { {0xcd96000b,0x68e90058,0xc7b9000e,0x2eaa0011}},	//   ודעת_, jled, tből_, _छत्त
  { {0x41c30044,0xe3b20003,0x33c9000b,0x68e91899}},	//   _वेबस, خرا_, ּהוּ_, dled
  { {0x2ca6006f,0x93b7000b,0x68fb08e2,0xc7b90031}},	//   skod_, ולנו_, emud, rből_
  { {0x63a20827,0xde030146,0x68e9003a,0xc7b9000e}},	//   syon, _апри, fled, sből_
  { {0x68e90082,0x88bc0066,0xc953000b,0x55bb000b}},	//   gled, _hvěz, דמה_, _ומלו
  { {0x9346002d,0x940b0009,0x4f6a0024,0x44261fbf}},	//   _інже, _וּבֵ, ішим_, mbo_
  { {0xd6d9003e,0x62880132,0x61e90030,0x139b0009}},	//   kułu_, _undo, řeli, _ובמע
  { {0xfeb70003,0xc0aa0012,0x867b0009,0xfe780073}},	//   بايت_, _واصل_, קרטו, rdį_
  { {0xf537000b,0xe5710009,0xb4d90011,0xd6d90034}},	//   ונטי_, נַי_, ़के_, dułu_
  { {0x9be4002d,0x8ae7002d,0x43940015,0x78a3000d}},	//   вірк, дівл, ваяс, _învi
  { {0xc333000b,0xe7e20011,0x35d4003c,0x45d40217}},	//   כוש_, _खड़ा_, _полё, _полс
  { {0x44260101,0xc1e8027f,0x21090011,0x7c2d0097}},	//   kbo_, дьте_, वदेश_, ðark
  { {0x2d580108,0x60c4020d,0x60cd1fc0,0x6f0f1fc1}},	//   mée_, giim, unam, _pucc
  { {0x4426012e,0x2d580108,0x3cf80003,0x9f340024}},	// [5090] dbo_, lée_, _تعود_, кеті
  { {0x44260013,0x7c3b0028,0x63a00248,0x60cd1fc2}},	//   ebo_, ðurf, ämne, snam
  { {0x2d580108,0x60cd0070,0x68e9003a,0x7ea40054}},	//   née_, pnam, yled, _còpi
  { {0x6d5a0006,0x20c5001e,0xf9fa0009,0x61e10032}},	//   itta, rķis_, _מהתמ, üllu
  { {0x68e0001e,0xf8b60009,0xfc300012,0xab6b0012}},	//   domd, _נפשי_, شحن_, تحاق_
  { {0xfaa70055,0x68e91601,0x7e780159,0x61e812d8}},	//   ьшен, wled, _navp, _bydl
  { {0xc9a90015,0x68e91fc3,0xfa980009,0x38a7005e}},	//   явке_, tled, ודגש_, _nõrk_
  { {0x2d580061,0x85050012,0x7fca0011,0x2aad06dd}},	//   dée_, _أورن, ापूँ, ržby_
  { {0x41df0037,0x8e550024,0xfe710012,0x291e0248}},	//   _पुरस, нтні, هدد_, _etta_
  { {0xf1a700b3,0xef1f0051,0xf7720009,0x9ea90024}},	//   _орен, _mtü_, נקי_, ївна_
  { {0x2d580061,0xfde900b3,0xfbc90009,0x7d091fc4}},	//   gée_, ядок_, _פת_, _kies
  { {0x7c2d0065,0x30840012,0x397a0009,0xa0a4004c}},	//   ðarh, _للمف, _מטענ, _ишчл
  { {0x76550002,0x850b0037,0x60c40574,0x7d091fc5}},	//   _oczy, _संकट_, viim, _mies
  { {0x386d00bd,0x8f9a000b,0xd6d90002,0x6ee60028}},	//   leer_, _מיני, tułu_, fðbu
  { {0x2d580061,0x60c4019a,0x95550012,0xf8c90081}},	//   cée_, tiim, _أختا, hẩm_
  { {0x7d09003e,0x291e0039,0x386d1fc6,0xf7080081}},	//   _nies, īta_, neer_, _rủi_
  { {0x7cd2001e,0x291e001e,0x60c410dc,0x8f0a0012}},	// [50a0] lāro, ūta_, riim, سياق_
  { {0x386d0070,0x60c41fc7,0xddc300d9,0x9bb70009}},	//   heer_, siim, _manž, _נהיה_
  { {0x3abb0093,0x69c50066,0x6c7a0009,0xe47a0009}},	//   _זמינ, úhel, ּרְד, ּרְכ
  { {0x0c760003,0xfc320003,0x7d09047f,0xd91b0009}},	//   عداد, احا_, _cies, _מוטל
  { {0x7d09032b,0xb09b000b,0x81bc001e,0x26c50010}},	//   _dies, _זיכר, _neēr, kilo_
  { {0xc3330093,0x44320164,0x2d580061,0x6d5a0851}},	//   רוג_, _ley_, yée_, ytta
  { {0x26c50470,0x0446002d,0x7d091fc8,0x8cb00011}},	//   dilo_, _певн, _fies, ंसदो
  { {0x2d580108,0x0f26002d,0xa3c20037,0x386d0070}},	//   vée_, ньом, ्पा_, geer_
  { {0x26c501a2,0x68e30054,0x56c60014,0x3f8200d9}},	//   filo_, _índe, ещна, íku_
  { {0xc6f70047,0x0f57000b,0x2d580061,0x61e8006f}},	//   нных_, עיים_, tée_, _tydl
  { {0xceb30093,0x6d5a0006,0x386d00bd,0xa00a0003}},	//   רית_, utta, beer_, _فقال_
  { {0x2d580108,0xac19002d,0x61e4003a,0x38ba001e}},	//   rée_, ьому_, ğild, tūru_
  { {0x2d580108,0xdcf50002,0x7c2d0028,0x389b0009}},	//   sée_, _urzą, ðari, _מיאנ
  { {0xda100037,0x8d940003,0x2d580061,0x2d980623}},	//   ाशित_, _للتش, pée_, øres_
  { {0x62980070,0x6440083f,0x629e14f8,0x59db0011}},	//   ijvo, _odmi, _dopo, _मुखर
  { {0xed57000b,0x61e50032,0x73c50012,0x6b841fc9}},	//   _נבחר_, ühli, _ليعم, _frig
  { {0x84640098,0xa923007a,0xfc640014,0x8c3d0060}},	// [50b0] _съще, ąžin, _същн, _hoşg
  { {0x9f60000e,0x38600097,0x7ea00031,0x752d0034}},	//   ásán_, afir_, _söpr, _łazi
  { {0x7d091fca,0x15a80014,0xda480009,0xb2bc0009}},	//   _pies, нъци_, _אֲרָ, _ממזר
  { {0x85040003,0xf5370009,0x71880009,0x26c5064b}},	//   هولن, תנאי_, _נְתַ, zilo_
  { {0x7d090006,0x889a0093,0xa036000b,0x386d0070}},	//   _vies, _חברי, _בארה_, veer_
  { {0x76550002,0xd6e20002,0xaa94002d,0xf09f001a}},	//   _uczy, _całą_, личч, _hoà_
  { {0x26c50470,0xd1310003,0x7d0913be,0x82340003}},	//   vilo_, جمع_, _ties, ارها
  { {0x48090014,0x68ed0d38,0xb7f50011,0x61110035}},	//   мейн_, nlad, _आराम_, _jāli
  { {0x99910066,0x386d051c,0x44321fcb,0x290b1fcc}},	//   kazů_, reer_, _rey_, _mica_
  { {0x78a90006,0xc7a80003,0x68ed1fcd,0xfaf30012}},	//   skev, عديل_, hlad, _إثر_
  { {0x7ea00028,0x38600028,0x19ab003c,0xf2df004b}},	//   _möpp, yfir_, _этап_, trân_
  { {0x7cea0028,0x03a6028b,0x26c51fce,0x7f850012}},	//   týri, вимо, silo_, _للصن
  { {0xeb9705cc,0x7cf6000e,0x2d98038e,0x78a6006f}},	//   вия_, tárb, ører_, ökve
  { {0xc3320093,0x61e400a2,0xc7b9000e,0x7ae31535}},	//   שום_, şile, mző_, nont
  { {0xc7b9000e,0x6cda010c,0x68ed1fcf,0x91e60229}},	//   lző_, _офис_, flad, тове
  { {0x20550146,0x7a3f003a,0xdfd20012,0x00860048}},	//   лтур, _açtı, ليز_, ълбо
  { {0x38600028,0x290b1fd0,0xa4fb0009,0x673b0034}},	// [50c0] rfir_, _dica_, _קלפט, nsuj
  { {0x6d4b0002,0x673b008e,0x0e6a0012,0x248d01a0}},	//   ągan, isuj, بصري_, _anem_
  { {0x200f00c1,0x290b0017,0xbd8a0003,0xb91a0003}},	//   _oggi_, _fica_, بنان_, _تتخذ_
  { {0x673b19a3,0xdd8f0012,0x68ed052e,0x67241fd1}},	//   ksuj, توم_, clad, ppij
  { {0x7cf1006f,0xa803003a,0x68e4004a,0x64a30001}},	//   pårn, şırs, moid, јача
  { {0xe7370046,0x2900004a,0x248d009b,0x753c0066}},	//   _јер_, lmia_, _enem_, _tvrz
  { {0x244a0003,0xa9670001,0x867b0009,0x2167004c}},	//   _يجري_, вија_, _קרלו, вији_
  { {0xe45f004a,0x68e41fd2,0x89db0009,0x18740048}},	//   nnöt_, noid, וחצי, угия
  { {0xa0670046,0x2900004a,0xb50c0037,0x7ae31fd3}},	//   тања_, imia_, _संजय_, bont
  { {0x3c32008a,0x68e40051,0xd357000b,0x68ed003a}},	//   _được_, hoid, _בימי_, zlad
  { {0x2459002d,0x68e41fd4,0xf6530009,0xdcf50034}},	//   нань_, koid, בצת_, _arzę
  { {0x249f014d,0x68e4004a,0xbdf70012,0xc1570009}},	//   ðum_, joid, خرًا_, _ישבו_
  { {0x99910066,0x1867004c,0x53470048,0x2bfe0011}},	//   tazů_, _јачи_, ъхна, रेलू_
  { {0x35dd0037,0x63a00248,0x7ac7020f,0x29001fd5}},	//   _नुक़, ämna, тсме, emia_
  { {0xeef70093,0x1ea90003,0xda34003c,0x99910030}},	//   _שמור_, _ثاني_, ресы, razů_
  { {0x5597000b,0xb97b0009,0x397b0009,0x6d5d004b}},	//   _ידוע_, ונלי, וטלנ, ăsat
  { {0x44391fd6,0xdff5004c,0x57f50288,0xd7e70024}},	// [50d0] mas_, упањ, упат, тіво
  { {0xd51a0020,0xa3c20037,0xc275004c,0x68ed1fd7}},	//   _bằn, ्पर_, _слој, slad
  { {0xf09f001a,0x7ae311d1,0x20d50012,0x7cf60097}},	//   _toà_, vont, _مقدس, lára
  { {0x78b6007a,0x24190015,0x935900bb,0xac190400}},	//   chyv, ходы_, ерку_, ходу_
  { {0x7d0d003e,0xe3b00003,0xe5040037,0x44391fd8}},	//   _mias, يره_, रगति_, ias_
  { {0xddce000e,0x1308002d,0xeb900012,0x7ae3008e}},	//   _ebbő, вній_, تظم_, uont
  { {0xe5340015,0x99850012,0xceb20009,0x26020011}},	//   _весь, البو, _פיל_, वेदी_
  { {0x44391fd9,0x673b019a,0x28c60011,0xaf990048}},	//   jas_, tsuj, रोपि, етох_
  { {0xe50a0020,0x7ae31fda,0x7cf6000e,0xe45f004a}},	//   _mặt_, pont, jára, tiön_
  { {0x63a40006,0xc7b9000e,0x1ab70011,0x4ab70011}},	//   äine, rző_, _अतिथ, _अतिव
  { {0x3cca0098,0x7d0d00c6,0x60550003,0x31580003}},	//   елно_, _bias, _مناط, _لجنة_
  { {0x7d0d1fdb,0xf9920009,0xc5f20009,0xa3c20011}},	//   _cias, _לרב_, מדי_, ्पल_
  { {0x68e4004a,0xf74500ac,0x889a0009,0x9cd60009}},	//   void, _село, _רבני, רורה_
  { {0x9af60003,0x387f1fdc,0x6e3500d9,0x7f3a0009}},	//   اكست, ldur_, _nezb, _טענו
  { {0xa2c30037,0x44391fdd,0xa9670867,0xa06a00f5}},	//   रफ़्, bas_, лира_, нава_
  { {0xd51a0020,0x387f0065,0x2d5c02d1,0xa0b50001}},	//   _rằn, ndur_, víe_, аљуј
  { {0xa4fb0093,0xdcf50002,0x7e7c0beb,0x6e350c10}},	// [50e0] _אלקט, _urzę, _parp, _bezb
  { {0x7c360028,0x68e41fde,0x74dc0011,0x78b6008e}},	//   _heyr, soid, नवकृ, shyv
  { {0x7c360065,0x6e35000d,0xda5b0009,0x725b0009}},	//   _keyr, _dezb, _אכיל, _אכיפ
  { {0x6d5e1fdf,0x9ce50024,0xcea90009,0x60c91fe0}},	//   rtpa, аціл, הי_, jiem
  { {0x1394002d,0xebd6000b,0x04430294,0x7e7c0d66}},	//   рилю, נֵ֣י_, сечн, _tarp
  { {0x38b50119,0x44391fe1,0xbb770009,0x261a0011}},	//   _våre_, zas_, טענו_, मुखी_
  { {0xcd78000b,0x4d78000b,0x5d78000b,0xd578000b}},	//   _בְּכ, _בָּא, _בָּנ, _בָּר
  { {0xacea0003,0xd51a001a,0x3f860054,0x7c2d0028}},	//   _أرسل_, _gắn, _prou_, ðart
  { {0xdfd00003,0x04570012,0xf2560012,0x46a80011}},	//   تية_, _حلقة_, _مضاد, _गवाह
  { {0xba1a000a,0x78ad001e,0x7d0d00b6,0x7cf61356}},	//   _أيضا_, zkav, _sias, vára
  { {0xa926005c,0x8b030066,0x2d870027,0x7d0d1fe2}},	//   _сдел, ířen, _crne_, _pias
  { {0x7cf6000e,0xc19b000b,0xd5b70055,0x3f860025}},	//   tára, _רשאי, усь_, _trou_
  { {0x6e94002d,0x2d870058,0x291e0097,0x6d4d0073}},	//   _вилу, _erne_, ítan_, _įnaš
  { {0xdb24000e,0x5b14004c,0xbda60012,0x6d5d004b}},	//   ásáb, смрт, _محبو, ăsar
  { {0x2b4000f1,0x7cf6147c,0x44391fe3,0xc6930009}},	//   šich_, márn, pas_, _לאס_
  { {0xd4680001,0x6e3a05db,0x7cf60042,0x98b10034}},	//   _биће_, latb, lárn, kszą_
  { {0xb4b10037,0x98b10002,0x611c009b,0xd7940048}},	// [50f0] ओसी_, jszą_, _včla, битъ
  { {0x78a20051,0x7cea0028,0xba190003,0x60c90002}},	//   _loov, kýrs, _جيدا_, ziem
  { {0xd0110003,0x7ae70027,0xef1f0052,0x2d87029d}},	//   _ولد_, mojt, _grün_, íne_
  { {0x611c0027,0xe4e40024,0x9b450012,0x52dd0011}},	//   _učla, бічн, لنصو, यव्स
  { {0x2d9c0623,0x7cf601bd,0x883a0009,0xa8560009}},	//   øver_, kárn, _בתרו, _דירה_
  { {0xddda000f,0x46b90044,0xae040037,0x38a70051}},	//   hető, _इतिह, रधान_, _võru_
  { {0x7c2d0028,0x9ed80001,0x48b500fa,0x627c0009}},	//   ðars, _смрт_, ищит, גנונ
  { {0x6e3a001e,0xe1f00012,0x99830073,0xdb0a0064}},	//   eatb, أسه_, lajų_, ľném
  { {0xddda000e,0x387f003a,0xc87f0032,0x60c91fe4}},	//   dető, rdur_, _maß_, riem
  { {0x0ea90015,0x60c91fe5,0x5db50003,0x46f50001}},	//   ткой_, siem, لإجر, јчит
  { {0x7cd2001e,0x60c9001e,0xbca60003,0x7cfd000e}},	//   lāri, piem, لمدي, kérd
  { {0x16070037,0x2d87009b,0xfce6026d,0x6b890227}},	//   वेयर_, _vrne_, ромо, _kreg
  { {0x7cc4000f,0xa3e60037,0x7cd20035,0x5f160011}},	//   nőri, _बुश_, nāri, नदण्_
  { {0xceb80002,0x6d4b0002,0x76430040,0x6d5a0248}},	//   chę_, ągaj, _udny, _åtag
  { {0xa9060012,0x7d020073,0xe2a70097,0xe45f0248}},	//   لبرن, ymos, æðar_, rnör_
  { {0xdd2f0066,0x7f4d0018,0x600b0060,0x27110011}},	//   _běžn, fraq, _gömü, ़दूर_
  { {0xc87f008b,0x7cf60029,0xf092000b,0x6b890061}},	// [5100] _daß_, láro, חנן_, _nreg
  { {0x29f5001a,0x8b3b0009,0xabfb0009,0x27f200b0}},	//   _óa_, _שתיצ, _בהפר, _øyne_
  { {0x1d0a046d,0x7cf60042,0xed5a003c,0x98b10034}},	//   вежи_, náro, тое_, wszą_
  { {0x6e3a000e,0x61e8005e,0x63ab0040,0xab2a0d4e}},	//   zatb, üdlu, fygn, вода_
  { {0xf7460046,0x9377000a,0x43760015,0xe29a0001}},	//   _њего, لصور_, рует, кад_
  { {0x78a20005,0xddda000e,0x61e9003a,0x66f90037}},	//   _soov, zető, şele, ्गणक_
  { {0x90440003,0x74560014,0x7cf60ca4,0x29570012}},	//   منغه, _възх, járo, لشيخ_
  { {0x757b000b,0x7cf80066,0x98b10034,0x10a3004c}},	//   _בטלפ, bíra, pszą_, жићн
  { {0x7cfd0061,0x6e3a0033,0xddda000e,0x26020037}},	//   nére, tatb, vető, वेरी_
  { {0x290f071a,0x1be10011,0x27ef0248,0x6e8a004c}},	//   _eiga_, _गुगल_, _dygn_, тљив_
  { {0xd657000b,0xc4c70003,0x7cfd0e90,0x78a2005e}},	//   סיטת_, لتحو, hére, _toov
  { {0x6e3a001e,0xd12f0012,0x60d60034,0xe786004c}},	//   satb, _آمن_, jnym, _вуко
  { {0xe8d70093,0x889b000b,0x00bb000b,0x8c1b0009}},	//   _דואר_, _שבדי, _במאמ, כוכי
  { {0x7cfd0061,0xd00b0009,0x99d70012,0xc87f0032}},	//   dére, _בּוֹ, لتزا, _saß_
  { {0xe8950015,0x63ab0002,0x26cc0d85,0x38c70048}},	//   бавь, zygn, mido_, ащав
  { {0x7cfd0108,0x45b7000b,0x6d430159,0x290f054e}},	//   fére, _כפול_, šnak, öga_
  { {0xc2eb0003,0x85040012,0x7ae700d9,0x28c60011}},	// [5110] _لعدم_, _بوين, pojt, रोधि
  { {0x26cc0844,0x7cf80066,0x6ac40012,0x6e450012}},	//   nido_, víra, _وقيم, إنضم
  { {0x64150003,0xaadc0009,0x60d60034,0x27230064}},	//   مواط, _בחזר, bnym, očný_
  { {0x4095000a,0xed58002d,0x27230029,0x8c3d0060}},	//   _الحر, рої_, nčný_, _boşa
  { {0x290f00c1,0xfbd00012,0xe28e0472,0xcb690012}},	//   _riga_, وته_, па_, امته_
  { {0xe50a001a,0x60cd02b4,0xdb4e0012,0x0ae80024}},	//   _lặp_, liam, رَى_, адій_
  { {0x26cc060e,0x7cd2001e,0xd2b80009,0xda090012}},	//   dido_, sāri, שלות_, ديثه_
  { {0x3949015d,0x7cf6000e,0xf9900012,0x71d80009}},	//   čas_, váro, ببه_, יווד_
  { {0xb4e30037,0x290f0051,0x93b50001,0xf7710012}},	//   नकी_, _viga_, _убац, ساة_
  { {0x7cf6000f,0xe8e00020,0x66f90037,0x7c3b0028}},	//   táro, _đọc_, ्गिक_, ðurn
  { {0x60cd007a,0xd0110003,0x7d0a0001,0x290f06db}},	//   kiam, _فلا_, лног_, _tiga_
  { {0x443d002c,0x98b30066,0xe2a60028,0x62811a2f}},	//   naw_, ědět_, _öðru_, _halo
  { {0x26cc084f,0xd6d90002,0x628301bd,0x7cf6081b}},	//   bido_, asła_, odno, sáro
  { {0x26cc060e,0x539a0009,0x26c71fe6,0x7ff40012}},	//   cido_, אישו, _umno_, _بسما
  { {0xc212000b,0x443d1fe7,0x2d980248,0x60d602c9}},	//   להם_, kaw_, äret_, tnym
  { {0xe50a0020,0x60cd1fe8,0x7cfd0061,0x6281002c}},	//   _gặp_, giam, tére, _lalo
  { {0xddd5012e,0x98a300a6,0xcc570009,0x2e160012}},	// [5120] _razš, чите, _הספק_, مباح
  { {0x38b50163,0x6281048b,0xee370055,0xfbd30009}},	//   _våra_, _nalo, йну_, _מתח_
  { {0x9986000a,0x60cd01a2,0x4d4a00de,0x7cfd08c5}},	//   _الجو, biam, упен_, sére
  { {0x7cfd10b7,0x26cc0017,0x99980066,0x443d002c}},	//   mérc, zido_, larů_, gaw_
  { {0x78bb006f,0xe4e90012,0x44221fe9,0x62811fea}},	//   dhuv, جعله_, ick_, _balo
  { {0x6d411feb,0xd37b0009,0xfe670012,0xc3330009}},	//   ksla, טרנט, _عد_, לוד_
  { {0xae070037,0xda650003,0x26cc084c,0x7cd2001e}},	//   वेदन_, تاني, vido_, lāru
  { {0xa3b80044,0x39690009,0x93160012,0x6cd60012}},	//   चना_, ׁבוּ_, _هورش, _اقرا
  { {0xd7f00003,0xf09f001a,0x2fc00052,0x26cc01c5}},	//   بكة_, _giàu_, nzig_, tido_
  { {0x7cf6000e,0x87e30015,0x60cd1fec,0x6e3e16de}},	//   sárl, яюще, ziam, napb
  { {0xdc99002d,0x26cc01c5,0xa5f80538,0x1df8003c}},	//   авні_, rido_, рену_, рены_
  { {0xb97b000b,0x4f660003,0x6281106d,0x7aea1a90}},	//   _תנאי, _هاتف, _zalo, loft
  { {0x6111001e,0x2fc00070,0xd00f0012,0x6d411fed}},	//   _tālr, jzig_, _كلم_, asla
  { {0x60cd0034,0xdddc0030,0xf7d70009,0x7cf10fcc}},	//   wiam, _narů, _פוגש_, råri
  { {0x443d002c,0x60cd1fee,0x52d70009,0x291a02b8}},	//   yaw_, tiam, צולע_, _cupa_
  { {0x291a000d,0x50f50024,0x79ab0009,0xed570009}},	//   _dupa_, ізат, אֹמַ, _הבהר_
  { {0x7bda00a2,0x40340047,0x60cd1fef,0x2aab0040}},	// [5130] ştur, яетс, riam, _købt_
  { {0x765a1ff0,0xcb380009,0xc879004b,0xe6950012}},	//   ngty, _הנזק_, roşi_, غلاد
  { {0x7c240065,0x28c60037,0xdd910003,0x443d1ff1}},	//   _yfir, रोहि, بوا_, taw_
  { {0xb4e30037,0x93f50024,0xe7b80011,0xe4e40024}},	//   नके_, опец, इनाप, пічн
  { {0x20d3000d,0xfd100003,0xeb990c1e,0xfaa506fd}},	//   nţie_, رجم_, рил_, жало
  { {0x2b440004,0xd3580009,0x672d001b,0x38690442}},	//   ámci_, מידי_, mpaj, lfar_
  { {0xaa560046,0xce68002d,0x4422006f,0x4a5c0009}},	//   цију_, _уряд_, yck_, אדוו
  { {0xd0fb0044,0x6b8d1ff2,0x6d411ff3,0x7c2200ba}},	//   ्षिण_, _orag, vsla, ccor
  { {0xdbf20066,0xef160015,0xcb340014,0x62811ff4}},	//   _přír, омы_, _нетъ, _talo
  { {0x7c3b0108,0x6d411de8,0x78bb1ff5,0x75450d21}},	//   _heur, tsla, shuv, оноз
  { {0x7cd20039,0x6d41007a,0xf652000b,0xa2af0011}},	//   kārt, usla, וצי_, ुसन्
  { {0xca29000b,0x240a0014,0x71880009,0x25be005e}},	//   _ים_, инни_, _לְנַ, _ütle_
  { {0x7c3b1ff6,0xbec3001e,0x43fa0024,0xe7390aa2}},	//   _meur, _ķīni, рхня_, _тел_
  { {0x7c3b0108,0x6d411ff7,0x6b8d1ff8,0xe71600af}},	//   _leur, psla, _drag, _וחסר_
  { {0xed5906e0,0x78a604d2,0xa3d50011,0x8cc60012}},	//   _той_, _pokv, ाऊँ_, _وقته
  { {0xb4e30037,0x382a004c,0x7aea0031,0x7cf60031}},	//   नको_, ржао_, zoft, zárj
  { {0x20d3007d,0x3ea70002,0x37870024,0x7c650012}},	// [5140] cţie_, _kont_, обто_, _رايل
  { {0x7cfd0061,0x2fc00032,0x61271ff9,0x61e9004b}},	//   méra, rzig_, _kıld, şela
  { {0x6eef0058,0x186a0048,0x7cfd0025,0x3ea71ffa}},	//   løbs, _кани_, léra, _mont_
  { {0x39580039,0x6ef00006,0x61fe0130,0x01fb0009}},	//   murs_, väbu, _izpl, _כפיל
  { {0x7cfd0108,0xaae60003,0x6e29003a,0x7c221ffb}},	//   néra, يستو, _şebe, rcor
  { {0x7cf80042,0x39580573,0x599a0009,0x6e960012}},	//   píro, ours_, ֹשֵׁ, _بلسا
  { {0x307a0012,0xdb1d0031,0x7cfd0025,0xbdf400af}},	//   لحظة_, rzsé, héra, _זֶּה_
  { {0xddd80107,0xc2130009,0xdb1d0031,0x6eef0040}},	//   _navš, והו_, szsé, købs
  { {0xd6da0098,0x629e0006,0xd7fa007c,0x4fd40015}},	//   ито_, öpos, шук_, яжит
  { {0x3ea7007d,0x7cfd0061,0xd37b0009,0x1996004c}},	//   _cont_, déra, _דרמט, _мјер
  { {0x3ea70108,0x69150013,0xac19002d,0x6b8d00b6}},	//   _dont_, _všec, йону_, _srag
  { {0xef1f0052,0x7cfd0025,0xdfa60012,0x39581ffc}},	//   _früh_, féra, _وحشي, durs_
  { {0x39580061,0x2bc50321,0x97c60012,0xba770012}},	//   eurs_, _लेखा, _بتضم, ياست
  { {0x6b8d00bd,0xd6d90002,0x7d1c0bb5,0x20d3004b}},	//   _vrag, kuły_, _ours, rţie_
  { {0xcd330003,0xca140014,0x8c3d003a,0x39580054}},	//   _قريب, ддръ, _boşl, gurs_
  { {0x7cfd0061,0x9c390001,0x20d3000d,0xa3e60011}},	//   béra, _упит_, pţie_, _बुक_
  { {0x6e3c00c6,0xec38000b,0x200f0051,0x907b0009}},	// [5150] _berb, _ואחר_, ägi_, סטמי
  { {0x7c3b0006,0xe8010037,0xdef10003,0x6127003a}},	//   _seur, लेगा_, رًا_, _yıld
  { {0x7cd2001e,0x9c190003,0xd6d90002,0xe5f50012}},	//   pārt, مياء_, guły_, أكاد
  { {0x7c940001,0x7e7702f1,0x6aba1ffd,0x859b0009}},	//   дршц, sexp, _altf, ישבו
  { {0x7c3b03eb,0x889a0093,0x62850101,0x2418002d}},	//   _veur, _הברי, _kaho, цією_
  { {0x337c000b,0x2909004a,0x68ed1ffe,0x6e3c1fff}},	//   שְׁב, lmaa_, load, _gerb
  { {0x314b0009,0xb2bc0009,0xe4530012,0x3abc0009}},	//   ׁתַּ, שמור, _يضر_, שמונ
  { {0x3ea70108,0x61dc0009,0xbf590024,0x6e3c2000}},	//   _sont_, יקוד, брої_, _zerb
  { {0x27200020,0x6d452001,0x2d9e2002,0x3ea72003}},	//   _còn_, lsha, exte_, _pont_
  { {0x7cf60017,0x645d098f,0x4ffa0009,0x628506c6}},	//   mári, egsi, מִינ, _naho
  { {0x3ea70061,0x6e250052,0x7cf62004,0xaea80012}},	//   _vont_, ichb, lári, تطيل_
  { {0x01fa0093,0x7f440061,0x7cfd0061,0x7cff0010}},	//   _הפעל, ysiq, téra, _kūry
  { {0x2720001a,0x5695002d,0x99870010,0x7cf62005}},	//   _gòn_, _надт, panų_, nári
  { {0x0cb80037,0x1e84002d,0x6ec40003,0xdd01001e}},	//   _आत्म, _олім, _يتوق, ītāj
  { {0x69c3000e,0xa6e10028,0xdddc000d,0xa50a0867}},	//   nzne, öðud, _marţ, _лека_
  { {0xe4c90003,0x7cfd2006,0x6e3c1759,0xc72602ad}},	//   _وبين_, péra, _serb, здай
  { {0x6e3c00c6,0xe5050003,0x7d1c0203,0xef170f09}},	// [5160] _perb, _تبوي, _surs, зму_
  { {0x1fb5007c,0x7d1c002a,0x24840051,0x7cd2001e}},	//   єстр, _purs, _samm_, pārs
  { {0xc27b0093,0x7f440061,0x6e3c0518,0xf2370009}},	//   _פרטי, ssiq, _verb, _מריץ_
  { {0x0457000a,0x6e3c0052,0x351a000b,0x628503ca}},	//   كلمة_, _werb, צוננ, _zaho
  { {0xd0f90044,0x33f6000a,0x6e3c00c6,0xd1380002}},	//   ंतरण_, أساس, _terb, _swą_
  { {0x66c00163,0x7d1c0027,0xdb23000e,0x78a4013a}},	//   _sökf, _turs, írál, ljiv
  { {0x7c3b0028,0x6f1d0052,0x76412007,0x9fb50030}},	//   ðurk, _zusc, daly, _dřív_
  { {0x8ddb0093,0x4ddb000b,0x78a40027,0x5f940014}},	//   _הקלק, _החלו, njiv, диит
  { {0x442603d8,0x2ca92008,0x7cf60018,0xb89b0009}},	//   mco_, _road_, cári, מבקש
  { {0x35b40686,0x7d04005e,0xa3a50030,0xd1380034}},	//   дбор, _ahis, jářů_, _twą_
  { {0x69c3003e,0x645a0010,0x62851f40,0x828b0009}},	//   czne, ėtin, _raho, _לְאֶ
  { {0x79b7000b,0x4dfb0009,0xa3d50024,0x2eb90011}},	//   _מלבד_, מפיא, домч, _इत्त
  { {0x9f59003a,0x62852009,0x68e31606,0x68ed0018}},	//   üyük_, _paho, _índi, voad
  { {0x764a0058,0xf77f0060,0xb05b0032,0x62870031}},	//   _udfy, ççe_, _kläg, udjo
  { {0x291e00c6,0x6f1d200a,0x645d020d,0x2ca9200b}},	//   _juta_, _susc, pgsi, _toad_
  { {0x9ddb0093,0xe8b5003a,0x7cfd0061,0x6d5a200c}},	//   _לקוח, _dışı, méro, muta
  { {0x20d3000d,0x291e200d,0x442603fe,0x6d5a200e}},	// [5170] nţia_, _luta_, dco_, luta
  { {0x7ed70003,0x4ed4002d,0x6e250052,0x290900ff}},	//   أزرا, нюєт, uchb, smaa_
  { {0xf5790003,0x6e250168,0x8d790012,0x7cfd1d4b}},	//   تماع_, rchb, تماء_, néro
  { {0x7cf6200f,0x7c3b0028,0x6e250032,0x257e0030}},	//   tári, ðurh, schb, _důl_
  { {0x68e40026,0x2d9c006f,0x9f890070,0xdddc000d}},	//   čidl, äver_, _vóór_, _parţ
  { {0xdb06000f,0x7cf60900,0x179a0009,0x8f9a0009}},	//   szkö, rári, _וישב, _וישי
  { {0x6d5a044f,0x76410010,0x644d07bd,0x7cf62010}},	//   juta, valy, _odai, sári
  { {0x44262011,0x291e1074,0x6d5a1a10,0x7cf10623}},	//   cco_, _duta_, duta, rårs
  { {0x76410101,0xf708001a,0x69c3000e,0x7cfd000e}},	//   taly, _hủy_, szne, térn
  { {0x443f03eb,0x38bc0066,0xab5b0032,0x979c0009}},	//   _heu_, _míra_, tzün, משחק
  { {0x20d3000d,0xb05b006f,0x6d5a2012,0x1d0a0103}},	//   aţia_, _kläd, guta, жени_
  { {0x443f0061,0xc1040012,0xb6050159,0x3f8f090a}},	//   _jeu_, _كولي, _rušč, _trgu_
  { {0xaca30020,0x20d3000d,0xab5b000e,0x3f83001e}},	//   _chỉn, cţia_, szün, ājus_
  { {0xb605009b,0x7d042013,0x6d5a2014,0x66c01452}},	//   _pušč, _whis, buta, _köke
  { {0xa1870001,0x6d55000e,0x3f8d0017,0xd946003c}},	//   мбра_, ázad, lveu_, ьеви
  { {0xdddc007a,0xc5f2000b,0x6aa10028,0xe8fa002d}},	//   _narš, _שדה_, ölfr, іла_
  { {0x2ab40005,0x4de60037,0x26d30017,0xa4850012}},	// [5180] _läbi_, _जुड़े_, fixo_, _سجين
  { {0xb6050010,0x257e0066,0x61e4003a,0x5b570009}},	//   _tušč, _půl_, şili, _קייב_
  { {0x64490065,0x729b000b,0xd5b20003,0xb05b006f}},	//   ðeig, _וסיס, خفض_, _bläd
  { {0x386d0227,0x77690248,0x66c00248,0x291e2015}},	//   jfer_, ktex, _sökd, _ruta_
  { {0x937a0003,0x7c3b0028,0x291e000d,0x8c431504}},	//   تصار_, ðuri, _suta_, тече
  { {0x291e0027,0x7bc6009b,0x38600028,0xd1300012}},	//   _puta_, izku, lgir_, همت_
  { {0x443f02be,0xa1270003,0xe2a70028,0x2d910034}},	//   _feu_, وكول_, æðir_, _grze_
  { {0x6b84001c,0x6d5a035f,0x52bb03bf,0x2c860010}},	//   _osig, vuta, _उत्स, _būdų_
  { {0xc7c60015,0x44291594,0xc7d80024,0x4fc6003c}},	//   ьски, _rfa_, ямих_, ьска
  { {0xad660003,0xc6f7003c,0x7cfd0025,0x7ead0064}},	//   واجه, мных_, téro, _súpr
  { {0x6b842016,0x867b000b,0x52d7000b,0x6d5a004a}},	//   _asig, חריו, _קובע_, uuta
  { {0x40930003,0xb8930003,0x20d3000d,0x6d5a2017}},	//   _للمر, _للمع, pţia_, ruta
  { {0x6d5a03fb,0x644000c6,0x764e047f,0xc7b60012}},	//   suta, _memi, _odby, _تصاع
  { {0x20d3000d,0x7cfd0061,0x6ffb0009,0xdd900012}},	//   nţin_, péro, _והדפ, _موت_
  { {0xaf07000a,0x2906001a,0x6127003a,0x6b8400c1}},	//   _تقوم_, _khoa_, _kıla, _esig
  { {0xd7880020,0x38600028,0xaca3001a,0xceb807ff}},	//   _kể_, ggir_, _thỉn, lkę_
  { {0xa635002d,0xe7190012,0xa2950024,0xc43c0009}},	// [5190] ензі, سيات_, _запі, _ותחי
  { {0x443f2018,0x2724003a,0x7cfd000e,0xceb809bb}},	//   _seu_, _dön_, zérl, nkę_
  { {0x443f01f2,0x7c290052,0xdd120060,0xb05b0d4c}},	//   _peu_, _pfer, nüşl, _pläd
  { {0x81b60009,0x8c250012,0x38b10031,0xef1f0060}},	//   _נהרג_, رفته, _járt_, _brüt_
  { {0x66c0006f,0xd7e7002d,0xdfc60003,0x443f0f4c}},	//   _söke, _ціно, _إي_, _veu_
  { {0xf8bf0028,0xc3340009,0x93b80009,0xa2940024}},	//   _hlé_, דוס_, ולדו_, качі
  { {0x62880149,0x443f08cc,0xceb80002,0x04670024}},	//   _dado, _teu_, dkę_, _отам
  { {0x248900bd,0x691501e9,0x26de2019,0x6440201a}},	//   _naam_, _všeo, ento_, _gemi
  { {0x6d4a013f,0x386d0b04,0x2d980675,0xb2750451}},	//   _avfa, rfer_, åren_, _плаш
  { {0xd7060047,0x29190005,0x7cfd000e,0x7ce8003a}},	//   нные_, _lisa_, sérl, zırd
  { {0xab5b000f,0x386d0052,0x8d750003,0x3f820028}},	//   szül, pfer_, رادا, ækur_
  { {0x26050011,0x6288201b,0x7cf60031,0xe3a70012}},	//   हेगी_, _zado, járt, هر_
  { {0x2bba0012,0xe3b7003c,0x68fb0060,0x2cad0227}},	//   ساحة_, ебя_, mlud, _moed_
  { {0xc3320093,0x6d480058,0x57560009,0x7fd60009}},	//   רום_, bsda, _נבצע_, _אונס_
  { {0x291900ec,0x11d5002d,0x7ce8003a,0xf652000b}},	//   _bisa_, вітр, tırd, _עצה_
  { {0xf8bf0061,0x3ce90011,0xadd60009,0x68fb0060}},	//   _clé_, टकों_, _רוקח_, nlud
  { {0x64460e9e,0x27e60061,0x3860201c,0x4f660012}},	// [51a0] maki, çon_, rgir_, عارف
  { {0x644605cf,0x66c0006f,0xf8bf000e,0x97a80009}},	//   laki, _sökb, _elé_, וֹעֵ
  { {0x644000c6,0xd23b000b,0x05760003,0x38600033}},	//   _pemi, _מגיל, عائد, pgir_
  { {0x0b460198,0x8fa60dd5,0x6446201d,0xceb80034}},	//   ендн, _заме, naki, zkę_
  { {0x6288201e,0x501b000b,0x7cf60029,0x9cd70009}},	//   _pado, _מוכו, lárs, עונה_
  { {0x764e0058,0x20d3004b,0xe986004c,0x6446201f}},	//   _udby, uţin_, ећин, haki
  { {0x644618f0,0x20d3000d,0x62882020,0x87070024}},	//   kaki, rţin_, _vado, _черв_
  { {0xc9530093,0x2cad0070,0x7d030070,0x7e7e0154}},	//   אמה_, _goed_, ïnst, lepp
  { {0xceb80002,0x644614bb,0x6d5e2021,0xdfd00012}},	//   tkę_, daki, lupa, شيد_
  { {0x8c3d000d,0x26de2022,0xc7b30009,0x7cf60366}},	//   _roşi, unto_, טבח_, kárs
  { {0xceb80002,0x6d480010,0x7cf62023,0x7529009b}},	//   rkę_, usda, járs, _čezk
  { {0x27e60002,0x7cf60029,0xa4d5002d,0xdd12003a}},	//   żony_, dárs, томі, rüşl
  { {0x2ab4005e,0x6d480032,0xceb80034,0x38b10031}},	//   _läbu_, ssda, pkę_, _várt_
  { {0x291900b6,0x6d480033,0x8f9b0009,0xaca30081}},	//   _sisa_, psda, _מידי, _phịn
  { {0xa2b30037,0xd0d50048,0x6466008e,0x98b30159}},	//   _अवस्, вовъ, ätiö, žeče_
  { {0xd5fb0093,0x6d5e00c6,0x8dfb0009,0xb5fb0009}},	//   _מפור, dupa, _מהות, _מלוכ
  { {0x3f860013,0xf1b9001e,0x29190f3c,0x44392024}},	// [51b0] _jsou_, ņš_, _visa_, mbs_
  { {0xdd950047,0x65950ec6,0x35e70055,0x98140012}},	//   казы, казу, нцев, طبقا
  { {0xd657000b,0xe2a70028,0x96b80012,0xfeb80012}},	//   תיבת_, æður_, راكز_, راكت_
  { {0x95540012,0x53350048,0x60c42025,0xec1500ae}},	//   اخلا, ведт, chim, نواد
  { {0xeaae02ac,0x53b30037,0x7cfd01c4,0xbc180024}},	//   ай_, ुनिश, eérk, ніші_
  { {0x6d5e00c6,0x69150066,0xb05b031d,0xbb3c0009}},	//   bupa, _všem, _fläc, לעדי
  { {0x7cfd000e,0x2b4d0066,0x6446010a,0xb8650012}},	//   gérk, šech_, yaki, ناظو
  { {0x29190248,0x68fb005e,0x319c0009,0x23d20011}},	//   ösa_, ulud, לבונ, _देवद
  { {0x69dc0028,0x24800051,0xb6a50024,0xb0f60012}},	//   _þren, õime_, випл, خفيض_
  { {0xf772000b,0xa6950001,0x7cfd000e,0x7c2d2026}},	//   סקי_, триј, lérh, _afar
  { {0xc692000b,0x89370012,0x64462027,0x69d10011}},	//   באי_, _أعطا, taki, _डेली
  { {0x89340351,0x7d090032,0x7f7519fc,0x90450012}},	//   _إعلا, _jhes, _аукц, _شنته
  { {0x387f2028,0xe6950012,0xd6b50012,0x5e950012}},	//   meur_, _للإد, _لإثب, _للإط
  { {0x4804007c,0x387f099b,0xfbd2000b,0x7cf6000e}},	//   _спів, leur_, שתך_, társ
  { {0x64460101,0xf9870003,0xf09f001a,0xaa430055}},	//   paki, جب_, _chào_, ресл
  { {0x8c3d00a2,0xe0da007c,0x6d5e004a,0x78a92029}},	//   _koşu, єва_, vupa, njev
  { {0x7643202a,0x4393004c,0xf7460430,0x60c4016d}},	// [51c0] _keny, _вањс, тезо, rhim
  { {0xc7af0012,0x39a40024,0x387f12f3,0x68e40064}},	//   غّل_, _блоґ, heur_, čidi
  { {0x2b4d02b5,0xdb1d000e,0x7643202b,0x78bb00ff}},	//   _avec_, özöt, _meny, kkuv
  { {0x6d5e202c,0xdb090066,0xdd8f0012,0xa3bd0011}},	//   rupa, ěnýc, غون_, ँईं_
  { {0xdb0f0066,0x2bd20037,0x7d1b00b6,0x387f101c}},	//   zycí, _देशा, _dius, deur_
  { {0x62630046,0xda630001,0xe6120012,0x3866004b}},	//   авља, ављи, _نشأ_, _scor_
  { {0x67220006,0xe2970001,0x6df60003,0x32db0009}},	//   _suoj, тај_, _شكرا, וחסנ
  { {0x6b960002,0x6603000e,0x61fa119d,0x7d1b03c1}},	//   _oryg, ünke, _vytl, _gius
  { {0xaca3001a,0x6f1c202d,0x76430260,0x8c3d004b}},	//   _giốn, _kirc, _beny, _coşu
  { {0xf76f0012,0x38b50248,0x66c0008e,0x7cfd202e}},	//   زاً_, _hårt_, _yöka, méri
  { {0x61e4003a,0x865b000b,0xa4d90001,0x7c2d0052}},	//   ğils, ודיי, едну_, _pfar
  { {0xc5f3000b,0xcb350014,0xb80a0003,0x7cf801bd}},	//   ידת_, лемъ, _قيام_, píru
  { {0xde58002d,0x7cf6000e,0x9f530024,0x3f860018}},	//   _залі_, tárr, _ввіч, _usou_
  { {0x752301a2,0x26c50029,0x3f8f0028,0xf4130009}},	//   _funz, chlo_, ægum_, יפר_
  { {0x7c3b0065,0xddc80002,0xb9250003,0xdcc20011}},	//   ðurs, nedż, افري, लसाज़
  { {0x6f1c002a,0xa617000b,0x6b961f24,0x629c0097}},	//   _airc, _בקוד_, _fryg, _órof
  { {0x7d1b01a2,0x66c0006f,0x7ff40012,0x8c3d004b}},	// [51d0] _rius, _söka, لسكا, _moşt
  { {0xfe70000a,0x539a000b,0x97570009,0xcddb004c}},	//   قدم_, _ניתו, כימו_, мње_
  { {0x5dd50003,0x7cfd000e,0x7af50066,0x387f0025}},	//   دقائ, térh, mozt, yeur_
  { {0x8c3d000d,0x6d5a18c7,0x7cfd202f,0xcd040024}},	//   _noşt, irta, féri, аччи
  { {0x387f0061,0x42d5002d,0x6d5a0032,0x785e004b}},	//   veur_, ліку, hrta, săvâ
  { {0x691503ec,0x6d5801bd,0x1634003c,0xda650048}},	//   _išei, ávac, _веря, увки
  { {0xfa78015a,0x7d090036,0x387f0106,0x764300b6}},	//   דעות_, _thes, teur_, _reny
  { {0x7af5000e,0x25c50060,0x76432030,0x7cfd2031}},	//   hozt, ıslı_, _seny, béri
  { {0x764300c6,0x387f0108,0x63a4004a,0x7af5000e}},	//   _peny, reur_, äint, kozt
  { {0xb7bd007d,0x6b890051,0x6127003a,0x05a90015}},	//   ncţi, _iseg, _yıll, евой_
  { {0x04460094,0xd46a0001,0x8db5002d,0x387f0025}},	//   ленн, нине_, успі, peur_
  { {0x3f4f0039,0xfbc70012,0xc7950012,0x8d760009}},	//   kļu_, مت_, _مشتب, נגרו_
  { {0xa2b90044,0x765c003e,0xe918007c,0x20240026}},	//   ्सप्, óryc, _році_, ásiť_
  { {0x7cc4000f,0x7bda0009,0x7af50031,0x7eb20040}},	//   nőrz, תקשו, gozt, _næpp
  { {0x27290065,0x41b50014,0x11da0003,0xb9b50014}},	//   _hún_, астт, رورة_, астъ
  { {0x6b962032,0xdfd20003,0x291d00b6,0xbc660014}},	//   _tryg, ميز_, _jiwa_, _свик
  { {0x3f4f001e,0x69150030,0x27292033,0x6f1c0270}},	// [51e0] gļu_, _všeh, _jún_, _pirc
  { {0x8c1b000b,0xe5a6004d,0xbc1b0009,0x67360073}},	//   _אופי, лизи, _אופש, rpyj
  { {0x6b8902d1,0xe45a096e,0x13170009,0xfd96003c}},	//   _aseg, еже_, _תחיל_, ышаю
  { {0x9b6a011f,0x1b4a0867,0x18a60021,0x136a0103}},	//   ешка_, езди_, _самм, ешки_
  { {0x38b51204,0x7cdc0159,0x33c90009,0x2d870040}},	//   _vårt_, dčrt, ֻהוּ_, æner_
  { {0x61fe0070,0x7cc4000e,0x29002034,0xa5460012}},	//   üplo, gőrz, llia_, _مضرو
  { {0x6b8901a2,0x8c3d007d,0x3d340093,0x27290164}},	//   _eseg, _poşt, _כָּל_, _aún_
  { {0x7cfd0cda,0x045a0003,0x8c79003c,0x17540048}},	//   péri, _سلطة_, _ищут_, авия
  { {0x2900004a,0xf8b30009,0x2bc60011,0x291d020d}},	//   ilia_, משה_, रैमा, _diwa_
  { {0x65740001,0x6b7b000b,0x4d98002d,0x7cdc0159}},	//   агођ, _ארמנ, вкою_, ačrt
  { {0x2b910026,0xd6db000b,0x76480002,0x656103f0}},	//   _môcť_, תחיל, rady, gulh
  { {0x703a0003,0x7ce8003a,0x7648002c,0x26d90025}},	//   _أساس_, tıra, sady, ésor_
  { {0x7af5000f,0xf09f001a,0xda7b00b3,0x9cd70009}},	//   tozt, _giày_, няв_, רוכה_
  { {0x66c00163,0x3d94002d,0x68e4003a,0x248d163a}},	//   _sökn, _викр, enid, žem_
  { {0x6234002d,0x7af50031,0x6d5c0031,0x63b90034}},	//   сесу, rozt, árad, zywn
  { {0x290001a2,0x61fe0002,0x383516e6,0x58d40217}},	//   glia_, _dypl, рнар, бост
  { {0xe8940015,0x7d0d008e,0x7ae30097,0xcb68004c}},	// [51f0] щать, _ihas, ynnt, _бање_
  { {0xaca3001a,0x68e4005e,0x248d0018,0x29002035}},	//   _phỏn, anid, _saem_, alia_
  { {0x66c00248,0x7d0d2036,0x9e0708ed,0x29002037}},	//   _tökn, _khas, учал, blia_
  { {0x63b9003e,0x3c470003,0x6fd00037,0x94190012}},	//   tywn, اضاف, _सेकं, نقاذ_
  { {0x2d98000f,0x20c70051,0x90980232,0xfd100012}},	//   _erre_, _võid_, _свят_, أجل_
  { {0x39550001,0xa6e20028,0x78ad2038,0x24430081}},	//   ањит, öðlu, ljav, ằm_
  { {0x6115007a,0x78ad013a,0xd2b80009,0x63b90034}},	//   _sąly, ojav, רלות_, sywn
  { {0x22450070,0x78ad013a,0x7f850012,0x53c60011}},	//   _welk_, njav, للبن, रैडश
  { {0x20190006,0x29030039,0x644b2039,0x20d3000d}},	//   äsi_, ēja_, magi, nţii_
  { {0x681b0039,0x64490028,0x98a70010,0x644b1980}},	//   _rādī, ðein, psnį_, lagi
  { {0x27e00065,0xdb1f005e,0x81c30035,0x82a4004c}},	//   _þinn_, övõt, šēji, _уште
  { {0xcb09000b,0xcdf60009,0x19560009,0x7d0d1e7f}},	//   _חל_, ימתי_, _כבעל_, _chas
  { {0x76550002,0xb05b0032,0x3ceb03a7,0xee2e042a}},	//   _odzy, _plän, _živé_, _мн_
  { {0xfc03002d,0xfc16000b,0x78ad009b,0xe8080024}},	//   іпро, יקרי_, ejav, _снід_
  { {0x66c001ab,0xa3e20321,0xd8260048,0xe297004c}},	//   _söko, _दशक_, идви, јас_
  { {0x91e3002d,0x60c9004a,0x61fe014a,0x2167004c}},	//   іоте, nhem, _vypl, јити_
  { {0x34fb000b,0x38b8000e,0x3cfb0009,0xacfb0009}},	// [5200] _בהקד, _iért_, _שלפנ, _שהפכ
  { {0xfd4c0020,0xdcf90066,0x539b0009,0x62831740}},	//   _nhiệ, _osvě, _ייפו, jeno
  { {0x4a5b000b,0x38b8000e,0x92e90003,0x5d6a0015}},	//   _בדיו, _kért_, _حريق_, тием_
  { {0x6e2d203a,0xcea90009,0x644b203b,0xb42500ae}},	//   _şabl, וי_, gagi, معهو
  { {0x20d3000d,0x883b000b,0xab940024,0xc4770009}},	//   cţii_, _בתכו, силі, שתנו_
  { {0xd9540003,0xb05b004a,0x6283203c,0xb2370012}},	//   منتخ, _yläo, geno, لكها_
  { {0x644b00c6,0x41b40003,0x27e0004b,0x69ce203d}},	//   bagi, إمبر, _ţin_, nzbe
  { {0x7cfd0031,0x99970048,0xfce6203e,0x644b09b8}},	//   nért, ркът_, _тобо, cagi
  { {0xc6f80001,0x7cfd0031,0x232a0365,0x61270060}},	//   лних_, iért, _рози_, _yılk
  { {0x62330046,0xd0070001,0x78ad07a5,0x5976003c}},	//   _међу, шење_, zjav, _выду
  { {0x0697000b,0x7d02000d,0x7cfd000e,0x95ca011d}},	//   בדים_, olos, kért, тупа_
  { {0x7d020052,0x66c0006f,0x89db0009,0x5ce40012}},	//   nlos, _sökl, _בחבי, ْكَل
  { {0x82f70012,0x7e6b008e,0xdee6169b,0x69ce001b}},	//   لأسئ, ämpö, _коди, ezbe
  { {0x7d02008b,0x1dc60011,0xd63a0024,0x7ce80060}},	//   hlos, लनात, _ряді_, lırl
  { {0x2e37000b,0xa2a70011,0x7d02203f,0x225e0034}},	//   _דרוש_, चात्, klos, ótka_
  { {0xcf27000a,0x7ce800a2,0xa8a40001,0x7cfd000e}},	//   لرئي, nırl, орук, gért
  { {0x2f0b0058,0x3ce6009b,0x6d580004,0x78ad2040}},	// [5210] søge_, dnov_, ávan, rjav
  { {0x20d3000d,0x93fc000b,0xd5bb00bb,0x6b8d2041}},	//   rţii_, _בלחי, ксе_, _isag
  { {0x63bd0e46,0x20c70005,0xb9950003,0x51950012}},	//   lysn, _võib_, _الجب, _الجذ
  { {0xfbd30003,0x20d3000d,0xc19a0009,0xa3550012}},	//   يتش_, pţii_, _עשרי, مختص
  { {0x7ce8003a,0xe4580024,0x799a0132,0x69de0064}},	//   dırl, ржі_, _artw, úpen
  { {0x8c1c0009,0x6b5e0097,0x644b2042,0x7d02079f}},	//   דודי, _hægð, sagi, alos
  { {0x644b00bd,0xfc670014,0x7ce8003a,0x7d020225}},	//   pagi, _възн, fırl, blos
  { {0x38692043,0x62832044,0xfc300003,0xb05b006f}},	//   ngar_, seno, _يحق_, _oläm
  { {0xfd4c0020,0xcb340048,0x60db2045,0x3f990097}},	//   _thiệ, _метъ, rium, ísu_
  { {0x20e8003a,0x38b80028,0xe57f001e,0xaab40012}},	//   eğil_, _sért_, šķus_, _وصلت
  { {0x2fcd000f,0xa294002d,0x7ce80060,0x200a0034}},	//   szeg_, _фахі, bırl, ębia_
  { {0xf41f004a,0x6b9b2046,0xed560024,0xdd7a0009}},	//   ydät_, _krug, щою_, נטרל
  { {0x66c0006f,0xd7770003,0xf8b20009,0x80a40011}},	//   _sökm, _خاضع, _משא_, कारे
  { {0x38690065,0x69ce0052,0xa3af0321,0x78a22047}},	//   egar_, tzbe, _ओपन_, _znov
  { {0xcd35000a,0xb05b004a,0xfe360009,0x5ed40012}},	//   _ارتب, _eläm, _פרקי_, _بتنز
  { {0x25710065,0x38691cfc,0x26c2001e,0x6d560009}},	//   mál_, ggar_, ūkot_, _היקף_
  { {0x4fa30014,0x69ce000e,0x2571000e,0xccf30009}},	// [5220] питв, szbe, lál_, _מכה_
  { {0x52860003,0x7ce8003a,0x064a0012,0xa3ab0011}},	//   _الدك, zırl, الاً_, गमन_
  { {0x7cfd000f,0x64490052,0x02b7000b,0xab5b0031}},	//   pért, _beei, _הליך_, szüt
  { {0x6b9b0e46,0x7d02004a,0x232a0339,0xab2a0695}},	//   _brug, ulos, годи_, года_
  { {0x33f60012,0x68f90034,0x6d43004b,0xb3530024}},	//   حساس, ładó, ânar, зкіш
  { {0x8c1b000b,0x26d80027,0x7ce8003a,0x6b9b0243}},	//   אוני, _umro_, dırm, _drug
  { {0x80a40037,0x7ce8003a,0xfc3f0066,0xd259002d}},	//   काले, tırl, ybí_, рці_
  { {0x141a0003,0x8557000b,0x64490052,0x493b0009}},	//   _ميزة_, _לשלב_, _geei, נגפו
  { {0xdbf10066,0xf0930009,0x30770012,0x43430560}},	//   _příc, לנה_, صحية_, _нетв
  { {0x66fa0044,0x8c3d003a,0xd3370009,0xe7b70009}},	//   ्तिक_, _inşa, _לרמה_, צהיר_
  { {0xba9b0009,0x25710031,0xd24f0012,0xba370009}},	//   _תסבי, gál_, _سنن_, _הטבח_
  { {0xd12f0003,0x89a50012,0x2419003c,0x7cfd0018}},	//   _أمن_, _بإكم, ионы_, vérs
  { {0x69150026,0x06fa0044,0xc8230012,0xc4d30009}},	//   _všet, ्ताव_, _عفوً, פגש_
  { {0x38bc0066,0x99d70012,0x764a0097,0x2571017a}},	//   _míru_, متزا, ðfyl, bál_
  { {0xa803003a,0xf8bf0025,0xd6db0009,0xfcd50012}},	//   ğıms, _liée_, _תחול, _ويتج
  { {0xad370009,0x691501bd,0x58d406eb,0x26de2048}},	//   _פנחס_, _ušet, пост, lito_
  { {0xf7700003,0xd6270003,0x24860029,0xbed9002d}},	// [5230] فال_, معاي, deom_, адах_
  { {0x6efd0061,0x59a80037,0x64490802,0xdb0b0012}},	//   lèbr, कमार, _seei, _حزبه_
  { {0x3eb10031,0x661a0097,0x66c00031,0xdd9b003c}},	//   özti_, _útkl, _zökk, ыша_
  { {0x6efd0025,0xb47b0009,0x6b9b001b,0x62872049}},	//   nèbr, רָ֑י, _prug, lejo
  { {0x1b190015,0x44780009,0xcaf50012,0x49020011}},	//   ажды_, מעאל_, يستب, _वीटो_
  { {0x60cd174e,0x8f3405fb,0x13c80009,0xe2990578}},	//   lham, _херц, מּוֹ_, рак_
  { {0x32cb0033,0x644f204a,0x3abc0009,0x26de204b}},	//   _nøye_, kaci, רמונ, dito_
  { {0x7ce8003a,0x644f1430,0x60cd204c,0x28a90011}},	//   tırm, jaci, nham, काधि
  { {0x752a0052,0x2d9c204d,0xd00c0009,0x28d80011}},	//   _aufz, _arve_, ְּחֹ, बोधि
  { {0x62950070,0x2003001e,0xd3d80012,0xba770012}},	//   jdzo, āji_, _طبقا_, _دارت
  { {0xb0350014,0xdb060002,0x66c0006f,0x20c90011}},	//   _днеш, zykó, _sökk, रसाध
  { {0x6295001e,0x52b40011,0xc0ab0012,0x673b008e}},	//   edzo, ुस्स, _حائل_, ppuj
  { {0x98f40003,0x0b430048,0x26de1d13,0x7ce80060}},	//   _عثما, мнян, bito_, lırk
  { {0x4375002d,0x8c1a0009,0xc3320009,0x68fb204e}},	//   чуют, יורי, ווך_, loud
  { {0x90b60046,0x7ce8003a,0xdd1c015b,0x644f204f}},	//   ољаш, nırk, vážn, baci
  { {0x644f2050,0xe4d30012,0xdb060034,0xf9920009}},	//   caci, _يقود, tykó, ורל_
  { {0xe8f7002d,0x2547000e,0x9d1b0009,0xcc570009}},	// [5240] ілу_, lől_, _דוקט, _וספק_
  { {0x68fb00bd,0xb05b004a,0x9e650012,0xdddc0073}},	//   houd, _yläk, كامن, _varž
  { {0xf27b000b,0x527b000b,0x2d9c00d9,0xc27b0009}},	//   _דריש, _דניא, íve_, _דריי
  { {0x672315ed,0xfbdb0011,0xc60a0011,0xdd1c0030}},	//   _linj, _मेहम, _वरीय_, sážn
  { {0x5f760012,0x5e460012,0x7afc2051,0x78a62052}},	//   _باجر, _وَحْ, oort, _inkv
  { {0x539b000b,0xaa570012,0xaa47004c,0x7cf60031}},	//   יינו, قلها_, опља_, gárz
  { {0x765c0002,0x26de0fa3,0x889a0009,0xc866004c}},	//   órym, vito_, ֹבִי, отпи
  { {0x60c42053,0x66c0006f,0x644f0962,0x91bb0009}},	//   nkim, _sökh, xaci, ימצי
  { {0x20020065,0x98b30027,0xb05b006f,0x60c40010}},	//   æki_, žeće_, _släk, ikim
  { {0xddde000d,0x26de0017,0x2d9c013a,0x22570012}},	//   cepţ, uito_, _prve_, _ولقد_
  { {0x3eb80207,0x60c400ff,0x644f2054,0xa2a70011}},	//   _mort_, kkim, taci, चार्
  { {0x62950002,0xdca60012,0x99980073,0x3d050011}},	//   wdzo, رى_, harų_, रतें_
  { {0xa0290003,0x99980010,0xd0070001,0x6d580042}},	//   _اسمك_, karų_, _деце_, ávaj
  { {0x2547000f,0xe5720003,0xf6d30012,0xa2270012}},	//   ből_, _قطع_, _يزود, ترحه
  { {0xdb1d000e,0xf84b04ad,0x28bf0011,0x5ea30012}},	//   nysé, ичай_, _एकदि, _زميل
  { {0x34b90037,0x26ca0002,0x515b0009,0x47350048}},	//   _आवेद, _albo_, יכלו, знас
  { {0x44290005,0x3eb80ed3,0xe7300012,0x60cd2055}},	// [5250] _iga_, _bort_, نصل_, rham
  { {0x501b000b,0xdd9b1e3f,0x2607003c,0xfc3f0030}},	//   שומו, ише_, очег, ajít_
  { {0x3eb8008b,0x63b6004a,0xbd880012,0xdb210031}},	//   _dort_, äynn, ينكن_, ótíp
  { {0xf9fa000b,0x6d8b0009,0x60c4010f,0x6d550031}},	//   _להתמ, יָדְ, ckim, ázai
  { {0x44290733,0x3eb82056,0xb3870012,0xa0360009}},	//   _mga_, _fort_, تجاه, _מארה_
  { {0x77ba000b,0x7ce8003a,0x67ba0009,0xaa45008e}},	//   _המשח, tırk, _המשק, _ävää_
  { {0x20090039,0x20bf0037,0xda7c0009,0xca7c0009}},	//   _šai_, _एकाध, ינגר, ינגט
  { {0xa3cb0044,0x66030002,0x40780015,0x25752057}},	//   लना_, _rynk, ощью_, mål_
  { {0xfa8b0015,0x3862000e,0x66e5005c,0x66c0006f}},	//   _всей_, ókra_, зопа, _söki
  { {0x2547000f,0x44291a54,0xf195002d,0xddde014a}},	//   től_, _aga_, _низь, lepš
  { {0xb05b004a,0x7afc2058,0x45d40024,0x1d150009}},	//   _eläi, vort, дцят, ּקָר_
  { {0x2547000f,0xdb0d0029,0x7afc0e22,0x397a0009}},	//   ről_, ľkýc, wort, _לטענ
  { {0xa2d20037,0xaaa70037,0x7afc2059,0x6723114d}},	//   भोक्, खांक, tort, _tinj
  { {0x44290005,0x6442000d,0x386d205a,0xcf920009}},	//   _ega_, zboi, lger_, _נטו_
  { {0x7d11000f,0x2f14006f,0x60c4004a,0x20c70051}},	//   üksé, lägg_, tkim, _võin_
  { {0x55ba0093,0x60c40010,0x386d205b,0xdcfa0012}},	//   _למצו, ukim, nger_, _دفعت_
  { {0x3eb8205c,0x60c4205d,0x386d205e,0x7afc205f}},	// [5260] _port_, rkim, iger_, port
  { {0x26c5007a,0xd00f0003,0x60c42060,0x7bdb0009}},	//   nklo_, الك_, skim, _לקפו
  { {0x3abb000b,0xa2bb000b,0x7abb000b,0xb2bb000b}},	//   _המינ, _המיט, _הציו, _המיר
  { {0x3eb80052,0x27ed0864,0x3d120011,0x386d0a82}},	//   _wort_, _žene_, _धीमे_, jger_
  { {0x389b0093,0x29020005,0x889b0009,0xa2940024}},	//   _היכנ, _ikka_, _הבכי, далі
  { {0x32050013,0xd3570009,0xc3330009,0x386d1faa}},	//   _byly_, ליני_, תוג_, eger_
  { {0xbefa0037,0xb909001a,0x68e00060,0xe5060012}},	//   ्तीन_, _nghỉ_, timd, _فبري
  { {0xf993000b,0xc1040003,0x61e50029,0x155b0009}},	//   תרה_, بوعي, úhla, _לכלב
  { {0x7b090065,0x68e0003a,0xdd1f0066,0x4fc60048}},	//   ðstö, rimd, tížn, яска
  { {0x692a0013,0x68e0003a,0xd3570009,0x43570009}},	//   _před, simd, _מימי_, _מסמל_
  { {0xaab00044,0xceb30093,0xd23b000b,0x45d40001}},	//   ञानक, תית_, _הגבל, фонс
  { {0xc9850003,0x718b0009,0xa1130012,0x628a2061}},	//   _تشكي, _לְדַ, _كولت, lefo
  { {0xde58002d,0x28a90037,0xc4d30009,0xf8a90011}},	//   _далі_, कारि, תגר_, कारय
  { {0x753c003e,0x764e0013,0x9713002d,0x501b000b}},	//   _otrz, _neby, _зміц, _הודו
  { {0x867b000b,0xf67b000b,0xc9840339,0x4e7b0009}},	//   _הרוו, _האומ, нути, _האוצ
  { {0x44292062,0xdd010035,0x6d3b00af,0xd5cb00af}},	//   _uga_, ītēj, _פתחנ, _לֶחָ
  { {0xf773000a,0xc4f80009,0x628a2063,0x31780034}},	// [5270] عار_, _מזהי_, kefo, atrz_
  { {0xf7480012,0x798d0034,0x20070035,0x0aeb0012}},	//   سلمي_, ławi, āni_, _دربي_
  { {0x27320081,0x69130060,0xb2bc0009,0x627a0009}},	//   _lân_, tçed, _למזר, _ונתנ
  { {0x386d0040,0x7ce80060,0x3ea70031,0x38350557}},	//   _øer_, tıri, űnt_, _інгр
  { {0x68ed2064,0xa09a0009,0x889a0009,0xb89a0009}},	//   mnad, _וירט, _וברי, _וברש
  { {0x66c00163,0x2909004a,0x628a2065,0x764e03ee}},	//   _sökv, llaa_, gefo, _geby
  { {0x95c50003,0x28a90011,0x68ed2066,0x79a70024}},	//   _غيره, कालि, onad, ярде
  { {0x04c90012,0xbca50012,0x68ed2067,0xb05b008e}},	//   _بوري_, _تمري, nnad, _eläv
  { {0x2732001a,0xcd020002,0x2909008e,0x628a2068}},	//   _cân_, _dość_, ilaa_, befo
  { {0x27320020,0x79960002,0xf412000b,0xd7060015}},	//   _dân_, ływa, _יפן_, мные_
  { {0x569c000b,0xcc8a0177,0xfe360009,0x386d0248}},	//   מיזצ, обне_, ורתי_, pger_
  { {0xfbc70003,0x859a000b,0x7ae32069,0x69fa0009}},	//   نت_, קשרו, lint, _ולעק
  { {0x1e0a0044,0x7e0a01e1,0xdce2001e,0x2f141ad3}},	//   _वर्ष_, _वर्ग_, gulā, läge_
  { {0x7d070061,0x3200003a,0x3ea70028,0xf6510012}},	//   térê, şiye_, _unnt_, _شئت_
  { {0x3cfa0012,0x91e60048,0xacf6004c,0x9cf6004c}},	//   _وعبد_, фове, _очиј, _очиш
  { {0x7ae31b70,0xbcf60003,0x6913003a,0x6298001b}},	//   hint, _تستغ, eçeb, zdvo
  { {0x7ae3206a,0x753c0002,0x7d04003a,0x31780002}},	// [5280] kint, _strz, _ikis, strz_
  { {0x7ae3007a,0x7f190024,0x9d460229,0x2909008e}},	//   jint, піху_, дежд, alaa_
  { {0x7e7e006f,0x7ae3206b,0x628a206c,0x6d411722}},	//   _öppe, dint, vefo, npla
  { {0xcdb6000b,0x69c30ff7,0x45b60009,0xf4830024}},	//   ופעה_, dyne, ופעל_, вушн
  { {0x6d67007a,0x7ae30163,0x68e40051,0x628a206d}},	//   _įraš, fint, miid, tefo
  { {0x68e40051,0x7ae3206e,0xd13a0695,0x69c1005e}},	//   liid, gint, охи_, äleg
  { {0x753c0002,0x2732001a,0x7a890009,0xdce20035}},	//   _utrz, _sân_, לָקַ, zulā
  { {0xc1730009,0x4ddb0009,0x09f70009,0x692a0030}},	//   דחה_, _וחלו, ומצם_, _přeb
  { {0xb05b0032,0xbe8a0476,0x6d41206f,0x7ae32070}},	//   _gläu, осне_, epla, bint
  { {0xcaa60003,0x66c00839,0x2ca90066,0x2732001a}},	//   _تصري, _töku, _snad_, _vân_
  { {0x27e90065,0x01da0003,0x68e40051,0x7e9b000b}},	//   _þann_, _بوضع_, kiid, קסטו
  { {0xbfc60098,0x692a0066,0x2732001a,0x88c60003}},	//   _обек, _třeb, _tân_, _تتطل
  { {0x68e40051,0xd91b0009,0x05de0011,0xe3c50012}},	//   diid, _וואל, _फेरब, رْسَ
  { {0x05760003,0x6d41006f,0xe9d30012,0x9ea70048}},	//   _قاعد, bpla, نغز_, _овча_
  { {0x6d55000e,0x41e4002d,0xe9190024,0x5db30012}},	//   ázat, віта, зові_, _لإير
  { {0xdce2001e,0xddc80034,0x69d50032,0x50640147}},	//   pulā, padł, rzze, ктуа
  { {0x8d180012,0x3cf20011,0x13f4003c,0x7c2d2071}},	// [5290] _تزور_, ंचने_, _изъя, _igar
  { {0x20c70005,0x4439000e,0x333c0009,0x66e4004c}},	//   _kõik_, lcs_, _ותזמ, вођа
  { {0x7ae301b3,0x2578000e,0xb05b0052,0x68ed0248}},	//   vint, nél_, _blät, pnad
  { {0x66c00163,0x809e0037,0x621a000b,0x44392072}},	//   _sökt, _खोले, _מותק, ncs_
  { {0x60d6000b,0x9cd8000b,0x7ae32073,0x883a0009}},	//   _נושא_, וואה_, tint, _מתרו
  { {0xdb25000e,0x499502ad,0x69c32074,0x6d412075}},	//   _épül, ешит, tyne, ypla
  { {0x64460002,0x7ae32076,0xb2360012,0xa3cf0011}},	//   ybki, rint, ركيا_, वैत_
  { {0x2f140052,0xa3c10011,0xac380012,0xd12e0012}},	//   räge_, ूना_, _يسقط_, حمي_
  { {0x692a0066,0x787a0009,0xf9070011,0x7d04008e}},	//   _přec, הָיו, _वीज़ा_, _rkis
  { {0xcf92000b,0xe2930012,0xb659003c,0x25780031}},	//   נטי_, _جذر_, чших_, fél_
  { {0x1d0a0098,0x75290070,0xb05b004a,0xa50a05f8}},	//   зени_, _kiez, _ylät, зена_
  { {0xa2b90037,0x41740012,0xeafa0011,0x6d412077}},	//   ्सक्, _جاكس, ृत्त_, rpla
  { {0x61fb00a2,0x10d80003,0x68e40051,0xa856000b}},	//   şull, _تبلغ_, viid, _ניסה_
  { {0xfbd2007e,0xa3cf0037,0xb05b006f,0x60c92078}},	//   רתך_, वैध_, _oläs, lkem
  { {0xd1320003,0x60c9008e,0x7c3b0097,0x06960012}},	//   امر_, okem, _ofur, _سنية_
  { {0x7529003e,0x26fa0037,0x7d760003,0xd8260048}},	//   _niez, ्त्र_, _أمير_, едби
  { {0xd00f000a,0x6fd6002d,0x6e3b003a,0x68e400ff}},	// [52a0] ملف_, хівц, _şuba, riid
  { {0x442d2079,0x4df60015,0x60c91106,0x68e413f9}},	//   _age_, няет, hkem, siid
  { {0x63a40028,0x66c0006f,0x6c9a000b,0xb05b0032}},	//   _hrin, _söks, ּשְׂ, _plät
  { {0x236601bd,0xf5250024,0xe4520012,0xe45f0248}},	//   troj_, вфін, اضا_, lhör_
  { {0xf1d80044,0x6abe0052,0x7ce8003a,0x43940015}},	//   _भेजन, _kopf, lırs, талс
  { {0x387f0065,0x2360207a,0xdbc7005e,0x60c90244}},	//   efur_, šijo_, _tööm, ekem
  { {0x629c0039,0x7ce8003a,0xd8da0009,0x82570012}},	//   idro, nırs, ּקִר, رؤوس_
  { {0xf1b3000b,0x89330003,0x25780074,0x09330012}},	//   רסה_, دعوا, vél_, دروج
  { {0x628e0033,0xb4be0011,0x67d40ce1,0xb05b0032}},	//   kebo, ेसी_, топу, _klär
  { {0x60c9004a,0x8f9b000b,0x25780031,0x4b260012}},	//   akem, ליפי, tél_, _أعرف
  { {0xa4d50024,0x49990024,0x69050031,0xdcf00060}},	//   воні, _отця_, góes, çeği
  { {0xbebc001e,0x58060003,0x60560012,0x70560012}},	//   kmīg, _كواك, _أنشط, _أنشا
  { {0x9b580098,0xdb0011ff,0x00bb0009,0xe8160011}},	//   ният_, _armé, _ממאמ, देखा_
  { {0x69a40044,0x2f970093,0x2364000e,0x56930538}},	//   किपी, _נכון_, ámja_, _башт
  { {0x3a250163,0x63a4067e,0x629a207b,0x30a70593}},	//   älp_, _erin, _mato, нрав
  { {0x7c2d0f86,0x629c207c,0x6d5a207d,0x63a4207e}},	//   _ugar, adro, msta, _frin
  { {0x7c840047,0xe7330003,0x6d5c207f,0xf484003c}},	// [52b0] _суще, اصر_, _avra, _сущн
  { {0xdef800e3,0x66c00163,0x2bdb0037,0x7ce8003a}},	//   ных_, _sökr, _मेगा, bırs
  { {0x75292080,0x22dc0009,0x63a4001b,0x2d872081}},	//   _piez, _מחזא, _zrin, ïne_
  { {0xed570009,0x629a005e,0x7ae70227,0x91b60009}},	//   תבאר_, _aato, lijt, _ספרא_
  { {0x0056000b,0xa8560009,0x9cd80009,0x69c7008e}},	//   _בשרת_, _בירה_, עודה_, lyje
  { {0xda620021,0xc3340009,0x6262003c,0x91e500fc}},	//   авши, אוס_, авша, коле
  { {0x6d580029,0xc6480012,0x57c90011,0x60c900e6}},	//   ávat, _سجّل_, िन्ह, tkem
  { {0x442d0058,0xceb80002,0x212b0066,0x628e0002}},	//   _uge_, eję_, _jich_, zebo
  { {0x212b0052,0xb05b004a,0x60c90fa6,0x629a0017}},	//   _mich_, _ylär, rkem, _fato
  { {0xaec20015,0x2cbf0070,0x2cad0066,0x98b2001e}},	//   ибыл, _houd_, _hned_, ādām_
  { {0xb9b50003,0x628e0623,0x6d5a2082,0x6f012083}},	//   _جماع, vebo, gsta, rolc
  { {0x7bc6003e,0x83fd000e,0x4c83002d,0x628e0033}},	//   tyku, _időb, алюв, webo
  { {0x28a50011,0x65680227,0x6b560009,0x6f012084}},	//   _ऑफ़ि, ardh, ֛ישׁ_, polc
  { {0xceb8003e,0xef18002d,0x6a860014,0x68e20002}},	//   cję_, _змі_, ълга, _zmod
  { {0x628e041e,0x20ca0012,0x7bc6016d,0x48e601c6}},	//   rebo, وبري_, syku, вовв
  { {0x55f6000b,0x7c2d009b,0x63a42085,0xb0990024}},	//   _במצב_, žarj, _trin, нтує_
  { {0x212b0052,0x9f4f0028,0xe45f006f,0x7ae7001b}},	// [52c0] _dich_, ægð_, phör_, bijt
  { {0x69a40037,0x86430357,0xc8ee05f3,0x6da60a36}},	//   किमी, инуж, _छद्म_, киза
  { {0xb13a0003,0xed570024,0xbebc0035,0x22582086}},	//   _تأخذ_, вох_, smīg, mark_
  { {0x09f70093,0x22580033,0xcb6a0014,0xa3ce0037}},	//   _ימים_, lark_, даде_, शनल_
  { {0x8c43003a,0x93930003,0x629a2087,0x6bd60012}},	//   _öğel, لجوا, _pato, ختار
  { {0x212b00bd,0x6e430046,0x291f00b6,0x6d5a2088}},	//   _zich_, _верз, emua_, ysta
  { {0x610c0052,0xf2d30009,0xd46a0012,0xd91a003c}},	//   eßli, שעו_, _يحرم_, мьи_
  { {0x2eca0037,0x07980001,0x23760012,0xc9530009}},	//   िस्त, евић_, _لائح, במה_
  { {0x6d5a003e,0xdfd00003,0x69c70002,0x2407092d}},	//   wsta, صيد_, zyje, _анти_
  { {0x2b460054,0xfe6f0012,0x63a2016d,0x4ea60357}},	//   mpoc_, يدٍ_, mvon, триа
  { {0xd5b7007c,0xdb04001a,0xe1650003,0x1e57000b}},	//   вся_, _triê, _مدني, כשיר_
  { {0x6913003a,0xceb80002,0x77ca0695,0xa3b60011}},	//   eçen, sję_, _олег_, _छपा_
  { {0x3f98001e,0x212b2089,0x60b70009,0x5bb8003c}},	//   ārus_, _rich_, _שהדף_, вляя_
  { {0x212b032b,0x27d70009,0x59b60011,0x9d9a0012}},	//   _sich_, _שֵׁם_, _अपार, _ينشئ_
  { {0x7aed0108,0xc1e80047,0xe717000b,0x31c4004d}},	//   éati, вьте_, _שחור_, аств
  { {0xc19b000b,0x257c0066,0x299b000b,0x66c0006f}},	//   ושלי, díl_, וסלמ, _sökp
  { {0xf7700003,0x3015208a,0x40340a8b,0xe89401c6}},	// [52d0] قال_, удар, реус, шать
  { {0x6e450003,0x61ee000e,0x2cbf0066,0x877b0009}},	//   انضم, ánlá, _soud_, ואמי
  { {0x29040914,0xd1310012,0xce940048,0x56940048}},	//   koma_, _دمج_, рахъ, рахт
  { {0xb87b0066,0xed58002d,0x399c000e,0x29040035}},	//   _zmín, тої_, zásá_, joma_
  { {0xfbd00003,0x692a0066,0xdb85002d,0x29041424}},	//   يته_, _přen, угли, doma_
  { {0xe3b00003,0x4999022a,0x3f990025,0x24510081}},	//   ترم_, етия_, _issu_, ạm_
  { {0xb05b004a,0x45d50015,0x7abc0009,0x6d5819b3}},	//   _yläp, _совс, וצגו, švar
  { {0xf9900003,0x60cd208b,0x2904208c,0x26cc0159}},	//   تبه_, nkam, goma_, ekdo_
  { {0x64590002,0x2fc9002c,0x399c0031,0x96550048}},	//   mawi, nyag_, tásá_, лънч
  { {0x1e95011f,0xe7aa0051,0x9695004c,0x0f580009}},	//   урир, _tööõ, уриш, דיזם_
  { {0x7d1b00c6,0xf8750003,0x290d04b2,0x60cd01a3}},	//   _khus, _مهاج, plea_, kkam
  { {0xc329015a,0x7e7e0163,0xaca30081,0x6459208d}},	//   _זו_, _öppn, _khốn, nawi
  { {0x691300a2,0xe81f0011,0x60cd208e,0x6f640024}},	//   tçen, मेशा_, dkam, _ввіз
  { {0x320c0002,0x2d950001,0xb05b006f,0xdb200029}},	//   żdym_, _брис, _släp, _štúd
  { {0xf656000b,0x7d1b0051,0x2bdb0011,0xdd030035}},	//   _עסקי_, _ohus, _मेघा, ņrād
  { {0x6459003e,0x68e9208f,0xddc80066,0x60cd002c}},	//   jawi, nied, jadř, gkam
  { {0x98a30014,0x9d1b000b,0xad1b000b,0x10a3022a}},	// [52e0] щите, _אוקט, _אוקר, щитн
  { {0x7d060006,0xdfcf000a,0x93b7000b,0x539b000b}},	//   loks, أيك_, _עליו_, _טיפו
  { {0x7d060051,0x7a7b0009,0xfc660048,0x31a30060}},	//   ooks, _אריס, гълн, _nız_
  { {0x7d0603fc,0x2d510027,0x6459002c,0x629e002c}},	//   noks, iše_, gawi, _hapo
  { {0x5453002d,0xaca3001a,0x59b60037,0x629e1470}},	//   світ, _chốn, _अपहर, _kapo
  { {0xd24f0003,0x2d510864,0xc2c40012,0x6721001b}},	//   كنه_, kše_, شيعي, jmlj
  { {0x2d51012e,0x91860003,0x29042090,0x64590034}},	//   jše_, اجتم, toma_, bawi
  { {0x629e2091,0x6721013a,0xc9530009,0x64560060}},	//   _lapo, emlj, זמה_, _neyi
  { {0x6d43007a,0x29040e68,0x59b60037,0x26130081}},	//   _atna, roma_, _अपवर, _ạo_
  { {0x7d06004a,0x7fd70009,0xf76f0012,0x7db40012}},	//   eoks, טופס_, ساً_, لمخص
  { {0xa9670014,0x9965002d,0x752d2092,0x68e92093}},	//   _биха_, _втіл, _piaz, bied
  { {0x7d0f000f,0x2ec10037,0x91bb0009,0xe73a0024}},	//   ulcs, _शक्त, _רמאי, _зед_
  { {0x6456003a,0x2d8b000d,0x3eb8006f,0x26130081}},	//   _deyi, ăcea_, örts_, _ẹo_
  { {0x945d003e,0x60cd0002,0x64590002,0x05d60012}},	//   _końc, wkam, zawi, _مزعج
  { {0x765a13f4,0x76550002,0x48ab0109,0xa63b0009}},	//   maty, _rezy, нтам_, _אגור
  { {0xa1570009,0x60c2005e,0x6d5e2094,0xc8790060}},	//   טבלה_, _joom, dspa, tişi_
  { {0x7e55002d,0xce6b01d4,0xab950024,0x3e6b0229}},	// [52f0] иває, еред_, _типі, ешен_
  { {0x60c20005,0x38bc0066,0x6b8d002c,0xc879097e}},	//   _loom, _míry_, _ipag, rişi_
  { {0x6459003e,0x3d950014,0x692a0066,0x999e0010}},	//   tawi, риер, _přel, _metų_
  { {0x9b750003,0xfc3f0066,0x23750003,0xd50b0012}},	//   لاتص, ncí_, لاتح, رغان_
  { {0x6d5e007a,0x3f8003eb,0x64590ac1,0xa85a000b}},	//   aspa, ctiu_, rawi, _בדרכ
  { {0x68e90656,0x26cf001e,0x7aea2095,0x8b580009}},	//   wied, īgos_, gift, ניוס_
  { {0x68e90006,0xfc3f0066,0x08d5022a,0x92580012}},	//   tied, kcí_, иция, اشهر_
  { {0xaca30020,0xdd020064,0xe9a80012,0x261a0011}},	//   _thốn, _ľuďm, ادون_, _भरती_
  { {0xf8b4000b,0x63b6004a,0x3cfb0011,0x68e92096}},	//   משק_, äynt, ोकने_, ried
  { {0xbf880003,0x66d20028,0x765a0455,0xfaf30012}},	//   ائيل_, _lækn, gaty, _اثر_
  { {0x7d060006,0x249f1441,0x69130060,0x26c32097}},	//   toks, _kaum_, tçel, _mojo_
  { {0x493a000b,0xed56002d,0x7d06004a,0x63a92098}},	//   _סגנו, шою_, uoks, _kren
  { {0x9f6b0098,0x200f005e,0x81110011,0x2d981489}},	//   _чрез_, ügil_, _डीएओ_, ærer_
  { {0x212f0036,0xe5a5069b,0xdb000017,0xd2520012}},	//   _high_, _вики, _irmã, تنس_
  { {0xa8560001,0xb5a80012,0x89890009,0x64560060}},	//   итај, _مايك_, כָּ֔, _teyi
  { {0xfc32000a,0x15fa000b,0x45fa0009,0x8d480009}},	//   _بحث_, _בהצע, _בהצג, _עֲצֵ
  { {0x4103002d,0x41270014,0xe7370014,0x6d5e2099}},	// [5300] ізув, рото_, иет_, wspa
  { {0xf8d20037,0x3f800d04,0x735b0009,0x79960034}},	//   _तत्प, rtiu_, _שכיח, ływi
  { {0x273b0020,0x63a9209a,0x6d5e1598,0xe45a0024}},	//   _lên_, _aren, uspa, вже_
  { {0x692a0030,0xfdf6000b,0xa533002d,0x113b0009}},	//   _přem, בצעת_, ініч, _שתכל
  { {0x273b0020,0x240705fb,0x2ca0021b,0x7aea209b}},	//   _nên_, анци_, _maid_, tift
  { {0x809e0044,0x60c20051,0x2ca00503,0x92940538}},	//   _खोजे, _soom, _laid_, сакц
  { {0xaca3001a,0xbae30012,0x20f7004b,0x63a9209c}},	//   _chồn, تكوي, răin_, _eren
  { {0x273b0020,0x692a0aec,0x859b000b,0x23690027}},	//   _bên_, _zřej, _בשלו, šaja_
  { {0x69d5000f,0x765a0915,0x1eaa0003,0xbb4306a5}},	//   _üzen, taty, نادي_, _метк
  { {0xee31000b,0xcdd40009,0x9f030012,0x4b7b0009}},	//   ּֽי_, ֶךָ_, يويو, _באמו
  { {0x6b8d00c1,0x60c20051,0x42db000b,0x87170009}},	//   _spag, _toom, _שקבע, שקיע_
  { {0xdb00000d,0xfc3f0066,0x6913003a,0x4fea00de}},	//   _urmâ, ucí_, tçem, _имен_
  { {0x6b820197,0x7e9a0012,0x765a13e7,0xd7e30557}},	//   ntog, _لنشر_, paty, _мішо
  { {0x2455001a,0xdb240028,0x6d48079d,0x4fdb0009}},	//   ấm_, ærðu, ppda, _שַׁד
  { {0x26c30164,0x95ca0001,0x7d760012,0x39a4004c}},	//   _rojo_, _јула_, _ضاغط, оштв
  { {0x6b820010,0x273b001a,0x40340015,0x2f0b0058}},	//   ktog, _yên_, жетс, søgt_
  { {0x692a0013,0x249f0052,0x61350010,0x200f0028}},	// [5310] _přej, _raum_, _išle, ægi_
  { {0x539c000b,0xba99002d,0x22950003,0xfda70001}},	//   _ייחו, _своє_, _الدس, ијем
  { {0x66d20028,0x20070002,0xf2960009,0xa6340024}},	//   _tækn, łni_, _הכתר_, інці
  { {0x7658004a,0x20c70051,0x8c190012,0x98480048}},	//   _levy, _võis_, هيار_, _вяра_
  { {0xb0b60009,0x28b60009,0xf8b60009,0xd37b209d}},	//   _הפרס_, _הפרש_, _הפרי_, тче_
  { {0x645d00c6,0x1308002d,0x7658014a,0xff040014}},	//   hasi, аній_, _nevy, _дясн
  { {0x2d9c0058,0x7d0d002c,0xfb1c000b,0xcad80009}},	//   ævet_, _okas, דוגמ, שוות_
  { {0x09f8000b,0x59ba0011,0xa9040012,0x63a9209e}},	//   ימום_, _उपसर, يبين, _tren
  { {0xc0c80001,0x6b8217e8,0xceb50012,0x6d410025}},	//   рује_, ctog, محدث, _élab
  { {0x2ca01160,0x2011001e,0xab280001,0x60080009}},	//   _said_, āzi_, _вођа_, יִתְ
  { {0x2ca01018,0x76580073,0x64a6033d,0x99d40012}},	//   _paid_, _devy, бана, _وتما
  { {0x273b0020,0x18a4002d,0x645d209f,0xdb0e0030}},	//   _tên_, _маєм, gasi, ějíc
  { {0x2ca00005,0x889a0093,0xb05b006f,0xa3d70037}},	//   _vaid_, _תבני, _poän, ानि_
  { {0x8c1a0093,0x62950347,0xce940048,0x87040012}},	//   טורי, gezo, _мачъ, _وبول
  { {0xf8db0044,0x98db0037,0xcb120009,0x6146004c}},	//   _बताय, _बताए, פלל_, себа
  { {0xa3d70044,0x60db0017,0x29d3001a,0xaca3001a}},	//   ाना_, nhum, ịa_, _khổn
  { {0x6d470039,0xbb86000a,0x36360003,0x2fdf100f}},	// [5320] _atja, _الخي, مراس, nzug_
  { {0x692a0013,0x3bbb0009,0xe45f0097,0xa1420035}},	//   _přek, _עמיד, gjöf_, šķin
  { {0x93250012,0x0d8610c2,0x36060012,0x68ed20a0}},	//   _برين, слен, حواف, biad
  { {0xdd8f0003,0x045a0003,0x69ce0010,0x3eaf001e}},	//   عون_, اجات_, mybe, ēgta_
  { {0x6b74002d,0x8c3d003a,0xdb000042,0x2cb70030}},	//   ілку, _başb, _armá, _šedé_
  { {0xd5d60015,0x2d9c0058,0x5dd60015,0x96ba0339}},	//   _любы, æves_, _любу, _суму_
  { {0x69d5003a,0xc5d50024,0x02690024,0xc5b80009}},	//   _üzel, _діть, ршій_, _דֶּר
  { {0x765e007a,0x1d0a0001,0x6b82200d,0x78a420a1}},	//   lapy, _себи_, ptog, ndiv
  { {0xd0100003,0xa9260042,0x69ce0030,0x8fa3004c}},	//   بلة_, mažď, hybe, зање
  { {0x27e0003a,0xceb30009,0x9f9b0009,0x079b0009}},	//   izin_, ִיר_, נסיפ, נסיל
  { {0xc04f007c,0x629504d2,0xb2a50012,0x15fa0011}},	//   _ні_, vezo, _بحقه, ्थिर_
  { {0x691300a2,0xf79a0003,0xa92617de,0x693c03a7}},	//   rçek, _منصب_, _удел, _včel
  { {0x78a400c1,0x68ed1606,0x31d10011,0x2cb2008e}},	//   ddiv, viad, सन्ध, öydy_
  { {0x68ed003e,0x27e0003e,0xadfa0037,0x877b0009}},	//   wiad, dzin_, ्थान_, _תאגי
  { {0x692a0013,0x6ce7002d,0x60c6079d,0x3da70012}},	//   _přeh, _гіпе, _bokm, _هُوَ_
  { {0x957c003e,0x316c0029,0x32cb0033,0x98c40db7}},	//   rząd, ádza_, _høyt_, псул
  { {0x68ed20a2,0xe9180024,0xcf270012,0xa0c40012}},	// [5330] riad, соті_, مرئي, أيقو
  { {0xa3ac0037,0x98be001e,0xbbd8000b,0x68ed20a3}},	//   गिन_, ītā_, _לוחץ_, siad
  { {0x69ce0070,0x98a20073,0x95670048,0x68ed179f}},	//   cybe, _likę_, създ, piad
  { {0x63ad20a4,0x76490060,0x841520a5,0xd12600ae}},	//   _kran, _şeyd, омех, _زم_
  { {0xd0060003,0x2d9c0058,0x2f0f0052,0xab64002d}},	//   _آل_, æver_, fügt_, звіл
  { {0x2369009b,0x8c1c0009,0xd1c9076b,0x398120a6}},	//   šajo_, אודי, илле_, tós_
  { {0xa4d5007c,0x6aa108eb,0xfd130012,0xa925003c}},	//   _дові, _valf, _فجر_, одкл
  { {0x63ad20a7,0x69d5000e,0x2b490027,0xe1640012}},	//   _oran, _üzem, _otac_, أدوي
  { {0x7e990012,0xbcb40030,0xa8cc0009,0x60db20a8}},	//   لنظر_, šším, ר֖וֹ, rhum
  { {0x66e5007c,0x39810017,0x2563003a,0x46e904ba}},	//   іона, pós_, tıl_, рдон_
  { {0xed590046,0xceb40009,0x2b490cea,0x81440012}},	//   јом_, ליץ_, _atac_, _فنلن
  { {0x7fd5002d,0xdd7a000b,0x41740012,0xa50a20a9}},	//   _мілі, סטרל, _رامس, рема_
  { {0x256300a2,0xf8bf0061,0xf8b8001a,0x2bac0011}},	//   sıl_, _liés_, _đĩ_, चिया
  { {0x69ce0010,0x82360003,0x60c60060,0xe5710012}},	//   tybe, ترحا, _sokm, _قطب_
  { {0xd9430001,0x19b9002d,0x63ad20aa,0xdbd80097}},	//   деси, буть_, _eran, hæða
  { {0xddc70002,0x27e020ab,0xed560009,0x2f14005e}},	//   _wejś, tzin_, _ובקר_, mägi_
  { {0xf092000b,0x20e8004b,0x7d0b0031,0x46ea1896}},	// [5340] ונן_, nşii_, dogs, адан_
  { {0x3200003a,0xafdb0260,0x26c720ac,0xceb200af}},	//   şiyi_, _iføl, _jono_, ֽיא_
  { {0x66d20065,0x8ab70009,0x2d8520ad,0xfc3f01e3}},	//   _hækk, _והיו_, ntle_, ldía_
  { {0xadb70003,0x83fd000e,0xcea90009,0xe5880009}},	//   تهما_, _időj, כי_, מָנָ
  { {0x7ed6002d,0xfc3f0164,0xa2c10037,0x693c154d}},	//   _дівч, ndía_, रॉक्, _oček
  { {0x8c1b000b,0x29000010,0x44020011,0x7eb60012}},	//   בוני, čiam_, _लखनऊ_, _بمسؤ
  { {0x645b0108,0xd259002d,0x66d20028,0x58d4003c}},	//   _feui, сці_, _lækk, зойт
  { {0x6cd60012,0xec770048,0x98a3004c,0x765c11d3}},	//   _بقرا, _мпс_, диће, _hery
  { {0xd6d00003,0x2918001e,0xb6020066,0x9f44004a}},	//   فقة_, ēra_, řádn, _ämä_
  { {0x6101001e,0x66d20028,0x539b0009,0x31780064}},	//   vēle, _sækj, _דימו, kurz_
  { {0xd6d7007c,0x48660014,0x957c0002,0x0697000b}},	//   іть_, _дълб, dząc, חדים_
  { {0x63ad1fe8,0x759b0009,0x97c60012,0x753c0034}},	//   _pran, ביטח, _وتشم, _murz
  { {0x6135007a,0x62980070,0x26c70073,0x6ff60012}},	//   _išla, oevo, _fono_, _بساط
  { {0x66d20058,0x2d850132,0x8c1b0009,0x84340024}},	//   _dækk, btle_, יוכי, ьняє
  { {0x66d20065,0x3860002a,0x692a0030,0xbbb70011}},	//   _tækj, fair_, _dřev, _आप्क
  { {0x66d20028,0x63ad20ae,0x3ea320af,0xad270012}},	//   _fækk, _tran, _sajt_, _برتو
  { {0xe4520093,0x14ab0037,0xd7590003,0xf7730003}},	// [5350] _אֶת_, _घोषण, صلات_, ظار_
  { {0x957c003e,0xddab0098,0xdbd80028,0x57780003}},	//   cząc, ител_, væða, تصفح_
  { {0xba9a000b,0x6a9a000b,0x429a0009,0xe29a0009}},	//   _הסתי, _השתנ, _הסתב, _השתר
  { {0x8c3d00a2,0x1e140024,0x291e01a0,0x853c0073}},	//   _başa, ємця, ïtat_, tvėj
  { {0x645b0108,0x83fd000e,0xad1c0009,0x88ba0009}},	//   _veui, _idők, בואר, _הזרי
  { {0x629800bd,0x7f3a0093,0xe2990177,0x2bb80012}},	//   gevo, _לעשו, сак_, تامة_
  { {0x32580009,0xd24e0012,0x7c970012,0xe0d10012}},	//   חסום_, دنى_, _وشرا, فزة_
  { {0x26c701a2,0x26de004a,0x673d0051,0x01fc0009}},	//   _sono_, ehto_, _kusj, יפול
  { {0xb4d70037,0x753c0052,0xf7710012,0x6d4a0035}},	//   िसी_, _zurz, راة_, _atfa
  { {0x2d850036,0xd2510003,0x66d20058,0x8f9a0009}},	//   ttle_, _أنا_, _rækk, ציתי
  { {0xf2d20009,0x38350959,0xf4090009,0x85780337}},	//   _רעב_, _енер, _עפ_, осят_
  { {0x8c3d00a2,0xd0110003,0x64410002,0x23720073}},	//   _yaşa, _كلا_, ślin, šyje_
  { {0xf7490351,0x69ce008b,0x692a0013,0x883a0009}},	//   _التي_, _über, _přev, _התנו
  { {0xa3ac0037,0x26de00f1,0xfc3f01e3,0x31780032}},	//   गित_, chto_, rdía_, turz_
  { {0x76ba000b,0xc332000b,0xc6920009,0x957c0034}},	//   _למספ, תום_, _נאה_, rząc
  { {0xa5070014,0xe2070002,0x957c0002,0x68fb0028}},	//   _неща_, ciół_, sząc, nnud
  { {0xfbd20003,0xbc7b000b,0x8e3a0003,0x96960e8a}},	// [5360] _ستة_, _הנפת, مسار_, зреш
  { {0x6fb30003,0x62070031,0x44200060,0xe9da003c}},	//   عملا, érlé, _izi_, _гко_
  { {0x80db0044,0x2a57000b,0x7cf6001e,0x9a3b0009}},	//   बसाइ, _מבין_, ašre, _לתיק
  { {0x19bb000b,0x765c0002,0x64460002,0xe4a30024}},	//   _המטב, _wery, ncki, ершо
  { {0x7e610039,0x765c0002,0x3cdd0037,0x753c0052}},	//   kalp, _tery, _खतरे_, _wurz
  { {0x60c40027,0xe57f001e,0x05cb0011,0x629801e3}},	//   ljim, šķas_, ाहाब, uevo
  { {0x78a60027,0x6913003a,0x60d60073,0x29050097}},	//   _kakv, rçev, okym, élag_
  { {0x61250028,0x60c40604,0x64a301b6,0x60d603ec}},	//   hólf, njim, _паса, nkym
  { {0x4cbb0009,0x629820b0,0x60d60073,0x30130048}},	//   _פזמו, pevo, ikym, ндър
  { {0xe8040037,0x64460002,0xfa670055,0xfb1a0012}},	//   _रखना_, ecki, _наук_, _اقطع_
  { {0xceb3000b,0x4420000d,0xdc99002d,0xde180012}},	//   גית_, _azi_, овні_, تقدت_
  { {0x98ab000d,0x493b000b,0xa93b0009,0x993b0009}},	//   _mică_, _הגאו, _התאפ, _התאה
  { {0x70530012,0x66d30060,0x6b9d0227,0xa2ab0011}},	//   _أنها, _yıkı, uwsg, फ़ाल्
  { {0x8f9b000b,0xeb91000b,0x236d009b,0x4fd30024}},	//   _לידי, כָל_, šejo_, _яжіт
  { {0xbd870012,0x673d0fb5,0x79540012,0xbea3004c}},	//   _فنون_, _susj, فَّا, _чајк
  { {0x3d060037,0x212900b6,0xd5fb0009,0x5dfb0009}},	//   षकों_, umah_, _לפור, _לפונ
  { {0x47350681,0x7d0e0034,0x657a0245,0x26ca20b1}},	// [5370] днас, łosó, luth, _bobo_
  { {0xb999002d,0x692a0aec,0x3f1420b2,0x42550012}},	//   _двох_, _křes, едус, _تندر
  { {0xddcd0010,0x764503ab,0xdb190034,0x83fd0031}},	//   _įkūr, rchy, zywó, _idői
  { {0xe4e4002d,0x94190015,0x66150066,0x66d3003a}},	//   нічн, ожет_, _vyzk, _sıkı
  { {0x0b44002d,0x6f020025,0x0ba80012,0xcb69004c}},	//   енін, éocc, كاوى_, цале_
  { {0x90d50020,0x4fd6000b,0x67ba0009,0x77ba0009}},	//   _cùn, _חושב_, _ומשק, _ומשח
  { {0x26fb0044,0x90d5001a,0xceb20009,0xc6920009}},	//   ्वीर_, _dùn, _בים_, _שאל_
  { {0x2369001c,0x26dc0017,0xd83e0159,0xe1f00012}},	//   _ovaj_, _alvo_, ščno_, دسه_
  { {0x3f8902b7,0x7e6120b3,0x09ba0011,0xb8f50011}},	//   ntau_, talp, _उप्य, _सक_
  { {0xef160047,0xe3b00003,0xcee90024,0x68fb01e3}},	//   ммы_, _حرف_, ідне_, snud
  { {0x692a0066,0xe7180009,0xfc3f01e3,0xddc10073}},	//   _přet, החזר_, rdín_, malū
  { {0xd7d50001,0x661d0066,0xb4ca0011,0x2d67001b}},	//   _ожењ, řsko, ोसे_, rđe_
  { {0x78a9001e,0x240a0024,0x69130060,0x78a620b4}},	//   mdev, інги_, hçes, _rakv
  { {0xc724007c,0xed590046,0x66d20028,0x78a90f85}},	//   _здій, _док_, _tæki, ldev
  { {0x78a6007a,0x692a0066,0x7d0f0031,0x60c40159}},	//   _pakv, _třet, bocs, tjim
  { {0x387f20b5,0xd87a0012,0x693c001b,0x80c00011}},	//   ngur_, تمرت_, _očev, वाये
  { {0x59ba0044,0xf772000a,0x60d60010,0x13060198}},	// [5380] _उपकर, ضاء_, rkym, _озим
  { {0xde8e001a,0x29000010,0x63a40175,0x78a9008e}},	//   _lịng_, čiai_, _isin, hdev
  { {0x27260020,0x78a617b4,0x7abb0009,0xaabb0009}},	//   hông_, _takv, _וציו, _וזיכ
  { {0xdb00000f,0xc689000b,0x60cb0070,0xc9530009}},	//   _ismé, יא_, _nogm, _שמר_
  { {0xa294002d,0x4432004a,0xcb670189,0x889b0009}},	//   еалі, äy_, даче_, _ובכי
  { {0x61010039,0x64490017,0xf773000b,0xed5a06fd}},	//   vēla, _efei, _בקש_, _мог_
  { {0x60cb0058,0x90d5001a,0xcb070012,0x629c20b6}},	//   _bogm, _vùn, بيون_, iero
  { {0x387f20b7,0x629c0cdf,0x61e30060,0x61010035}},	//   ggur_, hero, _ünle, tēla
  { {0xe2920003,0x47340015,0x3ea70060,0x90d50081}},	//   _لذا_, ннис, _bant_, _tùn
  { {0x692a0013,0x66cd0029,0x2018001e,0x61f9000e}},	//   _přes, _súkr, āri_, áblá
  { {0x9e77000b,0x63a420b8,0x3eb80060,0x6b960073}},	//   וגיה_, _asin, ırt_, _apyg
  { {0x3eb80031,0xa9aa0011,0xfc3f01e3,0xd9aa05f3}},	//   űrt_, चटीए, rdío_, चटीट
  { {0x97c60003,0x9b580014,0x3ea70033,0xdfd20003}},	//   _تتضم, мият_, _fant_, _جيش_
  { {0xab2b0012,0x629c20b9,0x6e9300ae,0xe69300ae}},	//   تسجل_, gero, _للها, _للهد
  { {0x8c3d00a1,0x63a40005,0x95c40003,0xdce2001e}},	//   _başl, _esin, _سيظه, gulē
  { {0x25f40037,0x6913003a,0x83fd0031,0xe7d20011}},	//   ्पनी_, eçer, _időv, _तथाप
  { {0x6d4e001e,0x6bd90012,0x629c20ba,0x6aba0227}},	// [5390] _atba, _رودس_, bero, _ontf
  { {0xdef80047,0x4a55002d,0x6913003a,0x78a9001e}},	//   мых_, _якос, tçes, zdev
  { {0x2d870061,0x64490052,0x61250031,0x63a40031}},	//   îne_, _pfei, lóle, _zsin
  { {0xcdf70009,0xfdf70009,0xe57f0035,0x200f005e}},	//   ומבי_, וצבת_, šķos_, ügis_
  { {0xdcfc0039,0x00760093,0xe667011f,0x2ca9068b}},	//   _aprē, _אתרי_, _отво, _maad_
  { {0xe8040037,0x66d20028,0x6b7c0009,0xde740012}},	//   _रखता_, _bæku, קרונ, _لدفع
  { {0xb87b0013,0xf9910012,0x8c3d0060,0x2f140032}},	//   _umís, ابت_, _yaşl, rägt_
  { {0x6aba008b,0x3a380009,0x32380009,0x3ea720bb}},	//   _entf, ורום_, וטון_, _sant_
  { {0x692a0066,0x6d5c0002,0x629c20bc,0xde8e0081}},	//   _přer, _zwra, yero, _vịng_
  { {0x92b40003,0xf6510012,0x78a901a0,0x3ffa0009}},	//   _لحما, دئة_, sdev, לִיא
  { {0xa3d70037,0x85b90003,0xc6920009,0xa2be0011}},	//   ानक_, سادس_, נאט_, शास्
  { {0x3ea720bd,0x98ac001e,0xa1560009,0x02a80011}},	//   _want_, īdī_, _נבנה_, _छोड़न
  { {0x93430015,0xdcf5001e,0x3ea704b8,0x36d50696}},	//   лняе, _apzī, _tant_, _подр
  { {0xcee80012,0xc7d60009,0x629c01e3,0xbd450012}},	//   _يرون_, _רוסי_, uero, _كنتي
  { {0x682a000e,0x0219002d,0xdb0d0061,0x2b890081}},	//   ködé, діть_, _traî, húc_
  { {0x63a4002c,0xe4c90012,0xe45f1028,0xdfd20012}},	//   _tsin, _يبين_, ljön_, هيز_
  { {0x1da70037,0x2b890029,0x63a420be,0xd00700de}},	// [53a0] गिकत, júc_, _usin, еете_
  { {0x5ea60003,0xa3b30037,0x8b570009,0xef1720bf}},	//   عمال, टिन_, _רייס_, ему_
  { {0xda5b000b,0x69c10051,0x6101001e,0x21390ccb}},	//   _מכיל, älet, vēln, _fish_
  { {0xe73a072b,0x8d5a0009,0x7ae30032,0x7c8320c0}},	//   _нем_, פכני, ehnt, гуше
  { {0x883b000b,0x98160012,0xbc670012,0x6d5c0031}},	//   _מתכו, _سبحا, رمون_, áraz
  { {0x68e40017,0x61050010,0x29000540,0xf9fa0009}},	//   lhid, mėla, lnia_, ּהֵמ
  { {0x7c96007c,0x6ee0000f,0xf2d30009,0xe45f0031}},	//   _прац, _több, רעו_, djön_
  { {0x7c24012e,0xada30024,0x3eaa0032,0x29120060}},	//   _ozir, _щасл, _habt_, noya_
  { {0xd252000a,0x63a4003a,0x2ca91730,0x0b1a0012}},	//   _منذ_, çind, _raad_, _فقرة_
  { {0x15f40044,0x2ca90005,0x61080066,0xf7730009}},	//   _आधार_, _saad_, děle, נקת_
  { {0x20d6007c,0x3ce00058,0xb95a0012,0x52d70009}},	//   _підс, _bliv_, _رجاء_, _רובע_
  { {0x3eaf001e,0xade30024,0x64400073,0xafe60048}},	//   ēgti_, уцьк, žmin, _поел
  { {0x29000d23,0x14d70009,0x61350159,0x693c0159}},	//   dnia_, תוכל_, _ošlj, _očes
  { {0x290005a9,0x2471001a,0x83fd000e,0x7c240035}},	//   čiau_, ễm_, _időt, _dzir
  { {0xe919002d,0xd6270001,0x7af5000e,0x59a60037}},	//   дові_, _поље_, rizt, _कैमर
  { {0x5ba7002d,0xd7e7002d,0x62850002,0x361b0009}},	//   _зроз, нізо, _wcho, _מווד
  { {0x2d9800c1,0xa6db0097,0x62850025,0x69c80474}},	// [53b0] _apre_, _auða, _tcho, øder
  { {0x7d040013,0x290020c1,0x2139002a,0x93fc000b}},	//   _zjis, ania_, _wish_, _מלחי
  { {0x53360009,0x8e840012,0x291201e3,0x313500af}},	//   _שנתן_, المه, boya_, _ֹנָם_
  { {0x693c0013,0x6101001e,0x68e420c2,0xdb08008e}},	//   _včet, vēlo, chid, älöi
  { {0x78ad0010,0x5c140021,0x2ca90064,0xdb0903a7}},	//   mdav, льшу, ľad_, _areá
  { {0xbb52000a,0x6101001e,0xe2960345,0x78ad20c3}},	//   جنوب, tēlo, ваш_, ldav
  { {0x692a0013,0x8aac0009,0xe9a80012,0xbb180012}},	//   _přep, לֹהֶ, فدين_, رزها_
  { {0xf1b40009,0x78ad20c4,0x776920c5,0x84640048}},	//   רסק_, ndav, tsex, _бъфе
  { {0x6009002d,0x0b940012,0x93940012,0x27e901e3}},	//   ьним_, _مجلد, _مجلا, nzan_
  { {0xf1b30044,0x81c3001e,0xcf92000b,0x8f9c000b}},	//   ुमान, ģēji, סטי_, ליחי
  { {0xb8950003,0x1d0a00f5,0x40950012,0xc4d50011}},	//   _للاع, дени_, _للار, _दवाओ
  { {0x43460014,0x7649003a,0x23690027,0xcb09000b}},	//   кемв, _şeyl, šaju_, _ול_
  { {0x83fd000f,0xe6c50003,0x20d10028,0x3ce00066}},	//   _idős, _لتغي, _fáir_, _vliv_
  { {0x8c3d00a2,0x60db0039,0x29000002,0xfbd20009}},	//   _başk, lkum, wnia_, סתם_
  { {0x3f8d03eb,0x45d20001,0x9f400029,0xf8bf001a}},	//   lteu_, _војс, rzií_, _chéo_
  { {0x7d040013,0xa7fb0164,0xb903003c,0x443f0081}},	//   _ujis, _seña, азск, _ngu_
  { {0x2d9820c6,0x60db001e,0x3f8d0054,0xa68602c4}},	// [53c0] _spre_, ikum, nteu_, клад
  { {0xdfcf000a,0x5b7b000b,0xd37b000b,0x6d430051}},	//   غيل_, _קריא, _קריט, _kuna
  { {0x60db0176,0x60c90033,0xdca606fd,0x781e0011}},	//   kkum, kjem, кажи, _पर्क_
  { {0x385a0012,0x7ae120c7,0xa9470009,0x6d4320c8}},	//   _تشدد_, _allt, _בָךְ_, _muna
  { {0x31da0037,0xd4670001,0x33940003,0x3eab004a}},	//   बन्ध, тиче_, التز, öitä_
  { {0x63a220c9,0x66d20040,0x7cf60035,0x600b0009}},	//   rwon, _væks, kšro, _חִלְ
  { {0xa9c30014,0x693c0027,0x98a00027,0x1e970009}},	//   исък, _učes, gmić_, _שכלל_
  { {0x60db002c,0x7c3b001b,0x61080030,0xb05b0032}},	//   gkum, žuri, dělc, _gnäd
  { {0x673c0b38,0x68e3000d,0xbb4600de,0x7d020aae}},	//   _kirj, _înde, _резк, mnos
  { {0xb996000a,0x661c006f,0x78ad1187,0x9a6a0012}},	//   _للطب, _kyrk, zdav, _آمال_
  { {0x6d440026,0xeab1000b,0x867b000b,0xa4d5002d}},	//   _čias, _לֹא_, וריו, гоні
  { {0x3eb9001e,0x9f64000e,0x83fd000e,0x3f8d0054}},	//   ēsta_, ától_, _időr, bteu_
  { {0x69d500a2,0x3f8d0054,0x7d0210bb,0x9f9c0097}},	//   _üzer, cteu_, inos, _gæða_
  { {0xdd900012,0xa3b30011,0x67da0035,0x3f8001a0}},	//   _هوت_, टित_, _mājā, duiu_
  { {0x6d4300b6,0x7b05001e,0x661c008e,0x61ea0032}},	//   _guna, _ērtā, _nyrk, nzfl
  { {0x8637000b,0xce370009,0xff530012,0xb6370009}},	//   _ברוב_, _באות_, لخط_, _ברוס_
  { {0x78ad1fe8,0x31340001,0x3f8008c8,0x6d4320ca}},	// [53d0] rdav, ретр, guiu_, _zuna
  { {0x64490010,0xe7190003,0x60db0066,0x6d43045b}},	//   žeid, ريات_, zkum, _yuna
  { {0x60cf000d,0x28c50037,0x673c00b6,0xed580024}},	//   _tocm, वामि, _dirj, воє_
  { {0x3d0d0011,0x3f800018,0x61250097,0x657a20cb}},	//   िकें_, buiu_, kóla, irth
  { {0xdfc6000a,0xf8bf0026,0xb0b60037,0x64410002}},	//   _اي_, _iné_, _अफ़ग, śliw
  { {0x7bdc000b,0x38690070,0xa9270029,0x61350010}},	//   וקדו, laar_, _obľú, _išli
  { {0xc3340009,0x69d80735,0x7d0220cc,0x70550012}},	//   בוס_, gyve, bnos, هنغا
  { {0x3ea10005,0x38691730,0x60db1609,0x3eaf001e}},	//   leht_, naar_, ukum, ēgtu_
  { {0xbebc001e,0x60c900b6,0x6125000e,0x60db12d7}},	//   klīd, rjem, góla, rkum
  { {0xfe71000a,0x6d440029,0x4ec50024,0xd706003c}},	//   حدة_, _čiar, уйов, лные_
  { {0x38690070,0x3f8d0054,0xb9550014,0x99890002}},	//   kaar_, steu_, _свещ, łał_
  { {0x3f8d0054,0x4c830024,0x3d000011,0x38690227}},	//   pteu_, блюв, ोकें_, jaar_
  { {0xd1100037,0x2d810052,0x2bba0012,0x38690227}},	//   ावरण_, huhe_, راحة_, daar_
  { {0xa6b40014,0x6d430a60,0x877a0009,0xdb0901a0}},	//   _всъщ, _tuna, _נאצי, _dreç
  { {0xc692000b,0xdc200011,0xcdc80012,0x7d020034}},	//   _האו_, _बर्ड_, _لذين_, ynos
  { {0xc4860046,0x3d0d0037,0xbebc001e,0xe45f000e}},	//   _слик, िकों_, alīd, zköz_
  { {0xd36f0003,0x93960012,0xdd040035,0x291f008e}},	// [53e0] _فهي_, _إجبا, šsēd, ilua_
  { {0x661c004a,0x3ea10032,0xc2c60012,0x3f800018}},	//   _pyrk, geht_, _إيدي, ruiu_
  { {0x38690070,0xd83e0010,0x63a920cd,0xa2c20011}},	//   baar_, ščio_, _asen, लास्
  { {0x98ba007d,0xb97b000b,0x5983002d,0x938a00f5}},	//   _după_, _אנטי, _улюб, еска_
  { {0x7af80013,0x254c0066,0x63a90031,0xe45f0031}},	//   tivt, _měla_, _csen, tköz_
  { {0x61080066,0x4ed50048,0xbb470012,0x1fb20011}},	//   děla, _кюст, دلون_, ीमीड
  { {0xbea30001,0xd2590024,0x3ce60248,0xc27b0009}},	//   _ћаск, тці_, phov_, גרצי
  { {0x6ad10044,0x58d40104,0xe6170345,0x91b70012}},	//   _सक्र, роит, _сдс_, اطور_
  { {0xdfd00003,0x5ea40012,0x03a90012,0xd6d00012}},	//   زيد_, لمظل, _لدلو_, ققة_
  { {0x539b000b,0x83fd000e,0x2a6a000e,0x6125000e}},	//   _אימו, _időp, jabb_, róla
  { {0xa3ac0044,0x69c5083c,0x02d50d60,0xff170009}},	//   गिक_, ähet, _тютю, רקית_
  { {0x7056000a,0xc5f3000b,0xdb090017,0x291f0017}},	//   _إنشا, מדת_, _preç, clua_
  { {0x8c3d000d,0x9be40024,0xd0100012,0x8ae70024}},	//   _paşi, бірк, _ظلت_, гівл
  { {0xa7fb0164,0x38690227,0x2a6a0031,0xb87b20ce}},	//   _seño, waar_, gabb_, _clín
  { {0x31c405cc,0xda35003c,0xca480012,0x386920cf}},	//   бств, ревы, الفه_, taar_
  { {0x3eae20d0,0x671d0011,0x905505d8,0x2120001b}},	//   _haft_, _बीजक_, рвац, glih_
  { {0xf7700003,0x3ea10052,0x70c50011,0x38690227}},	// [53f0] كال_, teht_, _लचील, raar_
  { {0xc7d7000b,0x44290027,0x26de0010,0xa3b30011}},	//   אומי_, _iza_, nkto_, टिस_
  { {0x71270003,0xbb3a0009,0x867b0009,0x07080012}},	//   _مرحل, _שעתי, תרבו, ديلي_
  { {0x7bd90002,0xddc1000d,0xa8a7004d,0x2d810032}},	//   tywu, lalţ, _срок, ruhe_
  { {0x3cfd0037,0xb464002d,0x8c480024,0x69c8005e}},	//   _लगने_, скіл, упів_, ädev
  { {0x6125003e,0x3f98000d,0x3eaf001e,0xe29920d1}},	//   góln, ărul_, ēgts_, так_
  { {0x60cd007a,0x3abc000b,0xbdd50024,0x45d50024}},	//   ojam, תמונ, _товщ, _товс
  { {0x6fb50003,0x39590066,0x3b550014,0xdfd10003}},	//   لمعا, _čssd_, _вкар, قيع_
  { {0x6d4700b6,0x82870003,0x6d4e0164,0x00c6003c}},	//   _huja, _مجال, íban, рлык_
  { {0x59670098,0x8c3d00a2,0xca480012,0x60cd005e}},	//   _бъда, _başv, _ملكه_, hjam
  { {0x28c50037,0xf2c4010c,0xf62505c6,0xb2ba0009}},	//   वादि, _устн, рдно, _שמער
  { {0x38690065,0x6287000e,0x895a0009,0x5dc80009}},	//   _þar_, egjo, _ידעת, אֶשְ
  { {0x8934000a,0x7d09001c,0x68e91847,0x99890002}},	//   _اعلا, _mjes, mhed, łań_
  { {0x60cd0039,0x7e670066,0x644f00c1,0xbebc001e}},	//   ejam, _nejp, acci, alīb
  { {0x70f6002d,0xe0460015,0x2a6a000e,0x27ed03de}},	//   ачає, инви, rabb_, lzen_
  { {0x2a6a000f,0xe3ba002d,0x6aa30052,0x68e918bd}},	//   sabb_, _аби_, henf, nhed

  { {0xb8fe015f,0x27ed03e4,0x9d1b000b,0x96660015}},	// [5400] _तक_, nzen_, _שופט, икае
  { {0x63a900a2,0x442000a2,0x9e3a0003,0xe9da0ac5}},	//   çene, _iyi_, نساء_, _ако_
  { {0x546a0593,0x6aa3205a,0x427b0009,0x4a7b0009}},	//   ваем_, denf, _באיג, _בריב
  { {0x7afc00a2,0x60cd0002,0xb3860012,0xdd8f0012}},	//   lirt, cjam, لجته, ظون_
  { {0x7c29003e,0x27ed0070,0x68e3000d,0x61010035}},	//   _czer, jzen_, _înda, cēli
  { {0x66e60014,0x9bb70009,0xa2f30024,0x957c0034}},	//   _тога, יהנה_, опіч, cząw
  { {0x7afc004a,0x3a3a006f,0x27ed1d31,0x7c2910d8}},	//   iirt, äpp_, ezen_, _ezer
  { {0xa3e60044,0x68e91f97,0xc953000b,0x7d090033}},	//   पना_, ghed, חמה_, _gjes
  { {0x6125003e,0xd0100003,0x7afc03ab,0x9cb30012}},	//   póln, ثلة_, kirt, _بمقت
  { {0x7d1b0013,0x501b0009,0xf76f0012,0x752220d2}},	//   _zkus, כופו, ذاً_, lloz
  { {0xc04f002d,0x78a40010,0x4b370009,0x10a60048}},	//   _мі_, keiv, _כרמל_, _виен
  { {0xf1b30011,0x4c95003c,0x68e920d3,0x645d016d}},	//   ंटरन, щимс, ched, ubsi
  { {0x8f540003,0xdcfc001e,0x69da00b0,0x692a0030}},	//   _انتش, _aprī, øten, _ořez
  { {0x61010039,0x6e940003,0x3f8420d4,0x3f91000d}},	//   vēli, _طلبا, mumu_, ăzut_
  { {0x5d84000a,0x89370003,0xdcfb001e,0xc1050003}},	//   _العل, لعرا, autā, موسي
  { {0xe63b0093,0x6d40009b,0xacf40003,0x60cd0010}},	//   _בתוכ, _nima, _وسيت, ujam
  { {0x692a0066,0x75220027,0xd3710003,0x33950003}},	// [5410] _břez, dloz, _عهد_, _الخز
  { {0x63ad01e5,0x4545000a,0x8f57000b,0x33fc000b}},	//   _isan, منطق, יסמא_, _שהזנ
  { {0x7c2920d5,0x27ed000f,0xdb0d00a2,0x254c0066}},	//   _szer, zzen_, _araç, _mělo_
  { {0xbd18007c,0x4518007c,0x3f840039,0x78a40036}},	//   ації_, ація_, kumu_, ceiv
  { {0x3f840333,0x8c3d000d,0x889a000b,0x28c50037}},	//   jumu_, _naşt, _גברי, वासि
  { {0xa3b80037,0xa036000b,0x3f84001e,0x60c220d6}},	//   छित_, _לארה_, dumu_, _anom
  { {0xfa78000b,0xddda0066,0xa3a90037,0xd24e0003}},	//   בעות_, patř, _गैस_, رني_
  { {0x27ed20d7,0xf8a70037,0x8c3d003a,0x63540066}},	//   tzen_, ख़िय, _başt, něný
  { {0xef190014,0x3f840708,0xdb0d0017,0x68e90f00}},	//   лми_, gumu_, _graç, rhed
  { {0x39b50039,0x06c90047,0x60c2006f,0x0d8504ac}},	//   _tās_, угой_, _enom, блон
  { {0x44260333,0xa6db0065,0x6da50014,0x27ed000e}},	//   _šo_, _auðk, щина, szen_
  { {0x7afc0052,0x7d190120,0x4c830024,0x33d60024}},	//   wirt, nows, плюв, бігт
  { {0x69c10033,0x7afc0a4e,0xeb97010c,0x386d0623}},	//   ålen, tirt, бия_, maer_
  { {0x8c1a000b,0x752213a3,0xa3d80011,0x7d190034}},	//   רושי, zloz, ाहत_, hows
  { {0x41b50098,0x7afc0065,0x63ad007a,0x69dc003a}},	//   остт, rirt, _esan, _üret
  { {0x7d190034,0x26c30018,0x7ce60064,0xdcfb0035}},	//   jows, _anjo_, _fóra, putā
  { {0x6d4000c1,0x4426001a,0x692a0066,0x7d190002}},	// [5420] _rima, _áo_, _přez, dows
  { {0x52aa0001,0xd308001a,0xa7850012,0x6d4020d8}},	//   _свом_, iệc_, تشفو, _sima
  { {0x610c00a2,0x69c80033,0x41a60011,0x63bb20d9}},	//   ağla, åded, _कैंस, _arun
  { {0x3ea5002e,0xdb0d0017,0x98be004b,0x1c1c0011}},	//   helt_, _praç, _mută_, _नडाल_
  { {0x2d85074f,0xd91b0009,0x26180011,0xb8ec0011}},	//   hule_, _תוכל, _बुरी_, ला_
  { {0x3f840039,0x2d8520da,0x539b0009,0x63bb20db}},	//   vumu_, kule_, ריסו, _drun
  { {0xa9670001,0x21670001,0x9da50012,0x63bb0032}},	//   бија_, бији_, _وصفه, _erun
  { {0x63bb000d,0x1754010c,0x99470003,0x9f540055}},	//   _frun, овия, حليل_, ович
  { {0x39420005,0x1eaa0012,0xf8b30009,0x2d850025}},	//   _miks_, هادي_, לשה_, eule_
  { {0xb6c60047,0xd36f0003,0x67530003,0x3f840b1a}},	//   ссий, _أهل_, أخير, rumu_
  { {0x2d850051,0x79530012,0x7abb0009,0xdcfb004b}},	//   gule_, _فَلا, _תצבו, jută
  { {0xf1b30093,0x6fc80037,0x63ad0066,0x27220028}},	//   _מסע_, रमां, _psan, iðni_
  { {0x8fa30047,0xda7b0024,0x28c50011,0x254c0030}},	//   _наце, ляв_, वारि, _tělo_
  { {0xde58002d,0x78250003,0x3ea5001e,0x248d0002}},	//   _такі_, _بعمل, celt_, żem_
  { {0xf3f9007d,0x6105007a,0x31c40001,0xa3a90037}},	//   _veţi_, lėli, пств, _गैर_
  { {0xa3d80011,0xd13000ae,0xc15700af,0x7ce620dc}},	//   ाहा_, ّمِ_, משלו_, _tóra
  { {0xa49b0054,0x63ad20dd,0x4f580012,0x2ca6005e}},	// [5430] riòd, _usan, مجلد_, deod_
  { {0xba990024,0x7f740024,0x7c2d20de,0x975700af}},	//   _твоє_, ягує, _izar, ציבו_
  { {0x957c003e,0xfe700003,0xbf370009,0x7e9b0009}},	//   cząt, عدك_, מאמץ_, רסבו
  { {0xa634002d,0x3ea520df,0x69c800b0,0x61050073}},	//   їнці, zelt_, ådee, kėli
  { {0x3f800054,0xe28e0103,0xdfdb0048,0xd37b033d}},	//   criu_, ма_, _сън_, уче_
  { {0x68ed0149,0x6d580027,0xa5e70a2c,0x61050073}},	//   lhad, _otva, _любл, dėli
  { {0x2360001e,0x2909004a,0xda7801d4,0x272f0060}},	//   ģija_, onaa_, сяч_, güne_
  { {0x63bb0020,0x68ed0017,0xfbdf0017,0x6913003a}},	//   _trun, nhad, ncês_, tçey
  { {0x44390149,0xa6db0028,0x6d58134f,0x98be000d}},	//   _às_, _auði, _atva, _sută_
  { {0x7d0d01a3,0x8d750012,0x0a68004c,0x5187076b}},	//   _ajas, ياجا, _грци_, _гуда
  { {0x3cca0ac5,0xca480012,0x7d0a004c,0x7ac4003c}},	//   ално_, _المه_, иног_, _эсте
  { {0x3ea503fb,0x6101001e,0xf2c9000b,0x2d81004a}},	//   selt_, tēlu, _בע_, irhe_
  { {0x7c2d0002,0xd5b8001e,0x79950052,0x2d8503ae}},	//   _czar, avā_, etzw, sule_
  { {0x7ce60002,0xe7560003,0x2d850ecd,0x55e500f5}},	//   _górn, _بلوغ_, pule_, _молб
  { {0xc5d5002d,0x442d0066,0x39420034,0x99e90009}},	//   _філь, _lze_, _piks_, בַּ֥
  { {0xa926007c,0xa3e90037,0xe4520012,0xfc3f01e3}},	//   ідал, मना_, _غضب_, seía_
  { {0x6d4a0032,0xdcfb0035,0x3f800073,0x69c809bc}},	// [5440] _zufa, attē, uriu_, ådeb
  { {0x98b9001e,0xb7d70012,0x7d0d0030,0x3f800018}},	//   _visā_, غولا_, _zjas, rriu_
  { {0x39420039,0x412a002d,0x6da60003,0x8d660024}},	//   _tiks_, _воно_, تمام, івде
  { {0xc7b9000e,0x3f80000d,0x0c261543,0x98be0035}},	//   kvő_, priu_, омен, ītē_
  { {0xbebc001e,0x442d0034,0xf7720012,0x6d580031}},	//   dlīn, _cze_, _تاج_, ívab
  { {0xe81d0037,0x6d44019a,0x272f0060,0x61050073}},	//   _पड़ा_, _liia, tüne_, vėli
  { {0x84e6002d,0x442d0070,0x6ecd0037,0x44a60012}},	//   _довж, _eze_, तानु, _وحرّ
  { {0x6d5e0006,0x68e40051,0x39420c1a,0xfe430024}},	//   mppa, nkid, öks_, _інто
  { {0xc6f8007c,0x68e40051,0x6d58080a,0xb87b0028}},	//   йних_, ikid, _stva, _slík
  { {0x232a0098,0xf5490020,0x35f4077e,0x42530012}},	//   _този_, _vấn_, зпор, _ينقر
  { {0xf6530093,0x68e40051,0x7e6a0028,0x7c2d0053}},	//   וצת_, kkid, _vefp, _szar
  { {0x26d801a2,0xf549001a,0xd48f004c,0x9c830ca4}},	//   _loro_, _tấn_, ерy_, _účtu
  { {0xb4270012,0x7b1f0018,0x93270012,0x309b00af}},	//   تعدو, pêut, قرآن, _כשאמ
  { {0xdb000052,0xcf260012,0x75d60012,0x2967004c}},	//   _ermö, _برصي, _ويشا, жњав
  { {0x5b14007c,0xe6c90037,0x286b0001,0x306b0001}},	//   ємст, रासङ, ирао_, ијан_
  { {0xd7770003,0x61080066,0x32f60034,0x5ba70198}},	//   قاطع, dělk, pływ_, _дроз
  { {0x68ed00c6,0xd7940014,0x7d1d20e0,0xff500012}},	// [5450] rhad, митъ, moss, نخل_
  { {0x7d1d20e1,0xd5bb06fd,0x6f790009,0xe73f0018}},	//   loss, исе_, מְעו, _opõe_
  { {0xde190012,0x25480060,0x442d0031,0x69c1162e}},	//   حقات_, _oğlu_, _sze_, æled
  { {0xe4e4007c,0x83fd000e,0x3eb9001e,0xfe370009}},	//   мічн, _időz, ēsti_, קראי_
  { {0x27f20002,0x00560009,0xa3a70012,0xc7b90031}},	//   czyn_, _משרת_, تحان, _éő_
  { {0xa6db0065,0x6d020037,0x883a000b,0x0ac70015}},	//   _auðv, _लगभग_, _לתרו, ющем
  { {0xddc3000d,0x1a7c0009,0x7d1d150e,0xc27c0009}},	//   _menţ, שְׂמ, koss, ברוי
  { {0x88c90024,0xf8bf0081,0xf8c50011,0x545520e2}},	//   слив_, _ghét_, वाइय, _хват
  { {0xd12e0003,0x8bb70003,0x7d1d20e3,0x44240077}},	//   دمي_, _بإزا, doss, _gym_
  { {0x6d440051,0xb05b006f,0x2ed60009,0xa3d80011}},	//   _siia, _snäl, ִֽים_, ाहर_
  { {0x1c010037,0x32b80003,0xa3b30037,0x44240034}},	//   _लेबल_, _بدقة_, टिक_, _zym_
  { {0x692c0052,0x499a000b,0x399a0009,0xc2120009}},	//   eßen, _לשעב, _ליעד, _אהב_
  { {0xddd5000f,0xd3080020,0x6d440051,0x7d0b0010}},	//   _mező, iện_, _viia, ings
  { {0x8c1a000b,0x6fb20003,0x5e450003,0xfbd20009}},	//   מורי, _أموا, _عَبْ, עתם_
  { {0xc332000b,0x7ced0025,0x26c720e4,0xdb1b0ef6}},	//   גום_, _sûre, _inno_, _crué
  { {0xaac70037,0x993a002d,0x7d7a000b,0x4dda0009}},	//   लाँक, сягу_, _הנקו, _לחצו
  { {0x68e40051,0xdb040028,0x8fa320e5,0x2ca020e6}},	// [5460] rkid, _frið, нате, _ibid_
  { {0x63a40101,0xc7230015,0x98a90002,0xabfb000b}},	//   _ipin, едуй, ymać_, _להפר
  { {0x7ae1000e,0x32db000b,0xf769000b,0xc3330009}},	//   ölte, _החינ, רק_, _רות_
  { {0xdc98002d,0xdcfb001e,0x19570009,0x44980024}},	//   івлі_, ortā, _מבטל_, івлю_
  { {0xaac70037,0xbbe90003,0x88bb0009,0xe8d70009}},	//   लांक, يرهم_, _הזכי, _זוכר_
  { {0xe7370098,0x539b000b,0xf96a0024,0x629c20e7}},	//   _нея_, מינו, брий_, nfro
  { {0xf5490020,0xa9670001,0xe5a30294,0x2167004c}},	//   _bấm_, пија_, _пири, пији_
  { {0xacea000a,0x44241bb8,0x26c700c1,0xf549001a}},	//   _ارسل_, _tym_, _anno_, _cấm_
  { {0x40530351,0x272b00b0,0x7d1d20e8,0x7afe1f5f}},	//   رئيس, rønn_, voss, _ompt
  { {0xd24f0003,0xb23a0003,0xcff7000b,0x6207000e}},	//   _منك_, _هكذا_, פציה_, árlá
  { {0x18a60047,0xba1a000a,0x6125000e,0x10a60109}},	//   _нажм, _ايضا_, zóli, _нижн
  { {0x7d022049,0x3ce620e9,0x6d4e20ea,0x2d780412}},	//   nios, nkov_, _muba, iče_
  { {0xa847000a,0x254c0013,0x6d4e0289,0xa2d30037}},	//   _علوم_, _měli_, _luba, बॉक्
  { {0xa03b0093,0x56930046,0xa77b000b,0x6d5c20eb}},	//   _העדפ, _зашт, _פרופ, _otra
  { {0x3a2500c5,0x569b0093,0xfe9b0093,0xd3080020}},	//   ælp_, _היוצ, _היומ, yện_
  { {0x7afe002a,0xc5eb0009,0x7db30012,0xd0d40048}},	//   _empt, _לַחֹ, _أصوا, носъ
  { {0x8498000a,0x3ce60a3d,0xc64b0003,0x6d5c20ec}},	// [5470] _رئيس_, dkov_, مجال_, _atra
  { {0x3f52001a,0xa6f80009,0x61250031,0x4a550223}},	//   _mâu_, קִּי, róli, _юкос
  { {0x94d5002d,0x3f52001a,0xa4d50024,0xaa9a0009}},	//   можц, _lâu_, можі, _ובתכ
  { {0xc2120009,0xc5f30009,0x16a90011,0xb87b0018}},	//   _יהי_, עדף_, _कस्ब, _alív
  { {0x212900c6,0xa6db0028,0xddc30042,0x6d5c20ed}},	//   mlah_, _suðu, _menš, _etra
  { {0xeb92000b,0x212920ee,0xd2990024,0xceb80034}},	//   דָה_, llah_, ітлі_, jdę_
  { {0x31560012,0x3ce60064,0x7bc00032,0x6f0120ef}},	//   ولوج_, bkov_, _ermu, vilc
  { {0x212900b6,0xac190447,0x47c50472,0x27340248}},	//   nlah_, _добу_, дбив, täng_
  { {0x3f520020,0x39460164,0x442b001a,0x6d5c0066}},	//   _câu_, _dios_, _ác_, _ztra
  { {0x60060015,0x2734006f,0x212900b6,0x0ea9003c}},	//   ьным_, räng_, hlah_, цкой_
  { {0x81bc001e,0x212900b6,0xf549001a,0x6b8b1dbd}},	//   _dzēs, klah_, _tấm_, lugg
  { {0xddc3001e,0xeb9a00de,0xc1050012,0x59a60011}},	//   _cenš, оим_, _توصي, _कैटर
  { {0x4c9a000b,0xc4760009,0xcc760009,0xceb80073}},	//   חברו, ותרו_, וגרת_, bdę_
  { {0x3f98000d,0x212900b6,0x63a4003a,0x6f7a000b}},	//   ărut_, elah_, çini, _וְהו
  { {0x3ced0051,0x6113000d,0xa022003a,0xda0d0011}},	//   _olev_, călc, _çözm, िपित_
  { {0x52da0044,0x74f70012,0x3eb90035,0x6b8b0097}},	//   _बक्स, _يفوز_, ēstu_, kugg
  { {0x2336007c,0xf092000b,0x6d5c1780,0x3ce6025e}},	// [5480] _охор, כנן_, _stra, vkov_
  { {0x212900b6,0xc9aa003c,0x61f50032,0xc956003c}},	//   alah_, _двое_, ßflä, _отмы
  { {0x27340163,0x3ced20f0,0x3ce602e7,0x55020037}},	//   vänd_, _blev_, tkov_, _लगाए_
  { {0x2d530017,0x61080066,0xd4670001,0xfce300f5}},	//   _mãe_, pěli, дице_, кохо
  { {0xe6f2001a,0xdb1b0054,0x1bf60011,0xd5b10081}},	//   hườ, _cruï, ीपटल_, _ấn_
  { {0x98b9007a,0x3ce60aa3,0x5e460012,0xda660012}},	//   _visą_, skov_, _يَحْ, ذاتي
  { {0x0566002d,0x3f52001a,0x7ce60002,0xf98f0012}},	//   _іван, _sâu_, _córk, لبي_
  { {0x57b4085b,0xf993000b,0xe611000b,0xceb80002}},	//   ебит, דרה_, _עִם_, wdę_
  { {0x69c11168,0x37aa0024,0xa6db0097,0x3eb820f1}},	//   _erle, ітин_, _guðs, _kart_
  { {0x98a30039,0xceb80010,0xddce20f2,0x1dc90011}},	//   ējā_, udę_, _nebū, िमंत
  { {0xceb3000b,0xe6f2001a,0xdb21000e,0xdd900012}},	//   דית_, gườ, _ítél, دوج_
  { {0x6ee403eb,0x41030014,0xa4d5002d,0xd3080081}},	//   _mòbi, _изхв, хомі, iệm_
  { {0x4432003e,0x69c800ad,0x29040c2b,0xd94305f7}},	//   _czy_, åden, mima_, _реци
  { {0x290420f3,0x1eaa0012,0xce940048,0x69c00035}},	//   lima_, _ذاتي_, _чакъ, āmen
  { {0x39150098,0x98a60002,0x212900b6,0xd915003c}},	//   емвр, _choć_, tlah_, едвы
  { {0xf8bf001a,0x43950001,0x67d50024,0x3d180011}},	//   _chép_, _заис, нобу, धकों_
  { {0xf7700003,0x0c740003,0x212900b6,0x26dc0010}},	// [5490] لال_, _شديد, rlah_, _kovo_
  { {0x212900b6,0x96070012,0x4429016d,0x3eb815d1}},	//   slah_, وبام, _iya_, _cart_
  { {0x33180003,0x61e1006f,0x2d8c16a0,0x3eac0227}},	//   _تزيد_, älld, nude_, iedt_
  { {0x2904001c,0x395e000e,0xd7fb004c,0xf8bf0081}},	//   jima_, ítse_, _дуг_, _ghép_
  { {0xcb690015,0xf0440015,0x00f6000b,0x7d0f000e}},	//   чале_, _аэро, _נמשך_, incs
  { {0x41b50a15,0x78a2002a,0xb0620051,0xeb920009}},	//   есит, _abov, _äärm, רָא_
  { {0xcad80009,0x6b8b0227,0xdb020032,0x2d8c20f4}},	//   ווגת_, sugg, stoß, jude_
  { {0xfa0d0020,0x290d007d,0x78ad007d,0x2d8c0051}},	//   _đầu_, unea_, neav, dude_
  { {0x4429194b,0x61e30260,0x60090024,0x63050012}},	//   _nya_, synl, яним_, _كورل
  { {0x644d0036,0xf8ac0037,0x0ab80003,0x61080030}},	//   _agai, _चस्प, _يطلب_, dělu
  { {0x2d8c0051,0xead40014,0xe7180009,0xf5060a8b}},	//   gude_, _шофь, וחזר_, езно
  { {0x998d003e,0x290420f5,0xc3290009,0xe6f20081}},	//   łeś_, cima_, _הו_, rườ
  { {0x9fe70012,0x7d0a0097,0xf3f20009,0x78ad20f6}},	//   _تساه, éfsi, ָ֣ר_, deav
  { {0x69c80033,0x3eb9001e,0x2d8c0107,0x78bb20f7}},	//   ådeo, ēsts_, bude_, lduv
  { {0xf8bf0020,0x28d30044,0x56920001,0xa49b0054}},	//   _phép_, थापि, _сајт, gnòs
  { {0x395e0039,0xa3cf0037,0x78bb0051,0x69dc0054}},	//   īts_, षमा_, nduv, _àree
  { {0xf7720003,0x13b60003,0x3f8d0054,0x1fa70024}},	// [54a0] طاء_, _أصبح, nueu_, нкти_
  { {0x8c1b0093,0x2904187a,0x441b0009,0xbc1b0009}},	//   _מופי, zima_, _מופס, _מופש
  { {0x6e930003,0x68e903ee,0x3eb8130b,0xcb130009}},	//   الما, kked, _vart_, _תלת_
  { {0x61e120f8,0x290420f9,0x6e170012,0x7d0620fa}},	//   älle, xima_, رينس_, niks
  { {0x2904001c,0xa294002d,0x2bc30011,0xd4090012}},	//   vima_, валі, शिया, وتهم_
  { {0xd24f0012,0x60cb020d,0xb87b07ef,0x3f8d159b}},	//   منه_, _angm, _flís, dueu_
  { {0xee2a0012,0xe5060012,0x49b70012,0x67210a35}},	//   _رأسه_, _كبري, فايد_, dolj
  { {0x859b000b,0xd3720012,0x7bc420fb,0x1543004c}},	//   _משלו, _مهر_, _oriu, _бесм
  { {0x3f8d03eb,0x6d5a0061,0x6133003a,0x26dc0017}},	//   gueu_, _étab, nçla, _povo_
  { {0x7d060213,0x290420fc,0xf1e00011,0xd80b0009}},	//   eiks, sima_, नहान, לִיָ
  { {0xa3d80037,0xf56e0024,0x69da008e,0x2d8c005e}},	//   ाहक_, акiв_, ätel, uude_
  { {0x2d8220fd,0x2d8c20fe,0x68e920ff,0x753d0031}},	//   čke_, rude_, cked, umsz
  { {0x6721048b,0x70530003,0xf8b3000b,0x66e61700}},	//   bolj, _إنها, _תשנ_, _пода
  { {0x7f170012,0xd5b00012,0x26dc00b8,0xf7170012}},	//   _كينز_, _نفت_, _uovo_, _كينغ_
  { {0x28c50044,0xd657000b,0x78ad204d,0x1e570009}},	//   वाचि, _איות_, teav, _אשור_
  { {0x88bd003e,0x61f5000f,0x765c0002,0x6ec80011}},	//   mośc, _üzle, _afry, ़ाकु
  { {0xdb07003a,0xff530003,0xab62003a,0xcaa70012}},	// [54b0] _ölçe, اخر_, şüre, _كصدي
  { {0x68e9000e,0xf7840012,0xd7c80012,0x8f8b0009}},	//   zked, اللَ, عوله_, לְבֵ
  { {0x88bd003e,0x6d49001e,0x61080066,0xbd4b0003}},	//   nośc, _piea, něls, سؤال_
  { {0xd5b1001a,0x6721000e,0x16380012,0x69c5008e}},	//   _ấm_, zolj, رسلة_, _irhe
  { {0x38692100,0x98ab0002,0x68e90060,0xeb9919c8}},	//   mbar_, _chcą_, vked, фил_
  { {0x88bd003e,0x6b9d0052,0x7d06003a,0x8afd0030}},	//   kośc, itsg, ziks, _otře
  { {0x6721048b,0xd2b80009,0xab5d0034,0x41b200ae}},	//   volj, גלות_, _drża, لمور
  { {0x61080066,0x2d57003a,0x9f5201e9,0x38692101}},	//   děls, _içe_, ždým_, nbar_
  { {0x75eb000e,0x78bb0051,0x68e92102,0x67210ebc}},	//   közö, rduv, rked, tolj
  { {0x2caf0070,0x7fe80003,0x38690052,0x3f83017b}},	//   legd_, عريف_, hbar_, čju_
  { {0xee39064f,0x88bd05a8,0x30e7002d,0x95850014}},	//   ьно_, gośc, _підб, ълне
  { {0xd7d10037,0x69c80033,0x67212103,0xc1780003}},	//   समाच, ådem, solj, _أصلا_
  { {0x3f8d03eb,0x9cd6000b,0x547a0009,0x2ef500f5}},	//   queu_, דורה_, וטרו, _издр
  { {0x2d6e0066,0x7d062104,0x8b880009,0x88bd0034}},	//   bře_, siks, עָרֶ, bośc
  { {0xc92a002d,0xdb09005e,0xb87b0018,0x38690032}},	//   довж_, _iseä, _alíq, fbar_
  { {0x99430003,0x63a92105,0xc6160009,0x6ba50248}},	//   لَّه, _open, _בחצי_, åtgä
  { {0x41270014,0x69c50052,0x657c0027,0x6bd70003}},	// [54c0] тото_, _erhe, _svrh, _لويس_
  { {0x6133003a,0x96630015,0x3869007b,0x1eaa0012}},	//   rçla, икуе, abar_, باري_
  { {0xdd8f000a,0x9d460098,0x63a9084c,0xceb2000b}},	//   قول_, вежд, _apen, שיב_
  { {0x7afd007a,0x80a10037,0x19570009,0xb05b0248}},	//   _įsta, _कॉले, _שבכל_, _snäv
  { {0x291200c6,0x8b960015,0x88bd0002,0x39402106}},	//   mnya_, треч, zośc, mmis_
  { {0x291200c6,0x9f40000f,0x3940015e,0x63a9003a}},	//   lnya_, rzió_, lmis_, çeni
  { {0x7d04083c,0x39400010,0xbb470012,0x8cc50011}},	//   _omis, omis_, خلون_, ियमो
  { {0x291200ec,0xb9e3002d,0xc213000b,0x2d6e0066}},	//   nnya_, ріши, יהו_, vře_
  { {0xa8e00020,0x88bd003e,0xf772000a,0x8afd0013}},	//   _độn, wośc, جاع_, _stře
  { {0x291200c6,0x88bd0002,0xf773000b,0x883b0009}},	//   hnya_, tośc, סקת_, ותפו
  { {0x291200c6,0x75eb000e,0x7bc20070,0x01da0012}},	//   knya_, vözö, lvou, _توضع_
  { {0x88930024,0x88bd0034,0xda4b0009,0x7d7b0009}},	//   _виїх, rośc, _חֲדָ, ונטו
  { {0x7bc200bd,0x244b0003,0xdb25000e,0x291200b6}},	//   nvou, بجدي_, ősít, dnya_
  { {0x39400051,0xf7770009,0x2caf0227,0x2fc6020d}},	//   emis_, _יעדי_, zegd_, _irog_
  { {0x38690052,0x291200b6,0x26ce05ca,0x1dd70012}},	//   tbar_, fnya_, _info_, _لبيع_
  { {0x25d7000b,0x395e000e,0x2fc62107,0x91bb0009}},	//   _יוון_, ítsa_, _krog_, ומלי
  { {0xf54a001a,0x38660164,0x38351f26,0xdddc05be}},	// [54d0] _cấu_, ñora_, унар, _perş
  { {0xb6f40046,0xf54a0020,0x8f9b000b,0x291200b6}},	//   азуј, _dấu_, וימי, anya_
  { {0x272f000e,0x291200b6,0x69c50adf,0x71d50009}},	//   lünk_, bnya_, _urhe, _עוֹד_
  { {0x5064002d,0x27390061,0x3ebc0262,0x48640048}},	//   _втра, mène_, _lavt_, _върб
  { {0x62810002,0xb4fc0009,0x27390025,0x6d4d00b8}},	//   ólow, ופאי, lène_, _miaa
  { {0x8f9a0093,0xfbd00012,0x68ed2108,0xc3240024}},	//   _אישי, تتم_, lkad, амік
  { {0x6eed0026,0x10a50014,0x78bd00b9,0xd3380009}},	//   _súbo, гийн, _kasv, דרגה_
  { {0x272f000e,0x3d020011,0xc7b10012,0x68ed2109}},	//   künk_, _लगें_, مّع_, nkad
  { {0xf54a210a,0xf7710003,0xdce2001e,0x78bd001e}},	//   _mất_, حاب_, zslē, _masv
  { {0xb06203d5,0x66ac000b,0x69c80033,0x7d04210b}},	//   ääri, ֵיכֶ, ådek, _smis
  { {0x7c2d00a2,0xde051128,0xb8950012,0x645e0034}},	//   _ayar, упни, _ملاع, śpie
  { {0x78bd009b,0x9a99001e,0x9e3c00d9,0xedb60009}},	//   _nasv, žādā, veďt, נִית_
  { {0x2d9e0052,0xb4fa000b,0x6cfa000b,0x272f000e}},	//   atte_, תפרי, תפרס, günk_
  { {0xdce20039,0x442d0033,0x7ae1004a,0x4375002d}},	//   tslē, _mye_, _jolt, шуют
  { {0xf54a131c,0x291200c6,0x7ae1210c,0x63be001e}},	//   _bất_, tnya_, _molt, āpni
  { {0xdce2001e,0xb4db0054,0x2dd80003,0x291200b6}},	//   rslē, rmàc, _جبهة_, unya_
  { {0x27e90101,0x291200c6,0x442d045d,0x8cd10037}},	// [54e0] gyan_, rnya_, _nye_, धारो
  { {0x4df60047,0x291200c6,0x7bcb0017,0x60db005e}},	//   ляет, snya_, _água, hjum
  { {0x291200c6,0x3f9f004a,0x96550001,0x448a0345}},	//   pnya_, htuu_, рђуј, ебен_
  { {0x68ed0163,0xdb0d0065,0x2d870164,0xb4ae0011}},	//   ckad, _hrað, ánea_, क़े_
  { {0xc879003a,0x98a00002,0xa2e60024,0xbebc0035}},	//   daş_, elić_, лодд, olīt
  { {0x68e3000d,0x2d9e0623,0x93b70009,0xa6460012}},	//   _îndr, ytte_, טלנו_, _مخزن
  { {0x81a60003,0x272f000e,0x60db0028,0x442d210d}},	//   احتل, zünk_, fjum, _eye_
  { {0x6fb40003,0x8c460014,0xdfd00012,0x20540048}},	//   لمبا, _бебе, قيب_, шкия
  { {0x98ab0002,0x8cd80037,0x3f92003a,0xb6f40001}},	//   _chcę_, यानो, nuyu_, изиј
  { {0x6d86000b,0xc7b30009,0xaa570012,0x62880031}},	//   ְתָּ_, צבת_, _ملكا_, ódol
  { {0x7c2d00c6,0x2360001e,0x645a0066,0x2d9e172a}},	//   _syar, ģiju_, ětin, utte_
  { {0x61e50052,0x272f000e,0x69c820df,0xf8b80011}},	//   ähle, tünk_, _irde, _आसिय
  { {0xf54a0020,0x2bc70037,0x9b580014,0xfbc70011}},	//   _rất_, लिया, лият_, लियम
  { {0x272f000f,0x88bd0002,0xbebc001e,0x78bd0027}},	//   rünk_, nośn, glīt, _sasv
  { {0xc3330093,0x68e2015e,0x80a10037,0x272f000e}},	//   מוש_, _kood, क्वे, sünk_
  { {0x2a3b0009,0x272f0031,0x68e217c9,0x27390025}},	//   תעלמ, pünk_, _jood, rène_
  { {0x7c2d00a2,0x68e20005,0xd7950014,0x61080002}},	// [54f0] _uyar, _mood, ризъ, yśln
  { {0x200d0065,0x3f87001c,0x68e20005,0x69c30029}},	//   _þeim_, čnu_, _lood, yvne
  { {0xf54a0020,0xe4e7002d,0x0dc80001,0x545500a6}},	//   _tất_, лідн, луци_, авет
  { {0x67250006,0xd308001a,0x68e20184,0x81c70035}},	//   sohj, iệu_, _nood, ntēš
  { {0x6d5a0061,0xc879003a,0x6725004a,0x287a0009}},	//   _étan, vaş_, pohj, _שנשמ
  { {0x2bc70011,0x98a00034,0x8d770012,0x3a2d0030}},	//   लिबा, tlić_, _مارا, řepu_
  { {0xdb000058,0x68e20070,0x6d5c0030,0x3abc0009}},	//   _opmæ, _bood, íral, גמונ
  { {0x3f9f004a,0x77851ad6,0x63ad0034,0x2d830030}},	//   ttuu_, ализ, _opan, ájem_
  { {0x2d8c00bd,0xccf20093,0x80a10037,0x3f9f004a}},	//   erde_, _וכן_, क्षे, utuu_
  { {0xe7390001,0xa3b00037,0x2ca900b6,0x7d0b210e}},	//   ђен_, _टैग_, _abad_, ligs
  { {0xa2d90044,0xe80c0037,0x3f9f004a,0x68e20132}},	//   मान्, _सेना_, stuu_, _food
  { {0x2730001a,0x7bc900a8,0x7d0b0480,0x68e2210f}},	//   hành_, _kreu, nigs, _good
  { {0x61e10163,0x2d8c2110,0x386d2111,0x63ad0018}},	//   älln, arde_, mber_, çanh
  { {0x80a10037,0x386d0052,0x7a40000e,0x5ffa0009}},	//   क्रे, lber_, játé, _בהנה
  { {0x11d5002d,0xc6920009,0x6592004c,0x386d005e}},	//   бітр, _ואו_, _дају, ober_
  { {0x3f5b001a,0x3f92003a,0xc9550015,0x659a000b}},	//   _kêu_, tuyu_, стры, _סיפק
  { {0xb8de015f,0x8f76002d,0x386d2112,0x6abe02b9}},	// [5500] _इस_, рубі, iber_, _tapf
  { {0x3f92003a,0x6e8a0012,0xc43b0009,0xe37b0009}},	//   ruyu_, ئناف_, _בתפי, _שריר
  { {0x610c003a,0xd308001a,0xdcff0066,0x1ea90003}},	//   aşla, iệt_, _úvěr, طالي_
  { {0x61ee0052,0x0b8a00f5,0x9e480009,0x5ca60024}},	//   _übli, вски_, אֲנִ, ридб
  { {0x3f5b001a,0xe3b20003,0x7bc908b9,0x94090009}},	//   _nêu_, ترا_, _creu, ְּנֵ
  { {0x3f8d03eb,0x68e20051,0x2d8b0002,0x2ba70011}},	//   dreu_, _sood, ącej_, _गहरा
  { {0xc27b0009,0xd2590024,0x68e20150,0x88bd0034}},	//   דרצי, уці_, _pood, rośn
  { {0x7bc9008b,0x55bb000b,0xa7740237,0x1f740048}},	//   _freu, _במלו, блич, блия
  { {0xdfd00003,0x50b70012,0x3f8001a0,0x99470012}},	//   سيد_, شديد_, nsiu_, جليل_
  { {0xe4650028,0x68e20429,0x539b0009,0x1a780009}},	//   _þörf_, _wood, _בימו, _תְּמ
  { {0x68e20005,0x0737000b,0xd5b7059a,0xd6d70015}},	//   _tood, שאים_, ася_, рты_
  { {0x6fc90037,0x3f8d0f4c,0xa06a0339,0x186a1846}},	//   रिमं, breu_, _рада_, _ради_
  { {0xda780026,0x81c7001e,0x9d180083,0x938b0048}},	//   _keď_, rtēš, роят_, ъсна_
  { {0xdce2007a,0x81c7001e,0x61e1006f,0x47330024}},	//   kslė, stēš, ällo, _дніс
  { {0x58d50014,0x090700fa,0xe0d30012,0xc05b0024}},	//   бовт, ачам, يزر_, віз_
  { {0x3f5b0020,0xa3d60011,0xa98b0009,0x63a22113}},	//   _yêu_, िमा_, כָמִ, kton
  { {0x63ad0101,0xad1c0009,0x3eb3209b,0x2ef50024}},	// [5510] _upan, _שוחר, text_, бзар
  { {0x6d58015e,0x28a60037,0xf54a001a,0xc7d70009}},	//   _kuva, क्ति, _hấp_, בומי_
  { {0x24550003,0x7d0b2114,0x6d5a0025,0x9f950032}},	//   مناس, tigs, _étal, _füße_
  { {0x28a60011,0x95c40012,0xb6070073,0x7c872115}},	//   _कॉलि, غينه, _rašė, руже
  { {0xd3080020,0x7ae507f6,0x493a000b,0x6d582116}},	//   yệt_, _koht, _תגרו, _luva
  { {0x7ae50006,0x7ae1000e,0x7bc9120a,0x99850012}},	//   _joht, ölth, _vreu, ملتو
  { {0xceb2000b,0x752d0002,0x6d582117,0x7db40012}},	//   _מים_, _okaz, _nuva, _وصفا
  { {0x26de0029,0x5a18000b,0x3f8d2118,0x4c940015}},	//   ejto_, יקון_, treu_, _мисс
  { {0x63bb003e,0x69de0033,0x7d09005e,0x3dcf0034}},	//   _usun, øper, _imes, łowę_
  { {0x3f8d08c8,0x59d70037,0x02450003,0x0f580009}},	//   rreu_, डमार, _هَذَ, ביזם_
  { {0x91f40012,0xdee40012,0x69c7001b,0xc9f40012}},	//   _وأما, تأيي, jvje, _وسمع
  { {0xf54a0020,0xf1c30010,0xcb6a010b,0xc4fa0012}},	//   _cấp_, rašė_, ламе_, اعدا_
  { {0x7052000a,0xa856000b,0x6f650003,0xa1360009}},	//   _عنوا, _הינה_, _اهتم, _פאנק_
  { {0x62630075,0x7d1b2119,0xda650012,0xcf240012}},	//   звра, _ljus, قافي, _وروي
  { {0x5d85000a,0x63a2000f,0xc332000b,0x8d950003}},	//   _البل, zton, פול_, _العش
  { {0x7a42000e,0x2bb80037,0xf54a001a,0x97da003c}},	//   líté, _इनला, _gấp_, льзу_
  { {0x27ed211a,0xfe720012,0x69c7001b,0xddc30030}},	// [5520] nyen_, كدا_, avje, _jenž
  { {0x7a42000f,0xdfcf0003,0x6d580060,0xf65604a5}},	//   níté, عيل_, _yuva, стаю
  { {0x2a57000b,0x3f800054,0x463a010c,0x546a00de}},	//   _לבין_, ssiu_, учая_, гаем_
  { {0x67230027,0x69c80033,0xd4990024,0xb0a60011}},	//   čnja, ådeu, ирі_, _कॉंग
  { {0x4c9b0009,0xdb0d005e,0x395a008e,0x88bd0034}},	//   רבנו, _eraõ, _hups_, rośl
  { {0xf773000b,0xaa570003,0x63a2211b,0xab270024}},	//   _מקש_, ملها_, rton, боча_
  { {0xcaa50003,0xa2d90037,0x7a42000e,0x63a2211c}},	//   تصني, मात्, díté, ston
  { {0xa617000b,0xc9530009,0x64a30dfb,0x27340248}},	//   _הקלד_, המה_, _наса, känk_
  { {0xda780066,0x69c70027,0x2000000d,0x60c4211d}},	//   _teď_, zvje, nzii_, idim
  { {0xf76f0003,0x4fbb000b,0x7a42000e,0x752d211e}},	//   راً_, נציא, gíté, _skaz
  { {0x9aeb000b,0x672819fa,0x12eb0009,0x7e7e00b8}},	//   _עַמִ, rodj, _עַמּ, iapp
  { {0xa157000b,0xb1460001,0xce37000b,0x7e7e0c21}},	//   _הבאה_, _унел, מאית_, happ
  { {0x27ed0033,0x765c0064,0x7e7e211f,0xf54a0b24}},	//   cyen_, ľryb, kapp, _vấp_
  { {0x6d580051,0x6d460051,0x6b840a05,0x80b80011}},	//   _tuva, amka, _dvig, ्यवे
  { {0xeab1000b,0xf67b0009,0x07370009,0x395a036c}},	//   וֹן_, _גאומ, _האגם_, _cups_
  { {0xa617000b,0x6113004b,0x2d870030,0xdcfb0035}},	//   _לקוד_, tăli, ánem_, rutē
  { {0x7ae52120,0xddc80027,0xe8030037,0x6133003a}},	// [5530] _toht, nadž, _रेखा_, nçli
  { {0x692c0052,0x60c408ab,0x2d87009b,0x6d402121}},	//   ußer, adim, šnem_, _ahma
  { {0xd657000b,0x69c80348,0xa2c60011,0x69da2122}},	//   ציאת_, ådet, ायर्, ätet
  { {0x7a42000e,0x89e80009,0x859b0009,0x62881483}},	//   zíté, _הַשֵ, רשאו, _addo
  { {0x889a000b,0x7d09009b,0x31a10034,0x93a7003c}},	//   _דברי, _vmes, wóz_, сшед
  { {0x09b90012,0x28a60011,0xa276004c,0xa8a70060}},	//   لطبع_, क्सि, обљу_, şmüş_
  { {0x6a9c0093,0x6d580026,0x314b000b,0x6aaa0052}},	//   אשונ, ívat, ְתִּ, _öffe
  { {0x63ac0030,0x7a400097,0x7d092123,0x6ab40011}},	//   ílný, _hátí, _umes, ूयॉर
  { {0xe8f6002d,0x69ce0028,0x7a42000e,0x61ee0002}},	//   іль_, _áben, títé, zybl
  { {0xe4500003,0xd705002d,0xd7090015,0x3dc60002}},	//   _أضف_, ізни, рное_, łowe_
  { {0x7a42000f,0xc692000b,0x4432004a,0x0a150012}},	//   ríté, ואי_, _syy_, _بواح
  { {0x7a42000f,0x03a60015,0x2d8b0066,0x89370012}},	//   síté, оимо, čce_, _اعطا
  { {0x7ccd0039,0xdd0c003e,0x7a42000f,0x43750024}},	//   mērķ, _późn, píté, зуст
  { {0x36690046,0x7bcd01ff,0xddd50030,0xdce207ee}},	//   _тако_, _drau, _nezů, oslī
  { {0x2d870029,0xd308001a,0xceb20009,0x76ba0009}},	//   šnej_, iệp_, _חיו_, _כמספ
  { {0x60c4007a,0x2734008e,0x7bcd2124,0x7e7e0602}},	//   udim, mäni_, _frau, wapp
  { {0x26c30164,0xa6e60015,0x7e7e2125,0xfc320012}},	// [5540] _bajo_, ожал, tapp, _تحث_
  { {0x249f007d,0xdce2001e,0x200011ad,0xa3e70011}},	//   _acum_, kslī, rzii_, पहर_
  { {0xa2dd0037,0xbc6a0003,0xad650012,0xdcfb0035}},	//   पान्, لمان_, كانه, lstā
  { {0x629c2126,0x7e7e0614,0x7ae10031,0x69c80064}},	//   lgro, sapp, öltv, ťdes
  { {0x8bb60003,0xa5330024,0xfbd20012,0x8b26003c}},	//   تصاص, єніч, بتا_, одде
  { {0x38720033,0x2fcf0058,0x298a004c,0x99660695}},	//   lbyr_, ægge_, асио_, отил
  { {0xc4ca0011,0x14ca0011,0xe297004c,0x290b2127}},	//   ियाओ, ियाण, цај_, _ymca_
  { {0xc0ca0046,0x89db000b,0xdcfb001e,0x3faa004c}},	//   руке_, שחקי, kstā, ањом_
  { {0x28a60037,0x8b650003,0xc7b00012,0x78fb0009}},	//   क्षि, _فالم, رّد_, יפקו
  { {0x2018007d,0x7f180012,0x945d0034,0x6d5c2128}},	//   ări_, إيدز_, _tańc, _kura
  { {0x7d0f004a,0x7bcd0010,0xa01b0052,0x865b000b}},	//   tics, _srau, _geöf, ידיי
  { {0x629c00bd,0xcd07007c,0x6d5c2129,0x000000c4}},	//   egro, ічни, _mura,
  { {0xdcfb0039,0x9be70024,0x69d501a0,0xdbdd0031}},	//   gstā, цінк, _àzer, _káér
  { {0x28a60044,0x2d870013,0x6d5c0d29,0x8f9b00af}},	//   क्रि, ánek_, _oura, _כידי
  { {0x7ae800c5,0xddc80034,0xc87b004c,0xdcfb0035}},	//   _modt, nadż, иџа_, astā
  { {0x23a4006f,0x5e430012,0x58d40fbb,0x5c75003c}},	//   böj_, _غَيْ, мост, _элит
  { {0x7e7c00c6,0x6fbc0037,0x69da0052,0x984b0014}},	// [5550] _berp, ्टिं, äter, рява_
  { {0xde970003,0x539a000b,0x6d5c0827,0x8ca70037}},	//   تجرب, _פיתו, _bura, ट्रो
  { {0x2aba0093,0xcddb0001,0x7bc00010,0x3aba000b}},	//   _המתא, шња_, _asmu, _המתנ
  { {0xe80c0044,0xd7bc0037,0x2eb70011,0x62880ca4}},	//   _सेवा_, ्टाच, _अस्त, ódov
  { {0x39490471,0x60da000b,0x3af50015,0xd0f60009}},	//   mmas_, _הקרנ, зяйс, _זמרת_
  { {0x6d5c0284,0xf7760009,0x2cb90031,0xaacb0011}},	//   _fura, _מעשי_, hesd_, ायिक
  { {0x78b4000f,0x02fc000b,0xdcfb001e,0x254d0002}},	//   _üdvö, שלומ, zstā, _eśli_
  { {0x28bd0037,0x721c000b,0x621c0009,0x2734008e}},	//   ्यधि, יווח, יווק, väni_
  { {0x7f5d0108,0xdcfb0010,0xfbbf0011,0xa0880009}},	//   _jusq, lutė, _एनिम, חְתִ
  { {0x7ae80f33,0x3f860066,0x7d1d0028,0x3949005e}},	//   _godt, _dvou_, érsn, hmas_
  { {0xdcfb007a,0x99d40012,0xe8550012,0xcee80012}},	//   nutė, _يتما, _فناد, ترين_
  { {0x61080002,0x26c3009b,0x645c000e,0xcb090009}},	//   yśli, žjo_, _őriz, _גל_
  { {0x2bba0003,0x98e40003,0x185a0009,0x07d80012}},	//   حاجة_, _تكنو, _הכנע, _وذهب_
  { {0xdcfb0039,0x254d0066,0x36c4002d,0xcf270012}},	//   rstā, _měly_, _обіг, _برؤي
  { {0x867a000b,0xbbb80037,0x78af001a,0x629c041a}},	//   _הרצו, _इन्क, _bbcv, rgro
  { {0x6d5a0108,0x629c06f9,0xe45f0031,0x7bc00097}},	//   _étai, sgro, ldön_, æmus
  { {0x4c9b000b,0x34fb0009,0xb4e50011,0x6d5c212a}},	// [5560] _השפע, _להקד, _पकड़_, _sura
  { {0x97560093,0xdfcf0003,0x39491f85,0xfbd30009}},	//   פיעו_, ديك_, amas_, _נתת_
  { {0xfc660098,0x7e7e0005,0x2561000e,0x7e7c036a}},	//   пълн, _õppe, _jól_, _verp
  { {0x89db0009,0xfd950024,0xfdf60009,0x6d5c067a}},	//   _החטי, ьшую, הצעת_, _vura
  { {0x7e7c00c6,0x98a4001e,0xa8570009,0xf0930009}},	//   _terp, jomā_, _מיכה_, _אנר_
  { {0x6ef60061,0x883b0009,0xfaa30048,0xdcfb0073}},	//   _câbl, _לתכו, ешън, butė
  { {0x3f860013,0x2bb80037,0x27f2004a,0xc1b80024}},	//   _svou_, _इनका, lyyn_, ілих_
  { {0x751a000a,0x60c60013,0x29000017,0x361b000b}},	//   _اقرأ_, _jakm, nhia_, _הולד
  { {0x0f560009,0x7ae80032,0xa067004c,0x2cb90031}},	//   ֔יִם_, _todt, чања_, vesd_
  { {0xabfb0093,0x6440212b,0x6c330003,0x27e00054}},	//   _ההמר, _izmi, _أفكا, ixin_
  { {0x2fc7008a,0x3949007a,0x6d56020d,0x4c951e12}},	//   ̉ng_, ymas_, _biya, минс
  { {0x660100a2,0x6d440016,0x394a004c,0x20c90012}},	//   _ülke, _chia, _узео_, _وبني_
  { {0x703a0003,0xa4e70009,0x2cb90031,0x3cdf0011}},	//   _اساس_, לֵךְ_, resd_, गाबे_
  { {0x66e3007c,0x3f82007a,0x28da0037,0x8c1b000b}},	//   _поча, škus_, भावि, מוכי
  { {0x6d56003a,0x69c816d1,0x7f3b0009,0x9e33004c}},	//   _fiya, ådep, _העגו, _пешч
  { {0x361b000b,0xa954002d,0xce37000b,0x6d4400c1}},	//   _לווד, ексі, _מאות_, _ghia
  { {0x7ae1000f,0xb8e50037,0x853d0010,0x80a10011}},	// [5570] ölts, _एस_, ntėm, क्टे
  { {0x6d5600a2,0x4b7c000b,0xdb7c0009,0x62880031}},	//   _ziya, _האזו, _הנזכ, ódot
  { {0x18750048,0x395e212c,0xe859076b,0x2d54004b}},	//   _огня, _nuts_, _манш_, _oţel_
  { {0xbd18002d,0x45180024,0x98a90034,0x752f0034}},	//   пції_, пція_, dlać_, nocz
  { {0xfbab027f,0x27e00081,0x41c20011,0xdd310972}},	//   стей_, cxin_, _वैबस, mężn
  { {0x3dc60002,0x539c0009,0x395e0025,0x2d850064}},	//   łowa_, מידו, _buts_, ysle_
  { {0xa9c4000a,0x0b420048,0x395e0132,0x2d9a0025}},	//   فزيو, ъншн, _cuts_, cupe_
  { {0x28da0037,0x35b3002d,0x6ca40538,0x25610102}},	//   भाषि, _обґр, _пруж, _ról_
  { {0x752f0002,0x9f44004a,0x29030010,0x645b01e3}},	//   docz, kymä_, ėja_, _igui
  { {0xb0c90037,0x8e74002d,0x25610504,0x6d560be2}},	//   ाएँग, нуюч, _pól_, _siya
  { {0x57ba0044,0x69c10027,0x6d5603ef,0x112b01d4}},	//   _उन्ह, _usle, _piya, _люди_
  { {0x31c4002d,0x2d85212d,0x82340012,0xb4c80011}},	//   _ясув, rsle_, _أركا, ईये_
  { {0x2d9a0033,0x6d560060,0xb9010011,0xbea505d8}},	//   _åpen_, _viya, दा_, _жалк
  { {0x6008000b,0x853d0010,0x7d1d004a,0xdcfe001e}},	//   _מִצְ, ntėj, anss, ispā
  { {0x6d560101,0xc332000b,0xe9a3002d,0x752f0002}},	//   _tiya, דום_, карп, bocz
  { {0xbd460003,0x316c001e,0x7d7a0009,0x6b890159}},	//   _تنبي, īdz_, _ונקו, _oveg
  { {0x6288000e,0x3af4004a,0x032601d4,0x2912212e}},	// [5580] ódos, _läpi_, _один, riya_
  { {0x29120101,0x60c9004a,0x68e400b6,0x24800068}},	//   siya_, hdem, sjid, _heim_
  { {0x80a60044,0x2912002c,0x26c7212f,0x56930024}},	//   _छापे, piya_, _mano_, таєт
  { {0xcea90009,0xc1730009,0x2d870dae,0x853d0073}},	//   יי_, _שחר_, ânea_, etėj
  { {0x9f520066,0x1ab40223,0x23ba0012,0x7a470025}},	//   ždém_, ебля, تداب_, pété
  { {0x416a0001,0x98a90002,0x2aaa0024,0x395e2130}},	//   ојим_, tlać_, ітло_, _puts_
  { {0x200d0065,0xbebc001e,0x80a50037,0x64400034}},	//   _þeir_, lnīg, ङ्के, _wzmi
  { {0x6abc0065,0x26c70101,0xe6430f80,0x98a3004c}},	//   herf, _aano_, _респ, виће
  { {0x6abc0028,0x80a60011,0x6440001b,0x2004001b}},	//   kerf, _छाने, _uzmi, uzmi_
  { {0x7ce60002,0x628301c5,0xe9da0012,0x752f0034}},	//   _górz, cano, _وذات_, wocz
  { {0x2480008b,0x0697000b,0x75d40003,0x8e97000b}},	//   _beim_, ודים_, ريحا, ודיו_
  { {0x68460003,0xd6170012,0xc0d30012,0x2ebb0011}},	//   _قَال, بتًا_, _ليمب, _उस्त
  { {0xb7d70003,0x27e0003a,0x6ee60003,0x752f0002}},	//   _يوما_, _çin_, _يستل, rocz
  { {0xf54a001a,0x8f8b000b,0x6abc2001,0xe6c80011}},	//   _mấy_, _וְהֵ, gerf, रयोज
  { {0x57570093,0xf54a001a,0x752f0002,0x569b0009}},	//   _קבוע_, _lấy_, pocz, _ויוצ
  { {0x6aaa0052,0xa2a70011,0xd2580024,0x628311fc}},	//   _öffn, _फ़ॉन्, ьця_, zano
  { {0x6abc03f7,0x74150012,0x545504ba,0xd7590012}},	// [5590] berf, _سودا, _явит, سلات_
  { {0xf3ff0018,0xa3be0011,0x60c90031,0x80d50011}},	//   lcão_, ीटर_, zdem, _मोने
  { {0x2734006f,0x6b891ce8,0xc6a40048,0x4ea40048}},	//   vänt_, _sveg, ърти, ърта
  { {0xdd980024,0xf7730012,0xf54a0081,0x7d020031}},	//   ьшу_, _لاس_, _bấy_, ghos
  { {0xdb0d0051,0xd0060012,0xe7030081,0xc4180012}},	//   _osaü, _إل_, hướ, وغها_
  { {0x8c1c000b,0xeb92000b,0xbc1c0009,0x2bf80009}},	//   חודי, אָה_, חודש, ומדן_
  { {0x6b9d002c,0xf1b10012,0xc27c0009,0xa9660365}},	//   husg, اءت_, חרוי, нища_
  { {0xc7c80020,0x628305e9,0x41b20003,0xc5f2000b}},	//   _bố_, sano, امير, _גדל_
  { {0xc7c80020,0x78bb2131,0x3f820064,0x39592132}},	//   _cố_, reuv, ákup_, _miss_
  { {0xfe71000a,0xeab00003,0x22510029,0x0ea90015}},	//   ددة_, _نعم_, _úzko_, чкой_
  { {0x6d5a0108,0x7bcf003a,0x3ea12133,0x2bc70011}},	//   _état, evcu, ight_, लिका
  { {0xed590013,0xdcfb0002,0x6abc0bf8,0xfce60447}},	//   _již_, ystą, werf, хомо
  { {0x628100c6,0xdd0c003e,0x394d2134,0x69c518cf}},	//   _kelo, _różn, mmes_, _ashe
  { {0xa3d00044,0xb4bc0011,0x799c0032,0x6abc0032}},	//   षित_, _अस्_, turw, uerf
  { {0x443a0020,0x394d0054,0x4efa0009,0x28a60011}},	//   ́p_, omes_, _מהסו, क्कि
  { {0x0d820014,0xfe36000b,0xf1c00064,0x409504a5}},	//   _слън, _ארצי_, ššou_, крут
  { {0x291f004a,0x1e9600b3,0xc9520009,0x99330012}},	// [55a0] inua_, ерер, רמן_, افقت
  { {0xf1c5001a,0x33770009,0x86c600ae,0xe73a03d2}},	//   _đáng_, _רעים_, عيان, чез_
  { {0x61e1006f,0x8a7b000b,0xceb20009,0xe5720012}},	//   ällt, _מאית, ריב_, اطئ_
  { {0xa6de0020,0x9136002d,0x3dc60002,0x3869126b}},	//   _nhưn, _їхні, łowo_, ccar_
  { {0x28c30037,0xf8b3000b,0x62812135,0xe3af0012}},	//   वजनि, _גשר_, _belo, مرو_
  { {0x2734006f,0x2120048b,0xda660012,0x3f7d0064}},	//   räns_, lnih_, راتي, dňu_
  { {0xc7c8008a,0x62810133,0x79450002,0xbf370009}},	//   _số_, _delo, zówe, _נאלץ_
  { {0xf993000b,0x98a40010,0x6d5e0061,0xe80c0011}},	//   ארה_, komą_, _épai, िछला_
  { {0xf7720003,0xd6d00003,0x7d000051,0x628114d4}},	//   داع_, لقة_, _ilms, _felo
  { {0x1ddb0037,0x98a40010,0xbfb30003,0xcb0a0012}},	//   यमंत, domą_, احيت, _عيان_
  { {0x3207003e,0xceb3000b,0x2d8a000e,0xda650012}},	//   czny_, אית_, ébe_, _شالي
  { {0xc7c8001a,0xdcfe0010,0xe703001a,0x26ca001e}},	//   _tố_, rupė, rướ, _labo_
  { {0xb8f40044,0x2120048b,0xf7f30012,0xc4d30009}},	//   िए_, dnih_, _مسود, אגר_
  { {0xb7db000b,0x41770012,0xe7db0009,0x14180012}},	//   _מקדי, فارس, _מקדש, ريّة_
  { {0x6b400052,0x318c0066,0xda350015,0x72280024}},	//   mögl, něz_, тевы, ецтв_
  { {0xadd7000b,0xe63b000b,0xa63b000b,0x89db0009}},	//   _טווח_, _מתוכ, _מגור, החלי
  { {0xf770000a,0x39592136,0x386914d9,0x8cb60011}},	// [55b0] مال_, _viss_, rcar_, ोजनो
  { {0x3ea10036,0xbebc001e,0x2d870017,0x38692137}},	//   ught_, lnīb, âneo_, scar_
  { {0x2120017b,0xfc3f015b,0x6f240024,0x69c50bb5}},	//   bnih_, _ší_, уєте, _ushe
  { {0x62810108,0x5ce404b3,0xd4e4048c,0xe4e40024}},	//   _selo, люча, лючи, лічн
  { {0x62812138,0x60cd2139,0xfaa50a2c,0x69e6004b}},	//   _pelo, mdam, вало, ăreş
  { {0x60cd0005,0x2d9e0005,0x3ebe0119,0x0442004c}},	//   ldam, kute_, jett_, јешн
  { {0x3ebe000e,0x60cd0010,0x12fc0009,0xa2a70011}},	//   dett_, odam, ההגב, _फ़ॉण्
  { {0x32070002,0x60cd213a,0xed6305b1,0xde580024}},	//   rzny_, ndam, _leží_, _часі_
  { {0x62870cc7,0xf7710003,0x13b40003,0x2d9e0052}},	//   kajo, جاب_, _مصلح, eute_
  { {0x753d000e,0xf7450001,0x6287009b,0x3ebe0b35}},	//   elsz, ђено, jajo, gett_
  { {0x60cd007a,0xb4cd0011,0x6b8d005e,0x6287162f}},	//   kdam, रयू_, _avag, dajo
  { {0xb8150001,0xdcfb0002,0x98a40010,0xc3290009}},	//   _идеј, ostę, tomą_, _וו_
  { {0x2120048b,0x8cb30037,0x66080002,0xed630064}},	//   vnih_, ेज़ो, azdk, _beží_
  { {0x68e90604,0xf4120009,0x501a0009,0x6b400031}},	//   ljed, שפך_, _קוסו, rögo
  { {0x21200133,0x19b90109,0xe7160009,0xc3320009}},	//   tnih_, нуть_, _בחסר_, יוך_
  { {0xf55a0012,0x2f040032,0xf9920009,0x60cd213b}},	//   _تلعب_, _möge_, ירל_, gdam
  { {0xf772000a,0xb4db0054,0x62870164,0x3f420028}},	// [55c0] شاء_, rmàt, bajo, iðun_
  { {0x139b000b,0x2120080a,0x6d49213c,0x68fb005e}},	//   _קביע, snih_, _ahea, hkud
  { {0xd6cf0003,0x68fb0051,0x65630017,0x212000eb}},	//   تقل_, kkud, _junh, pnih_
  { {0x3ebe000f,0x26ee0037,0x60cb002c,0xdb1f0061}},	//   zett_, _चक्र_, _nagm, _évêq
  { {0xa3b4007c,0xcb670001,0xa294002d,0x2d9e000d}},	//   ублі, ваче_, галі, zute_
  { {0xc7b30009,0x318c0030,0x934314f1,0x78a4213d}},	//   _דבש_, těz_, анче, lgiv
  { {0xe5670003,0xdcfb0002,0xcec30066,0x2d910030}},	//   _خط_, astę, ářů_, ázel_
  { {0x3f420065,0xd3720003,0x2d9e00c1,0xddd8080d}},	//   gðun_, _نهر_, vute_, _nevš
  { {0x3ebe000f,0xaae20037,0x87060014,0x3ce60037}},	//   tett_, पादक, вяне, टाने_
  { {0x68e90a48,0xab5b0032,0x2d9e213e,0xb2c500ae}},	//   ajed, ewün, tute_, _مغمو
  { {0xdb1b213f,0x5d550098,0x3ebe0119,0x60cd0010}},	//   _usuá, лкот, rett_, ydam
  { {0xdddc001c,0x26ca009b,0x3ebe2140,0x320a0064}},	//   _održ, žbo_, sett_, dzby_
  { {0x3ebe000e,0xaade0037,0xd7060345,0x88bd0002}},	//   pett_, मांक, _изди, pośr
  { {0x60c00006,0x9b580014,0x9b450012,0x6dd40012}},	//   lemm, кият_, انسو, _مقتض
  { {0x30a7002d,0x3eab01bd,0xbbbf0011,0x62872141}},	//   крав, žitý_, _एन्क, rajo
  { {0xdcfb0002,0x62872142,0x60c02143,0xdbca005e}},	//   ystę, sajo, nemm, _hõõr
  { {0x14190012,0xe6790024,0x60c0008e,0x62871dfb}},	// [55d0] _سيدة_, ейзі_, iemm, pajo
  { {0xdf390003,0x60cd2144,0x60c01a1e,0x69c30034}},	//   ركات_, sdam, hemm, ywne
  { {0x320a003e,0x60c02145,0x5c750048,0xda7a0009}},	//   czby_, kemm, глет, _אנתר
  { {0xada4002d,0x6d5e0061,0x60c02146,0x94740012}},	//   раїл, _épau, jemm, لدها
  { {0xeab90014,0xd7e4002d,0x289a000b,0x4429167d}},	//   ейл_, _кіро, _אירא, ça_
  { {0x5d650012,0x62852147,0xc5f80035,0x6d492148}},	//   _مُسْ, _jeho, ncēs_, _whea
  { {0x443e0020,0x60cb002c,0x27e9000d,0x19b50003}},	//   ́t_, _pagm, ţină_, احتج
  { {0x6d5a0061,0x08c51c84,0x28da0011,0x26c10064}},	//   _étap, убин, भागि, leho_
  { {0xa8190003,0x69c80054,0x68e9000e,0x68fb005e}},	//   عتبر_, _esde, rjed, rkud
  { {0x68e90027,0x98b8001e,0x26c12149,0xf1c00004}},	//   sjed, ērā_, neho_, ášku_
  { {0x273d001a,0x5ee80009,0x60cb214a,0x497503d2}},	//   rình_, דַרְ, _tagm, _слес
  { {0xf2c9000b,0x60c00061,0x97c50003,0xeb9a214b}},	//   _מע_, cemm, _مقصو, ним_
  { {0x8ca50037,0x26c10029,0xab5b0052,0x78a40260}},	//   _कारो, keho_, rwün, vgiv
  { {0x6e95000a,0x6f920003,0xd629048c,0xa0360009}},	//   _إلغا, _الوض, _поле_, _גאנה_
  { {0xceb2000b,0x0219007c,0x66090066,0xba1a0003}},	//   _היו_, віть_, _řekn, ريرا_
  { {0x386d214c,0xb87b0c8b,0xbebc0035,0x7bd60034}},	//   ncer_, _aníb, pnīc, _tryu
  { {0x3f8d0054,0x6cab0009,0x28aa0011,0xd943214d}},	// [55e0] nseu_, _אֹיְ, ङ्गि, сети
  { {0x6fb30003,0x628504a3,0x4b7b0009,0x6d430025}},	//   إملا, _geho, _ראיו, înan
  { {0x7d04214e,0xdd8f0012,0xad650012,0x1d1a003c}},	//   _klis, كول_, لانه, нюдь_
  { {0x05770012,0xf483004c,0x299b0009,0xfc3f07ef}},	//   امنة_, бушн, _אסטמ, lgía_
  { {0x3b960001,0xdddc0042,0x251b0009,0x60c0008e}},	//   ујет, _udrž, עונא, vemm
  { {0x7d0403eb,0x26c10029,0xf388001a,0xb6a3001a}},	//   _llis, ceho_, rợ_, _quầ
  { {0x7d0415ff,0xd1300012,0x60c0214f,0x5f03004c}},	//   _olis, يمت_, temm, _узра
  { {0xb87b0149,0x76430002,0x853d0010,0x7d190034}},	//   _iníc, żnyc, ntėt, ciws
  { {0x1d070047,0xb6a3001a,0x99470003,0x99850010}},	//   _сети_, _tuầ, دليل_, _bylų_
  { {0x60c00006,0x7d040101,0xf7b70012,0xb6c60048}},	//   semm, _alis, اديش_, усий
  { {0x0737007e,0xdbca0051,0xc27b000b,0xf1a90003}},	//   ראים_, _võõr, _נראי, _لانه_
  { {0x6917007d,0x79450034,0x1867004c,0xb87b0064}},	//   nţel, lówn, _баци_, _mníc
  { {0x8ff70003,0xab62003a,0x6285009b,0x60db0009}},	//   _مرور_, şüne, _peho, _רקדנ
  { {0x3f420097,0x853d0073,0xf53f18d8,0x39402150}},	//   oðum_, etėt, slå_, elis_
  { {0xe919002d,0x63a2004a,0x26c10064,0xdce20060}},	//   вові_, huon, veho_, arlı
  { {0xd7e7002d,0x3f420028,0xa2070009,0x9e4b0009}},	//   лізо, iðum_, רֶךְ_, _אֲחִ
  { {0x62850006,0x6c78000a,0xa295002d,0x351c000b}},	// [55f0] _teho, _صحيح_, _капі, _רוחנ
  { {0x7d160b7f,0x6917004b,0xde95004c,0x25a10032}},	//   _zmys, eţel, ражњ, tuhl_
  { {0x8afc003e,0x26c10101,0x63bb04f1,0xf647002d}},	//   _międ, reho_, _spun, ухан
  { {0x7db40003,0x48640014,0xe97a0009,0x297a0009}},	//   إصلا, _гърб, _שנרש, _שטרא
  { {0xdfc6000a,0x63a20957,0xcaa50012,0x4c840024}},	//   _بي_, guon, لصغي, слів
  { {0x2d910066,0x8f9a0009,0x501a0009,0xf8360009}},	//   ázek_, _בישי, _יורו, _כנרת_
  { {0x6f1a00bd,0x3f420028,0xa2290048,0x3b060048}},	//   ditc, gðum_, ъжка_, рещо_
  { {0x68ed00ec,0xa2a70037,0x2909008e,0xdb060031}},	//   njad, _फ़ॉर्, nhaa_, itká
  { {0xdddc000d,0x28da0037,0x3943001e,0x3cf40011}},	//   _terţ, भाजि, ējs_, ूसरे_
  { {0x7d160066,0xf1c00029,0x386d1fd0,0xc9870dc2}},	//   _smys, ššiu_, scer_, _буди
  { {0x1d0a029b,0x245a003a,0xa50a029b,0x3f8d0054}},	//   вени_, _tümü_, вена_, sseu_
  { {0xe3a70003,0xcb6a0014,0x7fd5002d,0x7dd0000e}},	//   ير_, каме_, _вікі, lósá
  { {0xdee50339,0x1ec90024,0x66090030,0x57df0011}},	//   _воли, _алли_, _řekl, नमोह
  { {0x3dc60002,0x5fb60009,0xfaa6004c,0xcc560009}},	//   łowi_, _כהנא_, јаво, יברי_
  { {0xfc3f1ba5,0x8f1a0009,0xada505c8,0xa1870b2b}},	//   rgía_, _בוסת, _тайл, ибра_
  { {0x75290027,0x61e1006f,0x6026002d,0x7d160002}},	//   _njez, ålla, адба, _umys
  { {0x6d3b0009,0xa686002d,0x8fa6010c,0x8e8606a5}},	// [5600] _בתקנ, илад, разе, игае
  { {0xbe85000a,0xd059002d,0x6d5f0061,0x68ed2151}},	//   مجمو, урсі_, _épar, ajad
  { {0xe29b000b,0x729b000b,0xd29b000b,0x6a9b000b}},	//   _בשיר, _בסיס, _בשיט, _בשינ
  { {0xf65500fa,0x07a6003c,0x76430060,0x8fa60281}},	//   стую, _камн, ünya, _каме
  { {0xf863007c,0xb6070039,0x6917000d,0xdc890009}},	//   _євро, ekšē, rţel, רְעָ
  { {0x5b13002d,0x99d60003,0xa9c60003,0x11d60012}},	//   оміт, لتعا, لزبو, لتعد
  { {0xe81a0037,0x79450002,0xb9e60024,0x69d80030}},	//   _नेता_, równ, ріли, _švej
  { {0x3f420065,0x29000603,0xdfd00012,0xa1330012}},	//   rðum_, nkia_, كيب_, يريش
  { {0x29000010,0x4c9b01b0,0x082a0048,0x63a20025}},	//   ikia_, _שבמו, ъцки_, quon
  { {0x3eb80028,0x60c42152,0xc7b30009,0xa2b00011}},	//   ýrt_, heim, קבת_, _आउट्
  { {0x2900004a,0xd3570009,0x62882153,0xab620060}},	//   kkia_, _כימי_, _iedo, şüle
  { {0x79fb000b,0x718b0009,0xe6110009,0xfbe80081}},	//   _שלאח, _יְדַ, פִי_, _trễ_
  { {0x628800b6,0xa1130012,0xb90a0011,0x442d2154}},	//   _kedo, _بونت, मा_, _xxe_
  { {0x6288008b,0x81c30039,0x65660001,0x29000073}},	//   _jedo, ņēmu, _књиж, ekia_
  { {0x8d940003,0x6da30001,0x68ed0054,0xf1940014}},	//   _البش, _дија, tjad, жись
  { {0xae5b0009,0x6d42004b,0x31710031,0x365b0009}},	//   _בכור, jloa, _ézze_, _בכונ
  { {0xb33b003a,0xf7730003,0x6e670434,0x68ed2155}},	// [5610] erçe, تاز_, атеж, rjad
  { {0xa857000b,0xc43c000b,0xe7300003,0x68ed0051}},	//   שימה_, _בתחי, وصل_, sjad
  { {0x7d1d004a,0xdddc2156,0x22640030,0x672500b0}},	//   oiss, _perš, ňské_, rnhj
  { {0xe3b10012,0xd6570009,0xcdd8004c,0x98a40030}},	//   كرت_, ביבת_, шњу_, romě_
  { {0xee870047,0x2d9e0052,0x62880070,0xe3b30003}},	//   _выбо, hrte_, _bedo, ترض_
  { {0x00560093,0xdaa80024,0x64400034,0x6d42004b}},	//   _לשרת_, ивід_, _dymi, aloa
  { {0x6ef30013,0x853d0010,0xe9a80003,0x6d42000d}},	//   _výbě, orėd, لدين_, bloa
  { {0xa7d50012,0x77850479,0x7d1d008e,0x2489004b}},	//   متخص, близ, jiss, _neam_
  { {0x2d9e052b,0x7ff50003,0xf41f2157,0x2e69003c}},	//   erte_, إسبا, _ää_, липп_
  { {0xaf0504f0,0x62880c3b,0xd706003c,0x06e90024}},	//   спол, _gedo, йные_, умок_
  { {0x24890132,0x7d1d2158,0x200d0031,0x2d9108ca}},	//   _beam_, fiss, szei_, éze_
  { {0xb8d40012,0x1d0a0048,0x7bdb102e,0x41550216}},	//   _وتنش, уеми_, _kruu, _увес
  { {0xb4c80037,0x61e1006f,0x89340012,0x78a90227}},	//   _उसी_, ålln, _بعلا, mgev
  { {0x20a70037,0xd4360009,0xa8560009,0x7d1d2159}},	//   _गाँध, מטרי_, _פיסה_, aiss
  { {0x7bcd215a,0xe1e70012,0xa22a0048,0x2900008e}},	//   _esau, أس_, ужва_, tkia_
  { {0x55f6000b,0x3cf10029,0xb8660003,0x29000010}},	//   _למצב_, ľová_, صارو, ukia_
  { {0x69030005,0x999a0066,0x26d10159,0x9b930012}},	// [5620] _tõen, _typů_, _bazo_, _فليت
  { {0xb33b00a2,0xc68f0003,0xd6d20009,0x2fa50012}},	//   nuçl, ِّل_, ּׂא_, تصفّ
  { {0xf992000a,0x20a70037,0xb0a70037,0x22f70009}},	//   _عبد_, _गांध, _गांग, _הזין_
  { {0x2f040028,0x78a90070,0xe76a0012,0x628e215b}},	//   _gögn_, jgev, _محسن_, labo
  { {0x1957000b,0x69030051,0x54360003,0x6bd30012}},	//   _לבטל_, _mõel, حرار, كتور
  { {0x6d420051,0x26c5215c,0x78a90b8c,0xfbd30009}},	//   sloa, jelo_, egev, פתו_
  { {0x7e7e0051,0x64400002,0xcd780009,0x55780009}},	//   _õppi, _wymi, _כְּכ, _כְּד
  { {0x6b400028,0x3ec50010,0x60f8022a,0xb9240012}},	//   mögu, įstų_, рния_, تفعي
  { {0x7d1d1b3f,0x7d020c62,0x6b400097,0xbb750048}},	//   viss, mkos, lögu, _духъ
  { {0x7d020065,0x63a600b6,0x7d1d0347,0x45b80024}},	//   lkos, dukn, wiss, агою_
  { {0xd6d70015,0xa3d00037,0x69da0202,0x2002215d}},	//   сты_, षिक_, _urte, ški_
  { {0xa06a0046,0xc5f3000b,0x07a60048,0x2d9e0032}},	//   _сада_, לדת_, _гадн, rrte_
  { {0x7056000a,0x14aa0037,0xe8d70009,0x29d80081}},	//   _انشا, _कारण, _לואר_, _hĩa_
  { {0x54540015,0x7d1d215e,0x5b27003c,0x2d9e1829}},	//   явят, siss, сьма, prte_
  { {0x41e4002d,0x25a50054,0x8afb000b,0x7d02001d}},	//   піта, cull_, נהלי, kkos
  { {0x673a0054,0x6b400097,0x628e020d,0xa2d90011}},	//   lotj, dögu, aabo, _फोर्
  { {0x2d910066,0xc1b50011,0x02fa0011,0x56670012}},	// [5630] ázev_, _अङ्ग, ्साह_, مداف
  { {0x56780009,0x7d020227,0x628e215f,0xe3b000ae}},	//   שְּׂ, ekos, cabo, _أري_
  { {0x41b50003,0xef11000b,0xd2b60009,0xbe640012}},	//   _بمجر, וּא_, _ולתת_, أهمي
  { {0x30a70047,0x7bdb0051,0x2ec50037,0xebd90048}},	//   _уров, _pruu, _वस्त, идеш_
  { {0x95540012,0xa4b80009,0x673a0031,0x34c90011}},	//   أخلا, מלאה_, kotj, _रसीद
  { {0x4999010c,0xfbb80009,0x0bb80009,0x2a9b0012}},	//   атия_, צפות_, צלום_, ائشة_
  { {0x78a900bd,0x945d003e,0x19860014,0x26c50604}},	//   tgev, _pańs, общи_, velo_
  { {0xb4c80044,0x8afc0002,0x628e2160,0x85050012}},	//   _उसे_, _pięc, zabo, _بورن
  { {0x78a900bd,0x656a0052,0x23740012,0xab740012}},	//   rgev, _aufh, _فالح, _فالإ
  { {0xdcc20037,0x78a90070,0x1bb80012,0x6903005e}},	//   षज्ञ, sgev, _دافع_, _sõel
  { {0x8afc003e,0x6b520058,0x78a90070,0x24ea00f5}},	//   _więc, lægg, pgev, амни_
  { {0x67280051,0x25d60009,0x42040012,0x32360009}},	//   andj, קורן_, _عِنْ, _וטען_
  { {0xcb6a0046,0xc3f9000b,0x26c504d2,0xb3830024}},	//   раге_, ׁלֹש, pelo_, млял
  { {0x7d090054,0xa8560009,0x8b260024,0x6ea60011}},	//   _lles, _וינה_, ідве, _खाएँ
  { {0xfd12000a,0xab19002d,0x69030051,0x27ff010a}},	//   _يجب_, сцях_, _tõel, lyun_
  { {0xb146007c,0xa0670014,0x18670ec6,0xf6520009}},	//   інал, жата_, жати_, _קצה_
  { {0xef1a2161,0x7b760012,0x4fea019c,0xdb060d4c}},	// [5640] ама_, _بطبا, шман_, ttkä
  { {0x27ed03eb,0x3eae0052,0x4ded0037,0x212900b6}},	//   ixen_, üft_, _छपाई_, anah_
  { {0xa2d40044,0xa96a0001,0x6f1e2050,0xe61a004c}},	//   _योग्, _њима_, ripc, јде_
  { {0xf7670003,0xd4c60012,0xe4e30024,0xdd8f0012}},	//   _يا_, تغطي, дішн, ئون_
  { {0x6b440054,0x7d022162,0xfbca0011,0x289b0009}},	//   lògi, rkos, िबिम, _דיכא
  { {0x2ae30044,0x60d6007a,0xb062004a,0x7d022163}},	//   खाएँ_, ldym, äämi, skos
  { {0xaab20044,0xf98f0003,0xf9670015,0x79450002}},	//   _जानक, نبي_, орый_, cówk
  { {0x60d6007a,0x6564004a,0x57f400ac,0xd1300012}},	//   ndym, _niih, зпит, عمة_
  { {0xc9530093,0xdec6004c,0x99e30064,0xcec60357}},	//   ומה_, ољно, ĺňal, ощни
  { {0x7b10008b,0x7d1b0002,0x60d6008e,0xba9700ae}},	//   _häuf, _zmus, hdym, _ونقص_
  { {0x60d60010,0x81c7001e,0x7b101683,0x673a0159}},	//   kdym, trēš, _käuf, rotj
  { {0x37e60015,0x6575000e,0xdb0a0028,0x2fe60012}},	//   _моег, ízha, ðnæt, _وكاف
  { {0xe9ff0020,0x79450002,0x9f460052,0x673a1d8e}},	//   _kiếm_, zówk, _groß_, potj
  { {0xdcfb003a,0x7b100052,0x752d0002,0xbd6a0048}},	//   rttı, _läuf, _wjaz, _крие_
  { {0x2d910066,0x64b30066,0x32050042,0x59ce0011}},	//   ázet_, _přič, ály_, _हैदर
  { {0x8d180003,0xdc3f0145,0x319b000b,0xb9250003}},	//   _وزير_, líčo, יבלנ, أفري
  { {0xc05b007c,0x212900c6,0x644d001e,0xf7700012}},	// [5650] рів_, rnah_, _uzai, نال_
  { {0x8cbc0037,0xc7d7000b,0xcddb0001,0x753d0102}},	//   ष्ठो, חומי_, иње_, losz
  { {0x2d870061,0x7e7e005e,0x2ef80032,0x60d60073}},	//   ène_, _õppu, _dorf_, bdym
  { {0xc5f3000b,0x753d0053,0xbd180024,0x79450034}},	//   ודע_, nosz, оції_, rówk
  { {0x69c1066e,0x35cc0011,0xab940024,0x999e0030}},	//   _sple, ़बड़, дичі, _bytů_
  { {0x79450002,0xc8ab0037,0x57fa000b,0x6ffa000b}},	//   mówi, _छाँट, _הלשו, _ההשפ
  { {0x62080003,0x63a200b8,0x4a9c0009,0x753d0efc}},	//   يْهِ_, aron, ביוג, kosz
  { {0x9943003a,0x3ea9000d,0xdcfb001e,0x61e1004a}},	//   _dış_, şită_, istē, älly
  { {0x47c20015,0xc4d20009,0xe8f60024,0x907c0009}},	//   ебыв, _אגן_, їль_, בטחי
  { {0x6564004a,0xd7090021,0xa9e70012,0x8e740024}},	//   _siih, сное_, _وثان, муюч
  { {0x6283009b,0x7bdf040f,0xed550009,0xc8ab0011}},	//   mbno, _arqu, ּבָר_, _छांट
  { {0xc1ba000b,0x753d000e,0x6d46004a,0x71d6000b}},	//   _למעש, gosz, ulka, _מועד_
  { {0x8027000a,0x6564004a,0x78ad0040,0x69de0030}},	//   _برام, _viih, dgav, _srpe
  { {0x3d020002,0x877a000b,0xb7da0009,0x63a42164}},	//   _mówi_, _האסי, _לקני, šing
  { {0xdce9003a,0x67212165,0xa2ad0011,0x753d0b8b}},	//   ardı, milj, _जार्, bosz
  { {0x15fa000b,0x45fa000b,0x248d0070,0x78ad1a6c}},	//   _להצע, _להצג, _neem_, ggav
  { {0x44260017,0xac17004c,0x2fcd0529,0x6f6600ae}},	// [5660] _ão_, _ноћу_, nweg_, سهام
  { {0x69de2166,0x63a20c0c,0xdaaa035c,0x60c91171}},	//   _trpe, vron, _увод_, heem
  { {0x42fb000b,0x02fb000b,0x8afb000b,0xbafb0009}},	//   _ההיס, _הלימ, _הפיק, _ההיש
  { {0xccf90002,0x61e10058,0xc8da0011,0xe4b80024}},	//   _coś_, ælle, _मोंट, іллі_
  { {0x672103ce,0xf8db0009,0xd4090012,0x645d00d9}},	//   kilj, _החכמ, يتهم_, _úsil
  { {0xb3e9000a,0x2365013a,0x63a22167,0x69dc2168}},	//   تعمل_, _cilj_, rron, _árek
  { {0xd1b70003,0xf2d30009,0x99d30012,0xe297004c}},	//   كايا_, געו_, فتيا, чај_
  { {0x859b0093,0xe01d0037,0x63a22169,0x8b660012}},	//   _לשלו, _बेहद_, pron, _فاطم
  { {0x6721000e,0x6b850012,0xe29a0bda,0x2fcd0227}},	//   filj, _يشكل, _газ_, gweg_
  { {0x3817000b,0xc7d7000b,0x4b7b000b,0x95ca05fb}},	//   פקים_, לופי_, _לאמו, бума_
  { {0x7ae800c5,0x908a000a,0xc27b000b,0xb87b01bd}},	//   _indt, _هناك_, _הרבי, _sním
  { {0x2902006f,0xcd070024,0x7afa216a,0xa92507ef}},	//   ökad_, їчни, _hott, rkþá
  { {0x8ae7002d,0x67210027,0x753d0053,0x9be70024}},	//   півл, bilj, rosz, чінк
  { {0x7afa0006,0x079b000b,0x23650248,0x63a00031}},	//   _jott, _פסול, ölj_, ámna
  { {0x2d9c0149,0x7afa07a8,0x76bb000b,0x78ad06c9}},	//   ável_, _mott, _המופ, tgav
  { {0x8e47000a,0x6b520058,0xd5b80035,0xa0c50012}},	//   _عليك_, væge, mtā_, بيرو
  { {0x78ad00bd,0x88bd0002,0x40340015,0xdbdd0028}},	// [5670] rgav, liśc, еетс, _háþr
  { {0x248d002a,0x7d0d0042,0x7afa216b,0xa8180012}},	//   _seem_, _hlas, _nott, ستقر_
  { {0xd5b80039,0x8afc000b,0x6b890002,0x28f90094}},	//   ntā_, _להזי, _sweg, _день_
  { {0xf6500003,0xd5b8001e,0x6578000e,0xb1b70034}},	//   ائك_, itā_, ívha, ążęc
  { {0xe28e01ef,0x3949006f,0x88f60009,0x50da0009}},	//   ка_, mlas_, _חזרו_, _וקרא
  { {0x7bdd0051,0xd5b8001e,0xaa880003,0x3949216c}},	//   ivsu, ktā_, كنهم_, llas_
  { {0x7d0d0342,0x56840012,0x68f90132,0x60c9216d}},	//   _olas, _سجِّ, _powd, teem
  { {0x7c3a003e,0xa4d4002d,0xa1560001,0x60090339}},	//   ętrz, _посі, мају_, жним_
  { {0xa2b50098,0x57e9002d,0x2d9e006f,0x60c90c98}},	//   _обач, ідом_, _åter_, reem
  { {0x7afa216e,0x88040012,0x2d680060,0xd9ff0011}},	//   _gott, عظيم, _iğer_, ैनात_
  { {0xcb120093,0x3cca06bd,0xddd50031,0xc6920009}},	//   _שלב_, олно_, _kezű, כאי_
  { {0xb9250003,0xcb090009,0xda080012,0x67210f1e}},	//   _تفصي, _דל_, _عينه_, silj
  { {0xed57002d,0xd4960009,0x06f50012,0x2ef50681}},	//   ьою_, וכרת_, _يستج, _оздр
  { {0xada10029,0xf6250001,0x2bc00011,0x88bd0034}},	//   ľúbe, _одло, _एहसा, biśc
  { {0xc5d5002d,0xc7b9000e,0x6146096e,0x443e0002}},	//   _ціль, ltő_, дева, łt_
  { {0x99430003,0xcd360003,0xc5f20009,0xdce4004b}},	//   نَّه, _ترتب, _ידו_, _dună
  { {0x1dd50037,0xc7b9000e,0x7ceb0009,0x4c9b01b0}},	// [5680] धिकत, ntő_, _וַיֶ, _ובפו
  { {0x98a00002,0xc5790009,0x3f800073,0x8fa304a5}},	//   dnią_, ַרְת, rpiu_, тафе
  { {0xdd8f0003,0x75d60003,0x394901e3,0x98a00034}},	//   لول_, بيضا, blas_, enią_
  { {0x7afa01a2,0xfdf6000b,0x0c260021,0x63ab0032}},	//   _sott, וצעת_, ммен, fugn
  { {0x3f420028,0x31c60037,0x63ab020d,0xd36f0012}},	//   iður_, लब्ध, gugn, لهن_
  { {0xa3df0037,0x8b890009,0x24170009,0x3940216f}},	//   णित_, פָנֶ, וחנן_, lois_
  { {0x2d6800a2,0xaac00044,0x63ab002c,0x7afa0097}},	//   _eğer_, श्यक, augn, _vott
  { {0x399b0093,0xa022003a,0xf1b3000b,0x31570012}},	//   קיפד, _şöyl, דסה_, وجية_
  { {0xb8d60302,0x99920002,0x8fa30001,0x88bd0002}},	//   _जा_, ódło_, вање, wiśc
  { {0x7ae80058,0x35f4011f,0xc3fb0009,0xabfb0009}},	//   _undt, епор, _ולמש, _והמר
  { {0x2d98000f,0x7d0d2170,0xda650012,0xd5b80035}},	//   ére_, _plas, _كامي, utā_
  { {0x26d8002c,0x3f420028,0x7e6d004b,0x6da30097}},	//   _laro_, gður_, _şapt, _síað
  { {0xd5b8001e,0x69c52171,0x6fb30012,0x7c670012}},	//   stā_, _sphe, _لمنا, بادل
  { {0x175404b3,0xd7030014,0x5f030014,0x20040034}},	//   _явля, _изчи, _изча, mymi_
  { {0x39400061,0xd5b00012,0x399a0035,0x2caf0248}},	//   fois_, _صفة_, nīs_, yggd_
  { {0x3cf80012,0xa2bf0011,0x98a00034,0xab5b0032}},	//   _يعيد_, _लॉर्, ynią_, gwür
  { {0x200404fa,0xd6db0014,0x39490164,0x6b8204d2}},	// [5690] nymi_, жте_, rlas_, jpog
  { {0x08540047,0x39492172,0x4b7c000b,0xcfb7000b}},	//   твую, slas_, _ואזו, ולמי_
  { {0x26d80010,0x69c50132,0x9f550031,0xfbdf0018}},	//   _daro_, _uphe, égén_, lvê_
  { {0x68f80026,0x399a001e,0xe0870003,0x98a00002}},	//   ľadá, dīs_, _تجدي, tnią_
  { {0xdcfe0039,0x907a000b,0xf3cb0003,0x03a50024}},	//   espē, _מטרי, تباه_, хило
  { {0x2909004a,0x62952173,0x60c22174,0x98a00972}},	//   lkaa_, nazo, _abom, rnią_
  { {0x3f420028,0x61450001,0xdb16000e,0xcb140009}},	//   yður_, нека, écéb, כלס_
  { {0xc7b9000e,0x35a80011,0x62950030,0x5d650012}},	//   ttő_, _कमज़, hazo, _أُرْ
  { {0x8335002d,0xafe5002d,0x7d04004a,0x629519f3}},	//   _знах, хопл, öise, kazo
  { {0xdb25004a,0xc7b9000e,0x93440001,0x60c200b0}},	//   äpäi, rtő_, _анђе, _ebom
  { {0x29090006,0x6ec10011,0x60cd008e,0x69de0248}},	//   kkaa_, र्यु, keam, åpet
  { {0xfd120003,0x28df0321,0x03a6035e,0x5f750012}},	//   اجد_, _पोलि, нимо, _كاتر
  { {0x3f420065,0xe72e0098,0xeb971dbb,0x20040002}},	//   rður_, _бе_, ния_, cymi_
  { {0x3b0a0015,0xb606001a,0x6295000e,0x60db001f}},	//   чего_, _khở, gazo, ldum
  { {0xa18a0098,0x19b9002d,0x1d0a0001,0xa50a0294}},	//   ябва_, муть_, _неки_, _нека_
  { {0x64410052,0xf9920009,0x6440005e,0x60db2175}},	//   ßlic, טרל_, ümis, ndum
  { {0x69c1003a,0x446600fa,0x39400007,0xe7aa0048}},	// [56a0] çler, _явив, rois_, явал_
  { {0x6441003a,0x77460012,0xab5b0032,0x7bd6020d}},	//   şlic, رَام, swür, _isyu
  { {0x39400149,0x02b7000b,0x93250003,0x20040002}},	//   pois_, _אליך_, _جرين, zymi_
  { {0x98a00002,0x99f70009,0xb0ae0011,0xc8ae0011}},	//   dnić_, _נזכה_, _टाइग, _टाइट
  { {0x1016000a,0x98a0003e,0x7afe2176,0xc9530009}},	//   _أبجد, enić_, _kopt, _תמר_
  { {0x399a001e,0x6d4b1652,0x539b0009,0xdcfe0035}},	//   tīs_, alga, לינו, tspē
  { {0x20040002,0x6b822177,0x58d4003c,0xbebc0035}},	//   wymi_, spog, войт, inīt
  { {0xa9670046,0x21670046,0xb9c30003,0xdfd00003}},	//   нија_, нији_, اقيي, ليب_
  { {0xcf260003,0xeab20003,0x399a001e,0x30770012}},	//   فردي, _معا_, sīs_, رحية_
  { {0xdcc90044,0x65690052,0x539b000b,0x501b000b}},	//   िज्ञ, _zieh, _מימו, פויו
  { {0x99e90012,0x21a30048,0x48e60024,0x62951544}},	//   _يعمق_, _бихм, _пожв, vazo
  { {0x26cc012e,0xc8df0011,0xdb0b0248,0x88c60012}},	//   sedo_, _पोंट, rtgå, _ستصل
  { {0x04670047,0x7c670003,0x60cd005e,0x539b0009}},	//   этом, عاجل, veam, ּילו
  { {0xdcfb0010,0x6df40012,0xdee3004c,0xa5c60031}},	//   ystė, _لكتا, _бољи, _adóű
  { {0x2909004a,0x6725019a,0xb9250012,0x9f5f0031}},	//   tkaa_, vihj, نفسي, _órát_
  { {0xc8c90012,0x62950030,0x79750034,0x58d4199e}},	//   بورن_, sazo, _wąwo, лост
  { {0x6b8d003e,0x6934002d,0xbcfb0e6a,0x60cd2178}},	// [56b0] _uwag, унту, rméd, ream
  { {0x6569008b,0xa037000b,0xdb1b003a,0xdb23000e}},	//   _sieh, תאמה_, _ipuç, érül
  { {0xfb1c000b,0x60cd2179,0x46150012,0x6935003c}},	//   _מוזמ, peam, خوار, _анну
  { {0x48ab0047,0x7afe0002,0xc19a000b,0x7bda001e}},	//   _этом_, _zopt, _קשרי, ātuv
  { {0x98a00002,0xc6a70001,0x4ea7004c,0x90980048}},	//   wnić_, _први, _прва, _явят_
  { {0x9f35007c,0x8c1c000b,0x1308002d,0xfe700003}},	//   _регі, הודי, нній_, _هدف_
  { {0x9f34002d,0x8f34002d,0x15a80014,0xa2a80011}},	//   _сері, _серц, _пъти_, फ़्ट्
  { {0xbebc001e,0xf994000b,0x53a50012,0x11d60012}},	//   znīt, ארק_, _لمرك, ئوية_
  { {0xe7b20003,0x60db0051,0x200b00d9,0x6fb20012}},	//   لميد, rdum, áci_, لميا
  { {0x88bd0002,0x97c40012,0x63af001b,0xb8e80011}},	//   ciśn, اتيم, ducn, _लॉ_
  { {0x200b0580,0x867a0009,0x51840024,0xc2570012}},	//   šci_, ורתו, _буча, _أخذت
  { {0xb4be0037,0x2f04006f,0xd48f0024,0x71580024}},	//   ीजे_, _högt_, арi_, _зріс_
  { {0x63af0027,0x711a0009,0x4c9a0009,0x2d470018}},	//   gucn, _קונפ, וברו, lões_
  { {0xa3e20044,0xc7b20009,0x9343003c,0xdb190064}},	//   धित_, _כבד_, иняе, ftwé
  { {0x320c00d9,0x63bd0227,0xa6e10097,0xb10a0012}},	//   ády_, atsn, íðug, وآرك_
  { {0xdddc007a,0x8afc0002,0x63af004b,0x2d85217a}},	//   _perž, _pięk, bucn, mple_
  { {0xf092000b,0xa6960001,0x7524003a,0x5f180011}},	// [56c0] ינן_, вреј, _imiz, योक्_
  { {0x32070042,0x06830024,0x7bc90009,0xbcfb0025}},	//   kyny_, игун, _נֶפֶ, rmée
  { {0x8afc003e,0x394d217b,0xf1e50011,0xba9b0009}},	//   _więk, kles_, किफ़_, _קסטי
  { {0x6da30751,0xca370009,0xe4a30024,0xd826076c}},	//   рица, _יניה_, аршо, _адми
  { {0x69030005,0xdd0c0002,0x2f040028,0x23b70003}},	//   _võet, _półn, _sögu_, ندوب_
  { {0x8c1b000b,0xf9c600b3,0x394d217c,0xf2360009}},	//   ווני, вщин, eles_, ֣רֶץ_
  { {0x6c860003,0xcb130009,0xbcaa0012,0x98a00034}},	//   _للأم, שלו_, _يدرك_, wnię_
  { {0xf9930093,0x28c20011,0xc7d80024,0x66030d71}},	//   ברה_, _वॉशि, емих_, änke
  { {0x29180010,0xa8ab000b,0x99470012,0x1eaa0012}},	//   ėra_, וֹיִ, خليل_, وادي_
  { {0x394d217d,0x75240017,0x9bb70009,0x8a060048}},	//   ales_, _amiz, _בהמה_, _иззе
  { {0xceb30093,0x4c9519fc,0x2d470018,0x236b0064}},	//   בית_, линс, cões_, žijú_
  { {0x98a30345,0xd026004d,0x110a0012,0xd8260048}},	//   _вице, _имей, _تغطي_, _идеи
  { {0xdcfb0039,0xd00f000a,0x39440010,0x7d00188c}},	//   lstī, _ولم_, moms_, _moms
  { {0xb3450017,0x5b27002d,0xda7b0015,0x27e6217e}},	//   moçã, тьма, ьям_, _iron_
  { {0x5757000b,0xa3e30037,0x1db60037,0x4ac40011}},	//   _שבוע_, _नज़र_, _अमित, ल्यव
  { {0xc60e0011,0xc1050012,0x89340012,0xdcfb0035}},	//   ानीय_, دوري, لعقا, istī
  { {0x93470003,0x0855002d,0x2d470017,0x3f9b0061}},	// [56d0] _لخدم, уваю, zões_, usqu_
  { {0xdcfb0039,0x3f9b0061,0x539c0009,0xb7e30011}},	//   kstī, rsqu_, _חיזו, कटतम_
  { {0x8d740351,0x395f007a,0x78a20029,0x2d470017}},	//   لانا, ymus_, _odov, xões_
  { {0x58840015,0xf4870339,0x39440213,0x7c87004c}},	//   _выра, тужн, joms_, туже
  { {0x4ac00037,0x2129041e,0x3944217f,0xad1c0009}},	//   श्वव, miah_, doms_, וואר
  { {0x69030051,0x2d470017,0x62981611,0x21292180}},	//   _tões, tões_, gavo, liah_
  { {0xb5940014,0xceb2000b,0x8afc0009,0x394d2181}},	//   _висш, _לים_, והגי, tles_
  { {0xdfd10003,0x27e60070,0x32070002,0xdb020028}},	//   ميع_, _bron_, ryny_, stoð
  { {0x200900c6,0x2d470017,0x7cd40002,0x395f2182}},	//   nyai_, sões_, _wśró, rmus_
  { {0x26dc00c1,0x395f2183,0x79a7010b,0xdbd1005e}},	//   _cavo_, smus_, _арде, _müüa
  { {0x88bd003e,0xd2510003,0x4d660247,0x20d70012}},	//   liśm, _انا_, лков, _لتشج
  { {0xf6520009,0x637f004b,0xdb062184,0x2d852185}},	//   מצי_, _tână, duká, rple_
  { {0x212900b6,0x6732000e,0xef280060,0xfbd20012}},	//   diah_, ódjá, lmüş_, حتج_
  { {0x26dc0010,0x290d004a,0x68fb0c40,0xa3bb0011}},	//   _gavo_, lkea_, ljud, _अमन_
  { {0x66f6000b,0xfce6002d,0x71760003,0xc3320009}},	//   _תמצא_, _бойо, اهرا, צול_
  { {0x6298000e,0xdd00001e,0xec160012,0x6903005e}},	//   zavo, ītīb, _موعد, _sõer
  { {0x6d462186,0xdd00001e,0xd12f0012,0xf7720012}},	// [56e0] moka, ūtīb, سمك_, صاء_
  { {0x6b84002c,0x6d462187,0xd00f0012,0x68fb005e}},	//   _itig, loka, ألك_, hjud
  { {0x290d004a,0x3abb000b,0xf2d30009,0xb2bb0009}},	//   kkea_, _אמינ, _העת_, _אמיר
  { {0xb87b0b45,0x35450024,0xae590024,0x6fcf0011}},	//   _caíd, ахів, трує_, _सैकं
  { {0x44200020,0xac970003,0xd326003c,0xbcb70009}},	//   ài_, انها_, льки, רפנו_
  { {0x53340001,0x8bd70009,0xb9b40012,0x41b40012}},	//   јект, טונו_, لمتع, لمتر
  { {0x2fc018c2,0xa5d8000b,0xd5d8000b,0x2dd8000b}},	//   ltig_, _בַּי, _בַּש, _בַּב
  { {0x26dc039c,0x29020006,0xf9930093,0x3eb2000d}},	//   _savo_, _joka_, זרה_, şată_
  { {0xe2920351,0x0ab60003,0x7ff60003,0x6d462188}},	//   _هذا_, _محاد, اسعا, doka
  { {0x2fc00052,0x3f82001e,0x39440010,0xc7d7000b}},	//   itig_, īku_, soms_, נויי_
  { {0x68fb0163,0xceb3000b,0x2722001a,0x644d00b6}},	//   bjud, זית_, hưng_, _syai
  { {0x2ed10037,0x9fe60003,0x2fc007a8,0x69da2189}},	//   _हस्त, _مسته, ktig_, _iste
  { {0xdb1d000f,0xc6210037,0x26dc0010,0x31570009}},	//   ltsé, _मध्य_, _tavo_, _עידן_
  { {0x501b0093,0x3dc60002,0x59b80037,0x45f80012}},	//   _אודו, łowy_, _इमार, _لفتح_
  { {0xfe6f0012,0x6d460031,0x867b01b0,0x656d218a}},	//   _عدو_, boka, _ארוו, _tiah
  { {0xdbd10051,0x93c7000d,0x6b520028,0xdb0b0058}},	//   _püüa, ltăţ, nægj, stgø
  { {0x2eab0046,0x200f000f,0x212900c6,0x2fc00058}},	// [56f0] ењен_, ági_, riah_, gtig_
  { {0xb87b0017,0x2d9e009b,0x7bcd002c,0x8c1c0009}},	//   _saíd, oste_, _ipau, _רוזי
  { {0x212900b6,0x69da0070,0x2d9e218b,0x74bc0011}},	//   piah_, _nste, nste_, ष्कृ
  { {0x39a1007a,0xdb1d0031,0x2d9e218c,0xa1590a36}},	//   mės_, dtsé, iste_, _јаму_
  { {0x39a1007a,0x5bc40003,0x889a007e,0xec78002d}},	//   lės_, متوف, _בברי, упі_
  { {0x637c000b,0x3f8900b6,0xd2a60594,0xdce40030}},	//   תנגד, mpau_, акше_, _buně
  { {0x39a1039c,0xd2b8000b,0x2d9e1549,0x63a80002}},	//   nės_, אלות_, jste_, ądni
  { {0xd131000a,0x93c7000d,0x25ab001e,0x2d9e218d}},	//   تمع_, etăţ, īklā_, dste_
  { {0x290d004a,0x02a70229,0x2d9e218e,0x69da218f}},	//   rkea_, _брем, este_, _este
  { {0x39a1007a,0xd7090015,0xfbd00012,0x290d008e}},	//   kės_, тное_, _عتق_, skea_
  { {0x6d462190,0x5ee8000b,0x69940024,0xf1c80012}},	//   toka, אַרְ, _гріх, _مولى_
  { {0x39a1007a,0x6d46004a,0x808b0012,0xd2280012}},	//   dės_, uoka, _أضاف_, _حكمه_
  { {0x9cd6000b,0xb9090037,0xd4560014,0xdce90029}},	//   בורה_, मय_, ртнь, _nieč
  { {0x6d460629,0x501a0009,0x539a0009,0xb4d20011}},	//   soka, _בונו, כישו, _वस्_
  { {0xc8960046,0xd5e80003,0x8a0300de,0x40960209}},	//   ирањ, _معين_, озре, ират
  { {0x692c003a,0x7bdb004a,0x387f0f50,0xdcfc0035}},	//   eğer, _osuu, ncur_, _otrā
  { {0x2fc00052,0xd00702ad,0x21670291,0x6937001b}},	// [5700] utig_, аете_, рити_, pćen
  { {0x39a1007a,0xbda60003,0xdb06003a,0xb7d70003}},	//   bės_, لحصو, dukç, ؤولا_
  { {0xab5b0052,0x69030051,0x629c1214,0x2bde0011}},	//   stüc, _tõep, maro, मिका
  { {0x7d040006,0x6603006f,0x6df30003,0x452a0048}},	//   _jois, änka, تكما, ъжен_
  { {0x656200b6,0x64360012,0xab770012,0xd3d70012}},	//   rmoh, جراء, لمنا_, لبوا_
  { {0x2d9e0013,0xbcfb0066,0xdb1d000e,0x39a6072b}},	//   yste_, jmén, ttsé, ашив
  { {0xbcfb000e,0x4aad0037,0x6028001e,0xd1b70012}},	//   dmén, फ़्टव, zīmī, لايا_
  { {0x4ddb000b,0x3d100037,0xf1a70011,0x27c60024}},	//   _בחלו, ासों_, _गिरन, ащог
  { {0x39a1007a,0xc60e0037,0x69da0002,0x629c2191}},	//   zės_, ान्य_, _wste, karo
  { {0x2d9e00bd,0xa9a60098,0x6360000e,0x7b100052}},	//   tste_, _вижд, lönf, _bäum
  { {0x0f570093,0x7bcd007a,0x69da2192,0x67ca001e}},	//   שיים_, _spau, _uste, lējā
  { {0x7d040017,0xd7e6002d,0x39a10010,0xa98b0009}},	//   _cois, _віко, vės_, _סָבִ
  { {0x6f030108,0x2d9e1b6c,0x9ffa0012,0x39520073}},	//   _fonc, sste_, _جراء_, dlys_
  { {0x6e94000a,0x39a1007a,0xbcfb0066,0xa3ae0037}},	//   _الثا, tės_, cmén, _किन_
  { {0xe919002d,0xba080014,0xdb0a0031,0xdb06005e}},	//   гові_, ахте_, ónáj, dukä
  { {0x39a10010,0x629c0070,0xd5fb0009,0x7bc2016d}},	//   rės_, aaro, _יפור, ktou
  { {0x39a10010,0x3e870012,0x25de0011,0x984b0048}},	// [5710] sės_, لشاف, गिकी_, тява_
  { {0x39a1007a,0x67ca0039,0x1dda0037,0xceb80010}},	//   pės_, dējā, _बनात, ngę_
  { {0x09f9000a,0xdcfc001e,0xa3df0011,0xbb3a0009}},	//   _صفحة_, _strā, णिक_, _תעתי
  { {0xee380024,0x71d60009,0x28f9003c,0xbcfb0031}},	//   шнє_, _פורד_, _семь_, zmén
  { {0x2bda0321,0xd0f60009,0x00f60009,0x8cbc0011}},	//   _मैदा, _המרת_, _הזרם_, ष्टो
  { {0xc324007c,0x20d1001a,0xebd80009,0x73d80009}},	//   омік, _ại_, שֵׁי_, שֵׁב_
  { {0x81c7001e,0x2002008e,0x412901c6,0x09f90012}},	//   ksēš, äkin_, локо_, افعة_
  { {0x97c50003,0x7b100052,0xba380009,0x3a380009}},	//   مقبو, _räum, יטוח_, ירום_
  { {0xbcfb000e,0x8afc0002,0x6f032193,0xa3ae0011}},	//   tmén, _pięt, _ponc, _किय_
  { {0x46f50015,0x6f1a12eb,0xef16003c,0x6917004b}},	//   счит, ghtc, ймы_, nţez
  { {0x7d0403fc,0xd3360009,0x160e0011,0x7d160040}},	//   _pois, _פרעה_, ानगर_, _plys
  { {0xcb090093,0xd2560009,0x94060012,0x7ae12194}},	//   _אל_, _השעה_, موجه, _halt
  { {0x629c014d,0x7f85000a,0x4424001a,0x7d0417e5}},	//   taro, _التن, àm_, _vois
  { {0x44630014,0xbcfb0031,0x66100031,0x2af005f3}},	//   явяв, lmél, ökké, चाएँ_
  { {0x7d040006,0x7b32003e,0x75290013,0xd356000b}},	//   _tois, sług, _omez, מישי_
  { {0xd1320003,0x69ba0037,0xb87b01e3,0xdcfe0035}},	//   أمر_, _एमसी, _raíc, rspī
  { {0xc6760003,0x29c1001a,0x66760003,0x66030248}},	// [5720] مطاب, hóa_, مدار, änkn
  { {0xe646007c,0x1ea90003,0xab5b000e,0x93fb000b}},	//   безп, لامي_, ltün, _עליי
  { {0x83650012,0x4e460012,0x645b0018,0x3c860012}},	//   _بديل, حَاق, _azui, مؤشّ
  { {0x67ca001e,0xdcb90024,0xf5250024,0xdca30696}},	//   tējā, ищі_, офін, заци
  { {0xa9470009,0x2d080011,0xcce50012,0xc30a0024}},	//   _לָךְ_, _वकील_, تسلي, ледж_
  { {0x7bc20061,0x67ca001e,0x11d60003,0x99d60012}},	//   rtou, rējā, متعد, متعا
  { {0xf2d3000b,0x7bc21f28,0x853d0010,0x41e60012}},	//   פעה_, stou, orėt, إستف
  { {0xd1300003,0x67ca001e,0xb7d80012,0x61e10040}},	//   ظمة_, pējā, لوبا_, ælli
  { {0x69c31bf2,0xaaba0012,0x17fa0012,0x7d0d008e}},	//   atne, _مدار_, ارعة_, öase
  { {0x272f0002,0xd6da062c,0xf5aa0009,0xbb560012}},	//   ożna_, ути_, ְבָּ, _انطب
  { {0xde580024,0x9e140024,0x63a42195,0x629a2196}},	//   рані_, ідмі, _avin, _ieto
  { {0x5c070048,0x9f95005e,0x7b320034,0x6937001b}},	//   бяга, _püüe_, słud, tćem
  { {0xe0430955,0x84340024,0x81c70035,0x629a2197}},	//   _енци, зняє, rsēš, _keto
  { {0x629a0061,0xa3e90037,0xf1ac0037,0xc87f0052}},	//   _jeto, यित_, _घटान, _maße_
  { {0xc333000b,0x63a42198,0x629a2199,0x39490522}},	//   לוש_, _evin, _meto, toas_
  { {0x9955007c,0x8637000b,0xce370009,0x68e4020d}},	//   ікац, _לרוב_, _לאות_, gdid
  { {0x752f0002,0xe7870024,0xe6990048,0xdb0f01e3}},	// [5730] micz, субо, иваш_, lucí
  { {0x752f003e,0x05790003,0x39490017,0x68e41f85}},	//   licz, لمئة_, soas_, adid
  { {0x65d50003,0x63a20052,0xedd50012,0x6eca0011}},	//   تياط, eson, تياد, त्यु
  { {0x752f003e,0x5455107b,0xe6110009,0x984b0048}},	//   nicz, овет, וִד_, _бяга_
  { {0xdcfc000d,0x2bdf0011,0x853c0009,0xe824003c}},	//   _stră, _पैमा, נגדי, _ефро
  { {0x539c01b0,0xcb9c0009,0x752f0034,0xab5b0031}},	//   נסוא, נסוט, hicz, ztün
  { {0x20120029,0x7ae1219a,0x3abc0009,0xe9a80012}},	//   čniť_, _valt, אמונ, مدين_
  { {0xdb0f01e3,0x98bf004b,0x1fa9003c,0xe7a91193}},	//   ducí, două_, акии_, авил_
  { {0x6d4b219b,0x63a2000e,0xef1902c4,0x6006003c}},	//   moga, cson, ими_, жным_
  { {0x629a0c3b,0x6d4b219c,0x59c50012,0x27e9008e}},	//   _geto, loga, _ويذك, ivan_
  { {0x752f003e,0x2919003a,0xceb2000b,0xf6510012}},	//   ficz, _olsa_, ויי_, بئة_
  { {0x752f0002,0x4c830024,0x671d0011,0x62850040}},	//   gicz, млюв, योजक_, _afho
  { {0xe72e04b3,0x78bb001e,0xdb0f000d,0x63600052}},	//   _же_, mguv, ducâ, höne
  { {0x2ca9219d,0x02f90009,0x3f8d0e1f,0xe2970229}},	//   _edad_, ׁלָמ, mpeu_, жар_
  { {0xcdc80003,0x60d60028,0x3f8d0054,0x6ee40012}},	//   _هذين_, teym, lpeu_, _رسول
  { {0x78bb0051,0x853d0010,0x63a4219e,0x7d1d0032}},	//   nguv, urėt, šini, chss
  { {0x98a90002,0x68e40892,0x370619fc,0x60d60097}},	// [5740] znać_, rdid, опаг, reym
  { {0xab5b00a2,0x27e20028,0x98a90034,0xd7ef0012}},	//   ntül, ækni_, ynać_, ضكم_
  { {0x6d4b219f,0x69de0133,0x8c3b0052,0x98a4000d}},	//   foga, _uspe, raße, nimă_
  { {0xa3ce0044,0xf09f0020,0x63a221a0,0x7bc618c7}},	//   _रहा_, _hoàn_, tson, otku
  { {0xd40300de,0x43940593,0x629a21a1,0x98a90034}},	//   дящи, чалс, _peto, wnać_
  { {0x6360000f,0xfbb20037,0xa3bb0011,0x7f190024}},	//   lönb, _जिनम, _अमर_, _лісу_
  { {0xddc30046,0xc3270003,0x9cb60003,0x63a221a2}},	//   _обри, تكون_, _ومست, sson
  { {0x63ad0333,0x984f003a,0x60f80083,0x1fa621a3}},	//   šana, _ağır_, сния_, орог
  { {0xdfd0000a,0x8afc0002,0x6ab60011,0xa2d60012}},	//   ريد_, _chęc, _अफ़्र, _ويرت
  { {0xe5c60047,0x15ea002d,0xcff7000b,0x752f0002}},	//   осмо, аємо_, קציה_, wicz
  { {0xa3e20044,0xd5b706e6,0x8e7b000b,0x667b000b}},	//   धिक_, ося_, יניה, יטיק
  { {0xbfa30020,0x6eca0011,0x657c008e,0x27e90060}},	//   _kiế, स्तु, _murh, yvan_
  { {0xa06a0001,0x9be40024,0x5bb8003c,0xdb1d0097}},	//   _тада_, мірк, оляя_, stsí
  { {0x672a0028,0x78a021a4,0xe4510009,0xc34b0365}},	//   _umfj, lamv, גֶל_, ряме_
  { {0x7d020039,0x398300a2,0x7bc6006e,0x853d0073}},	//   kjos, _kısa_, atku, urės
  { {0xa3bb0011,0xa98b0009,0x2eed004b,0x98a60159}},	//   _अमल_, יָמִ, _şef_, _omoč_
  { {0x39a5001e,0x6d4b0017,0xb7ed0011,0xe7ed0011}},	// [5750] zēs_, voga, जियम_, जिया_
  { {0xa9280013,0xd6db0001,0x27e921a5,0x657c047b}},	//   _požá, јта_, rvan_, _burh
  { {0x6d4b000f,0xab5b0052,0x0dc80024,0xe6780024}},	//   toga, ntüm, жучи_, ійці_
  { {0xbfa30020,0x04c80003,0xdce2009b,0xe5780024}},	//   _biế, قومي_, bmoč, ізі_
  { {0x78fa000b,0x2bbb0003,0x7ae501a3,0x97c70012}},	//   _הפרו, شاشة_, _kaht, _بتجم
  { {0x31690b51,0xfbb8000b,0x39a5001e,0x49950024}},	//   lmaz_, קפות_, tēs_, пшит
  { {0xdb240065,0x98a4000d,0xdd910003,0x3ea1005e}},	//   ðrét, ximă_, _سوء_, maht_
  { {0x7ae50051,0x39a5001e,0x3169003a,0xe8f903e2}},	//   _laht, rēs_, nmaz_, сли_
  { {0x69c7001c,0x39a5001e,0x63a909ea,0x7c220002}},	//   htje, sēs_, šenj, czor
  { {0x1dd20037,0xef19057b,0x7ae5004e,0xa2b4107b}},	//   _सहमत, смо_, _naht, _обуч
  { {0x7b320002,0x9f420030,0xa6e20097,0x9f400018}},	//   słuc, íká_, óðau, nviá_
  { {0x69c700c5,0x4a5a0009,0xc3290009,0x04460695}},	//   dtje, _הדעו, _גו_, земн
  { {0x987a000b,0x7d090c3b,0xa87a0009,0xa0880009}},	//   _האנט, _moes, _האנר, _וְצִ
  { {0xa3ae0044,0x28ce0037,0xf7480012,0x692c0060}},	//   _किस_, ह्नि, _وجوه_, rşem
  { {0x60cf0164,0xe2a70028,0xab270024,0x62630086}},	//   _bbcm, íðar_, чора_, евра
  { {0x04460014,0x64430002,0xf1e20011,0x657a0025}},	//   _нейн, _śnie, _कैफ़_, _éthi
  { {0x94bb0093,0xf09f0020,0xa0670014,0x6564002c}},	// [5760] _המפת, _toàn_, зата_, _ihih
  { {0x7d1b0176,0x8c3d003a,0x752d21a6,0x69dc0132}},	//   _alus, _keşf, _zmaz, pwre
  { {0xceb2000b,0xee3a0001,0xf297000b,0x8a7b0009}},	//   תיב_, љне_, _מכיר_, _לאית
  { {0xdd8f0003,0x7ae5048b,0xd9460001,0xc213000b}},	//   اون_, _zaht, _хеми, _נהר_
  { {0xf8b30093,0x98a4007a,0x629e00b6,0xdb1d000e}},	//   _אשר_, nimą_, _kepo, ltsá
  { {0xbfa30020,0xd379002d,0x7d1b05cd,0x63a621a7}},	//   _viế, ічі_, _elus, iskn
  { {0x7c220123,0x6564016d,0x6b520040,0x7d1b21a8}},	//   szor, _ohih, lægs, _flus
  { {0xbfa30020,0xbcfb000f,0xa37b0051,0x98a40010}},	//   _tiế, rmék, svõi, kimą_
  { {0x98a4007a,0x692c003a,0x5f000011,0x44220248}},	//   jimą_, eşek, राप्_, _åk_
  { {0x752d0013,0x98a40010,0xba3c0073,0x141b0009}},	//   _smaz, dimą_, _neįg, _הומב
  { {0x2d9802b5,0xa4d90046,0x27200020,0x1cd9003c}},	//   ère_, одну_, _lòng_, одны_
  { {0xd197000b,0x7ae51407,0x24860d1f,0xe97b0009}},	//   _זכאי_, _saht, ncom_, _הנאש
  { {0x399a0010,0x98a40010,0x61dc0011,0xab5b07bc}},	//   lūs_, gimą_, _मनुष, stüm
  { {0x32cf003a,0xc9770012,0x26da001b,0xcb8b0009}},	//   cıyı_, كارث, jepo_, מְלֹ
  { {0x65880013,0x48ab0015,0x629e21a9,0xceb30009}},	//   _běhe, йтам_, _depo, _טיס_
  { {0xe63b0093,0x55bb000b,0x76550002,0xa63b0009}},	//   _לתוכ, _המהו, _ryzy, _לגור
  { {0xc05b007c,0x224d0002,0x69c70262,0xdfd10012}},	// [5770] сів_, łek_, stje, ضيا_
  { {0x31690039,0x27200020,0xec38000b,0x6b8d002c}},	//   smaz_, _dòng_, _מאחר_, _itag
  { {0x7d1b21aa,0x692c0060,0x753d0032,0x3ea10032}},	//   _plus, kşeh, onsz, raht_
  { {0x95570012,0xe8550012,0x32cf0060,0x399a0073}},	//   أخطا, _يندد, zıyı_, dūs_
  { {0xed58002d,0x3b840024,0x8c3d0060,0x200f005e}},	//   чої_, еліг, _meşg, ägid_
  { {0x63ad029f,0x60c2040f,0x35b504ad,0xd7fa0009}},	//   šano, _acom, _обгр, _והשל
  { {0xe9d9007c,0x7d0900bd,0xdb24000e,0x7d1b0030}},	//   іки_, _toes, éséb, _tlus
  { {0x7d1b003a,0x2d830042,0x92580012,0xdfd10012}},	//   _ulus, íjem_, أشهر_, نيع_
  { {0xd0a80003,0xc4d20009,0xab390024,0xb4b90011}},	//   سطين_, _בגן_, _дпау_, चली_
  { {0x98a4007a,0x05a90047,0x399a001e,0xee39048c}},	//   vimą_, овой_, būs_, жно_
  { {0x63a90065,0x6aa321ab,0x82150012,0xfd120012}},	//   _hven, manf, _تواص, نجح_
  { {0x98a40010,0x301500b3,0x63a90028,0xdbd7008e}},	//   timą_, _одер, _kven, päät
  { {0xe3b20003,0xeb97022a,0x3e7c0030,0xf8b20009}},	//   خرج_, мия_, nští_, _ישא_
  { {0x98a40010,0xdb1d000e,0x2fc91899,0x877a0009}},	//   rimą_, ttsá, dtag_, _ואסי
  { {0xdcfb003a,0xa50a0867,0x1d0a0048,0x98a40073}},	//   artı, _мека_, _меки_, simą_
  { {0x63a9038e,0x6aa30052,0x98a40010,0xd59a0009}},	//   _oven, hanf, pimą_, _ובקל
  { {0x24860029,0x63ad0028,0x8fa3004d,0x63a90040}},	// [5780] vcom_, áanl, кате, _nven
  { {0x27200020,0xfe720003,0x24860002,0xb6360003}},	//   _vòng_, ندا_, wcom_, وعات
  { {0x6ce6002d,0x5afb000b,0x8afb007e,0x02fb0009}},	//   діле, _וליצ, _והיי, _ולימ
  { {0x399a0010,0x68e90040,0x27200081,0xe45a083a}},	//   vūs_, jded, _tòng_, оже_
  { {0x27ed00bd,0xc3da000a,0x68e900a2,0x2ca00051}},	//   jven_, تباط_, dded, _meid_
  { {0x60c200c1,0xdd920012,0x399a0073,0x298a004c}},	//   _scom, _لوس_, tūs_, осио_
  { {0x27ed0070,0x7b100052,0x999e0010,0x4b370009}},	//   even_, _häus, _rytų_, ורסל_
  { {0xcece0020,0x2ca00005,0x63a921ac,0xa9670001}},	//   _cộng_, _neid_, šeni, мија_
  { {0xc953000b,0xa7140024,0xf9570009,0x399a0073}},	//   כמה_, емпі, וסקת_, sūs_
  { {0x22160014,0xd7fb000b,0x8b650012,0x57fb0009}},	//   _офер, קהיל, _كالم, קליו
  { {0x1d35007c,0x1df80015,0x60cd003a,0x2902006f}},	//   ення, чены_, yfam, ökas_
  { {0x6603074a,0x81690012,0x9f40008e,0x249f0097}},	//   änki, _فإنّ_, lviä_, úum_
  { {0x7a130013,0x10160003,0x442621ad,0x88160012}},	//   _větš, _تباد, nzo_, _تباط
  { {0xbcfd001a,0x2d550040,0xdb0b0248,0x442621ae}},	//   _nhũn, lået_, stgö, izo_
  { {0x2bdf0037,0x76bb0009,0xf77f0060,0x62870034}},	//   _पैरा, _ומופ, _suç_, rcjo
  { {0x2d550058,0x79540012,0xc8c90012,0xd0d40048}},	//   nået_, نَّا, ثورن_, косъ
  { {0x4034035b,0x4c9c0009,0x62870034,0xa834004c}},	// [5790] ветс, _ובחו, pcjo, ветљ
  { {0x6937001b,0x6d590227,0x7658008e,0x60db0031}},	//   ećet, wlwa, _kyvy, zeum
  { {0x68e900a2,0xc9870003,0x200f0051,0x7cd9004d}},	//   yded, _تشخي, ägib_, змер_
  { {0x2fc90058,0xb4b90011,0xf53f00b0,0x3e7c0030}},	//   ptag_, चले_, nnå_, tští_
  { {0xdb1d00c5,0xcece0020,0xeb990063,0xcbc40012}},	//   rtsæ, _rộng_, чил_, نزوي
  { {0xfbb20044,0x3179000e,0xdb1d0058,0x8f9a0009}},	//   _जिसम, _hisz_, stsæ, _מישי
  { {0x929c0009,0xba9c0009,0xe5c4112e,0x2175004c}},	//   חיות, חסוי, _исто, нуир
  { {0x7d0d007d,0x75220013,0xfa78000b,0x7d04004a}},	//   _noas, choz, ועות_, öist
  { {0x61f80026,0x2019000f,0xbb840003,0x44260034}},	//   _ďalš, ási_, _للقي, czo_
  { {0x22950012,0x92670012,0x2ca002b9,0x63bd0150}},	//   _ألاس, _قدام, _seid_, dusn
  { {0xa2c40037,0xa2dc0011,0xc27a0009,0x7d0d0132}},	//   _रात्, फ़र्, _זרעי, _boas
  { {0x8996000b,0x7d0d21af,0x6aa121b0,0x64430034}},	//   _נכנס_, _coas, _helf, _śnia
  { {0x97d8000a,0x74550014,0x74160003,0xdb0605b1}},	//   _يظهر_, върх, روسا, lské
  { {0xe9ff0020,0x316d003a,0xada50ee6,0xaa810097}},	//   _giảm_, lmez_, _закл, _þýdd
  { {0x442601a2,0x2ca00051,0xa96a0001,0x3ea521b1}},	//   zzo_, _teid_, зива_, malt_
  { {0xc57a000b,0x316d003a,0xbcfb01e3,0xdb1d008e}},	//   _צרפת, nmez_, eléf, etsä
  { {0x63ad048b,0x9f40004a,0xc5690003,0xe53b0009}},	// [57a0] šanj, yviä_, _تحول_, _מתקר
  { {0xe9e50020,0x6fb30012,0x2d5c01a0,0x78a421b2}},	//   _đúng_, املا, ríem_, saiv
  { {0xdd8f0003,0x2d9c0061,0xba9b000b,0x429b000b}},	//   مول_, ève_, _מסיי, _מסיב
  { {0x3d1e0037,0x3ea5074f,0xcea90009,0x7b100032}},	//   _पतों_, halt_, מי_, _täus
  { {0x2d550033,0xeb97003c,0xdb060030,0x75220031}},	//   vået_, еич_, eské, rhoz
  { {0x3ea50005,0x853d0010,0x39401f85,0xd3700012}},	//   jalt_, gsėj, lnis_, جهت_
  { {0x8cc10037,0x3ea50597,0xdbd20051,0x2d55014f}},	//   _वालो, dalt_, lüüt, tået_
  { {0x2c57003e,0x61230051,0x2df70009,0x61d70009}},	//   _będą_, _võlg, _אצלך_, תוקף_
  { {0xc7d70015,0x6aa1000e,0x9346004d,0x7ae8020d}},	//   емых_, _felf, _знае, _tadt
  { {0x3940008b,0x80170003,0x61230051,0x33d5002d}},	//   hnis_, عزيز_, _tõlg, _шіст
  { {0x07370093,0x9b17000b,0xdb06000e,0x3f82173a}},	//   תאים_, _רחבה_, cské, _luku_
  { {0x6aa10070,0xdb0d0028,0xd1320012,0x721b0009}},	//   _zelf, ákök, _حمص_, _מובח
  { {0x8c3d00a2,0x0b8b0014,0xa2d50011,0x7d0d004b}},	//   _teşe, ясни_, _मॉड्, _voas
  { {0x61230051,0x63bd0738,0x6ffb0009,0x29aa0009}},	//   _mõle, rusn, _מהדפ, ּיּ֣
  { {0xcf57000b,0x63bd00b6,0x15f30003,0x31790034}},	//   _רבות_, susn, _مسيح, _pisz_
  { {0x3f8200c6,0x865b000b,0x365b000b,0x0e5b000b}},	//   _buku_, _מדוי, _מכונ, _מדוב
  { {0xb4dd0044,0xd6db0048,0x64a4004c,0xf51a0009}},	// [57b0] ड़ी_, зте_, _сања, _חֵיל
  { {0xc43c000b,0x6d5d006f,0x3f8f001e,0x4c3c000b}},	//   _מתחי, llsa, īgu_, _מתחב
  { {0xdb1d0163,0x39400052,0xf09f001a,0x26de21b3}},	//   rtsä, bnis_, _loài_, ieto_
  { {0xbd18002d,0x7db40003,0xdb0600d9,0x45180024}},	//   нції_, اصلا, vské, нція_
  { {0xdb1d0052,0xac840024,0x68ed0060,0xc7b90031}},	//   ptsä, угіл, mdad, rzők_
  { {0x3ce9009b,0x27240028,0xdb0600d9,0x5018004c}},	//   žav_, _röng_, tské, _џорџ_
  { {0x3ea50005,0x2d850061,0x9f4b0066,0x6d470029}},	//   valt_, _île_, ící_, čkaj
  { {0x63ad006f,0x3ea50052,0x13f50014,0x2909004a}},	//   _ovan, walt_, _избя, njaa_
  { {0xa3ae0044,0x31560003,0x4439006f,0xf8bf000e}},	//   _किए_, خليج_, _äs_, _elég_
  { {0xbcfb0013,0x7b770003,0xdb060066,0x39400b9c}},	//   hléd, _أطرا, pské, znis_
  { {0xdc340026,0xa3e90037,0x1af60009,0x3ea521b4}},	//   rúča, यिक_, _שמעל_, ralt_
  { {0x6aca0044,0x3ea50005,0x40870014,0xf9880012}},	//   िभ्र, salt_, _чужб, _أنني_
  { {0x68ed006f,0x8bac0009,0x26de21b5,0x4535003c}},	//   ddad, ּׁלִ, beto_, ухэт
  { {0x68ed0017,0x8064002d,0xe7330012,0x26de21b6}},	//   edad, _свіж, _حصص_, ceto_
  { {0xc332000b,0xa2c40037,0x394021b7,0xdb040017}},	//   בום_, _रास्, tnis_, _aviã
  { {0xdcf9001e,0x6d4400b6,0x21760001,0xddc70002}},	//   _tuvā, _ujia, ђувр, _wyjś
  { {0x68eb0101,0xdb160028,0xed570009,0x39520bb5}},	// [57c0] _magd, ðbót, _בבקר_, roys_
  { {0x394021b8,0x26060037,0xf3c90003,0x8afc0002}},	//   snis_, _सऊदी_, _أبيه_, _więz
  { {0x7589002d,0x63ad21b9,0xa50a0048,0x2d5518d3}},	//   есів_, _zvan, межа_, våer_
  { {0x6b840051,0x61230051,0xe9ff001a,0x68eb002c}},	//   _kuig, _põle, _nhằm_, _nagd
  { {0x99410002,0xead80024,0xb5450012,0xb9060011}},	//   kół_, емлі_, دخله, फ़_
  { {0x60c421ba,0xa9c60012,0xdd030035,0x7b1401a0}},	//   lgim, نزبو, ārām, _nàut
  { {0x3134002d,0xe5a3111e,0x2614000b,0xbcfb0061}},	//   лекр, _виси, _גַּם_, llée
  { {0xc213000b,0x60c421bb,0x9fe60012,0x23b20011}},	//   שהה_, ngim, نسخه, _जिंद
  { {0x68eb0101,0xa4b7000b,0x3f6603b0,0x26de21bc}},	//   _dagd, _שלמה_, ктоб, teto_
  { {0xaae50003,0xd5b8001e,0x4d98002d,0x6726001e}},	//   _مسمو, trā_, нкою_, īkjo
  { {0x5ebb000b,0xd5b8001e,0x8b57000b,0xe3570009}},	//   וזיק, urā_, _יימס_, _ישמח_
  { {0xb4dd0037,0xa5c20002,0x6d5d21bd,0xf6530009}},	//   ड़े_, łówn, ulsa, יצת_
  { {0xcfb40014,0x6d42004a,0x70b70009,0xd12f0012}},	//   _сблъ, inoa, _יהאד_, _بمن_
  { {0x68e0003a,0x60c4052d,0x2d870cb8,0x59c60011}},	//   lemd, egim, ínek_, रंपर
  { {0x987e003a,0xaa580001,0x98a90002,0xba740003}},	//   _açık_, виру_, niać_, لافت
  { {0xbcfb21be,0x68e0003a,0x60c420e4,0x3987005e}},	//   rmés, nemd, ggim, _võs_
  { {0x19580047,0x2909004a,0x691c0061,0x4fc70014}},	// [57d0] таты_, rjaa_, _réel, ъсва
  { {0xa2c40044,0x4fc40001,0x5fb70011,0x7d1d016a}},	//   _राष्, јста, ेंबल, lkss
  { {0x39460164,0xc7b9000e,0xd4b90593,0xe9190024}},	//   _ojos_, rzői_, елец_, _зоні_
  { {0x99f60093,0x2d590061,0xbcfb0061,0x3eb90010}},	//   _עזרה_, mées_, blée, ėsti_
  { {0xd006000a,0x2d590061,0x291e001e,0x62800066}},	//   _ال_, lées_, ītat_, ěmov
  { {0x5694007c,0xdb1d0061,0xa2d60011,0x65880030}},	//   _варт, fusé, म्प्, _něho
  { {0x2d590108,0x68eb0101,0x290f001e,0x8cbb0012}},	//   nées_, _pagd, _poga_, _يدرس_
  { {0x11d60003,0x2d590061,0xa9660264,0x88e5003c}},	//   اوية_, iées_, лища_, ужие
  { {0x7ff50003,0xf2c70345,0x9b880012,0xcf390024}},	//   اسبا, _асен, _لنقل_, ечні_
  { {0x245d000e,0x8f9a0009,0x09f70012,0x0609003c}},	//   zámú_, עיתי, _لأصد, енок_
  { {0x290f001c,0x2fcd006f,0x64a6035c,0x613e0035}},	//   _toga_, steg_, лана, zīli
  { {0xa3e70044,0x2f160065,0xdcfc0039,0x8d550024}},	//   _बना_, _hægt_, _kurā, итяч
  { {0xdcf90039,0x99410002,0xad1a0009,0xdb040018}},	//   _atvē, pół_, גורר, _aviá
  { {0x78a90051,0x6fb20012,0xbcfb0025,0x3ced005e}},	//   laev, _اموا, umér, _laev_
  { {0xc332007e,0x395f0051,0x2d590061,0x321e01bd}},	//   מוך_, olus_, gées_, áty_
  { {0xd1320012,0xa2d50011,0x2fc00227,0x5fb70011}},	//   حمر_, _मॉस्, tuig_, _इटाल
  { {0x6fa50003,0x806601b6,0x321e0042,0x9696005f}},	// [57e0] لإلك, уваж, šty_, греш
  { {0x6360000e,0x681a001e,0x139b000b,0xc2ea0012}},	//   zönj, _rādā, _רביע, _أعظم_
  { {0x2d590061,0x8f75002d,0x7524001b,0x629c040f}},	//   cées_, руті, _kliz, mbro
  { {0x291e0039,0xc689000b,0xe45f006f,0xab5b0032}},	//   ītas_, לא_, mför_, stüt
  { {0xdb5a002d,0x98a90002,0x395f0051,0x628f000d}},	//   нюк_, wiać_, dlus_, _şcoa
  { {0xab5b030f,0x395f005e,0xfbd30009,0x600b0009}},	//   ltür, elus_, צתו_, _נִכְ
  { {0xfc3f0065,0xe45f006f,0x6ef4000e,0x68e0003a}},	//   _þín_, nför_, nübő, temd
  { {0x60f80014,0x6d5d0066,0x6123005e,0x75d30012}},	//   тния_, ůraz, _kõla, _ديفا
  { {0xd3f4002d,0x04461707,0x6d3b0009,0xdb160031}},	//   _мiст, _сеан, _נתמנ, ácók
  { {0x68e00028,0x2d590061,0x395f0010,0x47341543}},	//   semd, yées_, alus_, рнос
  { {0x0f57000b,0xcf57000b,0xbcfb000e,0xe29b000b}},	//   ריים_, רבית_, jléc, _נשאר
  { {0x2d590061,0xac1901d4,0x9e770009,0xb2370012}},	//   vées_, вому_, טגיה_, _حكما_
  { {0x351b000b,0xb7960001,0x7bc2002a,0xd12f0012}},	//   תוכנ, _срећ, nuou, _عمه_
  { {0xce940014,0x2d590061,0xa01b006f,0xadd80024}},	//   _такъ, tées_, _oför, _амку_
  { {0xa3ab0044,0xdd900012,0x2259003c,0x316b004c}},	//   _कौन_, _بوب_, тивы_, ешао_
  { {0x2d590061,0x6aaa03de,0x01340012,0x63600032}},	//   rées_, haff, معقد, hönh
  { {0x2d590108,0xcebb0001,0xdd01001e,0x2d5c01a0}},	// [57f0] sées_, еље_, ūtīs, níeu_
  { {0xe7330003,0x56670012,0x2d590025,0xab5b21bf}},	//   حصر_, هداف, pées_, atür
  { {0x78a6000e,0x36d4003c,0x58d506eb,0x6aaa016d}},	//   _fekv, сохр, _конт, daff
  { {0xa4d5002d,0x219a0009,0x8d740012,0x7c2b21c0}},	//   роді, _שברא, مانا, tzgr
  { {0xd7e6000a,0x7bc20132,0x8d4c00af,0xbcb800af}},	//   _بك_, guou, עֲבֵ, רפדו_
  { {0x645a007d,0x883a000b,0x77ba000b,0xeb920009}},	//   ştig, _יתרו, _במשח, חָה_
  { {0xaa490014,0x395f0051,0x22490014,0x780d0037}},	//   ъпка_, tlus_, ъпки_, ाङ्क_
  { {0x63bd0027,0xe9720003,0x2bb60011,0xe8f909e8}},	//   krsn, يهود, _अटला, тли_
  { {0xa2cd0011,0xe7310012,0x7bc20132,0xa1120012}},	//   _साप्, قصد_, cuou, تويت
  { {0xe80d0037,0xaa880012,0xef16003c,0x9b7b0012}},	//   _सपना_, _منكم_, имы_, _أحرز_
  { {0x5284000a,0xd5b8001e,0x96ca0011,0x8afa0009}},	//   _المك, dzās_, स्टॉ, _שהעי
  { {0x7ae321c1,0xc19a000b,0x69670012,0x06560009}},	//   lent, _ישעי, _صداق, ייתך_
  { {0x7b04000e,0x78a621c2,0x69c3008e,0xa09a0009}},	//   _átté, _rekv, lune, _סיסט
  { {0xe45f006f,0x6844002d,0x673a000e,0x0b680009}},	//   tför_, _уніа, citj, ָׁלָ_
  { {0xc332000b,0x2d590061,0x629c04a3,0xbb430198}},	//   קול_, réer_, rbro, церк
  { {0xe45f0163,0xdfd20003,0x629c21c3,0x63600031}},	//   rför_, ييز_, sbro, zönh

  { {0x7ae30d39,0x1bed0011,0xb8ee0011,0x3ea721c4}},	// [5800] kent, _चैपल_, _रा_, _kent_
  { {0x61230051,0xf7720003,0x7ae321c5,0x8f750024}},	//   _võla, زاء_, jent, бухі
  { {0x2d87002a,0x69c30051,0x3abb0009,0x7abb0009}},	//   _june_, june, _במינ, _בציו
  { {0xdbd20051,0x6d4606c4,0x6aaa21c6,0x3ea721c7}},	//   _tüüp, nnka, waff, _lent_
  { {0xeb060046,0x44320020,0x9cd7000b,0xb92a001a}},	//   ичко, ày_, שונה_, _thuế_
  { {0x8c1b000b,0x2120009b,0x68e421c8,0x159a0012}},	//   כוני, lkih_, leid, _لنسخ_
  { {0x1bed0044,0xdcc60037,0x69c321c9,0x44200949}},	//   _चैनल_, _वांछ, gune, ši_
  { {0xb4cb0037,0x4420001a,0xf993000b,0x68e421ca}},	//   र्फ़_, ơi_, חרה_, neid
  { {0x42ea0001,0x3ea721cb,0x09330012,0xb3450018}},	//   _имао_, _bent_, تروج, unçã
  { {0x11d6007c,0x539b000b,0xef11000b,0x89d6002d}},	//   _відр, _סיבו, ִּי_, _відш
  { {0xceb3000b,0x36f7000b,0x63ad0010,0x6ed80011}},	//   חית_, בצים_, šant, न्यु
  { {0x74150003,0x673a0054,0x68e4004a,0x659b0009}},	//   موجا, sitj, jeid, כיטק
  { {0xd7940003,0x3ea721cc,0x69de21cd,0x6f940012}},	//   _التخ, _fent_, _appe, _التض
  { {0xd2460003,0x3ea71f14,0x6ed80011,0x23e40024}},	//   كن_, _gent_, न्मु, ціюв
  { {0x2729001a,0x29880aa2,0x2d5c01e3,0xa6fb0009}},	//   _súng_, исто_, níes_, _שִׂי
  { {0x68e4007a,0x1d080001,0xa5080001,0x767b000b}},	//   geid, _већи_, _већа_, _בטוח
  { {0xc05b007c,0x7ae321ce,0x1154002d,0xbcfb0061}},	// [5810] тів_, yent, ікую, cléa
  { {0x30770093,0xff530003,0x2ca90b7b,0x34a70037}},	//   שתמש_, آخر_, _head_, _ख़ुद
  { {0xe2a70065,0xd6d80001,0xb87b21cf,0xddcb0066}},	//   íður_, јту_, _país, řižk
  { {0x67050044,0x4584002d,0x98ad0002,0x753d0123}},	//   राहक_, ігів, mieć_, nisz
  { {0x3eac000e,0x69180097,0x4ea7004c,0x6aa8105e}},	//   kadt_, _víet, _врба, _bedf
  { {0x7ae30164,0x8ccc0037,0x78ad004a,0x2ca90bad}},	//   uent, _हाथो, laav, _lead_
  { {0xd2b80093,0x753d000e,0x34951a44,0x8ab80009}},	//   בלות_, kisz, _габр, בלוג_
  { {0x3ea721d0,0x78ad079f,0x69c321d1,0x7ae321d2}},	//   _sent_, naav, rune, sent
  { {0x6d59003e,0x17f90003,0x7ae309fb,0x9b940024}},	//   mowa, اربة_, pent, _митц
  { {0x6d59003e,0x69c321d3,0xdb1d0028,0x27e9002c}},	//   lowa, pune, fusí, iwan_
  { {0x9985000a,0x78ad004a,0x3ea713eb,0x31850012}},	//   _الصو, kaav, _vent_, _الصِ
  { {0x6d59003e,0x753d000f,0x3ea70036,0x6d46000e}},	//   nowa, gisz, _went_, unka
  { {0x68e40333,0xdcf50039,0x6b890164,0x2d800051}},	//   veid, _atzī, _jueg, _viie_
  { {0x6e950003,0x60c921d4,0x5ea50012,0xe6950012}},	//   _الغا, lgem, _امثل, _الغد
  { {0x6d59003e,0x6b890164,0x68e4020b,0x212004d2}},	//   kowa, _lueg, teid, tkih_
  { {0x628f000d,0xbcfb1ff6,0x60c921d5,0xcdb60009}},	//   _şcol, llén, ngem, _הפקה_
  { {0x6d59003e,0x612a0028,0x21670ec6,0xa3c90011}},	// [5820] dowa, _nýle, сити_, लूम_
  { {0x2120013a,0x7adf0011,0x6ae10011,0x0a5a0012}},	//   skih_, _पॉपअ, फ़ोर, _مشجع_
  { {0x7bc61b70,0x99d60003,0x248d0107,0x69de21d6}},	//   luku, _اتخا, žeme_, _uppe
  { {0x6d59003e,0xab5b003a,0x3386003c,0xdcf90073}},	//   gowa, crüb, букв, _buvę
  { {0x6b8100a1,0x7bc6002c,0x4c560003,0xd7f20012}},	//   _bilg, nuku, حضار, _عكس_
  { {0x60c90051,0xb5aa0012,0x270c0011,0x398e0097}},	//   egem, _مارك_, ाउज़र_, _kýs_
  { {0x6d590002,0xdb1d0017,0xbea30014,0xe1ef0012}},	//   bowa, lusã, _хаск, فسي_
  { {0x3eaa00bd,0x7bc60101,0xf8ba0037,0x6d590002}},	//   _hebt_, kuku, ेलिय, cowa
  { {0x2ca9021b,0x3eac05da,0x43860012,0x251b0009}},	//   _read_, tadt_, _طلاق, _עומא
  { {0x7522000f,0x753d0002,0x8afc0002,0x63b30066}},	//   lkoz, wisz, _chęt, ření
  { {0x753d000f,0x2ca90051,0x2f5b000b,0x3eac000e}},	//   tisz, _pead_, רדינ, radt_
  { {0x6ed80037,0x867b000b,0x30860003,0x3eaa0052}},	//   न्तु, טריו, _الإف, _lebt_
  { {0x78ad004a,0x6d430061,0x48e30011,0x2ca9005e}},	//   vaav, énai, _फ़ोटो_, _vead_
  { {0x6d59003e,0xa5f80001,0xab5b0052,0x27240028}},	//   zowa, _веку_, drüc, _sönn_
  { {0xc3390066,0x5334010c,0x2ca9005e,0x753d0034}},	//   _říká, черт, _tead_, pisz
  { {0x61fa0028,0x90990867,0x63a40073,0xdb1d03f0}},	//   ætla, рват_, šiny, fusã
  { {0x78ad0006,0x636d0c75,0xbe870003,0x506721d7}},	// [5830] raav, núnc, مجاو, ства
  { {0x6d590002,0x7d040002,0x75220227,0x6d4a21d8}},	//   wowa, _znis, ekoz, éfan
  { {0x6d59003e,0xe7ea0037,0xf41f004a,0x61230051}},	//   towa, _जैसा_, lyä_, _hõlm
  { {0x2ee50070,0x71880009,0x34ab0012,0xab5b21d9}},	//   zelf_, _לְשַ, اداً_, brüc
  { {0x6d590656,0xdfc60012,0x14d80009,0x6b8900b8}},	//   rowa, _تي_, מואל_, _queg
  { {0x6d59003e,0x39490071,0x6ed80011,0xa3aa0011}},	//   sowa, lnas_, न्दु, _खबर_
  { {0x6d590002,0x51840001,0x7548000e,0x41750012}},	//   powa, пуња, ószá, يابس
  { {0xf41f0006,0xa4d4002d,0x7ae70066,0x7bc600b6}},	//   kyä_, _носі, hejt, yuku
  { {0x7ae705b1,0x6b8121da,0xd4070024,0x69c701e9}},	//   kejt, _tilg, _уяви, huje
  { {0x60c90480,0x3c440012,0x907c0009,0x63720040}},	//   sgem, _عَلِ, נטזי, mæng
  { {0x7ae70013,0x61230005,0x92b40003,0x3195001e}},	//   dejt, _põll, _رحلا, _bāze_
  { {0x63a4007d,0x2ee50036,0x67210027,0x27e0000d}},	//   ţine, self_, sklj, _ţine_
  { {0xe457002d,0xdbf40037,0x442421db,0xc1780012}},	//   жжя_, इटेड_, ám_, _اصلا_
  { {0xa3ab0037,0x59dd0037,0x41dd0037,0xf1dd0037}},	//   कीय_, _महार, _महास, _महान
  { {0x63720058,0xe93a0001,0x42290009,0x63600031}},	//   hæng, ачај_, בֵּ֣, dönt
  { {0x2fc00040,0x986a0012,0x7bc61e34,0x8d760012}},	//   trig_, لحذف_, puku, _باتا
  { {0x78ab000f,0xab5b0052,0x2d8a01e3,0x3f8b016d}},	// [5840] _megv, urüc, _sube_, _cucu_
  { {0xdfcf000a,0xe6b70037,0x42560012,0x2a6d0030}},	//   ئيل_, _आयोज, _ونظر, řeba_
  { {0x7522000f,0xee3a0001,0x216a0472,0x7ccd0031}},	//   tkoz, јне_, _вини_, zőrő
  { {0xdca30046,0xed5a0015,0xd576002d,0xab5b0052}},	//   даци, шое_, цузь, prüc
  { {0x0b930003,0x63640054,0x63720058,0xfbcf0012}},	//   وجود, lòni, gæng, نتو_
  { {0x752900c1,0x2d8a0503,0x9f4001e3,0xd36f0012}},	//   _elez, _tube_, rvió_, نهن_
  { {0x63640054,0x91ba0009,0xcb130009,0xe6060012}},	//   nòni, ׁמַי, ולג_, _بِأَ
  { {0x31570003,0x67360002,0x68f60002,0x2572000e}},	//   يجية_, żają, ndyd, náld_
  { {0xc173000b,0xd0070001,0x2bd10037,0x42d60024}},	//   וחה_, жење_, _समया, _міжу
  { {0xa3df0037,0x4b260003,0xb7db000b,0xf41f008e}},	//   _तहत_, _بعرف, סקיי, vyä_
  { {0x61230005,0x7ae7095d,0x4b7b000b,0xc6930009}},	//   _sõlm, vejt, _כאמו, ואת_
  { {0xe4e7007c,0xf41f004a,0x55bb0009,0x2bb10011}},	//   ціон, tyä_, סמכו, ुंचा
  { {0x7d7b000b,0x7ae70066,0xe5710009,0xdfcf0012}},	//   ינטו, tejt, גַם_, _لين_
  { {0x7c2f00a2,0x4f570003,0x63640054,0x2d8402ed}},	//   _ücre, _وجود_, fòni, _lime_
  { {0xd13b0098,0x3a250028,0x69d50052,0x217b0003}},	//   аха_, álp_, utze, لحرب_
  { {0x91bb0093,0x2d9e21dc,0x2d840005,0x613e0010}},	//   ימלי, mpte_, _nime_, iūlo
  { {0x4d740003,0x368b022a,0x69d50347,0xab5b005e}},	// [5850] _تطور, асен_, stze, nuük
  { {0x8f9b000b,0x07050037,0x2d840061,0xdef10012}},	//   יימי, राइव_, _aime_, عًا_
  { {0xa2c401e1,0x8c3d1c95,0x3949006f,0x0cd60037}},	//   _राज्, _ieşi, pnas_, ठभूम
  { {0x62950002,0xe5700003,0xd9190009,0xadbc0024}},	//   lczo, نطن_, _הוֹל, рацi
  { {0x53a50014,0xe53c0009,0x63600097,0x8c3d0060}},	//   чалб, סתדר, pönt, _keşi
  { {0x6f180027,0x7dc70012,0x51f50012,0xc4840024}},	//   _novc, _وتأك, كسبر, флік
  { {0x27290065,0xf628002d,0x8a020014,0x7bda004b}},	//   _núna_, _діти_, езще, ătui
  { {0x637200c5,0x60cd1da5,0x3cf50011,0xf53f0248}},	//   mæne, ngam, इयों_, _öå_
  { {0xccf2000b,0x257201e9,0x6006003c,0x6b8d0025}},	//   _אכן_, nále_, зным_, _nuag
  { {0x91f70003,0x636d0028,0xb4e60011,0x6d4b0035}},	//   _وأضا, búna, बड़ी_, lnga
  { {0x3f990039,0xf8bf0149,0xfbc9000b,0x6360000e}},	//   ūsu_, _além_, _תת_, zöns
  { {0xc6160009,0x691c0025,0x62950034,0x6d5d21dd}},	//   לחתי_, _dées, eczo, gosa
  { {0x68e90051,0xdb06004a,0xd0040012,0x3940005e}},	//   meed, yskä, _يومً, viis_
  { {0x39910065,0x3b0a0047,0x6996002d,0x25720066}},	//   _kás_, щего_, зрах, dále_
  { {0xd0040044,0x6d5d120d,0xc6920009,0x3940020d}},	//   रम्भ_, bosa, _טאג_, tiis_
  { {0x55ba0093,0x636403eb,0x60cd0101,0x399121de}},	//   _המקו, ròni, ggam, _más_
  { {0x8ca20044,0xab5b0051,0x291900b6,0xdb06006f}},	// [5860] _क्यो, kuüh, _dosa_, tskä
  { {0x6d4b00c6,0xcc57000b,0xdb1d000e,0xc3fb0009}},	//   enga, _מספק_, pusá, _פליש
  { {0xceb2000b,0x39910107,0xc7a90009,0x3da50024}},	//   גיב_, _nás_, רב_, дріб
  { {0x7bc221df,0x6e3c0018,0x63600097,0x63720040}},	//   trou, úrbi, pöns, sænd
  { {0x8c3d003a,0x2cad051c,0x07fa0012,0xe3b70024}},	//   _yeşi, _deed_, _ارجع_, зліч_
  { {0xf1a60838,0x79a6022a,0x7bc203b5,0x6d4b21e0}},	//   прин, прие, rrou, anga
  { {0xa2cd0037,0x63a90002,0x2d8421e1,0xbb470012}},	//   _सार्, _ewen, _time_, ثلون_
  { {0x691c0061,0x7bc20061,0x62950002,0x07980001}},	//   _rées, prou, zczo, овић_
  { {0xba3c0010,0x50b70012,0xcf260012,0xb8d40011}},	//   _neįv, سديد_, كردي, _जज_
  { {0x539b000b,0x1037000b,0x6d42000d,0x8b8b0009}},	//   _לימו, פטים_, lioa, _הָאֶ
  { {0xba9b000b,0x39910017,0x6d5d21e2,0xd29b0009}},	//   _הסבי, _gás_, tosa, _השבט
  { {0x68e9002a,0xab5b0052,0xbcfb18ac,0xdd860012}},	//   ceed, grün, mlék, ضو_
  { {0xbcfb000e,0x645a1c95,0xd1090011,0x6ecc0011}},	//   llék, ştin, वारण_, ालाँ
  { {0x61230051,0xdce2009b,0x6d5d0269,0xa87b0009}},	//   _tõlk, dloč, sosa, _האדר
  { {0x6edb0093,0xe9ff0020,0x41e4002d,0xd6db000b}},	//   _החופ, _phẩm_, ніта, _החול
  { {0x60cd0010,0xe164004c,0x257200d9,0x613109f4}},	//   ugam, еђун, tále_, _målg
  { {0x94bc0009,0xcb690012,0xf6e70048,0x37090012}},	// [5870] _המחת, _ومعه_, зцен, يْرُ_
  { {0x8f9b000b,0x2cad0132,0x6bd40012,0x257208ca}},	//   ציבי, _seed_, _أتير, rále_
  { {0xe9ff001a,0xadab0012,0x97570009,0xcb120009}},	//   _thẩm_, صداق_, לימו_, _סלט_
  { {0x3eae0036,0x69c3009b,0x39910028,0x27f2004a}},	//   _left_, vrne, _rás_, ännä_
  { {0x68e90164,0x69d8001e,0x78fa0009,0xd7e40024}},	//   veed, etve, _ופרו, _піро
  { {0x09e50001,0xadec0011,0xc6860012,0xc2c40012}},	//   докн, जबान_, _لِ_, فيهي
  { {0x68e90005,0x2cad0051,0xdb0b0028,0xeab00003}},	//   teed, _teed_, gsgá, اعه_
  { {0x39910382,0x212b0002,0x6d42000d,0x63a90087}},	//   _vás_, óch_, cioa, _twen
  { {0x27ed0070,0x68e921e3,0xa2ce0011,0x60090024}},	//   uwen_, reed, _ताल्, іном_
  { {0x7d1b0036,0x29d7003a,0xa294002d,0x23740012}},	//   _hous, kça_, _зафі, _كالح
  { {0xc3320093,0x8e960009,0x4ad20011,0x24ea06bd}},	//   _שוב_, ודתו_, _सातव, омни_
  { {0xc329000b,0xd46a0015,0x3f9f008e,0x3eae0227}},	//   _דו_, жиме_, ppuu_, _eeft_
  { {0xa936000b,0x395f0bad,0x394d21e4,0xdb1d21e5}},	//   _קטנה_, mous_, mnes_, arsí
  { {0x09e60103,0x442221e6,0x257e0030,0x394d21e7}},	//   могн, ryk_, _vůli_, lnes_
  { {0x394d02d1,0x44220010,0x7bcb0028,0xfe9a0009}},	//   ones_, syk_, hugu, _ויצמ
  { {0x95560003,0x7d1b004a,0x395f0a39,0x752d21e8}},	//   _تختا, _nous, nous_, _glaz
  { {0xdb0b000f,0x29d70017,0x18671104,0xa446002d}},	// [5880] zsgá, aça_, дати_, _інод
  { {0xe7e50044,0xe9ff0020,0x8c430052,0x98a30010}},	//   _कहना_, _nhắm_, ößer, ėję_
  { {0x3f870005,0x3f8f0051,0xbf9b0025,0x917a0081}},	//   _minu_, _lugu_, _prêc, _lấy_
  { {0x6da30001,0xf5250024,0xf8b20011,0x395f21e9}},	//   тица, нфін, _ज़िय, jous_
  { {0x6d42007d,0xf8b3000b,0x394d21ea,0x7d090030}},	//   rioa, _בשר_, dnes_, _dnes
  { {0x69d80119,0x6d430061,0x394d1aa3,0xc2c40012}},	//   ttve, énar, enes_, ريعي
  { {0x91e30001,0xba3c0010,0x7bcb09d4,0x7aea2057}},	//   воје, _neįt, augu, reft
  { {0x2ef8003a,0x66030058,0xab5b000e,0x69ca031d}},	//   _harf_, ænke, erül, rufe
  { {0x6d400dc3,0x9b930012,0x1867004c,0xc5150012}},	//   _imma, _للقت, маћи_, _ثبّت
  { {0x7d09012e,0x00770009,0x692c0060,0x752d08fd}},	//   _znes, ותפי_, rşey, _slaz
  { {0x645a000d,0x63a2000e,0x752d21eb,0x6f1c21ec}},	//   ştil, lpon, _plaz, _morc
  { {0xa00a000a,0x3f870065,0x7ada0011,0xc2370009}},	//   _وقال_, _einu_, प्रॅ, _קראו_
  { {0x27320020,0x7b6704b3,0x248d0416,0xfc640014}},	//   _nâng_, дтве, žemo_, върн
  { {0x27e6002c,0x39440010,0x8c3d003a,0x78af004b}},	//   _ipon_, lims_, _teşv, _secv
  { {0x1dc50011,0x59f80048,0xdb1d0018,0xb3450018}},	//   _वियत, меря_, ersã, liçã
  { {0x752d0027,0xc1f7000b,0x63760284,0xcfab0012}},	//   _ulaz, ומלץ_, lând, قائم_
  { {0xb8f70037,0xb3450017,0xa2950024,0xdfd10012}},	// [5890] _सा_, niçã, _папі, طيا_
  { {0xce6b029b,0x25720028,0x394d21ed,0x6d4021ee}},	//   оред_, mála_, znes_, _amma
  { {0x2ef80052,0x7d1b0c4d,0x25720031,0xd5b80035}},	//   _darf_, _pous, lála_, nsā_
  { {0x6d5a0028,0xd5b80035,0x05740012,0x27e60034}},	//   _ítal, isā_, ناند, _opon_
  { {0x7d09012e,0x1c0f0037,0xdfc60003,0x68ed0017}},	//   _vnes, ामिल_, _حي_, mead
  { {0xd5b80039,0xb3450017,0x6ec70003,0x6d4021ef}},	//   ksā_, diçã, _تتحق, _emma
  { {0x394d0039,0xe0d10003,0x7bcb044f,0xc3340009}},	//   tnes_, هزة_, sugu, כוס_
  { {0x3f870005,0x7d09001c,0x21290f49,0xdb0f0034}},	//   _sinu_, _unes, nkah_, orcó
  { {0x8b67000a,0x395f002a,0xd7e60015,0x394d21f0}},	//   _قائم, rous_, емые_, rnes_
  { {0x27e4006f,0x6d4f00b6,0x809f0037,0x24980066}},	//   _ämne_, enca, _ग्रे, čemž_
  { {0x21290f50,0x63ad11f7,0x8e740024,0x68ed00b0}},	//   kkah_, _awan, куюч, kead
  { {0xb3450017,0x01fa0009,0x8d760012,0x2d650012}},	//   biçã, _מפעל, عادا, َطَّ
  { {0x78270003,0xa1160003,0x69c100f1,0x6376000d}},	//   _تعال, _سقوط_, álen, bând
  { {0x2732007d,0x637607ba,0x68fb0051,0x501a0009}},	//   _când_, râng, ldud, _מונו
  { {0x63a2000f,0xc7b9000f,0xc0e60800,0x69c10066}},	//   zpon, lső_, новк, šlen
  { {0xaadf0037,0x6376000d,0x4f96002d,0x68fb21f1}},	//   प्तक, mâne, ержу, ndud
  { {0x6f1c106b,0xaf060024,0x291d0034,0xd6d90009}},	// [58a0] _porc, нпал, _mowa_, ּחֲל
  { {0x62920026,0x27ff004a,0x6f660012,0x273221f2}},	//   ékoľ, ivun_, رهام, _vâng_
  { {0xf1bf0029,0xecea02ad,0xaac90011,0x2cfa0009}},	//   ýšte_, здел_, _राजक, ּלְא
  { {0x291d0002,0x0b8a0001,0xe9ff001a,0x938a0001}},	//   _nowa_, пски_, _chậm_, пска_
  { {0xe2f8002d,0x61230051,0x4af80015,0x69ce0028}},	//   делі_, _põlv, делю_, lube
  { {0x6d460532,0xdb1d0248,0x61350097,0x69dc21f3}},	//   hika, stsö, _jálf, otre
  { {0x61350028,0x394421f4,0x3f991a98,0x66e30024}},	//   _málf, tims_, ísun_, _щора
  { {0x31ba001e,0x4ddb000b,0x6d4600b6,0xdbd6004a}},	//   rīz_, _מחלו, jika, _pääa
  { {0xc7b9000e,0x6d4621f5,0x6376000d,0x20020097}},	//   gső_, dika, tând, íki_
  { {0xb3450149,0xccf90002,0x083b000b,0x6d460071}},	//   riçã, _zaś_, פעיל, eika
  { {0xb3450149,0xa0a60014,0x18a60014,0x2732000d}},	//   siçã, _заед, _заем, _rând_
  { {0x3f8a002c,0x7afa21f6,0xe2aa0030,0x6376004b}},	//   _libu_, _hatt, íční_, sând
  { {0x7afa0272,0x442601e5,0x27e60036,0x48fb0037}},	//   _katt, nyo_, _upon_, _लोगो_
  { {0x93880015,0x69dc0052,0x69c7009b,0x2ca4003a}},	//   есса_, ftre, trje, ımda_
  { {0x31c40098,0x0697000b,0x99850066,0xdb040164}},	//   лств, _אדום_, álů_, _avió
  { {0x7bda007d,0x7afa21f7,0x35b30048,0x80cb0011}},	//   ătur, _latt, _сбър, िलें
  { {0x3cf80003,0xe4a8000b,0xa954002d,0x28b20037}},	// [58b0] _سعيد_, _אֹתָ, укті, _ज़रि
  { {0xbcfb000e,0x238a0029,0x68ed21f8,0x212908e2}},	//   glév, ľujú_, sead, skah_
  { {0x238a0029,0xceb30009,0x7ae1005e,0x7bcf0060}},	//   žujú_, ריע_, õltu, lucu
  { {0x7bdd0051,0x865b0009,0x7afa008e,0x5a160009}},	//   otsu, הדבי, _aatt, _סקרן_
  { {0x7bcf00a2,0x7bdd0051,0x2556001e,0x3d190037}},	//   nucu, ntsu, nāla_, _बचने_
  { {0xbbd10044,0x2903001e,0x02c2002d,0x7afa0718}},	//   _समीक, ējam_, айшо, _catt
  { {0x0dc80015,0x7bdd0051,0x95c80001,0x4426002c}},	//   _пути_, htsu, _пута_, ayo_
  { {0x09f60012,0xa2cd0011,0xa156004c,0x25560035}},	//   ئفية_, _साक्, кају_, kāla_
  { {0x7afa01a2,0x43950014,0x290b003a,0xe534003c}},	//   _fatt, _разс, ıca_, _сеть
  { {0x84640014,0x7afa21f9,0xe4500012,0xbc680012}},	//   _съсе, _gatt, _اضف_, _أمكن_
  { {0x61350028,0xc6920009,0x65c50048,0xdca6085d}},	//   _nálg, יאי_, ъбна, кани
  { {0xda480009,0x63760018,0xc7b90031,0x02440012}},	//   _אֲנָ, râne, pső_, _حَمَ
  { {0x317f097e,0x69c10030,0x7bcf001b,0x4cba0009}},	//   mmuz_, šlel, gucu, וזרו
  { {0x03a30800,0x8ca20037,0x316d0763,0x2fc91a35}},	//   риро, _क्रो, llez_, drag_
  { {0x3f8a00c6,0x69dc0061,0x21fc015b,0xe1660012}},	//   _ribu_, utre, máhá_, ندري
  { {0x78a90070,0x5e560009,0x9dd60009,0x69dc21fa}},	//   nbev, _ביצע_, _סופק_, rtre
  { {0x54a50003,0x21670ec6,0x2cee0011,0xf8b20009}},	// [58c0] _صحيف, тити_, ज़ील_, ישן_
  { {0x9bb7000b,0x3ce30037,0x61230051,0x7d0d0002}},	//   _שהיה_, ट्ठे_, _sõlt, _znas
  { {0x42560001,0xba3c0073,0x160a0012,0x6123005e}},	//   _штит, _neįp, بياً_, _põlt
  { {0xf5030048,0x2a570009,0x442621fb,0x7afa21fc}},	//   изхо, _יבין_, tyo_, _satt
  { {0xe44d000b,0x63f30003,0x7afa21fd,0xd4970009}},	//   ּתוֹ, لأور, _patt, דכנת_
  { {0x44260a60,0x18370009,0x7dc60012,0x70b20011}},	//   ryo_, _יאכל_, _لترك, _ज़ुल
  { {0x44260101,0x7afa10f0,0x3cfd0011,0x99d30012}},	//   syo_, _vatt, _रोके_, لتيا
  { {0x50f40047,0xacea0003,0x69a70037,0xbcfb000e}},	//   узит, _ترسل_, टीटी, nlét
  { {0xe8050044,0x2bc90037,0xb8050011,0x30130048}},	//   रिया_, _रिया, रियम_, идър
  { {0xa2d70011,0xbcfb0025,0x17f70012,0xaf060a32}},	//   _बाध्, hlét, ئرية_, тчик
  { {0x29d30012,0x316d0025,0xb9c50012,0x99d30012}},	//   _نيلس, blez_, _متنه, _نقلت
  { {0xc4bf0037,0x2556001e,0xdccf001a,0x7bcf0060}},	//   ्लेख, tāla_, hỉnh_, tucu
  { {0x254f0034,0xe9ff0081,0x6f0d0030,0x443f0081}},	//   nęli_, _thảm_, áncí, àu_
  { {0x6d44000e,0x69c101bd,0x7bcf0712,0xcfb70009}},	//   _emia, šlem, rucu, _ילדי_
  { {0xa9230029,0x7bdd0a9d,0x442d21fe,0x8f750024}},	//   áľov, stsu, še_, _суці
  { {0x39980663,0x2579000e,0x2fc921ff,0xd9100012}},	//   _més_, féle_, trag_, يٌّ_
  { {0xa0750001,0xdb0605b1,0xed580009,0xbf9b0025}},	// [58d0] угач, lský, _שבחר_, _grêl
  { {0x6d44003e,0xa2f5002d,0xb7db0009,0xd3a40048}},	//   _zmia, _споч, וקמי, _тръп
  { {0xdb060042,0x656f0032,0xde780009,0x63bd0097}},	//   nský, olch, תְּך, lssn
  { {0xf653000b,0xccef004c,0x000000c4,0x000000c4}},	//   בצע_, ећa_,   ,
  { {0x69ca0065,0xc05b002d,0x63bd006f,0xd1030011}},	//   erfe, _цін_, nssn, _शोषण_
  { {0x63760017,0xab640024,0x39492200,0x613508d0}},	//   vânc, авіл, lias_, _mále
  { {0xbbe00037,0x216900be,0x68fd0010,0xa9690a76}},	//   _पङ्क, ники_, _kasd, ника_
  { {0x645a000d,0x63760017,0x6c850012,0xdb0600d9}},	//   ştii, tânc, _ملزم, dský
  { {0x54550373,0x613500d9,0x316d0025,0x68fd016d}},	//   _сват, _nále, rlez_, _masd
  { {0x656f03c0,0xdb060097,0x63762201,0x7c24005e}},	//   elch, fský, rânc, äire
  { {0x39490010,0x09e40024,0x98c30011,0x27290064}},	//   kias_, _воєн, षणाए, _júni_
  { {0x2cb9000e,0x3cee0011,0x02df0011,0xaadf0011}},	//   gasd_, ज़ें_, प्रभ, प्रक
  { {0x290f0163,0xeb970104,0x4424001a,0xe3b10012}},	//   _inga_, лия_, âm_, ْرِ_
  { {0x99f60024,0xa3e50011,0x30780012,0x2d910018}},	//   лябі, _नहर_, _شحنة_, ízes_
  { {0xbcfb15bc,0x394913b3,0x2f5a0009,0xc3480081}},	//   glés, fias_, _אדסנ, uổi_
  { {0x25560039,0xd24f0012,0x6d440034,0x4159003c}},	//   mālo_, أنف_, _umia, вшую_
  { {0x7d7b0009,0xc8b5003c,0x07a601c6,0xf53700af}},	// [58e0] _אנקו, рссы, уазн, _תרפז_
  { {0x32460003,0xbcfb000e,0x4c3b0009,0x63a42202}},	//   _منخف, slét, _נתיב, _itin
  { {0xf8bf0108,0x2556001e,0xdb23000e,0x613501bd}},	//   _clés_, nālo_, _órán, _zále
  { {0x61fa0065,0x721b000b,0x39490583,0x6131006f}},	//   ætlu, _נוכח, cias_, _tåla
  { {0x77f20037,0x9cd7000b,0xa37b0017,0x7afe2203}},	//   _अनेक_, רונה_, stõe, _kapt
  { {0x7bc4007a,0xf74601ec,0x61230051,0x39980017}},	//   šiuo, _сего, _hõlp, _pés_
  { {0xf2d30093,0xe9ff0020,0x41e60003,0x27e02204}},	//   צעה_, _phạm_, استف, ltin_
  { {0xa9670001,0x39980054,0xd0100003,0x3cee0037}},	//   лија_, _vés_, قلب_, ज़ों_
  { {0x2ef40c61,0xb4c20011,0x27360040,0xbcfb0031}},	//   азпр, ूली_, _tænd_, zlés
  { {0x138a000a,0x2474001a,0x7afe000e,0x58370015}},	//   _أخرى_, _ìm_, _napt, узья_
  { {0x22930351,0xaa93000a,0xca560046,0x32930003}},	//   _المس, _المث, _стањ, _المأ
  { {0x0e33002d,0x9f490028,0xa2d70011,0x8c190012}},	//   снюю, hvað_, _बाह्, نيجر_
  { {0xbf9b0017,0xccf3000b,0xdb060097,0x6e3a0031}},	//   _prêm, זכר_, sský, sztb
  { {0x61350066,0xdb060066,0x37090011,0x6b960060}},	//   _vále, pský, साज़ी_, _duyg
  { {0x2d9c0149,0x13d10044,0xbd6b0014,0x27e0003a}},	//   ível_, _सम्भ, _прие_, etin_
  { {0xbcfb000f,0x7bcb0097,0xc1770012,0x290001a0}},	//   rlés, yrgu, ادست, gdia_
  { {0x7afe007d,0x3ecb0001,0x67d5002d,0x39492205}},	// [58f0] _fapt, ећем_, розу, rias_
  { {0x2903001e,0x39492206,0xe7840024,0xd7c80012}},	//   ējai_, sias_, бухо, اوله_
  { {0x2474001a,0x3949052e,0x5eeb0009,0xcb120009}},	//   _àm_, pias_, עַמְ, _ולי_
  { {0x23b50012,0x621a0009,0x67d50959,0x1ad20011}},	//   لمؤس, _סורק, _кому, _साउथ
  { {0x7afe00a2,0x8d740003,0x00ba007e,0x84470012}},	//   _yapt, حالا, _שמשמ, دخال
  { {0xa3d60037,0xc9f50012,0xeb960488,0x2d440031}},	//   ांत_, لسبع, шиш_, tűek_
  { {0x3ce90066,0x81f60012,0xe9a80012,0x2bd10011}},	//   _obav_, لفور_, هدين_, _समका
  { {0x6bd70012,0x2d440031,0xa92514cf,0x61312207}},	//   _متطر, rűek_, рдил, _målo
  { {0x64c80010,0xead5003c,0x6d4b2208,0xa156004c}},	//   nčių, _возь, miga, јању_
  { {0x6360000e,0xe9ff001a,0x57450511,0x7fe80012}},	//   sönz, _nhầm_, рноб, اريف_
  { {0xd251000a,0xbb840003,0x9178001a,0x50f50014}},	//   _بنا_, _اللي, _lớn_, _взет
  { {0xd011000a,0x6ff50003,0xe9d00003,0x6d4b1b2c}},	//   _ولا_, _نستط, _رغم_, niga
  { {0xf9880012,0xe72e0d7c,0x99710034,0xd48f0024}},	//   _إنني_, _де_, _wąś_, орi_
  { {0x46a50001,0x6566000e,0x883a0009,0xa3e80037}},	//   _такв, sokh, _בתנו, _बहस_
  { {0xc3320093,0x63a40039,0x51860003,0x3195001e}},	//   חום_, ģini, لشرق, _bāzi_
  { {0x10a6005c,0x6d4b04d2,0x057a0012,0xdb060097}},	//   риан, jiga, _جمعة_, tskó
  { {0x6d4b0163,0xdfa50003,0x7afe2209,0x60d61989}},	// [5900] diga, محلي, _tapt, rgym
  { {0x61310163,0x4a460015,0xbcfb000e,0x3bbb000b}},	//   _håll, _внов, llép, _שמיד
  { {0xdb060028,0xc5d6002d,0x75d60003,0x27e0220a}},	//   sskó, різь, شيشا, stin_
  { {0x84e6002d,0xd656000b,0x19bb0009,0x4d4a0048}},	//   родж, ביעת_, _במטב, ъпен_
  { {0x61380013,0x2d520027,0x2ca90164,0xbcfb0031}},	//   _cíle, ašeg_, ñada_, ilép
  { {0x6abc0028,0xf7670003,0x69ce07b7,0xfbd30009}},	//   narf, _ذا_, orbe, קתו_
  { {0x6d4b01e5,0xe2970001,0xd24f0003,0xab270001}},	//   biga, шај_, ونه_, роја_
  { {0xbcfb0066,0x99830012,0x6abc203d,0xc5fb0009}},	//   jlép, يلوو, harf, _בפלט
  { {0xd0e20037,0x67230061,0x69c1003a,0x14a70011}},	//   क्षण_, _bonj, _evle, _क्षण
  { {0x25750163,0xf1bf0026,0x80a60037,0xbcfb000e}},	//   håll_, žšie_, _ट्रे, elép
  { {0x3eb8000f,0x0697000b,0x8b3b000b,0x6723220b}},	//   _mert_, ידים_, _שתבצ, _donj
  { {0x6a80000e,0x61350066,0x35470b05,0x2d9806b2}},	//   záfé, _válc, рхов, _mure_
  { {0xb7960001,0xc558002d,0x493b0009,0x4f9617de}},	//   _трећ, рияє_, _בגאו, _треу
  { {0x61310119,0xe2a30020,0x7d02004a,0x70530012}},	//   _pålo, _ngữ_, hdos, _بنها
  { {0x35f70003,0xb77b0009,0xda090011,0x637b004b}},	//   _نريد_, _שאוש, वियत_, eînc
  { {0xe8940021,0x44b5004c,0x2d52001b,0x68480035}},	//   жать, _убис, všeg_, pīdī
  { {0x58870015,0xcebb0001,0x286b0001,0xdb040018}},	// [5910] рыва, вље_, трво_, _aviõ
  { {0x6d4b220c,0x7d02220d,0xbf380024,0x3eb8220e}},	//   wiga, edos, азує_, _cert_
  { {0x04950003,0x2bc90011,0x645a004b,0x2d980614}},	//   ملاح, _रिहा, ştit, _cure_
  { {0x95090012,0x84c80012,0x7af50031,0x2d98220f}},	//   طقتك_, لِمك_, lezt, _dure_
  { {0x6d4b2210,0xf0920009,0xd1140011,0x93e90012}},	//   riga, _מנכ_, डारण_, افتك_
  { {0x3eb80065,0xf3670001,0xebf80009,0x257c08ca}},	//   _gert_, штен, שֶׁת_, víle_
  { {0x27f50060,0x9e150024,0xe37c00af,0x2bc905f3}},	//   şanı_, _удві, דרגר, _रिवा
  { {0x853d0010,0x7d06000e,0x2fcd0690,0xe9a80012}},	//   spėj, térő, treg_, جدون_
  { {0xdee50014,0x7af5000e,0xc4d2000b,0xb8ff0037}},	//   бопи, kezt, _מגן_, _ता_
  { {0xa3d60037,0xfc3f0029,0x7af5000e,0x25721b3c}},	//   ांस_, dzí_, jezt, máli_
  { {0x7524012e,0x3ea1008b,0x7d06000e,0x7af50031}},	//   _poiz, icht_, sérő, dezt
  { {0xc329015a,0xb895000a,0x4095000a,0xe9ff001a}},	//   _או_, _الإع, _الإر, _chấm_
  { {0x6abc0065,0x30850003,0x394d2211,0xdbf40011}},	//   tarf, _الشف, mies_, ेटेड_
  { {0x7af5000e,0x673a04a3,0xab5b0032,0x69d5004b}},	//   gezt, chtj, drüs, fuze
  { {0x4999002d,0x2bd10011,0x471a0009,0x6d410073}},	//   иття_, _समझा, _תוצג, _įlan
  { {0x3a25006f,0x3f4f001e,0x3eb82212,0x97430034}},	//   älpa_, kļus_, _sert_, śćdz
  { {0xf3f1008a,0x4e96000a,0x2d98002a,0xb4b40037}},	// [5920] ặc_, مشار, _sure_, टरी_
  { {0x7d002213,0x6d490017,0xf7720003,0x99870066}},	//   _sams, _amea, ساء_, kynů_
  { {0x6e930003,0xddb60003,0x1d0a00f5,0xd5760021}},	//   ألما, صحاب, лежи_, будь
  { {0x93aa000a,0x3eb8008b,0xecba0003,0x661c0051}},	//   هاتف_, _wert_, اطات_, ärki
  { {0xac180001,0x4432001a,0xa2940024,0x200b001b}},	//   ролу_, áy_, оалі, _grci_
  { {0xf6d5007c,0x8fa30014,0xcb670048,0x212002a1}},	//   _міся, _харе, баче_, ljih_
  { {0xc3330009,0xdb1d0025,0x394d2214,0x8f370009}},	//   הוג_, ussé, fies_, _פאלו_
  { {0xf9930093,0xc4c50003,0x212002a1,0xc034004c}},	//   הרה_, _وتقو, njih_, жниј
  { {0x29020a26,0x8d4b000b,0x98a30001,0x69d51418}},	//   _maka_, _עֲלֵ, чиње, zuze
  { {0x61350272,0x19ba007c,0x539b000b,0x11d6002d}},	//   _vála, _будь_, _עיבו, _гідр
  { {0xb9960003,0x7af50bb3,0xceb30009,0x9cf50024}},	//   _الصب, vezt, הית_, озні
  { {0xd7fe008a,0x29020101,0x63a4000d,0x5e77000b}},	//   _đăng_, _naka_, ţinu, מתין_
  { {0xbc4b0046,0x71650003,0x7d7b000b,0x2d92003a}},	//   учне_, _بالك, טרטג, _diye_
  { {0xfc3f0013,0xf9930003,0xdce9003a,0xfaa90012}},	//   rzí_, كبر_, ılıy, شهري_
  { {0x29022215,0x3f992216,0xa6c70003,0x315b0003}},	//   _baka_, _susu_, _طويل_, هجرة_
  { {0xa3d60037,0x0975002d,0x290405cd,0xfd130012}},	//   ांश_, ігаю, ndma_, _رجع_
  { {0x645a00a1,0x29070013,0x8c440001,0x60180048}},	// [5930] ştir, ěna_, _неће, ботя_
  { {0xec380093,0x6aba0065,0x8f9b000b,0x0c740003}},	//   _לאחר_, _netf, טימי, _عديد
  { {0x2ca90164,0x3ebe000e,0xab5b0032,0x8895004c}},	//   ñado_, iatt_, srüs, _минх
  { {0x3ea10052,0xfce5002d,0x85c80012,0x5c75046e}},	//   scht_, іоло, إِنْ_, олет
  { {0xed58002d,0x83c40024,0xeab908d1,0xb607068c}},	//   щої_, збіж, айл_, _koší
  { {0x85bb0003,0xdcb60037,0xc9a90838,0x394d0032}},	//   _مارس_, _अज्ञ, авке_, wies_
  { {0x394d2217,0x32160012,0x7aea0032,0x61350030}},	//   ties_, قيود_, _öfte, _dáln
  { {0x6d4f2218,0xa99c0009,0x321e008e,0x5d5404d5}},	//   jica, נבחר, ätyi_, _екст
  { {0x3cef0037,0x394d2219,0x200b01bd,0xe8df0081}},	//   ेजने_, ries_, íci_, hiện_
  { {0x2556001e,0x68f6003a,0x6d5a0028,0x394d221a}},	//   māli_, zeyd, _ítar, sies_
  { {0x442f0010,0x52550012,0x637f0018,0xf4090009}},	//   lyg_, _بناء, gêne, _שפ_
  { {0x29030039,0x6d4f221b,0x6b9b005e,0xdb060248}},	//   ējas_, gica, _kuug, nskö
  { {0x69c50033,0xde55001e,0x2556001e,0xaae00011}},	//   _avhe, _šādā_, nāli_, _नामक
  { {0x3b0a0047,0x539a000b,0x68e90222,0xf6290012}},	//   шего_, יישו, lfed, _نسعى_
  { {0xcb120093,0x68f60006,0x2120009b,0xbd460012}},	//   ולם_, teyd, tjih_, _ونتي
  { {0xe8fa0001,0x2556001e,0x61380028,0x60db221c}},	//   јла_, kāli_, _bíla, ngum
  { {0xfe78007a,0x2120009b,0xdc9b0009,0x28dc0011}},	// [5940] _šį_, rjih_, _דיפל, _यासि
  { {0xef170625,0x49100037,0xb6360012,0x6721001b}},	//   ому_, _दोनो_, يعات, njlj
  { {0x2902221d,0x7d04221e,0xa2af0011,0x20090035}},	//   _taka_, _kais, ुरन्, avai_
  { {0x186a0800,0xa06a0001,0x7a7b000b,0x69c3221f}},	//   _вами_, _вама_, _כריס, dsne
  { {0x69c1014a,0x05770012,0x7c830024,0xd38a0472}},	//   šlet, آمنة_, муше, айде_
  { {0x60db001e,0xe73a0015,0x7d042220,0x6d4f004b}},	//   egum, _тег_, _lais, zica
  { {0x6135000e,0x7bc22221,0xbb470012,0xa2db0011}},	//   _váln, ssou, تلون_, _नार्
  { {0x26c70029,0x63a9000d,0x20070002,0x8cd60011}},	//   ónov_, ţeni, łnie_, _भागो
  { {0x29020029,0x3ebe07c9,0x257200d9,0x6d4f2222}},	//   ľka_, tatt_, nálu_, vica
  { {0xf7720003,0x6f032223,0x7f830012,0x6a160012}},	//   باع_, _canc, ولين, _وبار
  { {0x613c000f,0x7e9b000b,0x1df80015,0x7d040061}},	//   _péld, יסיו, щены_, _bais
  { {0x3ebe0f33,0x7d040d29,0x20090073,0x67210159}},	//   satt_, _cais, yvai_, ajlj
  { {0x26350020,0x61352224,0x60c0004a,0xf9930009}},	//   áo_, _zálo, mamm, _חרף_
  { {0xdcfc007a,0x69d80061,0xdb06005e,0x637f0018}},	//   _turė, ouve, kskõ, mênc
  { {0x637f0017,0x7d042225,0xb9e4002d,0xe919002d}},	//   lênc, _fais, міти, бові_
  { {0x29c50039,0x90990014,0xa2d70011,0xd4b9003c}},	//   rķa_, сват_, _बाक्, _улиц_
  { {0x26020037,0x8bb70003,0x03b70003,0x7bb70012}},	// [5950] षिकी_, _بإعا, _بإعد, _بإعط
  { {0x60c02226,0x61312227,0xdb1d0018,0x6d590132}},	//   hamm, _måli, ossí, wnwa
  { {0xfeb80003,0x20090010,0x8afa0009,0x7afa005e}},	//   زالت_, svai_, _ההתי, õtte
  { {0x442f0163,0x2fc6001c,0x60c0004a,0x25560035}},	//   tyg_, _ovog_, jamm, tāli_
  { {0xc6d70003,0x69d803bc,0xfae00030,0xbf9b0025}},	//   _وتست, euve, ěšně_, _crêt
  { {0x637f0017,0x2572000e,0x73fc0009,0x93fc0009}},	//   dênc, lált_, שּׁו, ילדי
  { {0x69c30802,0x6d4d00e6,0xd2b80009,0xdcf70012}},	//   usne, _omaa, חלות_, _وأرب
  { {0xda5c000b,0x2572000e,0x6135000e,0xc9840012}},	//   יכול, nált_, _válo, وشيي
  { {0x63a92228,0x637f0017,0x1bd50015,0xe4490003}},	//   _uten, gênc, _хозя, _الذى_
  { {0x6131006f,0xdb1d0028,0x6d5d0061,0x7d042229}},	//   _dåli, fssí, éran, _sais
  { {0x613c0108,0xb9e7002d,0xc332000b,0xa50a0345}},	//   _séle, _фізи, _רוב_, бена_
  { {0xc1040003,0xf3f1001a,0xc27a000b,0xda7a0009}},	//   _يولي, ặn_, _הרעי, _הנער
  { {0x889a000b,0xab5b003a,0x6f030c72,0xc9520009}},	//   _הבני, rsün, _tanc, _אמא_
  { {0xdb060029,0x9f050003,0x443e0002,0xff530012}},	//   jskô, _روبو, ąt_, _تخص_
  { {0x7d040757,0xd356000b,0xdeba0009,0xba1a0012}},	//   _tais, לישי_, _המצל, حيزا_
  { {0x25aa01e3,0xdb060064,0x2572222a,0x613100b0}},	//   íble_, eskô, gált_, _målw
  { {0xed57000b,0xd7f9002d,0x6d3b0009,0xe53b0009}},	// [5960] _מבקר_, жує_, _לתקנ, _לתקר
  { {0x2b1d0044,0xdfcf0003,0xf4130009,0x869a05d8}},	//   माणु_, ايل_, _נפת_, стат_
  { {0xba9b000b,0xe29b000b,0x6a9b000b,0x1a9b000b}},	//   _לסיי, _לשיר, _לשינ, _לייע
  { {0xdb0d0065,0x6376007d,0xbf9b0061,0xdd8f0003}},	//   _hvað, mâni, _prêt, هول_
  { {0x6135000f,0x26c1002c,0x62830066,0x60c0004a}},	//   _váll, baho_, _únor, vamm
  { {0x7982029e,0x69d8001e,0x2556001e,0x637f0018}},	//   _show, tuve, mālu_, vênc
  { {0x2fc60027,0xa50a0867,0x60c0222b,0xdbf20030}},	//   _svog_, _лева_, tamm, dřív
  { {0xd130000a,0x69d8006f,0x637f0017,0xf55a0003}},	//   ئمة_, ruve, tênc, _الرب_
  { {0x2556001e,0x7bc60002,0x65630031,0x2d9c0150}},	//   nālu_, jsku, énhe, _suve_
  { {0x637f0149,0x9b46000a,0xc43b000b,0xdb1d222c}},	//   rênc, _عناو, _התמי, tssí
  { {0xbfa5008a,0x6e940003,0x7ec7000e,0xacf9002d}},	//   _hiệ, بلدا, lépí, онну_
  { {0xbfa50020,0xc19b000b,0x667b000b,0xd6570009}},	//   _kiệ, _השאי, מטיק, ליית_
  { {0x2572000e,0x7c8400b5,0xdfcf0012,0x7bc61693}},	//   vált_, еуре, _مين_, gsku
  { {0x6ffb000b,0xab5b000e,0x38170009,0xd7fb0009}},	//   _להדפ, csül, _מקדם_, _להדל
  { {0xbfa50020,0x61380013,0xde57002d,0xbb77000b}},	//   _liệ, _cílo, _наші_, פעלו_
  { {0x6d4d002c,0xdff30037,0xa4f1003a,0xdce9001e}},	//   _umaa, _अहमद_, dışı_, _okeā
  { {0xb4d90044,0xb9050037,0x2572000e,0x656f0b32}},	// [5970] ाली_, _ना_, rált_, moch
  { {0xc43c0009,0xa92500d9,0xb3bc0009,0x1eab0012}},	//   _לתחי, možň, _המזכ, صائي_
  { {0x200200a2,0x63760018,0x321e008e,0x6d5d222d}},	//   _eski_, câni, ätyt_, onsa
  { {0xbfa50020,0x3940222e,0xdbd7008e,0x29070035}},	//   _biệ, chis_, pääj, ēnas_
  { {0x6d5d2162,0x22070066,0x2d52009b,0xdce6001e}},	//   insa, bíhá_, kšen_, nokā
  { {0xbfa50020,0x212b0052,0xddca000d,0x78a20029}},	//   _diệ, _hoch_, _înşt, ľove
  { {0xd0150037,0xa189002d,0x19890055,0x69c7222f}},	//   तम्भ_, обка_, обки_, nsje
  { {0xf1c00066,0x26de001e,0x6d5d0061,0x3d070037}},	//   ýšit_, egto_, éral, षयों_
  { {0xc0c80001,0xf6d5002d,0x69d50d36,0x60060015}},	//   чује_, міня, hrze, дным_
  { {0x27e908f8,0x2bd20011,0xff250024,0xfbd20011}},	//   itan_, _सिता, ємно, _सितम
  { {0x7a35000a,0x69d50002,0x22590003,0x63ad2230}},	//   _تفاص, jrze, _بلاد_, _atan
  { {0x212b008b,0x27e900a2,0x69c70bba,0x69d50504}},	//   _noch_, ktan_, dsje, drze
  { {0xad1a0093,0x20030035,0x7bc61a8c,0xa2b20011}},	//   קושר, ājis_, usku, _अभद्
  { {0x9f84007c,0x63760017,0x6f071577,0x7bc62231}},	//   _згід, tâni, _najc, rsku
  { {0xfd64001a,0x6996002d,0xdb1d0028,0x613c0025}},	//   _chuộ, драх, ersó, _héla
  { {0x2556001e,0x55ba000b,0xc6920009,0xdb1d005e}},	//   tālu_, _ומקו, _באו_, dusõ
  { {0x212b03e4,0xb87b0066,0x48e30014,0xc9520009}},	// [5980] _doch_, _sbír, ъотв, דמן_
  { {0x63720058,0x613c0061,0x69d50002,0x8e3a0012}},	//   ræns, _méla, brze, يسار_
  { {0x68fb0006,0x27e900c6,0xa3d60037,0xdee30001}},	//   keud, atan_, ांक_, тохи
  { {0x20070002,0x61351a98,0x7ec70031,0xa4f10060}},	//   łnia_, _dálk, tépí, rışı_
  { {0x53fa0003,0x749b000b,0x59830024,0x8cb10011}},	//   تراح_, קיספ, _шлюб, ूरतो
  { {0xbfa50020,0x656f0070,0x60c42232,0x63bb0034}},	//   _việ, zoch, laim, _dwun
  { {0x2556001e,0xaa570003,0x62980042,0x6d5d0097}},	//   nāls_, ولها_, _úvod, ynsa
  { {0x68fb0058,0xbfa5001a,0xbcfb0030,0x7afc06f6}},	//   geud, _tiệ, sléz, hert
  { {0xbcfb0108,0xe2ca0345,0xc1730009,0xa9280030}},	//   nnée, _млад_, כחה_, _zažá
  { {0xc9f60003,0x613c0061,0x64460002,0x51f60012}},	//   _يساع, _déla, dzki, _يسار
  { {0x68ed00a2,0xd5b70015,0x2ca90052,0x8b8b0009}},	//   yfad, мся_, _pfad_, _וָאֶ
  { {0xb4d90037,0x20020028,0x613c0028,0x69dc2077}},	//   ाले_, ækis_, _féla, dure
  { {0x61ea008b,0x87260003,0x69dc2233,0x7afc2234}},	//   ltfl, _يعتم, eure, fert
  { {0x69d5003e,0xe451000b,0xc87f0032,0x7afc2235}},	//   trze, אֶל_, üße_, gert
  { {0xda78004d,0xeef70009,0xe9190024,0xab940024}},	//   дят_, _חמור_, пові_, тирі
  { {0x60c400c6,0x52140048,0x2d52001b,0x69c72236}},	//   gaim, ъдст, nšel_, rsje
  { {0xe8110037,0x3f9800b6,0x83670012,0xbfd90024}},	// [5990] ़िया_, _biru_, _يدخل, ядає_
  { {0x69d5003e,0x63ad0039,0x7bdd0101,0xc8080020}},	//   prze, ķinā, musu, _mở_
  { {0x212b0070,0x7bc90027,0x95c80024,0x9f9a008e}},	//   _toch_, _sveu, дуча_, lään_
  { {0x61350066,0xd6570009,0xe3b10012,0x27e92237}},	//   _válk, ויבת_, هرت_, ptan_
  { {0x9f9a004a,0x7bdd2238,0x68ed0164,0x62810102}},	//   nään_, nusu, _ñadi, _szlo
  { {0x63a001b3,0xc2c50003,0xc6860012,0x77ba0009}},	//   _dumn, ريبي, _مِ_, _ממשח
  { {0xa4d5007c,0xe1f10003,0x18a50024,0xa0a50024}},	//   _пові, است_, найм, найд
  { {0x9f9a004a,0x645a2239,0x3d1e0011,0x7afc223a}},	//   kään_, áciá, _बचें_, zert
  { {0x9f9a004a,0x69dc223b,0x0bd50012,0x7b08008e}},	//   jään_, _åren, _سياح, östä
  { {0x200d223c,0x61350028,0x7c840014,0x613e0010}},	//   rvei_, _máli, _русе, iūly
  { {0x7afc223d,0x20020028,0x68fb223e,0xfce607e8}},	//   vert, ækir_, peud, ноно
  { {0xd46a0001,0x7ae5036a,0x7afc0b3a,0xc6920009}},	//   зиме_, _acht, wert, טאי_
  { {0x7afc223f,0x3af60198,0x8afc0034,0x9f350024}},	//   tert, нявс, _ujęc, _педі
  { {0xa8560093,0xdbd20051,0x25560035,0x18360009}},	//   _אינה_, müüj, tāls_, _ראסל_
  { {0x7afc0033,0x69dc0269,0x6446170f,0x637607ba}},	//   rert, uure, szki, mânt
  { {0x395f104b,0x7ae50369,0x78a91a8a,0x6faa0024}},	//   nnus_, _echt, ncev, зваг_
  { {0x77860001,0x7b96002d,0x78a900c1,0x7bdd003a}},	// [59a0] елаз, _прої, icev, cusu
  { {0x8f9a0093,0xe2050020,0x98c5001e,0xbcfb0061}},	//   פיעי, _đóng_, ētās_, rnée
  { {0x63a02240,0x2d520030,0x3abb0009,0x8f750024}},	//   _sumn, yšel_, _ממינ, туті
  { {0x80be0037,0x89360003,0x9f4001a0,0xad660012}},	//   _एजें, _أعدا, stià_, راضه
  { {0x289b000b,0x3f8c0028,0x2d520159,0x26c52241}},	//   _מיכא, ymdu_, jšem_, kalo_
  { {0x23a60026,0xae1f0037,0xb4650012,0x98a90034}},	//   _môj_, यमान_, خدمه, tkać_
  { {0xc8080020,0xf777000b,0xbda50003,0x2bd20011}},	//   _sở_, _נעלי_, _لحقو, _सिवा
  { {0x65640082,0xab5b005e,0x9f9a008e,0x7bdd11d3}},	//   _njih, tsük, yään_, yusu
  { {0x6d4003d5,0x04570003,0x98a90002,0x613c0031}},	//   _ilma, _كلفة_, skać_, _féln
  { {0x9f9a004a,0x7ff30003,0x798d0002,0x7e46003c}},	//   vään_, اسيا, zmaw, ехме
  { {0x0f570093,0xb1e50003,0x35d80037,0x6131024c}},	//   תיים_, _لأنه, _डिफ़, _målr
  { {0x9f9a0006,0x7bdd00a2,0xd23b000b,0xc5f3000b}},	//   tään_, tusu, _מגבל, נדר_
  { {0x26c50027,0x18330012,0xf5370009,0xdb0b0097}},	//   balo_, _مروح, תרכז_, rsgö
  { {0xf8b8001a,0xa0070003,0xdb00006f,0x501b000b}},	//   _đĩa_, _أقول_, _utmä, _מודו
  { {0x6d4000a1,0x6b9a008b,0xdb500012,0x2bd30011}},	//   _olma, _mitg, حَّ_, _तिवा
  { {0x9f9a0006,0x798d002c,0xab660002,0x867b000b}},	//   sään_, umaw, leżą, _מרוו
  { {0x671c0037,0xa7750001,0xdfd10012,0xdfd4003c}},	// [59b0] नांक_, влач, شيا_, лоты
  { {0x7bcd007a,0x6d401541,0x78a20029,0x4de40037}},	//   šauk, _alma, ľova, _कमाई_
  { {0x7d0901a2,0xab660002,0x2d520029,0xde190012}},	//   _paes, ieżą, dšej_, بقات_
  { {0xa4d5002d,0xb606001e,0x7c590003,0x6285009b}},	//   тоді, dušā, ولار_, _izho
  { {0x7d09005e,0xe4ac0009,0xaf370012,0x61350031}},	//   _vaes, הֹוָ, _كرست, _kálv
  { {0x657d0032,0x21290159,0x2d522242,0x3394003c}},	//   hlsh, ljah_, všem_, гачё
  { {0x6376007d,0xbca50003,0x613c000e,0x290b00b6}},	//   vânt, _لمزي, _célo, _kaca_
  { {0x2d520029,0x7d1b1497,0xdd910012,0xd24e0012}},	//   ašej_, _unus, _ضوء_, غني_
  { {0xd12e0003,0xd5640001,0x95640014,0x78a92243}},	//   تمي_, _стрп, _сърд, rcev
  { {0xddd80010,0xdb000054,0x93970012,0x78a900b8}},	//   _gyvū, _numè, _أجرا, scev
  { {0x7bcd004a,0x26c3009b,0x99d40003,0x96650024}},	//   _avau, _mejo_, _متنا, ткне
  { {0xc0cb003c,0xee360198,0x2129016d,0xf09f0081}},	//   _хуже_, тню_, jjah_, _ngà_
  { {0x263c001a,0x7bcb2244,0xd009004c,0x21292245}},	//   ảo_, nsgu, _целе_, djah_
  { {0xeb970098,0x27ed0052,0xc7d6000b,0xfc03004c}},	//   кия_, mten_, _יוני_, јпро
  { {0x44200020,0x27ed10cc,0xdcfb003a,0x290b051f}},	//   ̣i_, lten_, aptı, _baca_
  { {0xf8b30011,0xdb1d008e,0x27ed1d6e,0x867a0009}},	//   ीरिय, essä, oten_, _קרקו
  { {0x290b000d,0x672e0027,0x27ed2246,0x9a9e0024}},	// [59c0] _daca_, _pobj, nten_, _мунi
  { {0x6fd40037,0x127a0003,0x27ed2247,0x98b3001e}},	//   _दिसं, _يحدث_, iten_, ādāt_
  { {0x200d0039,0xe7fe0044,0xa6960001,0x333b000b}},	//   _šeit_, _उनका_, трај, _חתימ
  { {0x63a40006,0xceb80002,0x9e750001,0x6dac0060}},	//   _kuin, zbę_, ућуј, _ağac
  { {0x44320020,0x6d5d0061,0xead4027f,0x19570009}},	//   ây_, érai, голь, _יבטל_
  { {0x680f000e,0x290d000d,0x68e40b4b,0xe4530009}},	//   ződö, edea_, lgid, סֶף_
  { {0x442001b3,0xf2d30009,0x31c3003c,0x2d520064}},	//   ţi_, בעו_, асыв, ršej_
  { {0x751a0003,0x9e4b0009,0xa967004c,0x27ed2248}},	//   _تقرأ_, _חֲמִ, кија_, ften_
  { {0xc9530093,0x27ed2249,0x60c20027,0x61380066}},	//   ימה_, gten_, _veom, _cíli
  { {0x6b9a00bd,0xcdd4000b,0x6376004b,0x25790097}},	//   _uitg, ְךָ_, râns, hélt_
  { {0xdb000108,0xcf770003,0x27ed224a,0xfe6f0012}},	//   _numé, خصيص_, aten_, ْدُ_
  { {0x27ed0052,0xa9270010,0xca370009,0xc2370009}},	//   bten_, gužė, _שנאה_, _שראו_
  { {0x27ed224b,0x29000017,0x63a4224c,0x0ee20011}},	//   cten_, deia_, _cuin, _पांड
  { {0x44260149,0xd2460003,0x9f40004a,0x6d4600b6}},	//   ixo_, من_, ntiä_, ahka
  { {0x4f9b0093,0x39a40001,0xaa540001,0x4a540001}},	//   _קבוצ, иштв, аврш, акрс
  { {0x58d40015,0x6285009b,0xc56b0012,0x9f40008e}},	//   иост, _vzho, _تحتل_, htiä_
  { {0x40340047,0x27e003eb,0x65620066,0xc05b002d}},	// [59d0] аетс, guin_, dnoh, фів_
  { {0x4ab70037,0x6562004a,0x44390575,0xc7d70009}},	//   _अभिव, enoh, mys_, כומי_
  { {0x7d0d0005,0xb05b0052,0x27ed0052,0xc3320009}},	//   _kaas, _geän, zten_, _הוי_
  { {0xc5f30093,0x753d000f,0xa3c00011,0x44390bb5}},	//   ידע_, nksz, ूओं_, oys_
  { {0x50da0093,0x4439224d,0x27ed1173,0x8d740012}},	//   _אקרא, nys_, xten_, جالا
  { {0x4dd70012,0x1c440024,0x7d0d005e,0x39e9003c}},	//   _لترس, шнім, _laas, едко_
  { {0x2b890026,0x51f5000a,0xc9f50003,0xf7720009}},	//   júce_, استر, استع, _הקם_
  { {0x09f6000a,0x661a000e,0x2b890029,0x44390759}},	//   افية_, _átka, dúce_, kys_
  { {0x34940177,0xe8f6003c,0x2d8701a0,0x27ed224e}},	//   _ватр, улы_, ïneu_, uten_
  { {0x4439007a,0x6d590101,0x257c05b1,0x20d3001a}},	//   dys_, liwa, víli_, ợi_
  { {0xa01b004a,0x7d0d0051,0x3f9c224f,0x28dc0011}},	//   _hyöd, _baas, _divu_, _याचि
  { {0x6d590101,0x6e210054,0x10150012,0xcb090009}},	//   niwa, _àlbu, _مبتد, _מל_
  { {0xd456002d,0x20070002,0x63a42250,0xc1720009}},	//   утнь, łnij_, _quin, _פחד_
  { {0x6d59002c,0x03a301ec,0x257c0064,0x61ee2251}},	//   hiwa, сиро, ríli_, ttbl
  { {0x6d590656,0xc5d5007c,0x799d0032,0x44392252}},	//   kiwa, _сіль, _bisw, ays_
  { {0x867a0093,0x7d0d0051,0x27e018ed,0x60c9005e}},	//   _ארצו, _gaas, tuin_, naem
  { {0x378a004c,0x29002253,0xe8160011,0x68e42254}},	// [59e0] ебао_, reia_, तिया_, rgid
  { {0x613c000e,0xbcfb000e,0x9bbb0009,0x27e00227}},	//   _célj, nnén, _רציפ, ruin_
  { {0x4e890009,0x29000018,0x2bc60011,0x4da50012}},	//   תָּ֣, peia_, रीना, لإنف
  { {0xcea9000b,0x6d590002,0xd7d40037,0x6cd60003}},	//   לי_, giwa, _दिलच, اقشا
  { {0xc3d70012,0xebd60009,0x9f40008e,0x27e02255}},	//   هبوط_, רֵ֣י_, ttiä_, quin_
  { {0xdceb001e,0x63520034,0x78bb0073,0xc1ba0009}},	//   rogā, ołni, ebuv, ֲמִש
  { {0x366a0015,0xe1ef0012,0x99d30012,0x59d30012}},	//   _чаво_, كسي_, متيا, مغير
  { {0x3d0e0044,0x3f9c0006,0x9f40004a,0x31340001}},	//   ियों_, _sivu_, stiä_, реир
  { {0xbc660046,0x6b460065,0x273b0020,0x44660024}},	//   _свак, _aðge, _kênh_, _свав
  { {0x8ff7000a,0x17f7000a,0x07f70003,0xadf40001}},	//   ارير_, ارية_, اريع_, апош
  { {0xab93000a,0xb5210037,0x3f82001e,0x9b930012}},	//   _اللغ, यालय_, ēku_, _اللت
  { {0xdce0001e,0xdd910003,0x6288001e,0x44392256}},	//   _ikmē, توج_, _izdo, tys_
  { {0x61350272,0xf9930009,0x7d00005e,0xe73a0024}},	//   _vált, _הרף_, õmsa, _пед_
  { {0x799d00b6,0x44390914,0x61380028,0xb09b0009}},	//   _sisw, rys_, _mílu, _ניגר
  { {0x613c000f,0x7d0d109a,0x7c390002,0x443f2257}},	//   _nélk, _taas, zywr, šu_
  { {0x6288009e,0x80b50b9b,0x000000c4,0x000000c4}},	//   _mzdo, рбах,   ,
  { {0x90990014,0x9f550345,0xd6db19cd,0xd3710012}},	// [59f0] тват_, авач, ете_, _وهب_
  { {0x69da0066,0xd5b8001e,0x3e6b0048,0x6d440064}},	//   átec, opā_, ншен_, _zlia
  { {0x6d590101,0x9cb50003,0x539a000b,0x613c000e}},	//   tiwa, لمات, _שיתו, _célk
  { {0x55bb000b,0x2dd80003,0x613c19d5,0x637f0783}},	//   גמאו, ابلة_, _délk, mêni
  { {0xd0060003,0xc2c50003,0x7bcf1aa3,0x6d590a60}},	//   _بل_, ليشي, nscu, riwa
  { {0x6ee20037,0x39490017,0x6d59002c,0x257c0066}},	//   _पाएँ, lhas_, siwa, dílu_
  { {0x4424001a,0x2002003a,0x69250083,0x83380009}},	//   ̣m_, çkin_, имка, ראוס_
  { {0x39490149,0xe9a80012,0xa3d60011,0x613801a0}},	//   nhas_, ددون_, _हिल_, _fílu
  { {0xbcfb000e,0xaae70012,0x44390040,0x78a208ef}},	//   tnén, _مساو, _æs_, _dgov
  { {0xff510003,0xef120009,0x7a1c004b,0xdceb004b}},	//   تخب_, ַּת_, _bătă, bogă
  { {0x23ab0058,0x4d660209,0xcf560009,0xc0d50012}},	//   _høj_, иков, שבתת_, _نياب
  { {0xa2af0037,0xfce60024,0x8d560223,0xed5a1ab3}},	//   ुरक्, шомо, рточ, том_
  { {0xd5b8001e,0x40e80009,0x5d67003c,0x69ce0227}},	//   apā_, _תַעֲ, риям_, wsbe
  { {0x290f02d1,0x2b1e0037,0x66e20001,0x6fb20003}},	//   _haga_, पाएँ_, _доша, _بموا
  { {0x61e3003a,0xdf740003,0x637f0017,0xc97a004c}},	//   nunl, _ادنب, gêni, вљач_
  { {0x6d5d0108,0x98a3004d,0xc6160009,0x290f2258}},	//   érat, жите, _כחצי_, _jaga_
  { {0x7d7b000b,0x290f2259,0xe8f7004c,0x60970012}},	// [5a00] _בנקו, _maga_, јлу_, لنفس_
  { {0x8c1b0093,0xdce90026,0xf3f1001a,0x57470001}},	//   _יופי, _cieľ, ặt_, азум_
  { {0xaadb0093,0x38690065,0x32db000b,0x26c7225a}},	//   _בחיר, _þarf_, _בחינ, _meno_
  { {0xfdf6000b,0x3949225b,0xce890012,0x61380018}},	//   יצעת_, chas_, ائكم_, _pílu
  { {0xb6a6002d,0xe3af0012,0xab5b0031,0x232a0024}},	//   _вигл, ورو_, psüt, коди_
  { {0xfc17000b,0xf74600bb,0x93930012,0x661a0031}},	//   יקני_, _тего, يجوا, _átko
  { {0xf2d3000b,0x61e31147,0xc2070012,0x4efb0009}},	//   קעה_, gunl, لقون_, _שהלו
  { {0xf98f0003,0xdceb000d,0x23ab0058,0x39400010}},	//   وبي_, rogă, _føj_, nkis_
  { {0x1ae60047,0x8ad6000a,0x290f0065,0xb8fe0037}},	//   _возм, _نتائ, _daga_, _तय_
  { {0x61fe0119,0x26c7012e,0x2d820070,0x661801bd}},	//   _oppl, _ceno_, elke_, _prvk
  { {0x6288001e,0x4d99002d,0x394008a1,0x2d68001b}},	//   _uzdo, лкою_, kkis_, rđen_
  { {0x78a20027,0xd5b80035,0xdde00031,0x637f0018}},	//   _ugov, rpā_, ítőj, vêni
  { {0x2d85001e,0x257201bd,0xe7b40012,0xcb220011}},	//   ēle_, nály_, _امتد, मांड_
  { {0x2904225c,0x957d0034,0x57fb0009,0x6df40012}},	//   lema_, krąg, _סלוו, _هكتا
  { {0xf99f00b8,0x29970012,0x26cc225d,0x38c70048}},	//   _piè_, لجرح, mado_, ищав
  { {0xa37b0017,0x5e9b000b,0xfe9b0009,0x0e9b0009}},	//   drõe, _בבוק, _ביומ, _בשול
  { {0x8387003c,0xc0c8004c,0x61e30060,0x351c0009}},	// [5a10] _выне, русе_, zunl, _יוהנ
  { {0xf7700003,0x613c0061,0x26cc060e,0x6d5d225e}},	//   وال_, _déli, nado_, lisa
  { {0x95d90015,0xab5b0051,0x2b890029,0xdb1d0040}},	//   удет_, ssüs, júca_, dssø
  { {0x2bd20011,0x26c70034,0x613c0445,0x6db40024}},	//   _सिखा, źno_, _féli, ійчу
  { {0xed58007c,0x290f00b6,0x60cd004a,0x6d5d005e}},	//   шої_, _raga_, maam, iisa
  { {0xfbb80093,0x61e3003a,0x60cd01a3,0x26cc052e}},	//   ספות_, tunl, laam, jado_
  { {0xa2ba0037,0xdb040164,0x2d8d0087,0x26cc01c5}},	//   ्रत्, _quié, _thee_, dado_
  { {0x6b4b000f,0x61e300a2,0x29040051,0x41b20003}},	//   _függ, runl, gema_, أمير
  { {0xc158000b,0x25a000b6,0x30190012,0x2bc60011}},	//   ישהו_, _riil_, اتبة_, रीदा
  { {0x91710020,0xbb850003,0x26cc225f,0x43850012}},	//   _mở_, _الطي, gado_, _الطق
  { {0x39400010,0xfaf00012,0x60cd01a3,0x212d001b}},	//   ykis_, _تثق_, kaam, pjeh_
  { {0x3cf40044,0x60cd0038,0x4a5a0009,0x200b0040}},	//   ेजें_, jaam, _גדעו, æcis_
  { {0xe72e0047,0x51740003,0x41740003,0xc9740003}},	//   _ее_, _بالأ, _بالس, _بالث
  { {0x26cc0583,0x68e92260,0x6d5d2261,0x752f0034}},	//   cado_, lged, érar, ajcz
  { {0x6d5d2262,0xc3320009,0x91860012,0xaa43092d}},	//   bisa, הום_, مجرم, перл
  { {0x661c00c5,0x6d5d2263,0xccc6004d,0x35d10011}},	//   ærke, cisa, _убий, _हिज़
  { {0x75242264,0x7d060d70,0xe3d60012,0x644f0034}},	// [5a20] _iniz, meks, _اتبع, czci
  { {0xcc57000b,0x2bab0037,0xdb0e004a,0xa696004c}},	//   _לספק_, _चढ़ा, äkär, бреј
  { {0xb5a9000a,0x61fe2265,0x139b000b,0xfb37000b}},	//   لانك_, _uppl, _תביע, _האיש_
  { {0x0c26002d,0x26cc060e,0x5693002d,0x63a92266}},	//   ймен, zado_, чаєт, _buen
  { {0x63a906f4,0x6b460065,0x6ba1003a,0xdb5a0024}},	//   _cuen, _aðga, _üzgü, люк_
  { {0x62810010,0x63a1001e,0x3ebe0028,0x26cc0e0a}},	//   _bylo, _ciln, _ýtt_, xado_
  { {0x26cc0aa1,0xdce2009b,0x599a0009,0xbcfb0025}},	//   vado_, lnoč, ְשִׁ, liée
  { {0x63a90164,0xb3ea0003,0x57b4024d,0x27e40132}},	//   _fuen, _معطل_, обит, tumn_
  { {0x7bcd001e,0xcf260003,0x26cc1888,0x6b4b0032}},	//   šaur, مردي, tado_, _hüge
  { {0x6d5d00b6,0x1754002d,0x27e00c6e,0x60cd0227}},	//   wisa, івня, irin_, zaam
  { {0x52860003,0x877b01b0,0xa3e40011,0x1df8003c}},	//   _الاك, ראיי, पूर_, шены_
  { {0x63a1007d,0xdc99002d,0x3946004a,0x35470024}},	//   _ziln, ивні_, _ulos_, схов
  { {0x4096000a,0xb896000a,0x69da0029,0x79840002}},	//   _الشر, _الشع, áten, dliw
  { {0x26ca06bc,0x9171001a,0x6d5d193b,0xe0850012}},	//   _nebo_, _rở_, sisa, _بجمي
  { {0x69da001c,0x91710020,0x60cd004a,0xdce9001e}},	//   šten, _sở_, taam, _pieļ
  { {0x8e83000a,0x7d0600a2,0xbcfb0061,0xf9b7000b}},	//   _عليه, ceks, fiée, מהלך_
  { {0x76a70003,0x58870015,0xe8940015,0x60cd01a3}},	// [5a30] محاك, сыва, зать, raam
  { {0x60cd2267,0xf2c70b4e,0x798414df,0xa3d20011}},	//   saam, _усин, aliw, _विज_
  { {0xdf360020,0x26ca0164,0x60cd004a,0xcb380009}},	//   _đặt_, _debo_, paam, _לנזק_
  { {0x63a90164,0x249f001e,0xc4c30011,0xe4cb0012}},	//   _puen, žumu_, शरेख, ابان_
  { {0x63a1134f,0xbcfb0061,0x25ad0864,0x7b080031}},	//   _piln, ciée, _čelu_, _értü
  { {0x2b220037,0x7ae7002d,0x6b4b0052,0x63bd0010}},	//   माएँ_, сюдж, _füge, ipsn
  { {0xeb92000b,0x63a12268,0x7d061b37,0x6b7c0009}},	//   וָה_, _viln, yeks, ארגנ
  { {0x628105b1,0x2fdf0359,0x63a12269,0x5fd40011}},	//   _vylo, trug_, _wiln, _दिखल
  { {0xe81c0044,0x63a90005,0xfbe00044,0x98a90029}},	//   निया_, _uuen, _नियम, kiaľ_
  { {0xf7710003,0xa3e80037,0x68e90052,0xbcfb0042}},	//   باب_, मंस_, sged, lnéh
  { {0x2bdc0037,0x79960002,0xa2ba0037,0x63bd0227}},	//   _बिहा, ymyw, ्रस्, epsn
  { {0xc3290093,0xbcfb01e9,0x2bc60011,0x6d5d0025}},	//   _בו_, nnéh, रीवा, érap
  { {0xe3b20012,0xbcfb0030,0x7d06226a,0xd38a0024}},	//   برج_, inéh, reks, ийме_
  { {0x957d003e,0x394d0149,0x7d06226b,0x395f226c}},	//   stąp, lhes_, seks, lius_
  { {0x6e950003,0x79840002,0x999e0066,0xe29a0695}},	//   _بلغا, tliw, átů_, рав_
  { {0x395f226d,0x201d0002,0xbcfb00d9,0xc2120009}},	//   nius_, _krwi_, jnéh, והל_
  { {0x60cb000e,0xbcfb022d,0x4999003c,0x79840034}},	// [5a40] _megm, dnéh, ётся_, rliw
  { {0x60cb000e,0x361a00fa,0x6d49226e,0x25e00011}},	//   _legm, ицею_, _alea, _किमी_
  { {0x395f0010,0x8afb0009,0x36060012,0x79840034}},	//   kius_, _דהיי, تواف, pliw
  { {0x92a60002,0x6d49226f,0xe5060012,0x8699003c}},	//   zyłą, _clea, تبطي, стут_
  { {0xa01b2270,0x613c0031,0xe5a3046e,0x6d420e64}},	//   _szöv, _mélt, фици, rkoa
  { {0x8c1b000b,0x3f780009,0x7c0b0009,0xaae60012}},	//   יוני, _הָֽע, שִׁ֔, زستو
  { {0xc333000b,0xbcfb01e9,0xe5060012,0x2d800073}},	//   ווג_, bnéh, _وبري, _okie_
  { {0xa01b004a,0x06570009,0xa9930012,0x96570009}},	//   _myön, _וילך_, وشيت, _ושלא_
  { {0xf9930093,0xff06004d,0xb8070012,0x87060048}},	//   ורה_, оянн, قييم_, ояне
  { {0xec370009,0x2d800034,0x394d005e,0x656d2271}},	//   _ואמר_, _akie_, ahes_, _sjah
  { {0x69da0013,0xceb3000b,0x637f0018,0xf7730009}},	//   átel, וית_, rênt, וקז_
  { {0xda650003,0x8fa60014,0x394d2272,0x613c0bf4}},	//   _عالي, _даде, ches_, _célt
  { {0xd7ef000a,0x98a90026,0xc4d30009,0xd11b0011}},	//   _لكن_, tiaľ_, וגר_, _पोषण_
  { {0xada50029,0x75d40012,0x9e660012,0xcaa70012}},	//   _skúš, _فيتا, _واثن, تصحي
  { {0xf1b8000b,0xda350015,0x613c0031,0x099b0012}},	//   מֶּל, чевы, _félt, لضرب_
  { {0xed580046,0xa3e80037,0x63bd0248,0x98a90064}},	//   _мој_, मूह_, ppsn, siaľ_
  { {0xa2ba0037,0xb2a70003,0x2eab0001,0xbcfb01e9}},	// [5a50] ्रश्, _وحده, ањен_, vnéh
  { {0xa295002d,0x249f0035,0x39810097,0x3ea7036e}},	//   _напі, žums_, lóst_, ønt_
  { {0x6d490036,0x98af001e,0xbcfb0042,0x88c70012}},	//   _plea, _logā_, tnéh, _وتحل
  { {0x395f0054,0x69d5057f,0x63ad2273,0x657d2274}},	//   xius_, msze, _kuan, nosh
  { {0x7c070003,0xbcfb01e9,0x28b60009,0xad1c0009}},	//   تباك, rnéh, _מפרש_, יואר
  { {0x27e900b6,0x883a007e,0x889a000b,0xdb01000e}},	//   muan_, _התשו, _לברי, _kilé
  { {0xeaf8000a,0x395f03eb,0x4429000d,0xe5730003}},	//   ترنت_, tius_, ţa_, _قطر_
  { {0x26000037,0x68ed2275,0x39810097,0x20550365}},	//   _रहती_, ngad, jóst_, зтор
  { {0x395f2276,0x27e9020d,0xab870024,0x63ad2277}},	//   rius_, nuan_, _дужк, _nuan
  { {0x395f0d1d,0x2ca9002c,0x394d0087,0x657d008e}},	//   sius_, _agad_, shes_, eosh
  { {0x395f007a,0x27e900c6,0x69d50002,0x673c006f}},	//   pius_, huan_, jsze, örja
  { {0xa3d70044,0x69d510ff,0x27e900b6,0x3114002d}},	//   ाओं_, dsze, kuan_, _офіс
  { {0x63ad02d1,0x5067000a,0x27e900c6,0x31b10031}},	//   _cuan, _بطاق, juan_, _ház_
  { {0x77ba000b,0xa0260028,0x98ad0027,0x957d0002}},	//   _המסח, stöð, iječ_, trąc
  { {0x6b500163,0xda660003,0x69d509c5,0x3cff0ca4}},	//   _lägg, ساسي, gsze, _obuv_
  { {0x3d150011,0x69950024,0x68ed2278,0x6e3c0032}},	//   णयों_, друх, ggad, ärbe
  { {0x69d50002,0x27e9010a,0x63ad2279,0xb4d80011}},	// [5a60] asze, guan_, _guan, ाणी_
  { {0x656b00b6,0xa01b004a,0x1e9607e6,0xdce9001b}},	//   engh, _työn, прер, _dječ
  { {0x63bb007d,0xf7720093,0x200f0028,0x7d1604b0}},	//   _atun, עקב_, ægir_, _kays
  { {0x2be00037,0x27e900b6,0x8fa61271,0xfd120012}},	//   _निदा, buan_, _наме, عجا_
  { {0x9f440061,0x2bcf0011,0x7c260159,0x6d46227a}},	//   sumé_, _सौदा, _škrb, ikka
  { {0x60c4039c,0x6b500248,0xb4d80011,0x656b227b}},	//   lbim, _dägg, ाणु_, angh
  { {0xf1070037,0xcb130009,0xf1aa0012,0x63bb008e}},	//   वजूद_, גלו_, حاته_, _etun
  { {0x4ddb000b,0x23dc0037,0x442000e7,0xb6a30341}},	//   _לחלו, _बिंद, _ori_, _числ
  { {0xebe30046,0x69d5003e,0x67380027,0xdb000040}},	//   _потп, zsze, _povj, _rumæ
  { {0x63ad00c6,0x0057000b,0xa857000b,0x4427001a}},	//   _ruan, פשית_, פייה_, _ăn_
  { {0x44200175,0x3abb000b,0xa2d30012,0xa2bb0009}},	//   _ari_, _המבנ, _سينت, _המבט
  { {0x6562004a,0x442000b6,0x27e9002c,0x63ad003a}},	//   nioh, _bri_, yuan_, _puan
  { {0x69d50002,0xa3cf0037,0x21370009,0x07f70012}},	//   wsze, वीप_, _מטאל_, _فروع_
  { {0x6d461b3f,0x889b000b,0xa3a40001,0xb09b0009}},	//   akka, _הבדי, ејск, _הידר
  { {0x39810065,0x4efb007e,0xb909001a,0x4420031b}},	//   póst_, _הלוג, _nghề_, _eri_
  { {0x27e900b6,0x62850042,0xd627004c,0x1958003c}},	//   tuan_, _vyho, _хоће_, пасы_
  { {0x69d5000f,0xd1970009,0xe81f0011,0x68ed227c}},	// [5a70] ssze, לכלי_, बिया_, rgad
  { {0xfbd2000b,0x27e902a0,0x69d50b95,0xdce9001b}},	//   _שתי_, ruan_, psze, _vječ
  { {0xe4d9000a,0xc5f8001e,0x6d4d0562,0x8afa0009}},	//   قوات_, ntē_, _klaa, _והתי
  { {0xe7dd0011,0xc5f80035,0x3f9a016d,0x656b227d}},	//   _मिलप, itē_, ampu_, ungh
  { {0xfc460020,0x1be9002d,0x9cd80009,0xa4870012}},	//   _đích_, ідки_, לואה_, أجان
  { {0xaabf0037,0xdb09003a,0xe1f10003,0x6b500248}},	//   ्रिक, _önün, نسب_, _vägg
  { {0xa3b401e1,0xd2b80009,0x6b4f0040,0xe29614f1}},	//   _जून_, הלות_, _nøge, маш_
  { {0x3a3a0248,0x673c0248,0xda6400ae,0xdb000522}},	//   äppa_, örjn, عاوي, _aumä
  { {0xd7ee0003,0x1abf0011,0x661c0040,0xd9da0011}},	//   لكي_, ्राथ, ærkn, _बट्ट
  { {0xb4e60044,0x6b4f00c5,0xf8aa0011,0x69da0097}},	//   कल्प_, _bøge, _कल्प, átek
  { {0x7d160061,0x1d0a0048,0x6b500032,0x5ee80009}},	//   _pays, оени_, _jäge, הַרְ
  { {0x4420227e,0xda7a0009,0x52c60011,0x2b920025}},	//   _pri_, _ונער, वर्स, râce_
  { {0x6d46004a,0x6b50006f,0x6b4b0051,0xdde00066}},	//   rkka, _läge, _süga, ětši
  { {0xa3cf0037,0x889a000b,0x2f180015,0x9f340024}},	//   वीय_, _ובני, _ночь_, _печі
  { {0x03a300de,0x316d000d,0x6b500154,0xe7300012}},	//   тиро, onez_, _näge, _حصن_
  { {0x61e1000e,0x4420163a,0xd1320012,0x316d0025}},	//   álla, _tri_, خمر_, nnez_
  { {0x4420227f,0xbf8a001a,0xd7f9002d,0xa01b0031}},	// [5a80] _uri_, _đoạn_, зує_, _ször
  { {0x6ac6000a,0x86ea0003,0xbcfb01e3,0x42560012}},	//   _تقدم, تعرف_, nién, _ينظر
  { {0x7cf1000e,0x95c30012,0x860a0012,0x65621916}},	//   zűrő, َيْه, تقاق_, tioh
  { {0x25e0015f,0x448a010c,0xe8df0081,0x998a0073}},	//   _किसी_, обен_, _trộm_, rybų_
  { {0x753b0061,0xdca3085f,0x645d0073,0x78a20064}},	//   _douz, ваци, _žsir, ľovs
  { {0xa294002d,0x9f400164,0x92940001,0x43730001}},	//   налі, rtió_, налц, кујт
  { {0x2be00037,0xe1ef0003,0x9f400a04,0xd2500012}},	//   _निवा, لسي_, stió_, طنة_
  { {0xd130000a,0xb8140001,0x9171001a,0x613c000e}},	//   امة_, едиј, _cờ_, _célp
  { {0x6b4f0e46,0x673c019a,0x36d40aa2,0x61ea004b}},	//   _søge, _korj, нопр, sufl
  { {0x6d4d0070,0xeeeb001a,0x7bc20431,0x4b260012}},	//   _slaa, _đừng_, mpou, _تعرف
  { {0x6d4d0643,0x917a001a,0x673c009b,0x32460012}},	//   _plaa, _cậy_, _morj, _تناف
  { {0xe611000b,0xc5f8001e,0x61e50066,0xc86602ad}},	//   נִי_, rtē_, áhle, _отли
  { {0x24920002,0x6d4d0070,0xc5f8001e,0x443f001a}},	//   _czym_, _vlaa, stē_, âu_
  { {0x673c004a,0xbcfb0478,0x1dae0011,0xdb190032}},	//   _norj, cién, टदात, sswö
  { {0xe8160037,0x442d000d,0xd13b00a6,0x46140012}},	//   तिका_, ţe_, оха_, _أوبر
  { {0x35d80011,0xf1940024,0x69d82280,0xbcfb2281}},	//   _डिज़, вись, isve, gnét
  { {0x6576000e,0x6b5002f1,0x25a9005e,0xa01b008e}},	// [5a90] ézhe, _säge, _iial_, _työm
  { {0xa01b004a,0x6440074a,0xcff70009,0xd6d10012}},	//   _hyök, ämie, וצמה_, اقا_
  { {0x753b2282,0x637f0066,0x93780003,0x7d0b000e}},	//   _pouz, ráně, _تصير_, tegs
  { {0xa8350046,0x6a9a000b,0x2be00037,0xba9a000b}},	//   _земљ, _משתנ, _निशा, _מסתי
  { {0x7bc4007d,0xfd58000b,0xf4d60012,0x212b1e81}},	//   ţiun, ושאי_, رووغ_, _inch_
  { {0x98af003e,0x94740003,0x2be00037,0x547c0009}},	//   _mogą_, خدما, _निरा, קטגו
  { {0x2006007d,0x4b38000b,0x23690027,0x3f810066}},	//   _apoi_, ורגל_, đaj_, mohu_
  { {0x3949134f,0x291900b6,0x6e94085d,0x66150031}},	//   nkas_, _jasa_, _рису, _iszk
  { {0x99410002,0x29192283,0xbcfb01e3,0xa0e30035}},	//   móż_, _masa_, tién, dēļā_
  { {0xe731000a,0x656f0017,0x6d96000e,0xaf090012}},	//   اصة_, ench, záad, أقدم_
  { {0x2b890026,0x248900b6,0x8d6601d4,0x3949002e}},	//   júci_, _ayam_, евне, kkas_
  { {0x917a0020,0x29191e80,0x2d842284,0x2b890064}},	//   _vậy_, _nasa_, ôme_, dúci_
  { {0x66f00011,0x2ca40248,0x61e10031,0xbc190024}},	//   _चालक_, ämd_, álln, мірі_
  { {0x883a0009,0xc7d60009,0x212b00b8,0xdbc6005e}},	//   _מתנו, _טוני_, _anch_, _tööe
  { {0x49960306,0x69960024,0x2bdc0011,0x7bc20030}},	//   ешат, ерах, _बिका, zpou
  { {0xa91d0b16,0xfbe00011,0xa3c10011,0x394921fb}},	//   bože, _निलम, ूठा_, gkas_
  { {0xd0070146,0x6566002c,0x27ed2285,0xc9520009}},	// [5aa0] нете_, mikh, nuen_, אמן_
  { {0xe1fa0047,0xa01b0006,0x65660f96,0x39492286}},	//   _его_, _myöh, likh, akas_
  { {0x1af70009,0x82f70009,0x64462287,0x673c0032}},	//   _אמיל_, _אציב_, lyki, _vorj
  { {0x3a2500c5,0x39490163,0x41bb000b,0xa2ba0037}},	//   ælpe_, ckas_, _מצטע, ्रक्
  { {0x6615000f,0x9cd7000b,0x673c004a,0xad650012}},	//   _eszk, תונה_, _torj, خاله
  { {0xfbd3000b,0x9f4d008e,0x3f490097,0xbc670012}},	//   נתו_, nteä_, _búum_, عمون_
  { {0x7d042288,0x63a804d2,0x29190060,0x27ed016a}},	//   _obis, _vidn, _yasa_, euen_
  { {0x7afb001c,0x6446007a,0xeeeb001a,0xf41f004a}},	//   đuti, kyki, _đứng_, yvä_
  { {0x63a8006f,0x27ed0962,0xd1170009,0x62880034}},	//   _tidn, guen_, תקפה_, _wydo
  { {0x6446007a,0xd6da004d,0x501b0009,0x6ac60012}},	//   dyki, чти_, לופו, _أقام
  { {0x0f570009,0xa3d30011,0xceb80034,0x4424005e}},	//   גיים_, हीन_, rcę_, _hrm_
  { {0xb4eb0037,0x6c350012,0x290d004b,0xa91d0159}},	//   मले_, نفجا, ceea_, tože
  { {0x291906db,0xa93b0009,0x656f0032,0x64460073}},	//   _rasa_, _מתאפ, rnch, gyki
  { {0x3e340003,0xe4510009,0x75280035,0x61e10031}},	//   _لفتر, בֶל_, ēdza, állo
  { {0xb9e4007c,0xa01b0006,0xda780014,0x41e4002d}},	//   літи, _työk, еят_, літа
  { {0xf8b20044,0x69da0061,0x39490010,0x23e00037}},	//   ीडिय, âtea, ukas_, _निंद
  { {0xb8d90044,0xa91d0066,0xb4bf0037,0xf6e70662}},	// [5ab0] _चल_, ložc, ेरी_, ецен
  { {0x2aee0044,0x20e1001a,0x7d0f000e,0x29000051}},	//   _जाएँ_, ỗi_, lecs, afia_
  { {0x9f400065,0x3f9e0028,0x86240109,0xfb1a0009}},	//   rtið_, imtu_, льце, _חותמ
  { {0x59b60037,0x40950012,0xf42a0064,0x9f400097}},	//   _आंतर, _للجر, späť_, stið_
  { {0x53e00037,0x4d880012,0xe3b80024,0x8d740012}},	//   _निःश, رَهُ_, ебі_, دالا
  { {0x16100011,0xc1b90012,0x63850048,0xaf090012}},	//   ़बार_, وابط_, ъгла, _تقسم_
  { {0x69da17a3,0x66150002,0x64460002,0xddcb0010}},	//   štev, _uszk, zyki, čiųj
  { {0x3f8c0028,0xa91d0159,0x9d180a21,0x27e92289}},	//   eldu_, olži, _пост_, oran_
  { {0x5b15011f,0xa91d009b,0x2d820132,0xe315004c}},	//   _имат, tožb, voke_, _имањ
  { {0x64460010,0x798d00b6,0x4f22003c,0x257c0030}},	//   vyki, hlaw, адьб, díly_
  { {0x9171001a,0xb6ba0009,0xa92b0024,0xd5e50048}},	//   _cỡ_, וצתי, _ніде_, ъжни
  { {0x644606d4,0x64590002,0x7d1b0692,0x98c70012}},	//   tyki, ozwi, _jaus, _أغان
  { {0x27ed0a04,0x2d82228a,0xef0e0a2e,0x6459016a}},	//   quen_, roke_, _км_, nzwi
  { {0x00560093,0x27e90054,0x64460010,0x66e5024d}},	//   _בשנת_, dran_, ryki, _рока
  { {0x9171001a,0xc3320009,0x6446228b,0xd6ce0012}},	//   _gỡ_, סול_, syki, _بقى_
  { {0x7d040b37,0x5d7a0012,0x9f40008e,0x64460073}},	//   _ubis, _تحتج_, ntiö_, pyki
  { {0xef1a0047,0xa067029b,0x18671104,0xdb080061}},	// [5ac0] мма_, вата_, вати_, _fidè
  { {0x03aa0003,0x798d002c,0xc3e50012,0xdfcf0012}},	//   _تدعو_, alaw, _إثيو, تيك_
  { {0xd5b9002d,0xf2d3000b,0x99860003,0x75d30012}},	//   есі_, _דעת_, _للدو, ليلا
  { {0x98ad0066,0xdb1d000e,0x216a002d,0x69de0b2d}},	//   ěněn_, özös, _цими_, špek
  { {0x3f8703ca,0x23b30012,0x3f8c0097,0xb8f60011}},	//   _oknu_, لمنس, yldu_, हर_
  { {0x7ceb003a,0xef1f0034,0x69dc090a,0x23271cd7}},	//   törü, ążce_, osre, кочи_
  { {0x672e0163,0x2b890029,0xbebc001e,0xd24f0003}},	//   _inbj, júcu_, ldīg, ينه_
  { {0xdce6007a,0x7d1b007a,0x60f80014,0x660d000e}},	//   mokė, _gaus, хния_, őnké
  { {0x67020037,0x6f1c11f7,0x7ceb0060,0x3cfb0009}},	//   र्थक_, _karc, sörü, _קלמנ
  { {0x98af003e,0x47340001,0xa2c10037,0x7d1b013a}},	//   _mogę_, унос, रुद्, _zaus
  { {0x6e940003,0xa4d5002d,0xba170012,0x7c22228c}},	//   طلحا, лоні, _ليلا_, lvor
  { {0xb4bf0037,0xa00a0003,0xc5f3000b,0x3eb90030}},	//   ेरे_, _يقال_, סדר_, ěsta_
  { {0x18360012,0x46b20011,0x20180035,0x7d1d228d}},	//   _جراح, जशाह, āris_, rdss
  { {0x6d401880,0x6abf0037,0x2bb50037,0x36d420b2}},	//   _loma, ्रेर, ंदबा, _сокр
  { {0xa91d0133,0x7d0f000e,0xd3540012,0x2259003c}},	//   loža, pecs, جَّة, хивы_
  { {0x6d400039,0x2d68000e,0x27e9228e,0x38c40024}},	//   _noma, lően_, tran_, ищув
  { {0x58870015,0x798d00b6,0xdfd10012,0x9b450012}},	// [5ad0] тыва, rlaw, صيا_, _منظو
  { {0xa857000b,0x27e9228f,0x5b150086,0x7d1b2290}},	//   דימה_, rran_, _смот, _saus
  { {0x3ea7006f,0xc6a70015,0xcb120009,0x7db40012}},	//   änt_, траи, _פלט_, لصنا
  { {0xbd18007c,0x4518002d,0x3cff0037,0x98b3001e}},	//   кції_, кція_, ोजें_, ādēt_
  { {0xdfc60003,0x20060061,0x69da02a1,0x6b832291}},	//   _دي_, çoit_, štet, tong
  { {0x9b450012,0xfc300012,0x7afc0032,0xc2c40012}},	//   طنبو, تحم_, _örtl, ليهي
  { {0xc334000b,0x45d40015,0x6a850015,0x7d1b2292}},	//   יוס_, _восс, ылка, _taus
  { {0x6f1c0929,0xe8f92293,0x6b832294,0x41b200ae}},	//   _zarc, хли_, song, حمير
  { {0xe4750001,0x5c75035c,0xc19c0009,0x4094003c}},	//   _слањ, _слат, ושהי, ирьт
  { {0xaa0b0003,0x52bf0037,0xa2ca0037,0x7aca0011}},	//   _يزال_, ्रोस, _स्प्, _स्पॅ
  { {0x8c4200a2,0xfbdf001a,0x2ca90029,0x0f560009}},	//   _öğre, uyên_, ľadu_, ריתם_
  { {0xc692000b,0x69dc0623,0x75280035,0xab5b0032}},	//   מאי_, vsre, ēdzo, spül
  { {0xc916000b,0xf8da0009,0x68070035,0xdce2001b}},	//   _תחנת_, _נחסמ, nījā, snoć
  { {0x60080009,0xe7330012,0x291d016d,0x437504d6}},	//   _יִצְ, _خصص_, _hawa_, ауст
  { {0x44320020,0xc0e60800,0xb9b50014,0x3f852295}},	//   ̣y_, ловк, истъ, molu_
  { {0x291d00c6,0x69dc0070,0x02bf0037,0xdb080e90}},	//   _jawa_, rsre, ्रॉन, _vidé
  { {0x27ff1e7c,0x69dc0032,0xdb240097,0x6f1c2296}},	// [5ae0] ntun_, ssre, þrót, _parc
  { {0x6b4f00c5,0x6807001e,0xdfcf0003,0x2d8f2297}},	//   _søgn, dījā, سيم_, elge_
  { {0x201900c1,0xceb2000b,0x02fb000b,0xecea0593}},	//   _essi_, ציא_, _אלימ, едел_
  { {0x8936000a,0x25ad0362,0x7c222298,0xa2c10011}},	//   _إعدا, _ciel_, tvor, रुस्
  { {0x43460014,0x0b8a0e0f,0x938a0146,0x4432001a}},	//   ледв, нски_, нска_, ãy_
  { {0x8c430046,0x6d40002a,0x2bb70011,0x7c222299}},	//   сеље, _woma, _इंसा, rvor
  { {0x2be00044,0xbae5002d,0x27410066,0x39420692}},	//   _निका, рцій, _méně_, _koks_
  { {0xdb01000f,0x6d40004a,0xa3e50037,0xba9b0009}},	//   _vilá, _uoma, _पटल_, עסקי
  { {0x2d68000e,0xed5701ef,0x9f54046d,0xcaf60012}},	//   tően_, _сот_, ивич, _مساب
  { {0x3817000b,0x25ad0480,0x57fb0009,0x394d0132}},	//   נקים_, _ziel_, עליו, akes_
  { {0x1d35007c,0xd5b70047,0x64400006,0xa37b0017}},	//   ання, лся_, ämin, nsõe
  { {0x291d002c,0xc8b60003,0xde220024,0x9f52008e}},	//   _gawa_, _إصاب, рсiя_, ltyä_
  { {0xfd1f00b8,0x6b4b005e,0x765a0034,0xbca50012}},	//   rdì_, _hügi, szty, شمسي
  { {0x77f70093,0x9097002d,0x6b4f0058,0x40930003}},	//   _עמוד_, _світ_, _nøgl, _الهر
  { {0x31c40406,0xa143001e,0x659506a5,0xf9930012}},	//   йств, _šķir, _каку, مبر_
  { {0x26190011,0x9f52008e,0x24890034,0x3915004c}},	//   _बनती_, htyä_, żami_, јмар
  { {0xc05b007c,0x69c70027,0x2be00011,0x6d8c0009}},	// [5af0] хів_, spje, _निगा, _אָזְ
  { {0x613c000f,0xbebc001e,0x4c9c0009,0x69c70031}},	//   _célz, ldīb, _אבחו, ppje
  { {0xb7c3007d,0x2d6f0066,0x442900d9,0xf7700012}},	//   ăţil, před_, _hra_, ساك_
  { {0x6807001e,0x2be00011,0xa37b005e,0x2d8f005e}},	//   tījā, _निखा, ssõd, ulge_
  { {0x25ad0347,0xa3cf0011,0x3f850060,0x8d780009}},	//   _viel_, वीं_, yolu_, נגדו_
  { {0x02c2002d,0x03a509cc,0x3bbc0009,0xe3b00012}},	//   ойшо, шило, עמוד, سره_
  { {0x6807001e,0x26140011,0x877a0009,0x61e10031}},	//   sījā, _फैली_, _יאשי, állh
  { {0x600902e2,0x3fe5096e,0x7d040051,0x27ff229a}},	//   вним_, ажив, õist, ttun_
  { {0xdb160020,0x67020037,0xe8d8000b,0xcd280012}},	//   _duyê, र्वक_, אוחר_, _حسّن_
  { {0x69c50036,0x753d003e,0x9397000a,0x20d3001a}},	//   _othe, ejsz, _إجرا, ải_
  { {0xbd460003,0x644b0010,0xfe710003,0x539a0009}},	//   لندي, lygi, تدة_, _סיעו
  { {0xe1f00003,0x6d5a0010,0x4429013e,0x3f85229b}},	//   _رسم_, _įtak, _bra_, solu_
  { {0x9984000a,0xa01b004a,0x06f70011,0x60cd229c}},	//   _النو, _myös, ुभाव_, dbam
  { {0xfbb60009,0x4429229d,0x46a503b0,0xbebc0035}},	//   יפשת_, _dra_, _калв, adīb
  { {0x29d3007d,0xc5d5007c,0x82a6002d,0x6369001b}},	//   nţa_, _тіль, равж, ažno
  { {0x867a0093,0xdb16001a,0x4429229e,0x1c46005c}},	//   _ברצו, _xuyê, _fra_, _вним
  { {0x657d000f,0xad1b0009,0xeab20012,0x9f52008e}},	// [5b00] érhe, _יוקר, _وعد_, ytyä_
  { {0x6d440051,0xf6520012,0xc49b0009,0x656b0132}},	//   _hoia, يئا_, _בשפת, eigh
  { {0x67020044,0x27ed008b,0x2fc90101,0xa01b0006}},	//   र्षक_, hren_, apag_, _syöt
  { {0x4429039c,0xa37b0149,0x91bb000b,0x6d59002a}},	//   _yra_, rsõe, _שמכי, ghwa
  { {0xa37b0149,0x9f520006,0x6b4b0051,0x201c0035}},	//   ssõe, ttyä_, _sügi, āvis_
  { {0x67020037,0x23e50024,0x8af70024,0x6b460097}},	//   र्शक_, сіїв, иніс_, _aðgr
  { {0x9f52004a,0x27ed229f,0x27e022a0,0xd3370009}},	//   rtyä_, eren_, lsin_, ירסה_
  { {0xdb160020,0xa01b004a,0x9f52004a,0x26d80f66}},	//   _quyê, _työt, styä_, _hero_
  { {0x27e022a1,0x57b3003c,0xdce9001b,0x6440008e}},	//   nsin_, обыт, _sjeć, ämil
  { {0x27e00006,0xa91d009b,0xabfb0009,0xf7720012}},	//   isin_, ložl, _בהמר, تاع_
  { {0xe8fa007c,0xdb160020,0x56b70009,0x6b500248}},	//   _але_, _tuyê, יפין_, _vägl
  { {0xa2ca0037,0x99750015,0x69ca0052,0xdcbb0014}},	//   _स्त्, _лучш, mpfe, ъщо_
  { {0x7d01000e,0x6b500052,0x534700ef,0x2d6f0030}},	//   láró, _tägl, ахва, třeb_
  { {0xf413000b,0x9f5f0028,0x442622a2,0x656b22a3}},	//   חפש_, _ærðu_, ivo_, zigh
  { {0x4f9b000b,0xe1670001,0x6dac003a,0x9f9b000b}},	//   _שבוצ, ађан, _aşam, _שסופ
  { {0x442922a4,0x7657000b,0x44260027,0x04670024}},	//   _tra_, _כבוד_, kvo_, _втом
  { {0x90990014,0xd6db0024,0x656b22a5,0x7d7c0009}},	// [5b10] уват_, вте_, vigh, _שנחו
  { {0xcdd4000b,0x26d80164,0xbf020011,0x441c0009}},	//   ֶךְ_, _cero_, र्लभ_, _יוחס
  { {0x4b7c000b,0x60db0061,0x7d01000e,0x69c522a6}},	//   _באזו, yaum, járó, _uthe
  { {0xfe370009,0x61f50060,0xeb9f0040,0x7c2922a7}},	//   ירבי_, muzl, stød_, _prer
  { {0x27e0004a,0xd7e4002d,0x44290d85,0x1d0c0009}},	//   csin_, _міро, ía_, דּוּ
  { {0xab64002d,0xb8ca0037,0x1b7b0003,0x9e35003c}},	//   овіл, गे_, خصصة_, _легч
  { {0x4426007a,0x9207001e,0xa01b004a,0x61f5003a}},	//   avo_, ksāš, _työs, nuzl
  { {0x9915007c,0xfa78000b,0x9a78000b,0xd24e0003}},	//   ські, יעות_, יתוף_, عني_
  { {0xccf20093,0x27ed00bd,0xe1640003,0xc6f90009}},	//   _מכן_, uren_, تدوي, ְלֹך
  { {0x6d5a0073,0x7d010031,0x27ed22a8,0x26c10f11}},	//   _įtai, báró, rren_, ncho_
  { {0x2295000a,0xaa950003,0xb87b0066,0x2f540024}},	//   _الاس, _الاث, _sdíl, ітьс
  { {0x6e36000b,0x05560406,0x27e0004a,0x8d560a41}},	//   צטרף_, стоя, ysin_, сточ
  { {0x69c10066,0x251a0009,0x4087004c,0x80cd0011}},	//   ílen, נושא, _тужб, _ध्ये
  { {0xaa460001,0xe4520009,0xe3b10012,0x4c9a0009}},	//   бегл, פֶר_, ِرِ_, טברו
  { {0x661c00c5,0x7f3a0009,0x27e0008e,0x154622a9}},	//   ærkt, _תעצו, wsin_, _гейм
  { {0x26c101e3,0x44260073,0x31bc017a,0xa5650012}},	//   echo_, yvo_, _víz_, _ودين
  { {0x41270098,0x26d822aa,0x937a0003,0xed57000b}},	// [5b20] щото_, _pero_, _مصدر_, _לבקר_
  { {0x66f90037,0x20e8001a,0xa01b004a,0x79890227}},	//   ्भिक_, ởi_, _pyör, hoew
  { {0x26d822ab,0xa2b70009,0x02b70009,0x27e022ac}},	//   _vero_, _לפיד_, _להים_, ssin_
  { {0x38bd000e,0x7589002d,0xdb080042,0x7d010031}},	//   _váró_, асів_, _vidí, váró
  { {0x9f40004a,0x442622ad,0x1ab401b6,0xc9530009}},	//   triä_, uvo_, обля, _זמר_
  { {0x8c1b000b,0x7d01000e,0xdfcf0012,0xa01b008e}},	//   טוני, táró, _سيف_, _työr
  { {0x316d0108,0xcb13000b,0x9f5f0061,0x46db0011}},	//   fiez_, פלה_, ctué_, _मज़ह
  { {0xbce50012,0xd2590024,0x69ca0032,0x20540048}},	//   _وأقو, шці_, rpfe, жкия
  { {0xeafa0003,0x7d01000e,0x4cbb000b,0x9f490028}},	//   _مرات_, sáró, _תזמו, otað_
  { {0x501b000b,0x5457000b,0x9f490028,0x25a01247}},	//   נויו, _הסמן_, ntað_, _ahil_
  { {0xab5b0018,0x6f230012,0x15150700,0x2f3b00af}},	//   nqüe, سَّن, одня, אגיד
  { {0x0697000b,0x9f47022d,0x614301b6,0xbcfb0031}},	//   מדים_, čné_, _неха, lnéz
  { {0xa3d30044,0xb19b0009,0x58960012,0x219b0009}},	//   हीं_, _עידכ, _اجاز, _עבדא
  { {0x661c00c5,0x96ba0447,0x38170009,0x70170009}},	//   ærks, _суду_, _לקדם_, _לחדד_
  { {0x39460005,0x6d9d0061,0x17970009,0x4f650012}},	//   _koos_, réab, _הדגל_, _بانف
  { {0x26de18a1,0xc5170012,0xe5f70009,0x99e40064}},	//   lato_, _طبعت, _הזהר_, ýňat
  { {0x57b40472,0x656f22ae,0x20040064,0x7d0d020d}},	// [5b30] збут, mich, ntmi_, _ibas
  { {0x656f22af,0x26de1d13,0x2d8b00b8,0x26c122b0}},	//   lich, nato_, loce_, ucho_
  { {0x46150003,0x7c21001e,0x8f9b0009,0x656f00b8}},	//   توار, ālru, ניבי, oich
  { {0xbcfb0108,0x2d8b07ca,0x656f22b1,0x26c10032}},	//   ciét, noce_, nich, scho_
  { {0x69c8001e,0xdce6001e,0xdb1d00e5,0x316d0025}},	//   _atde, nikā, ppsä, viez_
  { {0x656f008b,0xbcfb000e,0x2d68000e,0x7528001e}},	//   hich, gnéz, tőek_, ēdzi
  { {0x656f0002,0x99850003,0x7e280024,0x316d0025}},	//   kich, يلتو, _літа_, tiez_
  { {0x656f0066,0xbfc50014,0x7c2d06d5,0x47c50264}},	//   jich, обик, _orar, обив
  { {0x5fe20044,0xa91d0107,0x316d0061,0xcf390024}},	//   _पिछल, ložk, riez_, ачні_
  { {0x26de00c1,0xddc8000e,0x656f0052,0x8e090247}},	//   gato_, ezdő, eich, анов_
  { {0xe57a0014,0x656f22b2,0x316d0061,0xa15902e3}},	//   изо_, fich, piez_, _кажу_
  { {0xdb0d014d,0xdce60039,0x656f04a1,0x34aa0bda}},	//   _stað, fikā, gich, ивно_
  { {0x63bb0051,0x80270012,0xf4960012,0x351a0009}},	//   _juun, _درام, تشدد, בורנ
  { {0x26de01a2,0x1639000a,0x7d0d0051,0x63bb00e6}},	//   cato_, _نسبة_, _ebas, _muun
  { {0x99e90009,0x01e90009,0x68fb005e,0x81aa0012}},	//   יַּ֥, יַּֽ, ogud, لطرف_
  { {0xae78002d,0x644f0002,0x6d5d1bd0,0x442d22b3}},	//   _усіх_, byci, chsa, _ore_
  { {0x92b60003,0xbcfb0061,0x0fda003c,0x97da003c}},	// [5b40] _وحدا, riét, рьбы_, рьбу_
  { {0x44200605,0xfe720003,0x6723051f,0xa696004c}},	//   _isi_, ودا_, _janj, ореј
  { {0x442d22b4,0x8d66002d,0x6723080a,0xa2b90011}},	//   _are_, овже, _manj, ्डर्
  { {0x629e012e,0xa01b004a,0x9f490028,0x672300b6}},	//   _izpo, _työp, stað_, _lanj
  { {0x2480003a,0xbcfb000e,0x44200066,0x5c160012}},	//   çim_, tnéz, _jsi_, تظار
  { {0xbb430001,0x672322b5,0xb2ba0009,0xf9c60024}},	//   дељк, _nanj, ׁמְר, ощин
  { {0x644f003e,0x26de01a2,0xde03002d,0xa37b0051}},	//   zyci, vato_, _опри, ksõn
  { {0xb3ea0012,0x79680034,0x7524001b,0x96d80011}},	//   _نعطل_, oświ, _naiz, यरवॉ
  { {0x26de01a2,0xb0a40037,0xc05a002d,0xb4e60037}},	//   tato_, खेंग, рій_, पणी_
  { {0x8c1b000b,0xfa360003,0xf093000b,0x1037000b}},	//   _דומי, _وراد, ונח_, קטים_
  { {0xb4ab0028,0x26de1d13,0x20040121,0x656f22b6}},	//   _íþró, rato_, stmi_, tich
  { {0x7c2d0010,0xd00a002d,0x26de22b7,0x89a50012}},	//   _prar, _веде_, sato_, _فإنم
  { {0x98b3001e,0x3e55001a,0x656f22b8,0x26de152c}},	//   ādīt_, át_, rich, pato_
  { {0x656f22b9,0x79680002,0xdce6001e,0x2d8b1396}},	//   sich, dświ, rikā, soce_
  { {0xbcfb0061,0x316b0001,0x2bb70011,0x72280024}},	//   théd, ашао_, _इंका, оцтв_
  { {0x3f8c0039,0x98b90001,0x672301cd,0xb1a40024}},	//   lodu_, слат_, _zanj, дшук
  { {0x656d0101,0xcebb004c,0x10040048,0xe894003c}},	// [5b50] _imah, аље_, дяхм, дать
  { {0x4e1e0037,0x8af90001,0xf4140009,0x68e0016d}},	//   _बनाई_, _унос_, _חפץ_, hamd
  { {0x63bb02bd,0x7bc90347,0x672500b0,0xa1950635}},	//   _suun, _steu, rdhj, _наоч
  { {0x442d22ba,0xa4d40024,0x621a0009,0x63bb008e}},	//   _pre_, доці, _פורק, _puun
  { {0xbcfb0061,0x9f400164,0x69da000d,0x493a0009}},	//   chée, guió_, âtev, _הגרו
  { {0x8b220063,0x77ba0009,0x4fd60009,0x6440008e}},	//   едше, _למשח, _מושב_, ämii
  { {0x7de0000e,0x94d50001,0xa4d5002d,0x60dd003a}},	//   _vásá, _новц, _нові, _kesm
  { {0xceb2000b,0xa0090003,0xf27c000b,0x6b500051}},	//   _טים_, مقبل_, ירוש, _vägi
  { {0x60dd0149,0x672300b6,0x69c10066,0xa3b40037}},	//   _mesm, _panj, ílej, _जूझ_
  { {0xdc88000b,0xf8b80037,0x70b80011,0x7d190034}},	//   _וְעָ, _अल्प, _अल्ल, lews
  { {0xc7b40093,0x672300eb,0xaa890012,0xa37b005e}},	//   ובץ_, _vanj, _انضم_, tsõn
  { {0x7968003e,0x670b0037,0x070b0037,0x68e0000d}},	//   yświ, स्तक_, स्तव_, camd
  { {0x7524007a,0x9f35002d,0x58ba0009,0x88ba01b0}},	//   _vaiz, _неді, _המנצ, _המנז
  { {0x4420012e,0xa37b005e,0x3b0a004c,0xef180035}},	//   _vsi_, ssõn, љево_, ceļ_
  { {0xc3320093,0x44200002,0xb87b0164,0x60c40027}},	//   עול_, _wsi_, _leíd, tcim
  { {0x27f2003e,0x21670800,0xdfd20003,0x47c6002d}},	//   tryn_, писи_, فير_, збав
  { {0xb4d80037,0x442022bb,0x46ea0024,0x1dd70011}},	// [5b60] िरी_, _usi_, йдан_, भीरत
  { {0xf772000a,0x60dd0005,0x1eaa000a,0xd7ef0003}},	//   راء_, _eesm, ماضي_, اكل_
  { {0x7abb000b,0x98a20010,0xa2bb000b,0xddcb003a}},	//   _לציו, _tokį_, _למיט, ğişk
  { {0x3569002d,0xeeeb001a,0x6d9d0061,0xad650012}},	//   орін_, _đụng_, héan, وانه
  { {0x6d420006,0x5bc60012,0x999e0073,0x68b70009}},	//   rjoa, ستشف, štų_, _מלכא_
  { {0x67030044,0x421a0003,0x6d5b1181,0xac970012}},	//   _लायक_, مزعج_, _elua, أنها_
  { {0x3f8c22bc,0x68e00060,0xc8790060,0x7c2b0248}},	//   vodu_, tamd, vaşa_, avgr
  { {0x867b000b,0x3f8c0002,0xd91a002d,0xf67b0009}},	//   _הרלו, wodu_, ськ_, _האלמ
  { {0x7ff60003,0x68e0002c,0x48140024,0xb4ca0011}},	//   أسعا, ramd, ємос, ोरी_
  { {0x20ec0020,0xe2920003,0x3eb800e2,0x2d830030}},	//   ới_, _كذا_, ørt_, čkem_
  { {0xd6d70047,0xf5e30024,0x3f8c01b2,0xd9f005f3}},	//   чты_, ніям, rodu_, _घटित_
  { {0xd5b70015,0x19bb0009,0xc1bb0009,0x49bb0009}},	//   ясь_, _המאב, _המאש, _המאס
  { {0x60dd045b,0xe3b30012,0xe4a4003c,0xdb070031}},	//   _resm, فرس_, ерро, lmjé
  { {0x501b0009,0xde580024,0x7bcb0009,0x7d190a89}},	//   _לודו, _малі_, מֶלֶ, zews
  { {0xa195002d,0xf402000d,0x60dd013a,0xfaa90012}},	//   давч, luţă_, _pesm, زهري_
  { {0x9f470013,0xf67b000b,0x867b0009,0x99990024}},	//   ční_, _לאומ, _לרוו, ікат_
  { {0x57b500ac,0x5c740048,0xb8d50011,0xa91d0073}},	// [5b70] дбат, _плът, _छः_, uoži
  { {0xb8f40037,0x64d50037,0xdef10012,0xa91d0737}},	//   _स्_, दर्श, ئًا_, roži
  { {0x7d190002,0x6d5a0010,0x74b90048,0x657d22bd}},	//   tews, _įtar, оулс_, onsh
  { {0xceb3000b,0xaffd0024,0xa91d0064,0xcc9905c8}},	//   גיע_, _комi, poži, овец_
  { {0xa4b8000b,0x74290012,0xfdf90011,0xd59c0009}},	//   פלגה_, تكشف_, _ऍमऍस_, זבאל
  { {0x20090010,0x883a0009,0x26c5005e,0xfbd00012}},	//   mtai_, _ותשו, _ülo_, اتن_
  { {0x6fd50044,0x22540029,0xc9a90015,0xd567137b}},	//   _मौजू, _čaká_, овке_, _етап
  { {0x3238000b,0x394b0054,0x21290a12,0x17c9004d}},	//   לטון_, _jocs_, ndah_, огии_
  { {0x98bd0002,0xf53f04a7,0x200922be,0x320706bf}},	//   _nową_, rmål_, ntai_, stny_
  { {0x2009007a,0xbebc001e,0x4ed4002d,0x85e900de}},	//   itai_, ldīj, нюют, одов_
  { {0x7ae322bf,0x7bcd0c55,0xbae40012,0x2d8f005e}},	//   mant, _atau, _سكني, ooge_
  { {0xed57002d,0x20090010,0x90550024,0x657d0991}},	//   дою_, ktai_, _овец, gnsh
  { {0xc9740003,0x05630014,0xbebc0035,0x10080012}},	//   _ثالث, твян, idīj, _فتوى_
  { {0x2d990051,0x07a40024,0x60080009,0xfaa60479}},	//   alse_, _заін, _זִקְ, даго
  { {0x6dbe0029,0x45460003,0xe56a0012,0x7ed40012}},	//   _vďak, _ينتق, _ومتى_, _أزها
  { {0x69950024,0x6d9d0025,0xceb20009,0xd5b80035}},	//   ерух, néal, _ביו_, avās_
  { {0x60dd0028,0x75c80030,0xdee60148,0xd0070373}},	// [5b80] ósmy, _věze, дози, мете_
  { {0xef170047,0x7ae322c0,0xaf9a0024,0x1bf70009}},	//   мму_, jant, ітах_, _קציר_
  { {0x5b570009,0xd5b20003,0xe5c5002d,0x9d460014}},	//   _חייב_, نفط_, есіо, межд
  { {0x6d4609d2,0xd7ca0012,0x61fc05be,0x2d8f22c1}},	//   njka, _ووجه_, murl, goge_
  { {0x6b540054,0x6c1a0012,0xd38a0472,0xdb010030}},	//   _hàgi, تتاح_, ойде_, _zhlé
  { {0xbebc001e,0x68e422c2,0xd5d60012,0xa9c60012}},	//   adīj, laid, _يتأث, وزبو
  { {0xcb130009,0x2900005e,0xddc80034,0x61fc1dcb}},	//   דלו_, ogia_, zydł, nurl
  { {0x6b4f0058,0x290022c3,0xbea30a41,0x2d8f01e3}},	//   _søgt, ngia_, _раск, coge_
  { {0xe5710093,0xdb08004a,0x79a30014,0xf993000b}},	//   _עַל_, _pidä, ърше, כרה_
  { {0x0326002d,0xddc9000d,0xbb560003,0x8c170003}},	//   _іден, _înţe, _تنطب, _تيكر_
  { {0x36f7000b,0x6b50006f,0xdceb001e,0x6f1a002a}},	//   וצים_, _lägs, ligā, retc
  { {0x7bc00f3b,0xceb30009,0xf1a90012,0xbd6b0024}},	//   _kumu, כית_, _فانه_, ірне_
  { {0xdb010066,0x718b0009,0xed5f0064,0x443222c4}},	//   _shlé, _וְגַ, úžia_, _cry_
  { {0x289b0093,0x4432002a,0x889b0009,0x9f5f0060}},	//   _וידא, _dry_, _ובדי, örün_
  { {0xa294002d,0x394b0054,0xb6070042,0x44240f50}},	//   варі, _pocs_, _vaší, _lsm_
  { {0x68e40039,0x212900b6,0xc17b002d,0x290022c5}},	//   gaid, udah_, іїв_, ggia_
  { {0x7bc00039,0xc05b007c,0x44320002,0xf1940021}},	// [5b90] _numu, ців_, _gry_, тить
  { {0x70bb0037,0x20090889,0xa91d00d9,0xdce9001b}},	//   _उल्ल, rtai_, ložt, _rjeđ
  { {0xfad60093,0x2009226d,0x7afa0028,0xdceb0035}},	//   _אותך_, stai_, ótte, eigā
  { {0x7bc0002c,0x16770009,0xe5100081,0xbebc0035}},	//   _bumu, וגבל_, _lặng_, udīj
  { {0x515a0009,0x16000011,0x8d740012,0x7ee70048}},	//   _זכרו, लंडर_, خالا, _оцве
  { {0xe510001a,0x7d1d22c6,0xb7da0009,0xcef40012}},	//   _nặng_, hess, _מקשי, _لأفغ
  { {0x41b50014,0xb6070035,0xa91d0030,0x442422c7}},	//   нсит, ugšē, kožt, _esm_
  { {0xd2b80093,0xaa560003,0x8ab80009,0xc1050012}},	//   ולות_, عليا_, ולוג_, روخي
  { {0xa2ca0037,0x27e922c8,0x45240012,0x7d1d22c9}},	//   _स्क्, nsan_, _جرِّ, dess
  { {0x6b50006f,0xd7090015,0xc7d60009,0x787a0009}},	//   _lägr, чное_, עותי_, לָיו
  { {0x6dac00a2,0xcf920093,0x52380003,0x7bc00032}},	//   _işar, רטי_, _يسمح_, _zumu
  { {0x8c96002d,0xab5d0002,0x40950012,0xb88301e9}},	//   ергі, _duże, _كلار, olíč
  { {0xdfd10003,0x4424001a,0x6cfa0009,0x7ae122ca}},	//   _صيغ_, ìm_, הפרס, _kelt
  { {0x6b540663,0xfbd2000b,0xe3a70012,0xa2cb0011}},	//   _pàgi, רתם_, طر_, तुल्
  { {0x68e411d1,0x2d7801bd,0x1d96003c,0x03a3003c}},	//   taid, očet_, _приё, уиро
  { {0x64400006,0xdb010164,0xfc470066,0x44320a5f}},	//   ämis, _kiló, _klíč_, _try_
  { {0x68e40039,0xe4330003,0xd7f9002d,0x20870021}},	// [5ba0] raid, _مفيد, дує_, ейти_
  { {0x3a26002d,0xdceb001e,0x68e413f9,0xd6d20012}},	//   _змог, vigā, said, اقض_
  { {0x7bc009dc,0xeb9f0058,0xaadb000b,0x27e900b6}},	//   _sumu, ktøj_, _מחיר, asan_
  { {0x7bc0002c,0x2ee5002a,0x9f4701bd,0x75d30012}},	//   _pumu, half_, čná_, اينا
  { {0xe5050044,0xb87b0017,0x88bb0009,0xdca30ef0}},	//   ष्टि_, _veíc, _מזכי, гаци
  { {0x600b000b,0x7d1d22cb,0x93fb0009,0x2d6f0030}},	//   _מִלְ, zess, פלצי, třek_
  { {0x443f001a,0x78a2000e,0xf2d30009,0x46a30024}},	//   ̣u_, _szov, נעה_, _барв
  { {0x7bc00101,0x7ae10051,0xb6370009,0x72290024}},	//   _tumu, _eelt, _ארלס_, ьців_
  { {0x7c24003a,0x7ae122cc,0xd4300024,0x3b860024}},	//   çird, _felt, _мiсц, _злаг
  { {0x999c0010,0x7ae11b85,0x96340024,0x636d0034}},	//   tyvų_, _gelt, вноц, yźni
  { {0xa4d5002d,0x26c70027,0x7d020811,0xf5aa0009}},	//   коні, žnog_, ogos, ּבָּ
  { {0x867b0009,0x58d30024,0x27e922cd,0x63ba22ce}},	//   לריו, _боїт, ysan_, _hitn
  { {0x69c10052,0xf4840e0f,0x7c840014,0xe510001a}},	//   _zule, гурн, гуре, _tặng_
  { {0xdbc70005,0x99d70003,0x7d1d22cf,0x28b70009}},	//   _tööt, فترا, sess, _נפגש_
  { {0x22580066,0xb1a70001,0x39a70294,0x539b0009}},	//   _čeká_, ешак, ешав, פילו
  { {0x0e9b000b,0xa69b000b,0x5e9b0009,0x7e9b0009}},	//   _משול, _משופ, _מבוק, _מסוו
  { {0x442f0065,0x60dd0028,0x718b0009,0x7d020034}},	// [5bb0] _ég_, ðsmi, לְמַ, dgos
  { {0x501b0009,0xb8940012,0xb8830030,0x7d0222d0}},	//   הומו, الْع, vlíč, egos
  { {0xf7480003,0x66a90009,0x3a74003c,0xddde0034}},	//   علمي_, ֵינֶ, _блэр, ezpł
  { {0x69c122d1,0x7ae1122e,0x7ae718b7,0x15f40012}},	//   _rule, _selt, lajt, اسلح
  { {0x6fb50003,0xa37b0051,0x63ba00eb,0x69c122d2}},	//   _لمحا, esõi, _bitn, _sule
  { {0x7ae70b9c,0x39490c1a,0xe29907e6,0x6f1e0fdc}},	//   najt, ljas_, мал_, cepc
  { {0xc334000b,0x629a08ce,0xda620109,0x05770012}},	//   טוס_, _cyto, ивши, _كارد
  { {0x56940046,0x7ae1008b,0x9915002d,0x7ae70570}},	//   _саст, _welt, тькі, hajt
  { {0x7ed5002d,0x38690164,0x60060015,0x7c870001}},	//   кінч, nzar_, вным_, _чуве
  { {0x69c11140,0x7c24003a,0x63ba002c,0x7ae702a1}},	//   _tule, çire, _gitn, jajt
  { {0xa2ca0037,0xfe710012,0x3b640048,0x7ae722d3}},	//   _स्ट्, شدد_, _сътв, dajt
  { {0x212b032b,0x201900b6,0x6e3c0248,0x99d40012}},	//   _nach_, _opsi_, årba, _إتلا
  { {0x0d830c61,0x9cd60009,0x4c830024,0xa0c40012}},	//   рлян, כורה_, илюв, _إيهو
  { {0x7ae7009b,0x93fa000b,0xda660012,0x39490035}},	//   gajt, ולשי, نازي, ejas_
  { {0x27ff0006,0xf7960003,0x0219002d,0x1ae30015}},	//   luun_, _جنوب_, ніть_, росм
  { {0x7c2212db,0xf1a90012,0x6d960097,0x96270035}},	//   ywor, فاقه_, ráas, ieņē
  { {0xf577000a,0x6b5d0061,0x27ff004a,0x70b30012}},	// [5bc0] _جميع_, _règn, nuun_, لمفض
  { {0x7bfb0093,0x212b0036,0xd36f000a,0x5457000b}},	//   _קפיצ, _each_, _وهي_, _סביב_
  { {0xb87b01e3,0xcf920009,0x386915ef,0x212b22d4}},	//   _veía, סטב_, azar_, _fach_
  { {0x27ff004a,0x2027004a,0xceb2000b,0xed570dc2}},	//   kuun_, äviä_, ביב_, кох_
  { {0x6e350052,0x0b8a0103,0x14270024,0x938a0294}},	//   _erzb, мски_, віщо_, мска_
  { {0x67130037,0x9f4006fe,0xe3af0012,0xa3da0011}},	//   त्मक_, rrió_, يرو_, डीए_
  { {0xd5b2000a,0xf506057b,0x63ba081f,0x8b650012}},	//   _نفس_, _изво, _vitn, دانم
  { {0xc05a002d,0x63ba002a,0xf98f0003,0xdb0901e3}},	//   діо_, _witn, يبي_, _dueñ
  { {0xc1730093,0x19b7000a,0x59630014,0x394f002a}},	//   יחה_, خطوة_, ръща, _dogs_
  { {0x7d160013,0x63ba00bd,0x9f53003c,0x02be0011}},	//   _abys, _uitn, ивыч, ्डोन
  { {0x0f57000b,0x6b7b0009,0xee200024,0x7d1b005e}},	//   דיים_, _קרבנ, щенi_, õuso
  { {0xc693000b,0xdb160028,0x11e900ae,0xd5b803d2}},	//   יאת_, _styð, _أعلي_, кся_
  { {0x7ae701bf,0x385a0012,0x6d9d0025,0x161e0011}},	//   tajt, _تشاد_, néai, _बनकर_
  { {0x69c30031,0x3e340012,0x9e660012,0x10a30472}},	//   _ének, _مفتر, _لابن, _тичн
  { {0xe919002d,0x6d960028,0x53340001,0xda78010c}},	//   нові_, ráar, јест, вят_
  { {0x3f9e0065,0x386903eb,0xac550003,0xa2a70011}},	//   lltu_, tzar_, _منبث, टेट्
  { {0x39490051,0x4d740012,0x9715004c,0x7ae709df}},	// [5bd0] rjas_, _خطور, лмац, pajt
  { {0xf7700003,0x442922d5,0x3949005e,0x38690bce}},	//   يال_, _isa_, sjas_, rzar_
  { {0x38690002,0x752f0002,0x3a840015,0x35f5057e}},	//   szar_, odcz, _выяв, упер
  { {0x867b0009,0xeea80048,0x04c900ae,0x4a5a00af}},	//   ורבו, ттук_, روتي_, _נדרו
  { {0x7ae50005,0x24890017,0xed590027,0xdb090164}},	//   _keht, çam_, _niže_, _sueñ
  { {0x420906e6,0x27ff004a,0x59da0037,0xb464002d}},	//   енко_, vuun_, यीकर, шкіл
  { {0x69c50051,0x96f8004c,0xc879004b,0xe2150012}},	//   _juhe, _јест_, maşi_, ابتع
  { {0xc879000d,0x27ff004a,0x3abc000b,0x442900b9}},	//   laşi_, tuun_, ומונ, _osa_
  { {0xd00e0012,0x957d0034,0x60cd22d6,0x9f4007ef}},	//   كلي_, brąz, icam, orið_
  { {0xd25b0560,0x75c80030,0x200d22d7,0xed59001b}},	//   _оце_, _vězn, rtei_, _diže_
  { {0x200d007d,0x1d0a0014,0x394f006f,0x27ff008e}},	//   stei_, нени_, _togs_, suun_
  { {0xc3290009,0x27ff008e,0x925804a5,0x200d004b}},	//   _מו_, puun_, _шахт_, ptei_
  { {0x3af60024,0xe72e00db,0x60db1719,0x60cd22d8}},	//   лявс, _ле_, mbum, dcam
  { {0x752f0002,0xdce2001e,0x66e50024,0xf7490012}},	//   adcz, bloķ, _сока, _سلبي_
  { {0x6b5d0108,0xf7700003,0x442922d9,0x27ed0828}},	//   _règl, _بان_, _esa_, lsen_
  { {0x2fda0003,0xc879000d,0x98a90029,0x9f400028}},	//   فورد_, eaşi_, adač_, erið_
  { {0xc952000b,0x999e000e,0xa0670373,0xccf30009}},	// [5be0] זמן_, ítő_, гата_, _הכח_
  { {0x32460046,0x7d0922da,0x64590002,0x27ed22db}},	//   _беог, _aces, dywi, isen_
  { {0x9bb7000b,0x75d30003,0x02460012,0x67060011}},	//   _תהיה_, ميلا, _صَحَ, _शासक_
  { {0x27ed22dc,0x7c290017,0xc27b0009,0x9f400097}},	//   ksen_, _bser, _טריי, arið_
  { {0xbebc001e,0x7c29000e,0x3bf60001,0xdcef004b}},	//   ldīt, _cser, уџет, lică
  { {0x6be3000a,0x67210027,0xf4130009,0xcb340048}},	//   حكوم, jelj, צפו_, рекъ
  { {0x3d050044,0xa79b000b,0x7c2922dd,0x6721017b}},	//   _वाले_, _נשלח, _eser, delj
  { {0x41c30003,0x89380001,0xbcfb0061,0xbebc001e}},	//   حقيق, тпис_, thém, idīt
  { {0xa3cb0044,0xb6e6002d,0x6721000e,0x6d4022de}},	//   _रूप_, люнк, felj, _inma
  { {0xa8170003,0x66e40037,0x30170003,0x6ac60003}},	//   اتير_, गरिक_, اتية_, _إقام
  { {0x4906000a,0x442922df,0xba170012,0x3f7b0009}},	//   _مواق, _ssa_, _ميلا_, תאיס
  { {0xc5f80039,0x68e6009b,0x44260002,0x69c50052}},	//   dzēt_, _nekd, owo_, _ruhe
  { {0xc993000a,0xb9930003,0xfc640048,0xc7c80081}},	//   _النظ, _النب, бърн, _dốc_
  { {0xdcef007d,0x69c50006,0x4429012e,0x660122e0}},	//   fică, _puhe, _vsa_, bulk
  { {0x64590002,0xd6270001,0x9f40004a,0x471b000b}},	//   zywi, _боје_, isiä_, _נוהג
  { {0x7aea008b,0xc7c8001a,0x29ca001a,0x78d50048}},	//   haft, _gốc_, _mùa_, ржах
  { {0x9f4022e1,0xed58000b,0x765a004a,0x7ae507f6}},	// [5bf0] ksiä_, _תבחר_, lyty, _teht
  { {0xa857000b,0xe8740003,0xf7730012,0xb2750048}},	//   אימה_, حافظ, حار_, _влош
  { {0x539c000b,0x57a4027f,0xe4d50012,0xc879004b}},	//   _איזו, сшта, لقاد, raşi_
  { {0xeb1d0044,0x60c200b6,0xbebc0035,0x25f80012}},	//   फ़्त_, _ngom, ldīs, اءلة_
  { {0x3b090538,0xbcfb0025,0x88bd0034,0x6d8c0009}},	//   вело_, ckée, ieśc, עָבְ
  { {0x57fa000b,0x6ffa0009,0xe3b30012,0xd7fa0009}},	//   _בלשו, _בהשפ, حرص_, _בהשל
  { {0x67211dc0,0xf8e00037,0x66180029,0xcb660024}},	//   velj, नरूप, čaká, раще_
  { {0x8e840012,0xfa780009,0x765a031c,0x27ed22e2}},	//   _الفه, טעות_, dyty, tsen_
  { {0x84670098,0x672122e3,0x7c2922e4,0xf7710012}},	//   _съве, telj, _user, قاد_
  { {0xf7710003,0xa858000b,0x27ed22e5,0xb8fc0011}},	//   تاب_, טיחה_, rsen_, _त्_
  { {0xc5f80039,0xbea50469,0x8d760012,0x46a50048}},	//   dzēs_, ранк, لاحا, ранв
  { {0x6721013a,0xa3a90011,0x9c660012,0x8e960009}},	//   selj, _गीत_, لهجو, ידתו_
  { {0x672122e6,0x66010c55,0x6ea10011,0xe50d0011}},	//   pelj, sulk, _ऑरकु, _हानि_
  { {0x394d000f,0x98a20002,0x8caa0011,0xa2d80011}},	//   ljes_, _jaką_, जेटो, नुप्
  { {0x09e606e6,0xc7c8001a,0xbebc001e,0x2d8b0061}},	//   робн, _tốc_, udīt, ébec_
  { {0x395f0010,0xc5f8001e,0x629e01bd,0x261a0011}},	//   nkus_, rzēt_, _vypo, _बहती_

  { {0x629e0002,0x6fb60003,0x41270048,0x386d22e7}},	// [5c00] _wypo, لمرا, шото_, nzer_
  { {0x7c29003a,0x395f0051,0xfc5b0009,0x629e22e8}},	//   çere, hkus_, _סכימ, _typo
  { {0x395f0051,0x394d0070,0x59a70037,0x42fb000b}},	//   kkus_, kjes_, _कीवर, _בהיס
  { {0xe45a0047,0xf1bf0020,0x4426003e,0x3cc90009}},	//   кже_, _giá_, two_, ְלוּ_
  { {0x386d0070,0x765a0002,0xead40021,0x394d06e7}},	//   jzer_, zyty, боль, djes_
  { {0xdce6003a,0x21f40012,0x765a008e,0x88bd0034}},	//   ımın, مكتس, yyty, ześc
  { {0x636b0052,0x99660001,0x63030012,0x25bf004b}},	//   _fünf, итил, زويل, _fiul_
  { {0x25d70009,0x6d40036c,0x765a008e,0x67130011}},	//   _כולן_, _unma, vyty, त्सक_
  { {0xed570015,0x7f9d0061,0xa4fb000b,0x34fb0009}},	//   _тот_, hèqu, _שלמט, _שהמד
  { {0x3817000b,0x200b0054,0x394d01e3,0xf7760009}},	//   סקים_, àcia_, ajes_, יעִי_
  { {0x0737000b,0xd6860015,0x386d0017,0x68fd0010}},	//   באים_, рупп, azer_, ųsda
  { {0x79530003,0xc27b0009,0x765a0034,0x614302ab}},	//   _وَلا, _ברבי, ryty, _меха
  { {0xd0070098,0x9f470026,0xda020037,0x765a004a}},	//   _вече_, čnú_, रूरत_, syty
  { {0x27170066,0x93880015,0x200422e9,0xdb230060}},	//   _mění_, асса_, mumi_, _örün
  { {0x22b80003,0x7ae822ea,0x96b7004c,0xaa54004c}},	//   لدفع_, _medt, _кућу_, оврш
  { {0x69c81835,0x4dd30012,0x644d008e,0xeeeb0081}},	//   _mude, _بتوس, äaik, _đựng_
  { {0xb4e30011,0x7f070024,0x2d9922eb,0x4034003c}},	// [5c10] धरी_, иїжд, mose_, оетс
  { {0x69c80070,0xc7d7000b,0x657d22ec,0x7c2d0115}},	//   _oude, יומי_, lish, _isar
  { {0x75d3000d,0xcf93000b,0xd3380009,0xf7700012}},	//   _găzd, קטע_, _כרזה_, ذاك_
  { {0x20040039,0xe5700003,0x657d22ed,0xbbf50012}},	//   kumi_, وطن_, nish, مستث
  { {0x20040039,0xb8dd0037,0xdc98002d,0x0136000b}},	//   jumi_, ेख_, авці_, _פרשת_
  { {0xc5fb0003,0x68ed13f9,0x69c81e06,0x28b60009}},	//   _لعرض_, laad, _bude, _לפרש_
  { {0x0a6b0014,0x394d0070,0x2d990010,0x926b0048}},	//   ърди_, tjes_, kose_, ърда_
  { {0x386d008b,0x248d003e,0xf5e4002d,0x2d990010}},	//   tzer_, żemy_, _фірм, jose_
  { {0x256202d1,0x249f003a,0x395f0154,0x98a20002}},	//   _sólo_, _uyum_, rkus_, _taką_
  { {0x645d0010,0x442d22ee,0x386d0052,0x1f650760}},	//   dysi, _ise_, rzer_, ском
  { {0x386d000f,0x68ed0051,0x636b1711,0x394d0227}},	//   szer_, kaad, _münd, pjes_
  { {0x01340003,0x2d990010,0xc27a000b,0x89340003}},	//   _وعند, gose_, _גרעי, _وعنا
  { {0x69c80052,0x68ed0051,0x7bc901a0,0x7bc122ef}},	//   _zude, daad, _jueu, _kilu
  { {0x1dcf0037,0x4fd6000b,0x289a000b,0x6605016d}},	//   _संपत, _הוסב_, _גינא, kuhk
  { {0x7d1b01ae,0x7bc90025,0xa96a0048,0x2d991cdb}},	//   _obus, _lueu, гива_, bose_
  { {0x2012004a,0xfdf60009,0x67130011,0xc4fa0012}},	//   ttyi_, _המקש_, त्रक_, _صعبا_
  { {0x80aa002d,0x65a30051,0x636b0052,0x6d9d0025}},	// [5c20] ував_, põhj, _bünd, réat
  { {0x73060046,0x2012008e,0x67250040,0x7bc122f0}},	//   _упоз, rtyi_, gehj, _nilu
  { {0xb3bb000b,0x6d56003a,0xceb2000b,0x2012004a}},	//   _תמיכ, _koya, ִיד_, styi_
  { {0xe4e3002d,0x2364001e,0xdb1b0028,0xdd99002d}},	//   пішн, īmju_, _stuð, аші_
  { {0x31370009,0x59830048,0x69c822f1,0x6d5622f2}},	//   _הנכם_, _хляб, _sude, _moya
  { {0x636b003a,0xc7c8001a,0x2004001e,0x69dc22f3}},	//   _günd, _bốn_, vumi_, opre
  { {0x442d02d1,0x6a130003,0x645d0002,0x7bc10cfc}},	//   _ese_, كبير, zysi, _dilu
  { {0xf12600bc,0xdfd0000a,0x7bc1007a,0x4420001d}},	//   сько, ويب_, _eilu, _opi_
  { {0x96ea00c0,0xdce90027,0x7bc90d65,0x6fb40012}},	//   льна_, _smeć, _gueu, يمبا
  { {0xfe0c0037,0x0857000b,0x69c822f4,0x96f8004c}},	//   _हमास_, צבים_, _tude, јент_
  { {0x69c80006,0xa3be0037,0x2d990010,0xa3e40037}},	//   _uude, ेदन_, tose_, भीर_
  { {0x645d007a,0xc4e30037,0x2d990010,0x27f2004a}},	//   tysi, परेख, uose_, ksyn_
  { {0x68ed0051,0x6d440002,0x3f9a001e,0x657d0611}},	//   vaad, _dnia, kopu_, rish
  { {0x2d990010,0xab870024,0x5fb40012,0x645d22f5}},	//   sose_, сумк, _بمتط, rysi
  { {0xa77b000b,0xa9f8000b,0x20000899,0xb77b0009}},	//   _תרופ, יִּת, erii_, _תאוש
  { {0xc1050003,0x636b12c3,0x5ea30012,0x984b0048}},	//   توري, _sünd, _عميل, ляза_
  { {0xb8d10044,0x47d50003,0x2d870066,0x9f5502e3}},	// [5c30] _ओर_, زيار, énem_, овач
  { {0x660500c6,0x68ed0051,0x80d90321,0x7bdd068b}},	//   tuhk, saad, _फ्रे, mpsu
  { {0xa535002d,0x442d1835,0xbfa80048,0xeeab004c}},	//   жнеч, _sse_, стте_, утак_
  { {0xe7ed0011,0x47d50012,0xbfd50012,0x85040012}},	//   _चौथा_, _ويجر, _ويجع, كومن
  { {0xe3b10003,0xd0060012,0x8c420060,0x7bc922f6}},	//   ورت_, _تل_, _öğle, _queu
  { {0x442d012e,0x889a000b,0x76450028,0x66050051}},	//   _vse_, _כברי, _áhyg, puhk
  { {0x636b003a,0x6d4d005e,0x93940012,0xfa690024}},	//   _güne, öaas, أجنا, райк_
  { {0xc7c8001a,0x7bc90025,0x5d650012,0x3495004c}},	//   _vốn_, _tueu, _بُرْ, _дабр
  { {0x442d22f7,0x6d5622f8,0x636b0031,0x5f750012}},	//   _use_, _roya, _züne, قادر
  { {0x2d8b000f,0xd7750003,0xc7c8001a,0x75d3000d}},	//   ében_, تابع, _tốn_, _răzb
  { {0xaa670001,0x16a905fb,0xda020011,0x2f540024}},	//   _утак, рвни_, रूआत_, їтьс
  { {0x69dc012e,0x35d00011,0x18cb0012,0xf5320009}},	//   vpre, _तूफ़, _إذاً_, ֵ֥ר_
  { {0x9f35002d,0x316d000e,0x6d560ebe,0x6fa90011}},	//   _меді, mhez_, _voya, कतां
  { {0xfbd20093,0x316d000e,0x69dc073a,0x8bac0009}},	//   ותך_, lhez_, tpre, ָׁלִ
  { {0xa3cb0037,0xbcfb000e,0x6569016d,0x53a30024}},	//   _रूस_, mkén, _oleh, фарб
  { {0x316d000e,0xdce4080f,0xe0da0373,0x98aa0034}},	//   nhez_, _klič, рва_, śbą_
  { {0x88bd003e,0x06ea0001,0x316d000e,0x8eea0024}},	// [5c40] ześn, имак_, ihez_, имав_
  { {0xbf870020,0xbcfb000f,0x799b0070,0x7c24003a}},	//   _điện_, nkén, houw, çirm
  { {0x316d000f,0x2018007d,0x64410039,0x67190037}},	//   khez_, ării_, ālie, न्धक_
  { {0x361a000b,0x96da0037,0x16aa0011,0x68eb001b}},	//   יועד, _प्रॉ, _करीब, _negd
  { {0xead400e3,0x6b9c0070,0xbcfb0031,0x316d0031}},	//   поль, oorg, kkén, dhez_
  { {0x47c30098,0x69c30061,0x6562015e,0x9377002d}},	//   _обяв, _éner, skoh, обіт_
  { {0xe1ef0003,0x416a0001,0xbcfb0031,0x29e80f75}},	//   نسي_, ијим_, dkén, nşa_
  { {0x298a0001,0xf3da0012,0xdced001b,0x316d22f9}},	//   јско_, _نورث_, _imać, ghez_
  { {0xf74a007c,0x7f4a002d,0x6b9c006f,0xe726002d}},	//   аїни_, аїна_, korg, оєнн
  { {0x25620028,0x54570009,0x636b22fa,0x7c2d0018}},	//   _fólk_, _וסמן_, _münc, çare
  { {0xe8a70044,0x799b0070,0x52860003,0x7f3b0009}},	//   _खर्च, bouw, _بلاك, בעיו
  { {0x68460003,0x316d0061,0x3d27002d,0xdb1a004b}},	//   _وَال, chez_, цьов, _uitâ
  { {0xccf3000b,0xd5b80109,0x0cab0345,0x94ab064d}},	//   וכר_, юсь_, ртни_, ртна_
  { {0xa3b00044,0x99d70003,0xdf370012,0x7bdd0035}},	//   _टीम_, قترا, _وكنت_, rpsu
  { {0x2d8722fb,0xd1bb0003,0x67280027,0x81890012}},	//   ének_, لارا_, medj, منسق_
  { {0x65a30051,0x672822fc,0x9bf50048,0x34950198}},	//   põhi, ledj, _езич, _найр
  { {0x26c70b9c,0x58050012,0xb4d70011,0x6b9c22fd}},	// [5c50] žnom_, ثوذك, िडी_, borg
  { {0xb9020037,0x69da1624,0x57b40024,0x6b9c00b8}},	//   _न्_, _otte, дбут, corg
  { {0xcb12000b,0x8f9b0009,0x5f740012,0x6608005e}},	//   _אלי_, סיבי, ذاكر, nudk
  { {0xf653000b,0x8d740003,0xc4f80012,0xd2b60009}},	//   וצע_, وانا, قعها_, _מלתת_
  { {0x636b00a2,0xb4270003,0x44270003,0x14190003}},	//   _günc, تعاو, تراف, صيغة_
  { {0x39460149,0x3c1e001e,0xd8ba000b,0xc5db0003}},	//   _anos_, dāvā_, _לצרכ, _نظرا_
  { {0xaa560001,0x316d000e,0x660800b6,0x1df80015}},	//   зију_, thez_, judk, _меры_
  { {0x6b9c009a,0x2bcb0011,0x3cf80012,0x657b020d}},	//   zorg, ाददा, _وعقد_, _umuh
  { {0x443922fe,0x7ff50003,0x799b0070,0x2d9d0002}},	//   _és_, أسبا, rouw, mowe_
  { {0x316d000f,0x2d9d0002,0x395912de,0x2d8b22ff}},	//   shez_, lowe_, _loss_, ence_
  { {0x6b9c1711,0x63701ad3,0xada60048,0xdb030031}},	//   vorg, _häng, занл, jlné
  { {0xbcfb000e,0x2d9d0002,0x32360009,0xca360009}},	//   skén, nowe_, _מטען_, _מנעה_
  { {0x98a70066,0x33d5002d,0x160d0011,0x29d10097}},	//   ěně_, діст, ांडर_, _háa_
  { {0xd00e000a,0x0056000b,0x69da14b5,0x63701a7d}},	//   _صلى_, _משנת_, _ytte, _mäng
  { {0x88bd003e,0x62650003,0x0a390015,0x637018c2}},	//   ześl, وافق, очты_, _läng
  { {0xc6920093,0x394602d1,0x41b5002d,0x9f47022d}},	//   _ראה_, ños_, дсут, čný_
  { {0x2d9d0002,0x10090003,0xb6010066,0xfc320012}},	// [5c60] dowe_, قتلى_, žáde, _أحب_
  { {0xe6c60003,0x7e9a0012,0x161f0011,0x2d822300}},	//   ستطي, منذر_, _बहार_, like_
  { {0x443f0051,0x6b5b0009,0xbcfb0025,0x3f8f0018}},	//   _aru_, _הדיפ, phét, égua_
  { {0xed590066,0xe6930003,0x994a0003,0x2d9d0002}},	//   _což_, رلند, _الحل_, gowe_
  { {0xe8030044,0xdce60039,0x27ee0013,0xc1730009}},	//   _लिया_, dokļ, álně_, _נחש_
  { {0x88bd003e,0x6c83000a,0x27e000c6,0x8c1b000b}},	//   reśl, علوم, mpin_, מוני
  { {0x443f014d,0x32182301,0xfa330012,0x2d9d0034}},	//   _eru_, ntry_, فريد, bowe_
  { {0x63700c60,0xc7d80024,0x8a170009,0xb3ca003c}},	//   _händ, омих_, לחצו_, _глаз_
  { {0xc05a002d,0x63702302,0x3946009b,0x68e40017}},	//   сій_, _känd, _vnos_, ibid
  { {0x138a000a,0xdf78002d,0x69c62303,0xa77304a5}},	//   _اخرى_, ібні_, _like, ельч
  { {0x69c60006,0xaadb0093,0x7bcd0010,0xb22600fa}},	//   _oike, _החבר, _suau, _хмел
  { {0x2c200044,0x160d0037,0x0657000b,0x39462304}},	//   _यहां_, ांतर_, פיכך_, _unos_
  { {0xa7fd000e,0x7bc50051,0x660805b1,0x7c670012}},	//   szűr, _pihu, sudk, ساحل
  { {0xddda000f,0xe0850003,0x60bb000b,0x4033003c}},	//   sztő, _تجمي, _הצדד, _чешс
  { {0x171b000b,0x35f70003,0x8f1b0009,0x98a90034}},	//   _הווע, _فريد_, _הוות, odać_
  { {0xc5eb000b,0x636b0051,0x24920002,0xfc4a0030}},	//   _הַזֹ, _düna, żymy_, _spíš_
  { {0xa2bc0044,0x69c600c6,0x2cfb0011,0x7d7c0009}},	// [5c70] षेत्, _dike, ्लील_, _לנהו
  { {0x3f8c0028,0x29030010,0x2d9d0002,0x3f9e1f98}},	//   nndu_, ėjai_, wowe_, notu_
  { {0x2d9d003e,0x200900c6,0x7bdb00bd,0xda670003}},	//   towe_, suai_, _stuu, _رادي
  { {0x98aa0002,0x6b5d0025,0x2fd90012,0x3f9e06dd}},	//   śbę_, _nègr, _ووجد_, hotu_
  { {0x98ab01b3,0x2409007c,0xac09002d,0xa156000b}},	//   _dacă_, інки_, інка_, _חברה_
  { {0x2d9d0002,0x2d82017b,0x8c4202ad,0x5c380009}},	//   sowe_, zike_, теше, פרון_
  { {0x98ab000d,0x3f9e001e,0x656d00b6,0x2d9d0034}},	//   _facă_, dotu_, _olah, powe_
  { {0x316b0034,0x9f5201e3,0xdb1a0031,0x25620097}},	//   ócz_, buyó_, _vitá, _tóli_
  { {0x7c2900a2,0x63700006,0x798d002c,0xf2c7036f}},	//   çerl, _häne, inaw, _есен
  { {0x3f9e001e,0x57790012,0x0e6504a5,0x752b0031}},	//   gotu_, تصبح_, дкон, legz
  { {0x140d0011,0x7d1d0032,0x656d00d9,0x6370005e}},	//   _समुह_, ffss, _blah, _jäne
  { {0x27e0004a,0xf8bf0011,0x98bf0011,0x6d5b0025}},	//   ypin_, ्शाय, ्शाए, _joua
  { {0xef0e1ad6,0x3f9e2305,0x2eaa0011,0xe6aa0011}},	//   _им_, botu_, _कर्त, _कर्ज
  { {0x69c6000f,0x7c2400a2,0x8e8500f5,0xa3ba0012}},	//   _sike, çiri, _огле, تاجر_
  { {0xc3320093,0xc7b20093,0x69c60051,0x8d760012}},	//   כום_, _שבו_, _pike, _يابا
  { {0x140d0044,0x6370006f,0x57ea0014,0x6b832306}},	//   _समूह_, _sänd, ждам_, hing
  { {0x2fc70cbf,0xb4fb0009,0x3cfb0009,0x32182307}},	// [5c80] _king_, _ולפר, _ולפנ, stry_
  { {0x7f4a0012,0x656d0159,0x6b832308,0x798d020d}},	//   غلاق_, _zlah, jing, anaw
  { {0xf2d30093,0x8f9a0009,0x69c62309,0x637017c5}},	//   _בעת_, קיעי, _tike, _vänd
  { {0xbc6a0003,0xc1060012,0x9f5201e3,0x63700032}},	//   يمان_, _توحي, tuyó_, _däne
  { {0x3f8c0065,0x6370006f,0x64890009,0x6faf0011}},	//   yndu_, _tänd, ּעוּ_, _जीवं
  { {0x2fc70a55,0x6b83230a,0x7c2d1e15,0xc4770009}},	//   _ning_, ging, çara, ותנו_
  { {0x7f5c0018,0x3f9e230b,0xbe160012,0x2eee00b0}},	//   _iorq, votu_, _توزع, _reff_
  { {0x60f80014,0xc0340001,0xc7c8001a,0x867b0009}},	//   чния_, ениј, _hối_, _ורלו
  { {0x3f9e230c,0x3ce6230d,0x1c050011,0xf2020011}},	//   totu_, mbov_, _रियल_, रूज़_
  { {0x798d0002,0x6d41001e,0x836a0012,0x2d800025}},	//   znaw, ēlam, _بصرف_, _amie_
  { {0xc7c8001a,0xa3bd0037,0x3f9e230e,0x82660012}},	//   _mối_, ीआर_, rotu_, _تهان
  { {0x7bc8230f,0xcdf7000b,0xc7c8001a,0xbcfb0031}},	//   _hidu, ומטי_, _lối_, mkék
  { {0xb87b000f,0x9f400054,0x636b0052,0x91bb0009}},	//   _leír, nsió_, _dünn, _ומאי
  { {0x2fc70832,0x926b0681,0x56940148,0x9f4001a0}},	//   _ging_, орба_, _палт, isió_
  { {0xc7c8001a,0x8fa30001,0x3d0f0011,0x43790009}},	//   _nối_, _шаље, _डाले_, פְשׁ
  { {0x45fb000b,0x3dfb000b,0x8dfb0009,0xb5fb0009}},	//   _וההג, _ולהד, _וההת, _ולהכ
  { {0x46d20037,0x57b5035c,0xd0110012,0xdce60073}},	// [5c90] _सलाह, ебат, طلا_, eikė
  { {0x2fc70028,0xb87b000e,0xc0170009,0xc7c80081}},	//   öng_, _beír, וקמו_, _bối_
  { {0xdb1a004a,0xbdf80012,0x7af50031,0x3ea70097}},	//   _mitä, ِرها_, mazt, ænt_
  { {0xa4d5007c,0xceb3000b,0xe5730012,0xc7c80081}},	//   ході, דיע_, خطط_, _dối_
  { {0xd0060003,0x50da000b,0xd8da0009,0x8b25003c}},	//   _حل_, _מקרא, _מקרר, едле
  { {0xc5f80035,0xa5f9004c,0x6738001b,0xa91d03a7}},	//   ksē_, _негу_, _navj, diža
  { {0x9171001a,0x7c3a001e,0x7bc8055c,0x2fc72310}},	//   _nợ_, ātri, _didu, _ring_
  { {0x26180061,0x6d490e34,0xdb1a0051,0x6b832311}},	//   déo_, _unea, _aitä, sing
  { {0x6b830005,0xed590027,0x511a0009,0x07f90012}},	//   ping, _niži_, הֵינ, أربع_
  { {0x9a270003,0x636b1fc3,0x23790012,0xa2270012}},	//   _يعان, _sünn, _عماد_, _يراه
  { {0xa90f0011,0x0ea905c8,0x8cc20011,0x2ca92312}},	//   िलाफ_, якой_, रेनो, _ayad_
  { {0x20020010,0xe919002d,0x2fc70daa,0xb4ea0011}},	//   škia_, _ході_, _wing_, यरे_
  { {0xf5390026,0xe8060037,0xe5720009,0xda0b0011}},	//   _mať_, _शिया_, רַת_, सूरत_
  { {0xd8740012,0x547a00af,0x395d1603,0x29030b64}},	//   _جامب, לטרו, _hows_, ėjau_
  { {0x3f852313,0x02190024,0x41b60148,0xda660012}},	//   milu_, міть_, есат, راسي
  { {0xc7c8001a,0x213907ac,0x067a0009,0x867a0009}},	//   _rối_, _cash_, _מנצל, _מרצו
  { {0xa3cb0044,0xcc360003,0x7f5c0583,0x600a00b3}},	// [5ca0] _रंग_, _أربع, _porq, янам_
  { {0xe3b20003,0xdce60010,0x8c1b0009,0x2d8f2314}},	//   _حرب_, tikė, _צויי, enge_
  { {0xe8ac01e1,0x7bc800c1,0x2365000e,0x9b170009}},	//   _चर्च, _ridu, ölje_, _אחיה_
  { {0x7bc80051,0x22450058,0x644401a3,0x66032315}},	//   _sidu, ælke_, _krii, ánka
  { {0xd4671498,0xf5390029,0x7bc80051,0xdd8f0012}},	//   нице_, _dať_, _pidu, حون_
  { {0xc7c80020,0x9f4003eb,0x68f6003a,0xd25a0048}},	//   _tối_, rsió_, layd, зци_
  { {0x9f4003eb,0x316c0039,0x7bc801ff,0x99660001}},	//   ssió_, ūdzu_, _vidu, етпл
  { {0x9a670003,0x67380027,0x361b000b,0xbcfb014a}},	//   عميل_, _savj, _מולד, ckéh
  { {0x59d20044,0xb4af0044,0xdb1a0006,0xc173000b}},	//   _दूसर, _करे_, _pitä, טחה_
  { {0x23fb0009,0x987b0009,0xf3c90012,0x907b0009}},	//   _מהמא, פריק, _قبله_, פטיי
  { {0x539b000b,0xe694003c,0x4e8a0223,0xce940048}},	//   _ציבו, тины, ящим_, танъ
  { {0xfc3f0013,0x9f5f0028,0xe4a70511,0xc6930009}},	//   tví_, stuð_, ерго, טאת_
  { {0x69da000e,0xf9930009,0xe786004c,0x21390132}},	//   íten, _גרף_, _пуко, _rash_
  { {0x636b00a2,0x65b60030,0xdb1e0031,0xa91d2316}},	//   _günl, váhe, _pipá, nižn
  { {0xb5a7007c,0xa5d70003,0x7ed5002d,0xf2040055}},	//   _прий, _كبير_, _річч, лято
  { {0x6c850003,0xd1b80012,0xad270012,0x8afc0034}},	//   _للعم, فاقا_, _أرثو, _klęs
  { {0x6d4d0101,0xa898111e,0xc05b002d,0x7ce80009}},	// [5cb0] _inaa, екту_, чів_, _אַתֶ
  { {0x81bc001e,0xa91d04d2,0x21390132,0x600b0009}},	//   _spēl, jižn, _wash_, לִבְ
  { {0x6448001e,0xf6530003,0xafdb0623,0x4b7c0009}},	//   ādie, دئذ_, _grøn, _מאזו
  { {0x753d000f,0x752f0002,0x22440012,0x2d8f00b8}},	//   ndsz, necz, _إنَّ, unge_
  { {0x9cd80009,0x14d80009,0xb4af0011,0xa3b90012}},	//   גודה_, גודל_, _करो_, واتر_
  { {0x996c0066,0xa3bd0037,0xbcfb00d9,0x6f150034}},	//   měř_, ीआइ_, skéh, _uczc
  { {0x5338000b,0xe2960014,0x2d870164,0x69950014}},	//   גנון_, каш_, énes_, крих
  { {0x44290d7b,0x752f0034,0x423800af,0x397803d2}},	//   _opa_, jecz, תנהל_, есью_
  { {0xa3d5002d,0x26c70064,0x637401a0,0x395d0132}},	//   _розч, ľnou_, _bànd, _vows_
  { {0xe6450014,0x200304d2,0xab62003a,0xfe450048}},	//   веоп, čji_, şürm, вноо
  { {0x442900c6,0xc7b2000b,0xfce60ed2,0xa50a2317}},	//   _apa_, שבי_, коно, мена_
  { {0x2009007a,0x644419a8,0x29030010,0xd256000b}},	//   krai_, _prii, ėjas_, _בשעה_
  { {0xb4fa0009,0x68e92318,0xa2d80011,0x81bc0035}},	//   ופרי, mbed, नुक्, _opēj
  { {0x98a00002,0x69d60321,0xe3a70012,0x3b0a003c}},	//   leić_, _मंदी, شر_, ьего_
  { {0xcb120009,0xfaa605c6,0x44292319,0x2009231a}},	//   ילם_, таво, _epa_, erai_
  { {0xb903003c,0x64440349,0x68e9231b,0x7c29231c}},	//   изск, _trii, nbed, _oper
  { {0x64a60001,0x1c160037,0x63a3231d,0x64440c25}},	// [5cc0] _јапа, _तमिल_, konn, _urii
  { {0x1bba0003,0xf3ca0012,0xeb9f00b0,0x68f60060}},	//   _تابع_, _تبعه_, ktøy_, sayd
  { {0xa3bd0037,0x25b1000e,0xd3570009,0x6df30012}},	//   ीआई_, _álló_, _סיטי_, لكلا
  { {0x5693002d,0x753b000d,0x5983022a,0xf6520009}},	//   шаєт, _cauz, _влюб, יצב_
  { {0x07fa0012,0x0ffa0012,0x62a30034,0xb8f60011}},	//   _ترجع_, _تعجب_, ętoś, िख_
  { {0x752f003e,0x7c29003a,0xdb030017,0x5b13002d}},	//   zecz, çeri, lonê, иміт
  { {0xbcfb000e,0xc7b30009,0xd2500012,0xf9f70012}},	//   mkév, _כבש_, صنة_, نريث_
  { {0xf126002d,0x79a60014,0x673c231e,0x58380148}},	//   тько, ърле, _harj, езия_
  { {0xb425000a,0xc9530009,0x99970048,0x69cb231f}},	//   _معلو, שמח_, ъкът_, _dige
  { {0x63a30f52,0x753b0027,0x61fe0029,0x69cb0e4b}},	//   conn, _zauz, _ovpl, _eige
  { {0x752f003e,0x4375002d,0x69da0066,0x6442008e}},	//   tecz, _сутт, ítel, lvoi
  { {0x79820002,0x29122320,0x201901a0,0xd5fb0009}},	//   _umow, _øya_, àsic_, ופטר
  { {0xc4580015,0x64420d9b,0x94a80055,0xc7c80081}},	//   виях_, nvoi, втра_, _bốt_
  { {0xa5c70065,0x200903a2,0x636f0f85,0xb4e30011}},	//   _bjóð, vrai_, _lønn, _क्रय_
  { {0x5fb70093,0xffb7000b,0x6b870070,0x28c50011}},	//   _שהוא_, _שלוש_, rijg, लेनि
  { {0x81bc001e,0x6569004a,0x63a3000e,0x0eeb0011}},	//   _spēj, öehd, zonn, टर्स_
  { {0x7ff40003,0xa0c40003,0x3eb90002,0x69d808c5}},	// [5cd0] لسلا, ليفو, ęste_, _éven
  { {0x63702321,0xf7730003,0x68e90027,0x65b60042}},	//   _täna, جار_, zbed, máha
  { {0xf41f0006,0x9f34002d,0x9f59000e,0x637002fe}},	//   ltä_, рехі, ésé_, _känn
  { {0x5c750015,0x05b80012,0x5bcb0011,0x7a880009}},	//   ллет, ندنت_, ाद्व, _יָרַ
  { {0xf41f0006,0x317a000b,0x8c250003,0x7d7c0009}},	//   ntä_, _נרשמ, افته, ונאו
  { {0xf41f0006,0x2d840006,0x69cb0058,0x63a3004a}},	//   itä_, _emme_, _sige, uonn
  { {0x2bda0037,0x261c0164,0xb5950103,0x64422322}},	//   _यूना, cío_, _бивш, avoi
  { {0xf2df001a,0x56940001,0x63a319d9,0xc6920009}},	//   _đâu_, _таст, sonn, _האל_
  { {0xccf20093,0x38692323,0xc1740009,0x60db2324}},	//   _לכן_, nyar_, יחק_, rcum
  { {0x25a900b6,0x68e90347,0x6be80009,0x60db2325}},	//   _akal_, sbed, _יַעַ, scum
  { {0x8f9c000b,0x5ee80009,0x6370005e,0xfe710012}},	//   ויזי, כַרְ, _bänn, صدد_
  { {0x64580034,0xc7c80081,0x94aa0012,0xed5a0a01}},	//   ścił, _sốt_, ّاسِ_, хом_
  { {0x973c0027,0x9583003c,0xa5c70097,0x636b0060}},	//   moćn, сляе, _sjóð, _günk
  { {0xdcef0039,0xdb1a01e3,0x31be0011,0x66e209f8}},	//   ficē, _sitú, ्द्ध, _лоша
  { {0x412a0e0f,0x57560009,0x6370005e,0x201f004b}},	//   ново_, _תבצע_, _fänn, ltui_
  { {0xb8860013,0x7989003e,0x261c0164,0xc692000b}},	//   hlíž, niew, vío_, _לאו_
  { {0xc7c80020,0x81bc001e,0x0b960003,0xd00707e8}},	// [5ce0] _tốt_, _spēk, _مجدد, лете_
  { {0xef170001,0xdb030097,0x547b0009,0x62090060}},	//   лму_, llnæ, _נטיו, üslü
  { {0x6fb3000a,0x673c0c16,0x9d460014,0x201f004a}},	//   حملا, _varj, лежд, htui_
  { {0xacf60003,0xb5a5002d,0xc2370009,0x261c0478}},	//   اسات, арій, _ערכו_, río_
  { {0x1af4002d,0x673c2326,0xc9530009,0x7af82327}},	//   апля, _tarj, _המר_, tavt
  { {0xd3b70024,0x64422328,0xdfcf0012,0x75d60012}},	//   глії_, rvoi, _ريف_, _ميسا
  { {0xda0b0037,0x39401f85,0xa2260012,0xe7d80011}},	//   संगत_, odis_, ارته, _भूतप
  { {0xdced066e,0xf41f0006,0x6e93000a,0xe6930012}},	//   _plač, ytä_, _الفا, _الفد
  { {0xd6d0000a,0x1f74010c,0x044303b3,0x1d070048}},	//   يقة_, илия, _летн, _щети_
  { {0x1037000b,0x25a92329,0x501b000b,0x65b60fe1}},	//   נטים_, _skal_, עויו, váha
  { {0x0f57000b,0x539b0009,0x98a40073,0xaaa40011}},	//   איים_, _טימו, demą_, _खुलक
  { {0xf41f0006,0xdced00f1,0x86730024,0x7bd6232a}},	//   ttä_, _tlač, слює, _buyu
  { {0x63700163,0x60180014,0xdc870001,0xdceb0073}},	//   _vänn, _роля_, ућно, aigė
  { {0x200b0026,0x7bd6003a,0x25a6232b,0x7d040413}},	//   ácie_, _duyu, hool_, _edis
  { {0xf41f03fc,0x25a60051,0x6370004a,0xeef70009}},	//   stä_, kool_, _tänn, _גמור_
  { {0x65b60028,0x810f0011,0x39810073,0x53d40011}},	//   páha, िलेख_, tųsi_, ददाश
  { {0x0cab0024,0x5bb90148,0x26ca0064,0x2d8b232c}},	// [5cf0] _ятки_, _илия_, ľbou_, mice_
  { {0x2007048b,0x39400cb1,0x26ca0042,0x69d60011}},	//   čni_, adis_, žbou_, _मूवी
  { {0x6dbc003e,0x07080012,0x5f1c0011,0xecf90048}},	//   _właś, طيني_, _मान्_, вееш_
  { {0x6d5d006f,0x2d8b232d,0x4a5a0009,0xe6040012}},	//   njsa, nice_, _סדרו, إِنَ
  { {0x78fa0009,0xbcfb000e,0xdca50001,0xc0ab0003}},	//   _בפרו, lkés, јали, _ساحل_
  { {0xda650014,0x27e91137,0xd466035c,0x15f70012}},	//   ивли, mpan_, рише_, _مسرح
  { {0xe4e7007c,0xe0d10003,0xc3340009,0x79890227}},	//   _бізн, يزة_, מוס_, tiew
  { {0x7c2d0002,0x7c3e0002,0x59b50037,0x201f0add}},	//   _opar, łpra, ंतिर, ttui_
  { {0x646300a2,0xae0d0037,0x23a50037,0x316d003a}},	//   çtiğ, ांकन_, ओवाद, rkez_
  { {0x7e750003,0x5f050001,0x3862006f,0xa7b5004c}},	//   لاجئ, јзна, äkra_, јсиј
  { {0x64490028,0x201f232e,0xa1550048,0x2d8b232f}},	//   _hrei, stui_, _вълш, fice_
  { {0x6da6007c,0x2d8b000d,0xc6160009,0xe4c60048}},	//   рима, gice_, סחרי_, ийни
  { {0x98a40073,0x61e500d5,0x69d72330,0x7bc32331}},	//   temą_, _athl, _auxe, omnu
  { {0x68ed0623,0xe29a0024,0xa87a0009,0x03d60009}},	//   ebad, ваг_, _באנר, יושם_
  { {0x0cb201e1,0x75290e6e,0x27ff0060,0x644b052e}},	//   _जर्म, _obez, lsun_, _ágin
  { {0x68fb007a,0xf1c60028,0x64490061,0x7a40000e}},	//   naud, _þátt_, _orei, látá
  { {0x6d41001e,0x65b6000e,0x77860001,0x97da002d}},	// [5d00] ēlat, láho, алаз, тьбу_
  { {0xc3fb0093,0xfe720003,0x27ff004a,0x7a40000e}},	//   _שליש, يدا_, isun_, nátá
  { {0x3eae0399,0x1fb50015,0x68fb00e6,0xe7370593}},	//   æft_, сстр, kaud, рех_
  { {0xe29b000b,0x27ff004a,0x6564004a,0xba9b000b}},	//   _ישיר, ksun_, _joih, _יסיי
  { {0x25a60051,0x68fb001e,0x64492332,0x7afc004b}},	//   rool_, daud, _crei, oart
  { {0xaaba0044,0x69c4004a,0xf413000b,0xf53f006f}},	//   _इराक, lmie, קפו_, llåt_
  { {0xcad70093,0x65b6000f,0x64490480,0x65bd000e}},	//   בוצת_, jáho, _erei, léhe
  { {0x65b80066,0x64492333,0x7afc2334,0x59c60011}},	//   bíha, _frei, hart, लगिर
  { {0x4973007c,0x64492335,0x65b60066,0xc05a002d}},	//   ільс, _grei, táhn, тій_
  { {0x2d8b08ce,0x69c4074a,0xec370009,0xdb070097}},	//   wice_, hmie, _דאמר_, kljá
  { {0x63700163,0x2d9e0108,0xa4d5002d,0x68fb0f27}},	//   _vänl, _êtes_, йоні, baud
  { {0x65b60066,0xbcfb000e,0x7af72336,0x6d402337}},	//   sáhn, ekér, _sext, _jama
  { {0x69cf034e,0x69c42338,0x6d402339,0x7afc18c6}},	//   _rice, dmie, _mama, fart
  { {0x6d400101,0xc90f0044,0xf87b000b,0xd6d00003}},	//   _lama, िल्म_, _שְׁל, _عقب_
  { {0xe2f80024,0x61ea0032,0x67bb0009,0xd7bb0009}},	//   ресі_, npfl, _שמוק, _שצור
  { {0x7c2900a2,0x29dc02d1,0x65b60029,0x44f50001}},	//   çers, _día_, náhl, _упис
  { {0xdefb0047,0xdfd10003,0x7afc233a,0x9f52004a}},	// [5d10] вые_, سيا_, bart, ksyä_
  { {0xc43c000b,0x65760029,0x7d1b00c1,0x69cf0002}},	//   _יתחי, _zlyh, _scus, _wice
  { {0x5cd50003,0x20020470,0xeb9f0058,0x3f8c005e}},	//   مقاط, ških_, esøg_, iidu_
  { {0xbd18007c,0x4518002d,0x6449233b,0xceb30009}},	//   иції_, иція_, _prei, קיף_
  { {0xf956000b,0x91ba0009,0xb9560009,0x515a0009}},	//   _הסרת_, _תמרי, _הירח_, _עכשו
  { {0x2c380009,0x0c240024,0xe2990337,0x3b840024}},	//   שָׁם_, юмін, лал_, оліг
  { {0xf1bf001a,0x0378000b,0x7c22233c,0xca490012}},	//   _khá_, שתות_, ator, البه_
  { {0x3f8c001e,0xa37b0051,0x27ff019a,0xfa980009}},	//   eidu_, spõh, tsun_, ידוש_
  { {0x68fb0d2b,0x67550012,0x33d40024,0x6c850012}},	//   raud, مخدر, _дієт, _الذم
  { {0x6d4000a2,0xfbd00003,0x65b6000e,0xe7390001}},	//   _zama, _قتل_, táho, ћен_
  { {0x27ff00c1,0x68fb03ec,0xc4c90009,0xba740012}},	//   ssun_, paud, _נג_, _وامت
  { {0xd6560093,0x2902000f,0x7afc1060,0xc692000b}},	//   צירת_, ókat_, wart, לאי_
  { {0x65b6000f,0x29dc0028,0xaf490012,0xd00917de}},	//   sáho, _sía_, _مشغل_, _селе_
  { {0x69d8000e,0x79960034,0x65bd0031,0x65b60031}},	//   _évek, wnyw, véhe, páho
  { {0x5f740003,0x11da0003,0x3eaa0042,0x26c50004}},	//   _ظاهر, اورة_, čité_, _úloh_
  { {0x29dc0164,0xe8030037,0xdfd20003,0x7c220002}},	//   _vía_, _लिखा_, كير_, ytor
  { {0x75d3000d,0xe5710009,0xf6d60012,0x6d40233d}},	// [5d20] _văzu, _חַי_, مزاد, _rama
  { {0x395f0051,0x2000233e,0x65bd0e90,0x2d8e0034}},	//   hjus_, rsii_, réhe, śleć_
  { {0x63700163,0x65bd000f,0xdfcf0003,0x671e0037}},	//   _länk, séhe, ريم_, _पाठक_
  { {0x89360003,0x7c22233f,0xbcfb000e,0x7c060012}},	//   _اعدا, ttor, nkép, مبتك
  { {0x2365012e,0xddc90010,0xdb01015b,0x0b8a0103}},	//   _bolj_, yzdž, _sklá, лски_
  { {0xeb9f0058,0x5f1c0011,0x230a0012,0x37e3004c}},	//   rsøg_, _माध्_, اتشي_, _хорг
  { {0x5a34002d,0x39420051,0x7a430eb0,0xe2460012}},	//   інит, _kaks_, mítá, إختي
  { {0x7a430272,0xf596000a,0x80c40037,0x61ea0052}},	//   lítá, _الرج, ाइले, rpfl
  { {0xe58b000b,0x61ea0032,0xdb1a0031,0x331a0012}},	//   _עָלָ, spfl, _kitü, _مزاد_
  { {0x8b65000a,0x65b60066,0x74130003,0xfafe001e}},	//   _والم, sáhl, _روما, šība_
  { {0xdb010066,0x39a10010,0x4d990024,0xfe6f0012}},	//   _uklá, lėse_, икою_, ّدُ_
  { {0xd5b80109,0xa1c60e8a,0xc7b90031,0xbcfb0031}},	//   йся_, _убед, ltől_, gkép
  { {0x443900bd,0x39a10010,0x7a43000e,0x386d006f}},	//   uws_, nėse_, kítá, cyer_
  { {0x69da0006,0x325506bd,0x7a430031,0xc7b90031}},	//   _kute, овгр, jítá, ntől_
  { {0x7de60003,0xf1bf001a,0x7a43000e,0x7afa0bc1}},	//   _استم, _phá_, dítá, _mett
  { {0x98750015,0xc05b002d,0x07180011,0x1e970009}},	//   олбц, ліз_, _दाँव_, _לכול_
  { {0x7ff70003,0xc7b9000e,0xc6f90055,0x1fdb0012}},	// [5d30] إسرا, ktől_, инах_, اظرة_
  { {0x28c50037,0x7afa2340,0xd5b90035,0x7a430031}},	//   लेषि, _nett, itām_, gítá
  { {0xf7700003,0xb6350003,0x2eff0025,0x69da2341}},	//   راك_, تفاع, _œufs_, _nute
  { {0x6aba00a2,0xd5b9001e,0xbcb5003c,0xa5f8004c}},	//   ütfe, ktām_, обещ, сецу_
  { {0x7afa2342,0x28c50011,0x23650159,0x7a430031}},	//   _bett, लेशि, _polj_, bítá
  { {0x7afa02b5,0x661d003e,0x7ee50003,0xc5fb0012}},	//   _cett, ński, _ذكرن, _معرض_
  { {0x2e480014,0x6370006f,0x831c0009,0xdfd00012}},	//   _лято_, _sänk, טוגז, _أيّ_
  { {0xe87c00a2,0x212b13b4,0xfa78000b,0x636b0052}},	//   nüşü, ých_, מעות_, _küns
  { {0xb9010044,0x395f005e,0xd5b20081,0x7afa2343}},	//   _दल_, rjus_, húc_, _fett
  { {0x93970003,0x69da0017,0x443f06db,0xa8580009}},	//   _اجرا, _fute, _isu_, מיחה_
  { {0x3eb90002,0x69da2344,0xdb030031,0xbcfb0031}},	//   ęsto_, _gute, noní, tkép
  { {0x2d8f0732,0x6370006f,0x7a43000e,0x7afa0ad2}},	//   nige_, _tänk, zítá, _zett
  { {0xbcfb000e,0x32110002,0x07190011,0x6aab0011}},	//   rkép, erzy_, दलाव_, _ज़रुर
  { {0x2d990070,0xbcfb000e,0x289a0009,0x2d8f0032}},	//   anse_, skép, _דינא, hige_
  { {0x7d090013,0x7a43024a,0x644d0051,0x27ed0084}},	//   _odes, vítá, _erai, lpen_
  { {0xa1160003,0x644d190a,0xe4d60003,0x2d8f017b}},	//   تورت, _frai, _بتثب, jige_
  { {0x42d60024,0xdd8f0012,0x7a430031,0x02d60012}},	// [5d40] _міну, _جوي_, títá, _وتدخ
  { {0x47c3002d,0xeab20003,0x6aab0037,0xa6b60063}},	//   дбув, _يعد_, _ज़रूर, осещ
  { {0x67210037,0x95860015,0x0d860015,0x85060003}},	//   _मानक_, олже, олжн, قوان
  { {0x7a43000f,0x39a10010,0x0dc90012,0x2d8f2345}},	//   sítá, tėse_, مبنى_, gige_
  { {0x69da007a,0x7a43000e,0xac970003,0x27ed0070}},	//   _sute, pítá, ينما_, jpen_
  { {0x69da2346,0x6d440051,0xafdb038e,0xd9b40037}},	//   _pute, _laia, _prøv, ुष्ट
  { {0xfce6002d,0x27ed0070,0x7e230001,0x443f0010}},	//   _мово, epen_, _одрж, _esu_
  { {0x39a10010,0x63700032,0xf2d30009,0x68e42347}},	//   pėse_, _däni, ועו_, ncid
  { {0xfbbc0037,0xc7d70015,0xfc0300b3,0x7f432348}},	//   ोगाम, омых_, _опто, _banq
  { {0xdb1a0017,0x6440003a,0xa857000b,0x0857000b}},	//   _vitó, _ismi, קייה_, קבים_
  { {0x9f40004a,0x3218002a,0x69da0038,0x44261f51}},	//   mpiä_, jury_, _uute, lto_
  { {0x6562004a,0x758b00de,0x32180b32,0x2d9900b8}},	//   njoh, рсов_, dury_, unse_
  { {0x98b9000d,0x9b6b0048,0xcb470024,0x44262349}},	//   _masă_, ашва_, охви, nto_
  { {0x644d0061,0xf413000b,0xf0930009,0x98b9004b}},	//   _vrai, ופש_, _קנס_, _lasă_
  { {0x4426234a,0xf364003c,0x236c0248,0x298b004c}},	//   hto_, фтян, ödja_, асао_
  { {0x2d92000e,0xab5d0002,0xa91d0010,0x644d234b}},	//   ézet_, _duży, sižv, _trai
  { {0x44260026,0x64410039,0xb0c50037,0x47d50003}},	// [5d50] jto_, ālis, लेंग, سيار
  { {0xcb680001,0x442607ff,0x7d1d0192,0xe7330012}},	//   _мање_, dto_, lgss, بصر_
  { {0x69da000f,0xbb3a000b,0xdb1a0066,0x636b0052}},	//   ítet, _העתי, _chtí, _wüns
  { {0x2004001e,0x31590003,0x98b9000d,0xbdf80012}},	//   ksmi_, _الحج_, _casă_, تركا_
  { {0x43750047,0x515a0009,0x415a0009,0xab5d0034}},	//   зуйт, _הכרו, _הדרג, _zuży
  { {0x9342002d,0x8388002d,0xa3570012,0xda090012}},	//   енше, обів_, تخصص, ميته_
  { {0x09e20014,0x4426234c,0xef23001e,0x220b0009}},	//   нощн, ato_, _ceļš_, ׁפַּ
  { {0xe29c000b,0xf652000b,0xe9a80003,0x7d0922f3}},	//   ישור, _אצל_, يدين_, _udes
  { {0x4426084f,0xf8b90037,0xf1b4000b,0x443f0051}},	//   cto_, _आरोप, וסק_, _usu_
  { {0x6370234d,0x27ed055b,0x1b770012,0xa6850048}},	//   _hänv, rpen_, _بدرج, злод
  { {0x2f54007c,0xdbc6004a,0xd5e50198,0x29d1001b}},	//   єтьс, töön, яжни, _ušao_
  { {0x7aba0093,0xb2ba0093,0x3aba0009,0xa2ba0009}},	//   _הצעו, _המער, _המענ, _המעט
  { {0xe6b80037,0x69c909de,0x6564008e,0x50da0009}},	//   _अर्ज, mmee, öihi, _הקנא
  { {0x8cc20011,0xc7a80012,0x3218234e,0xe8200011}},	//   रेगो, _ودول_, tury_, _ममता_
  { {0xaacb0037,0xa3cc0037,0xa3d401e1,0xdce8003a}},	//   ाधिक, रगत_, _संघ_, şmıy
  { {0xe0da0014,0xd7f20012,0x64a60024,0x64400097}},	//   сва_, فكر_, _найа, æmis
  { {0x68fd060e,0x351b000b,0x44260583,0x7d7b000b}},	// [5d60] _desd, _הופנ, xto_, _לנקו
  { {0x46a60014,0xbcfb000e,0x68e4234f,0xa3bf0011}},	//   пазв, njén, scid, ेषण_
  { {0xada50029,0x32db0009,0x9af70009,0xd6d20012}},	//   spĺň, _לחינ, _מזיק_, رقص_
  { {0x44262350,0xe45a002d,0x05660014,0x44760009}},	//   tto_, йже_, явен, ּעַל_
  { {0xe8d7000b,0x6f01009b,0x657b0030,0x69c9005e}},	//   _מוכר_, kalc, _dluh, dmee
  { {0x6f01009b,0x6562004a,0xdce0001e,0xdcef001e}},	//   jalc, sjoh, _domā, ticī
  { {0xcb070012,0xd257003c,0x2d990031,0x644b1d68}},	//   سيين_, зцы_, érek_, avgi
  { {0x15430001,0x7e9b000b,0x4426179f,0x3ec20035}},	//   _песм, _הסלו, pto_, ērtē_
  { {0xd8230046,0xec7a002d,0x3ce60029,0x98160012}},	//   едњи, _упа_, mcov_, أبعا
  { {0x4386000a,0x447b0009,0x69c20bb4,0x547b0009}},	//   _علاق, _הנמע, _whoe, _הטמו
  { {0x6283003e,0xcdd40009,0x2bc90011,0xdb1e0031}},	//   czno, ֽךָ_, िगरा, _lipó
  { {0x0697000b,0x3ce60029,0x8e970009,0x515505c8}},	//   לדים_, ncov_, לדיו_, _отчу
  { {0x0cab0098,0xc0d30003,0x94ab120f,0x5c740667}},	//   стни_, _كيمب, стна_, елят
  { {0xa857000b,0x9a870209,0xc2140009,0x1ddc0011}},	//   _מידה_, публ, ֽהּ_, यदात
  { {0x82a40046,0x539b0009,0xd1bb0012,0xa2950024}},	//   еште, צילו, مارا_, фаві
  { {0x2d9c000f,0xdb0a0163,0x3197000d,0x673a009b}},	//   ével_, llfä, tăzi_, letj
  { {0x2bbc0011,0x3ce60064,0x4fd50adc,0xa3cc0011}},	// [5d70] ोगशा, dcov_, джат, रगा_
  { {0x656900b6,0xdb0301bd,0x83190012,0x33fc0009}},	//   _soeh, koná, _بقدر_, _ההזנ
  { {0xcb12000b,0xe81e0011,0x661a2351,0x56940024}},	//   _בלי_, यूबा_, nutk, нафт
  { {0x6fd80037,0x7afe2352,0x673a0031,0x6f010159}},	//   _भूकं, _zept, hetj, zalc
  { {0x442b002d,0x69de0002,0x9cd80009,0x34ab0012}},	//   сцем_, _zupe, פוגה_, حداً_
  { {0x8c1c000b,0x673a009b,0xdb0305b1,0x65bd1038}},	//   מודי, jetj, foná, kého
  { {0x6f01012e,0xaa560001,0xaa450048,0x661a016d}},	//   valc, дију_, фейл, jutk
  { {0xeeeb008a,0x6370004a,0xc6920009,0x8a7c0009}},	//   _động_, _hänt, _סאן_, מאות
  { {0xfc300003,0x62830123,0xef190024,0xcf390024}},	//   _محل_, szno, омп_, очні_
  { {0x3789002d,0x43940001,0x69c9002e,0x06090021}},	//   ібно_, _заус, smee, онок_
  { {0xd1310003,0xd0190002,0x7bdf0061,0x6f01080b}},	//   _لما_, suń_, _auqu, ralc
  { {0xcb09015a,0x92b40012,0x7bdf01e3,0x6abe0032}},	//   _כל_, _أحكا, _buqu, üpfe
  { {0x63ae0026,0x3949006f,0xd1380adc,0xbcfb0031}},	//   tobn, ddas_, _ххх_, pjén
  { {0x7d0d0005,0x39490835,0x661a00b6,0x3ce62353}},	//   _edas, edas_, butk, zcov_
  { {0x23270048,0xab270048,0xcb880009,0x93430048}},	//   ьори_, ьора_, פְשֹ, ънре
  { {0x41b50024,0x291f2354,0x63ae2355,0x636f0040}},	//   есут, ngua_, sobn, _køns
  { {0x3ce60029,0xdb03000e,0xdb1e0054,0xe3b20012}},	// [5d80] vcov_, zoná, _dipò, _لرد_
  { {0xdced001c,0xe3b20003,0x394901c5,0x636f0260}},	//   _plać, _جرب_, adas_, _møns
  { {0xdb1a000e,0xa5260024,0xc7af0012,0xeb9f00b0}},	//   _kitö, дмед, جّل_, prør_
  { {0xdb03000e,0x6d9100d9,0x673a0031,0x000000c4}},	//   voná, sťan, zetj,
  { {0xdd8f0003,0xd467004c,0x113b0009,0x3ce60064}},	//   جون_, мице_, _ותכל, rcov_
  { {0x53330046,0x661a0163,0x68f60058,0xa08b000b}},	//   вешт, _åtko, lbyd, _וְלִ
  { {0xd2500003,0x28be0037,0x6370006f,0xf9c60024}},	//   انب_, ्धवि, _häns, мщин
  { {0x3d180037,0x6370006f,0xd80a0048,0x6444008e}},	//   थलों_, _käns, охол_, _osii
  { {0xf1b3000b,0xb4bd0011,0xc0a90009,0xdb030097}},	//   כסה_, _अरे_, ּיתָ, llný
  { {0x7d00006f,0x3e4c0066,0x39490010,0xc4c50003}},	//   _hems, _pět_, zdas_, _ستقو
  { {0x4e8a0015,0xaadb000b,0xbcfb000e,0x7d000028}},	//   ющим_, _וחבר, mkéz, _kems
  { {0xdb070030,0xc0460012,0xe2910012,0x3e4c0030}},	//   rojí, _يخشو, _إذْ_, _vět_
  { {0x68f60058,0x321c01e9,0x2d850073,0x403414ea}},	//   dbyd, luvy_, ėle_, _челс
  { {0x29042356,0x69c6008e,0xdb0706dd,0x3033003c}},	//   lama_, _ahke, pojí, _решё
  { {0xd8480020,0x6444004a,0xc7d7000b,0x7e860066}},	//   _họ_, _esii, _קווי_, úspě
  { {0xbda70003,0x200f0018,0x7d000031,0x29042357}},	//   _تحتو, ágio_, _nems, nama_
  { {0xe8940047,0x80c40037,0x39492358,0x23de0011}},	// [5d90] вать, ाइटे, rdas_, _फूलद
  { {0x753d000f,0xcebb0001,0xbc380003,0x6bd70003}},	//   lesz, оље_, _آسيا_, _تتعر
  { {0x63700163,0xb6070020,0x65150012,0x261a0011}},	//   _vänt, _giớ, فوائ, मूली_
  { {0x29d1014a,0x2a76000b,0xc7b9000e,0x753d000e}},	//   _však_, _נערך_, rtői_, nesz
  { {0xc9160093,0xed58002d,0x3eb90010,0xdb030061}},	//   _אחרת_, ьої_, ęsti_, nonç
  { {0xcc78007e,0x6ffa0009,0x8c1c0009,0x57fa0009}},	//   ועדה_, _מהשפ, קווי, _מלשו
  { {0xd6690003,0x2d870025,0x60c20031,0xf52703b0}},	//   _عمرو_, ènes_, _azom, _офан
  { {0x3f9e0708,0x29042359,0x7dde0035,0x753d235a}},	//   entu_, gama_, _mūsd, jesz
  { {0xc7950015,0x20090645,0x4f9501d4,0xd00e0012}},	//   ерны, nsai_, ерну, ملي_
  { {0x0082002d,0x16650109,0x0e6503e8,0xd3d80012}},	//   ульо, евом, екон, _قبلا_
  { {0xc7b2000b,0x7c360028,0xa3cc0011,0x753d0031}},	//   רבי_, _spyr, रगर_, fesz
  { {0xf2df008a,0x2904001c,0xc3290093,0x753d09c5}},	//   _đây_, cama_, _לו_, gesz
  { {0x251a0009,0x636f0623,0x41740012,0x61e1235b}},	//   הורא, _uøns, _جالس, _hull
  { {0x61e100a1,0x7c2b0032,0xbea50868,0x324603d2}},	//   _kull, itgr, _палк, негг
  { {0x7c2b005e,0x539a0009,0x753d235c,0x61e1235d}},	//   htgr, לישו, besz, _jull
  { {0x61e11813,0xbd03068c,0x57ea05c8,0xe9d70288}},	//   _mull, žérs, здам_, екс_
  { {0x2d80004b,0x7d06235e,0x02cb0011,0x68f60040}},	// [5da0] _ilie_, maks, ाधुन, rbyd
  { {0x63700163,0x4a46002d,0x7d06235f,0x29041ca7}},	//   _väns, _знов, laks, zama_
  { {0x200900b6,0x8afb0009,0x42fb0009,0x064a0012}},	//   asai_, _מפיק, _מהיס, ثلاً_
  { {0x84e6002d,0xd5b9001e,0xfce61c85,0xee49001a}},	//   ходж, stāv_, ходо, _mẽ_
  { {0xee49001a,0xdb03004a,0x29040c2b,0x41bf0011}},	//   _lẽ_, konä, vama_, ्षरस
  { {0x753d003e,0x7d060051,0x8c1b0009,0xa2940024}},	//   zesz, haks, פוצי, калі
  { {0x7d00003a,0x3ebe0028,0xdbc70051,0x60c2000e}},	//   _tems, _átt_, _tööj, _szom
  { {0xb0340001,0x7e0b000b,0xc0340001,0x7d061535}},	//   вниш, _מִמֶ, вниј, jaks
  { {0x753d000e,0x41c30003,0x98a3004c,0xe123004c}},	//   vesz, دقيق, лиће, умњи
  { {0x7522000f,0x3f9e0027,0x29041738,0x61e12360}},	//   lgoz, untu_, sama_, _full
  { {0x29040027,0x753d000e,0x4256002d,0x6a160012}},	//   pama_, tesz, _ятат, _سبار
  { {0xc27b000b,0x7bce00b6,0x7bda2313,0xf56e0024}},	//   _מרבי, embu, _hitu, икiв_
  { {0x753d0d27,0x61e10070,0x7bda0010,0xdcbb0014}},	//   resz, _zull, _kitu, ящо_
  { {0x7d060e7b,0x661e2361,0x000000c4,0x000000c4}},	//   aaks, kupk,   ,
  { {0x7dde007a,0x6d96001e,0x81c70015,0x5e260003}},	//   _būse, mšan, ещае, _أعتق
  { {0x7d0600a2,0xb6bb000b,0x8d770003,0x61d80015}},	//   caks, _מצוי, _ساعا, емся_
  { {0x20090010,0xc7d9004c,0x69cd2362,0xbfd90024}},	// [5db0] usai_, дмах_, rmae, ддає_
  { {0xf773000a,0x200b0029,0x4c9c0009,0xaa890012}},	//   دار_, ácii_, _מבחו, _ينظم_
  { {0xe717000b,0x6d910029,0x57a4004c,0xee490081}},	//   תחבר_, sťam, ушта, _xẽ_
  { {0x79840002,0xd5b30011,0xd5b90035,0x7c2b2363}},	//   chiw, ीतिज, mtās_, ttgr
  { {0x04450098,0x6d960039,0x69da0044,0x61e119dd}},	//   телн, kšan, _पंजी, _sull
  { {0x9f940052,0x26010037,0xf62b002d,0x6d96009b}},	//   mäß_, वीडी_, _ніби_, jšan
  { {0x7bda00c6,0xeb92000b,0xc6d70003,0xdce20027}},	//   _ditu, יָה_, _ستست, akođ
  { {0x9f42004a,0x6d961ab2,0x20550fbb,0x61e12364}},	//   _etkä_, ešan, втор, _vull
  { {0xee49008a,0xf7710003,0x7d06083c,0x7f19002d}},	//   _sẽ_, لاد_, vaks, міну_
  { {0x76550002,0xd5b9001e,0x6d96001e,0x394b0d29}},	//   _krzy, ktās_, gšan, _lacs_
  { {0x7d0603fb,0x4ed4002d,0xab840223,0xbea505f7}},	//   taks, люют, _сутк, танк
  { {0xa3e60044,0xed5706e6,0xf5060014,0xee49001a}},	//   _बंद_, вою_, ъзмо, _vẽ_
  { {0x7d060333,0xe8180044,0xb8e70011,0x29022365}},	//   raks, _दिया_, ोइ_, _reka_
  { {0xc88300a2,0xdee20024,0xb09a0009,0x97240012}},	//   ığı_, _коши, _קיסר, _مفهو
  { {0x7d061c17,0xd5b90035,0x64420034,0x29022366}},	//   paks, gtās_, zwoi, _peka_
  { {0x6f03002a,0x29c1000e,0x2d990c48,0xc2120009}},	//   _henc, zóan_, éret_, יהל_
  { {0xdb1a004a,0xc172000b,0x6f0300b6,0x8bb60003}},	// [5dc0] _yhtä, בחן_, _kenc, _لإدا
  { {0xd5b9001e,0x7783002d,0xcc570009,0x76550034}},	//   stāt_, алуз, _יספק_, _brzy
  { {0x6f032367,0xf74304b3,0x11d60003,0x7d040d58}},	//   _menc, рехо, _لتحد, _keis
  { {0xdb0a0119,0x6b81008b,0xdd8f0012,0x5cf60024}},	//   llfø, _allg, يول_, тяжу
  { {0x7d042368,0x7bda004a,0xc7b9000e,0xdb0a0164}},	//   _meis, _pitu, ntős_, sofí
  { {0x66e60001,0xf8b30009,0x7d042369,0xd36f0012}},	//   _јова, _כשר_, _leis, يهن_
  { {0xcb13000b,0xdb0a0058,0x79a60014,0xbae50024}},	//   בלו_, ilfø, крие, уцій
  { {0x32530014,0x29020463,0x7d04236a,0x3ce00040}},	//   рвър, úka_, _neis, _ngiv_
  { {0xf9930093,0xebe6007c,0xa3b20011,0x831a0012}},	//   ירה_, _розп, टका_, _يقرر_
  { {0xd3780027,0x394d1d6b,0x6d96098f,0x3940016d}},	//   _biće_, ades_, ušan, heis_
  { {0x7d04008b,0x539b000b,0x39400010,0xce670024}},	//   _beis, _קיבו, keis_, вряд_
  { {0xceb30093,0x61460046,0xd9460046,0xac190094}},	//   יית_, _једа, _једи, ному_
  { {0x661d007a,0x4813002d,0xc7b9000e,0x6d961456}},	//   ąska, _вміс, ttőt_, pšan
  { {0x7e540003,0xa3a4004c,0xc4d30009,0x7dde0035}},	//   _منتص, ајск, יגר_, _bīst
  { {0xdcfb001c,0x9e340047,0x2e4a0014,0x6d960027}},	//   _sluč, _сейч, _цяло_, ošal
  { {0x7d0402dc,0xd5b90035,0x6f030060,0x64561603}},	//   _geis, rtās_, _zenc, _fryi
  { {0x2d99236b,0x08550047,0xd5b9001e,0x636b0032}},	// [5dd0] mise_, ываю, stās_, _münz
  { {0x76550656,0xb4330026,0x2d99236c,0xaac70012}},	//   _przy, ľúčo, lise_, _لتجن
  { {0x645a0039,0x394d236d,0xe7310009,0xc6e40024}},	//   ātie, ydes_, מֵא_, ріуп
  { {0xd256000b,0xeb9f0033,0x39400017,0x6d960159}},	//   _עשרה_, ksøk_, ceis_, jšal
  { {0x6d4d01e5,0xd91a0009,0xb4bf0011,0xc9520009}},	//   _maaa, _אורל, ीधे_, _המכ_
  { {0x76550002,0x539c0009,0x67210011,0x399a0035}},	//   _trzy, ֽיהו, _माइक_, zīst_
  { {0xeb9f0033,0xdb070028,0xaa080003,0x61e5004a}},	//   esøk_, lljó, نزيل_, _juhl
  { {0x63b5000e,0x6d4d002c,0x5274002d,0x394d236e}},	//   hozn, _naaa, рушу, udes_
  { {0x63b50123,0x2d991497,0x6f03236f,0xd5b80024}},	//   kozn, dise_, _penc, _рср_
  { {0x7d04035f,0x6d960010,0xf745004c,0xd378001b}},	//   _seis, ašal, ћено, _piće_
  { {0x7982002a,0x69dd0061,0xbd460003,0x41e70024}},	//   _flow, _oise, هندي, _різа
  { {0x69dd009b,0xe0550012,0x7de80030,0xeb9f00b0}},	//   _nise, _مختب, _těsn, bsøk_
  { {0x39400894,0xedb60009,0x8c960024,0x7d042370}},	//   veis_, רִית_, урні, _veis
  { {0xa09a0093,0xade30044,0x7d04008b,0x3940008b}},	//   _אינט, गदान_, _weis, weis_
  { {0x7d041392,0x7dca0028,0x69dd2371,0xafdb00b0}},	//   _teis, lýse, _bise, _esøk
  { {0xd5b20003,0x5c960003,0x6456002a,0x6569008e}},	//   _دفع_, _مؤخر, _tryi, öeht
  { {0x7dda0066,0x7d040028,0xd7f9002d,0xefca0015}},	// [5de0] _důsl, ðism, вує_, елал_
  { {0x7dda0066,0x65bd000e,0x39402372,0x69dd06f6}},	//   _půso, véhi, seis_, _eise
  { {0x44222373,0x6449008e,0x3ec90009,0x03d70009}},	//   luk_, _asei, תֶּ֣, _תוים_
  { {0xc4860015,0x240a01ef,0xf5250024,0x05ba0012}},	//   ллек, енди_, ифін, ردات_
  { {0xdca3046d,0x6e210032,0x7bde2374,0x64a3004c}},	//   баци, hulb, _kipu, баца
  { {0xd3700003,0xdced003a,0x96060012,0x9cd70009}},	//   تهت_, _olağ, _مبرم, אונה_
  { {0x7ed5002d,0xe2130003,0xb4db0054,0xd357000b}},	//   _вітч, مبيع, ndàr, טיסי_
  { {0x636b00a2,0x68fb0070,0x63b50029,0xd7fa0001}},	//   _düny, gbud, zozn, нуо_
  { {0xc173000b,0x44222091,0x859b0009,0xa3b60011}},	//   מחה_, juk_, _נשמו, ड़ता_
  { {0x442200c6,0xeb9f0033,0x2d99002a,0x3f9a016d}},	//   duk_, rsøk_, wise_, nipu_
  { {0x2d990005,0xdd910003,0xb2290003,0x3ce90133}},	//   tise_, قود_, _لأنك_, žave_
  { {0xdb180028,0xc6930009,0xd83f0073,0x61e52375}},	//   ilví, מאת_, ščiu_, _ruhl
  { {0xa8770012,0x63b50031,0x69dd2376,0x44222377}},	//   _محور_, tozn, _rise, guk_
  { {0x09bf0044,0x69dd0005,0xdfd00003,0x7bde00b6}},	//   ्ष्य, _sise, _بيت_, _cipu
  { {0x5fbb000b,0x63b50ebc,0xead5003c,0x8e23004c}},	//   _רצונ, rozn, ровь, иjе_
  { {0xeeeb0081,0x7c22079b,0x365b0009,0x44222378}},	//   _đống_, kuor, _טכונ, buk_
  { {0x200f000f,0x69dd045d,0xb7bd000d,0x3cf80012}},	// [5df0] égi_, _vise, suţe, _صعيد_
  { {0xe7190003,0xe8ff0061,0x68fb2379,0x78bd0042}},	//   ئيات_, _août_, zbud, _vysv
  { {0x4fc40015,0x7c3b237a,0x8f1b0009,0xa3b20011}},	//   сста, _spur, תובת, टकर_
  { {0xe8ff0061,0xe4d90003,0x69c017c7,0x714700b3}},	//   _coût_, نوات_, jlme, _схож
  { {0x6ee70003,0xe3b10012,0x28070030,0xb47c0024}},	//   _مسأل, يرت_, átně_, нкцi
  { {0xaa150046,0xab62003a,0x289a0009,0xa3d80011}},	//   афиј, şünm, _יירא, िषय_
  { {0x45d5003c,0x4422237b,0x69c009b8,0xdb0607ef}},	//   _вовс, zuk_, flme, ðmál
  { {0x7de1001e,0x200d0051,0xc692000b,0xe8ff0061}},	//   _mēst, tsei_, _ואל_, _goût_
  { {0x64490006,0xf8b50037,0xa1560001,0x39a10010}},	//   _usei, ंथिय, рању_, gėsi_
  { {0x25a90005,0xe7b20003,0x6c840003,0xe7390001}},	//   _ajal_, يميد, _الكم, њен_
  { {0x66cf0031,0xe7320009,0x02a70451,0xf1fb0012}},	//   dóké, חֵר_, _срам, _أعطت_
  { {0x442200ec,0x7d0b002c,0xdb0e0004,0x01fa0009}},	//   tuk_, nags, robí, _יפעל
  { {0x0c23022a,0xdb0e0030,0x99d40012,0xe5880009}},	//   омян, sobí, _اتلا, רָתָ
  { {0x88c8002d,0x7df3000d,0x68e2237c,0xe4520009}},	//   _слів_, _răsf, _zgod, קֶר_
  { {0x44220ba9,0x0219002d,0x03a30015,0x8f9a0009}},	//   suk_, літь_, циро, _שיצי
  { {0x4422237d,0xfaa30024,0x7c961896,0x65930a36}},	//   puk_, іато, _вроц, _мају
  { {0x55bb000b,0x90a50003,0x7d0b0de9,0x8c4604b3}},	// [5e00] _במקו, محكم, dags, _тепе
  { {0x6fc20029,0xa3ba0012,0x547b0009,0x9b930012}},	//   môck, _جابر_, _סטיו, _وليت
  { {0x5ea60012,0x7d160030,0x6e46003c,0x99650035}},	//   جمال, _kdys, реез, zēš_
  { {0x2bb40037,0x63740054,0xf7690009,0x6b9c0060}},	//   ंकवा, _rànq, וק_, lirg
  { {0xd40302ad,0x5c03010c,0xdca6076b,0x24800031}},	//   оящи, ояща, шади, áim_
  { {0xd3b7002d,0x5bb70024,0xae060011,0xd378001b}},	//   алії_, алія_, वीडन_, _bića_
  { {0x7c22004a,0x7f3b000b,0xcb130009,0x5e780009}},	//   suor, _שעלו, קלה_, _גָּד
  { {0x66cf000e,0xada60434,0xfe710012,0x71660012}},	//   zóké, _табл, _عدّ_, شابك
  { {0xad1b000b,0xdb030051,0x21770009,0x251b0009}},	//   _שומר, elnõ, שתפר_, _שומא
  { {0x1be10302,0x1037000b,0xf8370009,0x3952008e}},	//   _गूगल_, סטים_, סנית_, hdys_
  { {0x0f57000b,0x9a6a0003,0x5a96085d,0x63b8237e}},	//   ביים_, _جمال_, _траф, movn
  { {0xd5b8007c,0xba9b000b,0xdb060028,0x63b80008}},	//   ися_, _בסבי, ðmæl, lovn
  { {0x28d20037,0xcff40048,0x98aa0035,0x66cf0031}},	//   देशि, _уплъ, īmēm_, tóké
  { {0x63b80082,0x4fb30012,0x8f530012,0xa87b00af}},	//   novn, _وصور, _وننش, _באדר
  { {0x41e7002d,0xda780014,0xb3450017,0xdce00066}},	//   ріга, аят_, leçã, _pomě
  { {0x7de10039,0x6edb000b,0x7edb000b,0xd6db0009}},	//   _vēst, _בחופ, _בקוצ, _בחול
  { {0x0f15002d,0x6b9c0052,0x63b80618,0x26c5094e}},	// [5e10] ймаю, birg, kovn, _šlo_
  { {0x7d1d0272,0xeeeb0020,0x29c1000e,0x9cd80009}},	//   _össz, _đồng_, tóak_, _דוחה_
  { {0xd6db0098,0xdfd80098,0x7d0b1173,0xc7b3000b}},	//   тта_, рът_, tags, קבע_
  { {0xfe370093,0x25a60061,0x8d740003,0x2d940024}},	//   שראי_, gnol_, يانا, оріс
  { {0xa3ae0044,0x7c840001,0xe5700012,0xb3450018}},	//   _कदम_, жује, بطل_, jeçã
  { {0x7f85000a,0xdb030061,0x63b8009b,0xf7850012}},	//   _السن, onné, govn, _السَ
  { {0x09f90003,0x752d000d,0x7d0b002c,0x6567004c}},	//   دفعة_, _ocaz, pags, _књаж
  { {0x212900c6,0xf3ff0017,0xe8180037,0xf9920009}},	//   ngah_, _ção_, _दिशा_, ּ֨ה_
  { {0xdb0e000e,0x3c440012,0x68fb005e,0xa3b705f3}},	//   őkés, _وَفِ, _õudu, जवा_
  { {0x9b74000a,0x23740003,0xab740003,0xf092000b}},	//   _والص, _والح, _والإ, פני_
  { {0x1d0a0345,0x32110002,0x7dca0097,0xfce60842}},	//   лени_, jszy_, lýsa, йоно
  { {0xaca3001a,0x443f00b6,0x645b237f,0x66030030}},	//   _ngừn, _kpu_, _krui, ánky
  { {0x7d092380,0xb3450017,0x7d040028,0xe0ce0594}},	//   _mees, ceçã, ðisi, _хв_
  { {0x0056000b,0x7d090cc6,0xd8d60009,0x443f016d}},	//   _לשנת_, _lees, _פוסט_, _mpu_
  { {0x7df3000d,0x15f50003,0xa2bb0321,0x6b9c2381}},	//   _băse, _استح, _शुद्, rirg
  { {0x7d090039,0x69cf17d8,0xf1a90012,0xd1320012}},	//   _nees, _chce, لاقه_, ثمر_
  { {0xa3d80037,0xed590029,0x3d0b0037,0x74130003}},	// [5e20] िषद_, ôže_, ारने_, _فويا
  { {0x4b26007c,0x753b000d,0xdfcf0003,0xf4570009}},	//   _умов, _abuz, فيق_, _פייר_
  { {0x6564014a,0xe7370015,0xa91d0010,0xd94600de}},	//   _knih, сех_, sižy, _лени
  { {0x7df3000d,0xf2d3000b,0x7c260066,0xd5b90024}},	//   _găse, _מעת_, oukr, асі_
  { {0x7d0d0065,0x3157000b,0xe4e5002d,0x63b8080d}},	//   ðasa, _היכן_, цієн, tovn
  { {0x53e5002d,0x69c42382,0xbcfb0031,0xbf160012}},	//   іціа, llie, njér, _دوسب
  { {0x8e860003,0x6d5a001e,0x3ce9080a,0x7d090070}},	//   _الأه, ētaj, žava_, _fees
  { {0xa91b0028,0xb3450017,0x6d460027,0x63b802a1}},	//   _alþj, teçã, jeka, sovn
  { {0xc953000b,0x6d462383,0x23e50024,0x49730024}},	//   למה_, deka, _дієв, їльс
  { {0x69c4008b,0xb3450017,0xa6140021,0x44262384}},	//   hlie, reçã, омоч, muo_
  { {0x0f57000b,0xdceb02a1,0x6ac60012,0xa2bf0011}},	//   זיים_, žičn, _اقام, _लुप्
  { {0x26c2001e,0x63700032,0x61fc0159,0xda650012}},	//   āko_, _gänz, dprl, _باكي
  { {0x32110002,0x637d01a0,0x443f01a0,0x69c42385}},	//   wszy_, _sèni, ïu_, dlie
  { {0xf41f004a,0x44260010,0xd2460003,0x47d40012}},	//   rrä_, iuo_, ون_, _بيتر
  { {0x979b0009,0xf76f0012,0xbf9b0009,0x69c40e00}},	//   _תשוק, _ساو_, _תיוש, flie
  { {0x929b000b,0xf1940015,0x60f90015,0x69c42386}},	//   אילת, пись, рная_, glie
  { {0xdcfd0010,0x73c50012,0xc1040012,0x779906bd}},	// [5e30] nksč, _ويعم, ثوقي, акар_
  { {0x3ef8000b,0x32110002,0x3f87018a,0x7d092387}},	//   שִּׁ, pszy_, ónu_, _sees
  { {0xdcf90003,0x6440001e,0xcb12000b,0x2900172a}},	//   لفات_, _apmi, _קלט_, bbia_
  { {0x05c90037,0xd6d82388,0x645b0227,0x69c42389}},	//   रतिब, сту_, _prui, clie
  { {0x0c25002d,0x44261f4e,0xd469004c,0x7d090b55}},	//   імкн, guo_, риле_, _vees
  { {0x6d46003e,0xe81e0037,0xcec30066,0x58ba0009}},	//   zeka, _पिता_, _jiří_, _כמרצ
  { {0x4b7c000b,0xf1b9001e,0x2d820192,0x4a450024}},	//   רטוג, toš_, ykke_, інив
  { {0xceb2000b,0xa3e90037,0x4426002c,0x91e20014}},	//   _חיל_, यदा_, buo_, моще
  { {0x17f90003,0xd00e0012,0xd7e6003c,0x61e2016d}},	//   جربة_, نلي_, омые_, _diol
  { {0xbca4000a,0x3f9e00c6,0x69c4001e,0x7df3000d}},	//   _عملي, gitu_, zlie, _născ
  { {0x27e300bd,0x798d00b6,0xa1190003,0xb2ab0232}},	//   _mijn_, khaw, _نقاط_, _стаж_
  { {0x68e2007a,0x9596002d,0x27e30070,0x3f9e00b6}},	//   žodi, ішні, _lijn_, aitu_
  { {0x2ec60044,0xe6c60037,0xef0e05c6,0x69c60011}},	//   _वर्त, _वर्ज, _ом_, ातरी
  { {0xd3ba002d,0x7e7e004a,0xf1bf0029,0xaae50012}},	//   румі_, yypp, _aká_, كسفو
  { {0x6d4615c9,0xe1660012,0x25bf0060,0x63a40025}},	//   peka, يدري, _okul_, éini
  { {0xddc305cc,0x65c302ad,0x6d96001b,0x290b238a}},	//   _общи, _обща, ešav, _ceca_
  { {0x6bd60012,0x387f016d,0x2fda0012,0x290b238b}},	// [5e40] _وتخر, nyur_, لورد_, _deca_
  { {0x7fd50024,0xb6a6019c,0x69c4238c,0x91f60012}},	//   піхі, оизл, slie, _وأجا
  { {0x6e460012,0x69c4238d,0x2b4701a0,0x75490031}},	//   تنام, plie, denc_, _észü
  { {0x302a002d,0xa802003a,0xe45a06fd,0x3f9e0064}},	//   _комп_, çıkl, иже_, zitu_
  { {0x201900d9,0xfc2f0012,0xe2f80024,0xa3ae0011}},	//   ásil_, نحو_, белі_, _कदा_
  { {0xd3d70012,0x44221491,0x7de50073,0x78a4238e}},	//   يبوا_, irk_, _pėst, _živo
  { {0x018a0024,0x63bc00b8,0x3f9e0c51,0x973c001b}},	//   ищий_, iorn, vitu_, niće
  { {0x27e301e4,0xeb9f0033,0xdb03170f,0x3d040011}},	//   _zijn_, nsør_, fonó, लरों_
  { {0xa8470012,0xf5570012,0xdb1808ca,0xdb0308f4}},	//   قليم_, _بلقب_, hové, gonó
  { {0xdfd00003,0x3dc6238f,0xdb1800d9,0xaac00011}},	//   عيد_, llow_, kové, _शुभक
  { {0x63bc006f,0xcdd4000b,0x29560014,0x7df3004b}},	//   dorn, ּךָ_, _мъдр, _răsc
  { {0xc05a002d,0x20060002,0x973c001b,0xdb1803a7}},	//   _вік_, _twoi_, diće, dové
  { {0x83fd000e,0x290b00b8,0xdb030478,0x3f9e1cf0}},	//   _erőf, _reca_, conó, pitu_
  { {0x33f00054,0x46140003,0xc2140009,0x27f90064}},	//   _màx_, _فوتر, ּהּ_, ísne_
  { {0xfe6f0003,0x7ac400fa,0x66b30024,0xc2c50012}},	//   _لدي_, дсте, _обшу, سيري
  { {0xdb18006f,0x27e30227,0x3f8a2390,0xc5f700ae}},	//   llvä, _sijn_, _albu_, _بعوض_
  { {0x05d40012,0x3ce9005e,0x8ae70024,0x27e30227}},	// [5e50] _تزوج, _igav_, _мінл, _pijn_
  { {0x973c0027,0xa8570009,0xdb180042,0x3dc60132}},	//   biće, חימה_, bové, elow_
  { {0x6e28012e,0x78a404d2,0x22590012,0x6da4001b}},	//   nudb, _živl, _الجد_, rđav
  { {0xa9270003,0x85e80024,0xe4510012,0x27e30227}},	//   _بعده, ідів_, فضت_, _wijn_
  { {0xdfdb0098,0x3ce9009b,0x3c470003,0xdc98002d}},	//   _във_, žavo_, تضاف, овці_
  { {0xa87a0093,0x7d0d002a,0x7df3000d,0x50da000b}},	//   _האשר, _leas, _lăsa, _לקרא
  { {0x51f50012,0xaa880012,0x31790034,0x4ea4004c}},	//   أستر, ينهم_, _kosz_, _жрта
  { {0x386d03eb,0xa0590003,0x3949171b,0x63bc1459}},	//   txer_, مؤخر_, neas_, zorn
  { {0x7bc7048b,0x73c50012,0xb4670012,0x973c001b}},	//   klju, _فيرم, _بدأه, ziće
  { {0x1b78000a,0x637d0054,0x6a670012,0x5f450012}},	//   _وصلة_, _cènt, _وطال, أندل
  { {0xa2bb0044,0x98ab003a,0x63bc0082,0xb4b40037}},	//   _शुल्, ıcı_, vorn, _जुड़_
  { {0x973c0027,0x7d0d2391,0xdb032392,0x6d960159}},	//   viće, _ceas, ponó, jšat
  { {0x80690003,0x7d0d000d,0x4c830048,0x63bc2393}},	//   _دمشق_, _deas, еляв, torn
  { {0x70520003,0xdb1801bd,0x27ff1c17,0xf0920009}},	//   _أنوا, tové, mpun_, _אנד_
  { {0x7d1b0027,0x91fc001e,0x63bc006f,0x7d0d2394}},	//   _odus, _grād, rorn, _feas
  { {0x6d960010,0x867a0009,0xfe700012,0x7d0d0227}},	//   tšau, _לרצו, _جده_, _geas
  { {0xa2a20044,0x53a60015,0xa0670345,0xdb180042}},	// [5e60] _केन्, _наиб, пата_, sové
  { {0xdb0a006f,0x7d1b000d,0x47c3002d,0x79840002}},	//   llfö, _adus, ебув, skiw
  { {0x6b81003a,0x4b7b000b,0x8a59001e,0xf6230345}},	//   ölge, _האיו, šējā, едхо
  { {0xdd99002d,0x25a20030,0x361a0009,0x6d562395}},	//   оші_, nikl_, מועד, _jaya
  { {0xdd8f0003,0xe4e3002d,0x14ba0003,0x29120de5}},	//   دون_, нішн, حداث_, maya_
  { {0x6d5600c6,0x7d1b0872,0xa3b20011,0x2d9908cf}},	//   _laya, _edus, टकट_, érez_
  { {0xed5a05fb,0x7d040097,0x3c360040,0xdb0301a0}},	//   _лов_, ðiss, hæv_, tonò
  { {0x7de80013,0x6e280248,0x645a0035,0x91f50081}},	//   _měst, vudb, ātij, _tŕn
  { {0x7d0d1160,0x61e601cf,0x291200b6,0x7dda0030}},	//   _reas, _mikl, iaya_, _důst
  { {0x7d0d0666,0x74130003,0x291200b6,0xabfb0009}},	//   _seas, _أولا, haya_, _להמר
  { {0x7bc7001c,0x6d560160,0xc7b9000e,0x7c240010}},	//   vlju, _baya, mről_, šird
  { {0x6e280058,0xc7b9000e,0x29122396,0x29d30012}},	//   rudb, lről_, jaya_, _كيلس
  { {0x291200c6,0xdb1c0028,0x2177000b,0x6d560225}},	//   daya_, ilræ, _מתאר_, _daya
  { {0x7dda0013,0xe2f80024,0x466a0048,0xc7b90031}},	//   _zůst, зері_, _грим_, nről_
  { {0xdcfd001e,0x2912003a,0x2f3b0009,0x4f3b0009}},	//   aksā, faya_, _הגוד, _התוע
  { {0x2912002c,0x58bb0012,0x25a2001b,0x6d5601a6}},	//   gaya_, ماذج_, cikl_, _gaya
  { {0xc7b9000f,0xdb1a09f9,0x61e600b6,0xa40b0011}},	// [5e70] kről_, _aktí, _dikl, _सौंप_
  { {0x394902d1,0x4439001e,0xd8740003,0xc66b003c}},	//   seas_, mts_, راقب, йшее_
  { {0x4b7c000b,0x29121860,0xcdd50009,0x394901e3}},	//   _לאזו, baya_, ֵךְ_, peas_
  { {0x2019000e,0x7ddf0f31,0x21000159,0x44392397}},	//   ásik_, _būsi, nčič_, ots_
  { {0xc952000b,0x43950447,0x7dda0030,0x44392398}},	//   _סמך_, мадс, _růst, nts_
  { {0xbb420014,0xf4580009,0x44392399,0xcc580009}},	//   вешк, פיור_, its_, פסוק_
  { {0xc7b20009,0xdce80060,0x91fc0035,0x4439096c}},	//   _סבל_, _çoğa, _arāb, hts_
  { {0xe8180037,0x8065022a,0x4439239a,0xb5a40024}},	//   _दिखा_, движ, kts_, _зруй
  { {0xdce00039,0x27ff00b6,0x6d4b1110,0x6d5601eb}},	//   _domē, upun_, mega, _raya
  { {0xe619002d,0x3c440012,0x0ea9003c,0x6d56239b}},	//   одо_, _سَمِ, жкой_, _saya
  { {0x6d4b0070,0x291207d0,0x63a3239c,0x6d56239d}},	//   oega, yaya_, minn, _paya
  { {0x9a880003,0x7c240027,0xb2ba000b,0x63a31033}},	//   _عَنْ_, šire, _ומער, linn
  { {0xd1b80003,0x4f950538,0xdb1c0025,0x6d5601e3}},	//   _عاما_, _орку, loré, _vaya
  { {0xa3cd0044,0xa3bf0044,0x69c9239e,0x6d560922}},	//   रति_, ीति_, llee, _waya
  { {0x0caa0037,0x29121147,0x63a3004a,0x4439239f}},	//   _कश्म, taya_, iinn, ats_
  { {0x27e70028,0x63a301a3,0x05660e63,0x4439036c}},	//   _hinn_, hinn, _цвин, bts_
  { {0x44390689,0xa3cd0037,0xd12f0003,0xa3bf0011}},	// [5e80] cts_, रता_, شمل_, ीता_
  { {0x62830029,0x291223a0,0xe3d60012,0xef1a0024}},	//   kyno, saya_, _تتبع, іме_
  { {0x27e70065,0x99d60003,0x291200b6,0x98c3001e}},	//   _minn_, _يتجا, paya_, īvāk_
  { {0x6f0e1f97,0x27e70051,0xa2b10011,0xcc8a0012}},	//   _webc, _linn_, _अख़्, يناه_
  { {0xc7b9000e,0xdb150031,0x6aa60011,0x7c2b0031}},	//   tről_, lozá, गप्र, gugr
  { {0xf6260046,0x290f0051,0x3991000e,0x39a5001e}},	//   _одго, _aega_, _lásd_, zēst_
  { {0xcf57000b,0xc7b9000e,0x6d4b04cf,0x2d8d0132}},	//   _קבלת_, rről_, bega, _flee_
  { {0xdb1c006f,0xc7b9000e,0x63a300b6,0x69c90e80}},	//   llrä, sről_, ainn, glee
  { {0xdb15000f,0x274a04ac,0xcf260012,0xab5c0035}},	//   hozá, очно_, وردي, _ekļa
  { {0xdb15000f,0xf6980001,0xb23a0012,0x61fe001b}},	//   kozá, звој_, _وكذا_, _otpl
  { {0xd12f0794,0x69c90804,0xdce0001e,0x466a002d}},	//   _их_, blee, _tomē, іром_
  { {0x27e70065,0xd56701b6,0x90460012,0xdb15017a}},	//   _einn_, фтоп, _يناه, dozá
  { {0x27e70dc7,0x5c740800,0x41770012,0x443923a1}},	//   _finn_, влят, _تمنح_, uts_
  { {0x44260149,0x6d4b0034,0xdfa60012,0x9f340024}},	//   iro_, zega, _تحصي, _чекі
  { {0x7c2b0052,0x443923a2,0x7d0d0097,0x47330012}},	//   zugr, sts_, ðask, _شروز
  { {0xd5b9001e,0xc7f90024,0xdce400d9,0xea000081}},	//   irāk_, знає_, _znič, _giật_
  { {0x90990014,0x62830002,0xc2eb0003,0x629a0029}},	// [5e90] чват_, zyno, _وعدم_, útor
  { {0x657b23a3,0x32550447,0x6e95096e,0xdb150031}},	//   _souh, _звор, низу, bozá
  { {0xe6590003,0x657b0066,0x44390f31,0x6d4b23a4}},	//   ثلاث_, _pouh, _ūs_, tega
  { {0x63a313c6,0x85040012,0x69c00034,0xfe060011}},	//   winn, نومن, jome, वीएस_
  { {0x6d5d0028,0x78fa0009,0x442623a5,0xcd980009}},	//   _ósam, _מפרו, gro_, ודאת_
  { {0xcf270012,0x6d4b23a6,0xca55004c,0x62830034}},	//   _ترحي, sega, етињ, tyno
  { {0x7dd60029,0x27e70033,0x63a31d9d,0xe7be0011}},	//   láse, _rinn_, rinn, ्तरप
  { {0x3cf90037,0x63a323a7,0x27e70795,0x8de50012}},	//   ंडों_, sinn, _sinn_, _أكره
  { {0x2019000f,0xb7bd000d,0x69c90070,0x80a900b3}},	//   ési_, luţi, rlee, явив_
  { {0xeafb0037,0xe7390001,0xc0520009,0x7ddf0035}},	//   ्रोत_, чео_, נזי_, _mūsu
  { {0x290f012e,0xd131000a,0xaa95000a,0x69d00037}},	//   _tega_, _مما_, _ثلاث, _डीवी
  { {0xceb2000b,0xdb0a00d9,0xfbc90009,0x69c023a8}},	//   ריט_, čník, _הת_, come
  { {0x394d00b4,0x70550012,0x0d830198,0x186900b5}},	//   mees_, _سنغا, улян, _хали_
  { {0x33d5002d,0xdb15000e,0xe51f0011,0xdce40159}},	//   віст, tozá, मृति_, _unič
  { {0x6b810028,0x28db0011,0xd946137b,0x395917ad}},	//   ölga, मेरि, неви, _bass_
  { {0x79a50001,0x394d0644,0xdb1523a9,0x6fcb0032}},	//   врђе, nees_, rozá, lüch
  { {0x3959032b,0xfc320003,0x8c9f0037,0x6d0b0009}},	// [5ea0] _dass_, _صحة_, _खेलो, _מִיַ
  { {0xa2bb0037,0x44260017,0xdc3b000b,0x996c0030}},	//   _शुक्, vro_, _צעיר, měť_
  { {0x7dca014d,0xd337000b,0xdfcf0012,0xf55a0009}},	//   lýsi, _אריה_, حيل_, ּדְמ
  { {0xfd120012,0x99800073,0x7dd60031,0x44260b6c}},	//   اجا_, čiū_, lásb, tro_
  { {0x8ba60014,0x14170012,0x6fb10011,0x69c60474}},	//   нидж, فينة_, ीकां, _ikke
  { {0xdb180013,0xb7bd000d,0xb607001a,0x8c1b000b}},	//   poví, buţi, _khớ, לוני
  { {0xe9e60867,0x599a0009,0x1c1c0011,0xd3370009}},	//   нцио, ּשִׁ, _निकल_, תרצה_
  { {0xf992000a,0x69c00079,0xd2590024,0x394d0644}},	//   طبع_, uome, ьці_, gees_
  { {0xf993000b,0x57a60014,0xdcef001b,0xcfa6046e}},	//   טרה_, ешна, _šeće, ешни
  { {0x389b000b,0x25a60054,0x8fa30001,0x5a961003}},	//   פיינ, liol_, лање, _преф
  { {0x1797000b,0x645600b6,0xcf930009,0xa3bf0011}},	//   גדיל_, _asyi, רטת_, ीतर_
  { {0xceb30093,0x2e380028,0xac19027f,0x6fcb0032}},	//   טית_, réf_, мому_, tück
  { {0x142a0009,0xa3bd0011,0x21750024,0x40340048}},	//   הוָ֑, इकल_, _шуфр, _релс
  { {0x6fcb008b,0x62980e6e,0x69c61171,0xa8570009}},	//   rück, ozvo, _akke, _ריגה_
  { {0x2d990108,0xeef7000b,0xaf5b0009,0xf7730009}},	//   ères_, _אמור_, _זכוכ, _תקצ_
  { {0x62980416,0x04950003,0x661a006f,0xf1a4002d}},	//   izvo, _للبح, mstk, грун
  { {0xb5070037,0xe89400b3,0x2bd20037,0x93470012}},	// [5eb0] _व्यय_, гать, _दीवा, _كخدم
  { {0x6d4f0002,0xb7bd000d,0x69c60028,0xd6db076b}},	//   leca, tuţi, _ekke, пте_
  { {0xa295002d,0x765a0029,0xf7700003,0x394d002a}},	//   _рані, _štyr, حاق_, yees_
  { {0x2d8b0013,0xe8210037,0xdb030061,0x63a723aa}},	//   nkce_, _मिला_, miné, lijn
  { {0x7655003e,0x2fd9000a,0xc916000b,0x6d4f000d}},	//   _wszy, _يوجد_, _בחרת_, ieca
  { {0x539c0009,0xc4d40009,0x7c3d0032,0x2bf80009}},	//   ּיהו, נגס_, itsr, עמון_
  { {0xa9240013,0xbd050061,0x41b50014,0xf6280024}},	//   ůžet, _créé, ксит, _піти_
  { {0xe2a8000a,0x6d4f0027,0x63a70070,0x6d5d0f00}},	//   عاون_, jeca, hijn, jdsa
  { {0x0c390012,0xc8db0011,0x6d4f23ab,0x7989016d}},	//   _زكاة_, मेंट, deca, rkew
  { {0x656d00a1,0xfd4d0020,0x9f850048,0xf745004c}},	//   _anah, _ngoạ, тгод, њено
  { {0x9f470013,0x6fcb0052,0x6d5b00e6,0xfb380012}},	//   _jiné_, rüch, _kaua, _سألت_
  { {0xdb180066,0xd1b80012,0xc2c40012,0xe5a60ef0}},	//   mová, _كانا_, _صيني, тими
  { {0x7dd6000e,0xdb181234,0x442f0052,0x6e280227}},	//   tásb, lová, nug_, ardb
  { {0x63a71528,0x8fa50024,0xc3550048,0xdb030018}},	//   gijn, _шале, лъсъ, conô
  { {0xc3320093,0xdb180066,0x69c60011,0xf6960012}},	//   יום_, nová, ातची, _لنوع_
  { {0x3a250065,0x61fc0031,0x38600412,0x5ee800af}},	//   álpa_, _érle, _širi_, _אַפְ
  { {0x61eb01a2,0xdb1800d9,0x7bc323ac,0x394017b1}},	// [5ec0] _migl, hová, konu, rfis_
  { {0xdb180013,0xdfcf0003,0x6fb30003,0xd00f0003}},	//   ková, قيق_, لمقا, تلك_
  { {0xe9da0046,0x60cb0010,0xa22a0014,0xdb180066}},	//   _око_, _lygm, _южна_, jová
  { {0xdb180013,0x8ab7000b,0x6d93003a,0x7589002d}},	//   dová, _יהיו_, _açab, нсів_
  { {0x99980066,0x7bc323ad,0xe70a00ae,0xeb9a11b0}},	//   ltrů_, fonu, _يتسن_, мид_
  { {0x661a0002,0xd7030014,0x5e260012,0x61eb0025}},	//   ystk, _взри, _لعرق, _aigl
  { {0xcb670001,0x82330003,0x442f0071,0xdb180030}},	//   таје_, لريا, aug_, gová
  { {0xdb1c2201,0x6d4f01a0,0x69c41b77,0x442f23ae}},	//   norâ, xeca, noie, bug_
  { {0x8c460001,0xbcfb0061,0xc7ba003c,0x443d0034}},	//   _језе, ndée, дён_, ctw_
  { {0x836a0012,0x7c650012,0xdb1808ca,0x5c370009}},	//   _تصرف_, _حافل, bová, _ברמן_
  { {0xdb1c0164,0x61eb00c1,0xf8bf0061,0xdb180145}},	//   gorí, _figl, _idée_, cová
  { {0xa1830015,0x3987005e,0x63a70227,0x6448004b}},	//   _вышл, _tõsi_, wijn, ădin
  { {0x20190013,0x709a0012,0x63a70227,0x26c20034}},	//   ásit_, _تنشأ_, tijn, łko_
  { {0x8fa30406,0xdb030025,0x62350024,0xaa590842}},	//   _каче, tiné, легу, нигу_
  { {0x91c70001,0x442f23af,0xc7d70009,0x63ad0025}},	//   вљал, zug_, _שווי_, éani
  { {0xe5c4002d,0xa806003a,0xe9b40024,0x656d020d}},	//   _всьо, ktığ, абсь, _unah
  { {0xdb180013,0x3dc90101,0xcd340003,0x7bc3003a}},	// [5ed0] zová, _ikaw_, _ضريب, yonu
  { {0x2fc7008a,0x2484143c,0x8c1c0009,0x3e070048}},	//   ông_, ämme_, _חוזי, вядв
  { {0x200200a2,0x6449008b,0xdb180066,0x7dd6000e}},	//   _etki_, _spei, xová, lása
  { {0xdb180013,0x35b50015,0xceb3000b,0x45340557}},	//   vová, ыбер, ביע_, ихіт
  { {0xef18001e,0x7bc323b0,0xdb03004a,0xfc3f1ef5}},	//   kaļ_, tonu, ynnä, ntí_
  { {0xa8560093,0xdb1c0164,0xdb180066,0x764a0058}},	//   _גישה_, yorí, tová, _opfy
  { {0x443d0002,0xa9a50d60,0x6b7c0009,0xda650012}},	//   stw_, ликд, ורגנ, طاغي
  { {0xdb180013,0xdb1c0064,0x61fe0030,0xceb20009}},	//   rová, vorí, ípla, _היל_
  { {0xdb180066,0xf7710003,0x11d60012,0x7bc323b1}},	//   sová, ماد_, دوية_, ponu
  { {0x2d9900bd,0x2f55002d,0xaf050015,0xdb180066}},	//   ëren_, утис, ыпол, pová
  { {0x6f150164,0x8f7a0009,0x99350012,0x225b0012}},	//   _mezc, תנתק, _مفات, _تجذب_
  { {0xed57002d,0x3ce90027,0xc1050012,0x6b8123b2}},	//   гою_, žavu_, _صوتي, _holg
  { {0x711a0093,0x28f80015,0x2d8023b3,0x808b0012}},	//   _נוספ, _речь_, _voie_, _تضاف_
  { {0xf7730003,0x395f19ff,0x9cd60009,0xe50a0011}},	//   _خاص_, ldus_, טורה_, _ह्नि_
  { {0xe29a04a5,0x7f3a0009,0x69c41628,0x321e068c}},	//   хав_, _נעקו, toie, éty_
  { {0x395f23b4,0x7dd60031,0x798d020d,0x7d190a8f}},	//   ndus_, bása, gkaw, jaws
  { {0xdfd20003,0xdb01000e,0x88c50012,0x99980030}},	// [5ee0] مير_, _emlé, لتكل, strů_
  { {0xd00f0003,0x395d002a,0x386f006f,0x66e60538}},	//   سلم_, _laws_, ågra_, гоза
  { {0x11d60003,0x6fd00248,0x41c30011,0x80aa0011}},	//   _متحد, läck, शवास, _जेने
  { {0xb5050003,0x29560014,0xa806003a,0xc5160003}},	//   لظهو, _съор, ttığ, ابات
  { {0xd91b000b,0xd8760003,0x251b0009,0xbd870012}},	//   _אוכל, _صاحب, תונא, طنون_
  { {0x8f76002d,0xb9070037,0xea00001a,0x7d160028}},	//   _сумі, ये_, _ngẫu_, _leys
  { {0x8a46000a,0xe2460003,0x2611009b,0x7dd6000e}},	//   ائتم, اختي, jšo_, zása
  { {0x7df3007d,0xa806003a,0x7d0d0065,0x75d60003}},	//   _găsi, ptığ, ðast, _إيرا
  { {0x6b81008b,0x351b000b,0x5b360003,0x2fc50052}},	//   _folg, _רומנ, _معار, folg_
  { {0xa8570093,0x6c830003,0x2ca70001,0xf62a002d}},	//   נייה_, _الْم, _скуп_, німи_
  { {0xd6d00003,0x20190028,0xd5b9001e,0x35b50400}},	//   تقد_, ásir_, krāt_, ибор
  { {0x7dd6000f,0x6d46006f,0x3866091e,0x4a570009}},	//   tása, _ökad, _tror_, _תשאל_
  { {0x2611009b,0x98a3013b,0x5b270055,0x71d70009}},	//   ašo_, _лице, льва, _עודד_
  { {0x752400c1,0x44200010,0x7d190002,0x7dd60074}},	//   _ediz, _dvi_, zaws, rása
  { {0xdcfb0013,0xe919002d,0xb595002d,0xfc3f1e14}},	//   _souč, кові_, _вийш, stí_
  { {0x6fd00052,0x7dd60031,0x32db0009,0xa1580476}},	//   läch, lásn, תחלנ, ласу_
  { {0x7ff70003,0x798d0c0f,0x0f150109,0x69dc0011}},	// [5ef0] اسرا, rkaw, имаю, _पठनी
  { {0x6fd00052,0x395f0010,0x2ba90011,0x798d0034}},	//   näch, zdus_, _औषधा, skaw
  { {0xb8cc23b5,0x644e009b,0x12fa000b,0xb5100011}},	//   _के_, čniš, _בהתב, ारूप_
  { {0x6b810623,0xa2ff0011,0x6fd00032,0x7bc723b6}},	//   _solg, ॉर्ज_, häch, loju
  { {0xf41f0006,0xd91a0009,0x6b810550,0x399e0030}},	//   nsä_, _שושל, _polg, růst_
  { {0x200900c6,0x3f8f001e,0x7bc703d3,0x93fc0009}},	//   mpai_, īgus_, noju, עלוי
  { {0x6b8100bd,0xa806003a,0x2fc50070,0x6f1a0027}},	//   _volg, rtış, volg_, datc
  { {0x91fc001e,0x395f1f85,0x20090035,0xd1850048}},	//   _grām, udus_, opai_, рлий
  { {0x3f83001c,0x395f0039,0x5d840003,0xc174000b}},	//   _koju_, rdus_, _القل, מחק_
  { {0x20540098,0xa8580009,0x20090073,0xe8480012}},	//   стър, ריזה_, ipai_, اجين_
  { {0x4420001c,0x3f8301bf,0x2d850061,0x7bc703d3}},	//   _svi_, _moju_, _îles_, doju
  { {0x629c009b,0x8afc0002,0xfce6072b,0xc27a0009}},	//   vzro, _wnęt, ионо, _ברעי
  { {0x3952004a,0x53a60012,0x7d1b0097,0xc8880012}},	//   veys_, لمحك, ðusa, _مخول_
  { {0x6fd0006f,0x889a007e,0xd6a90012,0xae990012}},	//   räck, _בבני, _لدعم_, _لضبط_
  { {0x3952004a,0xf53f0058,0x629c0027,0x9f470030}},	//   teys_, rnår_, uzro, _jiní_
  { {0xd132000a,0x6026002d,0x7dd6000e,0x2d990052}},	//   تمر_, идба, máso, chse_
  { {0x7bc7001e,0x7dd6000e,0xcef60001,0x20870055}},	// [5f00] boju, láso, ачењ, айти_
  { {0x753b000d,0x27ee0028,0x7bc7001e,0x661b0034}},	//   _acuz, öfn_, coju, _łuka
  { {0xed5a007c,0xd5b9001e,0xdb0e0002,0xee3a1e3f}},	//   кож_, prāt_, sobó, тне_
  { {0x3d100037,0x3abb000b,0x7dd6000e,0xe5720012}},	//   ारें_, _ימינ, zásn, غطا_
  { {0x3ad50020,0x66090066,0xf3e60015,0x63aa00b6}},	//   _áp_, _čeke, аждо, tifn
  { {0x7dd6000e,0x389b0009,0x9cd70009,0xe6060012}},	//   káso, _ייכנ, בונה_, _نظرً
  { {0x2b4700a2,0xd2500003,0x7ddd000e,0x5f790009}},	//   _önce_, سنة_, lése, _עָשׂ
  { {0x7dd6000e,0xd1300003,0x29000ece,0x6e930012}},	//   dáso, أمة_, ncia_, _بلفا
  { {0x7ddd000f,0x7df3007d,0x57f30015,0x7dd6000e}},	//   nése, _măsu, опыт, tásn
  { {0x2d8423b7,0xc43b0009,0x6fb40012,0x63ad0025}},	//   _home_, _בתמי, إمدا, éant
  { {0x61e40013,0x29000029,0xa3e30037,0x36f7000b}},	//   kmil, kcia_, नगर_, יצים_
  { {0x6fd00052,0x9a3b0009,0xdb1c0018,0x6442008e}},	//   säch, _יתבק, vorá, otoi
  { {0xc19b000b,0x94a8011d,0x7bc70d68,0x31ba0035}},	//   _בשאי, атра_, toju, cīza_
  { {0x764e0058,0x2484006f,0x7ddd000e,0x61e401b7}},	//   _opby, ämma_, dése, emil
  { {0xf41f03fc,0x7bc70039,0xdced0027,0xb062004a}},	//   ssä_, roju, _inač, äänn
  { {0x3d100044,0x7df3007d,0x2d8423b8,0xd1b80012}},	//   ारों_, _căsu, _nome_, لاقا_
  { {0x7d1d03d5,0xc1040003,0xed590029,0xc60f0037}},	// [5f10] mass, توقي, ôžu_, ाठ्य_
  { {0xe719000a,0x6e670014,0xe7330003,0x753b000d}},	//   ايات_, итеж, تصر_, _scuz
  { {0x6f1800a2,0x6442008e,0x80a70011,0x97570009}},	//   _mevc, etoi, _घेरे, שיבו_
  { {0x2d8405a3,0x290001a2,0x7d1d23b9,0x7ddd0031}},	//   _come_, ccia_, nass, lésb
  { {0x7dd6000f,0x995100f1,0x2fd90012,0xe8160011}},	//   záso, _náš_, _موحد_, दीदा_
  { {0x2bbb000a,0xb3c8002d,0xf4580009,0x6ee70012}},	//   خاصة_, аліз_, יידר_, _نسأل
  { {0xe695000a,0xb2220065,0x5e950003,0xcb14000b}},	//   _الأد, _áætl, _الأط, קלק_
  { {0xd2b80093,0x7dd80029,0x7dd6000e,0xf9910012}},	//   ילות_, písa, váso, ثبت_
  { {0x64420061,0x81a40012,0x7f190024,0x6006003c}},	//   ctoi, تحول, ліну_, бным_
  { {0x7dd60272,0xc0c80001,0x29190028,0x3f830028}},	//   táso, јуће_, _lesa_, ðju_
  { {0x7ddd0c1f,0x7d1d008b,0x201f0017,0x29000002}},	//   zése, fass, ssui_, ycia_
  { {0x7d1d000f,0x7db60003,0x7dd6000e,0x260c0011}},	//   gass, إصدا, ráso, डीटी_
  { {0x2d9e007a,0x515a000b,0xa5c70028,0xe8210037}},	//   ėte_, _תכנו, _slóð, _मिटा_
  { {0x3b950001,0xf4120009,0x7ddd124f,0xcff60009}},	//   ојст, הפך_, gésb, _פצצה_
  { {0xe2970046,0xe7160009,0xdcfd0060,0x29000064}},	//   бар_, _החצר_, ansı, tcia_
  { {0x7ddd0272,0xe9df0020,0xcc8a0003,0x61e42012}},	//   tése, _chú_, _منبه_, umil
  { {0xe0da0014,0xa9671103,0x2bba0003,0x29190a63}},	// [5f20] ува_, щита_, _مادة_, _desa_
  { {0xe47b015a,0x2d840036,0x656023ba,0xdf290003}},	//   _עריכ, _some_, _samh, لأمن_
  { {0x7ddd000f,0xc7d6000b,0x86c60012,0xd7ef0012}},	//   sése, צועי_, حيان, ركم_
  { {0x7ddd000f,0x4a5b000b,0x66030066,0x44260012}},	//   pése, _עדכו, ínka, مرتف
  { {0xf3f10020,0xdb01000e,0x853b0009,0xa3bc0011}},	//   _bị_, _emlí, רגני, _अदा_
  { {0x64420f4a,0xd7960012,0xdb0301a0,0xd00f0012}},	//   rtoi, _السخ, ginà, _سلف_
  { {0x2d8423bb,0x644223bc,0x20060034,0x171b0009}},	//   _tome_, stoi, _stoi_, _תולע
  { {0xed5a007c,0x7ddd000e,0x60f80014,0x154319f8}},	//   _щоб_, zésb, шния_, _несм
  { {0xf8af0012,0x44221b72,0x7d1d23bd,0x75d30012}},	//   ّةٍ_, jsk_, vass, _ريكا
  { {0x8ff70003,0x995100f1,0x63a40070,0x17f70003}},	//   حرير_, _váš_, ëind, حرية_
  { {0x9f94004a,0x34b80011,0x7c2211b7,0x7d1d1d3c}},	//   mää_, _अशुद, lsor, tass
  { {0x799b0070,0x7d02009b,0x69da0003,0xea770009}},	//   chuw, ncos, _صباح_, _לגבר_
  { {0x6f1e000f,0x3ced0051,0x7ddd000e,0x0cab046d}},	//   kapc, äev_, tésb, утни_
  { {0x7df3000d,0xce940014,0xa4b7000b,0x7d0400b6}},	//   _păst, _малъ, מלכה_, _efis
  { {0x99d70003,0xe9df001a,0xf7d70009,0xb9270048}},	//   مترا, _phú_, _הוגש_, йфай
  { {0x7ddd000e,0x1637000b,0x442f0028,0x61fa066c}},	//   sésb, _הנהר_, yrg_, _mutl
  { {0x9169001a,0x9f94004a,0x7ddd000e,0x99d40012}},	// [5f30] _hữu_, kää_, pésb, ستفا
  { {0x6fba0037,0x9f94004a,0x6fdd0061,0x9c18000b}},	//   ैकिं, jää_, pèce, _החזק_
  { {0xdfd80014,0x9f470066,0x9e15002d,0xe9df001a}},	//   сът_, _jiná_, ідді, _thú_
  { {0xfe700003,0x25b90028,0x3cf80012,0xc4f80012}},	//   عدل_, nnsl_, معهد_, معها_
  { {0x7c840001,0x0c240024,0x442f1dda,0x29d70018}},	//   зује, змін, urg_, nçam_
  { {0x9cd8000b,0xcb690001,0x8c1c0009,0xd61b0012}},	//   צוגה_, раке_, רוגי, _مترا_
  { {0xf3f10020,0xfbd00003,0x386913d1,0xc334000b}},	//   _vị_, رته_, lvar_, לוס_
  { {0x9915002d,0x1989003c,0xdb1c0018,0x3829004c}},	//   цькі, рбии_, porç, ажио_
  { {0x2eb90011,0x628e0034,0xb8560012,0x718c0009}},	//   _आशुत, zybo, قليص_, רְוַ
  { {0x6dbc017b,0x762511ed,0x464909c6,0x6fa9004c}},	//   nčan, омоз, азон_, рвог_
  { {0x98b900a2,0xcb120009,0x36c5003c,0x7c2423be}},	//   ısı_, _חלב_, юбог, _svir
  { {0x3cf00037,0xcb090009,0x1dc90011,0xf8750012}},	//   ुँचे_, _יל_, िकित, _وهاج
  { {0x5d670015,0x442423bf,0xf1d50011,0x7b02008e}},	//   циям_, ém_, _डीएन, _äytö
  { {0x7ddd000f,0x9f43004a,0x6dbc001b,0x628e0073}},	//   tésc, öjä_, jčan, tybo
  { {0x3869001e,0x1be70024,0x6d930060,0x29d723c0}},	//   evar_, ідси_, _açam, açam_
  { {0x7c2423c1,0x63ae016d,0x7c220031,0x7d1b23c2}},	//   _tvir, sibn, ysor, _neus
  { {0xef1a057b,0xc952000b,0x77860001,0x3f870457}},	// [5f40] има_, ומן_, олаз, _konu_
  { {0x3fe3002d,0xafdb024c,0x2d820604,0xde960012}},	//   джув, _spør, ljke_, يجاب
  { {0x9f940006,0xd6260003,0x291f0051,0xa2e60b05}},	//   vää_, تعذي, kaua_, _фонд
  { {0xceb2000b,0xb6ba000b,0xdb0300d9,0x216a0024}},	//   ויב_, בצעי, viná, _тими_
  { {0x9f9403fc,0x7c830015,0x1957000b,0x4c560012}},	//   tää_, дуще, _ובכל_, تضار
  { {0x7d021775,0x9afa0009,0xe7320012,0xbebc0035}},	//   scos, ׁפְח, _تصح_, rgīz
  { {0xe2970046,0x9f94004a,0x7c2223c3,0x6446005e}},	//   жај_, rää_, ssor, htki
  { {0x9f940006,0x764301a0,0x99f70009,0x6f1c23c4}},	//   sää_, ànye, חזקה_, _herc
  { {0xa3da0037,0xdb0323c5,0x9f941545,0x7dd60031}},	//   ़ता_, siná, pää_, másh
  { {0xff980046,0x7dd6000e,0x30170012,0x478a0048}},	//   ској_, lásh, آتية_, рсим_
  { {0x6146002d,0x0f57000b,0xf76f0012,0x45d5004c}},	//   _межа, חיים_, ئاً_, зонс
  { {0xd49b0024,0xeda70024,0xdb070064,0x65ab004c}},	//   арг_, ішно, rijí, ртог_
  { {0x7b670406,0xf3ff0018,0x656423c6,0x6d4023c7}},	//   отве, rvão_, _daih, _mcma
  { {0x60d7000b,0x69d60031,0xa0070012,0xb8070012}},	//   _וודא_, elye, _بقول_, _بيوم_
  { {0x6dbc0027,0xdb0e000e,0x8f9b0009,0xf9930012}},	//   včan, ójáb, _דיגי, وبر_
  { {0x65c40046,0x60f90015,0x6b8823c8,0x3f8716c0}},	//   _обја, сная_, _lodg, _zonu_
  { {0x7dd601c4,0x7dd80029,0x6f1c1d5d,0xe70b0012}},	// [5f50] dásh, rísl, _berc, لتان_
  { {0xdfd1000a,0x3f870028,0x3e6b0014,0x7d1b00b6}},	//   ريا_, ðnu_, ишен_, _seus
  { {0xd575064f,0xa3c00011,0xdb030060,0x7c2a0035}},	//   зуль, ीवन_, linç, _āfri
  { {0xdce0003a,0xd5b9001e,0x44391810,0x6b9a0032}},	//   _almı, ksām_, ous_, _altg
  { {0xa97a000b,0xd46900b5,0x317a0009,0x397a0009}},	//   _הארכ, силе_, _הארד, _הטרנ
  { {0xf1bf0065,0xd7fa000b,0x7dd6000e,0x5ffa000b}},	//   _hjá_, _להשל, tásk, _להשה
  { {0xdb15000e,0x443923c9,0x539c0009,0x6fd401a0}},	//   lozó, hus_, שיוו, càci
  { {0xd24e000a,0xe4e7002d,0x6dbc009b,0x3f87003a}},	//   اني_, _дізн, nčal, _sonu_
  { {0x25ad009b,0x443923ca,0xe9a80012,0xbd440012}},	//   _imel_, jus_, تدون_, _تنقي
  { {0xe7390001,0x753d23cb,0x93970012,0x398e0097}},	//   љен_, egsz, _بجرا, _hýst_
  { {0x80dd0037,0xc7b2000b,0x59bd0011,0x443923cc}},	//   _परवे, תבי_, ्कार, eus_
  { {0x6e2e000e,0xc1040012,0xdb150031,0x443923cd}},	//   ábba, _قومي, kozó, fus_
  { {0x65640006,0xea000020,0x8c4800a2,0x70fa000b}},	//   _vaih, _biết_, cağı, _ההנח
  { {0x7dd6000e,0x398e0028,0x61e923ce,0x3f81005e}},	//   zásh, _lýst_, lmel, _õhu_
  { {0x6446003e,0x67210027,0x471a000b,0x443923cf}},	//   stki, malj, _הוצג, aus_
  { {0x61e923d0,0x6f1c0002,0x443923d1,0x67210031}},	//   nmel, _serc, bus_, lalj
  { {0xe53b000b,0x212000b6,0x859b000b,0xe58b000b}},	// [5f60] _התפר, raih_, _לשקו, _הָיָ
  { {0xea00001a,0x91fc001e,0x4a460001,0x7ddd0031}},	//   _giết_, _krāt, _енов, nésn
  { {0x7dd6000e,0x69c10061,0xeab20003,0xbafb000b}},	//   tásh, élec, _سعد_, _להיש
  { {0x6f1c23d2,0x6d590480,0x7e620034,0x6fd401a0}},	//   órcz, gewa, łopo, ràci
  { {0x0b8a0098,0x17fa0003,0x25fd0037,0x6b880404}},	//   йски_, _درجة_, _रूसी_, _podg
  { {0x61e2120d,0x533400dc,0x03a30024,0xab27004c}},	//   _shol, фект, ничо, поља_
  { {0x67210470,0x8f9b000b,0x9f47004a,0x7d1b0028}},	//   dalj, _פילי, _minä_, ðusk
  { {0xb6bb000b,0xa8a60001,0x3ebb0009,0x79a3003c}},	//   _הצלי, зрок, _הצלב, ерье
  { {0x7df4007d,0xdca3111e,0x291d00b6,0x2bdc0037}},	//   _răsp, _зати, _dewa_, यतदा
  { {0x61e2002a,0xdc9b007e,0x81bc001e,0x4c9b01b0}},	//   _whol, _הסמכ, _zvēl, _השמע
  { {0xdb1c000e,0xe535003c,0xdd210073,0x8c480060}},	//   ború, мень, rįžk, sağı
  { {0xa2cd0011,0xc27b0009,0xdb030018,0x7c24001b}},	//   _दुष्, _לרבי, tinç, širu
  { {0x6f050034,0x9be70024,0x4439005e,0x7c2623d3}},	//   ychc, зівк, uus_, gskr
  { {0xf1bf0065,0x6d590002,0x443923d4,0x442623d5}},	//   _sjá_, zewa, rus_, iso_
  { {0xea000020,0xbef70003,0xf2c402ad,0xda78022a}},	//   _viết_, _عروض_, естн, пят_
  { {0xceb3000b,0x7c261ff1,0x443923d6,0x5e430012}},	//   _ריק_, bskr, pus_, _أَيْ
  { {0xea000020,0x91fc0039,0xa2cd0037,0xf53f024c}},	// [5f70] _tiết_, _krās, _दुर्, mgå_
  { {0x4c9c0093,0x6e950001,0x39b7004b,0x4fd40223}},	//   _לבחו, мизу, răsi_, ежут
  { {0x44290119,0xb81e0037,0x3f8a00d9,0xcb120009}},	//   _hva_, _मौसम_, _dobu_, _שלט_
  { {0x3ea10051,0xf53f0033,0x9cb50003,0x88bd0002}},	//   _ühte_, ngå_, ومات, naśc
  { {0xf8c10037,0x6b6501ef,0xe3650472,0xc867003c}},	//   _एशिय, дкла, дкли, _этни
  { {0x9f8f0051,0x291d00b6,0x6e3a0af2,0x6dbc09d2}},	//   nüü_, _sewa_, kutb, nčaj
  { {0x672100eb,0x7d060248,0x752d001b,0x0b160012}},	//   valj, ycks, _odaz, ذقية_
  { {0x44290416,0xd9e30037,0xceb2000b,0x61e9000d}},	//   _ova_, _कीमत_, _סין_, umel
  { {0xf53f0058,0x7ddd000e,0xdb180042,0x7dd800d9}},	//   dgå_, tésn, lový, získ
  { {0xa858000b,0x91fc001e,0xa0880009,0xd7bf0011}},	//   ליחה_, _prāt, לְתִ, ्विच
  { {0xdb1c0026,0x7c2923d7,0xdb1800d9,0x9f5f0025}},	//   porú, _hver, nový, nqué_
  { {0xc3290093,0x9f47004a,0x6136003a,0x67210027}},	//   _כו_, _sinä_, rülü, salj
  { {0x89340003,0x4c830014,0x7aed0066,0xdb180042}},	//   _أعما, вляв, žitě, hový
  { {0x99800026,0x6d41000e,0x7ae40066,0xdb180042}},	//   čiť_, őlap, řite, kový
  { {0x386d23d8,0xfbd20009,0xa3ce0011,0x6146004c}},	//   lver_, דתם_, रवत_, мева
  { {0xe9da007c,0x7dd80028,0xdd8f0012,0x09c80011}},	//   іка_, rísk, _نوى_, लवेय
  { {0xeafa0012,0xdfd20012,0x7dd80097,0x1f6601c6}},	// [5f80] _وردت_, نير_, sísk, мкам
  { {0x02d60012,0x386f0097,0x31790031,0xb17b00b0}},	//   _يتدخ, ægra_, _ensz_, _uhån
  { {0xdfcf000a,0x9f5f03eb,0x5b7b000b,0x15460015}},	//   جيل_, rquè_, _וריא, деем
  { {0x442613d0,0xe57a003c,0x7c290602,0x6fd4159b}},	//   tso_, юзе_, _bver, làct
  { {0x045a0003,0x386d0070,0x442622c3,0x9c5a0012}},	//   تجات_, jver_, uso_, تجاز_
  { {0xa3a80037,0xdb18014a,0x442623d9,0xf8b30009}},	//   खों_, bový, rso_, _ישר_
  { {0x7c290036,0x442623da,0x31ba001e,0x47d30012}},	//   _ever, sso_, līzi_, _شيفر
  { {0x32530098,0x61430046,0xd91a002d,0x39420051}},	//   твър, већа, цьк_, üks_
  { {0x39400051,0x6dbc0029,0x660d074b,0xcfaa0003}},	//   igis_, yčaj, _čaka, قادم_
  { {0x187b000b,0xada40002,0x83fd000e,0x26d8005e}},	//   קטיב, óźni, _erős, üroo_
  { {0x44290027,0x7c290029,0x0737000b,0x8afb000b}},	//   _sva_, _zver, ואים_, _והבי
  { {0x9a250003,0x569301d4,0x11da0012,0x7ddd0025}},	//   _أعلن, тают, _بوصة_, réso
  { {0x50e20037,0xf8e20037,0xf53f006f,0x2edb0037}},	//   _परिष, _परिय, rgå_, _भर्त
  { {0xa3ce0011,0x7dd60031,0xf53f0248,0xbbeb0012}},	//   रवि_, dásu, sgå_, ترجم_
  { {0xdce20029,0xa7570009,0xbda70012,0x6fdd0025}},	//   jkoľ, _חשוד_, _يحبو, iècl
  { {0x7520000e,0x6448004b,0x3f8e0097,0x2d840248}},	//   _nemz, ădir, öfun_, ömet_
  { {0x8b670003,0x98480048,0x6d5d23db,0x6c840012}},	// [5f90] _قادم, дяха_, mesa, _لليم
  { {0x6d5d21f1,0xdb1801bd,0xb7d50012,0xb7140012}},	//   lesa, tový, رقاب, نظمت
  { {0xfbdf0017,0xee380024,0x9df9003c,0x19950f21}},	//   ntêm_, днє_, чнет_, _заня
  { {0xfa96000b,0x9f5f190a,0xdb180042,0x63b523dc}},	//   _נדרש_, rqué_, rový, lizn
  { {0x31ba001e,0x80270003,0xac270015,0xc952000b}},	//   cīzi_, _ترجم, ффек, _עמך_
  { {0xf4140009,0x2484005e,0x61ed23dd,0xd9b90011}},	//   דפס_, ämmi_, lmal, ॉक्ट
  { {0x7ddd000e,0x6d5b0012,0x8e380012,0x6e2e0031}},	//   tésl, _وجرح_, _يسفر_, ábbl
  { {0x9f59014a,0x2d990070,0x386d001e,0x7c2923de}},	//   _musí_, jkse_, tver_, _tver
  { {0xa3df0037,0x386d0573,0x7c29142f,0xa2d60011}},	//   तता_, uver_, _uver, _मुन्
  { {0xbf1d0037,0x2d990070,0x0ea90015,0x7c3d005e}},	//   _फ़ोन_, ekse_, зкой_, dusr
  { {0x9a140024,0xc7a80012,0x7dd60031,0x39400073}},	//   _афіш, بديل_, zásu, ygis_
  { {0xe20a0028,0x6d5d23df,0x443d0227,0xa2940024}},	//   slóð_, gesa, ouw_, _шахі
  { {0xcd96000b,0xdb07004a,0x67250051,0x38580012}},	//   גדרת_, kijä, kahj, _يشهد_
  { {0x2d990051,0x91fc001e,0xf3e70012,0xdce20064}},	//   akse_, _krāp, طأ_, ykoľ
  { {0x6d5d00c6,0x6fd403eb,0xc4dc0037,0x0cdc0037}},	//   besa, ràct, _बर्ख, _बर्म
  { {0x7dd6000e,0x6d5d23e0,0x69db008e,0x645a004b}},	//   tásu, cesa, nlue, ătib
  { {0x26de077d,0x55bb000b,0x3fe60103,0x10150012}},	// [5fa0] _što_, _ממקו, ежав, َبْد
  { {0x2d9f004a,0x61ed004a,0x63b523e1,0x7dd60031}},	//   _alue_, amal, cizn, rásu
  { {0x443d0070,0xdee60021,0x2d9f064a,0x394000b0}},	//   euw_, хожи, _blue_, pgis_
  { {0xbd67002d,0xb5a90003,0x7ae1034f,0x61bd0011}},	//   ерше_, وانك_, ülte, ्कृष
  { {0x2004000d,0x7dd60bff,0xc9530009,0x6ab80011}},	//   _îmi_, láss, _גמר_, इप्र
  { {0x62810033,0x80af0011,0xd62a076b,0x6d5d1be5}},	//   ålog, ूपरे, _ноге_, zesa
  { {0xcb070003,0xa2d60011,0x35a60024,0x66e3005f}},	//   ريين_, _मुम्, _завг, _бора
  { {0xea000020,0x2449090d,0x6df60012,0x7ddd0031}},	//   _nhật_, búm_, _أكرا, tésm
  { {0xfafa0012,0x7cf60060,0xa3c00011,0x6d5d23e2}},	//   _فراغ_, _dürü, ंचा_, vesa
  { {0x999f0039,0x69db004a,0x7dd6000e,0x04570012}},	//   ārši_, alue, zást, _سلمة_
  { {0x61ed003e,0xcb8b000b,0x63b523e3,0xdd910012}},	//   ymal, _מְאֹ, vizn, لود_
  { {0x29d70054,0xba9b000b,0x69db10b7,0x7cf60060}},	//   nçat_, _מסבי, clue, _gürü
  { {0x6d5d23e4,0x2d9917c9,0xf98700ae,0x000000c4}},	//   resa, rkse_, _سنوي_,
  { {0xcf260003,0xb3640048,0x629523e5,0xc4d30009}},	//   _أرشي, лъск, tyzo, רגש_
  { {0xdb070006,0x66730003,0x7cf6003a,0x63b50550}},	//   vijä, _مدير, _yürü, rizn
  { {0x26db0093,0xd6db000b,0x62950002,0x7edb0009}},	//   _מקומ, _מחול, ryzo, _מקוצ
  { {0xdb07019a,0x69c013d6,0x4034076b,0x7c080012}},	// [5fb0] tijä, inme, летс, _كييف_
  { {0x200f0039,0x83190012,0x7dd623e6,0x8fa4004c}},	//   īgi_, _تقدر_, sást, гађе
  { {0x7dd61d0b,0x88bd0002,0x61ed0c07,0x4fc41832}},	//   pást, jaśn, pmal, уста
  { {0x7dd6000e,0x4cb90198,0x8cf50012,0xa63b0009}},	//   lásr, млею_, نكاش, לגבר
  { {0xdce0001e,0x644b0348,0xc0580024,0xcb69076b}},	//   _pamā, utgi, _пір_, дале_
  { {0x7cf600a2,0x6d110011,0x69c023e7,0x7dd60031}},	//   _sürü, _ड्रग_, enme, násr
  { {0xdddc000e,0xdb0a0028,0xab280003,0xd3d80012}},	//   _errő, kifæ, رسول_, ربها_
  { {0x69c023e8,0x11d90012,0x36d4003c,0x69db008e}},	//   gnme, بوعة_, _соср, ulue
  { {0xa1560001,0x7dd6000e,0x442b0002,0x88e50048}},	//   тању_, záss, jsc_, ъжие
  { {0x69c00070,0x69db004a,0x93e00037,0x7ddd000e}},	//   anme, slue, _खींच_, lésh
  { {0x29d70149,0x7cf6003a,0xea00001a,0x7dd6000e}},	//   nças_, _türü, _phật_, dásr
  { {0xfbc9000b,0x61cc0011,0x383506e5,0xa5960024}},	//   _ות_, ावृष, _андр, трощ
  { {0xb87b000f,0x7c2b23e9,0x7dd80066,0xc5f2000b}},	//   _szín, nsgr, míst, ידט_
  { {0x4fe8002d,0x33d5002d,0x7dd6000e,0xd7c80012}},	//   _змін_, гіст, táss, _كونه_
  { {0xea00001a,0x3f8e0028,0xdb15000e,0x25e30037}},	//   _thật_, öfum_, óbáb, _टीवी_
  { {0x25a000c6,0x442d0416,0x7d1b0028,0x316d23ea}},	//   _ulil_, _ove_, ðust, ndez_
  { {0xa3e40044,0x7ddd01c4,0x3946001e,0x7de50012}},	// [5fc0] नतम_, zésk, ļos_, _حسوم
  { {0x660311d7,0x672300b6,0x75240032,0x6ff20034}},	//   _kunk, _jenj, _heiz, _płci
  { {0x672300ec,0x395f004a,0x75240070,0x53370009}},	//   _menj, keus_, _keiz, _בנין_
  { {0x6603000f,0x2002004a,0xdd99002d,0x08fa0012}},	//   _munk, _tuki_, нші_, _يرحب_
  { {0x7dd80837,0xcfaa0012,0x29d723eb,0x395f23ec}},	//   díst, _قاسم_, aças_, deus_
  { {0xf413000b,0x7dd80028,0x442d0b54,0x57250012}},	//   ספו_, vísu, _dve_, _مرفق
  { {0xdb030006,0xdb1c0002,0x2480000d,0x442d23ed}},	//   ynnö, loró, ţim_, _eve_
  { {0x7dd6000f,0x752423ee,0x80dd0011,0xd1300012}},	//   zásr, _neiz, _परखे, حمة_
  { {0xf1b30093,0x69c00036,0x4fd4010c,0x67470028}},	//   יסה_, rnme, лжит, _þrjá
  { {0x29d708cc,0x1f730015,0xdb1c0029,0x925a0012}},	//   nçar_, алья, torý, _يشار_
  { {0xd5b90039,0xc7b3000b,0xa3d60011,0x75240032}},	//   ksāt_, שבת_, िकन_, _beiz
  { {0x63b80066,0x4439001e,0x25a60c0b,0x7dd80017}},	//   livn, trs_, nhol_, míss
  { {0x44390108,0x40340014,0x442d23ef,0x7dd6000e}},	//   urs_, _селс, ée_, tásr
  { {0x7ddd000e,0xccf30009,0xf7480012,0x61bd0011}},	//   zésh, יכר_, _ألغي_, ्क्ष
  { {0xa2d60044,0x75fa0013,0x7ddd0061,0x57fb0009}},	//   _मुद्, _různ, hési, _קלוו
  { {0x39a4002d,0x672823f0,0x7c2d23f1,0xd2570009}},	//   ашув, ladj, _tvar, כשלה_
  { {0x10750015,0x07090012,0xcfab0012,0xfc3f0840}},	// [5fd0] ылаю, فيذي_, وائم_, quí_
  { {0xcebb0001,0x67280027,0xf0e30037,0x0f140024}},	//   мље_, nadj, _खरीद_, имую
  { {0x442d001c,0xdfd80098,0xf3f00003,0xd6d10003}},	//   _sve_, тът_, _بأي_, حقا_
  { {0xceb3000b,0x29d723f2,0x6d93003a,0xfcab0009}},	//   סיף_, rças_, _açar, ֽיַּ
  { {0x212900b6,0x7ddd23f3,0x656d0872,0x493a0009}},	//   maah_, résh, _maah, _אגרו
  { {0xdd0300a2,0xbcfb000f,0xe6130003,0x7ddd000e}},	//   ırıl, ldés, _نشر_, sésh
  { {0x7ddd000e,0xeb92000b,0xdb12000e,0x8b580009}},	//   pésh, מָה_, ágár, דיוס_
  { {0x200b0149,0xaa560003,0x22560003,0xfac1001a}},	//   ício_, اليا_, اليد_, _đầy_
  { {0x672323f4,0x66030010,0x752423f5,0x316d10b3}},	//   _penj, _sunk, _reiz, rdez_
  { {0x6728219b,0xf092000b,0x6dbc0027,0x9f850863}},	//   gadj, צני_, učav, угод
  { {0x67230065,0xcb120009,0xd215004c,0x6fdd01a0}},	//   _venj, _הלב_, _смећ, nèci
  { {0xe81e0037,0x25d5000b,0x8aa421d7,0xc99b0012}},	//   _मौका_, רוֹן_, _труд, _تخطط_
  { {0xa3c703bf,0x91f6000b,0xac9a0003,0xa3c00011}},	//   _उदा_, _עמנו_, رنسا_, ंचल_
  { {0xd00e0351,0x5b790093,0xfc030138,0x9cd60009}},	//   _على_, ׂרָא, спро, רושה_
  { {0x15f50037,0x32050a5f,0xdf480012,0xdb1c0034}},	//   ेदार_, _july_, _شؤون_, woró
  { {0xdb1c0002,0x63b823f6,0x6dbc0008,0xbf9b0018}},	//   toró, zivn, nčat, _quên
  { {0x31600039,0xd5b9001e,0x88e60015,0x00e61f10}},	// [5fe0] reiz_, rsāt_, ужае, ужан
  { {0x6d4901b3,0xb81b0037,0x33660339,0xb4fb0009}},	//   _acea, पीएम_, _свог, _אלפר
  { {0x5276002d,0xb9c60012,0xd7ef0012,0xe7f60011}},	//   _супу, _مقدي, أكل_, ीदता_
  { {0x6d461dcc,0x6e2e000e,0xf2d3000b,0xb5da0012}},	//   ngka, ábbi, _לעת_, رباء_
  { {0x2d800002,0x63b823f7,0x69c423f8,0x25a623f9}},	//   _mnie_, tivn, mnie, rhol_
  { {0x7ddd0061,0x0a6a004d,0xf4570009,0x69c423fa}},	//   rési, ерии_, ריסר_, lnie
  { {0x63b823fb,0x645b004b,0x5fdb0009,0x69c423fc}},	//   rivn, _epui, _נחלק, onie
  { {0xc0340046,0x3834070f,0xb81b0011,0x8e970009}},	//   аниј, анир, पीऍम_, _גדלו_
  { {0xf9930093,0xa2d60037,0x4f660012,0xdb0a005e}},	//   מרה_, _मुस्, هادف, tifä
  { {0xbcfb000e,0x57b40024,0x6562005e,0x8f34004c}},	//   zdés, рбот, leoh, јенц
  { {0x539b000b,0x7bd50066,0x17570009,0x6442008e}},	//   _ריבו, vozu, נסטר_, luoi
  { {0xceb30093,0x04f50024,0x69d60132,0x6562008e}},	//   מית_, изню, joye, neoh
  { {0x69c423fd,0x23b50012,0x2d800034,0xdb180018}},	//   dnie, لمحس, _dnie_, vivê
  { {0x6d460101,0xd2460003,0x69c4037f,0x7f960025}},	//   agka, ين_, enie, _pâqu
  { {0x9f470066,0xcfb7000b,0xea00001a,0x5fdb0009}},	//   _jiný_, _תלוי_, _phạt_, _רחוק
  { {0xdb080028,0xdb0300d9,0x5eeb0009,0x6442008e}},	//   _umdæ, diný, _אַחְ, kuoi
  { {0xbcfb000f,0xa3e40037,0x60f90015,0x61fd001e}},	// [5ff0] rdés, नता_, тная_, _visl
  { {0xb4c30037,0xc8880012,0x6d490025,0x7d0f0031}},	//   ्थी_, دخِل_, _scea, lccs
  { {0x69c4208f,0x6dbc01bd,0xabfa0009,0x23fa0009}},	//   bnie, jčas, _שהתר, _שהתא
  { {0xdb1c0065,0x16380003,0x6a9a000b,0xd6d80447}},	//   lorð, اسلة_, _ישתנ, уту_
  { {0x3f9e0028,0x8b2502ad,0xd4d80024,0x7a110035}},	//   kktu_, адле, льші_, _māte
  { {0x3235002d,0x6fdd0054,0xdcfd001e,0x7bc300e6}},	//   ахис, pèci, eksī, unnu
  { {0xfe09001a,0xf9910003,0x798d0002,0x6b7c0009}},	//   _mắc_, قبة_, ojaw, תרונ
  { {0x798d00b6,0xf9910012,0x7c150024,0x3f9e0034}},	//   njaw, تبت_, _вдає, ektu_
  { {0x290d000d,0x6dbc0bb7,0x7f190024,0xf1b923fe}},	//   rcea_, ačas, кіну_, riš_
  { {0x04940003,0x81bc001e,0x69c40f62,0xd7ee0012}},	//   _الْح, _svēt, znie, وكي_
  { {0x7db60012,0xcfb60009,0x69c423ff,0x20020097}},	//   لصحا, שלתי_, ynie, íkir_
  { {0x58d50098,0x67270031,0xbca60012,0x7db60024}},	//   _коет, _lejj, لمجي, рсоц
  { {0x69d60108,0xfe090020,0x69c4001e,0xdb01101c}},	//   voye, _bắc_, vnie, _allé
  { {0x69c4003e,0xa6950001,0xc4f60009,0xb92b0081}},	//   wnie, _вриј, יזרי_, _thuỷ_
  { {0x6f7a0093,0x69c423fd,0xa2d60037,0x69d60061}},	//   _יְהו, tnie, _मुश्, toye
  { {0x2d802400,0x75d30012,0x69950024,0x6e3c0031}},	//   _unie_, _ويوا, брух, árbe

  { {0xd0070014,0xdb1c0028,0xff260001,0x7ddd000e}},	// [6000] иете_, borð, имао, tésv
  { {0x69c40039,0x2d800039,0x998d009b,0xef17026d}},	//   snie, ķiem_, češ_, иму_
  { {0xe8e20037,0x443d0002,0xbb3b000b,0x433b000b}},	//   _पर्च, erw_, _בעיי, _בעיב
  { {0xd6560009,0xe1ff0081,0xda7b0009,0x6442008e}},	//   ייעת_, _gió_, _סנכר, tuoi
  { {0x7ddd0e0a,0x9f4f01e3,0xbcfb0025,0x6fdd01a0}},	//   mést, _jugó_, ndép, lècu
  { {0xc477000b,0xba760003,0x649b000b,0x93b3002d}},	//   יתנו_, لاعت, כסנד, обіц
  { {0x200601a2,0xfe670003,0xeb97004c,0x29020073}},	//   _suoi_, _بد_, риј_, žkam_
  { {0x200601a2,0x0c3a0003,0x63bc1b7d,0xe1ef0012}},	//   _puoi_, _لكرة_, hirn, وسي_
  { {0xa3d60044,0x20060061,0x7cf10028,0x64a3120f}},	//   िका_, _quoi_, iðré, _дата
  { {0x200601a2,0xa857000b,0x4734022a,0x7d042401}},	//   _vuoi_, סייה_, щнос, _agis
  { {0xc986002d,0xeb970001,0x3f9e0028,0x98ab001e}},	//   _вули, _њих_, rktu_, ēlāk_
  { {0x200601a2,0x9980007a,0xfe09001a,0xc1070015}},	//   _tuoi_, čių_, _sắc_, _кэше_
  { {0xe4e7002d,0xa2da0011,0xe3d70012,0x6ce70024}},	//   рінн, _पुत्, لتسع, ріне
  { {0x99890026,0x69c80e90,0x889b000b,0xa3a4004c}},	//   čať_, éden, _בבדי, ојск
  { {0xdb1c014d,0x79820036,0xff17000b,0x9f37000b}},	//   rorð, _know, _דקות_, _כנגד_
  { {0x4efb007e,0xdce6003a,0x7bd801bd,0x98170012}},	//   _בלוג, akkı, hovu, لبطا
  { {0xfe090020,0xb6070029,0x629c002c,0x63bc2402}},	// [6010] _tắc_, _teší, ayro, birn
  { {0x7a0a0002,0x36d5003c,0x7dc80060,0xdb180248}},	//   _pętl, бозр, hısl, nnvä
  { {0x78ad000f,0x17f80003,0x41d60037,0x995c0066}},	//   szav, شركة_, डकास, _síť_
  { {0xeef7000b,0x7bc7009b,0xd4350012,0x66000031}},	//   במבר_, lnju, معتب, _cimk
  { {0x91fc0039,0x7ddd000e,0x7dd80029,0x65a60097}},	//   _frāz, léss, rísp, _jóha
  { {0x9cd8000b,0xd7952403,0xda650003,0x39490051}},	//   בודה_, _الآخ, ماعي, lgas_
  { {0x92640003,0x53380009,0xaa560012,0x39490035}},	//   قديم, בנון_, ملوا_, ogas_
  { {0x3949007a,0xe7eb0037,0x63bc1831,0xdb15099e}},	//   ngas_, _जीता_, zirn, nizâ
  { {0xe8f90015,0x629c0002,0xb1160012,0x30790012}},	//   ыли_, zyro, حقًا_, احبة_
  { {0xf7450046,0xf8b2000b,0xf7710012,0x39980097}},	//   љено, פשי_, ساخ_, _sést_
  { {0x59c70037,0x63bc009b,0x9f470054,0x02440012}},	//   रचार, virn, _sinó_, _وَكَ
  { {0xdeb6000b,0xcb090009,0x865a0009,0x41740012}},	//   מפתח_, _טל_, נדרי, _وانس
  { {0x39980066,0x63bc2404,0x3ce50011,0x39490aa0}},	//   _vést_, tirn, _औरों_, dgas_
  { {0xa01b0028,0xdb180061,0xb4e80037,0x9cd6000b}},	//   _kröf, tivé, _भरी_, מורה_
  { {0xd299007c,0x7ddd01c4,0x3a99002d,0x1ae6003c}},	//   атті_, tést, аттю_, совм
  { {0xdb180061,0x99f6002d,0x39492405,0x98a40035}},	//   rivé, сягі, ggas_, lamā_
  { {0xea000020,0xcc360003,0x351b0009,0xad1b0009}},	// [6020] _nhất_, _اربع, _גופנ, _גופר
  { {0x4477000b,0xb2260028,0x6566000e,0x69dd2406}},	//   _פעיל_, nmæð, lekh, _ekse
  { {0xe3c8001a,0x8cb40011,0xbebc0035,0x85060012}},	//   hực_, उज़रो, rbīg, موان
  { {0x99860003,0x60c90010,0x7ddd000e,0xa3c00011}},	//   _الحو, _žeme, lésr, ंचक_
  { {0xea000020,0x98a4001e,0x74130012,0x61e40060}},	//   _chất_, kamā_, كونا, mlil
  { {0x98a4001e,0x7ddd0031,0x69c10025,0x61e42407}},	//   jamā_, nésr, élev, llil
  { {0x6e960003,0x52370003,0xa7a70024,0xcb130009}},	//   _الزا, مسيح_, _укра_, הלו_
  { {0xdb15119d,0xa8140103,0x48140ae9,0x6d6201bd}},	//   vizí, одиш, омис, ítač
  { {0xc173000b,0x7ddd000e,0xa01b0052,0x61e40f8b}},	//   לחה_, zéss, _eröf, ilil
  { {0x64460051,0xe7b8004c,0xa0970009,0x98130012}},	//   duki, ргош_, צדיק_, أبيا
  { {0xdb18006f,0x7a150002,0x61e40773,0x11d6027f}},	//   rnvä, _kąte, klil, _людя
  { {0xc6930093,0x69c8000f,0xfc3f0029,0xacf90024}},	//   לאת_, édel, trí_, инну_
  { {0xe8940055,0x21770009,0x9f340024,0xe0850012}},	//   _фаль, _לתאר_, _делі, _وجهي
  { {0x7ddd000e,0x212000b6,0x98a4001e,0x58f70009}},	//   téss, ebih_, camā_, _המדע_
  { {0x0f570093,0xb2840047,0xd7bb000b,0x64460692}},	//   _היום_, пытк, _תצור, auki
  { {0x394903e9,0x672a0028,0x61e4002c,0x6446002c}},	//   ugas_, _hefj, glil, buki
  { {0xa2da0037,0x752f0002,0x87070003,0xad1c000b}},	// [6030] _पुस्, macz, مبال, _עוזר
  { {0xdb0f004a,0xb17b006f,0x752f0002,0xfe09001a}},	//   äjät, _skåd, lacz, _mắn_
  { {0xa6c80012,0xc3320009,0x8b880009,0xa1950365}},	//   موكل_, _קוט_, _הָרֶ, _данч
  { {0x752f003e,0x98a40035,0x69dd2408,0xcd2b0012}},	//   nacz, zamā_, _ukse, اسان_
  { {0x15f40003,0x87e70048,0x6738001b,0xf1c90081}},	//   أسلح, _гюве, _odvj, hạc_
  { {0x80dc0037,0xe2990e98,0x65660031,0xf45800af}},	//   _पड़े, иал_, zekh, ציור_
  { {0xa1890047,0x19890015,0x64460002,0x53380009}},	//   ибка_, ибки_, zuki, זנון_
  { {0x7ddd000f,0xfe09001a,0xea00001a,0x3f980028}},	//   zésr, _bắn_, _thất_, örun_
  { {0x660a0052,0xa01b0028,0xb4e80037,0x752f0002}},	//   _aufk, _drög, _भरे_, dacz
  { {0x61e400a2,0x6d4a003a,0xe7390001,0x3056000b}},	//   zlil, ılaş, јен_, קשתך_
  { {0x8aa70001,0x8b08000b,0x61e4031c,0x65660031}},	//   _урад, _הִנֵ, ylil, tekh
  { {0x6d4b2409,0x20190051,0x7d090010,0x7c24000d}},	//   ngga, _otsi_, žesn, ţire
  { {0x7ddd000f,0x2247000f,0xfe09001a,0x80c80037}},	//   tésr, lunk_, _gắn_, _रखें
  { {0xbea50098,0x98a20039,0xb6a50015,0x23ab0058}},	//   _малк, _nekā_, _милл, _føje_
  { {0x752f003e,0x92e90003,0x61e4240a,0x7ddd0031}},	//   bacz, مرفق_, tlil, résr
  { {0x69c906cb,0x7ddd000e,0x867a0009,0x212b0929}},	//   nnee, sésr, _כרצו, _cech_
  { {0xe9d7002d,0xb8860028,0x7ddd000e,0x200300b6}},	// [6040] іку_, mtíð, pésr, _biji_
  { {0xaadb0037,0xe73a002d,0x98a4000d,0x7a300031}},	//   _मुवक, реж_, lamă_, _jótá
  { {0x20190006,0xa6ca0003,0x97c50012,0x7dd60031}},	//   _etsi_, جوال_, ستكم, dász
  { {0xa2da0044,0x75d3000a,0x2247000e,0x69c1000e}},	//   _पुष्, ويلا, dunk_, élet
  { {0xdb15117f,0xb87b000e,0x938a04fb,0x7bdc0647}},	//   lizá, _szív, иска_, ooru
  { {0x660407f6,0xdce00066,0x7a150002,0x6d4b17cc}},	//   _liik, _zamě, _wąte, agga
  { {0x2247000e,0xb97a0009,0xada6003c,0xdb15240b}},	//   gunk_, ֹנִי, _давл, nizá
  { {0xf126007c,0xa9c3002d,0x66040051,0x8c46010c}},	//   цько, дськ, _niik, _мебе
  { {0x54ee0037,0x99580066,0xa2da0321,0xdb0803ee}},	//   _जरिए_, _též_, _पुर्, _omdø
  { {0x9182001a,0x752f0034,0x66ca0009,0x7c650012}},	//   iểu_, wacz, ֹמֹ֔, _عاقل
  { {0xf09f001a,0x7a11001e,0x877b0009,0x6bd70012}},	//   _ngàn_, _tāta, באיי, _بولس_
  { {0xd83f03a7,0x67210159,0x69db0c04,0xdb1c0602}},	//   íčku_, ablj, coue, hnrä
  { {0x660400b6,0xcce70012,0x752f0034,0x672a0097}},	//   _diik, تسدي, racz, _tefj
  { {0xbebc0039,0x67ef00c5,0xfbbc0037,0x69c0240c}},	//   rbīb, tøje, ्चिम, lime
  { {0xdce00066,0x200b00b6,0x7e2a002d,0xbae50003}},	//   _pamě, _suci_, _тіла_, سكري
  { {0xdb180017,0x7dd6000e,0x644001e3,0x7bdc001b}},	//   diví, zász, ámic, aoru
  { {0x3cf60037,0x69c0004a,0x2247000e,0x859c000b}},	// [6050] ेशों_, iime, zunk_, _כשהו
  { {0xa2d60044,0x75d2001e,0x6442240d,0xa08b0009}},	//   _मुक्, rāze, droi, יְבִ
  { {0x69c9004a,0x69c1000e,0x6dab0030,0x7c360064}},	//   ynee, éles, dřaz, _zvyr
  { {0x3f8e0028,0x8e08002d,0x2c5e001e,0xed580024}},	//   öfur_, інів_, kādā_, жої_
  { {0x0c24007c,0xd116000b,0x7c840001,0x04c80012}},	//   дмін, _מקרה_, дује, يومي_
  { {0x70fa000b,0xb09a000b,0x2247000e,0x389a000b}},	//   _להרח, _הישר, tunk_, _הישנ
  { {0x3f89001a,0xfb120012,0x6442008e,0x8cbb0011}},	//   _đau_, رويج, aroi, _शेरो
  { {0xa2ce0011,0x32160012,0x9dab0048,0x237b0034}},	//   _सशस्, أييد_, _тъга_, _żyją_
  { {0x7bdc00a2,0x66040005,0x2247000e,0xdb0e2239}},	//   yoru, _riik, sunk_, ribú
  { {0xca770012,0xf2070048,0x69c90227,0xd7f8004b}},	//   _واضغ, _дядо, snee, gmă_
  { {0xc7b2000b,0x69cf0034,0x7c360073,0x4d8a0012}},	//   גבי_, _ojce, _svyr, مَدُ_
  { {0x69c0240e,0xdb15000e,0x8e960009,0x26b60009}},	//   cime, vizá, לדתו_, פִים_
  { {0x7bdc240f,0x6604004a,0xb8860097,0x20b8003c}},	//   toru, _viik, rtíð, _мышь_
  { {0x44290002,0xa3b60037,0xe1f90010,0xe3c60012}},	//   _dwa_, चों_, lmų_, سْأَ
  { {0x66e20a15,0xa2d601e1,0xa6b40014,0xd6d70003}},	//   _поша, _मुख्, _осъщ, _بتشغ
  { {0x7bdc000d,0x60c90010,0x3f98003a,0x6e3a000b}},	//   soru, _žema, _soru_, _התקד
  { {0x8afc0034,0x7bdc2410,0xfe090081,0x51550557}},	// [6060] _zbęd, poru, _mắm_, ьтру
  { {0xfe09001a,0x3eda0003,0x6c7b000b,0x94bb0009}},	//   _lắm_, موذج_, _פריד, _למפת
  { {0xdfcf000a,0x3f980065,0x639b000b,0x386d0052}},	//   ديل_, _voru_, _הסינ, hwer_
  { {0x21020010,0xfe09001a,0xd5b90024,0xdd8f0012}},	//   _ačiū_, _nắm_, осі_, ُول_
  { {0x397b000b,0x394d1aeb,0xdd990064,0x845a004c}},	//   _הטכנ, dges_, _doň_, срет_
  { {0x7fd6002d,0x394d0052,0x98a40010,0x64422322}},	//   _хімі, eges_, namą_, rroi
  { {0x89d80003,0x27f70066,0xcb57000b,0x03ad000b}},	//   يوتر_, řené_, פסקה_, שׁוּ
  { {0xd6570093,0x7ae10052,0x7643000e,0x394d0262}},	//   _מילת_, ülti, ánye, gges_
  { {0x98a40010,0x752d00c1,0x044300f5,0xdb03005e}},	//   kamą_, _reaz, _петн, dinõ
  { {0xec37000b,0x98a40010,0x2c5e001e,0x6c330003}},	//   _מאמר_, jamą_, rādā_, _أفلا
  { {0xd7f8007d,0x6b880058,0x1df90015,0x1757000b}},	//   rmă_, _indg, жены_, הסיר_
  { {0x7ae5004a,0x65ab004c,0xddab05d8,0x25a61c3a}},	//   _ryht, стог_, стол_, nkol_
  { {0xf1b30009,0xa2c40011,0xf1c90081,0x764800b0}},	//   _אסף_, िपक्, oạn_, sudy
  { {0x083b0093,0x75ff001e,0xb4bd0011,0x661c0035}},	//   _פעול, _mūzi, _आधी_, _otrk
  { {0x1f5b000b,0xa75b000b,0xaf5b000b,0xdb0a0017}},	//   _הדוא, _הדור, _הכוכ, lifó
  { {0x19940014,0xe5f500ae,0xf1940557,0xf41f2411}},	//   нася, _تكبد, нись, ppä_
  { {0xe53c000b,0xa2be0321,0x6d3c0009,0xcdf80009}},	// [6070] _התחר, _वेस्, _התחנ, _צמחי_
  { {0xdefb0015,0x97150024,0x06fd0030,0x6d5d2412}},	//   бые_, ємец, čívá_, lfsa
  { {0xe1f9007a,0x36340003,0x3ea7000e,0xd6180003}},	//   ymų_, فرنس, ánt_, كتنا_
  { {0xceb3000b,0x25a6002c,0xa3b10011,0x6d4f0227}},	//   עיף_, gkol_, फ़ोन_, ngca
  { {0xeb990063,0xb97a0009,0x69cd001b,0xe44e0048}},	//   жил_, _ונרי, mnae, ъж_
  { {0x44780009,0xe4520009,0x2bdd0011,0x54780009}},	//   פעול_, דֶה_, यवधा, פגוע_
  { {0x394d03eb,0xe2960048,0xe1f90073,0xa1f50a36}},	//   tges_, дащ_, tmų_, мџиј
  { {0x6b880168,0x6d5d0070,0x69cd2413,0xdb030031}},	//   _endg, jfsa, nnae, nkné
  { {0xbf050044,0x7c970003,0xe1f90010,0xbcfb0025}},	//   रश्न_, _عشرا, rmų_, nféd
  { {0x6d48007a,0xdb1e0061,0x386d0002,0xdb01000e}},	//   ėdam, _empê, rwer_, _ellá
  { {0xdb080108,0x9d4604b3,0xc9870001,0x0f580009}},	//   _élém, менд, _нуди, ליזם_
  { {0x64590002,0x9f450061,0xb9c50012,0x24802414}},	//   otwi, illé_, _تقصي, _prim_
  { {0x7536000b,0x64590832,0xc7950012,0xc1040012}},	//   וארד_, ntwi, _يشتب, _كومي
  { {0x98140003,0x61e92415,0x70fa0009,0x68fa0009}},	//   _أبنا, llel, _והנח, _ולנה
  { {0x644b0065,0xea00001a,0x61e9004a,0x91e60229}},	//   hugi, _chết_, olel, дове
  { {0x25b70012,0x98a40073,0x24802416,0x7bc32417}},	//   _يهود_, samą_, _trim_, hinu
  { {0x91e302e2,0x200706db,0xdb18000e,0x09e31036}},	// [6080] тоте, _kini_, hivá, тотн
  { {0x68e6007a,0xdfcf0003,0x249f0052,0x1bfb0011}},	//   _vykd, ليق_, äume_, _एओएल_
  { {0x463a0015,0x7e560055,0xfaf20012,0x7bc32418}},	//   ючая_, ьтац, _جثة_, dinu
  { {0xea000020,0x26130017,0xceb20009,0x98ad0011}},	//   _đặc_, _mão_, כיב_, टनाए
  { {0x3ea6001e,0x3cc90009,0x26130081,0xb4db01a0}},	//   ņot_, ּלוּ_, _lão_, lgàr
  { {0x6ac90037,0xbf9b0025,0x69c40032,0x7bc32419}},	//   िपूर, _quêt, liie, ginu
  { {0x261305ab,0x644b007a,0x64590002,0x661c001b}},	//   _não_, augi, atwi, _utrk
  { {0x69c10037,0x61e9004a,0x61fb0ddc,0x1bfb0011}},	//   रोपी, glel, gmul, _एओऍल_
  { {0xc05a007c,0xa0670001,0xa50b000b,0x7bc3241a}},	//   цій_, дања_, _וּבִ, binu
  { {0x6b880058,0x2613001a,0xaa5a0012,0xb4aa0011}},	//   _undg, _bão_, _ولذا_, खनी_
  { {0xae0e0037,0x61e90010,0x2007013d,0x6446241b}},	//   िदिन_, blel, _dini_, erki
  { {0x61e2001c,0x26130018,0x91360012,0x7c22241c}},	//   _ukol, _dão_, _آراؤ, opor
  { {0x79fb000b,0xe4e4002d,0x6d5d0028,0x6ce4002d}},	//   _ולאח, вірн, rfsa, віре
  { {0x29020010,0x7e9a0012,0xaed40048,0xae0e0011}},	//   žkas_, _ونشر_, _полш, िदान_
  { {0x6446004a,0xc2c50012,0x69cd001b,0xa278004c}},	//   arki, ريري, tnae, мбру_
  { {0x26070044,0xdb07004a,0x06fd0066,0x7bc3000d}},	//   _सूची_, kijö, čítá_, zinu
  { {0x399b000b,0x7d0d0818,0x98140012,0x656b241d}},	// [6090] קימד, _igas, نبلا, vegh
  { {0xc8080020,0x645a000d,0x61e9000e,0x7c22241e}},	//   _bởi_, ătit, zlel, dpor
  { {0x2f380003,0x2bdd0037,0x4439001e,0x7bc3241f}},	//   بثقة_, यवसा, lss_, vinu
  { {0x765a004a,0x9afa0009,0x12fa0009,0x8afa0009}},	//   itty, _מפתח, _מהתב, _מהתי
  { {0xe2a60028,0xd46b0012,0x711a0009,0x2ca90031}},	//   öðva_, تحام_, _מורפ, áad_
  { {0x3f9c001c,0xdb180570,0xe667010c,0x200f0a12}},	//   _novu_, tivá, _отбо, _rugi_
  { {0x0b160003,0xc808001a,0x7bc31916,0xd3780034}},	//   رقية_, _gởi_, rinu, _dać_
  { {0x2bdd0037,0x4439001e,0xceb2000b,0x2007070c}},	//   यवहा, kss_, _עין_, _sini_
  { {0x26130149,0x3179003e,0xf7710003,0x7bc32420}},	//   _são_, _masz_, هاد_, pinu
  { {0x6a670003,0xbc680003,0x765a03ee,0xdb1c01e3}},	//   _يطال, _تمكن_, ftty, tirí
  { {0x6609007a,0xc4c9000b,0x75f60066,0x7c2d2421}},	//   _kiek, _פג_, háze, _awar
  { {0x99840003,0x31790002,0x26130017,0x1d0a0014}},	//   _للمو, _nasz_, _vão_, яеми_
  { {0x66092422,0xc5f200af,0x09b800ae,0xcdb600af}},	//   _miek, טדט_, _تطلع_, תפרה_
  { {0x26130017,0x889a000b,0xb09a0009,0x5f750012}},	//   _tão_, _מבני, _מינר, _ساتر
  { {0x36660098,0x44390052,0xe29a00b3,0xfbd20009}},	//   _защо_, ass_, чав_, אתם_
  { {0xa9280042,0x66092423,0x5e560012,0x89490012}},	//   drží, _niek, _أليس_, ِجلّ_
  { {0xa0670019,0x7c2d0002,0xdfd20012,0x69c400a8}},	// [60a0] ната_, _gwar, هير_, riie
  { {0xdb07004a,0x5c5b0009,0x44202424,0xdb0e2425}},	//   vijö, _צדיק, _iti_, nibü
  { {0x6ac90037,0xe1f20003,0x2f15000e,0xcb57000b}},	//   िपोर, _مسح_, _súgó_, _אסיה_
  { {0x66090002,0x76430031,0x44200073,0x7c222426}},	//   _ciek, ánya, _kti_, tpor
  { {0xb4aa0044,0x660910de,0x85130024,0x7e750031}},	//   खने_, _diek, уміє, _eszp
  { {0xd2500003,0x765a004a,0xa3d60011,0xa01b0810}},	//   لنت_, ytty, िकट_, _krön
  { {0x91ba000b,0xed6305b1,0x9b250024,0xc1ba0009}},	//   ּמִי, íží_, тфіл, ּמִש
  { {0xfce6002d,0xd1300003,0xdbd20051,0x865b0009}},	//   _зобо, جمة_, lüüs, _מדלי
  { {0x3998000e,0x21170012,0x3ce70011,0xc7c605f7}},	//   _kész_, رتيب_, _छुपे_, есни
  { {0x66090070,0xc43b000b,0xdbd20051,0xf43b0009}},	//   _ziek, _מתמי, nüüs, _מתמש
  { {0xc7b3000b,0x216a004c,0x7ddd0031,0xa96a004c}},	//   רבת_, _нижи_, mész, _нижа_
  { {0x7bc10026,0xdd12003a,0xa1ba0012,0x71730012}},	//   _zmlu, rüşm, _عطاء_, _مهما
  { {0x499b000b,0x938b0014,0x07a60345,0xc19b0009}},	//   _משאב, псва_, _падн, _משאי
  { {0x44391d2d,0xe6940012,0x5e940012,0x75f60030}},	//   rss_, _للتد, _للتط, váze
  { {0x6d40001c,0xdce0001e,0xf41f006f,0x0f7b0009}},	//   _odma, _kamē, kväg_, _מרגל
  { {0x7c2d0002,0xd5b90035,0x82340012,0xdb1c0018}},	//   _twar, opām_, طرفا, tirã
  { {0x7ddd000f,0xdd04000d,0x9182001a,0x9f6b0148}},	// [60b0] kész, ărăt, iều_, зрез_
  { {0x75f60013,0x6609007a,0xdb01004a,0x2cb3003a}},	//   ráze, _siek, _yllä, ındı_
  { {0x66090039,0x442d0002,0x07080012,0xa01b2427}},	//   _piek, _swe_, فيكي_, _grön
  { {0x7bc10013,0x7a88000b,0xdb070058,0xfd100012}},	//   _smlu, _נָתַ, thjæ, مجه_
  { {0x645d0005,0x212915b1,0xade80012,0xab950024}},	//   ntsi, mbah_, رفهم_, киді
  { {0x200a00a2,0x7ddd000f,0xcb660014,0x66090002}},	//   _gibi_, gész, ваше_, _wiek
  { {0x9e35002d,0x66090cac,0x4fd60009,0x43720012}},	//   _шевч, _tiek, _יושב_, شهير
  { {0x645d0005,0xceb80002,0xd8750003,0xa9220014}},	//   ktsi, dzę_, ناخب, адъл
  { {0x61ed002c,0x04c80012,0x70520012,0x3375004c}},	//   ilal, _كوفي_, لنيا, _игар
  { {0x644f2428,0x5ae70012,0xeafb0012,0x4420005e}},	//   duci, _كثاف, _فرضت_, _rti_
  { {0x273c0013,0x44200058,0x61ed0010,0xd5b9001e}},	//   lání_, _sti_, klal, apām_
  { {0xe0110037,0x30850003,0x2d9f0061,0xdb1c01e3}},	//   ़दाद_, _للصف, _joue_, dirá
  { {0x853a000b,0x2129009b,0x273c0066,0x6d410073}},	//   וגרי, dbah_, nání_, ėlap
  { {0xf8b6000b,0x61ed00b6,0x8fa21097,0xf74502bb}},	//   _בפני_, elal, _ваше, _реко
  { {0x245b001a,0x644f001e,0x3998000e,0x8db60024}},	//   hêm_, auci, _rész_, _аспі
  { {0x273c0013,0xc212000b,0x61ed2429,0x7aec000e}},	//   kání_, שהן_, glal, _öntő
  { {0x2d5a009b,0x62850052,0x644f0962,0xa2ce0011}},	// [60c0] _všeč_, _erho, cuci, _सशक्
  { {0x273c0013,0x7bc71187,0xdb1c01e3,0x61ed242a}},	//   dání_, ciju, birá, alal
  { {0x1dc60044,0x7ddd000e,0x290f006f,0xdb1807c7}},	//   _लगात, vész, _ogga_, nivå
  { {0x85060012,0xbd67004c,0x290f016d,0x7a030031}},	//   نوان, врше_, _ngga_, _főti
  { {0xbcfb000e,0xf41f006f,0xdb18008e,0x94730012}},	//   leér, rväg_, yivä, لدوا
  { {0x656f003e,0xe2f80024,0xdce00035,0xf41f0248}},	//   zech, нелі_, _samē, sväg_
  { {0x644f0002,0xdce0001e,0xcb130009,0x03a3004c}},	//   zuci, _pamē, סלה_, ријо
  { {0x28c70044,0x1677000b,0xf2d3000b,0x61e4004a}},	//   _रेडि, _בגלל_, יעו_, noil
  { {0xa9670001,0xdb180872,0x71e70012,0x7eab008e}},	//   тиња_, tivä, خفيف_, yöpö
  { {0x61e4004a,0x656f0052,0x644f001b,0xdce4001b}},	//   hoil, wech, vuci, _naiđ
  { {0x03a30046,0xdd910003,0x61e4004a,0x4256027f}},	//   _њихо, مود_, koil, _штат
  { {0xb5a7005c,0x75f80066,0x61e4004a,0x442600c1}},	//   трой, bíze, joil, opo_
  { {0xceb8003e,0x7f860003,0x61e4004a,0xb8570012}},	//   szę_, _للإن, doil, _للنص_
  { {0x442602d1,0xdb1c242b,0xf4130009,0x656f242c}},	//   ipo_, tirá, יפש_, sech
  { {0x764f003e,0x273c0066,0x1394002d,0xcb340014}},	//   ącyc, zání_, ширю, ресъ
  { {0x7bc7039c,0x1e970093,0x19b80003,0x645d0051}},	//   siju, _יכול_, نطقة_, ptsi
  { {0x7bc7007a,0x61ed06b0,0x657b020b,0xadd80009}},	// [60d0] piju, rlal, _rauh, _שוחח_
  { {0x273c06bc,0x7d1d0272,0x7643000e,0x57b40024}},	//   vání_, lcss, ányo, абут
  { {0xe45f004a,0xa6f8000b,0x75f61007,0xd6f80009}},	//   ltö_, תִּי, láza, תִּש
  { {0x273c0066,0x9c590001,0xa439011d,0x1c39003c}},	//   tání_, ешку_, езду_, езды_
  { {0xe45f004a,0x7544002d,0x4426002c,0x91ba0009}},	//   ntö_, рніз, gpo_, _נמשי
  { {0x273c0066,0x8bc70048,0xdced0035,0x6bd700ae}},	//   rání_, ъсед, _anaī, ختصر
  { {0xaa560001,0x82a40001,0x657b1642,0xe45f008e}},	//   гију_, ишће, _tauh, htö_
  { {0x16190037,0xf1c9001a,0x75f6022d,0x31b10064}},	//   _नंबर_, oại_, káza, _báza_
  { {0xfe0a001a,0x2d0f0037,0x600900b3,0xf1b40009}},	//   _mắt_, िशील_, нним_, יסק_
  { {0x777c03eb,0x25a0002a,0x53b70321,0xaf75004c}},	//   _xarx, _soil_, _अतिश, ућић
  { {0xd1310003,0xd7a40037,0xadc3001a,0xdb1c0028}},	//   _هما_, _ओवरच, _giản, gnrý
  { {0x7db60003,0x63a1000e,0x4035022a,0x31b10064}},	//   اصدا, _holn, _бедс, _fáza_
  { {0xb6070028,0x660d242d,0xa7850012,0x90450012}},	//   _sjáð, _diak, _مشغو, _إنته
  { {0xb8820107,0xca76003c,0x69c9092c,0x628303a7}},	//   čítk, лубы, liee, ovno
  { {0xfe0a0020,0xc332000b,0x61e41531,0xbda60012}},	//   _bắt_, מום_, toil, _محظو
  { {0x443f001c,0x69c90070,0xfe0a001a,0xc5d60024}},	//   _ovu_, niee, _cắt_, _щіль
  { {0xc5fb000b,0x2283003a,0xe0da0014,0x20ca0012}},	// [60e0] _אפקט, _lık_, хва_, ربري_
  { {0x64970009,0x7c240060,0x26180011,0x69c901a4}},	//   _עדיף_, _itir, _बंदी_, hiee
  { {0x7e9a0003,0x86c60003,0x4d4a00f5,0x531b0009}},	//   عنصر_, ديان, епен_, _רוטצ
  { {0x35e5007c,0x25a00028,0xad260012,0xfe0a0081}},	//   аців, ðil_, ارضو, _gắt_
  { {0x69c60032,0xac94004c,0xcfaa0012,0x03a620e2}},	//   _imke, ралш, _كاسم_, лидо
  { {0xab770012,0x66e602ba,0x44261fbd,0xeb971e11}},	//   ُمنا_, _бога, rpo_, лич_
  { {0x3678000b,0x69c90070,0xae78000b,0x75f6000e}},	//   _בְּע, fiee, _בְּת, záza
  { {0x442601a2,0x60c9007a,0x69c90051,0x7c3d006f}},	//   ppo_, _žemi, giee, yssr
  { {0xc0960003,0x4c780009,0x7dc80031,0x60f80048}},	//   اجعت, _שָֽׁ, tűsn, ъния_
  { {0x47340001,0xdb05008e,0x75f607db,0x6d44242e}},	//   шнос, _ylhä, váza, _adia
  { {0xbebc001e,0x17f70003,0x7c240856,0x3f820030}},	//   icīg, درية_, _atir, ěku_
  { {0x386000a2,0xe9da002d,0x88860003,0x7a150002}},	//   ktir_, _яке_, _مؤتم, _wątk
  { {0x6384000e,0x443f242f,0x91f70009,0x26140011}},	//   zínű, éu_, _עמדו_, _नूरी_
  { {0xa87b0009,0x69c80025,0xfe0a0081,0xa01b0248}},	//   _נאור, èden, _sắt_, _fröj
  { {0xe45f004a,0x623500b3,0x3879024e,0x1f370009}},	//   stö_, ребу, _sssr_, _גרור_
  { {0x38600065,0x8e470003,0xbebc001e,0x6d5a000e}},	//   ftir_, _إليك_, ecīg, őtar
  { {0x98170003,0x2f19003c,0x89340012,0x473519c8}},	// [60f0] ابرا, возь_, إعفا, инас
  { {0xd1010037,0x3cfc0009,0x62882430,0x7bc50097}},	//   लेषण_, _אלחנ, _ordo, _umhu
  { {0xfe0a0020,0x95cb0001,0x63a12431,0xaac30011}},	//   _tắt_, нуда_, _roln, _वेंक
  { {0x673a000f,0xd6570009,0x3d0f0011,0xbdf700af}},	//   hatj, ריאת_, िशें_, נֶ֑ה_
  { {0x113a000b,0x2283003a,0xdb1c0051,0x386003e5}},	//   _שתשל, _sık_, birä, ctir_
  { {0x98880009,0xba750012,0x78110011,0x94040012}},	//   _עָרֵ, لابت, ़दीक_, مونه
  { {0x5b580093,0xea00001a,0x63a10cb8,0xe2990288}},	//   אשון_, _chặt_, _voln, тай_
  { {0x63a10002,0xe0450014,0x4c570003,0x629a008e}},	//   _woln, ании, _مضطر, ätoi
  { {0xc7950015,0xf994000b,0x5fb90011,0xa91d001b}},	//   арны, מרק_, _इताल, jdže
  { {0xb068000a,0xf092000b,0x673a000e,0xf745004c}},	//   اصيل_, קני_, gatj, јено
  { {0xf772000b,0x69c911cc,0x96b90339,0x93fa0009}},	//   חקי_, piee, тупу_, _סלעי
  { {0x60d60010,0x38600028,0xba9a000b,0xee3600fa}},	//   _žyme, ytir_, _בסעי, шню_
  { {0x27e50159,0x67d50024,0x8cc00011,0xe3c60012}},	//   poln_, _коду, _लेखो, لْحَ
  { {0xf771000a,0xbcfb0028,0x44240035,0xa01b0248}},	//   _ذات_, mfél, īm_, _tröj
  { {0xdb25000e,0x24890284,0x9e640012,0x6d400097}},	//   ásár, _eram_, _هاين, ómas
  { {0xe2060028,0xdb010017,0x38601073,0x24892136}},	//   _þótt_, _polê, ttir_, _fram_
  { {0xbcfb000e,0xfbdf0576,0x75f60031,0x24892432}},	// [6100] nfél, guês_, lázo, _gram_
  { {0xf772000a,0xc43b000b,0x6d5b01eb,0xee0e0011}},	//   غاء_, _שתיי, _acua, िद्ध_
  { {0x38602433,0xdff50198,0xf6d50024,0x539b0009}},	//   stir_, сять, біця, _סיטו
  { {0x38602434,0xa6130024,0xf6230024,0x69c60032}},	//   ptir_, іміч, ідчо, _umke
  { {0x27220066,0xdce40133,0x66022435,0x6e290159}},	//   nční_, _obič, rmok, _čebe
  { {0x026a01ec,0x6d5b2436,0x212d0064,0x21200159}},	//   вший_, _ecua, ebeh_, lcih_
  { {0x95960046,0xa596002d,0x66020010,0x7bca2437}},	//   _краљ, _кращ, pmok, rifu
  { {0x3869000d,0xdb010054,0x23690027,0x51860538}},	//   _ţara_, _molè, đaja_, рука
  { {0x673a000e,0xb9970015,0x75fd000e,0xdfa60003}},	//   tatj, рвых_, néze, لحدي
  { {0x07b80003,0xe2920012,0xff060024,0x62880159}},	//   اهدة_, _وذا_, иянн, _trdo
  { {0x24860058,0xdce00010,0xd3b9002d,0x7dc70012}},	//   lvom_, _pamė, _суті_, لتحك
  { {0x2486001b,0xa3c90011,0xdceb0035,0xa01b0032}},	//   ovom_, लोन_, legā, _fröh
  { {0xa3ca0044,0xa91d013c,0xfc3f01bd,0x19bb0009}},	//   _लगा_, udže, usí_, _במאב
  { {0x2d850002,0x69d62438,0xfd1f00c1,0x9be70024}},	//   śle_, enye, scì_, рімк
  { {0xf9c70098,0x19950014,0x6ffb0009,0xdb010061}},	//   ащан, бавя, _שהופ, _colè
  { {0xa5350015,0x2486001b,0xe9b40024,0x24892439}},	//   _унич, kvom_, обсь, ťami_
  { {0x87270012,0x24890031,0xd7aa0011,0x753d243a}},	// [6110] لعام, _uram_, _चकाच, masz
  { {0x753d0272,0x2fc70020,0xdf390003,0xe70b0012}},	//   lasz, òng_, اكات_, نتان_
  { {0x7515000a,0xf1c9001a,0x3ea7000d,0xd6180012}},	//   مواض, oạt_, ânt_, لتنا_
  { {0xb9950003,0x51950003,0x753d000e,0xc9950012}},	//   _الحب, _الحذ, nasz, _الحظ
  { {0x629a0029,0x24890018,0x000000c4,0x000000c4}},	//   ätov, íam_,   ,
  { {0x753d000f,0x368b0001,0xfbc40024,0xfe0a0081}},	//   hasz, _исбн_, обіо, _lắp_
  { {0x0bb80093,0xe1ff001a,0x3875003a,0xdd2c0010}},	//   שלום_, _khó_, şarı_, _lėšo
  { {0x22490604,0x3a380009,0x82d80009,0x63a50032}},	//   čak_, ברהם_, יווג_, _lohn
  { {0xf0a60048,0x75fd0031,0x78ad243b,0x0dc80216}},	//   йкъл_, kézb, nyav, _тури_
  { {0x67f00006,0x27950047,0x2019003e,0xab640034}},	//   täji, сшир, _musi_, ężki
  { {0xbebc001e,0x6be40003,0x92b40003,0x644f243c}},	//   ecīb, _بكلم, _وحما, erci
  { {0x39420028,0xed5700b3,0x75f60135,0xea000081}},	//   ókst_, бою_, rázo, _đắc_
  { {0x3f69011f,0xd1160009,0x59c40012,0xb0c70011}},	//   _било_, _הקנה_, _بينك, _रेलग
  { {0x2011003a,0x27220066,0x6b810051,0x02d60012}},	//   _nizi_, rční_, _jalg, متأخ
  { {0x24860029,0xa3f60009,0x6b81243d,0x25b30031}},	//   zvom_, ממשק_, _malg, ánló_
  { {0x66240003,0x27ed0002,0xa3c90011,0xe1ff0081}},	//   _بروك, ślną_, लोब_, _chó_
  { {0xb7160003,0x2120003a,0x2011003a,0x3ff60012}},	// [6120] مباش, rcih_, _bizi_, مكرر
  { {0xbf650012,0xc49b0009,0x2a690034,0x63a50032}},	//   قدمو, _עשית, łaby_, öhnl
  { {0xcf250003,0x6b7b000b,0x61e90feb,0x2011003a}},	//   ترقي, _גרינ, koel, _dizi_
  { {0xc27b0093,0x84460003,0xddd40029,0x2486243e}},	//   _ערכי, مختل, ťaži, tvom_
  { {0x61e90070,0x8d5b0009,0xeb100011,0x9f5800b8}},	//   doel, רכני, ाश्त_, _dirò_
  { {0x9f58003a,0x6ac50028,0x75f80064,0x6b81243f}},	//   örü_, _útfæ, cízn, _calg
  { {0xb2860015,0x9f45004a,0x9b430012,0x7f3b0009}},	//   сылк, illä_, سنيو, _תעלו
  { {0x75d60003,0x673e0865,0xdb072440,0x6444005e}},	//   _ايرا, lapj, nkjá, _ovii
  { {0xa3c90044,0x251b0009,0x189a0012,0x753d0031}},	//   लोड_, _תומא, اضعة_, vasz
  { {0xfe0a001a,0x907b000b,0x187b0009,0xc07b0009}},	//   _sắp_, נטיי, נטיב, נטיש
  { {0x7bdf0108,0xe2160003,0xa2d30012,0x6f790009}},	//   éque, _طباع, _فيكت, בְרו
  { {0x64420006,0x8cb50044,0xd6d70094,0xd5a60003}},	//   osoi, उनलो, сть_, ذف_
  { {0x8b030066,0xe4e7002d,0x753d04ff,0xd12f0012}},	//   ěřen, сінн, rasz, _أمه_
  { {0x3f82001e,0x69da122d,0x7d16000e,0x9cd70009}},	//   ēkus_, éten, _egys, מוכה_
  { {0x5e260003,0xcff7000b,0xe1ff001a,0x753d000e}},	//   _اعتق, _הצגה_, _phó_, pasz
  { {0x64420006,0x3835007c,0x201100a2,0x63a50052}},	//   ksoi, жнар, _sizi_, _wohn
  { {0x656d002c,0x3ec80010,0x90990048,0xb9240012}},	// [6130] _ibah, žutė_, шват_, سفلي
  { {0x10040048,0xc5f90035,0x69c50031,0xa91d2441}},	//   пяхм, itēm_, éhez, idža
  { {0xb8f00044,0x163b000a,0xdb010025,0x64420025}},	//   _वे_, اسطة_, _tolé, esoi
  { {0x6b8100e2,0x8d650024,0x201b0012,0x7afa2442}},	//   _salg, івле, _متسع_, ütte
  { {0x2019015e,0x6b810051,0x7ae4003a,0xa3bd0037}},	//   _uusi_, _palg, şitl, _आता_
  { {0xf41f004a,0xd2a90001,0xd6d7003c,0x1a29003c}},	//   yvän_, икле_, ́ть_, ажки_
  { {0xb16e0028,0x6b81062d,0xfaa20048,0x5155004c}},	//   _þýði, _valg, дащо, отпу
  { {0xd9fb0044,0xd9f90037,0x44292443,0xd2b80009}},	//   ्षित_, ंतित_, _ota_, מלות_
  { {0x764f0002,0x9f45008e,0xa01b0248,0xdb180030}},	//   ącym, yllä_, _eröv, livý
  { {0x3e7a0039,0x2011000e,0x2cb200b0,0xa3ab0011}},	//   _būt_, özi_, øyde_, कॉम_
  { {0x753b0070,0xc332000b,0x3f832444,0xb9e70024}},	//   _keuz, _חוב_, _maju_, _ліди
  { {0x7c2906bc,0xc329000b,0x5ee8000b,0x8c96002d}},	//   _kter, _יו_, מַרְ, оргі
  { {0x7641006f,0x645d006f,0xccfa0024,0x34fa0024}},	//   ssly, _åsid, рхні_, рхню_
  { {0xe6c50012,0xd6a90012,0xf807046e,0x79820034}},	//   _وتغي, _ندعم_, _учен, _zaow
  { {0x3e7a001e,0xdb1d000e,0x9c870107,0x613a046d}},	//   _gūt_, ózás, _počí, ичар_
  { {0x753b2445,0xaa570012,0x7bce0577,0x6442008e}},	//   _neuz, تلفا_, sibu, ysoi
  { {0xd5b9001e,0x691e009b,0x3f8300b6,0x20870109}},	// [6140] apās_, všeč, _baju_, ойти_
  { {0x2480003a,0x46f60229,0x88c50012,0x6fb90011}},	//   _isim_, очет, ستقل, इसिं
  { {0xfe720003,0x3f830027,0x69cb1e75,0xdfcf0012}},	//   بدء_, _daju_, _omge, خيل_
  { {0x213f00b6,0xf53f00e2,0x44290248,0x3ea70248}},	//   jauh_, lkår_, _yta_, änta_
  { {0x84330024,0x0c760012,0x43940189,0xdca30dd5}},	//   дніє, تداد, залс, маци
  { {0x1c39002d,0xa01b006f,0x7b66002d,0xdb180029}},	//   сяць_, _pröv, ітле, bivý
  { {0x96630188,0xd2500012,0x2258005e,0x290f0159}},	//   _окре, رنة_, nurk_, žgat_
  { {0xcb13000b,0x24800027,0x248d0989,0x2caf0033}},	//   ולו_, _osim_, _frem_, bygd_
  { {0x673c00c6,0xcf9a004c,0xb4250012,0x39402446}},	//   _kerj, ајн_, _فعلو, iais_
  { {0xc5f90035,0x75f60031,0x3faa004c,0x661c2447}},	//   rtēm_, lázh, рњим_, _kurk
  { {0x394009d4,0x673c2448,0x3ffb0009,0x44292449}},	//   kais_, _merj, שפיע, _sta_
  { {0x69da000f,0x63a800f1,0xe5c7002d,0x3ebe0028}},	//   étel, _hodn, існо, _ýttu_
  { {0x3940244a,0x97c60012,0x6fb60012,0x94a800ab}},	//   dais_, _وتتم, _ومصا, отра_
  { {0x10a30001,0x98a30001,0xa7fd000e,0x0aeb0012}},	//   _циљн, _циље, ltűn, لرأي_
  { {0xd13b1103,0x248005a2,0x0f570009,0x9a880048}},	//   иха_, _esim_, _ויום_, ощта_
  { {0x2d85001e,0x2d8403dd,0x224d244b,0x656d016d}},	//   ēles_, _name_, ček_, _ubah
  { {0x2bdb0044,0x673c244c,0x31690164,0xc7470003}},	// [6150] _बदला, _berj, rfaz_, قضاي
  { {0xf773000a,0xc72b002d,0xd7f10012,0x368b0048}},	//   بار_, ріал_, ركا_, исен_
  { {0x877b0009,0xcb880009,0x3940244d,0x673c0032}},	//   שאבי, _וְרֹ, bais_, _derj
  { {0x2d840036,0x46380003,0xe618002d,0x3940244e}},	//   _came_, تأكد_, іді_, cais_
  { {0xc19a000b,0x399a000b,0xc864065d,0x5064004d}},	//   _השרי, _הירד, _отри, _отра
  { {0xd0fa0037,0x75f601bd,0x547c0009,0x447c0009}},	//   ्धरण_, tázk, שְׁנ, שְׁא
  { {0x61e4012e,0x05770012,0xee780012,0xdb0709bc}},	//   čiln, _وارد, _وصفت_, skjæ
  { {0x2d84244f,0x75f600f1,0xdb050025,0x248d2450}},	//   _game_, rázk, _cohé, _trem_
  { {0xb3670014,0xdb1e004a,0x6579002a,0x8c250012}},	//   _мъжк, _ympä, mewh, _رفضه
  { {0x63a80034,0x2d840159,0x39400035,0x9f582451}},	//   _godn, _zame_, zais_, őzöl_
  { {0xfe710003,0xa1150012,0x39400025,0x201f01a0}},	//   ردد_, _فوات, yais_, squi_
  { {0x67ef00c5,0x69cb008b,0x12fa000b,0x25a9002a}},	//   tøjs, _umge, _ההעב, _coal_
  { {0x1c43002d,0x29160003,0x7f9504ad,0x60021596}},	//   нням, _عقود_, _надх, lôme
  { {0xe81f0037,0x6d5d002c,0xdc880009,0xf7e80012}},	//   _बढ़ा_, agsa, קְרָ, _وروى_
  { {0x3af50015,0xf772000b,0x41b60014,0x7f3a0009}},	//   дятс, _נקה_, псат, _העצו
  { {0x69db1e36,0x25a92452,0x3209020d,0x39401030}},	//   nnue, _goal_, gmay_, uais_
  { {0x55bb000b,0x673c2453,0x39402454,0x8d5b0009}},	// [6160] _למקו, _perj, rais_, _הכפי
  { {0x2d842455,0x661c2456,0x75fd0031,0x39402457}},	//   _same_, _purk, nézn, sais_
  { {0xc333000b,0x673c2458,0x64462459,0xd3370009}},	//   _אות_, _verj, lski, _מריה_
  { {0x27190066,0x63a80a45,0xae1a0009,0x31b10030}},	//   třní_, _sodn, צונכ, _fázi_
  { {0x673c0ba9,0xc953000b,0x6446245a,0x859d0009}},	//   _terj, _אמר_, nski, ישׁו
  { {0x60d60010,0x9cd70009,0x999f0064,0x69db1f58}},	//   _žymo, הונה_, čuť_, enue
  { {0x2d84245b,0x5b230012,0x7bdf0025,0x75fd0031}},	//   _tame_, رفيل, équa, dézn
  { {0xcb130093,0xa9c3002d,0x64460051,0x63a80002}},	//   עלה_, еськ, kski, _wodn
  { {0xa41c001e,0xa99b0009,0xf98f0012,0xdcef004b}},	//   ādēļ_, מבקר, طبي_, iecă
  { {0x25a900c6,0x60021596,0x0ba90012,0x9cbb0009}},	//   _soal_, lômb, _والى_, _הצמח
  { {0xdd910003,0xb8f30321,0x46670024,0x35550012}},	//   نود_, _हे_, прям_, وندز
  { {0x18a60083,0xba9b0009,0xf6530009,0xa4d50024}},	//   _наем, _לסבי, עצר_, домі
  { {0x5c070014,0xdcef000d,0x296b0009,0xdb050064}},	//   зява, decă, _ה֣וּ, _dlhý
  { {0xf3f1001a,0x60c4245c,0x6fb40012,0xabe70009}},	//   ộ_, dzim, _زمبا, ּֽךְ_
  { {0xd378002d,0xa294002d,0x2cb30066,0x2fa50012}},	//   ччя_, нарі, _řadě_, _تصنّ
  { {0xd6db0009,0x365b0009,0x6edb0009,0x52140588}},	//   _לחול, _הכהנ, _לחופ, едст
  { {0x798600b6,0x99d40003,0xe45f000e,0x765a0e80}},	// [6170] _dakw, رتفا, szöb_, luty
  { {0xdc3c000b,0x87d70012,0xc1040012,0xdb010478}},	//   _העזר, أغرا, رولي, _solí
  { {0xf7700003,0xdb030097,0xdb070097,0x4fc4245d}},	//   طال_, lhnö, rhjó, хста
  { {0xf650000a,0x25a90065,0xf3ff0017,0x6459002c}},	//   ائل_, ðal_, otão_, tuwi
  { {0x8ccd0044,0xfc460066,0x15180003,0xf3ff0017}},	//   _देशो, říve_, أزمة_, ntão_
  { {0xe2990001,0x765a004a,0x9f470029,0x321e0002}},	//   жак_, kuty, _okná_, _buty_
  { {0xf7720009,0x3869245e,0x45f70012,0x6d4d0031}},	//   _שקל_, ltar_, _فأرس, _odaa
  { {0xdb080061,0x3eae0052,0x321e021b,0x6446245f}},	//   _modè, äfte_, _duty_, yski
  { {0x9f64003a,0x87550048,0x25b20060,0xd7f8004b}},	//   ütçe_, мънц, öyle_, flă_
  { {0x38692460,0x7f4101c5,0x24800060,0x69c007bc}},	//   itar_, ualq, çime_, ahme
  { {0x386900a1,0x6446003e,0x6281001c,0x9be4002d}},	//   htar_, wski, _uslo, _чітк
  { {0xd7f8000d,0x64490028,0xf8750012,0x64462461}},	//   ală_, _kvei, _يهاج, tski
  { {0x6446007a,0xb4b80037,0xd7f8004b,0x7ae90060}},	//   uski, चने_, blă_, şetl
  { {0x395f0051,0x386907c7,0xa0090012,0xe0d00012}},	//   lgus_, dtar_, _بقتل_, _حزم_
  { {0xca750015,0x3869000d,0x75f80031,0xa18a0048}},	//   нуты, etar_, bízh, обва_
  { {0x395f2462,0x38692463,0xd5af0012,0x64462464}},	//   ngus_, ftar_, _نفى_, pski
  { {0xa0670098,0x60c40027,0xe7aa0063,0x1867024d}},	// [6180] мата_, uzim, овал_, мати_
  { {0x09030001,0x7a150002,0xdb24004a,0xdc8b0009}},	//   тпун, _wątp, ärät, _וְטָ
  { {0xf413000b,0xa206002d,0x44202233,0xe1f90010}},	//   _שפת_, _опод, _hui_, klų_
  { {0x442003fb,0x60260001,0x89360003,0xf7690009}},	//   _kui_, _одма, _تعدا, יק_
  { {0x75e8003a,0x397b0009,0xa5330024,0x0c7a0012}},	//   mızd, _וטכנ, тніч, تصاب_
  { {0x442002a5,0xdca3004c,0x36360012,0x28c70011}},	//   _mui_, таљи, _يرأس, _रेटि
  { {0xe2970046,0x44202465,0x0e550048,0x64491f09}},	//   дај_, _lui_, _пътя, _evei
  { {0x75e800a2,0xd130000a,0x44200061,0xe1f90010}},	//   nızd, دمة_, _oui_, glų_
  { {0xdb080061,0xb8140001,0x20182466,0x6d402093}},	//   _modé, ндиј, _kiri_, _iema
  { {0x69c0002a,0x389b0009,0x909b0009,0x6d402467}},	//   shme, קיינ, קסיק, _hema
  { {0xbbd70093,0x0f570093,0x6d4000c6,0x3f870027}},	//   _קובץ_, ויים_, _kema, _danu_
  { {0xb9930003,0xd1300012,0xb1e50012,0x75f60031}},	//   _للمب, _صمت_, _كأنه, kázu
  { {0x442001a2,0x6d4000c6,0x394411a0,0xfbd30012}},	//   _cui_, _mema, mams_, نتس_
  { {0xa3c90044,0xf3ff0149,0xb3450017,0x6d4000b6}},	//   लों_, rtão_, maçã, _lema
  { {0xb3450149,0xf3ff0149,0xa0070003,0x66270029}},	//   laçã, stão_, _تقول_, ľské
  { {0x23690027,0x39150001,0x7de70003,0x39440010}},	//   đaji_, ембр, _تستم, nams_
  { {0xdbd60006,0x201800a2,0x28f80015,0xb3450017}},	// [6190] _kään, _biri_, деть_, naçã
  { {0x201800b6,0xdbd60269,0x7d00005e,0x22450097}},	//   _ciri_, _jään, ümse, álks_
  { {0x7bd5180f,0x201806db,0xfc460066,0x9ee90003}},	//   mizu, _diri_, říte_, أفضل_
  { {0x39440259,0x28d00037,0xa2b6000b,0xdbd60269}},	//   jams_, _सेवि, _נפרד_, _lään
  { {0x645d0605,0x6d402468,0x91ba0009,0x7c640012}},	//   nusi, _dema, _זמרי, ناول
  { {0x6d400005,0xe7300003,0xb3450017,0x3a2100b6}},	//   _eema, _نصف_, daçã, _kuhp_
  { {0x6d40002a,0xdb0a0032,0xc5570012,0xcddb004c}},	//   _fema, chfü, _يضرب, _дња_
  { {0x6d40036a,0x6b9a0052,0xceb2000b,0x64490028}},	//   _gema, _entg, _גיל_, _tvei
  { {0xa2d10044,0xd3750046,0xb3450149,0x645d01ff}},	//   _डेस्, _плаћ, gaçã, jusi
  { {0x60060047,0x09dc0037,0xfd65001a,0x75f819ce}},	//   нным_, _यद्य, _thuố, vízi
  { {0x442001a2,0xf1bf0017,0x645e0002,0x3255002d}},	//   _sui_, _olá_, ąpie, _чвер
  { {0x3944001e,0x645d2469,0x6cc60223,0x4420246a}},	//   cams_, fusi, ейма, _pui_
  { {0xb3450149,0x61fb003a,0x4420246b,0x88c40003}},	//   caçã, mlul, _qui_, _لتول
  { {0x4420008a,0xf1bf000e,0xa3ab0037,0x43750103}},	//   _vui_, _alá_, कॉल_, куст
  { {0x637300a2,0x645d007a,0x6e950003,0x61fb0051}},	//   mını, ausi, _ألعا, olul
  { {0x6373003a,0x61fb003a,0x3eb80260,0xbc660024}},	//   lını, nlul, ørte_, _звик
  { {0x645d0af9,0x2f560021,0x61fb08d4,0xc0590024}},	// [61a0] cusi, етес, ilul, діє_
  { {0x7f86000a,0x637300a2,0x39440035,0x6d46246c}},	//   علان, nını, zams_, laka
  { {0xb3450149,0x6d4000c6,0xdb1a0061,0x2018009b}},	//   zaçã, _pema, _ulté, _viri_
  { {0x6d4613b7,0x98a60048,0xccf90034,0xadc30081}},	//   naka, _зиме, _byś_, _viến
  { {0xb3450017,0x25ad0070,0x6373003a,0x7ec6000e}},	//   xaçã, _doel_, kını, _képé
  { {0xf09f0020,0xadc30020,0x69d600a2,0xb3450149}},	//   _ngày_, _tiến, liye, vaçã
  { {0x6373003a,0xbcfb0061,0x6d461bdf,0x39440cac}},	//   dını, nfér, kaka, tams_
  { {0xb3450149,0x7ec6000f,0xdbd60006,0x7bc30029}},	//   taçã, _lépé, _sään, ahnu
  { {0x6d4600c6,0x75d30003,0xc05a002d,0x6373003a}},	//   daka, _إيقا, чій_, fını
  { {0xb3450149,0x7bc3008b,0x50b70003,0x645d246d}},	//   raçã, chnu, عديد_, vusi
  { {0x7bd5007d,0xd6da00c0,0xd337000b,0xab690003}},	//   vizu, яти_, _נראה_, _تحقق_
  { {0xb3450017,0x92c2003a,0x3f8a001e,0x01360012}},	//   paçã, ışın, _labu_, _أعاد
  { {0x637300a1,0xdb07000e,0x69d6003a,0x8cd60011}},	//   bını, ülön, diye, _मेमो
  { {0x637300a2,0xbcfb0108,0xf1bf0065,0x7d040002}},	//   cını, ffér, _slá_, _dzis
  { {0xa3c20037,0xda7800a6,0x4e930012,0x69d60060}},	//   ्फ़_, нят_, _مشير, fiye
  { {0x4efb000b,0xceb30009,0x929b0009,0x6d4611d3}},	//   _מהוו, _תיק_, הילת, caka
  { {0xdbd1005e,0xdc140060,0xbcfb0031,0x7c970012}},	// [61b0] tüüb, aşıy, rfés, _أشعا
  { {0x2a720034,0x60020018,0xdb18005e,0x7ec60031}},	//   łyby_, tôma, livõ, _gépé
  { {0x8e990003,0x69d60060,0x3f8c0097,0x7afa13c3}},	//   بناء_, biye, iddu_, _nytt
  { {0x3eae0163,0x6373003a,0x69c4246e,0xdb18005e}},	//   äfta_, zını, chie, nivõ
  { {0xc867002d,0x6373003a,0x8428002d,0xad1c0009}},	//   _ятни, yını, ежів_, פוגר
  { {0xfd100003,0x7afa04e2,0x69da0031,0x6d46246f}},	//   حجم_, _bytt, étev, zaka
  { {0xa91d0010,0xf9910003,0x02c2002d,0x6d4602a0}},	//   ldži, لبة_, ийшо, yaka
  { {0xa91d007a,0x6a9c0009,0xccf90034,0xdb1c0097}},	//   odži, לשונ, _tyś_, hirð
  { {0x6373003a,0xa91d0010,0x6d461f1f,0x8e200024}},	//   tını, ndži, vaka, _рiк_
  { {0xd7ee0003,0xa91d0010,0xeb930003,0x6d461642}},	//   يكي_, idži, _حظر_, waka
  { {0x637300a1,0x61fb00a2,0xd7090047,0x7ec60061}},	//   rını, plul, ьное_, _répé
  { {0x637300a2,0x23690027,0x75fd000e,0x99840012}},	//   sını, đaju_, nézh, _ملمو
  { {0x6d4600ec,0x69d6003a,0xc8d00037,0xdb1c0028}},	//   raka, viye, _सेंट, firð
  { {0x799d2470,0xa695004c,0x6d46112a,0x69e3001b}},	//   _answ, _ариј, saka, šteđ
  { {0x69d6003a,0x3f8a00b6,0x60c9003a,0x434300ac}},	//   tiye, _rabu_, lzem, ресв
  { {0x60d60010,0x75f6000e,0xdc14003a,0xbcfb0025}},	//   _žymi, rázs, rşıy, rfér
  { {0x7bc1004a,0x69d6003a,0xc5f9001e,0xa3c20037}},	// [61c0] _ollu, riye, rtēt_, ंसद_
  { {0xe29a0001,0x61e4009b,0x386d0c22,0x69d60b70}},	//   _жао_, čili, iter_, siye
  { {0x386d0369,0x644d001e,0x3942055c,0x69de000e}},	//   hter_, _zvai, _teks_, épek
  { {0xf2d30093,0xd5b90024,0x80c40011,0xef180035}},	//   _כעת_, нсі_, िनमे, neļa_
  { {0x01370009,0xc0e30024,0xdc74003c,0x3f8c0097}},	//   _ברכת_, _вояк, углы, yddu_
  { {0xa3cc0044,0x6d440051,0xe2a3001a,0xe3af0012}},	//   शों_, _leia, _trữ_, قرى_
  { {0x29000010,0x38600056,0xb286003c,0xe9e61728}},	//   _šia_, luir_, тылк, кцио
  { {0xe1ef0003,0x6f03003a,0x7bc10051,0xa9670001}},	//   يسي_, ünce, _ellu, вића_
  { {0xa3c20037,0x386d2065,0xbc6a0012,0x7c240025}},	//   ंसा_, gter_, _زمان_, _nuir
  { {0xdb080029,0xf41f004a,0x57b3003c,0x9b850012}},	//   _hodí, ivät_, ибыт, _مؤمن
  { {0xa91d007a,0x3f8a0029,0x798d0002,0xf1c9001a}},	//   zdži, ľbu_, ydaw, hạy_
  { {0xa91d0010,0x3f8a22bc,0xdb1c0097,0x40960012}},	//   ydži, žbu_, virð, _للصر
  { {0x70540003,0x442410de,0x386d2471,0xd0370024}},	//   _إنتا, _jum_, cter_, _азії_
  { {0x386003eb,0x9f9a0051,0xdb1813f9,0xdb1c0028}},	//   duir_, _jääb_, sivõ, tirð
  { {0x49bb0003,0x24180015,0x26da0051,0xfc48001a}},	//   وارد_, торы_, _äpo_, hử_
  { {0x31c40d60,0xf2070024,0xe7170009,0x11d90012}},	//   асув, тяго, _בחור_, روءة_
  { {0xa91d0010,0xf487002d,0x44242472,0x38600201}},	// [61d0] udži, _руйн, _num_, guir_
  { {0xf7700003,0x62830002,0xa91d2473,0xa8570009}},	//   قام_, ywno, rdži, כימה_
  { {0xdef10012,0x98140012,0x4ed50012,0x8bb40012}},	//   حًا_, شبكا, دقاء, _خصيص
  { {0xdb030052,0x69da000e,0x7aba0009,0x644b0248}},	//   rknü, étet, _נצרו, tsgi
  { {0x4424007d,0x33d5002d,0x386d0b5a,0x3949002c}},	//   _cum_, лікт, xter_, maas_
  { {0x39490070,0xadc3001a,0x60c9009b,0xab64002d}},	//   laas_, _thắn, vzem, ивіл
  { {0xb3640014,0x69c20070,0x2bb80003,0x798b002c}},	//   ръчк, _bloe, خانة_, _pagw
  { {0x60c92474,0x24890027,0x3949020d,0xe9690229}},	//   tzem, _osam_, naas_, хаил_
  { {0x386d0108,0x7bd80051,0x6d442475,0xdbd1005e}},	//   uter_, bivu, _reia, _küün
  { {0xe4e4002d,0x28090012,0xa91d0159,0xee3903e1}},	//   _тісн, عْدَ_, deže, нно_
  { {0x4424008b,0x61e9001c,0x201c001e,0x248900b6}},	//   _zum_, čelj, _divi_, _asam_
  { {0xf41f0006,0x600b0060,0x75e80060,0x69c20227}},	//   yvät_, lümd, fıza, _gloe
  { {0x3a2500bd,0xa01b000e,0x44241592,0x7c242476}},	//   _hulp_, _csök, êm_, _quir
  { {0x70520003,0x600b0060,0x9f840031,0x8fa20ce1}},	//   _انوا, nümd, _töé_, _гаше
  { {0x24890039,0xf772000b,0xfbd2000b,0x2d840025}},	//   _esam_, _הקו_, מתך_, ômes_
  { {0x7bc7005e,0xb7bb0081,0x38601cf6,0x0566034d}},	//   ahju, _quãn, tuir_, _свин
  { {0x09f7000a,0x91060015,0x10a305fb,0xcf5a0024}},	// [61e0] افقة_, упае, битн, ереч_
  { {0x728a0046,0x9d1b000b,0x351b000b,0xad1b000b}},	//   _због_, _אופט, _אופנ, _אופר
  { {0xdb082477,0x39490051,0xc7d60009,0x2c170009}},	//   _podí, baas_, נועי_, _תקיש_
  { {0x7589002d,0x65661373,0x224c08ca,0x21a6003c}},	//   ксів_, ngkh, ádku_, _симм
  { {0x61e42478,0xf9930009,0x99f70009,0x7e6101cb}},	//   mnil, _פרש_, _תזכה_, hulp
  { {0x0fda0012,0xab940024,0xec130012,0xbc0d0009}},	//   _أبحث_, рикі, موند, ֭הוָ
  { {0xed5a002d,0x201c004a,0x61e42479,0x91b80011}},	//   _пов_, _rivi_, onil, _इकाई
  { {0x7bd80006,0xdd00003a,0xe6170048,0x2d82001b}},	//   sivu, ştın, _бдс_, jeke_
  { {0x69c20070,0x7bd8008e,0x600b0060,0xc2070012}},	//   _vloe, pivu, bümd, دقين_
  { {0x30770003,0x61e40051,0x8f860001,0x06fd0066}},	//   احية_, hnil, ућил, číná_
  { {0x2002001e,0xb7db000b,0xa91d02a1,0xcff70009}},	//   ēki_, תקיי, veže, רציה_
  { {0x3e4e0034,0x60d60073,0x113a0012,0x61e40ca4}},	//   ręt_, _žymu, _أثاث_, jnil
  { {0xdfda0014,0x5c7400fa,0x55bb0009,0xcbb80011}},	//   _пък_, блят, תמכו, _अवाञ
  { {0xd00f0003,0xaedc0024,0x6e940472,0xd2350048}},	//   _فلن_, _облi, _вику, ингъ
  { {0x39490101,0x57fb0093,0x539b000b,0xa0070012}},	//   taas_, _רלוו, עילו, _حقول_
  { {0x11d40003,0x99d40003,0xa91d009b,0x61e4009b}},	//   متقد, متقا, seže, gnil
  { {0x24890017,0x4fd50055,0x361c0009,0x9fbd0034}},	// [61f0] _usam_, ажат, _אוהד, _głów_
  { {0xb8cd0037,0x600b003a,0x61e414d5,0x4439247a}},	//   _कप_, küme, anil, mps_
  { {0x443912ea,0x370700f5,0x98140012,0xa3c20011}},	//   lps_, учав, إبقا, ंसर_
  { {0xf653000b,0x44391e56,0x28d00011,0x645d247b}},	//   מצע_, ops_, _सेकि, _åsik
  { {0xdcfd007a,0xcb69010b,0xdd3c0009,0x853c0009}},	//   kesč, вале_, תעדכ, תגדי
  { {0xfd100003,0xd0180048,0x42550426,0x4439247c}},	//   سجن_, _бфс_, атит, ips_
  { {0xfbb8000b,0xdce90027,0x9e150024,0x02d80011}},	//   רפות_, _obeć, _вдві, _भेदभ
  { {0x660e0919,0x000000c4,0x000000c4,0x000000c4}},	//   _ďako,   ,   ,
  { {0xc9a60015,0x3d010011,0x6d4b247d,0x29190248}},	//   рвые_, ोधों_, maga, äsa_
  { {0xd00e0003,0xd0090001,0xa7b50001,0x6d4b247e}},	//   ولي_, ђене_, рсиј, laga
  { {0x9fbd003e,0x539a0093,0x4dd60003,0xd5b90037}},	//   _słów_, _שיעו, لتحس, _आवाज
  { {0x6d4b0167,0x6b83247f,0x58d9022a,0xb9e40024}},	//   naga, leng, _идея_, _лічи
  { {0xe72e0146,0x44630014,0x91ba0009,0x18690048}},	//   _ме_, овяв, _שמני, _рали_
  { {0x60cd0039,0x6b832480,0x3e510034,0x95160009}},	//   dzam, neng, kąt_, יקרא_
  { {0x6d4b002c,0x753d000e,0xaa460593,0x2bb80011}},	//   kaga, bbsz, ребл, _अवसा
  { {0x61e4007d,0xdb1c2481,0x45d3004c,0x6b832482}},	//   unil, nkré, _мојс, heng
  { {0x69c9004a,0xcf4601b6,0x15fb0009,0x97360012}},	// [6200] ihee, инай, _שהפע, لعاص
  { {0x6b830119,0xe80b0044,0xf41f006f,0x3eba0227}},	//   jeng, _सीमा_, svär_, typt_
  { {0xdd8f0001,0x03770009,0xef120009,0x8e860306}},	//   ош_, _דתית_, ַּע_, ргее
  { {0x6d4b0175,0x3e6e0066,0xc7a9000b,0x3eba0034}},	//   gaga, rýt_, וב_, rypt_
  { {0xdd8f0003,0x60cd0002,0xd577000b,0x93b5001a}},	//   بون_, czam, שתנה_, _vĩn
  { {0x69c90070,0x6d4b0c25,0x6b832483,0x394603bd}},	//   ehee, aaga, geng, _seos_
  { {0x6d4b2484,0x877b000b,0x31c60001,0x9a870012}},	//   baga, _שאלי, исив, لَوْ_
  { {0x75fd000e,0x600b0060,0x38bc0097,0xcd290012}},	//   nézt, rüme, _nárú_, _مسكن_
  { {0x6e20002c,0xdce2009b,0xdb080042,0xdfa6004c}},	//   _iimb, ogoč, _dodá, ајно
  { {0xdb1a000f,0xa77300b3,0xc7b10009,0x645d09ef}},	//   _eltá, ольч, ִ֑י_, vrsi
  { {0x60cd00c1,0x6e630021,0x9f970009,0x17970009}},	//   zzam, отяж, בדיה_, בדיל_
  { {0xaadb000b,0xad670012,0x69c90227,0xd12f0012}},	//   _בחבר, جاده, chee, _قمم_
  { {0xb4c10037,0x75e8003a,0x99890002,0xdcfd0010}},	//   ंने_, mızl, ymał_, pesč
  { {0x6e2018ff,0xb09b0009,0xeda30011,0x7ff30012}},	//   _limb, _שיגר, _ऐच्छ, _وسوا
  { {0xd6270046,0x6d4b0101,0xf96b02ac,0x1ab4010c}},	//   _које_, yaga, край_, обря
  { {0x75e800a2,0x6602000e,0x171b0009,0x39a40024}},	//   nızl, jlok, _בווע, ошув
  { {0x8cd60011,0xf8b80011,0x78f80012,0x286b0048}},	// [6210] _मेलो, ेनिय, لعكس_, ърво_
  { {0x960f0044,0x60cd2485,0xc60f0037,0x69c6000e}},	//   िष्ट_, rzam, िष्य_, _elke
  { {0xb8fe0044,0x22950003,0x60cd0002,0x66020068}},	//   _थे_, _الجس, szam, flok
  { {0xde58002d,0xad670012,0x225e0064,0x6b830415}},	//   раці_, شاؤه, átke_, weng
  { {0x6d4b0e9e,0x24f80015,0x746b0306,0x75e80060}},	//   raga, анцы_, трев_, dızl
  { {0x44212486,0x44290020,0x28d00037,0x3ea7006f}},	//   _jih_, _mua_, _सेटि, änts_
  { {0x0d670098,0xeb92000b,0x95670014,0xdb1c0052}},	//   _възм, לָה_, _възд, chrä
  { {0x49980047,0x2bd90011,0xc6920009,0x69c9008e}},	//   атья_, _भगवा, _צאן_, uhee
  { {0x69c92487,0xa938000b,0x75fd000e,0x6b830631}},	//   rhee, בטחה_, hézs, peng
  { {0xeb900012,0x69c90afd,0xdb030031,0x9f540097}},	//   _يظل_, shee, ajná, æfða_
  { {0x3f912488,0xa2940024,0xe7fa0011,0x7c292489}},	//   _mazu_, _мафі, ्तता_, _huer
  { {0xc3290093,0x667a0009,0x26b60009,0x69de0031}},	//   _טו_, נטרק, צִים_, épet
  { {0x248d0013,0x44210027,0x213f00b6,0x4429248a}},	//   _jsem_, _bih_, mbuh_, _cua_
  { {0x7c2902d1,0x44290535,0x8cb50024,0xe8f80024}},	//   _muer, _dua_, ісяч, _тлі_
  { {0x657b0027,0x442901d7,0xdd1101bd,0x4e350012}},	//   _obuh, _eua_, _výšk, _اعتز
  { {0x7bdc0010,0x3e710bb3,0x3eb80052,0x0e560009}},	//   siru, mát_, ärte_, _השקט_
  { {0x69d8007a,0x10a30014,0x3e71000e,0x7bdc248b}},	// [6220] _įved, питн, lát_, piru
  { {0xbb86000a,0x43860003,0xaf960001,0xab66022a}},	//   _الدي, _الدق, љшај, _увол
  { {0x3f91008b,0x60020017,0x539b0009,0x2bb70009}},	//   _dazu_, nômi, _עיטו, _הפיך_
  { {0xcb13000b,0x237f0027,0x6602004a,0x3f85029c}},	//   _מלת_, đuje_, ulok, helu_
  { {0x6ba50065,0x7c290164,0x7bca002a,0xdcf601e9}},	//   _útgá, _cuer, thfu, _obyč
  { {0xac25002d,0x39400010,0x3f850c3d,0xd7f20012}},	//   іфік, lbis_, jelu_, _ركز_
  { {0x3e71000f,0xc3330093,0x69a40037,0xe80b0037}},	//   ját_, לוג_, काली, _सीधा_
  { {0x7c2902d1,0xb0340001,0xc0340001,0x28d90011}},	//   _fuer, ониш, ониј, _बेहि
  { {0x04430048,0x7c21021e,0x98b70048,0x600b0060}},	//   _нетн, _filr, йлът_, lüma
  { {0xb7fa0037,0x7c2f0061,0x44290017,0xec37000b}},	//   ्तिम_, _écra, _rua_, _לאמר_
  { {0x4429248c,0xd337000b,0x539b000b,0x7c290052}},	//   _sua_, _הרבה_, _תיבו, _zuer
  { {0xceb30093,0x6fc00163,0x442100b6,0x6e9b0009}},	//   לית_, _böck, _sih_, אבטח
  { {0x44290020,0x50ba0012,0xa91d09df,0x5c7404a5}},	//   _qua_, _حداد_, ležn, плят
  { {0x4429001a,0xb8de0037,0x600b003a,0x3e71024a}},	//   _vua_, ीन_, küma, bát_
  { {0xd5bb0014,0x3f910002,0x5e440012,0x82a4004c}},	//   _бсп_, _razu_, _بَعْ, пште
  { {0x4429248d,0x6fc00052,0xfe370009,0x22510031}},	//   _tua_, _höch, _פרחי_, rszk_
  { {0x7bc800a2,0xc6050044,0xb3eb0003,0x44210027}},	// [6230] _oldu, रतीय_, _معدل_, _tih_
  { {0x6d4f00a2,0x2fc70020,0xf7730012,0xe7590024}},	//   laca, óng_, ثار_, рижі_
  { {0x6fc0008b,0x7c290164,0xa3ac0011,0x3ebe00b0}},	//   _möch, _suer, गान_, nytt_
  { {0x6d4f00a2,0x7c290af9,0x29d3000d,0xd6180012}},	//   naca, _puer, nţat_, متنا_
  { {0x998000a2,0xd838003c,0x7bc60073,0x3e710031}},	//   lmiş_, _гэс_, _įkur, zát_
  { {0xcc78000b,0x248d009b,0x403400b3,0x3e71000e}},	//   צגות_, _vsem_, _херс, yát_
  { {0x998000a2,0x8b580009,0xaabb0011,0x6d4f045b}},	//   nmiş_, זיוס_, ैनिक, kaca
  { {0x3e71000f,0x205508b0,0x08c50345,0x32dc0009}},	//   vát_, отор, жбин, טחונ
  { {0x7c210065,0x6e2a0052,0xf9940009,0x7dc60018}},	//   _tilr, _aufb, פרץ_, _bósn
  { {0x3e7122fb,0x2903001e,0xaa590015,0xb8d10011}},	//   tát_, āja_, _вижу_, _ऑप_
  { {0x59c90044,0x95860063,0x7dea0024,0xa5da0012}},	//   रसार, олне, имог_, لبحر_
  { {0x38600065,0x69d90052,0x04ca0012,0xc2c40012}},	//   yrir_, _umwe, لوجي_, _عيني
  { {0x7d0d003e,0x3e711d6c,0xe919002d,0x26c3009b}},	//   _czas, sát_, _тоді_, šjo_
  { {0x38600061,0x2480003a,0xcb6a0001,0xe739035c}},	//   vrir_, çimi_, јаве_, _тек_
  { {0xdcfd001e,0xab090012,0x6d4f248e,0x61e9248f}},	//   resā, متفق_, baca, onel
  { {0x3e55001e,0x7afe005e,0x02060024,0x61e92490}},	//   māt_, üpti, ізан, nnel
  { {0x20c90044,0x3e55001e,0xe1f7002d,0x7bc30028}},	// [6240] िनिध, lāt_, ігу_, kknu
  { {0x61e92491,0x61fb002a,0x62811e9d,0x94bb0009}},	//   hnel, houl, _oplo, _כמפת
  { {0x3e550333,0x61fb12ab,0x6e24005e,0x20052492}},	//   nāt_, koul, _kiib, illi_
  { {0xa3c20037,0x867a0009,0x98a6066f,0x6010008e}},	//   ंसक_, ירעו, _диме, däme
  { {0xf1b3000b,0xd38a0024,0x61e9001b,0x59bf0011}},	//   _חסר_, ийде_, dnel, _एकतर
  { {0x3e55001e,0x2ac60001,0x92940063,0x69c42493}},	//   kāt_, жљив, закц, lkie
  { {0x6d4f00a2,0x3e550039,0x441b000b,0x599a000b}},	//   yaca, jāt_, בוסס, ֹשִׁ
  { {0x3e550039,0x61e90950,0xa91d0470,0x394b0054}},	//   dāt_, gnel, režn, _xecs_
  { {0xc213000b,0xbfaa02e3,0xa91d02a1,0xf8bc0011}},	//   והה_, атне_, sežn, ोनिय
  { {0x907b000b,0x187b0009,0xa4b70009,0x61e92494}},	//   סטיי, סטיב, _ולמה_, anel
  { {0xa91d0039,0x69c40006,0x600b0051,0x6d4f2495}},	//   bežo, kkie, kümn, taca
  { {0x61fb0025,0x79960034,0x6fc00032,0x3ad30012}},	//   coul, jdyw, _wöch, _غينز
  { {0xe5070003,0x69c40002,0xb9b30012,0x6fc00032}},	//   تبدي, dkie, _تمنع, _töch
  { {0x3e550039,0x60cc003a,0x69c4001e,0x61e0003a}},	//   bāt_, ılmı, ekie, liml
  { {0xe658000a,0x6d4f003a,0x2e4a0014,0x62811ee8}},	//   _البث_, paca, _тяло_, _xplo
  { {0xc0350046,0x9980003a,0xe2f80024,0x7c3d0248}},	//   знај, rmiş_, цесі_, ppsr
  { {0x247e0035,0x7d0d2496,0x394b0035,0x60c009ee}},	// [6250] nāmā_, _uzas, _vecs_, nymm
  { {0xdb180065,0x7de4000e,0xdb2105b1,0x69c415a0}},	//   mkvæ, rőse, _štít, akie
  { {0x61e92497,0x61e00060,0xdb180097,0x69c40034}},	//   ynel, kiml, lkvæ, bkie
  { {0xdcfd000d,0x8afa000b,0x69c40679,0x60c008af}},	//   cesă, _להתי, ckie, kymm
  { {0x6281012e,0xc1050003,0x3e55001e,0x3e47000e}},	//   _splo, _روسي, zāt_, zőt_
  { {0x00ba000b,0x3e50004b,0x7c2d016d,0x4c3c0009}},	//   _המשמ, oştă_, _muar, סתוב
  { {0xf1bf2498,0x7bc30029,0xf5e70024,0x38692499}},	//   _giác_, rknu, _діам, luar_
  { {0x2a360003,0x3e55001e,0x3e75006f,0x7bc3249a}},	//   أكيد_, vāt_, måt_, sknu
  { {0x61fb042f,0xafe50024,0x3e750248,0xdddc0030}},	//   roul, зопл, låt_, _zprů
  { {0x3e55001e,0x2fb6000b,0x69c40034,0x3e470031}},	//   tāt_, ִּים_, zkie, tőt_
  { {0x69c40002,0x7d04004a,0xb4d60011,0x6e24005e}},	//   ykie, _syis, ाज़ी_, _piib
  { {0xca96000b,0x3e55001e,0xc27a0009,0x3eb80248}},	//   _מדעי_, rāt_, _לרעי, ärta_
  { {0xe8ee0098,0x7c2d0164,0x6e240051,0x3e55001e}},	//   _чл_, _cuar, _viib, sāt_
  { {0x442500c6,0xf8b6000b,0x6cfa000b,0x889a000b}},	//   _jil_, _מפני_, מפרס, _לבני
  { {0x442d1531,0xdbd7004a,0xfe710012,0xc7b40012}},	//   _lue_, määs, _أدت_, _تصنع
  { {0x7c3b00a2,0x316d0025,0x6d4d0227,0x69c40ae1}},	//   _otur, ngez_, _geaa, ukie
  { {0x44250a5f,0x9f45003a,0x3cdb0011,0xe7fa0011}},	// [6260] _oil_, kolü_, _खेले_, ्तला_
  { {0xf7720003,0xb8860028,0x61e0003a,0xdc9b0009}},	//   عاء_, lsíð, ziml, _פסיכ
  { {0x3bbb0093,0x61e0003a,0x03bb0009,0x9bbb0009}},	//   _המיד, yiml, _הציל, _הציפ
  { {0x600b003a,0x26120011,0x4425249b,0xca3700af}},	//   lüml, _धीमी_, _ail_, _מנטה_
  { {0x4425249c,0x299b000b,0x499b0009,0xc19b0009}},	//   _bil_, _הסכמ, _השכב, _השכי
  { {0x442d249d,0x600b003a,0x69cb249e,0x249f249f}},	//   _due_, nüml, _alge, _drum_
  { {0x4425003a,0x249f0028,0x9d46002d,0x2d8024a0}},	//   _dil_, _erum_, _невд, _obie_
  { {0x442d02d1,0x89d80003,0x32530014,0x7c3b000d}},	//   _fue_, توبر_, хвър, ţuri
  { {0x61e000a2,0x600b003a,0xa806003a,0x442d00b6}},	//   riml, küml, apış, _gue_
  { {0x61e000a2,0x60c0006f,0xc43b000b,0xbfaa022a}},	//   siml, rymm, _לתמי, стие_
  { {0xb8860065,0x6449008b,0x6d4d0051,0xbb3b000b}},	//   fsíð, _zwei, _peaa, _העבי
  { {0xd6d70015,0x77fa0011,0x56930198,0x60060097}},	//   яты_, ्तुक_, хают, iðmi
  { {0xc19b000b,0xacf90024,0xf1a90011,0x8fa603cd}},	//   _לשאי, інгу_, कारन, _наде
  { {0x4813002d,0x9202001e,0x6492001b,0xbcfb0025}},	//   _зміс, žādo, džić, dgét
  { {0x9f7b000b,0x3f7b000b,0x7c25004a,0x0f7b0009}},	//   _הנוח, _האוס, _vihr, _האוב
  { {0x63ba0002,0xde930012,0x386924a1,0xdb010060}},	//   _lotn, _أجوب, tuar_, _rolü
  { {0x290f006f,0x600b003a,0x2d8b155c,0x2ca024a2}},	// [6270] åga_, büml, mece_, _grid_
  { {0x2907001e,0x442d24a3,0x64490032,0x2d991886}},	//   āna_, _rue_, _rwei, ldse_
  { {0xfe78007a,0x442d15f2,0x26c70066,0x7c3b11c5}},	//   ntį_, _sue_, áno_, _stur
  { {0x21670047,0x28de0037,0x442524a4,0x201a004a}},	//   _этог, _नेवि, _sil_, ampi_
  { {0x6748000e,0x26c70133,0x61ed24a5,0x219a0009}},	//   érjü, šno_, mnal, _וברא
  { {0x442d0061,0xb8e30037,0x9cd8000b,0x65780029}},	//   _vue_, ौन_, הודה_, _ľahš
  { {0x994d0026,0xf1a90037,0x9f451726,0xdd100029}},	//   _môžu_, कालन, zoló_, ižši
  { {0xbcfb000f,0x63a824a6,0x44250ad2,0x600b003a}},	//   ngés, _endn, _wil_, züml
  { {0x2d8b00a2,0x442d0005,0x93270003,0x316d0061}},	//   dece_, _uue_, _فران, rgez_
  { {0xcee90015,0x69da000e,0xa91d009b,0xe7310012}},	//   ждое_, étez, ležk, خصة_
  { {0xaf090003,0x3b640012,0x8f3600af,0x9a4700ae}},	//   تقدم_, _أُمِ, ואתו_, _رضاه
  { {0xfbc9000b,0xfce600b3,0xa1150003,0x12fa0009}},	//   _דת_, домо, _قوات, _והעב
  { {0xb8860065,0xdbd700ff,0xdcfb001b,0xef180035}},	//   rsíð, pääs, _obuč, deļu_
  { {0x660e0026,0x39520036,0xb8860028,0x9f450bf4}},	//   _ďaku, ways_, ssíð, roló_
  { {0x600b003a,0x7f3a0009,0xf1aa0012,0x628e0227}},	//   rüml, _ועצו, ياره_, uwbo
  { {0x3209002c,0x15f60012,0xbcfb0031,0x71660012}},	//   glay_, _تستح, ggés, باسك
  { {0xe45f000e,0x34b30012,0x6e2e24a7,0x6ec50011}},	// [6280] ször_, _لميز, _subb, ानकु
  { {0x6e2e01a2,0x764100c5,0x2cad0058,0x3209002c}},	//   _pubb, oply, åede_, alay_
  { {0xcb8b0009,0xa3cb0011,0x8b570009,0x3dcd0132}},	//   _וְכֹ, ऊसर_, _קיטס_, _blew_
  { {0x5ce60003,0xa91d009b,0xe5c5002d,0xba9b0009}},	//   وكال, režj, нсіо, _וסטי
  { {0xc9530009,0x307a0012,0x63ba0159,0x2f560048}},	//   _שמש_, _بحجة_, _potn, _отвс
  { {0xdb210026,0x9cd7000b,0x61e4000d,0xdf3a0003}},	//   _štát, וונה_, liil, _ذكرت_
  { {0xa9340015,0x0a6a002d,0x926a0024,0x3dcd0132}},	//   нейш, ірки_, ірка_, _flew_
  { {0xa9c3007c,0x61e4007d,0xcb13000b,0xa3ac0037}},	//   вськ, niil, כלו_, गाह_
  { {0x2d8b00c1,0x60c400b6,0xb78a004c,0x3f9824a8}},	//   vece_, nyim, ољне_, _karu_
  { {0xdfd00003,0x660416de,0x8c4305f0,0x9cd70009}},	//   ايد_, _akik, _рефе, _חומה_
  { {0xdd910003,0x6442004a,0xeeaa0024,0x81a60012}},	//   هود_, lpoi, іток_, _يحصل
  { {0xfe780010,0x656f0032,0x75e80031,0x7c2824a9}},	//   rtį_, _öcht, yűze, _hidr
  { {0xfe78007a,0x5c070014,0x657d0028,0xbcfb000e}},	//   stį_, дява, rfsh, egér
  { {0x62850248,0x7df20035,0x0a950048,0xab8405d8}},	//   _ppho, rāsa, нагю, куск
  { {0x7bc70028,0x8ae4002d,0xbcfb0061,0x6e940012}},	//   rkju, вітл, ggér, _ألبا
  { {0x3e78000f,0x99d40003,0xdb1a0018,0x61e4004b}},	//   mét_, نتقا, _potê, giil
  { {0x9f580065,0xb8150046,0x3f980535,0x752d000f}},	// [6290] _skrá_, едај, _baru_, _igaz
  { {0xed59001c,0xdb1c0065,0xdc3c0009,0xb4cb0011}},	//   _može_, skrá, _ועזר, लनी_
  { {0x8e990003,0x79820002,0xdb1c0058,0x61e400b9}},	//   ثناء_, _obow, ekræ, biil
  { {0x61e4007d,0x25a90164,0xed580024,0xafdb0040}},	//   ciil, ñal_, дої_, _stød
  { {0xa9280066,0x60d60002,0x25d80009,0x8d740012}},	//   _vyžá, czym, וואן_, ضانا
  { {0x3e78000e,0xe2990dd8,0x58050012,0x60100248}},	//   két_, зак_, _أوسك, lämn
  { {0x45d5002d,0x3e78000e,0x69330030,0x3f8c0073}},	//   _зовс, jét_, přeč, dedu_
  { {0x6010006f,0x76410029,0x41a90011,0xf9920009}},	//   nämn, vply, काइस, ָ֨ה_
  { {0x60e90024,0x80c90011,0x602515cb,0x98a524aa}},	//   ямим_, िनें, ндиа, хипе
  { {0x443f00ec,0x61e4000d,0xf092000b,0x3862000e}},	//   _itu_, ziil, נני_, ákra_
  { {0x3e78000f,0xa3ac0037,0xba740003,0x2bac0037}},	//   gét_, गार_, _لانت, चारा
  { {0xadb70012,0x60100248,0xe29a0009,0x58d51884}},	//   ّهَا_, jämn, _משער, _поет
  { {0x2d9e06bc,0x3156000b,0x61e40269,0x60100248}},	//   ěte_, _ניסן_, viil, dämn
  { {0x69c90006,0x6e290052,0x2ba70037,0x764124ab}},	//   lkee, _lieb, खागा, pply
  { {0x78a2015b,0x386d24ac,0xc3320009,0x5f050024}},	//   _zrov, luer_, רול_, _язка
  { {0x69260001,0x60140054,0xda650003,0x6e291336}},	//   емба, ràme, ضافي, _nieb
  { {0xe0da0098,0x386d0061,0x61e4000d,0xb779000b}},	// [62a0] чва_, nuer_, riil, ּאֲש
  { {0x60d6003e,0xe47b000b,0xacfb0009,0x3cfb0009}},	//   rzym, _צריכ, _מהפכ, _מלפנ
  { {0xf1bf0020,0x69c92487,0x60d60002,0x4432001a}},	//   _giáo_, kkee, szym, _huy_
  { {0x6e29003e,0x6736001e,0xdd900012,0x7deb0073}},	//   _cieb, _šajā, شوت_, tęsi
  { {0xdb080061,0xa3ac0037,0x4c9406a5,0xdca30294}},	//   _indé, गाल_, тилс, лаци
  { {0x443202d1,0xddc20066,0x7deb0010,0xed59009b}},	//   _muy_, splň, ręsi, _rože_
  { {0xfe67000a,0x68290010,0x661d0002,0x78a224ad}},	//   _حد_, _užda, ymsk, _srov
  { {0x3e78000e,0x68ed0030,0x69c90227,0x224c08ca}},	//   vét_, _žada, gkee, ádky_
  { {0x63ab0013,0xfd57000b,0xe9370012,0xa4490012}},	//   ální, _רשמי_, رسيت_, _يشكك_
  { {0x3e78000f,0x2eaa0009,0xdb1a0064,0x660224ae}},	//   tét_, ִשָּ, _loté, look
  { {0x1df9003c,0xd6d30009,0x386d0032,0xa5f90ce1}},	//   дены_, ָׂר_, auer_, дену_
  { {0x78a224af,0x386d0061,0x3e7824b0,0x443224b1}},	//   _trov, buer_, rét_, _buy_
  { {0xb4cb0044,0x3e78000f,0xc4580015,0x94a8011d}},	//   लने_, sét_, ниях_, нтра_
  { {0x44320020,0xb8e60037,0x26c50066,0x6fe60061}},	//   _duy_, ोई_, bylo_, _décè
  { {0xd6cf062c,0x3f87005e,0x86c30012,0x5fa60011}},	//   _ст_, õnum_, _ميون, _कोयल
  { {0x9b17000b,0x5eeb0009,0x6602005e,0x6440001b}},	//   תחלה_, _מַחְ, jook, _otmi
  { {0x765a1a01,0xdb1c006f,0x4432199b,0x89340012}},	// [62b0] lsty, ekrä, _guy_, اعفا
  { {0x7c2f0108,0x6e2913c6,0x0c780012,0x7dc60097}},	//   _écri, _sieb, _أصيب_, _rósi
  { {0x6444007d,0xf6530003,0x201e0010,0x6e29001e}},	//   ţiil, ائط_, imti_, _pieb
  { {0xcb120093,0xa2b6000b,0x28d90037,0xc05b0024}},	//   _כלי_, _ספרד_, _बेझि, _ніг_
  { {0x62880692,0xeb99004d,0x19560009,0x394924b2}},	//   _apdo, дил_, _שבשל_, mbas_
  { {0xf1bf001a,0x6b620001,0x3949137a,0x2ba40011}},	//   _hoá_, акша, lbas_, _गोदा
  { {0xe2960014,0x6440039a,0xc3340009,0xae010011}},	//   ващ_, _etmi, נוק_, ईवान_
  { {0xe628001a,0x56940d60,0x765a24b3,0xcd340012}},	//   _chỗ_, _щаст, dsty, _مركب
  { {0x69c91849,0x7fd50024,0x2d8f0031,0xf1a80009}},	//   rkee, віні, mege_, ת֛וֹ_
  { {0xf3ff0149,0x22910010,0x69c900ca,0x4cc80009}},	//   drão_, _tšk_, skee, _אֶעֱ
  { {0x4432001a,0xf3ff0017,0x2bb00011,0x96650048}},	//   _suy_, erão_, ञासा, ъкне
  { {0x3869033b,0x89370003,0x9f5e008e,0xbcfb0031}},	//   krar_, _أعضا, eltä_, tgép
  { {0x386d0a80,0x4432001a,0xdb1c000e,0x4b560014}},	//   quer_, _quy_, özök, къвт
  { {0x39490164,0x5f05005f,0x320d24b4,0xd7050c7b}},	//   ebas_, _изла, lley_, _изли
  { {0x3b071c84,0x7df50034,0x7c270024,0x09e60367}},	//   веро_, ząsa, торг_, вовн
  { {0x44320020,0x25bf000d,0xb2220028,0xf2d20009}},	//   _tuy_, _noul_, _þætt, בעל_
  { {0xc952000b,0xf1bf001a,0xc006002d,0x7e7d000d}},	// [62c0] ימן_, _giám_, впак, ăspu
  { {0x46a60098,0x7bd50052,0xd00f0003,0xbea60593}},	//   казв, chzu, قلق_, казк
  { {0x66160066,0xdb1a0030,0x39490245,0x386924b5}},	//   ůzku, _toté, bbas_, arar_
  { {0xceb2000b,0x9182001a,0xb6ba000b,0x2d8f0051}},	//   ייב_, iệu_, וצעי, gege_
  { {0x6c330012,0xdb1c24b6,0x200c0097,0x320d24b7}},	//   لفنا, phró, yldi_, dley_
  { {0x64460010,0x765a179c,0xac450012,0xbb840012}},	//   ipki, ysty, ائنه, الغي
  { {0x37e30094,0xfbd3000b,0xa50f0011,0x92570012}},	//   _торг, שתו_, _सर्च_, نشير_
  { {0x31c30015,0xa2b50037,0x1e97000b,0xf1bf001a}},	//   исыв, _उपस्, _בכלל_, _xoá_
  { {0xa0670046,0x2eca0037,0x4c850003,0x3e7c0fe1}},	//   вања_, ान्त, _مؤلف, lít_
  { {0x0eea01d4,0xd9bf0011,0xb4ce0011,0xfc3f01e3}},	//   дьми_, _एक्ट, शनी_, nvíe_
  { {0x99860003,0x6010004a,0x3e7c029d,0xf7730009}},	//   _للاو, jämm, nít_, בקת_
  { {0xadf40037,0xd94600f5,0x6010020b,0xdb080060}},	//   ेकिन_, _реди, dämm, _modü
  { {0x04c90003,0x7d160002,0xd7960012,0x257d0031}},	//   روسي_, _czys, _للشخ, láló_
  { {0x7e9a0012,0xf4340012,0x7d080097,0xf3ff0018}},	//   _ينشر_, شِّح, _sérþ, rrão_
  { {0x257d000f,0x3e7c0013,0xf2c4005c,0xd2500003}},	//   náló_, jít_, астн, ْنِ_
  { {0xa3cf03bf,0x442c21a7,0x320424b8,0x429b0009}},	//   _शतक_, _lid_, nomy_, וסלב
  { {0x78a60027,0xdb080034,0x394601e3,0xf19404a5}},	// [62d0] _crkv, _kodó, ñosa_, шить
  { {0xb8db0037,0x25ad0070,0xb4c10037,0x25bf24b9}},	//   _अप_, _snel_, ूनी_, _soul_
  { {0x3e7c000e,0xc332000b,0x69dc0010,0xe7f50011}},	//   gít_, _לוי_, _įren, ीकता_
  { {0x442c002a,0x65150012,0x32040034,0xdb080034}},	//   _aid_, هوائ, jomy_, _lodó
  { {0x4d64002d,0x11da000b,0x50f401d4,0x442c0295}},	//   рків, _נחשב, _взят, _bid_
  { {0xf092000b,0xe4520009,0x6e2d0132,0x69cd008e}},	//   _הנך_, זֶה_, _liab, lkae
  { {0x442c0036,0x36d50015,0xbed50001,0x9aa50012}},	//   _did_, _совр, _совј, امبو
  { {0x2c1a0037,0x9f4c0031,0x69cd24ba,0x3f9c005e}},	//   _मीनू_, kodó_, nkae, _aavu_
  { {0xe4e7007c,0x6ce7002d,0xacf5004c,0x6d591642}},	//   _рівн, _ріве, _спаљ, mawa
  { {0x6d590160,0x7deb0002,0xe0d6003c,0xe45f008e}},	//   lawa, zęst, увь_, työn_
  { {0xc7d6000b,0xdb010017,0x80240012,0xa2a40011}},	//   רותי_, _colô, جريم, किण्
  { {0xb17b0248,0x6d5924bb,0xe8e00081,0xcb120009}},	//   _smån, nawa, êịm_, _פלא_
  { {0xd1960009,0x4dda0009,0x7bc124bc,0x61e924bd}},	//   _תכני_, תחרו, _kolu, miel
  { {0x61e90039,0xadc3001a,0x96950001,0x64460010}},	//   liel, _khẳn, _бриш, rpki
  { {0xd0060014,0x3f8700b6,0x7deb0010,0x311f0011}},	//   _щеше_, _ibnu_, tęst, मेरः_
  { {0xdb010163,0xa2a40037,0x6d590c0f,0x96b80012}},	//   _inlä, कित्, jawa, _جاهز_
  { {0x7d16003e,0x6d59003e,0x26010037,0x7deb0010}},	// [62e0] _uzys, dawa, रवरी_, ręst
  { {0xa4b7000b,0x3e7c0066,0x60c9002c,0x61e90480}},	//   _עליה_, tít_, iyem, hiel
  { {0x6d5600b6,0x61e919a3,0x5b7b0009,0xc7af0012}},	//   _keya, kiel, _אריא, ثّل_
  { {0xf1a30037,0x2bbe0037,0x257d000e,0x200500ff}},	//   _खोलन, ्स्थ, váló_, holi_
  { {0xf1b30093,0x3e7c000e,0x10030037,0x20051c77}},	//   _הסר_, sít_, रकाश_, koli_
  { {0xa3de0044,0x66060006,0xafe60047,0xda660003}},	//   दों_, hokk, _согл, هابي
  { {0xcb750046,0x387f14de,0xadc3001a,0x442c24be}},	//   ручњ, etur_, _chẳn, _vid_
  { {0x3f9c0333,0x61e90002,0xb3a40037,0x387f0028}},	//   _savu_, giel, _गोरख, ftur_
  { {0xbb46077e,0xdb0824bf,0x68260024,0xdcef0035}},	//   _безк, _indí, льоз, recī
  { {0xe8d70009,0xdb0124c0,0xdfd00012,0x200524c1}},	//   טופר_, _polô, زيج_, goli_
  { {0x61e900bd,0x6d56003a,0xf7730009,0x35f50024}},	//   biel, _beya, זקת_, ипор
  { {0x0136000a,0xd6d700be,0x90a60003,0x6606000e}},	//   _إعاد, уть_, _محتم, gokk
  { {0x7bc1003a,0xb4c10037,0x8ca70037,0x20050636}},	//   _yolu, ूने_, चियो, boli_
  { {0x200501a2,0x645d0038,0xa09b0009,0x6ec60012}},	//   coli_, rssi, _ניוט, _متبق
  { {0x7dc60065,0xcb37000b,0x66660014,0x236c000e}},	//   _póst, ראלי_, _сълз, ódja_
  { {0xdb1a0e23,0xbce70012,0x6606016d,0xdd1c0030}},	//   _notí, _مأخو, cokk, sářo
  { {0x7c970003,0xf1c2001a,0x9f550ec6,0x9f6b01d4}},	// [62f0] _إشعا, _đỡ_, ивач, ерез_
  { {0xdefb00e3,0xf7700003,0x6d400028,0x4f670003}},	//   ные_, كام_, _afma, طائف
  { {0xbb3a000b,0xa3d80037,0x569500de,0x3ea70f9b}},	//   _בעתי, ासन_, рает, ínt_
  { {0x7887001e,0x387f0028,0x07080012,0x14750012}},	//   tīvā, ytur_, ديمي_, لاتج
  { {0x6d590160,0x415a0009,0x25b60012,0x7bc124c2}},	//   rawa, _בדרג, شهود_, _polu
  { {0x7aa50003,0x61e90002,0x6d59003b,0x600f0623}},	//   لإعل, wiel, sawa, rømk
  { {0xf2d50009,0x5fc80011,0xdd95003c,0x6d5924c3}},	//   יעַ_, ाउनल, _кавы, pawa
  { {0xc9a905cc,0x7bd80051,0x20050002,0x387f1073}},	//   твие_, ahvu, woli_, ttur_
  { {0xa9220098,0x20d5002d,0x200522b7,0x629a18b4}},	//   одъл, рійс, toli_, _esto
  { {0x77820047,0x09d20037,0xadc3001a,0x8e850014}},	//   ольз, _सत्य, _thẳn, агое
  { {0x387f0065,0x612b00a2,0x61e919a5,0x2005208f}},	//   stur_, _bölü, piel, roli_
  { {0xb2ba000b,0x6606004a,0xf2c4002d,0x4ac40003}},	//   _במער, uokk, _усун, _ديمق
  { {0x7df20039,0x89340003,0x7c380027,0xfd120012}},	//   nāsi, _اعما, _čvrs, تجد_
  { {0xb6a5007c,0x660624c4,0x78a400b8,0x765e008e}},	//   _викл, sokk, vviv, yspy
  { {0x3f9301bd,0xfbd20009,0x7643021e,0x8b26004c}},	//   dexu_, חתם_, _utny, рдве
  { {0x386d0061,0xc0460003,0x4efa0009,0xb14602bb}},	//   orer_, لخطو, _שהקו, рнал
  { {0xc7b20003,0xe73a0001,0xf1b20009,0xc0450012}},	// [6300] يّر_, вез_, חסן_, مخلو
  { {0x076a0003,0x78a412bf,0x7df20035,0x25a024c5}},	//   ئماً_, rviv, dāsi, _hail_
  { {0xed5a0047,0x386d0052,0xdb1a0066,0x765e004a}},	//   вое_, hrer_, _potí, uspy
  { {0xa2a40044,0xd6250003,0x386d0192,0xbef60009}},	//   किस्, معني, krer_, בצעו_
  { {0x25a024c6,0x9426004c,0x998c0073,0x6e2224c7}},	//   _mail_, амде, ūdų_, rmob
  { {0x7fd50024,0xf2360009,0xb4b60011,0x386d24c8}},	//   _лісі, ֑רֶץ_, _छपी_, drer_
  { {0x16060037,0x4e060037,0xd5760024,0xf1ca0011}},	//   रवार_, रवाई_, _вузь, _रवान
  { {0x39400663,0xdb25000e,0x7df2001e,0x629a0121}},	//   ncis_, ísér, bāsi, _vsto
  { {0xdb1a0149,0xdfda0014,0xb9c30003,0x98b70048}},	//   _botã, вън_, تقيي, илът_
  { {0x38600061,0xf7b80001,0x1ae600f5,0x4fc605c8}},	//   isir_, угој_, _козм, рсиа
  { {0xd737000b,0x0737000b,0xa3b30037,0x7bdb0009}},	//   יטית_, יאים_, टार_, _שקבו
  { {0x7de7002d,0x386d08b9,0xadd9003c,0x25d9003c}},	//   ріод, brer_, умму_, уммы_
  { {0x91bb0009,0xc0d30012,0x9a250012,0x386d0025}},	//   _שמדי, _ويمب, _اعلن, crer_
  { {0x2bbe0037,0x30db0009,0xdc8b0009,0x15140024}},	//   ्सटा, _שַׁע, כְלָ, ідря
  { {0x25a01160,0xb8050012,0x29e80060,0x9b58176d}},	//   _fail_, _ابنه, aşam_, рист_
  { {0x386000b6,0xb6bb0009,0xcad70009,0x76bb0009}},	//   fsir_, _יצוי, בולת_, _ימופ
  { {0x7a350010,0xe4530012,0xe8380024,0xe8550012}},	// [6310] _ište, _بضع_, ипті_, صناد
  { {0xd759000a,0x5399034c,0xf7730003,0xcb99002d}},	//   الات_, _своя_, تار_, _свої_
  { {0x29070002,0x16380012,0x33fc0009,0x394d0073}},	//   łna_, لسنة_, _בהזנ, ybes_
  { {0x6d5d0167,0x237f0027,0x7df20035,0x386d24c9}},	//   nasa, đuju_, tāsi, yrer_
  { {0x7bc50005,0xdff80037,0x9b450003,0xa3b30037}},	//   _kohu, ुवाद_, منشو, टाल_
  { {0x6d5d24ca,0x6fa60011,0x14d80009,0xe3c40012}},	//   hasa, _कोलं, סוגל_, يْنَ
  { {0x6d5d0167,0xaa560001,0xf21c0037,0xdcfb0027}},	//   kasa, бију_, _भीड़_, _obuć
  { {0x82f8000b,0x386d24cb,0xfaf80009,0x22f80009}},	//   יצוב_, trer_, יצוי_, יזון_
  { {0x6009035c,0x6d5d0190,0xd4980177,0x386d19d9}},	//   лним_, dasa, _врх_, urer_
  { {0x60100006,0x39590036,0xe81d0011,0x3a87003c}},	//   tämi, _less_, _बीमा_, _выдв
  { {0xd1310003,0x86980357,0x61ed24cc,0xed5a0c7b}},	//   _فما_, атят_, kial, лон_
  { {0xfbc9015a,0xfc460066,0xed59124c,0x63a124cd}},	//   _את_, říme_, _jež_, _haln
  { {0x2281000f,0xb6070065,0x9045000a,0x95960009}},	//   lók_, _sláð, _انته, זכרו_
  { {0x8fa40003,0xad9b0066,0x660d005e,0xa1420035}},	//   _ومنه, hoúh, _ekak, _ēķin
  { {0xc3320093,0xf1db0037,0xa3e90037,0x216a00ac}},	//   לום_, _बतान, _मगर_, ливи_
  { {0xed590382,0x2281000e,0xdb07000e,0x62830070}},	//   _než_, iók_, ámáv, itno
  { {0x39590163,0x6c860003,0xadd7000b,0xe3b20003}},	// [6320] _dess_, _الخم, _לוקח_, _فرد_
  { {0x94bb0009,0x628313e8,0x61ed005e,0xa8190009}},	//   _עמית, ktno, aial, אֵ֣י
  { {0x3e63003a,0x386024ce,0xdb1e0042,0x139b0009}},	//   nıt_, ssir_, _kopí, _גביע
  { {0x629e001c,0x2281000e,0x9e650012,0xed5a0012}},	//   _ispo, dók_, زامن, اشات_
  { {0x63a124cf,0x62830972,0xed590c85,0xb6080919}},	//   _baln, etno, _dež_, _našť
  { {0xd3700003,0x0fda0012,0xf2360009,0x3e630060}},	//   ذهب_, _إبحث_, ֖רֶץ_, kıt_
  { {0x69c60006,0x6d440002,0xf6d5002d,0x599a0009}},	//   _koke, _ofia, _дітя, ָשִׁ
  { {0x66f7000b,0xf9920012,0x6df60012,0x600b005e}},	//   _המלא_, سبع_, _اكرا, lümp
  { {0x69c6007a,0xc7d80024,0x6d5d24d0,0xd943004c}},	//   _moke, имих_, vasa, чењи
  { {0x389b000b,0x2e4a0014,0x22810028,0x61ed24d1}},	//   ניינ, лямо_, bók_, zial
  { {0xd36f0003,0x66fa0037,0x3a3a0051,0xf76f0012}},	//   _أهم_, ्थिक_, _nupp_, ءاً_
  { {0x89a50003,0x7bc80051,0xe7170009,0xca370009}},	//   _وإنم, ödun, מחיר_, _הנאה_
  { {0x63a100a2,0x6d5d1395,0x629e0004,0xdb230031}},	//   _yaln, rasa, _aspo, örök
  { {0x07a30015,0x6d5d002c,0x3eb800a8,0xda35003c}},	//   _начн, sasa, ärts_, жевы
  { {0xd7f8000d,0x82370003,0xcf260003,0x68290010}},	//   mnă_, إرسا, _ارشي, _uždi
  { {0x8e470003,0x5215002d,0xd0d50015,0x5c750015}},	//   _اليك_, ідат, ообъ, _длит
  { {0x2281000e,0xa3d80011,0x94770012,0xb0290012}},	// [6330] zók_, ासा_, _ادعا, لكرم_
  { {0x62830066,0xdb1f000e,0xdb180030,0x7df50073}},	//   ytno, űvés, ejví, mąsi
  { {0xa935002d,0x6e9924d2,0x56940681,0x60cd0060}},	//   _менш, рвер_, захт, syam
  { {0xd56b002d,0xfc3f01e3,0x8d770012,0xdb010018}},	//   рiал, nvío_, صاصا, _falê
  { {0xa5bd007a,0xd7fb007c,0x6d8c0009,0xa509004c}},	//   _siųs, _був_, רָבְ, јела_
  { {0x2281000f,0x3e6300a2,0xcac9004c,0xbae50012}},	//   tók_, yıt_, игле_, يكشي
  { {0x23760012,0x44332133,0x98a40060,0xf1bf0031}},	//   زميد_, _mix_, damı_, _fiát_
  { {0x644b0163,0x3eae0058,0x22810031,0x39590097}},	//   ppgi, æfte_, rók_, úss_
  { {0x63a10028,0xc7950015,0xf7710003,0x9be70024}},	//   _taln, орны, واد_, _ліжк
  { {0x166500b3,0xdc880009,0x9e6502c4,0x660b07c2}},	//   овом, _לְעָ, овод, logk
  { {0x6d5b00c6,0xf772000b,0xdb1e01e9,0x02440012}},	//   _keua, וקי_, _popí, _فَلَ
  { {0xd7f8000d,0x8c3d003a,0x26b60009,0xda1d0011}},	//   ană_, _arşi, קִים_, _पठित_
  { {0x7c3b00b9,0x5cac0009,0x395f12fb,0xdffb0011}},	//   _juur, ְׁלַ, maus_, ्वाद_
  { {0xa3e40037,0xb8ed0037,0x395f24d3,0x98b20034}},	//   पों_, रह_, laus_, _żyć_
  { {0x44330061,0xe95a0048,0x65690030,0xe1f90073}},	//   _dix_, иращ_, _odeh, onų_
  { {0x69d8007a,0x395f01f8,0x6e920012,0x21f60024}},	//   _įves, naus_, _آليا, іївс
  { {0x6ab60044,0xdfd20003,0x629e0002,0xf992000b}},	// [6340] _अप्र, وير_, _wspo, ורן_
  { {0x95f40037,0x395f24d4,0x1df40011,0xddc20073}},	//   ेक्ट_, haus_, ेक्ष_, kslū
  { {0x35af0044,0x2fc709fe,0x9bb7000b,0x644924d5}},	//   _जोड़, _mong_, _והיה_, _atei
  { {0xbc4a0001,0x7c3b13f2,0x2fc724d6,0x395f0d66}},	//   ачке_, _buur, _long_, jaus_
  { {0x7de4000e,0x2cad000d,0x902a0003,0x395f1d60}},	//   lőss, _cred_, _نأسف_, daus_
  { {0xe0fb000b,0x66e60a25,0x7c3b0070,0x6fb60003}},	//   _כלכל, _дога, _duur, _بمسا
  { {0x291d0034,0x98a40060,0x2cad0bf4,0x249f01a0}},	//   _azwa_, vamı_, _ered_, _esum_
  { {0x4427006f,0x395f0010,0xe5770024,0x8c4a0024}},	//   amn_, gaus_, _мзс_, _впав_
  { {0xdfd0000a,0x6141000f,0x9f4c0025,0x98a40060}},	//   فية_, _háló, lidé_, tamı_
  { {0xd7f8000d,0x388e001e,0xe0b70009,0x76740365}},	//   ună_, mērā_, קליט_, плоф
  { {0x2127008a,0xd7f8000d,0xa2a10037,0x60140054}},	//   ̀nh_, rnă_, _कैप्, nàmi
  { {0x44330689,0xb90a004c,0x7df50073,0x88c60012}},	//   _six_, _кнез_, tąsi, _وتشل
  { {0x7a350010,0x7bc824d7,0x8fe60012,0x3bf60011}},	//   _išta, _kodu, _وأتم, ँचूँ_
  { {0x61ed0029,0xa3b30011,0x44330025,0xf7480012}},	//   ďale, टाए_, _qix_, _الغي_
  { {0x3866045d,0x69d8007a,0x9f840028,0xcb340048}},	//   _hvor_, _įver, _röð_, деръ
  { {0xd6db0009,0x7a010035,0x24860670,0x2fc70227}},	//   _כחול, pēte, ktom_, _zong_
  { {0xed58000b,0xdcfd001e,0x40590003,0xc05b0024}},	// [6350] _ובחר_, resē, صلاح_, ріб_
  { {0x7f5c03eb,0x644f03eb,0x2fc7001a,0x2a780132}},	//   _cerq, mpci, _xong_, burb_
  { {0x7c3b07f6,0x8db5002d,0xdfd80014,0x644924d8}},	//   _suur, зслі, цът_, _stei
  { {0x40350014,0xa714002d,0xee38002d,0x2cad24d9}},	//   _немс, ємці, іні_, _pred_
  { {0x2fc70020,0xd7770003,0x19ba000b,0x2d990052}},	//   ưng_, _واسع, _המרב, iese_
  { {0xf1a30044,0x7bc8007d,0xbb850003,0x883a000b}},	//   _खोजन, _codu, سلبي, _לתשו
  { {0x5b58000b,0xaa560001,0x2d990b4b,0x9f4c0061}},	//   חיוב_, пију_, kese_, cidé_
  { {0x2fc724da,0x02fc0009,0xceb20009,0x41a60048}},	//   _song_, ילומ, _איל_, звън_
  { {0x2fc7002c,0x395f027e,0x2cad001b,0x69da0227}},	//   _pong_, raus_, _ured_, ëtei
  { {0xb4d70044,0x200c013a,0x60e6003c,0x7afc0159}},	//   ानी_, godi_, ямым_, _žrte
  { {0x68290010,0x7bc80051,0x9f4a000e,0x2fc7001a}},	//   _uždu, ödum, émák_, _vong_
  { {0xdb010066,0x6d410002,0xdb160030,0x2fc724db}},	//   _nalé, ślan, ícíc, _wong_
  { {0x621a000b,0xb9c40003,0x993a000b,0x63a50052}},	//   _פונק, _تقني, _התנה, _bahn
  { {0xc879003a,0x2fc7020d,0x69cb0aa0,0x9f450030}},	//   muş_, _uong_, ögen, bilá_
  { {0x8c1a000b,0xc879003a,0xe1ff0097,0x77ba0009}},	//   מושי, luş_, _bjó_, _למסח
  { {0x395d002a,0x2b8f003a,0xcb12000b,0xdb0109ec}},	//   _jews_, lıcı_, גלל_, _valè
  { {0x7f5c03eb,0x7d7b000b,0x5d7b000b,0x24860029}},	// [6360] _perq, _הנפו, _האפק, xtom_
  { {0x2b8f00a2,0x7bd50052,0x7b07000e,0x386f000e}},	//   nıcı_, ckzu, érté, ágra_
  { {0xbb3b000b,0x61fb13a3,0x433b0009,0x91db0011}},	//   _לעיי, knul, _לעיב, बसाई
  { {0xb2bb000b,0xf41f004a,0xd7f1001a,0xf2d30009}},	//   _המטר, ntän_, hĩ_, _נער_
  { {0xc1730093,0x7bc80267,0x69c4001e,0x2b8f0060}},	//   _אחר_, _podu, mjie, kıcı_
  { {0x929402c4,0xdb1e0064,0x60100248,0x61fb0e64}},	//   дакц, _zopá, räms, enul
  { {0x200c0027,0x539b0009,0x248624dc,0x8f0b05f3}},	//   vodi_, מיסו, stom_, _सुलझ_
  { {0x7bc80052,0x49ba0012,0x4efb0009,0x3f9a1ca8}},	//   _wodu, صاعد_, _ההלו, lepu_
  { {0xfc3f0066,0x74160012,0x09ca0011,0xc05a0024}},	//   tvím_, _فورا, _रवैय, щій_
  { {0xf1bf0020,0x6d460248,0xb3c10011,0x3b8314f1}},	//   _khác_, ecka, रॉफ़्, _плуг
  { {0x916d001a,0xadf30011,0xf1190011,0x98b80060}},	//   hối_, _आगमन_, _दर्द_, ğrı_
  { {0x36f7000b,0xb8660003,0x7abb000b,0x9c870042}},	//   לצים_, _فاتو, _לצבו, _načí
  { {0xa2a40037,0x160d0037,0xba090012,0x31e50012}},	//   किक्, िकतर_, _بتلك_, _تسلّ
  { {0x60b7000b,0x889b000b,0x7a01001e,0xd7940014}},	//   _מהדף_, _לבדי, mēta, _цикъ
  { {0x7a01001e,0x2d990070,0x764a0033,0xf7730009}},	//   lēta, pese_, _utfy, _טקס_
  { {0xc2c40003,0x067b0009,0x4efb0009,0x63a50032}},	//   ريقي, _הנהל, _להוו, _wahn
  { {0x7a01001e,0xe894003c,0xdb030064,0x7bc10097}},	// [6370] nēta, нать, rdné, ölus
  { {0xe9e2003e,0x61430028,0xba990024,0x7ff70012}},	//   leźć_, _kíló, _двоє_, أسرا
  { {0xdb1e0029,0xda670012,0xf6990012,0xf1bf0081}},	//   _topá, _عادي, تناع_, _chác_
  { {0x68f8000f,0xfe700003,0x2b8f003a,0xd6d80015}},	//   áadá, ادل_, zıcı_, чту_
  { {0xb4d70044,0x2b8f00a2,0x0db80003,0xfc3f0030}},	//   ाने_, yıcı_, ثالث_, dvík_
  { {0xa3e70044,0x9c87014a,0x00ba0009,0xe3b30012}},	//   मों_, _začí, _ומשמ, عرش_
  { {0x78ad0051,0xfaa20014,0x6d46006f,0xf41f008e}},	//   lvav, ващо, ycka, ytän_
  { {0xd2b8000b,0x09f90012,0x20d50024,0x601008fb}},	//   ללות_, تفعة_, діос, lämp
  { {0x8f75002d,0x2b8f003a,0x61fb24dd,0x36040012}},	//   муні, tıcı_, rnul, _أوقف
  { {0x2628000d,0xdb24000e,0xe645052c,0x0eb80011}},	//   _uşor_, űrés, меоп, इमंड
  { {0x9f840005,0x7d16004a,0x2b8f0060,0x61fb0030}},	//   _töö_, _syys, rıcı_, pnul
  { {0x443f0005,0x02440003,0x7d16008e,0x7a350073}},	//   _kuu_, _أَنَ, _pyys, _išto
  { {0x7a01001e,0x601008ec,0x6d440073,0x67e00248}},	//   cēta, kämp, žiag, _höje
  { {0x69cb0070,0x443f00b9,0xe6c50003,0x442a04d2}},	//   _hoge, _muu_, _يتغي, umb_
  { {0x160d0044,0x69cb0005,0x7fb60012,0x7f92004c}},	//   िकार_, _koge, _زهير_, _рајх
  { {0x7deb0034,0x69c40e38,0x7bc10097,0x06960012}},	//   zęsz, ujie, ölur, _آنية_
  { {0x69cb24de,0x799b0070,0x3eb10032,0x6b930248}},	// [6380] _moge, ieuw, _arzt_, ädgå
  { {0x46f60014,0xe29a0001,0x69d607c2,0x69dd24df}},	//   мчет, _дао_, skye, _else
  { {0x3a260046,0x7a01001e,0x3bbb000b,0x0d8600bb}},	//   _омог, zēta, _ומיד, длен
  { {0x69cb00c5,0x397a0012,0x93bc0081,0xe5060012}},	//   _noge, _بصدد_, _chăn, وبشي
  { {0x9588007a,0x249a0003,0xbc9a0003,0xdca3013b}},	//   _grąž, تخاب_, تخاذ_, каци
  { {0xa91d0010,0xf1bf001a,0xdb0801d7,0x443f01a0}},	//   igžd, _thác_, _indú, _duu_
  { {0xfe670012,0xdced0060,0xb17b0040,0x06750223}},	//   _جد_, _ocağ, _flåd, _путя
  { {0x68290010,0x6b9c0052,0x7a01001e,0x69cb24e0}},	//   _uždr, herg, tēta, _coge
  { {0x6b9c0033,0x60630012,0x31570012,0x60f8042a}},	//   kerg, نهيل, ذجية_, яния_
  { {0x6d440026,0xb8e60037,0x7a01001e,0x2918001e}},	//   žiad, _उप_, rēta, āra_
  { {0x179b000b,0xd491001a,0x7a01001e,0x644024e1}},	//   חייב, ằm_, sēta, _humi
  { {0x6b9c00bd,0xc333000b,0x78ad0010,0x644001ea}},	//   eerg, _סוף_, yvav, _kumi
  { {0x443f0020,0xd9430001,0x3a26006f,0x644003ec}},	//   êu_, _речи, _ihop_, _jumi
  { {0x64400010,0x6b9c24e2,0xc4d30009,0x69cb04a3}},	//   _mumi, gerg, דגש_, _zoge
  { {0xa195002d,0x628a24e3,0x19bb0012,0x3f7b0009}},	//   навч, ntfo, يطرة_, _ואוס
  { {0xba740003,0x7bde0031,0xdb070031,0x9f890097}},	//   ضافت, _elpu, ndjé, _húð_
  { {0x9be7002d,0x6440000d,0x60100248,0x7bd824e4}},	// [6390] _жінк, _numi, tämp, kkvu
  { {0xf770000a,0x443f00b6,0xab630002,0x25a90227}},	//   لام_, _ruu_, ążka, _haal_
  { {0xdef10003,0xe47d003a,0xb4d70011,0x7bc80009}},	//   دًا_, ştüğ, ान्_, _חֶרֶ
  { {0xc05b002d,0x644001ea,0xbd450012,0xcad60009}},	//   _міг_, _bumi, رنتي, _נורת_
  { {0xf9920093,0xf3ff0017,0xe458002d,0xe5340024}},	//   _ערך_, nsão_, джі_, вець
  { {0x69cb0052,0x6440000d,0x6a850083,0xe3b10012}},	//   _soge, _dumi, елка, طرت_
  { {0xb6060066,0x93bc001a,0x05770012,0xae0f0011}},	//   _hláš, _thăn, _يارد, सवान_
  { {0x6d410002,0x63ba0359,0x6b9c034f,0xb60605b1}},	//   ślaj, _entn, zerg, _kláš
  { {0x05840024,0xe8f90a21,0xfd130012,0x69cb24e5}},	//   _шурм, яли_, _شجر_, _voge
  { {0x612a000f,0x386924e6,0xeb900012,0xbb550012}},	//   lölé, isar_, _نظم_, _أناب
  { {0x69cb002a,0x64400052,0x998d0034,0xef190790}},	//   _toge, _zumi, tleń_, ямо_
  { {0xed57007c,0xa954007c,0x63a80133,0x99d70003}},	//   ною_, _акці, _zadn, _تتطا
  { {0x7a01001e,0xdce90066,0xab5c001e,0x30840012}},	//   lēto, _odeč, _soļi, _للنف
  { {0xdce60039,0x3949001e,0x18760009,0x47d50012}},	//   mekļ, ecas_, _נעצר_, _سيعر
  { {0xb7da0093,0x386924e7,0x3af5003c,0x7a010035}},	//   _מקסי, esar_, вятс, nēto
  { {0x4c860024,0x6b9c24e8,0x422900af,0xaa5700ae}},	//   _злив, serg, לֵּ֣, علقا_
  { {0x48e30014,0x34b30003,0xc9520009,0x11d70012}},	// [63a0] готв, _مميز, טמן_, روكة_
  { {0xdce6001e,0x4c060012,0xdee60e98,0x644024e9}},	//   iekļ, _سِجل, нози, _rumi
  { {0x24460020,0x63a81746,0x2003009b,0xb17b0058}},	//   _hôm_, _radn, čjih_, _slåe
  { {0x64400101,0xafdb01fb,0xceb2000b,0x9f4c0030}},	//   _pumi, _støt, טיב_, vidí_
  { {0x61f6003a,0xfba40011,0x6fd60025,0xf1bf0081}},	//   miyl, _ओसाम, _fâch, _khán_
  { {0x7a050010,0xab94002d,0xb4fb0009,0xfaa6004c}},	//   mėta, тикі, הפני, ешин
  { {0xfbd3000b,0xed5a029b,0xd2500003,0x628a0033}},	//   רתו_, _нов_, جنب_, utfo
  { {0x61f6003a,0x6440002c,0x7e7e006f,0x8cb30011}},	//   niyl, _tumi, mupp, इटमो
  { {0x7e7e24ea,0x60d6004a,0xf98f0012,0x7a050073}},	//   lupp, nyym, صبي_, nėta
  { {0xddc90002,0x4f6a003c,0x394901e3,0xc0930012}},	//   łożo, чшим_, zcas_, اجيت
  { {0x11d6002d,0xb7db000b,0xd6d70232,0x03d70009}},	//   _підр, פקטי, етя_, _רובם_
  { {0x7c3a012e,0x443a007a,0xaadb000b,0x7a050010}},	//   _hitr, _aip_, _מחבר, kėta
  { {0x25d7000b,0x91a6001a,0x99e90012,0x68fb0064}},	//   תוכן_, _nhỏ_, _تعلق_, _ľudo
  { {0xf3ff0149,0x7a050010,0xf8b3000b,0xf1bf24eb}},	//   rsão_, dėta, _תשס_, _chán_
  { {0xf3ff0149,0x25a900bd,0xa294002d,0xdce9009b}},	//   ssão_, _taal_, ларі, _rdeč
  { {0xda100044,0x2007080a,0x224c0066,0xdcfd001e}},	//   ावित_, čnim_, ídka_, nesī
  { {0xa898002d,0x3949052e,0x2098003c,0xdcfd0035}},	// [63b0] нкту_, rcas_, нкты_, iesī
  { {0xc9140001,0x394901c5,0xb4fc0009,0x389b0009}},	//   удућ, scas_, _מפחי, הימנ
  { {0xf770000a,0xddc90010,0x98140003,0x3f9e001e}},	//   صال_, iudž, ابقا, ietu_
  { {0x61e424ec,0x3f9e005e,0xd6570009,0x07080012}},	//   chil, hetu_, גיאת_, ريني_
  { {0x6fd60061,0xdb030066,0x7e7e008e,0x3f9e0b68}},	//   _tâch, rdní, aupp, ketu_
  { {0x3f9e0027,0x72950015,0x58f60009,0x7c3a24ed}},	//   jetu_, вших, _יצרן_, _citr
  { {0x2fc70028,0xdb1c0028,0xfbb8000b,0xa2a10011}},	//   öngu_, skrö, תפות_, _कैश्
  { {0x7a01001e,0xaa0b0011,0x9e34003c,0x6d560060}},	//   rēto, ावेज़_, _бесч, ıyac
  { {0x3c24006f,0x6566000e,0x7c3a24ee,0x6d440029}},	//   höva_, vakh, _fitr, žiac
  { {0xd00e0003,0xf0920009,0xe3b30012,0xd4370012}},	//   يلي_, סני_, _حرر_, _أعرب
  { {0x2367009b,0x13b60009,0xb9950012,0xba740012}},	//   manj_, _שהעל_, _للاب, _مانت
  { {0x75e60034,0x8d660048,0x9dd50009,0x7c3a24ef}},	//   _mózg, ъвме, דוֹק_, _zitr
  { {0x656600c6,0xf1bf001a,0x20100028,0xddc9001e}},	//   rakh, _phán_, ólið_, budž
  { {0x9cd60009,0xa0090012,0x86c50012,0x7c2e07ea}},	//   דושה_, _تقتل_, _ليتن, umbr
  { {0x61f6003a,0x61e424f0,0x77f601b0,0xf4120009}},	//   tiyl, thil, _במסד_, יפך_
  { {0xaea80012,0x69c900b0,0x24460081,0xdb0101a0}},	//   _أطول_, njee, _tôm_, _malà
  { {0xa0670098,0x61f6003a,0x2367009b,0x69cf24f1}},	// [63c0] ката_, riyl, kanj_, _doce
  { {0xd7f9002d,0x61f6003a,0x69c9004a,0xafdb024c}},	//   нує_, siyl, hjee, _stør
  { {0x7c3a00c1,0x7d1b002c,0x69db004a,0x26dc0042}},	//   _ritr, _ayus, kkue, ávo_
  { {0xdd8f000a,0xdd900003,0xcf250003,0x973c001b}},	//   قوم_, صوت_, اركي, meće
  { {0xdd8f000a,0x6564004a,0x04940003,0x6e3b00b6}},	//   تون_, _meih, التح, _diub
  { {0xdb0e0065,0x9cd7000b,0xbf650012,0x236724f2}},	//   _þjón, כונה_, _مدفو, ganj_
  { {0xe2970046,0x7ac30014,0x32630015,0x3f9e24f3}},	//   вај_, исъе, атыв, vetu_
  { {0x7c3a003e,0x2d820033,0xf2d3000b,0x225e01bd}},	//   _witr, _øke_, שעה_, átky_
  { {0x7c3a0108,0x7bdc0028,0xab5c001e,0x69360066}},	//   _titr, kkru, _soļu, břež
  { {0x7ba50012,0xa3e60011,0x7c3a0227,0x69db008e}},	//   _مصمم, _पति_, _uitr, akue
  { {0xdef40015,0xddc90027,0xfe780010,0xc5f9001e}},	//   упны, rudž, urį_, ksēt_
  { {0xe0da0046,0x973c0027,0x7a250002,0x79850003}},	//   _ове_, deće, rótc, _مؤهل
  { {0xa3e60044,0x29550014,0x1bbb0012,0xc0e3004c}},	//   _पता_, _съхр, واسع_, _коцк
  { {0xdb01000e,0xf1bf001a,0xdb1a24f4,0x2007013a}},	//   _halá, _pháo_, _anté, čnik_
  { {0x179b000b,0x569402bb,0xa3e70011,0x27f40034}},	//   _חיוב, _сайт, मोट_, ędną_
  { {0x2918003a,0xd6d9002d,0x1f37000b,0xddc8000d}},	//   ğraf_, _яті_, _ברור_, ălţi
  { {0x201e00b8,0x69cf24f5,0x9f5e0025,0x9ce80024}},	// [63d0] olti_, _voce, enté_, _офiс
  { {0xb8cb0044,0xdefb0047,0x5f740003,0xf7730012}},	//   _कई_, мые_, لامر, شاط_
  { {0x236702a1,0xd5750198,0x387f0227,0xf7730009}},	//   vanj_, гуль, zuur_, שקע_
  { {0x7a050010,0x39150012,0x960d0011,0xf1bf0081}},	//   mėto, _موجز, िकेट_, _khám_
  { {0x1514002d,0xf1bf0029,0x41b60011,0x1bd50024}},	//   адця, _iná_, _अफ़स, лодя
  { {0xe5040044,0x5e450012,0x7a350073,0xa3b30011}},	//   रपति_, _مَسْ, _išti, _जोश_
  { {0xbe880001,0xe29901ef,0x7a050073,0xe2960048}},	//   _исте_, хай_, nėto, гащ_
  { {0xc334000b,0x42d4002d,0x387f0562,0xa3b30011}},	//   סוק_, рішу, tuur_, _जोर_
  { {0x65640052,0x75e60002,0xe4a40001,0x69c9004a}},	//   _reih, _józe, _врхо, rjee
  { {0x68e9003e,0x764300c6,0x87b80015,0x69c6004a}},	//   rzed, _puny, вуют_, öker
  { {0x2007102c,0xa2d50003,0xaa550001,0xdce00066}},	//   čnih_, _حيات, _свеш, _odmě
  { {0x8d76000a,0x26190061,0x7de4000e,0x7a050073}},	//   دادا, déos_, lősz, dėto
  { {0xe1f90010,0x224524f6,0x88c40012,0x973c001b}},	//   mių_, _hulk_, _نتول, veće
  { {0xe1f9007a,0xf0a8002d,0x8c4300b3,0x65641709}},	//   lių_, _шкіл_, сере, _weih
  { {0x973c0027,0x386d1b0c,0x7cea0031,0x998c0073}},	//   teće, lser_, _köré, _gudų_
  { {0xe1f9039c,0x601d0054,0x394d24f7,0xa2260012}},	//   nių_, dèmi, nces_, ارسه
  { {0x973c0027,0x386d24f8,0xa7640048,0xa926054b}},	// [63e0] reće, nser_, ижаr, удал
  { {0xd8480020,0x5f760003,0x53a60001,0x25bf0a66}},	//   _học_, طائر, _саоб, _anul_
  { {0xe1f9007a,0x7de4000e,0x394d0002,0xe57a24f9}},	//   kių_, dősz, kces_, езе_
  { {0x386d0989,0x5155002d,0xa1550014,0xc27b0009}},	//   kser_, _втру, _върш, _ארטי
  { {0x386d0058,0x7c3e0ff4,0xd8480081,0xdb1a03a7}},	//   jser_, _kipr, _mọc_, _dotý
  { {0xd848001a,0x386d0040,0x2aaa004c,0x660224fa}},	//   _lọc_, dser_, етио_, snok
  { {0xe81d0037,0x141b0009,0xba730012,0xe727064d}},	//   _बीटा_, עוצב, مايت, _борд_
  { {0x85b50046,0xdd920003,0xe1f90010,0x291d0034}},	//   _кључ, _دور_, gių_, _bywa_
  { {0xdfd0000a,0x75d30003,0x00760009,0x2edc0011}},	//   قية_, _ايقا, אתִי_, मन्त
  { {0x0897000a,0x18970003,0x749b0009,0xdc9b0009}},	//   اضيع_, اضية_, _אימפ, _אסמכ
  { {0xdb010272,0xe1f90010,0x3817000b,0x6c330012}},	//   _talá, bių_, רקים_, _افلا
  { {0xd946035c,0x61460294,0x443e24fb,0x07370009}},	//   _седи, _седа, _hit_, טאים_
  { {0xd848001a,0xe4e40024,0xf5390064,0x3495004c}},	//   _dọc_, бірн, äť_, јагр
  { {0x25ad124c,0xdce00aa3,0x113b0009,0xdd1c0035}},	//   žel_, _nemč, _נתגל, kšžo
  { {0x443e24fc,0xda780098,0x7c3e00b6,0x682b003a}},	//   _mit_, лят_, _dipr, nüde
  { {0x2ddb0003,0xb9550048,0xf1bf0081,0x7a050073}},	//   _سبعة_, рващ, _thám_, rėto
  { {0x443e24fd,0xc7f5004c,0xdff5004c,0xdfdb0048}},	// [63f0] _oit_, азаћ, апањ, нъж_
  { {0x1e0d0037,0xe1f90010,0x3a2016d0,0x443e24fe}},	//   िक्ष_, zių_, alip_, _nit_
  { {0x141c0009,0x4c3a0009,0x9d550012,0x3f8f0034}},	//   _אוזב, _שתתב, لنات, ęgu_
  { {0x4a5a000b,0x6d440010,0x0dc80345,0x443e24ff}},	//   _שדרו, žian, лучи_, _ait_
  { {0xe1f9007a,0xd264001e,0x7de4000e,0xe3ae002d}},	//   vių_, _viņš_, tősz, об_
  { {0xd7e4002d,0xa3bb0012,0x7a010035,0x7c3e01a0}},	//   _лісо, عاشر_, mēti, _xipr
  { {0x7a010039,0x67e00163,0x3cfc0044,0x3bbc000b}},	//   lēti, _möjl, _लेने_, תמוד
  { {0x25bf007d,0x40950048,0x386d2500,0x7de40031}},	//   _unul_, арот, tser_, sősz
  { {0xe1f9007a,0xdb1a02d1,0x443e0689,0x68ed0164}},	//   rių_, _botó, _fit_, nzad
  { {0xe1f9007a,0x443e003a,0xa7650447,0x1e000011}},	//   sių_, _git_, шкод, ोक्ष_
  { {0xe1f9007a,0x7c3e01a2,0xed5a07a1,0x9f960040}},	//   pių_, _ripr, кон_, _væø_
  { {0x63a32190,0x19590015,0x443e0070,0x62832501}},	//   lenn, _рады_, _zit_, muno
  { {0x4c830014,0x63c4000e,0xdb1a125b,0x515a0009}},	//   оляв, _átné, _fotó, _סכסו
  { {0x61fb000d,0xdb1a0034,0x6609001b,0xb6020030}},	//   liul, _gotó, _ljek, _řádc
  { {0xa96a0014,0xd7fa0009,0x98140012,0x78bc0035}},	//   кива_, _שהצל, _ابنا, ārve
  { {0x65bb004a,0xd848001a,0x24f6002d,0xdb080028}},	//   _vähä, _họa_, _вчор, _ólík

  { {0x67560003,0x60db047b,0x20360012,0x63a32502}},	// [6400] لخار, nyum, لفرس, kenn
  { {0x65bb0006,0x47c3002d,0x60c90054,0x63a32503}},	//   _tähä, обув, ixem, jenn
  { {0xe37b0093,0xd37b000b,0x5b7b000b,0x1eca0014}},	//   _בריר, _בריט, _בריא, ължи_
  { {0x6996002d,0xdcf6003a,0xe7290003,0x443e2504}},	//   _трох, _hayı, اسكو_, _sit_
  { {0xdcf600a2,0x9cf60001,0xa5bb000e,0x7a01001e}},	//   _kayı, јчеш, nlóa, cēti
  { {0x7bce006f,0x3eab004a,0x0bf30024,0x61e9092c}},	//   njbu, äitä_, опію, ehel
  { {0x98b200a2,0x628302d1,0xb4db03eb,0xdcf6003a}},	//   mayı_, guno, ncàr, _mayı
  { {0x98b2003a,0x973c0027,0x443e051c,0x6a130012}},	//   layı_, jeća, _wit_, يبير
  { {0xc7c617fe,0x63530066,0xe3aa004c,0x629e016d}},	//   асни, nění, _икад_, _lppo
  { {0x443e00bd,0xf093000b,0xf41f004a,0x3879000e}},	//   _uit_, קנת_, ntät_, ásra_
  { {0x09e6007c,0x8c1b000b,0x6283000d,0x3eb8000e}},	//   _кожн, _יומי, cuno, írt_
  { {0x61fb000d,0xceb30009,0x5e770009,0x5183038f}},	//   ciul, קיר_, סתכן_, _душа
  { {0x53470046,0x70540003,0x98b2003a,0x3eb90035}},	//   ихва, _انتا, kayı_, āsta_
  { {0xb09b0009,0x6fb30012,0x66062505,0x7a010035}},	//   _סיור, _ومنا, ankk, vēti
  { {0xec34002d,0x8e840003,0x25b0004a,0x72050012}},	//   інсь, _العه, öllä_, موسم
  { {0x68ed03eb,0x31c4007c,0x2f3b000b,0x7a250028}},	//   tzad, осув, _בגוד, jótl
  { {0x7c95000a,0x63a30ca7,0x98b2003a,0xe76b004c}},	// [6410] _الخص, yenn, fayı_, вјек_
  { {0x66090119,0x3d1a0037,0x7a01001e,0xad1c0009}},	//   _sjek, _बड़े_, rēti, _בוחר
  { {0x0dcb0024,0xf7700012,0x5695003c,0x63a32506}},	//   куди_, باق_, сает, venn
  { {0x3618007c,0xdcf6003a,0x261c01e3,0x7a010035}},	//   ацію_, _zayı, díos_, pēti
  { {0xdcf600a2,0x22b5001e,0x4423009b,0xe5090012}},	//   _yayı, _sāk_, olj_, ديشو_
  { {0xdb0500d9,0x2fe50012,0xbca40012,0xb1360009}},	//   _zahá, _اكسف, تمهي, _לארח_
  { {0x6fc40044,0x66090144,0x539c0009,0x7eb00031}},	//   रारू, _tjek, דיוו, rópá
  { {0xf9910003,0x61e9019a,0x63a32507,0x2cac008e}},	//   سبب_, uhel, senn, ähdä_
  { {0x973c001c,0x20d5007c,0x62832508,0x61e9060f}},	//   veća, сійс, suno, rhel
  { {0xdb010052,0x7d1e0034,0x3e630031,0x0ea9003c}},	//   _palä, ępst, tűt_, гкой_
  { {0xee3a0146,0x66f90037,0x261c0164,0x38c10028}},	//   лно_, ्पिक_, cíos_, færð_
  { {0xdcf600a2,0x5a350001,0x68290066,0x644112bd}},	//   _sayı, _унет, _vždy, _hili
  { {0xf41f004a,0x49b80003,0xd848001a,0x64412509}},	//   ytät_, _خالد_, _tọa_, _kili
  { {0xf8b60093,0xb05b0052,0x66190034,0x6441016d}},	//   _לפני_, _kräf, howk, _jili
  { {0xfbd2000b,0x499a003c,0x98b20060,0x6441250a}},	//   לתך_, лтая_, vayı_, _mili
  { {0x5e76000b,0x68ec003a,0xb1460014,0x91a6001a}},	//   _התקן_, _öldü, снал, _khó_
  { {0xdce40010,0x64490010,0xb4db0054,0x98b2003a}},	// [6420] _keič, _nuei, scàr, tayı_
  { {0x3b860001,0x6441002c,0x076a0003,0x798903de}},	//   _улог, _nili, اماً_, hgew
  { {0x98b200a2,0x3cfc0037,0x6d440010,0x45460003}},	//   rayı_, _लेते_, žiam, مناق
  { {0x798900bd,0x261c0164,0xc3330009,0x75890024}},	//   jgew, víos_, _מות_, исів_
  { {0xa1360003,0x999e0010,0x6441250b,0x44fa0012}},	//   _دردش, ūtų_, _bili, دراج_
  { {0x0e6a0003,0x395f1f85,0x0c370012,0xd8480081}},	//   _مصري_, ebus_, مكنة_, _bọn_
  { {0xeaaf0003,0xfe580009,0xd3790024,0xd257003c}},	//   فعي_, _כֻּל, рчі_, бцы_
  { {0xf1bf001a,0x905405f7,0xd2b70009,0x3b090009}},	//   _phái_, овиц, מלצת_, ימוּ_
  { {0xc1b70015,0x8b960021,0xdfda0048,0x2242005e}},	//   слых_, _греч, гън_, _mikk_
  { {0xad9b0065,0x22420033,0x5457000b,0x2fca0012}},	//   rnúm, _likk_, _לסמן_, ابةً_
  { {0xa3ad0044,0x501b0093,0x70a50037,0xad9b0028}},	//   _औसत_, רויו, _ऑन्ल, snúm
  { {0xdce00039,0xdb1a0149,0xf1bf0020,0x68ed0002}},	//   _zemā, _entã, _thái_, _żade
  { {0xa5bb0026,0x999f003a,0x81430012,0x3946016d}},	//   blón, lmuş_, _عنون, _igos_
  { {0xad9b0029,0x48130024,0x7a050073,0xd0100012}},	//   onúk, _еміс, mėti, _تلت_
  { {0x7a35007a,0xb797000b,0x6ffb0009,0x8a780009}},	//   _ištr, _הכוח_, _תפוג, יָּק
  { {0xd257000b,0x2242000e,0xbbb40011,0x000000c4}},	//   משלה_, _cikk_, ंयुक,
  { {0x4d78000b,0x7a080066,0x02a50011,0xc94b0009}},	// [6430] _התחל_, větl, _खन्न, אֲבֹ
  { {0x645d006f,0x752d0027,0xdd310002,0x8af90014}},	//   mpsi, _izaz, _mężc, _внос_
  { {0x22420033,0x61e3000d,0x81c8001e,0xa3b80037}},	//   _fikk_, _înlo, orēķ, ज़ार_
  { {0x63a7003e,0x95670014,0x22420033,0x7a050010}},	//   lejn, съжд, _gikk_, kėti
  { {0x7a350027,0x64491c05,0x6441250c,0x62870761}},	//   _oštr, _quei, _pili, lujo
  { {0x62870061,0x7a050010,0xdb03025b,0xb05b0052}},	//   oujo, dėti, lené, _präf
  { {0xc7b2000b,0x61ed0051,0x7a01001e,0x973c0027}},	//   _קבל_, ohal, zētu, dećo
  { {0x26de0010,0xdd94003c,0xdb030064,0xef180035}},	//   dyto_, _насы, nené, ngļu_
  { {0x644103fc,0x2cad0036,0x76580010,0x63c40066}},	//   _tili, _used_, _atvy, átní
  { {0xcf39002d,0x316b0002,0xb05b006f,0x7ff50003}},	//   ичні_, _lecz_, _träf, تسبا
  { {0x63a7250d,0x656f0052,0x060a0055,0x7afc00eb}},	//   dejn, fach, инок_, _žrtv
  { {0xfbc9000b,0x2214002d,0x2480163d,0x80b10011}},	//   _בת_, _ефір, šime_, _अनपे
  { {0x9c820066,0x3e48003a,0xdb030042,0x387e0035}},	//   _účte, _işte_, dené, _ātro_
  { {0xdee50046,0x7a010035,0x853a0009,0x2ca00060}},	//   _моли, rētu, יגרי, çidi_
  { {0xed5a0098,0xe7ff0037,0xc7440003,0x22420051}},	//   _кой_, ोचना_, _عضوي, _pikk_
  { {0x32090101,0x61ed250e,0xb2260024,0x7bc50018}},	//   gnay_, ghal, імал, _enhu
  { {0x68300052,0x6fdf0061,0x6fcd0011,0x7c660012}},	// [6440] häde, _pêch, तापू, _باعل
  { {0xb4e60044,0xbb860003,0x63a70066,0xfc320012}},	//   पनी_, _بلدي, cejn, _تحب_
  { {0xba760003,0x61460001,0x5ea60003,0x539b000b}},	//   _باخت, _мена, تمال, _דייו
  { {0x4444250f,0xa5260014,0xdb0805b1,0xbd490012}},	//   _hi_, омед, _nadá, مؤهل_
  { {0xc5f3000b,0xa6de001a,0x44442510,0xf1bf001a}},	//   ודא_, _ngưn, _ki_, _cháu_
  { {0x27160066,0x2ca90d04,0x61e42511,0xbc370012}},	//   něné_, çada_, lkil, يسوا_
  { {0x6830006f,0xfbd30009,0xb05b031d,0x41c50011}},	//   rädd, ותג_, _präg, वांस
  { {0x61e40006,0xe6170014,0x672e0027,0xfa330012}},	//   nkil, _ддс_, _izbj, وريد
  { {0xc05a002d,0x98a30001,0xdfa6004c,0xa0a60024}},	//   шій_, диње, ојно, ішил
  { {0x33d5002d,0xc7b80027,0x656f0832,0x109b0009}},	//   _ніхт, kođe_, wach, סביב
  { {0xb05b0052,0x2450001a,0x61ed0029,0xc43b000b}},	//   _träg, _hàm_, yhal, _כתמי
  { {0x69a10037,0x44442512,0x7bda2513,0x26de2514}},	//   _कॉपी, _ai_, ötun, ryto_
  { {0x44440750,0x656f0b3d,0x63a70066,0x81c8001e}},	//   _bi_, rach, tejn, rrēķ
  { {0x68ec003a,0xdb08014a,0x61e40225,0x9c8305b1}},	//   ıldı, _zadá, ekil, _účet
  { {0x24500020,0x44442515,0x6fc90044,0x63a70026}},	//   _làm_, _di_, रासं, rejn
  { {0x244f00a2,0xdce60039,0x3f8c0028,0x527b000b}},	//   _tüm_, sakā, lgdu_, ינלא
  { {0x44442516,0x68fb0029,0x93470003,0x2fd82517}},	// [6450] _fi_, _ľuds, _وخدم, _borg_
  { {0x44442518,0x3f8c0028,0x61ed027e,0xcb350014}},	//   _gi_, ngdu_, shal, _непъ
  { {0xdb0a0065,0x656d00b6,0xac380012,0xe7190012}},	//   ldfæ, _keah, _بسيط_, حيات_
  { {0x29dc02d1,0x4444007d,0x661d004a,0x6445002c}},	//   _días_, _zi_, nosk, _hihi
  { {0xe7bc0044,0x444400a2,0x69ce0044,0x8cbe0037}},	//   ्ञाप, _yi_, थानी, शियो
  { {0x493a000b,0xf8da0009,0xd8da0009,0x68300248}},	//   _לגרו, _החשמ, _הקשר, täde
  { {0x5b7c000b,0x6445004a,0xbb420048,0x337c0009}},	//   ברוא, _mihi, нешк, שְׂב
  { {0x2fd80070,0x798d00b6,0xb05b006f,0x6445002c}},	//   _zorg_, ngaw, _träd, _lihi
  { {0x2458003c,0xdb080031,0xa156004c,0xa5bb0031}},	//   _мать_, _vadá, чању_, rlól
  { {0xbca40003,0xf092000b,0x7a050010,0xf1b9001b}},	//   _تمكي, עני_, mėtu, doše_
  { {0x7a05007a,0xdb1a0017,0x61e40028,0x98ab003a}},	//   lėtu, _botõ, ykil, ımız_
  { {0xba9a0009,0xd8750012,0x20d70012,0x7a010035}},	//   _לסעי, _فاتب, _وتشج, rēts
  { {0xb4e60044,0x3f910002,0x27160066,0x660b0190}},	//   पने_, _oczu_, těné_, ingk
  { {0x69d90036,0x29240029,0xeb9a004c,0x58ba0009}},	//   _howe, ísať_, љив_, _למנצ
  { {0x61e400a2,0x644500b6,0x78bb0097,0x232a06bd}},	//   tkil, _dihi, lvuv, сови_
  { {0x798d0101,0xc2430136,0xc3320009,0x6d440073}},	//   ggaw, енск, תול_, žiai
  { {0x62830066,0x24530003,0x44440deb,0x20d60024}},	// [6460] hrno, _كنيس, _ti_, чівс
  { {0xd12f0003,0x69d9002a,0x61fd0051,0x798d002c}},	//   امك_, _lowe, _emsl, agaw
  { {0xf1bf0020,0x2bf7000b,0x33db0009,0xc8690009}},	//   _phát_, _זמין_, _החיד, רן_
  { {0x69d9003e,0xcf890009,0x29dc01e3,0x224c0030}},	//   _nowe, טט_, _vías_, ídku_
  { {0x91bb0093,0x5d1a0003,0x200100b6,0x49bb0009}},	//   _המכי, حتاج_, bihi_, _המכס
  { {0xa533007c,0x38602519,0x660b1642,0xc4770009}},	//   хніч, mpir_, angk, לתנו_
  { {0x6fc90037,0xa6a90003,0xb05b0032,0xbea3034d}},	//   रारं, _وافق_, _gräb, _парк
  { {0x5eeb000b,0xd6eb0009,0x1e970009,0x9f5e251a}},	//   _הַמְ, _הַמָ, _מכלל_, mité_
  { {0x9f5e0108,0xc034004c,0x69dd005e,0xbe130012}},	//   lité_, мниј, ösea, _أوقع
  { {0xb4d80037,0x25a00051,0x7bda005e,0xd7f701c6}},	//   ाही_, _abil_, ötul, зую_
  { {0x2127008a,0x47340094,0x9f5e11ff,0x23890066}},	//   ́nh_, ьнос, nité_, ňují_
  { {0x63aa0028,0x644505ea,0x6602251b,0x69d91603}},	//   lefn, _sihi, niok, _gowe
  { {0x644d0149,0xd7e6002d,0xe4c7003c,0x19bb0009}},	//   _quai, _ніко, чённ, _למאב
  { {0x493b000b,0x69d90070,0x987b0009,0x661d005e}},	//   _הגדו, _zowe, _פרוק, sosk
  { {0x9f9b000b,0x661d01bd,0x079b0009,0x45f90012}},	//   _הסופ, posk, _הסול, _وفتح_
  { {0xdb1a006f,0x9f5e0061,0x62980070,0xf8bf0576}},	//   _intä, dité_, itvo, _pré_
  { {0x2c27002d,0xc05b002d,0x7d7c000b,0x765c0002}},	// [6470] _ньог, сіб_, _הנחו, _atry
  { {0x44270164,0x201e0259,0x7c940012,0x7bda251c}},	//   _ón_, noti_, _أشيا, _notu
  { {0x200c0101,0x200100a2,0xd6db0014,0xdfd80014}},	//   indi_, rihi_, щта_, чът_
  { {0x2ca90017,0x660b0a60,0x98cc0011,0xb4d80011}},	//   çado_, ungk, ़माए, ाहू_
  { {0xee38007c,0x3e4c0066,0x201e1f85,0x61d60009}},	//   їні_, _děti_, koti_, _חורף_
  { {0x7a05007a,0xda650003,0x69d90168,0xf8b20009}},	//   rėtu, واعي, _sowe, _ששם_
  { {0x7528003e,0x9f5e251d,0x201e01ff,0x4e1d0037}},	//   ędzi, cité_, doti_, नवाई_
  { {0x7bc80065,0x200c00ea,0x3a29000e,0xceb20009}},	//   _endu, endi_, nlap_, _ביל_
  { {0x00c90024,0x85040012,0x69d90132,0x62980a84}},	//   ілок_, _كوفن, _vowe, atvo
  { {0x201e11a0,0xdb03251e,0xd7090015,0xff510003}},	//   goti_, lení, жное_, خخة_
  { {0x93940003,0xe7f50037,0x69d90f66,0xff560009}},	//   _سجلا, _इतना_, _towe, ובתך_
  { {0xf3e90093,0xae000037,0xed57002d,0x7bc0001e}},	//   _דף_, लोपन_, мою_, ēmum
  { {0x6d440da5,0x04680009,0xd5760009,0xab04005e}},	//   žiav, ֔יךָ_, ותרה_, öövä
  { {0x33d500bc,0x67d40511,0x7a080030,0xa022005e}},	//   ніст, _почу, věti, öötu
  { {0x60080009,0x9f5e0025,0x8c43137f,0x044305d4}},	//   _מִקְ, xité_, тере, терн
  { {0xdb0301e9,0x9f5e251f,0x9f450030,0xe3b80060}},	//   jení, vité_, chlá_, _akıl_
  { {0xd3780027,0xdb0301bd,0x6cd30012,0x41270048}},	// [6480] _hoće_, dení, _لقيا, дото_
  { {0xdfa60003,0xdee60001,0x629801bd,0x40e80009}},	//   بحري, мози, ytvo, הַעֲ
  { {0x86c6000a,0x4e020037,0x3e4c0066,0xb7d70012}},	//   بيان, _लगाई_, _pěti_, بولا_
  { {0x9f5e0108,0xb2bb0009,0x35e50024,0x2d920060}},	//   rité_, _ומטר, нців, üye_
  { {0xc1730093,0x3ead001c,0xa3b20044,0x68ed003e}},	//   _בחר_, _ćete_, _ऐसा_, _żadn
  { {0x6846002d,0x2ac60001,0x69dd02f1,0xc29a0009}},	//   _інва, дљив, ösen, ַיִך
  { {0x160e0044,0xe28f000a,0x7bda000d,0xdb07000e}},	//   ाचार_, لذي_, _votu, tejé
  { {0x80b50037,0x63aa0028,0x4efb0009,0x62982520}},	//   _उनमे, sefn, _והלו, rtvo
  { {0x7bda007d,0x201e03d3,0x68e400b6,0x6fd20011}},	//   _totu, toti_, nyid, ठापू
  { {0x6e2400c6,0xff980001,0x201e0010,0x24862521}},	//   _akib, чкој_, uoti_, mrom_
  { {0xd8480020,0xeb97002d,0xcb0a0003,0x3c24006f}},	//   _mọi_, _цих_, _بيان_, hövs_
  { {0x6d440010,0x6e362522,0x64480132,0xf1bf0081}},	//   žiau, _chyb, _hidi, _nháp_
  { {0xdca60003,0x32040002,0xe611000b,0x40940012}},	//   دى_, mimy_, אִם_, _ألتر
  { {0x6e2400a2,0x7a13000d,0xdb030042,0xd0100012}},	//   _ekib, măta, zení, _حلت_
  { {0x7ed30003,0xa2940024,0x07a3004c,0x60c20ba5}},	//   _لزيا, карі, _рајн, _hrom
  { {0xd2b7000b,0x2d8f0058,0x973c0027,0x32040002}},	//   וללת_, _øge_, jeći, nimy_
  { {0x973c0027,0x60f90015,0x7a13000d,0x7b67022a}},	// [6490] deći, чная_, năta, _отне
  { {0xc6170037,0xceeb0003,0x5fc90037,0x7ae3004a}},	//   तव्य_, يران_, राइल, yynt
  { {0x6c180003,0x9f45008e,0xa1590024,0x9f040012}},	//   _تتيح_, silö_, _нану_, نوكو
  { {0x6830006f,0xbdf80012,0xbb3a0009,0x8c950024}},	//   räda, ورنا_, _מעתי, еркі
  { {0xb4e90037,0xdb030029,0xfdf8000b,0x4d64002d}},	//   मने_, rení, וצאת_, тків
  { {0x7ae3008e,0xdb0303a7,0x9f5a01a0,0xc6a72523}},	//   tynt, sení, cipà_, _орби
  { {0xd8480020,0x387e001e,0xf9910012,0xb17b00b0}},	//   _gọi_, _ātri_, هبة_, _flåt
  { {0x6287004a,0x9e480029,0x030d001a,0xe0d901b6}},	//   irjo, _keďž, _đều_, зви_
  { {0x7c15002d,0x320d2524,0x7bda005e,0x6d560060}},	//   _здає, rney_, ötuk, ıyat
  { {0x6448003a,0xf8b2000b,0x660f08f4,0x6e241f24}},	//   _gidi, נשי_, enck, _skib
  { {0x6d440010,0x32040034,0x7a080030,0xd62a11a2}},	//   žiat, bimy_, větv, зоне_
  { {0x98a0007a,0xb2ba0009,0x2bc70011,0x6abd0011}},	//   _šią_, _ממער, लाका, ्मीर
  { {0x2e320028,0x8cc20037,0x60c20404,0x3c360040}},	//   gáfa_, लियो, _grom, hæve_
  { {0xb6020066,0x98f40012,0xccf201b0,0xda660012}},	//   _žáda, _جثما, נכם_, فاري
  { {0xf1bf0020,0xf1d30044,0x20052525,0x16000011}},	//   _pháp_, थापन, mili_, लोडर_
  { {0x61e92526,0x4efa0009,0x69dd0e9c,0x3ebe0097}},	//   nkel, _מהצו, _cose, _átti_
  { {0xa84a000a,0x6287004a,0x04570003,0x69dd0c9f}},	// [64a0] سلام_, arjo, _كلية_, _dose
  { {0x68f60002,0xd7f9002d,0xad1b000b,0xb17b10bd}},	//   rzyd, мує_, _מופר, _slåt
  { {0x69cb2527,0xf1bf001a,0xabfb0009,0xeb970009}},	//   _onge, _tháp_, _זהיר, _אדיר_
  { {0xe5720003,0x6606015e,0x7ae12528,0xc27b0009}},	//   اطا_, nikk, älte, _צרכי
  { {0x43940015,0xdb030029,0x2005045b,0xe5730009}},	//   валс, rdný, kili_, רַע_
  { {0x628e0066,0x66060c39,0x24801187,0x69cb2529}},	//   oubo, hikk, šimo_, _ange
  { {0x8c1b000b,0x539b0009,0x7c2a0132,0xbf160012}},	//   הוסי, פיקו, rlfr, _أوزب
  { {0x7bde0006,0xf2d3000b,0xf1b9001e,0x7e9b000b}},	//   _lopu, רעה_, toša_, _מסלו
  { {0x3157000a,0x8c95007c,0x64480163,0x6c860003}},	//   رجية_, _архі, _tidi, _سلام
  { {0x200500a2,0x3204003e,0x547b000b,0xa2c00011}},	//   gili_, simy_, _מטמו, विद्
  { {0x3f9e0028,0x63ae0066,0xc7f70009,0xa3c40011}},	//   rftu_, debn, גזית_, _एफ़_
  { {0x61e910cc,0xa2570009,0xc3330009,0xb9260012}},	//   ckel, _נבדק_, _עוף_, _كفاي
  { {0x7a250028,0xdb0301bd,0xafe61728,0x37e60588}},	//   rótt, mená, _подл, _подг
  { {0x63ae008b,0x66060006,0xd25b003c,0xdb030031}},	//   gebn, aikk, зца_, lená
  { {0x1757000b,0xdbc70051,0x7ee30003,0x63ba006f}},	//   _אסור_, _töös, _مكون, _matn
  { {0x8e830003,0x6606000e,0x8e970009,0x8cbe0011}},	//   _إليه, cikk, _נדחו_, शिशो
  { {0xc61d0011,0x18980012,0x9be70024,0x3e4c0030}},	// [64b0] नवीय_, فضلة_, _зінк, _větu_
  { {0xf7700003,0xb05b0d4c,0xe944003c,0xdb070030}},	//   مام_, _frän, ухсо, lejí
  { {0xb05b0163,0x56950015,0xf773000b,0x44230027}},	//   _grän, тает, רקע_, moj_
  { {0xaf340003,0x24eb000b,0xd6270012,0x14750012}},	//   اركت, ּקַּ, رعاي, ناتج
  { {0xe458002d,0x672a0028,0x63ba0097,0x4425016d}},	//   ежі_, _lyfj, _batn, _pkl_
  { {0x4423001c,0xeab10012,0xe3b10012,0xfce20198}},	//   noj_, لعب_, شرت_, рошо
  { {0x61e90006,0x63ba0039,0x28030002,0xb5a70511}},	//   tkel, _datn, ępną_, _прай
  { {0x2005252a,0x63ae0002,0xe9d10012,0x68300032}},	//   wili_, zebn, شغب_, hädl
  { {0xbcdb0003,0x44230082,0x16c90037,0xdb070030}},	//   _عذرا_, koj_, िम्ब, dejí
  { {0x4423001c,0x66060070,0x113c0009,0xa8a40012}},	//   joj_, wikk, התחל, اصيو
  { {0xdb01252b,0x3dcd002a,0x9aa40012,0x63ae01bd}},	//   _való, _knew_, _مملو, vebn
  { {0x7a13007d,0xdce00066,0x69cb0d51,0x3ddf0070}},	//   măto, _nemě, _unge, _jouw_
  { {0x63ae0013,0x7a13000d,0xf41f02fe,0x2005252c}},	//   tebn, lăto, rrän_, pili_
  { {0x6606252d,0x58f6000b,0xafe20015,0x629c03a2}},	//   sikk, _שמסע_, _вошл, ttro
  { {0x7a13000d,0x629c0017,0xadfa0012,0x6606005e}},	//   năto, utro, _يربط_, pikk
  { {0x212b0066,0x63ae048b,0xe71601b0,0x629c252e}},	//   _bych_, sebn, _בחצר_, rtro
  { {0x628e002c,0x2bba0003,0xa3ba0003,0x80a60012}},	// [64c0] subo, _قادة_, _قادر_, ضمان
  { {0xf1b9001e,0x3c770009,0x25370009,0x8c460024}},	//   košo_, _שתים_, _בנפש_, _шепе
  { {0xc815007c,0x6e220051,0x224b006f,0xf1b9001e}},	//   уєть, toob, _fick_, jošo_
  { {0x224b0163,0x98b10030,0x9f5e0030,0xf1b90035}},	//   _gick_, íběh_, vití_, došo_
  { {0x2b060044,0xe76a0003,0xdb0a0058,0x22400051}},	//   _हेतु_, _يحسن_, ldfø, mmik_
  { {0xdce00066,0xdb070066,0x82a60015,0xb4fb0009}},	//   _země, zejí, вшие, ופני
  { {0x63a3000f,0xfba40037,0x2ba40037,0x7a13000d}},	//   _önne, ख्यम, ख्या, găto
  { {0xcb130093,0xa9c3002d,0x7a080066,0xada603e2}},	//   ילו_, аськ, věts, _шабл
  { {0xc7b00012,0xf1bf0031,0x44a500ae,0x1c46107e}},	//   مّة_, _okán_, _محلّ, _анам
  { {0x6604000f,0xaac60012,0x6c330012,0x394f0132}},	//   _amik, _لتصن, _نفقا, _eggs_
  { {0x7a13000d,0xf1b9001e,0x442309b5,0xef1f0060}},	//   căto, cošo_, voj_, şün_
  { {0x6f0305ab,0x867b000b,0x3ebe0028,0x6281000e}},	//   únci, ורטו, _áttu_, álom
  { {0x5c070098,0x6fb60003,0x442301d2,0xf8b60011}},	//   вява, _لمشا, toj_, _अनिय
  { {0xdb070013,0x224b036c,0xce940048,0x443a252f}},	//   sejí, _sick_, _бакъ, _chp_
  { {0xf837000b,0x1837000b,0xaad20037,0x9f5e00c1}},	//   _שנות_, _שאול_, थमिक, mità_
  { {0x9f5e01a2,0xed59013a,0xb05b0248,0x4423001b}},	//   lità_, _kaže_, _fräl, soj_
  { {0xdb07000e,0x6d5d000e,0xb8950012,0xcf9b004c}},	// [64d0] ldjü, mcsa, طلاع, дје_
  { {0x9f5e01a2,0x109b000b,0xd9440001,0x61440001}},	//   nità_, ובמב, ређи, ређа
  { {0xdb0303eb,0xf7700003,0xa3b60037,0x628a0040}},	//   menç, زال_, ज़न_, jrfo
  { {0xed58007c,0x212b003e,0x2d940024,0x61f6101a}},	//   вої_, _tych_, иріс, chyl
  { {0x65940046,0x4584002d,0x1da50037,0x69cf2530}},	//   рачу, ргів, ग्यत, _ince
  { {0xf1b9001e,0x59d10037,0x7a13000d,0x61ed0380}},	//   tošo_, हावर, tăto, lkal
  { {0xa2c00037,0x36d40015,0x9f5e00c1,0x7a080030}},	//   विष्, _корр, dità_, větr
  { {0x7a13000d,0xc5f9001e,0x5338000b,0xdb1a0054}},	//   răto, spēj_, כנון_, _matè
  { {0x49d60009,0x7a13004b,0xf1b90035,0x9d15003c}},	//   אֵין_, săto, sošo_, _сдач
  { {0xa7b50001,0x7a13000d,0xdb030028,0x5fcd0011}},	//   усиј, păto, venæ, ़ाइल
  { {0x764d00c6,0xb9950012,0xdb050030,0x61ed2157}},	//   _biay, _ملاب, _pahý, kkal
  { {0x76550002,0x2459001a,0x26b6000b,0xb2260097}},	//   _muzy, _kèm_, נִים_, rhæð
  { {0x2d9e003e,0xe0ce0560,0xc7a50048,0x07a50048}},	//   ęte_, _ув_, _билк, _балн
  { {0x9f5e01a2,0x2d9e0013,0xb2260065,0x6c360012}},	//   cità_, řte_, phæð, افسا
  { {0xf8bf0031,0x8f9a0009,0xd8480081,0x479a0009}},	//   _szép_, _ניקי, _vọt_, _ניקס
  { {0x61ed002c,0x5cd60024,0xdb1c11e4,0x7ae10248}},	//   gkal, _біох, ndré, älta
  { {0xb05b006f,0x68e900b6,0xa5bb000e,0x6e26000e}},	// [64e0] _främ, nyed, alós, mokb
  { {0xdb030017,0xb8dc0011,0x46f60048,0x99890034}},	//   cenç, _आन_, лчет, gnał_
  { {0xdfcf0012,0xdb9b0009,0x0bb70009,0xbd8a0012}},	//   ثيل_, _אסיר, _גלים_, فنان_
  { {0xd5b9002d,0xed5a16dd,0xdd8f0012,0x05ba0012}},	//   ксі_, ход_, كوم_, عدات_
  { {0x63be000e,0xa0750015,0x0cd400fa,0xa4d4002d}},	//   _kapn, _высш, ролю, ролі
  { {0x7ff60012,0xf5370009,0xd7f20012,0xdc890009}},	//   _إسحا, ננסי_, _اكس_, דְקָ
  { {0x9f5e01a2,0x2bd50044,0x60c40017,0x139b000b}},	//   vità_, दाता, lvim, תבצע
  { {0x248009ea,0xeaaf0012,0x60c42531,0x69db0097}},	//   _ovim_, سعى_, ovim, gjue
  { {0x2733001a,0xe45f003a,0x9f5e00c1,0xdb1a0c4d}},	//   _ạn_, _çöp_, tità_, _maté
  { {0x16000037,0x6281000e,0xbcfb0061,0xdb1a0061}},	//   लोरर_, álok, ncée, _laté
  { {0x9f5e152c,0x9f34002d,0x8f340a76,0x57fb0009}},	//   rità_, рені, ренц, גליו
  { {0x867b000b,0x9f5e00c1,0x60c4003a,0xdb0a0017}},	//   ערכו, sità_, kvim, nefí
  { {0xcd070731,0xdb030017,0xae040037,0xf1b30009}},	//   учни, tenç, शोधन_, _לסף_
  { {0xab950046,0x61e20005,0xe4540015,0x30830003}},	//   јављ, _hool, скры, _الوف
  { {0x61e20005,0xf1b80037,0x1f5b000b,0xdb030c56}},	//   _kool, _आसान, _אדוא, renç
  { {0x6738001c,0xdb1a0061,0x69c000c8,0xdb030017}},	//   _izvj, _caté, ndme, senç
  { {0x9da80048,0x15a80048,0xa775004c,0x6234004c}},	// [64f0] _съща_, _същи_, илач, сету
  { {0x61ed0ba1,0x7bda005e,0x6aba0032,0x21e7005e}},	//   skal, ötut, _ostf, _rõhu_
  { {0x6e99002d,0x60c41f85,0xbb760009,0xf7700012}},	//   твер_, avim, _דעתו_, ثاق_
  { {0xe60e007c,0x867b000b,0x69cf002a,0x63be01bd}},	//   ід_, תראו, _unce, _zapn
  { {0x6aba007d,0xa97a000b,0xeb0d0011,0xeb990d4e}},	//   _astf, _בארכ, िप्त_, вил_
  { {0xa3cb0011,0xda650048,0x6265193d,0x38692532}},	//   _रोम_, авки, авка, mpar_
  { {0x6ff40034,0x93940012,0x09f505c8,0x69c00227}},	//   yńcz, إجها, ичия, fdme
  { {0x11e50047,0x7a0c004b,0x99d50012,0xdb03008e}},	//   ржим, oşta, شتبا, venä
  { {0xe534002d,0xf7710003,0x45d405d8,0x6fb50012}},	//   _геть, ياد_, _уотс, لمظا
  { {0xef1f00a2,0x93940003,0xd7e60015,0xdb0300ff}},	//   şüm_, _هجما, имые_, tenä
  { {0x2480001c,0xc7b2000b,0x6e26000e,0x325501d4}},	//   _svim_, חבי_, tokb, _твер
  { {0x09e10011,0x75e60031,0x6cc60198,0x660b0032}},	//   _नवगठ, _rózs, айма, nigk
  { {0x442700b9,0x7ae10052,0x200b0061,0x64430328}},	//   oon_, ältn, écis_, omni
  { {0x70fa000b,0x69a10037,0x660b0052,0x6e26000e}},	//   _בהנח, क्री, higk, sokb
  { {0xdb010066,0x56920001,0x232a0103,0x64430035}},	//   _oblí, _дајт, тови_, imni
  { {0x7166000a,0xd848001a,0x171a000b,0x60c40027}},	//   شارك, _họp_, _בוצע, tvim
  { {0xdfd2000a,0x97560046,0x4223002d,0x661d000e}},	// [6500] يير_, атељ, ідув, érke
  { {0x6443003e,0xbc7b000b,0xd47b000b,0xe53b000b}},	//   jmni, _שנית, _שאיל, _בתפר
  { {0xdfcf0003,0x660b0052,0x1dda0011,0xe4f60011}},	//   ظيم_, figk, _बचात, ुछवि_
  { {0x660b0052,0x248d05b1,0xc27b0009,0xfb370009}},	//   gigk, šeme_, _ברטי, _כאיש_
  { {0x8d5b000b,0x68300052,0x44fa0012,0xa3cb0011}},	//   דכני, hädi, خراج_, _रोड_
  { {0x61e22267,0x44272533,0x68220064,0xe3af00ae}},	//   _sool, gon_, hôdz, ِري_
  { {0x61e20005,0x66e60ed4,0x501b0009,0x660b2534}},	//   _pool, _това, _סולו, bigk
  { {0x2489001e,0x9874048c,0x28a60024,0xd6cf0012}},	//   šama_, блиц, ашог, _تقف_
  { {0xdfd0000a,0xf1bf2535,0x44272536,0x61e2005e}},	//   كية_, _cháy_, bon_, _vool
  { {0x23780009,0xdb780009,0x33780009,0xdcc90012}},	//   _תָּמ, _תְּש, _תְּב, _حذفه_
  { {0x75d5000a,0xcf57000b,0x20190054,0x93fb000b}},	//   ميدا, יבית_, ésia_, _שלבי
  { {0x2607002d,0x98a60696,0xe1f90073,0x10a6016e}},	//   рчог, _виде, chų_, _видн
  { {0xf9fb0009,0x628e2537,0x01fb00af,0xd13000ae}},	//   _בהאמ, erbo, _בפאל, _عمت_
  { {0x9ce40024,0x99890034,0xed590073,0x8fa3004c}},	//   іцял, znań_, _maža_, _даље
  { {0xf8b60044,0xaae8002d,0xe8b60037,0x70b60037}},	//   _अनुप, аєте_, _अनुच, _अनुल
  { {0x41680001,0x7bda0051,0xd6db000b,0x200c2538}},	//   ијум_, ötur, _יחול, lidi_
  { {0x442701e5,0xa3b60044,0x628e10d8,0x5e440012}},	// [6510] yon_, ज़ा_, arbo, _بَيْ
  { {0x4fd4002d,0xc7f8002d,0x59a60011,0x1e1f0011}},	//   ожут, анує_, क्तर, यक्ष_
  { {0x63b5012e,0x660b0052,0x44390010,0x1754002d}},	//   mezn, tigk, _ės_, івця
  { {0x7ae80052,0x38690b11,0xa3a90011,0x9f5e008e}},	//   ädte, ppar_, ग्न_, litä_
  { {0x71d6000b,0xfd100003,0x660b0052,0x44980024}},	//   _הורד_, وجه_, rigk, ивцю_
  { {0x660b0052,0x8428002d,0xdb030064,0x29c30081}},	//   sigk, ажів_, menú, _ựa_
  { {0x9f5e004a,0x38660017,0x68ed01ea,0x7a13000d}},	//   iitä_, _ator_, lyad, lăti
  { {0xef1f00a2,0x44272539,0x40950373,0xdb07005e}},	//   şük_, son_, брот, mejä
  { {0x63b5000e,0x91fc0035,0xdb07079f,0xf1b9253a}},	//   kezn, _itāl, lejä, noši_
  { {0x3179000f,0x753b0027,0x41020015,0x2d991886}},	//   _lesz_, _izuz, языв, egse_
  { {0x539a000b,0xbbb30037,0x63b5253b,0xa3bd0011}},	//   _תיעו, ंजीक, dezn, ीएन_
  { {0x7bc103fc,0xf3e90093,0xe5a6003c,0x200c005e}},	//   _halu, _אף_, щими, aidi_
  { {0x9f4c004a,0x661b006f,0x31560009,0xf2360009}},	//   ehdä_, _mjuk, _הינן_, _פרנץ_
  { {0x09340003,0x61fb0051,0x03a60001,0x7bc101b7}},	//   _برمج, lhul, љиво, _jalu
  { {0x6e950351,0xb7da0093,0xe695000a,0xa3a90044}},	//   _العا, _תקצי, _العد, ग्य_
  { {0x9e640012,0x7bc1016d,0xe862004b,0xdb180031}},	//   _باون, _lalu, _înţţ, ndvá
  { {0x7a13000d,0xe7ee0037,0xed620010,0xe45f0248}},	// [6520] găti, _चकमा_, ąžą_, lvön_
  { {0xa3a90037,0xdb1c1ef5,0x9cdb0009,0x5fd20011}},	//   ग्म_, ldrí, _עקיפ, साइल
  { {0x66760012,0xc68f0012,0x683d0025,0x5b570009}},	//   صدار, ِّم_, cède, _לייב_
  { {0x7e63000e,0xdb1c1aa3,0x765a0025,0xe5e50012}},	//   ínpa, ndrí, _étym, يثني
  { {0xceb8003e,0x628100d9,0x7c83027f,0x442a0532}},	//   zwę_, álov, пуще, oob_
  { {0x69c4253c,0x3ebd004a,0x68f60002,0x66090060}},	//   ldie, äytä_, _żydo, _emek
  { {0xd378001c,0x2bb90037,0x7ac60015,0x200c253d}},	//   _već_, _इसरा, ссле, vidi_
  { {0x7ae50051,0x7bc30029,0x63b50b32,0x6da3046d}},	//   ähta, adnu, zezn, _ниса
  { {0x657d000e,0xe918002d,0x224c0066,0x71d7000b}},	//   vash, ропі_, ídky_, מוקד_
  { {0x6e2d00c5,0x7bc1253e,0xe7ce0011,0x6ee60012}},	//   _skab, _galu, _होमप, مسجل
  { {0x9f5e0006,0x78a4035f,0x5f38002d,0x6e450028}},	//   vitä_, htiv, рпня_, _útbú
  { {0x61e60039,0xd7370093,0x61fb0347,0x07370009}},	//   _nokl, מטית_, chul, מאים_
  { {0x01360003,0x200c253f,0x09360012,0x1c39003c}},	//   _اعاد, pidi_, _اراج, измы_
  { {0xb05b0163,0x63a90027,0x69c42540,0x29000512}},	//   _kräv, đeno, edie, dzia_
  { {0xec34007c,0x9f5e004a,0x61e6079d,0x5f440012}},	//   їнсь, ritä_, _bokl, _بنغل
  { {0x245d008a,0xf1b9001e,0x3f8e0028,0xc27b0009}},	//   _tìm_, toši_, ófun_, טרלי
  { {0x7c970003,0x89340003,0x62950066,0x61e62541}},	// [6530] _اشعا, كعكا, suzo, _dokl
  { {0x661b006f,0xdefb0015,0x6609006f,0xab2b0012}},	//   _sjuk, лые_, _smek, _مسجل_
  { {0xd6d10003,0x69c4001e,0x68ed0de6,0x41c40037}},	//   بقا_, bdie, syad, _लोकस
  { {0x9999007a,0x7e9b000b,0x3f8a0002,0x569b000b}},	//   _visų_, רסאו, óbuj_, ריאצ
  { {0x7bc10005,0x03950035,0xdb180040,0xdb07005e}},	//   _palu, žīmā_, ndvæ, sejä
  { {0xdfdb0098,0x660f0169,0xd7f10081,0x24892542}},	//   _съм_, hick, _ỗ_, šamo_
  { {0x660f006f,0x7a33003a,0xce940014,0x7bc30347}},	//   kick, eçti, _наръ, rdnu
  { {0x7bc111f7,0x7c670012,0x22f80009,0x2aa10034}},	//   _walu, _هائل, מזון_, rób_
  { {0x2aa1003e,0x61fb2543,0x660f2544,0x7bc12545}},	//   sób_, rhul, dick, _talu
  { {0xdb1a0013,0x69c40029,0xa68500b3,0x94040012}},	//   _zatí, zdie, олод, _فوقه
  { {0x20f40020,0xae000044,0xa3b60037,0x660f00f1}},	//   ài_, लोकन_, ज़र_, fick
  { {0x58d50014,0xd62a0015,0x58b90012,0x660f2546}},	//   _моет, роме_, _ناتج_, gick
  { {0x5984002d,0x21580012,0xc0e507e8,0xb05b0032}},	//   _хліб, _اجمع_, _фолк, _kräu
  { {0xda660003,0x2b400030,0xd91a0009,0xdce90064}},	//   قاري, řice_, _דונל, _oceľ
  { {0xfbd2000b,0x386d2547,0xa34a0048,0x61e611b5}},	//   ותם_, lper_, рзва_, _pokl
  { {0x78a41624,0x69c42172,0x799b002c,0x2cbf0004}},	//   ttiv, udie, nguw, _osud_
  { {0x3fe60294,0x6c360012,0x69c42548,0x59b90011}},	// [6540] ожав, _وفعا, rdie, उज़र
  { {0x29000026,0xa91d0029,0xddc90034,0x628307a5}},	//   rzia_, mažd, _nieł, ksno
  { {0x7a13007d,0x5693002d,0x2cbf005e,0x78a42549}},	//   lătu, даєт, _asud_, stiv
  { {0x1ddd0037,0xdb1c0017,0x645b020d,0x26de01a0}},	//   यायत, adrã, _buui, _àtom_
  { {0x64b60003,0x5c73002d,0x21f8000e,0x9d1a0012}},	//   تحار, дліт, _néha_, جزاء_
  { {0x20190061,0xb8e00011,0x2caf0248,0xb05b0032}},	//   ésil_, ूट_, _ägde_, _präv
  { {0xa3a90037,0xfc3f0164,0xaab70012,0xab8b0009}},	//   ग्ध_, ntía_, قدير_, שָׂ֖
  { {0xd3780027,0xab5c001e,0xa91d0042,0x32db0009}},	//   _moći_, _daļa, každ, שחקנ
  { {0xb7bc0039,0xef18001e,0xbc6a0003,0xf1b9001e}},	//   loģi, daļa_, _ضمان_, jošu_
  { {0xb4d60037,0xddc90002,0xdb0e0028,0x27f80028}},	//   िमी_, _gieł, ndbó, órn_
  { {0x8cc20044,0x660f0107,0xd3780027,0x1f5b0009}},	//   लिको, tick, _noći_, ידיא
  { {0x2ca6005e,0x7d021804,0x3dc6254a,0x64410064}},	//   otod_, ozos, ndow_, _zhli
  { {0x7a13007d,0xe611000b,0xdb15000e,0x2ca60051}},	//   gătu, תִי_, mezé, ntod_
  { {0xdb15000e,0xc04f002d,0xdc8b01b0,0x889b0009}},	//   lezé, _іі_, יְלָ, _כבדי
  { {0x3d110044,0xc1ee0044,0xa2c00011,0x66730012}},	//   _देने_, _जवाब_, विट्, _قدير
  { {0xd3780027,0xbd6b004c,0xee08004c,0x91fc0035}},	//   _doći_, _трке_, _мејл_, _stāj
  { {0xf8bc0037,0x2e320028,0x7a13000d,0xe8550012}},	// [6550] ्टिय, gáfu_, cătu, سناد
  { {0xe4530003,0x62810066,0xf7700012,0x6283008e}},	//   _تضع_, álos, نام_, ysno
  { {0xdb15000f,0xd6db0731,0x35d00037,0xdd910003}},	//   kezé, шта_, _तोड़, فوا_
  { {0xdb15000f,0xa91d0027,0x62810027,0x25b90030}},	//   jezé, laže, šlos, nesl_
  { {0x7bc5002c,0xdb15000e,0x89da0009,0xc4f80012}},	//   _kahu, dezé, _החרי, يعها_
  { {0xa91d0066,0x22491e68,0x18760009,0xf8b20009}},	//   naže, lmak_, _מעשר_, _רשם_
  { {0xf414000b,0x1dc60037,0x660d01a3,0x7bc52012}},	//   ופס_, _रोकत, _omak, _mahu
  { {0x224900a2,0x7bc50051,0xa2cc0037,0xdb1c1ba5}},	//   nmak_, _lahu, हित्, ndrá
  { {0x63a9001c,0x6009002d,0xa91d02a1,0x97d90012}},	//   đenj, йним_, kaže, مبدأ_
  { {0xaf050098,0x9b880012,0xa3cb0011,0x386d06f6}},	//   зпол, _ونقل_, _रोल_, rper_
  { {0xf529000b,0x2249003a,0xdb0a066d,0x09f70012}},	//   _עץ_, kmak_, gefä, _وأصد
  { {0xd131000a,0xf1b9001e,0x333a0009,0x24920073}},	//   _كما_, tošu_, _התעמ, šyme_
  { {0x62080003,0xda080012,0x515a0009,0x33d60024}},	//   _بْنِ_, _بينه_, _הכנו, півт
  { {0xdb1a000f,0x33d5002d,0x660d0051,0x7a13004b}},	//   _hatá, міст, _emak, rătu
  { {0x7bc500b6,0x9f7a0009,0x0f7a0009,0x877a0009}},	//   _dahu, _הנצח, _הרצל, _האצי
  { {0x8066002d,0xc332000b,0x786600ac,0xfc3f01e3}},	//   зваж, גול_, зказ, rtía_
  { {0x765c00b6,0x859b000b,0x60d5000b,0xfc3f0164}},	// [6560] _sury, _השפו, הוּא_, stía_
  { {0xa856000b,0x683400c1,0x660d0034,0xd9b80011}},	//   פיעה_, tàdi, _zmak, _आस्ट
  { {0x4444001c,0x2ec60003,0x59bd0011,0xd5af0024}},	//   _ih_, ثقاف, ्यार, нс_
  { {0x72db000b,0xdca60001,0x2d82013a,0xe1f20012}},	//   _הקטג, зади, nake_, _أسد_
  { {0x63b80026,0xdb15000e,0x44441162,0x7bc5013d}},	//   tevn, vezé, _kh_, _yahu
  { {0x69c60006,0x0fda000a,0x61f6006f,0x62980010}},	//   _hake, _ابحث_, lkyl, tuvo
  { {0x80c40037,0x75280002,0xdb15000e,0x2ca61a0e}},	//   रिके, ędzy, tezé, stod_
  { {0x05660014,0xdb1e0004,0x69c60577,0xf9920012}},	//   _хван, _napí, _jake, ربع_
  { {0x2d820051,0xbcfb000e,0x6b560003,0x69c6254b}},	//   dake_, gcél, _فضائ, _make
  { {0x6d400333,0xe9df001a,0xdb030042,0x3cf20011}},	//   _izma, _khúc_, lený, ुनने_
  { {0x7bc50005,0xa91d0027,0x2249003a,0xda660012}},	//   _rahu, važe, ymak_, _راضي
  { {0xaac201e1,0xaadb000b,0x38a60029,0xdb030029}},	//   _वैयक, _לחבר, kôr_, nený
  { {0xc5f3000b,0xdb1c0028,0xa91d0066,0xdb0e00b0}},	//   גדר_, ndræ, taže, nebæ
  { {0xf1da0037,0x99800010,0x60bb0009,0x3e610097}},	//   भावन, klių_, _לצדד, _fót_
  { {0x224900a2,0x2d820033,0x883b000b,0xe2f90024}},	//   tmak_, bake_, _התגו, цеві_
  { {0x31c4002d,0xa91d0066,0x21f80066,0x7bc7006f}},	//   нсув, saže, _mého_, sdju
  { {0x7bc500ec,0x224900a2,0xbd450003,0xdb0301bd}},	// [6570] _tahu, rmak_, _تنظي, dený
  { {0xd6db03e1,0x2bde0011,0xd8740012,0x98480048}},	//   йте_, माणा, عاقب, пяха_
  { {0x224900a2,0xe9df001a,0xb05b031d,0xe7ae0011}},	//   pmak_, _chúc_, _präs, ज्यप
  { {0xe9df0020,0x3f810107,0x36180024,0x2bcb0011}},	//   _giúp_, sahu_, пцію_, ायवा
  { {0x8cd00037,0x99800010,0x8d280024,0xb4640024}},	//   दियो, alių_, поїв_, екіл
  { {0x69c60070,0xc952000b,0xd0f60009,0x3e4d0030}},	//   _zake, _שמך_, _חמשת_, _věty_
  { {0xea000020,0xddcd0002,0xa2bd0037,0xaa490109}},	//   _hoạt_, _miał, _वैश्, опка_
  { {0xe5730003,0x3f9e001e,0xdb03254c,0x7c2e254d}},	//   _سطر_, egtu_, menü, zobr
  { {0x3a2d00bd,0xdb03000e,0x60c2000e,0xdddc02a1}},	//   roep_, lenü, _csom, _uvrš
  { {0x62870119,0xdb1e0017,0xf1b9254e,0xb1160012}},	//   ksjo, _japã, tošs_, بقًا_
  { {0x3d110044,0x4ac10037,0x9f5e004a,0xea00001a}},	//   _देते_, _शनिव, yntö_, _loạt_
  { {0x6b83254f,0xcb120009,0xa3a90011,0x44442550}},	//   lang, _בלב_, ग्र_, _sh_
  { {0xddcd0002,0x69c61571,0x69d9031f,0xfc3f11f8}},	//   _biał, _rake, _inwe, rtín_
  { {0x2d822551,0xddcd0002,0x41bd0037,0xdb030042}},	//   sake_, _ciał, ्यवस, zený
  { {0x2d82009b,0x82a3002d,0x69c62552,0x24890060}},	//   pake_, карж, _pake, _evam_
  { {0xc8c90011,0x24440248,0x645701a0,0x6ec40012}},	//   रिंट, döme_, _eixi, _أتوق
  { {0x44440036,0x2fc71dcc,0x69c60070,0x6b83003b}},	// [6580] _th_, _kang_, _vake, kang
  { {0xe9df001a,0xdce4001e,0x35c60037,0x26d10a48}},	//   _phúc_, _ediģ, _रोज़, _brzo_
  { {0x78a90133,0xdb030e1c,0x68110066,0x69d90070}},	//   htev, genü, mědě, _onwe
  { {0x61eb00c5,0xb05b004a,0xdd8f0003,0x2fc72553}},	//   _nogl, _isän, لوم_, _lang_
  { {0x2d800005,0x91bb000b,0xdb030857,0xdb0901e9}},	//   _meie_, _ומכי, rený, čnýc
  { {0x2fc70733,0x69d9008b,0xe9df0020,0x690b000b}},	//   _nang_, _anwe, _thúc_, _וּלְ
  { {0x99890026,0x629c0010,0xa5760003,0x61eb0058}},	//   slať_, nuro, _يُست, _bogl
  { {0x63a90027,0xdb18000e,0xa3b00011,0x61eb00b8}},	//   đeni, nevé, _टॉस_, _cogl
  { {0x63bc0f33,0x80c40037,0x6d401ee9,0xdb1a0017}},	//   kern, रिटे, _uzma, _antô
  { {0xddc9001e,0xdb180025,0x6b832554,0xd7f70842}},	//   _cieņ, hevé, cang, дую_
  { {0xa3bd0037,0xdb0e006f,0x2f97000b,0x61eb0d20}},	//   ेयर_, nebä, וכין_, _fogl
  { {0x99890002,0xb4950001,0x72160012,0x64570025}},	//   ział_, нимљ, _غذائ, _sixi
  { {0xe9f7007c,0x2bbb0003,0xa3cb0037,0x9fe60003}},	//   _інші_, ياسة_, रएल_, _يسته
  { {0x63bc00c5,0xa08b000b,0x62950002,0x2fc713eb}},	//   gern, _וְהִ, trzo, _gang_
  { {0x64540001,0x54540001,0xa5f90001,0x53340dc2}},	//   тврђ, тврт, _неку_, верт
  { {0x62870119,0xf1bf000e,0x5e270003,0x20140002}},	//   rsjo, _akár_, _تعتق, ścić_
  { {0x2fc72555,0x90990098,0x6b8300c6,0x40590003}},	// [6590] _yang_, яват_, yang, سلاح_
  { {0x6602004a,0x1ddd0037,0x7bc80002,0x62870033}},	//   ehok, यावत, _nadu, psjo
  { {0x201e0006,0xa3e20037,0x040e001a,0x238a0029}},	//   inti_, धान_, hườn, šujú_
  { {0x7bda044f,0x99890002,0x60000052,0x24440032}},	//   _antu, siał_, _röme, röme_
  { {0x6b830f37,0xeb8e0ef0,0xee380024,0xc9760009}},	//   tang, ли_, єні_, _רגשי_
  { {0xa87a000b,0x9f65004a,0x28d20011,0x3cf20011}},	//   _מאשר, ätät_, तिनि, ुनते_
  { {0x6b7c0093,0xa3b80003,0x7bc80052,0x4255022a}},	//   חרונ, ظاهر_, _dadu, нтит
  { {0x44310272,0xdb1c0149,0x78a92556,0xaa560001}},	//   hoz_, ferê, ttev, нију_
  { {0x2fc70101,0xf8c80020,0xddc90039,0xfa0d0020}},	//   _pang_, _cứ_, _pieņ, _đấu_
  { {0xf7710003,0x6000000e,0x511a0009,0xd709003c}},	//   داة_, _töme, לֵינ, зное_
  { {0x68110066,0xc9590012,0x61eb00b8,0xdb030034}},	//   vědě, _فلاش_, _togl, renó
  { {0x91fc001e,0x7bc81ade,0x69d91ba1,0xdb1e009e}},	//   _stāv, _zadu, _unwe, _napá
  { {0x51840024,0xfc3f0030,0x30a7004c,0xdb0e1fb2}},	//   _руха, atím_, _црев, ndbö
  { {0x2fc700c6,0x224d1e68,0x3ced0051,0x1d16000b}},	//   _uang_, lmek_, äeva_, תקשר_
  { {0x2d8003fb,0xed59001e,0x04430014,0x8c1a0009}},	//   _teie_, _daži_, уерн, לושי
  { {0x3f8500c6,0x224d00a2,0xe1f90010,0xb05b0810}},	//   lalu_, nmek_, nkų_, _präp
  { {0x361b000b,0xa3cb0037,0x87ba0015,0x63ad0027}},	// [65a0] _מוקד, _रोक_, зует_, đanj
  { {0xfd470015,0xb05b004a,0x4aaa0024,0x3f852557}},	//   _язык_, _isäl, _екон_, nalu_
  { {0x869a0014,0x539b0009,0xfe720012,0x6b7b0009}},	//   ятат_, _ציטו, ادئ_, _מרינ
  { {0xf5390026,0x9cca0015,0x9756000b,0x14ca0015}},	//   _byť_, зыка_, גיעו_, зыки_
  { {0x201e004a,0x6b812558,0xdce00035,0x7bc82559}},	//   ynti_, _belg, _iemī, _padu
  { {0xc049001a,0xdce60010,0x225901bd,0x98160012}},	//   _vườn_, sakė, _zisk_, _أبحا
  { {0x59d10037,0xd9bd0037,0xf8c8001a,0x85b6004c}},	//   _दोहर, ्यूट, _sứ_, _пљач
  { {0x49ba0003,0x7bc800b6,0xcb130009,0xa2b70009}},	//   ساعد_, _wadu, טלו_, תפקד_
  { {0xdfd00351,0xc8c90037,0x0c3a0003,0xcfa60014}},	//   لية_, रिएट, _فكرة_, ншни
  { {0x7bda00ec,0x040e001a,0xdb0a0262,0xf0930009}},	//   _untu, rườn, kefø, ננת_
  { {0xa7de0029,0x3817000b,0xf76f0003,0xa91d017b}},	//   _kľúč_, תקים_, حاً_, raža
  { {0x63a5008b,0x644e00b6,0xceb30009,0x8afb0009}},	//   _schn, embi, ניר_, _מהבי
  { {0x3f85001e,0x645a1c46,0x2259255a,0x63a50034}},	//   balu_, _kiti, _risk_, _pchn
  { {0x6d44003e,0x97c60003,0xca770012,0x62980b41}},	//   _dzia, _ستتم, فارغ, orvo
  { {0x03d7000b,0x600b0009,0xf6d30012,0xed59001b}},	//   עולם_, _צִדְ, _مزيد, _važi_
  { {0x9adb0009,0x644e255b,0x4f3b0009,0x7f3b0009}},	//   החלט, ambi, _מתוע, _מעוו
  { {0xb9550014,0x64a40001,0x7e0c0009,0xab870ed4}},	// [65b0] тващ, _бања, _מִזֶ, _пунк
  { {0x7fb90003,0x6e3d0b5a,0x224d0060,0x88bb0009}},	//   ظهار_, llsb, zmek_, הזמי
  { {0x6288000e,0x22590121,0x9f5e01e3,0xfbdf0081}},	//   ádot, _tisk_, litó_, _đê_
  { {0x7afa255c,0x6b81255d,0x2eee006f,0x2a760009}},	//   øtte, _selg, äffa_, _שערך_
  { {0xed4e007c,0x645a003a,0x69dd1580,0xb5c80012}},	//   ро_, _biti, _inse, عوهم_
  { {0xdb1c03eb,0x629a000e,0x74150003,0xd1160009}},	//   ferè, átog, ضوعا, _יקרה_
  { {0x6b810119,0xe9d1000a,0x224d003a,0x63a30028}},	//   _velg, لغة_, tmek_, _önnu
  { {0xe4e7002d,0x9f34002d,0xe1f90010,0x9adc0009}},	//   _пізн, _сесі, ukų_, לחוט
  { {0x224d00a2,0x8f990014,0x6298004a,0x6c55077e}},	//   rmek_, мънт_, arvo, _акау
  { {0x29030010,0x78ad23b9,0x1c570012,0x399a0060}},	//   ąja_, itav, _أخرج, tüsü_
  { {0x248d0989,0x78ad01a3,0x94040012,0xa3e60011}},	//   _hvem_, htav, _حوله, _बचत_
  { {0xc1150001,0x645a0052,0xc3320009,0x3f85005e}},	//   _имеј, _ziti, _דוב_, salu_
  { {0x64480006,0x91f60009,0x645a0060,0xf1b20009}},	//   _yhdi, _שמנו_, _yiti, _כסא_
  { {0xccf2000b,0xd3720003,0x39440024,0x96f90012}},	//   סכם_, شهر_, _сніг, _يعثر_
  { {0x644e0722,0x03670365,0x3e860030,0x83a80009}},	//   rmbi, тиск_, _vítá_, עֱשֶ
  { {0x61e9255e,0x3eaa0145,0x248d0159,0x7f3a0009}},	//   njel, žití_, _ovem_, _קעקו
  { {0xed590027,0xaffa0003,0x59a60011,0x200500d9}},	// [65c0] _kažu_, وفرا_, क्टर, ohli_
  { {0x61e9226b,0x62880066,0x69dd255f,0xbddb01a0}},	//   hjel, ádos, _ense, smèt
  { {0x68f6004a,0x248d000d,0x0d862560,0x61e92561}},	//   syyd, _avem_, влен, kjel
  { {0x645a02d1,0xa2d50044,0x35aa0037,0xceb2000b}},	//   _siti, भिन्, _काफ़, שיא_
  { {0x61e9001c,0x38ab0033,0xdca3004d,0x6da30103}},	//   djel, jør_, иаци, рича
  { {0x61e9000f,0x24920010,0xdb1c0054,0x8433002d}},	//   ejel, šymo_, terè, аніє
  { {0xdee32562,0x394013be,0x7ac60015,0x66e3013b}},	//   _кори, _šis_, тсле, _кора
  { {0x61e90272,0xddc90002,0x38ab0623,0x52730012}},	//   gjel, _mieś, før_, جاوز
  { {0x61eb0052,0x38ab0058,0x91fc001e,0x13b60012}},	//   ögli, gør_, _stās, _لصاح
  { {0xa7740015,0xc949000b,0xdb180fe1,0x69cb060d}},	//   ылоч, עֲקֹ, leví, _eage
  { {0xed59001e,0xf1bf0029,0xe7e30037,0x9f9b0009}},	//   _dažu_, áške_, _कचरा_, וסיפ
  { {0x1af7000b,0xa3cb0011,0xc0d60012,0x13170009}},	//   _שמאל_, _रोज_, _ليصب, _בחבל_
  { {0xa3e60037,0x98a30472,0x69c02563,0xe89401c6}},	//   _बचा_, _виче, meme, _саль
  { {0x3ed40003,0x69c02564,0x84340024,0x54450012}},	//   _مقتر, leme, иняє, انسك
  { {0xe8e00020,0xdeef0015,0xdb180017,0x9f5e01e3}},	//   _đội_, _ты_, levâ, sitó_
  { {0x78ad2565,0x0f57000b,0x8f45002d,0xd9e50037}},	//   ttav, _ביום_, _схід, कायत_
  { {0x57b50014,0x25d80009,0x6d480034,0x69dd0032}},	// [65d0] лбат, _יוהן_, ędac, _vnse
  { {0x673c0065,0x7538000b,0x26120029,0xa4b60009}},	//   _byrj, _באחד_, yšok_, _עלתה_
  { {0xa3d60037,0x69c02566,0xf1ab0011,0xf7700012}},	//   ियन_, keme, _छापन, تاق_
  { {0x78ad0065,0xa3b00044,0x69dd0d26,0xceb3000b}},	//   ptav, ट्स_, _unse, ייע_
  { {0xe9df0029,0x61e90027,0xa91d0042,0x1d340024}},	//   _inú_, vjel, važo, анця
  { {0xb4fc0009,0x80d60011,0xe3b10012,0x69cb2567}},	//   ופדי, बिने, صرت_, _sage
  { {0xfbb80093,0xa91d007a,0x3f830028,0x69cb2568}},	//   דפות_, tažo, ðjum_, _page
  { {0x38ab0262,0xb05b0248,0x683d01a0,0xc6920009}},	//   tør_, _osäk, mèdi, _לאל_
  { {0x61e92569,0xdd03001e,0x28c90037,0x7a0c000d}},	//   rjel, ārēj, रिटि, oştr
  { {0x24890039,0xfbc00011,0x95fe0011,0x2d84256a}},	//   šams_, _एसएम, ॉफ्ट_, _zeme_
  { {0x61e90027,0x7c350b28,0x24800132,0xe61a0306}},	//   pjel, dozr, _swim_, едн_
  { {0xf3f10020,0xfbc9000b,0x7ae50051,0x69c0256b}},	//   _họ_, _מת_, ähtu, ceme
  { {0x3e680061,0xed5700b3,0xf1f80012,0xb9080012}},	//   _eût_, лою_, _جعلت_, _لزوم_
  { {0x40920003,0x3e680061,0xb8920012,0xf0920009}},	//   _الور, _fût_, _الوع, _פנו_
  { {0x3ea10051,0x4e950003,0xab2700f5,0x75d60012}},	//   juht_, _إشتر, гора_, _ميغا
  { {0x316d0830,0xbbc00011,0x44230159,0x8a430012}},	//   ncez_, _एस्क, anj_, مَّن
  { {0x998d0002,0x48e30014,0xa3d60037,0xc0e302ad}},	// [65e0] mień_, ботв, ियम_, ботк
  { {0xdee605fb,0x7f860012,0x66e60adc,0x7bde0132}},	//   лози, الان, лоза, _unpu
  { {0x69c0256c,0xdb180030,0xa5bb01e3,0x683d01a0}},	//   yeme, teví, inón, gèdi
  { {0x94aa09f0,0x69c00054,0xc1760003,0xf769000b}},	//   етка_, xeme, _حددت, לק_
  { {0x22400f5f,0x69c0256d,0xdb1c0040,0x443a016d}},	//   mlik_, veme, edrø, _kkp_
  { {0xbc670003,0x22400100,0x3e860012,0xc27a0009}},	//   دمون_, llik_, _مشرف, ֲרִי
  { {0x6604256e,0xc0030001,0xd25a0294,0xd3790024}},	//   _olik, _упрк, нци_, тчі_
  { {0x22401d4a,0x6ca60003,0x66190002,0x98a70002}},	//   nlik_, _مصطل, ciwk, łną_
  { {0x4a5b000b,0x2df7000b,0x69c0256f,0xbfaa0177}},	//   עדפו, _עצמך_, reme, нтне_
  { {0x201a002c,0xd8b70012,0x3e680025,0x645e0349}},	//   nipi_, اديا_, _pût_, _nipi
  { {0x10370093,0xf1bf0029,0xf837000b,0xa01b0028}},	//   רטים_, ššie_, רנית_, _kvör
  { {0x0f57000b,0xa3b00037,0x21670001,0x56930021}},	//   טיים_, ट्र_, _бици_, щают
  { {0x22400051,0xec150012,0x74150012,0xdb1801a0}},	//   dlik_, لوحد, لوحا, levà
  { {0x36d40015,0x22400c40,0x60000248,0xee3f0ca4}},	//   _вокр, elik_, _sömn, slý_
  { {0x6604006f,0x57fb000b,0x645e2570,0xfc3f081b}},	//   _flik, _אלגו, _dipi, ktív_
  { {0xdb0a2571,0xb9250003,0x44f50264,0x6f4b0009}},	//   lefó, لفزي, _впис, _אֲחַ
  { {0xa3b00037,0xf3f1001a,0xcf9b0001,0xb8150001}},	// [65f0] _टॉक_, ự_, еје_, адај
  { {0x629a0029,0x2ba40037,0x7b15003c,0x64460073}},	//   átoc, _ऑफ़ला, _вдох, _ūkin
  { {0xf770000a,0xdb0a0052,0xdd910003,0x22402572}},	//   سال_, gefü, قوا_, blik_
  { {0x79860070,0x683d0054,0x3ea10052,0x248d1a83}},	//   _gekw, rèdi, ruht_, šemu_
  { {0x26d80149,0xa2bd0037,0xb5c2002d,0xa3c90011}},	//   _erro_, _वैज्, ійшл, _ईसा_
  { {0x69cf02d1,0x683d03eb,0xb09a000b,0x9aa50003}},	//   _hace, pèdi, _בישר, لمتو
  { {0x2d8b0013,0x6d9c0029,0x2bf8000b,0x38af003a}},	//   kace_, _sťaž, רמון_, lür_
  { {0x48b50014,0xc2450001,0xe9d90fbb,0x61ed2573}},	//   ащот, јник, тки_, njal
  { {0x38af003a,0x22560012,0x25f40011,0xdb030025}},	//   nür_, جليد_, ूसरी_, igné
  { {0x998d0002,0x61ed0269,0x66042574,0xa3d40011}},	//   wień_, hjal, _slik, _सों_
  { {0x6604003e,0xa3e20037,0xcb350048,0x645e00b8}},	//   _plik, धार_, _тежъ, _ripi
  { {0x2d8b0066,0x2480000d,0x645e02a0,0x7bc32575}},	//   gace_, ţime_, _sipi, lenu
  { {0xef180039,0x8c460014,0x645e2576,0x9f4a0029}},	//   daļu_, иеме, _pipi, _robí_
  { {0x46f5002d,0x7bc30051,0xdb18000e,0x38af003a}},	//   _вчит, nenu, levá, dür_
  { {0xdb0a0054,0x998d0002,0x78bd09d4,0xa3d60011}},	//   lefò, pień_, _apsv, ियत_
  { {0x66040033,0x38af0052,0x61ed0028,0x20b30011}},	//   _ulik, für_, gjal, ुबंध
  { {0x77860001,0x7bc3004a,0x22402577,0xc956003c}},	// [6600] илаз, kenu, rlik_, ртвы
  { {0x6aa30052,0xa01b0028,0xdfcf0003,0xdb1c1aa3}},	//   kunf, _svör, ويق_, lerí
  { {0xa3e90044,0x05661932,0x69cf2578,0x63a10002}},	//   यान_, авен, _face, ólne
  { {0x61ed003e,0xe61a0014,0x7bc30051,0x44382579}},	//   cjal, ъде_, eenu, lor_
  { {0x443800bd,0x8cd90037,0x397b000b,0xe5890009}},	//   oor_, मियो, _בטכנ, רָעָ
  { {0x2d8b0013,0x9cd7000b,0x2c6b0262,0xab770012}},	//   zace_, יונה_, _død_, لمها_
  { {0x03a30001,0x3f98257a,0x2ef80009,0x4420001b}},	//   цијо, órum_, _גִּב, đi_
  { {0xe5a30103,0x929b0009,0xdb1c01e3,0x28d20011}},	//   _миси, דיקת, jerí, तिलि
  { {0x2d8b0066,0x4438257b,0xed5700de,0x5d9b0009}},	//   vace_, kor_, _вот_, _שבמה
  { {0x6abe0119,0xf8b3000b,0xdefa0015,0x4438257c}},	//   _oppf, קשת_, вым_, jor_
  { {0x2d8b0066,0x9f340024,0xb05b0032,0x38af0060}},	//   tace_, сені, _präz, zür_
  { {0xfe780010,0x7a8b0009,0x8afb0009,0x7af70248}},	//   rpį_, _יָדַ, _שהאי, äxte
  { {0x61e201a2,0x2d8b257d,0x61430014,0xf657000b}},	//   _inol, race_, _деца, יסטי_
  { {0x3cee0044,0x7e60257e,0x4438257f,0xa3e90011}},	//   _आपने_, _limp, gor_, याय_
  { {0x6e94000a,0xd838012e,0xe694000a,0x5e940003}},	//   _البا, moč_, _البد, _البط
  { {0x1f5b000b,0xd7a60037,0x38af030f,0xaf5b0009}},	//   _בדוא, _खाँच, tür_, _בכוכ
  { {0xa3d60044,0x2f8b0001,0xa3e90037,0x478b004d}},	// [6610] िया_, вљен_, याम_, всем_
  { {0x38af003a,0x2c6b0262,0xe53c0009,0x6d3c0009}},	//   rür_, _rød_, _בתחר, _בתחנ
  { {0xe8e0001a,0x61ed0028,0xe7190003,0x61e20027}},	//   _đời_, pjal, ديات_, _onol
  { {0xd6d8111e,0xdb360009,0xb7c60035,0x20180060}},	//   шту_, _לנתח_, _apģē, _emri_
  { {0x3d110037,0xf1b90027,0xe4c80012,0x661d005e}},	//   _देखे_, niše_, لبون_, iisk
  { {0x00f6000b,0x66fc001e,0xd838009b,0xa1560009}},	//   _המשך_, _sākš, joč_, _לברה_
  { {0x7d060051,0xa91d0010,0x7642003a,0xe7300012}},	//   _üksn, maži, bloy, _قصف_
  { {0x1dcf0037,0x163401d4,0xa3d90011,0xc2120009}},	//   _सोचत, _деся, _ठोस_, ּ֔ה_
  { {0x44382580,0x03c70015,0x7bc32581,0x6aa30032}},	//   yor_, _всем, penu, sunf
  { {0x63ad0027,0x6006003c,0x389a0009,0x61e22582}},	//   đans, йным_, ניתנ, _enol
  { {0x3f870061,0x661d2583,0xdb1c02ea,0xc4c90009}},	//   _venu_, fisk, terí, _רג_
  { {0x64430163,0x2d9e0052,0x99d40012,0x26120064}},	//   llni, ßte_, _وتنا, yšou_
  { {0xa3ae0044,0x4dda000b,0x3f870061,0xa91d00eb}},	//   _काम_, אחרו, _tenu_, kaži
  { {0x2d9e23b0,0x96f90012,0x7f850012,0xf7850012}},	//   şte_, _معبر_, _الثن, _الثَ
  { {0x44272584,0x69c40052,0xdb1c0017,0x98140012}},	//   inn_, teie, derã, _ببنا
  { {0xc3320093,0x63bb0027,0x7cde000d,0x661d037f}},	//   פון_, đuna, _hărţ, cisk
  { {0x986a0003,0xc044001a,0x44382585,0xe0da003c}},	// [6620] احرف_, _đoạt_, por_, ыва_
  { {0x25ad000d,0x7e69009b,0x60000248,0x69c406fc}},	//   _acel_, _čepr, _tömm, seie
  { {0x3ea50005,0x6abe0395,0x7e6000b6,0x2bf70009}},	//   nult_, _uppf, _pimp, _המין_
  { {0x44270052,0x644312c9,0x26120064,0x78a4008e}},	//   enn_, elni, pšou_, puiv
  { {0x78a40149,0x7c380027,0xc1730009,0xe4d30012}},	//   quiv, tovr, _מחר_, كتوب
  { {0x3ea50005,0x6aa10065,0x6d40022d,0xcce50003}},	//   kult_, álfg, _vyma, تسمي
  { {0x6d40003e,0x7e60007d,0xae780009,0x501b0009}},	//   _wyma, _timp, _כְּת, _עולו
  { {0x52d7000b,0x9a670003,0x90980015,0xb5fd02a1}},	//   מוצע_, حميل_, авит_, _piše
  { {0x6d40003a,0xd838001b,0xc05a0024,0xdb1c0034}},	//   _uyma, toč_, ліо_, odró
  { {0x7cde007d,0x661d0002,0xf1b90027,0xb5fd0027}},	//   _cărţ, wisk, više_, _više
  { {0x442700a2,0x28cf0044,0xb05b004a,0xdc190002}},	//   _ın_, _सैनि, _isät, _głęb
  { {0xd838009b,0x6f090066,0x25ad0060,0xb6620024}},	//   soč_, _řeck, üel_, омiк
  { {0xd7940048,0xe4c7003c,0x80e50012,0x3f8c18f9}},	//   _дилъ, щённ, _وأهل, padu_
  { {0x661d2586,0x19570009,0x70540012,0xa5bb0034}},	//   sisk, _הבדל_, _بنتا, wiód
  { {0xa3e90037,0x3ea5002a,0xdb1a0052,0x62550010}},	//   यात_, cult_, _natü, _išor
  { {0xddc40002,0xf1b904d2,0x26df001b,0xdb1a0031}},	//   _chiń, piše_, _čuo_, _ható
  { {0xf5b40003,0x86080003,0xe66f0028,0x481900fa}},	// [6630] _رصيد, _دقيق_, ðaþý, ажаю_
  { {0x5f78000b,0x201e2587,0x31180012,0xf7700012}},	//   שָּׂ, niti_, حتفظ_, ّان_
  { {0xd6db0015,0x8d790003,0xb87b1209,0xa91d2588}},	//   ыта_, لماء_, _oríg, raži
  { {0x8d870015,0xa01b0052,0x7cd90530,0xf0750012}},	//   сужд, _zwöl, имер_, _وُجد
  { {0xa91d0010,0x7ae0001e,0x2bb90003,0xda780029}},	//   paži, āmte, لاثة_, _atď_
  { {0xdb18004a,0xc7c70014,0x3a29000e,0xad1c0009}},	//   kevä, _усми, lnap_, נוגר
  { {0xfbd00003,0x39e9002d,0xdb070051,0x201e2587}},	//   عته_, идко_, pejõ, diti_
  { {0x201e006b,0x1dd90011,0xdb1c025b,0x40950479}},	//   eiti_, _बोलत, nerá, орот
  { {0x26dc004a,0x7cde000d,0x09f60003,0x64430042}},	//   _arvo_, _părţ, تفية_, plni
  { {0x3ea50005,0x66090065,0x3943001e,0xdb1a052e}},	//   tult_, _hlek, ājs_, _cató
  { {0xa3d60011,0x93940012,0xfc300012,0x3a290040}},	//   ियर_, _رجلا, _أحق_, knap_
  { {0x3616007c,0xdb1c0032,0xb87b0064,0x26dc001b}},	//   ієнт, rdrü, _kríd, _drvo_
  { {0xdb1c2589,0x89370003,0x201e258a,0x3ea5258b}},	//   sdrü, _اعضا, biti_, sult_
  { {0xbddb0061,0x201e1192,0x8c560012,0xa1560009}},	//   llèl, citi_, تئجا, _ובנה_
  { {0x66090005,0xe363007c,0x8c430a76,0x60080009}},	//   _olek, дкри, фере, _לִקְ
  { {0xf2d2000b,0x21670129,0xceb20009,0xaa030012}},	//   ועל_, жити_, _חיה_, وِّي
  { {0x2bb20037,0xdb1a0060,0x2d8f258c,0xeb9a258d}},	// [6640] _जापा, _satü, dage_, _кип_
  { {0xdfa60003,0xa5bb000e,0xba760012,0x39420073}},	//   تحري, ciób, _واجت, _vyks_
  { {0x6602004a,0x06ca004d,0x8f9a0009,0xfc3f01e3}},	//   tkok, ргей_, שיעי, quía_
  { {0xdb1c0164,0x3f8a014a,0x201e013a,0xee3a05c6}},	//   cerá, _webu_, ziti_, шне_
  { {0x76460028,0xa3d60011,0xf9830024,0x61e61736}},	//   ilky, ियल_, _ігро, _inkl
  { {0x38b40c60,0xe7ae0011,0x8bc30048,0x2be30011}},	//   mär_, ज्ञप, дсъд, खाएं_
  { {0x3d1a0044,0xe8e00020,0xdb1a0164,0x78b6004a}},	//   _मेरे_, _đối_, _rató, ltyv
  { {0x7e640051,0x11ea0012,0x527b0009,0xddc309e8}},	//   _niip, شعبي_, בנקא, _обси
  { {0x7c3c0cf4,0x201e0416,0x29000054,0x1d070015}},	//   korr, titi_, nyia_, _дети_
  { {0x6e2d0070,0xdb1c00f1,0xdfd00003,0x26dc013a}},	//   _sjab, zerá, ريج_, _prvo_
  { {0xf773000b,0x998d0002,0x201e258e,0x2c6f016a}},	//   וקת_, nieś_, riti_, _süd_
  { {0x78b6007a,0xae160037,0x91da0011,0xe4e70024}},	//   ktyv, दोलन_, _पोलै, оігн
  { {0x3cf70037,0xba170012,0x98b30035,0x61f30064}},	//   ुनें_, _بينا_, ādīs_, želá
  { {0x466a002d,0xc0460003,0x998d0002,0x443c258f}},	//   _крим_, _بخصو, kieś_, nov_
  { {0x7bd50029,0x298b0001,0x2d8f0ebe,0x8a780009}},	//   rdzu, исао_, yage_, מָּק
  { {0x96180003,0x38b4006f,0xf3640842,0xee770012}},	//   _وغير_, fär_, ьтян, _بصوت_
  { {0x7c3c03eb,0x27f8002a,0x443c2590,0xa3bc0037}},	// [6650] borr, _born_, kov_, ेजा_
  { {0x443c0026,0x69d6002c,0xa91d01e9,0xd6db19cd}},	//   jov_, adye, mažt, ите_
  { {0xa3ae0037,0xa3e90037,0x3c3b0066,0x443c0a3d}},	//   कलन_, यास_, rávě_, dov_
  { {0x6295000f,0xbb3a000b,0x24890070,0x38b4006f}},	//   mszo, _לעתי, _kwam_, bär_
  { {0xd1260003,0xfe38000b,0x6295000e,0x11450003}},	//   _أم_, חראי_, lszo, _رَسُ
  { {0x60fa000b,0x97c70003,0x99840010,0x6447017b}},	//   _ההשק, _بتحم, komų_, nlji
  { {0xa3bc0037,0x27e90081,0xe62b004c,0xad9b0097}},	//   ेज़_, _đan_, _кôд_, nhús
  { {0x60000052,0x6295000e,0xddc4004b,0x7ae1008e}},	//   _römi, iszo, _munţ, älty
  { {0x7e64004a,0xd24e0003,0x443c18b7,0x64470159}},	//   _riip, دني_, bov_, klji
  { {0x443c11ad,0xf8b20009,0xaae70012,0x62950540}},	//   cov_, עשי_, _وساو, kszo
  { {0xb8f223b5,0x26150026,0x644700eb,0xa91d0042}},	//   _है_, sťou_, dlji, važu
  { {0xbddb0108,0xb2ba000b,0x78b6004a,0x0dba0003}},	//   blèm, _למער, ytyv, حادث_
  { {0xeb040037,0x998d0034,0x76460097,0x62950efc}},	//   रन्त_, zieś_, rlky, eszo
  { {0x3cee0037,0xdd3a000b,0x387f00b6,0x644709d2}},	//   _आपसे_, מערכ, mpur_, glji
  { {0x63bc00a2,0x09e6007c,0x60c20066,0x824a0003}},	//   _örne, повн, _zpom, مشرف_
  { {0x78b60006,0x443c2591,0xdb12000e,0x249f001e}},	//   ttyv, zov_, égér, šuma_
  { {0x7c3c2592,0x64470604,0x64412593,0xf8bd0011}},	// [6660] porr, blji, _okli, ्बिय
  { {0xa3d40037,0xabaa0001,0x1cb70009,0x20050060}},	//   _सोच_, _увоз_, _צליל_, nkli_
  { {0xe9df001a,0x78b6004a,0x443c0aa3,0xabfb0009}},	//   _phút_, styv, vov_, _הפיז
  { {0xed5a0015,0x7d060051,0x7e9a0009,0x2bca0011}},	//   бое_, _üksk, מסעו, ाजवा
  { {0xd4e30015,0x443c2590,0x1bd40365,0x16a80011}},	//   еющи, tov_, доля, _कम्ब
  { {0x74140003,0x7469002d,0xddc90034,0xb5fd0412}},	//   بوتا, ірів_, _cheł, _viša
  { {0x05bb0044,0x443c2594,0xfbd30009,0xf1bf0097}},	//   ोजशब, rov_, גתו_, _sjái_
  { {0x443c2595,0xb5fd0159,0x7c660012,0x30a602ab}},	//   sov_, _hišn, _فاطل, пров
  { {0x443c025e,0xb8060012,0xa067004c,0xe1ef0012}},	//   pov_, كبده, пања_, اسى_
  { {0xdcef001e,0xdb1e0164,0xc9170009,0xe0180024}},	//   sacī, _japó, פחית_, іжні_
  { {0xa3e90044,0x64470416,0xbb4a0003,0x1b7b000b}},	//   यार_, vlji, _الان_, _הטבע
  { {0x6a16000a,0x4c950015,0x60cd0034,0x3f830097}},	//   _عبار, мимс, ywam, ðjur_
  { {0x63a10002,0x644700eb,0x23e70024,0xa9670012}},	//   ólno, tlji, півв, _عموم_
  { {0x515b000b,0x6295000e,0x909b0009,0x95f90011}},	//   _הכדו, tszo, _פסוק, _ऍक्ट_
  { {0xf7d70093,0xd7bb000b,0x67bb000b,0x78a421ba}},	//   _מוגש_, _הצור, _המוק, eriv
  { {0x6447009b,0x7afa006f,0x7ed30012,0x60cd0034}},	//   slji, ätta, _أزوا, twam
  { {0x6295000f,0x85b80003,0x859c000b,0x660d002c}},	// [6670] sszo, _رايس_, _השחו, _ilak
  { {0xf7700003,0x6d41003a,0xb87b0029,0x2be30037}},	//   هام_, ğlad, _príb, खाओं_
  { {0x59f90014,0x6d41003a,0xc5d5002d,0xdb1c0052}},	//   _деня_, şlad, діль, gerä
  { {0x60db007a,0xe0df001a,0x44232596,0x64412597}},	//   yvum, _trò_, lij_, _skli
  { {0x99f6000b,0xa3e90011,0x865c0009,0xdfdb0048}},	//   _חזרה_, याल_, צדדי, _лъв_
  { {0xb4ad0037,0x03a50001,0x4423037b,0xce6b011f}},	//   _कमी_, фико, nij_, _град_
  { {0x52b20003,0xa3ae0037,0x3946002c,0x6263000e}},	//   نموذ, _कार_, _ayos_, _főol
  { {0xdb1c0017,0x35d4003c,0x60db005e,0x88e50148}},	//   serç, _посё, tvum, джие
  { {0xceb80ff7,0xde580024,0x200e0073,0x23dd0011}},	//   etę_, _хаті_, škių_, मयाद
  { {0x20190003,0x99dd05b1,0x660d2598,0x14190012}},	//   تتبع_, plňo, _alak, _بيئة_
  { {0x60c4001e,0x660d1bf2,0x82870012,0xe5a607ae}},	//   _ģime, _blak, _رجال, мини
  { {0x200517a1,0x387f2599,0xbb3a0009,0x9f640030}},	//   skli_, ppur_, _ותעז, ítám_
  { {0x2101007a,0x6ff50003,0xcd960009,0x44230159}},	//   nčią_, _يستط, ודרת_, fij_
  { {0x4423009b,0xb05b006f,0x7c230675,0xdff50024}},	//   gij_, _spän, ninr, _іяль
  { {0xd7590003,0x3f85000d,0x660d032c,0xc0520009}},	//   _بلغت_, mblu_, _flak, _שזו_
  { {0xa3e90044,0x78a4007d,0xc332000b,0xa5bb01bd}},	//   याँ_, triv, דול_, lión
  { {0x3cf90044,0xc5eb0093,0xa3ae0037,0x7e7c259a}},	// [6680] ्नों_, _וַיֹ, _काल_, _strp
  { {0x4423012e,0x07a30047,0x7d060051,0x261a0011}},	//   cij_, каун, _üksi, मोरी_
  { {0x4444259b,0xb05b004a,0x2249000e,0x78a4004a}},	//   _ik_, _epäo, blak_, sriv
  { {0xe9d9003e,0xbef6000b,0x64a60048,0x68e90030}},	//   jdź_, וצעו_, дада, _šede
  { {0xa3e90037,0xcfaa0012,0x62a30035,0xd78a0012}},	//   यां_, _واسم_, īvoš, _ونحو_
  { {0xdb1c004a,0xe9d90034,0x98b10030,0x7c230097}},	//   perä, edź_, ůběh_, ginr
  { {0xb87b259c,0xa0670001,0x07a30001,0xeaaf0012}},	//   _tríc, _цара_, _јасн, لعي_
  { {0x4444259d,0x92570012,0x4423259e,0x471b0009}},	//   _lk_, وشير_, zij_, _וולג
  { {0xb5fd0604,0xfc2a0048,0x7bca0132,0x8cd50011}},	//   _mišl, _джак_, pefu, _मैपो
  { {0xf957000b,0xa5bb0029,0x34fb0009,0xa4fb0009}},	//   וספת_, gión, _והמד, _ולמט
  { {0xe8e0008a,0x660d259f,0xad9b0064,0xf76f0012}},	//   _đổi_, _plak, skúm, جاً_
  { {0x444404b4,0xfc3f02d1,0x2fd8000d,0xceb80d30}},	//   _ak_, dría_, _larg_, rtę_
  { {0x7afa0163,0xceb825a0,0x442325a1,0xf3f10081}},	//   ättn, stę_, tij_, _kịp_
  { {0x249f0010,0x68e2000e,0xce940014,0xa5bb1214}},	//   šumo_, _irod, _закъ, ción
  { {0x27ed001a,0xaa590001,0x44440ccd,0xdb1a0066}},	//   _đen_, зиву_, _dk_, _obtí
  { {0x35f80003,0x444425a2,0x4087004c,0x992b003c}},	//   _يريد_, _ek_, дужб, оюза_
  { {0xdb050052,0xa2d30011,0x2a640048,0x0855003c}},	// [6690] _schä, डिङ्, търг, еваю
  { {0xdd0d0002,0x644a0058,0xfc3f0164,0x2249003a}},	//   półr, jlfi, bría_, slak_
  { {0x23d90044,0xc72b0024,0x670e0011,0x7c230025}},	//   _योगद, ціал_, ानिक_, vinr
  { {0x68e2012e,0xdd9b002d,0x78a20145,0x1cb90003}},	//   _orod, іше_, šova, كاتب_
  { {0x629a012e,0xdb0905b1,0x4375002d,0x26dc0248}},	//   _avto, čníc, нуйт, åvor_
  { {0xe9d9003e,0xdb1c25a3,0xb464002d,0x60c0005e}},	//   wdź_, rdrö, вкіл, _ämma
  { {0x44290027,0x78ad004a,0xbb4205fb,0xaa45004c}},	//   đa_, luav, лешк, некл
  { {0x61fd0039,0x7c23006f,0xa4d50024,0x64460073}},	//   _josl, sinr, _побі, _ūkit
  { {0x8435002d,0xd2580009,0xa0c50012,0xe9d90034}},	//   _знає, ושהה_, ريدو, rdź_
  { {0x68e20002,0x69cd005e,0x0aeb0012,0x0ea9003c}},	//   _drod, heae, _وراي_, пкой_
  { {0xaab40003,0x9991000e,0x44440051,0xf626013b}},	//   _لإنش, őző_, _rk_, едно
  { {0x644500c6,0x61fd001e,0x6619003a,0x444425a4}},	//   _akhi, _nosl, _çakı, _sk_
  { {0x8fa508e5,0x68e225a5,0x444425a6,0xddce0073}},	//   _зале, _grod, _pk_, _subū
  { {0x6b95000e,0x78bb0028,0x7e6925a7,0xf8b20009}},	//   gazg, mtuv, _liep, _עשו_
  { {0xca560001,0x24560028,0x78bb0269,0xa5bb052e}},	//   етањ, væmd_, ltuv, gnós
  { {0x7e69003e,0x471a000b,0x2bb20037,0x171a000b}},	//   _niep, _מוצג, _जावा, _מוצע
  { {0x99800029,0x656d0064,0xb05b008e,0x10a305c8}},	// [66a0] jniť_, ľahl, _epäm, литн
  { {0x7d060006,0xe53b000b,0x444425a8,0x200e0097}},	//   myks, _מתפר, _uk_, ófi_
  { {0x39ea0098,0x93b7000b,0xa3e90037,0x61eb0061}},	//   _едно_, _אליו_, याई_, _ongl
  { {0xf1bf0026,0x69d90002,0xa06a0001,0xc27b000b}},	//   íšte_, _nawe, _нама_, _מרטי
  { {0x95970009,0x7e6925a9,0xa4d40024,0xc8b6003c}},	//   תכנו_, _diep, толі, _ясны
  { {0x6e2600bd,0x7bdc007a,0x99890002,0x229a001e}},	//   hikb, ndru, chał_, tīk_
  { {0x53340015,0x68e20027,0x7d06004a,0xdb070031}},	//   ъект, _srod, hyks, ogjá
  { {0xb6bb000b,0x20bd0037,0xdb1f0066,0x7bce0052}},	//   _מצלי, ्बंध, ávát, hebu
  { {0x39770003,0xf9930009,0x20070032,0xadb70012}},	//   رصيد_, ארח_, önig_, _سهلا_
  { {0x4c9b000b,0xdc9b000b,0x25a0013d,0x4ab20011}},	//   _משמע, _מסמכ, _adil_, ुझाव
  { {0xd36f0012,0x9f340024,0x68e20034,0x69db25aa}},	//   _اهم_, тені, _wrod, bdue
  { {0x3eac0040,0x12eb0009,0x78bb25ab,0x68e225ac}},	//   rudt_, _מַדּ, btuv, _trod
  { {0x68e20002,0xb05b0574,0x7bda139e,0xdb1c0064}},	//   _urod, _späm, _katu, zdrô
  { {0x7bce0052,0x672b000e,0x7bda00b6,0x7d060051}},	//   gebu, áljá, _jatu, _üksu
  { {0xc9870001,0x2365006f,0x99800029,0x7bda25ad}},	//   еузи, älj_, zniť_, _matu
  { {0x7bdc1046,0x7bce005e,0x7bda25ae,0x78ad0521}},	//   adru, aebu, _latu, tuav
  { {0x97a7002d,0x9c390014,0x7e6900c1,0x7bce0010}},	// [66b0] ерел, _опит_, _riep, bebu
  { {0xb4bf0011,0xbfd80024,0xc02e0081,0x60db001b}},	//   ीबी_, ндує_, _điệu_, _šums
  { {0x7e690039,0x8c1c000b,0x3f910027,0x2246000e}},	//   _piep, _מוזי, _vezu_, _okok_
  { {0x99800029,0x867b0009,0x4a9a0009,0x7c950012}},	//   tniť_, פרדו, _קירג, نشتا
  { {0xddc0000d,0x7bda1074,0xf53f0260,0x629a0042}},	//   _simţ, _batu, mgås_, átov
  { {0x99800029,0x80ca0011,0x99dd0030,0xfaa5033d}},	//   rniť_, _सैटे, plňk, вако
  { {0x93940012,0x52a90024,0x99800064,0x07090012}},	//   اجها, євим_, sniť_, _غيري_
  { {0x7bce0002,0x99800029,0x78bb019a,0x8d740012}},	//   zebu, pniť_, ttuv, _ماكا
  { {0x7bda25af,0x290b0029,0x682b0002,0x78bb0603}},	//   _fatu, áca_, ażde, utuv
  { {0xa2a90037,0x95540003,0x7d060010,0xd7090015}},	//   _टिप्, _إخفا, vyks, дное_
  { {0xdcfd001e,0x78bb00b9,0xf772000b,0x442725b0}},	//   kasē, stuv, יקי_, min_
  { {0x7d060006,0xdb24000e,0x442725b1,0x61eb25b2}},	//   tyks, árít, lin_, _ungl
  { {0x64430005,0xed57007c,0xb5fd0010,0x7d060051}},	//   ooni, кою_, _aišk, _ükst
  { {0x33d5002d,0x442725b3,0xd1160009,0x224d0368}},	//   ліст, nin_, _בקנה_, llek_
  { {0xae1f0037,0xd4670001,0xb5fd009b,0x7d06004a}},	//   मोहन_, тире_, _višj, syks
  { {0x442725b4,0x7bdc0052,0x7bce15b1,0x44310032}},	//   hin_, sdru, sebu, anz_
  { {0x41270098,0xc9660048,0x87ba003c,0xf9920009}},	// [66c0] вото_, твай, дует_, ירן_
  { {0xc0e30024,0x10050024,0x6b680031,0x79890032}},	//   шоук, ляєм, _cégü, hbew
  { {0x78a90070,0xd6cf0003,0x539b0009,0x79890227}},	//   hrev, يقك_, _קיטו, kbew
  { {0x442702dc,0x7bda25b5,0xd3370009,0xf53f04a7}},	//   ein_, _satu, _יריה_, mgår_
  { {0x10a3002d,0x7bda25b6,0x442725b7,0x1cb70012}},	//   _киян, _patu, fin_, ناوب_
  { {0x9d1b0093,0x2ac60001,0xe1f90010,0x76a60012}},	//   וונט, вљив, ejų_, _لحرك
  { {0x3cee015f,0x63a10002,0xd25a05fb,0xb4170012}},	//   _आपके_, ólni, мци_, ضغوط_
  { {0x58d8022a,0xc4c60012,0x75d60012,0xe9e30024}},	//   едия_, _لتطو, _جيرا, ацьо
  { {0xdfd0000a,0x3d0c0037,0xe3ba011d,0x5cc50012}},	//   مية_, हनों_, _оба_, _مغلق
  { {0xad1b000b,0xa5bb000e,0xbddb0025,0x6e240031}},	//   _חומר, ciój, hlèt, _amib
  { {0x64480039,0x645a00a2,0xa3c80037,0x65950560}},	//   _ikdi, _ihti, ोजन_, лану
  { {0xceb3000b,0xf53f0058,0x569300b3,0x6e9b0009}},	//   סיר_, dgår_, шают, ובטח
  { {0xf1b3000b,0x78a90017,0xe4a70048,0x629c00d0}},	//   _כסף_, crev, ърно, esro
  { {0xa3a40046,0xb5fd009b,0xddc20034,0x69c60032}},	//   ијск, _pišk, lloń, _abke
  { {0xdb2300a2,0x2bc40037,0x442d0027,0x07a30001}},	//   _ürün, ल्या, đe_, _тајн
  { {0x442725b8,0x9f5c0107,0x35b50148,0xa5bb0031}},	//   zin_, _nové_, _сбир, ziój
  { {0x44270893,0xb9550014,0xce380009,0xd7fb003c}},	// [66d0] yin_, уващ, _שאחת_, муж_
  { {0x442725b9,0x1b4b0003,0x2d990b15,0x6f950012}},	//   _ön_, _يؤدي_, lase_, الاض
  { {0x62670003,0x6b68000e,0x78a9029d,0x8e740012}},	//   _لاحق, _végü, zrev, لانض
  { {0x44270fed,0x64431528,0xe3b80060,0x645a25ba}},	//   win_, woni, _acı_, _ahti
  { {0x2bc00037,0xd49b0001,0x8cc50012,0x442725bb}},	//   श्वा, фре_, اقته, tin_
  { {0xa5bb000e,0x442725bc,0x1c440024,0x711a0009}},	//   fiók, uin_, анім, _טורפ
  { {0x63b5001e,0x442725bd,0x6e9401ef,0xc7b20009}},	//   igzn, rin_, _вису, _לבם_
  { {0xe0d905fb,0x645a008e,0x44271510,0x78a925be}},	//   еви_, _ehti, sin_, trev
  { {0x8bb70003,0xa5350015,0x224d11a6,0x442725bf}},	//   _لإضا, _снач, rlek_, pin_
  { {0x7d040006,0xbf0e0037,0xa3e20037,0x6d3a0009}},	//   äise, ानून_, _नों_, _אֲבו
  { {0x765b0020,0xa5bb000e,0x41b50003,0xddc4000d}},	//   _khuy, ciók, _ممار, _chiş
  { {0x6d4100a2,0xb87b0026,0x69dd25c0,0xe8950024}},	//   ğlan, _príl, _nase, _бадь
  { {0x6d4100a2,0x10a50014,0x645a004a,0xb05b004a}},	//   şlan, _силн, _yhti, _epäi
  { {0xe1ff000f,0xb87b01e3,0xa09a0009,0x61ef01e3}},	//   _fiók_, _crím, _טינט, _ancl
  { {0xb6a30020,0x2d9925c1,0xfae70012,0x625310b3}},	//   _xuấ, base_, حث_, rçon
  { {0xceb20093,0x61fb0065,0xb5fb25c2,0x7e6d00c1}},	//   _היה_, njul, rmác, _giap
  { {0x62530025,0x76460073,0x629c25c3,0x69dd12a3}},	// [66e0] pçon, moky, ssro, _dase
  { {0x93bc000d,0xd7f90024,0x6fa50012,0x6716003c}},	//   _amăn, кує_, لإمك, льеф
  { {0x442a0051,0x07b70003,0x55e600f5,0x0d86025c}},	//   mib_, اهمة_, ложб, глен
  { {0x765b008a,0x7e7e000e,0xbddb0025,0x7bc30097}},	//   _chuy, _éppe, llèr, efnu
  { {0x40950046,0xb6a3001a,0x7bc325c4,0xa42601c6}},	//   _врст, _suấ, ffnu, лькл
  { {0x442a0532,0x69dd25c5,0x98160012,0xbab40012}},	//   nib_, _zase, _إبحا, لمتب
  { {0x0cb10037,0x68e425c6,0x026a0024,0xa3e90011}},	//   _जम्म, lvid, нший_, याज_
  { {0xaa540001,0x7d0d000e,0x68e40051,0x3f9a001e}},	//   јвиш, önsé, ovid, lapu_
  { {0x442a0051,0x2d9905e7,0xd1300012,0x05dd0011}},	//   kib_, vase_, تمة_, _नोटब
  { {0x6aa10065,0x7e6d00c6,0x442a00b6,0xd0730003}},	//   álfk, _siap, jib_, حديث
  { {0x63060003,0xe7c60011,0xbe190024,0x68e4005e}},	//   _حوال, र्यप, вжнє_, hvid
  { {0x90e60003,0x24560028,0xb5fd04d2,0x68e425c7}},	//   _مستن, væma_, _piši, kvid
  { {0x2ed10011,0x249f25c8,0xb87b25c9,0x69dd25ca}},	//   _सन्त, éum_, _prím, _rase
  { {0x3ed40003,0x8f76002d,0xb5fd02a1,0x68e425cb}},	//   _نقتر, _суді, _viši, dvid
  { {0x3a2900c6,0x1797000b,0xd25b00f5,0xff7b0009}},	//   tiap_, _גדול_, еца_, _אטומ
  { {0x8e830003,0x2bc40011,0xc2570012,0xb5fd25cc}},	//   _اليه, ल्ता, اخست, _tiši
  { {0x37ab0014,0x3fab0001,0xb6340003,0x290f0074}},	// [66f0] етен_, ењем_, _دعوت, ága_
  { {0x3eac00bd,0xf957000b,0x76490028,0xf1b9017b}},	//   ordt_, רסמת_, _skey, riši_
  { {0x69dd02fb,0x96e80223,0x7e2b0024,0xa3ae0011}},	//   _tase, льца_, ніда_, _काज_
  { {0xee2e002d,0x61ef002a,0xc64b0003,0x64470c07}},	//   ін_, _uncl, رجال_, loji
  { {0x798d0160,0xe578002d,0xae1c000b,0x2ed10037}},	//   mbaw, узі_, עודכ, _तन्त
  { {0x64470708,0xaae50003,0x23290447,0xf3e50055}},	//   noji, لسعو, коли_, ржко
  { {0x765b001a,0x3d9525cd,0x41b50012,0x90560009}},	//   _thuy, _вибр, لمغر, _כבשו_
  { {0x020504ac,0x7d040032,0x212b0018,0x7afa25ce}},	//   рзин, äisc, úcho_, ätti
  { {0x2003077d,0xd5ed0020,0xa5bb000e,0x320d23c8}},	//   _koji_, _giả, ciói, rkey_
  { {0xb87b0026,0x6009020e,0x6006003c,0xb05b008e}},	//   _príj, тном_, иным_, _epäv
  { {0x442a0051,0x644713be,0xe7391c79,0xcfb60009}},	//   vib_, doji, тен_, בלתי_
  { {0x3a7a000b,0x12fa000b,0x25e60011,0x60160018}},	//   _סטנד, _בהעב, _जोशी_, _câmb
  { {0x7bde0807,0x320201e9,0x442a0190,0x25d60009}},	//   _papu, _roky_, tib_, בורן_
  { {0x799b0227,0xa01b0097,0x711a0009,0xb4d60011}},	//   lauw, _stön, _בונפ, _सनी_
  { {0x19960001,0xc7b2000b,0x69960014,0x442a25cf}},	//   ијар, _ובו_, ирах, rib_
  { {0xdb1c19ce,0x798d002c,0xa5f70001,0xb5fb0f9b}},	//   cerý, gbaw, _већу_, lmán
  { {0x48e30015,0x64470f31,0x2ca0001b,0x442a005e}},	// [6700] оотв, boji, _uvid_, pib_
  { {0x69c40802,0x8fa60210,0x07a600a6,0x4c9b01b0}},	//   sfie, раже, ражн, _ששיע
  { {0x23fb000b,0x69c40052,0x93fb0009,0xf1b9001b}},	//   _ספטמ, pfie, _סלטי, lišu_
  { {0x3eb90002,0x78ad25d0,0x627b0009,0x91e60560}},	//   ństw_, brav, _שנכנ, _томе
  { {0x78ad0017,0xf1b9001b,0x7e6225d1,0x7c2a25d2}},	//   crav, nišu_, rmop, tifr
  { {0x66e60098,0xdb1c000f,0xd91b000b,0xdb070028}},	//   _кога, kerü, _יוכל, rfjö
  { {0xdb070028,0x32b70012,0x7c2a0248,0xdb1c0034}},	//   sfjö, لدية_, rifr, meró
  { {0xc48600f5,0x41e60024,0xbebc0035,0x6aa10097}},	//   _влак, ріка, lzīg, álfi
  { {0x6b9c002c,0x9a670012,0xb7bc0035,0xc05a0024}},	//   karg, جميل_, liģi, кіо_
  { {0x9cd7000b,0xdb1c0002,0x23890066,0xf80600f4}},	//   _דומה_, neró, čují_, рчин
  { {0x6d4100a2,0xb87b0026,0x0857000b,0xbb460014}},	//   ğlam, _prík, שבים_, _тежк
  { {0x3ce9012e,0x6d4100a2,0xd2520012,0x62850025}},	//   _prav_, şlam, _بنص_, _rtho
  { {0xc5f3000b,0x6b9c0033,0x644703d3,0xfbd30012}},	//   קדש_, farg, toji, يتس_
  { {0x7f840003,0xab94002d,0xdb1c0032,0x511b0009}},	//   _الغن, жирі, berü, _שֵׁנ
  { {0xda780098,0xbebc0039,0x644709d4,0x99dd0042}},	//   ият_, dzīg, roji, plňt
  { {0x9dab0014,0xa01b000e,0x52141f26,0xf9930012}},	//   _ръка_, _etöl, одст, تبس_
  { {0x6b9c02d1,0xb05b0029,0x32d8001a,0x64470042}},	// [6710] barg, _opät, _lũy_, poji
  { {0xb5fd0145,0x6b9c0b45,0x8c240012,0xc1040012}},	//   _lišt, carg, _وفيه, غولي
  { {0x8ae4007c,0xdc3c0093,0x2fe40003,0xdd910012}},	//   _діял, _בעזר, تكلف, كوا_
  { {0x7d0b0163,0xb5fd0027,0x25b90028,0xcad60009}},	//   tygs, _ništ, ngsl_, _פורת_
  { {0xe9ff001a,0xdb1c000e,0x98ab0035,0xfce5091c}},	//   hoản_, zerü, īmēt_, соло
  { {0xa5bb000e,0x0c24002d,0xda7801bd,0x8c480024}},	//   cióv, омін, _buď_, апів_
  { {0x07340024,0xe4f30011,0x2ef5004c,0xc6d400ae}},	//   _дерю, _आपकि_, _узвр, _وتفت
  { {0x2019001e,0x5338000b,0xcb380009,0xb05b008e}},	//   īsim_, ינון_, ינוק_, _epät
  { {0xa9fa0009,0x7bca0097,0x7bc5005e,0x6b9c0060}},	//   אִית, _öfug, õhus, yarg
  { {0x04590003,0x20030028,0xb5fb0030,0x6d5b004b}},	//   _صلاة_, ðji_, umán, _izua
  { {0x5f45000a,0x6604004a,0x2eb60011,0xa6b4003c}},	//   إنجل, _poik, _अमृत, осящ
  { {0xf409000b,0xd5b20009,0xceb20009,0xe9df0081}},	//   _אפ_, ּׁם_, היט_, _thúy_
  { {0x3085000a,0xafe50109,0x20850012,0x6b9c25d3}},	//   _التف, _голл, _التّ, targ
  { {0xb5fb0065,0xaffe001a,0x1c390015,0x6e3b013a}},	//   lmál, _thướ, аясь_, _ljub
  { {0x3ce60029,0x2d9d0034,0x2ef80032,0xad9b0097}},	//   zvov_, kawe_, ärft_, rkúr
  { {0x6b9c25d4,0xb5fb0097,0x3f98016d,0x3f811a4d}},	//   sarg, nmál, _seru_, echu_
  { {0x5156005c,0xdb1c25d5,0x315a0012,0xe9d7004c}},	// [6720] ству, teró, اجأة_, љку_
  { {0x3cfb000b,0xc9520009,0x33d50024,0xcfa90012}},	//   _עלינ, למן_, _діют, لامم_
  { {0xa8560009,0xb4650012,0xe9ff0081,0xfe720012}},	//   ציעה_, _بديه, _ngắm_, سدا_
  { {0xb05b25d6,0x9e760009,0xa2f70009,0xc8690009}},	//   _spät, צגנה_, _המטה_, גן_
  { {0x6aa10065,0xdd990026,0x69d600a2,0x61e4003a}},	//   álfv, _deň_, meye, mdil
  { {0x69cb008b,0x69d600a2,0xa5070046,0x61e40b4b}},	//   _abge, leye, сеља_, ldil
  { {0x2ef8000b,0xfba9002d,0x61e40051,0xb05b004a}},	//   _דִּב, ртій_, odil, _epäs
  { {0x69d6003a,0x8f37000b,0xd7f8000d,0xbda50012}},	//   neye, _האלו_, rmăm_, _وحقو
  { {0xdb050052,0x9f58003a,0x24f6004c,0x99800073}},	//   _schü, _borç_, _учвр, lnių_
  { {0xa208003a,0x61e4004a,0x60c403ec,0x3f980f81}},	//   ılış_, hdil, itim, úru_
  { {0xdb1c0065,0x60c4035f,0x60160017,0x57fb000b}},	//   lfræ, htim, _câma, אליו
  { {0x0f57000b,0x442e003a,0x60c416a0,0xb1e50012}},	//   מיים_, lif_, ktim, _وأنه
  { {0x69d60f1f,0x7bd5099e,0xb87b159b,0x7c2e25d7}},	//   deye, tezu, _hrív, fibr
  { {0xdcfd0039,0x23740003,0xf537000b,0x395900a8}},	//   lasī, كافح, מרכז_, üsse_
  { {0x60c4007a,0x00570009,0x54540024,0x6b9a25d8}},	//   etim, _השגת_, ївст, _metg
  { {0x3f9e001c,0x53340406,0xdb180032,0x20c20097}},	//   latu_, чест, bevö, oði_
  { {0x625325d9,0x7c2e005e,0x779900b5,0x60f9003c}},	// [6730] nçoi, bibr, икар_, шная_
  { {0xdb180051,0x20c20028,0x249f001e,0xf7730012}},	//   levõ, iði_, šums_, ساط_
  { {0x3ed5000a,0xa3e20037,0x602f0010,0xdef10003}},	//   تقار, _नोट_, _rėmė, بًا_
  { {0x6aa10028,0x64550052,0xeb050011,0xdb18005e}},	//   álfu, llzi, रहीत_, nevõ
  { {0xeb990046,0x3f9e208f,0xdb1c0028,0xd7e70024}},	//   аил_, katu_, gfræ, _ліво
  { {0xdb050061,0x2bc40011,0xa5bb25da,0xd469004c}},	//   _adhé, ल्ला, gnóz, шиле_
  { {0xf9910003,0xe4500003,0xb4d60037,0xa5bb0002}},	//   وبة_, رضه_, _सन्_, niós
  { {0x20c20028,0x7c380070,0x80a90109,0x2eee0040}},	//   fði_, anvr, авив_, æffe_
  { {0x20c20065,0x5fc60011,0xdb18005e,0x6d5b004b}},	//   gði_, र्वल, devõ, _uzua
  { {0xbebc0039,0xd825007c,0xa7fc003a,0x2bb80003}},	//   dzīb, ідни, smın, _هامة_
  { {0xc7b2000b,0x83c40011,0x25d50009,0xcce90009}},	//   ובי_, _लॉगआ, ֗וֹן_, _שכ_
  { {0xb9e40024,0xbe660012,0x69c90011,0x91c90011}},	//   _нічи, تهجي, _हॉली, _हॉलै
  { {0x9556000a,0x4dda0009,0xb90b0012,0x8fa510c2}},	//   تخدا, בחרו, _حزام_, _дале
  { {0xdb1c0065,0xf1bf01e3,0x68e90192,0x9cd60009}},	//   ferð, _acá_, mved, חושה_
  { {0xdb1c0065,0x69d600a2,0xe7e20037,0x99890029}},	//   gerð, teye, _कोटा_, znať_
  { {0xe9da0001,0x60c425db,0xaea80012,0xa5bb0031}},	//   јка_, ttim, _اطول_, ghód
  { {0x3c460012,0xe0860012,0x7a3e0035,0x7c2e0073}},	// [6740] _وَبِ, تجزي, nīta, pibr
  { {0xe29a0046,0xe7320003,0xb05b02f1,0x99890029}},	//   _као_, وصا_, _spär, vnať_
  { {0xe57a011d,0xf1d90011,0x20071b10,0xe7c60011}},	//   азе_, ढ़ान, _moni_, र्षप
  { {0xdd8f0012,0xecea003c,0x20070030,0x27150081}},	//   نوم_, идел_, _loni_, ín_
  { {0x99800010,0xac460012,0xdca306bd,0x442e25dc}},	//   snių_, يئته, дачи, tif_
  { {0x7a3e0039,0xdb1c0065,0x2aaa0001,0x973c0027}},	//   dīta, rfræ, атио_, laće
  { {0x442e25dd,0x61e200ba,0xdb1c0097,0xad9d0034}},	//   rif_, _paol, sfræ, _koźl
  { {0x9f5c022d,0xdd140029,0xdb070033,0x6b9a0070}},	//   _nová_, pĺňa, rgjø, _wetg
  { {0xd0100003,0xdcfd001e,0x49b70012,0xd1b70012}},	//   فلة_, rasī, زايد_, زايا_
  { {0x20c20065,0x20180028,0x7e7c25de,0x3f9e00b6}},	//   rði_, óri_, _kurp, uatu_
  { {0xdb180005,0x61e20051,0xa01b0028,0x4fd70009}},	//   tevõ, _taol, _stök, חויב_
  { {0x62650003,0xa4d5002d,0x9e270024,0xaadb0009}},	//   _فانق, помі, ієнк, _כחבר
  { {0xa9260003,0xe4e4002d,0x2715001a,0x3f9e0c0f}},	//   _بعضه, мірн, án_, patu_
  { {0xa067002d,0x7bd80d69,0x68fb0054,0xbebc0035}},	//   _дача_, nevu, _àudi, rzīb
  { {0x5fb7000b,0x764b016d,0x7bca25df,0x600d1d72}},	//   _והוא_, yogy, iffu, _cúmu
  { {0xd6280001,0xeab00012,0x7bda0025,0x2007001b}},	//   _моје_, ضعف_, ôtur, _zoni_
  { {0x7afa0163,0xa01b006f,0x99890034,0x201e079b}},	// [6750] ättr, _utök, tkał_, ohti_
  { {0x20070065,0xc7f8002d,0x7bd80066,0x6aa10028}},	//   ðni_, онує_, jevu, álfs
  { {0x443100a2,0x68e9074b,0x7bd82151,0x7bda0009}},	//   miz_, zved, devu, _הקתו
  { {0x99890034,0x78a4008e,0xdb030032,0x443125e0}},	//   skał_, bsiv, rgnü, liz_
  { {0x25a00065,0xddc9001e,0x01fa0009,0xc4db004c}},	//   ðila_, _cieš, _הפרל, рђе_
  { {0x443100a1,0x7bd800b4,0x6a95002d,0xfc04002d}},	//   niz_, gevu, приє, мпіо
  { {0x60d9003a,0xb5fb000e,0x8c1c0009,0x4dd70012}},	//   şamı, rmáj, שווי, _وترس
  { {0x7a3e001e,0xdce80002,0x820b0009,0x2cb00060}},	//   tīta, _śląs, יהֶ֖, üldü_
  { {0x4431003a,0x661b005e,0x17f90012,0x25e60011}},	//   kiz_, _iluk, مردة_, _जोगी_
  { {0x7bd800c1,0x87250406,0xb5fb000e,0x79840002}},	//   cevu, змож, lmáh, zciw
  { {0x8e85002d,0x661b0028,0x7a3e0035,0x68e9256a}},	//   ягне, _kluk, sīta, sved
  { {0x3ebe00b0,0x9f510031,0x4efa0009,0x201e005e}},	//   _åtte_, _hozó_, צהרו, ahti_
  { {0xe0ce002d,0x317a0009,0x973c001b,0xdd4a004c}},	//   _яв_, _האנד, vaće, стнa_
  { {0x21580012,0xd0110012,0x74160012,0x20130081}},	//   _بجمع_, _سلع_, أوسا, _ôxi_
  { {0xdb1c0163,0x8f9a000b,0x661b0051,0xdce6003a}},	//   kfrå, _היצי, _oluk, rakı
  { {0x154604a5,0xd5ed0081,0x8886004c,0xddd20034}},	//   _нейм, _già, злаж, łgło
  { {0x55bb000b,0x973c0027,0x799d0032,0x6aa10097}},	// [6760] _המפו, raće, _desw, álfr
  { {0x9f470033,0x7d04004a,0x98af0010,0x661b004a}},	//   _ennå_, äism, _lygį_, _aluk
  { {0x660900bd,0x3c450012,0x6beb0009,0x41c0003c}},	//   _boek, _تضيف, _הַכַ, _а́ет
  { {0xddc92172,0xb87b0029,0x24560028,0xc0490009}},	//   _pieš, _prít, dæmi_, אז_
  { {0x2017000f,0x1dc10011,0xf1b30009,0x5fbd0011}},	//   áció_, ष्टत, _אסר_, ्भाल
  { {0x7e7c0039,0x61e600a2,0x661b0051,0xddc90010}},	//   _turp, _hakl, _eluk, _vieš
  { {0xe2970001,0x3f9c0025,0x661b25e1,0x61e625e2}},	//   пај_, _revu_, _fluk, _kakl
  { {0xddc90039,0x7f3b0093,0x2d800026,0x99d60003}},	//   _tieš, _העלו, žieb_, ستعا
  { {0xdfd00351,0x4431003a,0x7643000e,0x0ef40011}},	//   نية_, yiz_, énye, इम्स_
  { {0x660901e4,0x3cfa0037,0x7d0d004a,0xf093000b}},	//   _zoek, ्हीं_, äase, ענת_
  { {0x644e25e3,0xbbe90012,0x6fc10011,0x224d0227}},	//   dobi, _برقم_, र्टू, boek_
  { {0xf27b0093,0xa3cd0044,0x60120065,0x8afb000b}},	//   _הראש, ष्ठ_, _dæmi, _להבי
  { {0xd564004c,0x7a3e0035,0x2ca6020d,0xf9930009}},	//   етрп, līto, nsod_, _טרף_
  { {0xb3470017,0xdc8b0009,0x648b0009,0x7bc8005e}},	//   _naçõ, מְלָ, מְלְ, õdup
  { {0x443125e4,0xdb1c0061,0xd6d00012,0x7a3e0035}},	//   riz_, ngrè, _شقة_, nīto
  { {0x4431003a,0x7548000e,0x6e2d002c,0x0f57000b}},	//   siz_, észé, _umab, _מיום_
  { {0xd5ed001a,0x61e60027,0x764f0002,0x83870015}},	// [6770] _giá, _dakl, mocy, _ныне
  { {0x224d00bd,0x660900b6,0x661b014f,0x649c0009}},	//   zoek_, _soek, _sluk, _היזה
  { {0xb87b0026,0x3ea7000f,0x2ca900c5,0x200a02a1}},	//   _prís, ént_, _hvad_, _dobi_
  { {0x7a3e001e,0x9f4a0018,0x24560097,0x7bc100b8}},	//   dīto, _robô_, væmi_, _sclu
  { {0xdb1c0163,0x629a002c,0xed4e098c,0xc4840024}},	//   rfrå, _awto, то_, елік
  { {0xe0fa000b,0x78fa0009,0xdb1c0248,0xd7e40024}},	//   _ולשל, _ופשו, sfrå, _пісо
  { {0xe45f004a,0x61e6003a,0xcb660014,0x66091730}},	//   ytön_, _yakl, маше_, _toek
  { {0x601f0061,0x6c850003,0x644e25e5,0x661b005e}},	//   _même, _يلزم, zobi, _uluk
  { {0x629a000e,0x320b0002,0xe8f9002d,0x8cd50037}},	//   átoz, _mocy_, іло_, _मैचो
  { {0x4de60037,0xc87f0052,0x7e6425e6,0x248d25e7}},	//   _जोड़े_, _muß_, _ship, _item_
  { {0xa294002d,0x1f65002d,0xfb150003,0x644e0864}},	//   _захі, ьком, _تواج, vobi
  { {0xcb120093,0x320b0002,0xc3320009,0xe6170024}},	//   _שלא_, _nocy_, _בוב_, ддю_
  { {0x61e90033,0xdddc0010,0xa8eb0012,0xa87b0012}},	//   mdel, _surū, _دعاك_, _احصر_
  { {0xb4ce0044,0x90450003,0x61e61f3e,0x63a31858}},	//   _रही_, _تنته, _sakl, nann
  { {0xe45f0028,0x68ed03d3,0xe8520012,0xc87f0032}},	//   mtöl_, evad, _جنود, _auß_
  { {0x27e70065,0x2d9f008b,0xda650003,0xddcd000d}},	//   _hann_, _neue_, فاقي, _viaţ
  { {0x27e7008b,0x80aa002d,0x644e0002,0x6b670061}},	// [6780] _kann_, ював_, pobi, tégé
  { {0xdd0c003e,0xc9630015,0x61e9004a,0x973c0027}},	//   półc, твуй, hdel, laća
  { {0x6d4100a2,0xdb050052,0x27e70c28,0x5693002d}},	//   şlat, _schö, _mann_, ваєт
  { {0x6b67000f,0x60c90033,0x61e91e9d,0xc87f0052}},	//   ségé, ktem, jdel, _fuß_
  { {0x3cfa0044,0x25a00005,0xd5e40020,0x0e690003}},	//   ्हें_, _meil_, _chỉ, أصلي_
  { {0x9f980028,0x7a3e0035,0x68200032,0x0fda0012}},	//   _náðu_, tīto, _böde, _ببحث_
  { {0xa6e10028,0xfbd3000b,0x25a000b7,0x69db0032}},	//   óðle, דתו_, _oeil_, feue
  { {0xe1ff008a,0x6df60003,0xdb25000e,0x7a3e001e}},	//   _khóa_, _تكرا, ésér, rīto
  { {0x83c60014,0x301405cc,0x7a3e001e,0x7bdc07c9}},	//   _обаж, едпр, sīto, keru
  { {0x3958001e,0x9b930012,0x224907a5,0x682025e8}},	//   ārs_, _للكت, čaka_, _föde
  { {0x27e7008b,0x7bdc25e9,0xa6350024,0xde590024}},	//   _dann_, deru, енні, зані_
  { {0xd3780027,0xa01b006f,0x7d090051,0x7bdc005e}},	//   _naći_, _utöv, äeso, eeru
  { {0x60c90108,0x9f980028,0x7d04004a,0xadc3001a}},	//   ctem, _fáðu_, äish, _hoản
  { {0x515b0009,0x9f980097,0xdb030018,0x7bdc25ea}},	//   _וכדו, _gáðu_, danê, geru
  { {0x25a00119,0x6adc0044,0xcf260003,0xd7bb0009}},	//   _feil_, _मनोर, _ترشي, _וצור
  { {0x25a00028,0xda700012,0xe2540012,0x63a325eb}},	//   ðill_, لُّ_, نَّخ, zann
  { {0x7d00006f,0xd8790003,0xee3f01e9,0xd59c0009}},	// [6790] ämst, سمات_, mný_, _ובחל
  { {0x61e902e7,0x9c380015,0x2d810066,0xee3f0042}},	//   zdel, _опыт_, ěhem_, lný_
  { {0x4fc40048,0xc7c40048,0x63a325ec,0x28080012}},	//   ъста, ъсти, vann, بْلَ_
  { {0x2ddb000a,0xee3f022d,0x94790001,0xdb030017}},	//   تبطة_, nný_, пску_, banê
  { {0x69c0002a,0x6820006f,0xd1260012,0xee3f0030}},	//   dgme, _söde, _إم_, iný_
  { {0xc7ce0020,0x5faf0037,0xb09a0009,0x2005005e}},	//   _sống_, _फ़ाइल, _מישר, _õli_
  { {0x69db0052,0x60230066,0x8b940024,0x248d0034}},	//   teue, růmě, тріч, _wtem_
  { {0x61e90feb,0xd5e4001a,0xee3f0042,0x3ebe0248}},	//   udel, _thỉ, jný_, _åtta_
  { {0xb4ce0044,0x2919000f,0xee3f00f1,0x973c001b}},	//   _रहे_, ása_, dný_, vaća
  { {0x63f40003,0x60c925ed,0x9b880012,0x93bc004b}},	//   _لأمر, rtem, _ينقل_, _clăd
  { {0x98ab003a,0x74280012,0x27e70704,0xe9ff0081}},	//   ğlık_, _تكلف_, _vann_, _ngầm_
  { {0x98ab003a,0x27e70052,0x0607002d,0xc7ce001a}},	//   şlık_, _wann_, енюк_, _uống_
  { {0x55ba0009,0x973c001b,0x39590248,0x25a025ee}},	//   המרו, raća, _nyss_, _veil_
  { {0x33d5007c,0x25a0008b,0x7d04004a,0x7bdc0052}},	//   кіст, _weil_, äisi, ueru
  { {0x78a903eb,0xcf880003,0x63a1001e,0x25a025ef}},	//   lsev, _غضون_, _meln, _teil_
  { {0xb87b0026,0x2caa0014,0x6d41003a,0xbca60003}},	//   _príp, _екип_, ğlar, _كمبي
  { {0x6d4100a2,0x6e3b000b,0xba170003,0xe0850003}},	// [67a0] şlar, _מתקד, ريكا_, نجلي
  { {0x999f001e,0xe1080009,0x1ae60217,0x78a925f0}},	//   ārša_, וּעָ, _зоом, isev
  { {0x31ba003a,0x28ac0037,0xdb9b000b,0xe39b0009}},	//   nüzü_, _चिकि, _מסיר, _משיכ
  { {0xa01b006f,0x78a91277,0x2cea0024,0xdb0301a0}},	//   _stöt, ksev, зько_, manè
  { {0xb97b000b,0x64410066,0x62810066,0x98b80035}},	//   _מרכז, čliv, ílov, ārī_
  { {0xbb3a000b,0x22401b04,0x6281010a,0x0aea0012}},	//   ּעֵי, lnik_, _bulo, كربي_
  { {0xc843002d,0x63a30051,0x6281000d,0xddc90029}},	//   _серй, _õnne, _culo, _sieť
  { {0x63a10005,0x60f80014,0x6281002c,0x224025f1}},	//   _eeln, дния_, _dulo, nnik_
  { {0xd7f00003,0x63a1000e,0xdd8f0003,0xee3f01bd}},	//   لكة_, _feln, _طول_, vný_
  { {0x20d30003,0x3ea6001e,0xc6190011,0x3a3f0132}},	//   اتيج, ņotu_, दस्य_, anup_
  { {0x2cb0007a,0xdb060006,0xee3f00f1,0xa2d30012}},	//   žodį_, ämäl, tný_, _ميلت
  { {0x444425f2,0x7bc525f3,0xb5fb0031,0xdced0073}},	//   _aj_, _schu, ilág, škąj
  { {0xba290003,0xee3f01bd,0x224025f4,0xdb150097}},	//   _تسلم_, rný_, dnik_, _íbúa
  { {0x7a230051,0xee3f0042,0x3e67005e,0xe45f0097}},	//   _mõte, sný_, mõte_, mtök_
  { {0x24560065,0x0057000b,0xdb080066,0xdb220028}},	//   væmt_, _רשות_, _oddí, ðuðu
  { {0x7a3e0039,0x9b58002d,0x444425f5,0xa75b0009}},	//   dītk, хист_, _ej_, _מדור
  { {0x9f5c0026,0xb9ca0081,0xe45f0097,0x3ebe24e4}},	// [67b0] _novú_, _sưị_, ntök_, lutt_
  { {0x44440033,0xe53c000b,0x1154002d,0xfd65001a}},	//   _gj_, _מתחר, укую, _thuẫ
  { {0xf3ff008a,0x2240012e,0xdd910003,0x3ebe0033}},	//   _đã_, bnik_, لوا_, nutt_
  { {0xfe700003,0xee38002d,0xceb30009,0x36180024}},	//   مدن_, ннє_, ריף_, нцію_
  { {0x63a10071,0xad670012,0x0d840024,0x93bc004b}},	//   _peln, راؤه, улін, _rmăr
  { {0x61ed000f,0x6c940003,0x60cd01ea,0x31ba0060}},	//   ldal, اشنط, mtam, yüzü_
  { {0x92e80003,0x9f35002d,0x63a10002,0x8d950012}},	//   فريق_, _реві, ólny, _للأش
  { {0xc6920009,0x9975004c,0x78a925f6,0xceb80034}},	//   _כאל_, купш, tsev, drę_
  { {0x5c750046,0x9f430013,0xe45f0028,0xe0d9002d}},	//   _алат, _mají_, gtök_, єво_
  { {0x628125f7,0xbb840003,0x61ed004a,0xbebc0035}},	//   _tulo, _ملكي, hdal, azīm
  { {0xb5fb0066,0x60cd00e6,0x3e7b0035,0x22400034}},	//   klád, htam, _sūta_, ynik_
  { {0x23740003,0x1995002d,0x9a880003,0x78a90051}},	//   _صالح, _радя, _أَنْ_, psev
  { {0x271c008a,0x2240013a,0xceb80034,0xb5fb0031}},	//   ản_, vnik_, arę_, emás
  { {0x2240003e,0x3ebe0033,0x61fd2095,0x7bc325f8}},	//   wnik_, butt_, _ansl, ngnu
  { {0xe8050037,0x78660097,0x03a30288,0xdaba0012}},	//   राना_, uðve, рисо, ظهرت_
  { {0x78660028,0xc2430909,0x61ed25f9,0xdb080025}},	//   rðve, анск, gdal, élép
  { {0xf3f10020,0x61eb0101,0x9f430066,0x60cd0b8a}},	// [67c0] ộc_, _magl, _dají_, gtam
  { {0x22400416,0xe3b8003a,0xa01b0d4a,0x61eb0c8e}},	//   snik_, _alın_, _stör, _lagl
  { {0x224004d2,0x141b0009,0xba760012,0xaec60048}},	//   pnik_, _חויב, _لاحت, тбел
  { {0x22ac0066,0x443825fa,0x7c2103ce,0x61eb25fb}},	//   věk_, lir_, _allr, _nagl
  { {0x7a3b004a,0x44380061,0x9f4700d9,0x60cd1d98}},	//   sätä, oir_, _dané_, ctam
  { {0xdb18000f,0x3e670051,0xa5070001,0x5453002d}},	//   egvá, võte_, теља_, авіт
  { {0xb6a3002d,0xbebc001e,0x7a3e001e,0xbae30012}},	//   _висл, tzīm, līti, لكوي
  { {0xdbdf0065,0xcb13000b,0x26140017,0x78b10028}},	//   síðu, שלה_, _mãos_, _ákvæ
  { {0xfce300e3,0x7a3e001e,0x0a670014,0x20540048}},	//   _кото, nīti, ърши_, лкия
  { {0xd7f70047,0xe8050037,0xdfd00003,0x443809db}},	//   вую_, राया_, حيد_, jir_
  { {0x539b000b,0x3817000b,0x4fbb007e,0xaabf0037}},	//   _חיבו, דקים_, וציא, _एमएक
  { {0x68e40002,0x12a90012,0x7c380830,0xddcd0034}},	//   kwid, _أدلى_, livr, _skał
  { {0x9f470026,0x44380f92,0xdb030042,0x23c90011}},	//   ľné_, fir_, vané, _रामद
  { {0x7a3e0039,0x61e0003a,0x9f4700f1,0x68e40431}},	//   dīti, leml, žné_, dwid
  { {0x60c0004a,0x2bd20037,0x20140034,0xdd030060}},	//   lumm, द्धा, ęcić_, ırıd
  { {0x60cd25fc,0x69dc000e,0xcad7000b,0xb765002d}},	//   ttam, őref, כולת_, _стій
  { {0xe7cf0044,0xf8b1000b,0x443825fd,0xe5f80009}},	// [67d0] त्वप, ֶשׁ_, bir_, _יזהר_
  { {0x443802d1,0x7d58000b,0x7e691d43,0x2bd20011}},	//   cir_, _ביחד_, _shep, द्दा
  { {0xdcef003a,0x60cd25fe,0x539a000b,0x645501f0}},	//   macı, stam, _איתו, mozi
  { {0x61e0009b,0xfb1a000b,0xadef0011,0x645525ff}},	//   jeml, _נורמ, ज़ाइन_, lozi
  { {0xe8df0020,0x91ba0093,0xd838009b,0x98560002}},	//   _thực_, _אמרי, kič_, _złą_
  { {0x61eb0039,0xd838009b,0xcb69011d,0xbb450048}},	//   _sagl, jič_, нале_, лелк
  { {0x61eb0101,0x6bb4002d,0x62850029,0x78ad0010}},	//   _pagl, рсіє, _juho, lsav
  { {0x93bc000d,0x63a50052,0xceb20009,0xe4d70012}},	//   _plăc, _lehn, _ליל_, _لتطب
  { {0xe1ff0020,0x7d04004a,0xa7fc003a,0x64550550}},	//   _nhóm_, äist, klıd, kozi
  { {0x515c0009,0x6fd40024,0xd8380159,0x661d09bc}},	//   וכחו, ацює, gič_, eksk
  { {0x2ba70037,0x7a3e001e,0xddcb0034,0x6da60c7b}},	//   _औज़ा, zīti, mogł, лина
  { {0xe8f5000a,0xa2d80044,0x80f50012,0xdb012600}},	//   _مستخ, _महत्, _مستض, _relè
  { {0x25a00028,0x44382601,0x2c690018,0xcdf60009}},	//   ðili_, tir_, aúde_, אמרי_
  { {0x78ad0033,0x64551b8d,0xc1720009,0x17150012}},	//   dsav, gozi, _החד_, _مذبح
  { {0xdb01000f,0xe6d20044,0x44382602,0x232a046d}},	//   _belé, _सहेज, rir_, хови_
  { {0x6e920003,0xfaa50015,0x7a3e001e,0x225f003a}},	//   _اليا, ршён, tīti, nluk_
  { {0x41270014,0xc9660014,0xe0860012,0x11d70012}},	// [67e0] гото_, увай, اجري, طولة_
  { {0xdb0103eb,0x7a3e0035,0x225f016d,0xdc9b0009}},	//   _telè, rīti, hluk_, _רייל
  { {0x5477000b,0xdb01000e,0xbe850003,0x2d80001e}},	//   _תגיע_, _felé, لجنو, žiem_
  { {0x69d00011,0x64432603,0x63a50032,0x78bb0248}},	//   ड्शी, enni, _zehn, kruv
  { {0x7a3e001e,0x69ca000e,0x2a60016d,0x8e570009}},	//   nūte, őfes, mlib_, נינג_
  { {0x6e2403eb,0xc4d3000b,0x2a600051,0x76a60003}},	//   _llib, צגו_, llib_, _محرك
  { {0xd2500003,0xd62a046d,0xca320009,0x82b30012}},	//   ينت_, _зове_, ֶם֙_, محيط
  { {0xd5e4001a,0x7afa004a,0x611a001e,0xc4c60012}},	//   _nhì, ätty, _tālā, _متطو
  { {0x02e1015f,0xf993000b,0xe63b000b,0xdcef003a}},	//   _पन्न, זרח_, _נתמכ, yacı
  { {0x6a650028,0x998d0010,0x7aed0034,0x44382604}},	//   rófa, rieš_, łata, _ör_
  { {0x0857000b,0xa857000b,0xeb9701ec,0x8c1b0009}},	//   רבים_, רייה_, _сих_, _רובי
  { {0xd1040037,0x27ea001e,0xb5fb119d,0x27e10032}},	//   रमाण_, _šinī_, dlác, zehn_
  { {0x6455000e,0x661d0e21,0x409600b5,0x5096004c}},	//   tozi, rksk, _срет, _сређ
  { {0x63aa0028,0x6e242605,0xf0930009,0xb1170012}},	//   nafn, _elib, _הנס_, _حقها_
  { {0x501b000b,0x443f0027,0xdcef003a,0xa7fc003a}},	//   _אוגו, đu_, racı, rlıd
  { {0x5eeb0009,0x64550032,0x201e2606,0x4efb0009}},	//   _רַגְ, sozi, lkti_, _טלוג
  { {0xbf1d0037,0x64432607,0xb035076b,0xa91b0097}},	// [67f0] पन्न_, ynni, анаш, _afþr
  { {0x201e2462,0x6285004a,0x27ee0028,0x7c940012}},	//   nkti_, _tuho, _jafn_, _اشيا
  { {0xdb010164,0x201e0071,0xd5b10012,0xd6db003c}},	//   _telé, ikti_, قفا_, эта_
  { {0x78ad0039,0x7afa0058,0xeef7000b,0xd5e4001a}},	//   psav, ætte, טמבר_, _khí
  { {0xfaf80039,0x53a50012,0x2bd20011,0x7bc70031}},	//   _arī_, لمشك, द्वा, ogju
  { {0x27ee0065,0x24960003,0x493a000b,0x00ba0009}},	//   _nafn_, جنود_, _יגרו, _במשמ
  { {0xa3490098,0x1b490014,0x786b003a,0x7bfc0009}},	//   ъзка_, ъзки_, güve, תפוצ
  { {0x201e0010,0x99f50024,0x5f440012,0x4b380009}},	//   ekti_, рякі, _انفل, טרול_
  { {0xdd140029,0xcbc70012,0x225f0060,0x9f4b0030}},	//   kúša, _مزاي, rluk_, ěcí_
  { {0x99990002,0x7a3e001e,0x66db004a,0x70520012}},	//   ósł_, dītu, _näkö, ينيا
  { {0x4384000a,0xbb84000a,0xabfa0009,0x93fa0009}},	//   _المق, _المي, _שהער, _שלעי
  { {0x9756000b,0x92670012,0x59d50011,0x0f560009}},	//   ייתו_, _صدام, _डॉलर, ייתם_
  { {0xd5e40020,0x59670014,0x98b8000d,0x999a0009}},	//   _chí, _съжа, ără_, _סבסט
  { {0x7bc70028,0xe78708d6,0xd5760009,0x05760009}},	//   ggju, _судо, יתרה_, יגרם_
  { {0x765b00a2,0xfaa60406,0x883a0009,0xdb030064}},	//   _okuy, рабо, _שתצו, kaní
  { {0xc4860ef0,0x93430024,0xcb120009,0xfe720012}},	//   _клик, інте, חלל_, _بدت_

  { {0xddc90039,0x2d800029,0xdb03134c,0xe9d7004c}},	// [6800] _biež, žiek_, daní, јку_
  { {0x7a230051,0xcef60001,0x6c330003,0xacfb0009}},	//   _võta, ичењ, _وفيا, _יהפכ
  { {0x3bbb0093,0x539b000b,0x0d86048c,0x9bbb0009}},	//   _במיד, _שיטו, ален, _בציפ
  { {0x3a2900bd,0x05ba0003,0x9f5c014a,0xfcaa0003}},	//   chap_, ئدات_, _nový_, ناتو_
  { {0x45b70024,0x201e0073,0x499b0009,0x7646008e}},	//   ргію_, ykti_, _בשכב, inky
  { {0x69d90052,0xa7fc003a,0x74130003,0x98a3004c}},	//   _abwe, zlıb, يونا, _фире
  { {0x7f4300bc,0x7aed003e,0x7c3c004a,0x69ad0037}},	//   _держ, łatn, iirr, _ज़मी
  { {0x63aa0028,0x27ee0028,0x61e40feb,0x442521c9}},	//   safn, _safn_, neil, _ell_
  { {0x973c0027,0xc8c70012,0x55bb0009,0x914a0048}},	//   maći, لوين_, _שממו, ъчка_
  { {0x7e6d002a,0x201e0010,0x7d28003a,0xdb1c0040}},	//   _shap, ukti_, ırsı, mgræ
  { {0x61e40006,0xc7b3000b,0x7c3c0028,0x201e0010}},	//   keil, חבת_, dirr, rkti_
  { {0xd5e4001a,0x7c3c0028,0x443c2608,0xd5ed001a}},	//   _phí, eirr, liv_, _khả
  { {0xb894000a,0x4094000a,0x64580051,0x61e40028}},	//   _التع, _التر, oovi, deil
  { {0xb4d70044,0xbebc001e,0xc8db000b,0x7cda001e}},	//   _सही_, dzīv, _סקוט, mārā
  { {0xf1a70146,0x1a5b0003,0xaf070003,0x63a8009b}},	//   иран, نشرة_, _نقوم_, _medn
  { {0xd5e40020,0xddcd001e,0x62880017,0x63a81622}},	//   _thí, _skaņ, _mudo, _ledn
  { {0xdb030026,0xdb1c0028,0x99840010,0x60c42347}},	// [6810] vaní, rgrá, limų_, guim
  { {0x9f47014a,0x3a20003a,0x443c013a,0xfda70011}},	//   žní_, akip_, jiv_, _ख़ुफ
  { {0xdb010058,0xa1870015,0x99840010,0x64470027}},	//   _udlø, _выгл, nimų_, mnji
  { {0xdb05000e,0x64b50012,0x1e840024,0xd3560009}},	//   _nehé, محتر, ілім, _לשתק_
  { {0x7afa00a2,0x62882156,0x24e700db,0xac190198}},	//   _artt, _audo, рцег, лоду_
  { {0x443c00c5,0xb4e70037,0x99840010,0x62882609}},	//   giv_, _बनी_, kimų_, _budo
  { {0x9984007a,0x6ef0000f,0xdb1c0028,0x60130030}},	//   jimų_, róbá, agræ, _výmě
  { {0x09f90003,0x99840010,0xf2e40024,0x7e62260a}},	//   افظة_, dimų_, юючо, clop
  { {0x76590002,0x443c08ab,0xa1e80012,0x42380009}},	//   mowy, biv_, شريك_, ינהל_
  { {0x998d0026,0x76590002,0x7c2a0052,0x61e40480}},	//   dieť_, lowy, chfr, zeil
  { {0xc2c4000a,0x64470133,0xdb05000e,0x3eb10030}},	//   _ويكي, dnji, _fehé, ézt_
  { {0xd99b0003,0x76590002,0x8e4a0012,0x3f9e016d}},	//   _شخصا_, nowy, الحك_, abtu_
  { {0x915e001a,0xd9450001,0xee3700b3,0x61e4260b}},	//   _mặc_, _ћели, сня_, veil
  { {0x61e4008b,0x7e62000e,0x6f950012,0xdb0a0097}},	//   weil, zlop, _الغض, rgfö
  { {0xddc9003e,0x4e950003,0x76590002,0x7a3e001e}},	//   _bież, _اشتر, kowy, lūta
  { {0xbb430406,0x443c0416,0x60c4004a,0x78c40028}},	//   ческ, ziv_, tuim, _útví
  { {0x76590002,0xe8fa0015,0xf6530009,0x998d0064}},	// [6820] dowy, ыла_, _מצה_, cieť_
  { {0x60c40070,0x25370009,0x25a92127,0x27e50032}},	//   ruim, _לנפש_, _zeal_, neln_
  { {0xd00f0003,0x68e90052,0x6440029d,0x63a8260c}},	//   علم_, hwed, émiu, _redn
  { {0xd5ed0020,0x452a0047,0xdb1c0058,0xb0c80037}},	//   _phả, лжен_, tgræ, िंदग
  { {0x98a0003e,0x7a230051,0xf3f1001a,0x28030066}},	//   dzić_, _mõtl, _bạ_, ární_
  { {0x9cd70093,0x26c5002c,0xccf3000b,0x62882116}},	//   מונה_, kulo_, פכו_, _pudo
  { {0x63a8012e,0xaab70003,0x76590002,0x99d60003}},	//   _vedn, مدير_, bowy, متظا
  { {0x9984007a,0xae0c0037,0xd5ed001a,0xe45f006f}},	//   vimų_, _सचिन_, _thả, ntör_
  { {0x361b000b,0xf98f0003,0x63a8009b,0xdca30d60}},	//   _עומד, ربي_, _tedn, _нати
  { {0x6016007d,0x25a90b7b,0x6e220033,0x99840010}},	//   _câmp, _seal_, lkob, timų_
  { {0xeb97000b,0xcff7000b,0x81040037,0x25a90051}},	//   _הדבר_, זציה_, रमुख_, _peal_
  { {0x2bdb0037,0x99840010,0x7d1d004a,0xde59002d}},	//   म्ना, rimų_, tyss, рамі_
  { {0x5c070014,0x27e50c60,0x99840073,0xd4070048}},	//   бява, beln_, simų_, бяви
  { {0x7d0d004a,0x99840010,0x71650012,0x76590034}},	//   äasi, pimų_, _بامك, zowy
  { {0xa3cd0044,0x752f003e,0x26c50844,0x998d0029}},	//   ष्ट_, szcz, culo_, sieť_
  { {0xb9c5000a,0x7d09004a,0x9f510017,0x7afa0097}},	//   تقري, äess, _fazê_, ætta
  { {0xb4e70037,0xb8150001,0x9be7002d,0x914b0014}},	// [6830] _बने_, одај, _лінк, учва_
  { {0x2cb40066,0x64400061,0xddc90002,0x76590002}},	//   řadí_, émit, _wież, wowy
  { {0x7659003e,0xdb010164,0x9c180009,0x67b80012}},	//   towy, _pelí, _לחזק_, صالح_
  { {0x3e7b007a,0xe3b800a2,0xf7700003,0x31c70015}},	//   _būti_, _adı_, رال_, _усов
  { {0x76590002,0x2249000e,0xe4c50024,0x63850f28}},	//   rowy, mnak_, ійки, огла
  { {0x2249000f,0x76590002,0x14190003,0x9cd80009}},	//   lnak_, sowy, شيعة_, צווה_
  { {0x6d4100a2,0xdb070066,0x8c1c000b,0x539c0009}},	//   ğlay, kají, רווי, ניהו
  { {0x2249000f,0x6d4100a2,0x68e90052,0x7c28260d}},	//   nnak_, şlay, twed, _eldr
  { {0x4105002d,0xdb070066,0xa507002d,0x22490bb3}},	//   ізов, dají, _уявл, inak_
  { {0xc7ac0009,0xd7c90012,0x66160060,0x26c50c7f}},	//   ְׁכָ, جوده_, _soyk, tulo_
  { {0x2249000f,0x68fc001e,0xcfb60009,0x443a005e}},	//   knak_, ārda, חלתי_, _rmp_
  { {0xb5fb0013,0x27e50052,0x443a00b6,0xbe3a002d}},	//   slán, seln_, _smp_, рчої_
  { {0x3cf40037,0x2249260e,0xb5fb260f,0x2bdb0011}},	//   इटें_, dnak_, plán, म्भा
  { {0x6744000e,0x4add0011,0xdd7a0009,0xbebc0035}},	//   átjá, _महाव, יטרל, tzīt
  { {0x63ae066e,0x366a0046,0xd36f0012,0xdb1c0248}},	//   rabn, _како_, َهُ_, xgrä
  { {0x9fa30065,0x2249000f,0xbebc001e,0x23db0011}},	//   _síðu_, gnak_, rzīt, म्बद
  { {0x10050037,0xe79a0003,0x7bdc0028,0xd87a0003}},	// [6840] रांश_, لخاص_, _örug, لمرت_
  { {0x6e2904b4,0xdb1c006f,0x69cf1725,0x7d1b0052}},	//   _aleb, tgrä, _ecce, äuse
  { {0xf9860015,0x9182001a,0x90560009,0xdfcf0012}},	//   _мгно, iểm_, קבעו_, ضين_
  { {0xdd900003,0xdb1c006f,0xd5e9001a,0x6f1e0034}},	//   روت_, rgrä, _chè, rypc
  { {0xe8f72610,0xdb1c006f,0x9f470029,0x97c60012}},	//   _для_, sgrä, ľná_, _وتسم
  { {0x9f470145,0x62830061,0x7c830063,0x6e222611}},	//   žná_, _énor, муще, skob
  { {0xcb070012,0xb2ba0009,0xfba90024,0xdb032612}},	//   قيون_, ׁמַר, стій_, taná
  { {0xbae5002d,0x92570012,0x8f370009,0xa2cb0011}},	//   яцій, يشير_, _ואלו_, तंत्
  { {0x3cf40044,0xdb070066,0x60d619a3,0xdb0301e9}},	//   इटों_, vají, ntym, raná
  { {0x60d6007a,0xb5fb000f,0x2249000f,0xccf90002}},	//   itym, alál, znak_, _myśl_
  { {0x2249003a,0xcf930009,0x57fb0009,0x60d6008e}},	//   ynak_, וטת_, בליו, htym
  { {0xa3ba0037,0x82360012,0xc1060012,0x2a870031}},	//   _आएँ_, _برئا, _وواي, _főbb_
  { {0x867b000b,0x938b0014,0x067b0009,0xf1040011}},	//   ירטו, исва_, ינטל, रमोद_
  { {0x7a230005,0x20182613,0x69ad0011,0x9faf0060}},	//   _võtm, _nori_, _ज़ही, _işçi_
  { {0x2249000f,0xb4e70037,0x539b0009,0xb5fb0031}},	//   tnak_, _बन्_, שילו, llám
  { {0x645c00b8,0xdb010031,0x786f0474,0xddeb00ae}},	//   aori, _jelá, røve, _ضربه_
  { {0xdcea0066,0x765d14bb,0xa2ca0011,0xfbd30011}},	// [6850] čnět, mosy, सूत्, _तापम
  { {0x2249000e,0x629a2614,0xe6160159,0x7c2e0032}},	//   snak_, _otto, _čišč, chbr
  { {0x2018000d,0x98ac001e,0x2249000e,0xfbd20009}},	//   _dori_, ālās_, pnak_, _אתי_
  { {0xb5fb000f,0xfe700012,0x765d2615,0x735a0009}},	//   klám, ندن_, nosy, _לכתח
  { {0xd5e9001a,0xa3e70011,0xe44e0024,0x629a2616}},	//   _ché, यजल_, еж_, _atto
  { {0x9f430026,0xd91a000b,0x7870006f,0x611a000b}},	//   _majú_, _הושל, täve, _הושה
  { {0x3e4f0002,0x2009001a,0x3e720042,0xdb010031}},	//   zęta_, _đai_, láte_, _belá
  { {0x7a3e001e,0x69cd0028,0x645c2617,0x11d50012}},	//   sūtn, ngae, zori, ستبد
  { {0xd5fb0020,0xa3dc0037,0x7870004a,0x645c2618}},	//   _giú, ण्ड_, säve, yori
  { {0xe8df0020,0x25ad08de,0xdb030054,0x44230064}},	//   _chức_, _heel_, janç, _ôj_
  { {0xdb030149,0xb5fb0c1f,0x25ad0051,0x961d001e}},	//   danç, mláj, _keel_, _ziņa
  { {0xfce6007c,0x765d0101,0xfe720003,0x99d40003}},	//   помо, gosy, عدد_, _يتنا
  { {0x2bd20044,0xc1040003,0x61e90051,0x3cfe0037}},	//   _सामा, _يومي, meel, लिये_
  { {0xa09a0093,0x78fa000b,0x889a000b,0x645c004a}},	//   _היסט, _לפנו, _הבסי, uori
  { {0x479a000b,0x20072619,0xba6a0012,0x64400025}},	//   _פיקס, _inni_, محرك_, émiq
  { {0x60d60006,0x3e7b0039,0x23970066,0x2bd20037}},	//   ttym, _būtu_, tějí_, _साभा
  { {0x22400051,0x30860012,0xa7fc0060,0xe6db0011}},	// [6860] riik_, سلاف, klıl, _बहुज
  { {0xdb030017,0xe53b000b,0xdbca002d,0x60d619a3}},	//   canç, _לתפר, _угод_, rtym
  { {0x61e90269,0x9f450031,0x60d6261a,0x7bdc036e}},	//   keel, felé_, stym, mfru
  { {0xd5e90020,0x60d60002,0x6820006f,0xb6ba0009}},	//   _phé, ptym, _nödv, מצעי
  { {0x61e900bd,0x25ad00bd,0xac970003,0x6286002c}},	//   deel, _deel_, كننا_, _iiko
  { {0x02a6005c,0x764b002c,0x961d001e,0x7bdc000d}},	//   прим, angy, _viņa, nfru
  { {0x25ad002a,0xf3f1001a,0xaac60003,0xb5fb000e}},	//   _feel_, ội_, ستثن, rmáz
  { {0x8cc40044,0xa9c3007c,0x200701a2,0xc1ea002d}},	//   _रिपो, нськ, _anni_, ське_
  { {0xe8df001a,0x68fc001e,0x62860540,0x2485261b}},	//   _phức_, ārdo, _miko, _film_
  { {0xb0330015,0x20180028,0x2cb70066,0x3137000b}},	//   еньш, ðri_, ředí_, פנים_
  { {0x61e900bd,0xfaa306e6,0x6a65000e,0x63a30051}},	//   beel, _захо, zófi, _õnni
  { {0xa2260003,0x7a230051,0x78b6008e,0xb5fb0031}},	//   _عرضه, _võtk, ksyv, mlák
  { {0xe8df0020,0xdb050164,0x5c070014,0xcdb7000b}},	//   _thức_, _vehí, пява, הפכה_
  { {0x3e720013,0x68fb0017,0x6286004a,0x765d002c}},	//   váte_, _áudi, _aiko, sosy
  { {0x7e860013,0x60c400ea,0x3fdb000b,0x5fdb000b}},	//   íspě, erim, _הקוב, _החוק
  { {0xda7b002d,0xd7f8000d,0x7bce0e10,0x34dc0011}},	//   сяг_, ldă_, agbu, _यहूद
  { {0xdff50046,0x442c0036,0x55bc000b,0x628600b6}},	// [6870] мпањ, _old_, _המחו, _diko
  { {0xd7f8007d,0x44ef0002,0x3e7201e9,0xe1ff1a4d}},	//   ndă_, _iż_, ráte_, _chór_
  { {0x9f450013,0x2dd5027f,0xa8570009,0xa9230073}},	//   telé_, джер, לימה_, įžim
  { {0x8aa8000b,0x443e261c,0x2485005e,0x22910031}},	//   _מֹשֶ, _amt_, _silm_, _rák_
  { {0x248d0149,0x25ad0804,0x51fa0009,0xf9fa0009}},	//   _quem_, _veel_, _והרצ, _והרמ
  { {0x3cde0011,0x6f010018,0xf0920009,0x7c84004c}},	//   _गहरे_, _álco, _בנך_, нује
  { {0x6e2d00a2,0xe3b00003,0x25ad0051,0x9f450061}},	//   _olab, اره_, _teel_, pelé_
  { {0x02dd0044,0x68fb0051,0x7548000e,0x443e06b2}},	//   _महीन, tvud, ászá, _emt_
  { {0xdb0e0d48,0xe0210011,0x49000011,0xa7fc0060}},	//   rabé, _यवाद_, रियो_, lmıy
  { {0xb8d50044,0x8afc003e,0x661b004a,0xa5bb0028}},	//   _जब_, _częs, _houk, skól
  { {0x44ef0002,0xa7fc003a,0xe0200037,0xc7b20009}},	//   _aż_, nmıy, _मकसद_, כבי_
  { {0x661b0006,0xd5ed001a,0xd7f8000d,0x6443261d}},	//   _jouk, _chà, adă_, lini
  { {0x224d000e,0x6286004a,0x60c9261e,0xcdb60009}},	//   mnek_, _riko, quem, ופרה_
  { {0x60c400a2,0x224d000f,0x3b0a0047,0x6e2d1573}},	//   vrim, lnek_, оего_, _elab
  { {0x70760003,0xa3df0037,0x8f9a0009,0xe7b20012}},	//   _تموز_, ध्य_, _ויצי, _شميد
  { {0x224d000f,0xe1f90010,0x6e2d001e,0x64432145}},	//   nnek_, ndų_, _glab, hini
  { {0x7546002d,0xe1f90010,0x224d000e,0xdb07000e}},	// [6880] _іноз, idų_, inek_, rajá
  { {0xcb6a0001,0x2bd20321,0x6443261f,0x66092620}},	//   _мапе_, _साधा, jini, _anek
  { {0x224d000f,0x64432621,0x9eea0012,0x62860e0e}},	//   knek_, dini, تفال_, _tiko
  { {0xd5ed008a,0x29000010,0xd7f8000d,0x64432622}},	//   _khá, _šiam_, zdă_, eini
  { {0x224d000e,0xa7fc003a,0xdb0a2623,0x15490009}},	//   dnek_, rmız, rafí, ּנוֹ_
  { {0xe3b8003a,0x224d0002,0x64432624,0x88bd0034}},	//   _alır_, enek_, gini, zyśc
  { {0x15ee0037,0x54330003,0xe8110011,0x7dc60012}},	//   ज़ार_, ضرور, ़ाना_, _يترك
  { {0xf2d30093,0x7f3b000b,0x224d000e,0x644315ff}},	//   דעה_, _ועלו, gnek_, aini
  { {0x961d0039,0xd5ed001a,0xdfd00003,0x32530014}},	//   _ziņo, _nhá, هية_, ъвър
  { {0x3f140406,0x629e0027,0xd7f8004b,0xb5fb0031}},	//   едос, _otpo, udă_, mlái
  { {0x3eb8000f,0x6d5a000d,0xd7f8000d,0x7bc1000e}},	//   ért_, ştal, rdă_, ólum
  { {0xa5f90015,0x26c70027,0x7e760025,0xdb010060}},	//   чему_, šnog_, _chyp, _selç
  { {0x95640014,0x2bd30011,0xf27b0009,0xa7fc0060}},	//   върд, _तादा, _וראש, nlık
  { {0x7a310033,0xbddb0054,0x7d04004a,0x69d5000e}},	//   _måte, cièn, äisy, őzet
  { {0xd5ed0020,0x98a30010,0x2902003a,0xdb010052}},	//   _thà, ąją_, _arka_, _gelä
  { {0x90990014,0xa7fc003a,0x3e56001e,0x31c40232}},	//   зват_, klık, tāte_, ксув
  { {0xa9550001,0x6443003a,0xb9550014,0x44ef0034}},	// [6890] хваљ, yini, хващ, _uż_
  { {0xc9840046,0x661b0066,0xe1f90010,0x3e720028}},	//   ђути, _souk, zdų_, máta_
  { {0x26cc0164,0x07080012,0xceb80034,0x74580012}},	//   nudo_, ويكي_, nsę_, _تشيس_
  { {0x64430002,0xdce40002,0x69dc000e,0x60c20010}},	//   wini, _wzią, őrej, šoma
  { {0x6443117e,0x7870004a,0x3a360009,0xeb990063}},	//   tini, säva, _נרשם_, пил_
  { {0x97c70003,0xdb030028,0xe8d6000b,0x201c080a}},	//   _تتحم, manú, _אושר_, _novi_
  { {0x60cd0006,0x224d000f,0x64432625,0x999f0029}},	//   luam, tnek_, rini, hnuť_
  { {0x644306f8,0x999f0029,0x64b70012,0x634e0031}},	//   sini, knuť_, _يحذر, lőné
  { {0x7c670003,0x60250014,0xe1f90010,0x25bf00b6}},	//   _قائل, едпа, rdų_, _idul_
  { {0x7e640065,0x224d000e,0x699f0037,0xaae70012}},	//   _skip, snek_, _ग्री, _يساو
  { {0xbddb0054,0xfe46048c,0x224d000e,0x61ed0845}},	//   rièn, енно, pnek_, keal
  { {0xd5ed0020,0x998d0002,0x6ec00011,0x8afa0009}},	//   _phá, nież_, _विरु, _מהעי
  { {0xdb070051,0xce360009,0xa5bb0097,0x61fb016d}},	//   hajä, תארת_, rhóp, mdul
  { {0xa9220028,0x853a000b,0x68320040,0x6a650097}},	//   _óþar, לגרי, _kæde, rófu
  { {0x91e60104,0x26cc0e0a,0xd6a80012,0x60db2626}},	//   нове, cudo_, _قديم_, ltum
  { {0xd5ed0020,0x11da0003,0x2bdf0037,0x60db0010}},	//   _thá, ثورة_, प्ता, otum
  { {0x2bd20037,0x0d860024,0x321d0034,0x63b5001b}},	// [68a0] सलमा, _ялин, _mowy_, bazn
  { {0xf3f10020,0x25dc0037,0x8d5b0009,0x7d042627}},	//   ột_, ग्री_, _מכפי, _iris
  { {0xf09f00c1,0x5693002d,0x60db015e,0xdb070051}},	//   _età_, гаєт, htum, gajä
  { {0x321d003e,0xe29b000b,0x60db0735,0x02460012}},	//   _nowy_, _משטר, ktum, _أَحَ
  { {0x6a650028,0xdd110060,0xbfc50030,0x8c460588}},	//   hófs, rüşe, _říšs, неде
  { {0xb8e60044,0xa7fc003a,0x3e580029,0xf1bf01bd}},	//   ैं_, rlık, dčte_, _zdá_
  { {0x46f4000b,0xfbd30009,0x6a650097,0xb5fb23e6}},	//   _בֶּן_, אתו_, jófs, slái
  { {0x93bc000d,0x61fb002c,0xcb130009,0x28c70011}},	//   _alăt, gdul, רלה_, _लिमि
  { {0x290010ac,0x29022628,0xfce30048,0x60db1f0e}},	//   nvia_, íka_, _йото, gtum
  { {0xdb06007d,0x26cc0017,0x53a60003,0xd575002d}},	//   ămân, tudo_, _أماك, _русь
  { {0xde59002d,0xd5ed001a,0x28c20011,0x63b507db}},	//   дані_, _nhã, _शिवि, vazn
  { {0x999f0029,0x11d60012,0x0ae90012,0x26c22629}},	//   tnuť_, _ستؤد, _تركي_, čko_
  { {0x7a230051,0x61ed002a,0x28f80015,0x645a0042}},	//   _mõtt, veal, _цель_, čtin
  { {0x00f7000b,0xaad40037,0x9f470029,0x76460010}},	//   _נמוך_, _धमाक, ľnú_, aiky
  { {0xdb580015,0x9f470029,0x2cea0037,0x7d0400ff}},	//   еют_, žnú_, टबॉल_, _eris
  { {0x7d04262a,0xa3d60037,0xfd26001a,0x3377000b}},	//   _fris, _हाथ_, _đình_, תעלם_
  { {0x7c2a0033,0x865c0009,0xc8c80011,0x2c690064}},	// [68b0] kkfr, _מדהי, िंगट, súdi_
  { {0xc058002d,0x6820006f,0x3e56001e,0x3a29021e}},	//   ніх_, _södr, māta_, skap_
  { {0xdcfd00a2,0xc5d5002d,0x2900004a,0xc7b3000b}},	//   ması, віль, avia_, רבע_
  { {0x7a3e0010,0xadbc002d,0x60db0010,0x69c30010}},	//   būti, зацi, ytum, ėnes
  { {0x3e560039,0x98a90002,0x999f0002,0x4e180003}},	//   nāta_, dzać_, ykuł_, عتمد_
  { {0x853c000b,0xdcfd003a,0xb4fc0009,0xf3f10012}},	//   הגדי, nası, פלור, شأت_
  { {0xdce4003e,0x2bd20037,0x42550014,0x660d0027}},	//   _dzię, _सारा, ктит, _onak
  { {0x00e50024,0x3e560035,0xaa56004c,0x682401a0}},	//   вжин, kāta_, кију_, _mòdu
  { {0x60db0006,0x93bc007d,0xac950014,0xdcfd003a}},	//   utum, _plăt, _разш, kası
  { {0x601e0066,0x7c2a190d,0x3e56001e,0xb97c0009}},	//   _námě, ckfr, dāta_, הנחי
  { {0x34d10037,0xcf92000b,0x9182001a,0xaac70003}},	//   _समुद, יטי_, iếm_, _ستان
  { {0x98a90002,0x27010010,0x32b80012,0x25e90011}},	//   czać_, _mėn_, _أدلة_, ज़गी_
  { {0xee37002d,0xdcfd003a,0x3e56001e,0x55ba000b}},	//   тня_, fası, gāta_, ומרו
  { {0x660d012e,0xa802003a,0x44630014,0x290000c1}},	//   _enak, şırk, ивяв, vvia_
  { {0xc64a0003,0xfbd2000b,0x2bd30037,0xc7d60009}},	//   _يجعل_, יתם_, _तारा, _יוסי_
  { {0xc332000b,0x2900262b,0x3e56001e,0xdb080064}},	//   בול_, _šiai_, bāta_, _jedá
  { {0x7bc1001c,0xa3c30037,0x6fd80011,0xd1860024}},	// [68c0] _odlu, ्ला_, _मामू, тлай
  { {0xddc20027,0xdb05031d,0x60c9262c,0x8fa60024}},	//   dloš, _behä, irem, таже
  { {0x9999000f,0x4444262d,0x7a3e001e,0x68fc001e}},	//   _első_, _im_, sūti, ārdi
  { {0x601e0066,0xdb080042,0x78bb01a3,0xe6c50012}},	//   _zámě, _nedá, ksuv, اتلي
  { {0x7a230005,0x7e6200b9,0xbddb0061,0x9597000b}},	//   _võtt, roop, xièm, דכנו_
  { {0x07a30098,0xdca30001,0xad650003,0x682d0029}},	//   _варн, шаљи, دامه, _súdn
  { {0x7a230051,0x99d60003,0x32b70003,0xdb050052}},	//   _tõtt, نتظا, ندية_, _gehä
  { {0x60f81438,0xda090037,0xf5060ac5,0xdce40002}},	//   ения_, वागत_, _избо, _wzię
  { {0x8e55002d,0xd1050011,0xbce50012,0xc05a0024}},	//   _стрі, रियण_, _مألو, дін_
  { {0x88bd003e,0x6e2002d1,0x98a90002,0x4444262e}},	//   myśl, _homb, szać_, _nm_
  { {0x61e6080d,0x6447001b,0x7a310248,0xdcfd0060}},	//   _obkl, viji, _låta, vası
  { {0xd36f0003,0x4444262f,0xa3d20011,0xc0aa0012}},	//   _بهم_, _am_, _वाँ_, _قاتل_
  { {0xecc70014,0xdcfd003a,0x64470027,0x44442630}},	//   ъщно, tası, tiji, _bm_
  { {0x63b80260,0x5c240012,0xa5bb0034,0x22980031}},	//   navn, لُّم, yków, _kék_
  { {0xdcfd00a2,0xc3480048,0xeb910009,0x1867004c}},	//   rası, вяте_, מָן_, _шаљи_
  { {0x444405ab,0xe5e90006,0x79a40047,0x660d0027}},	//   _em_, ämää, ируе, _unak
  { {0x497500b3,0xd6580009,0xa3d20011,0xdb070064}},	// [68d0] улас, _שיחת_, वला_, najú
  { {0x63b8012e,0xc6a70001,0x98170012,0x6ca40048}},	//   javn, врди, خبرا, _тръж
  { {0xdd910003,0xdb05006f,0x63b800eb,0xd084003c}},	//   موا_, _behå, davn, рыти
  { {0x74aa0037,0xdb070029,0x2906006f,0x44442631}},	//   जीकृ, kajú, _oroa_, _zm_
  { {0xb5fb000e,0x51870001,0xd4350012,0xc987004c}},	//   llás, _јуна, ُعتب, _јуни
  { {0x27fc091a,0x60c92632,0xdb070029,0x442b0015}},	//   _navn_, vrem, dajú, ьцем_
  { {0x2a6d0051,0x3cef0037,0xe1f10003,0xb5fb000e}},	//   tleb_, _इनके_, مسة_, nlás
  { {0x6e20000f,0xc1b90003,0x2a6d0051,0xe8f907ae}},	//   _gomb, رابط_, uleb_, ели_
  { {0xb5fb00f1,0x212900b6,0x60c92233,0x7d55004c}},	//   hlás, nyah_, urem, _свах
  { {0xa2ca0037,0xef190ba3,0x1db30011,0x6ff50048}},	//   संख्, емо_, ुणवत, учих
  { {0xe7f60044,0x99d50003,0x5f450012,0x2906008e}},	//   ीयता_, _مقات, انجل, _eroa_
  { {0xe80a0044,0xb6360003,0x23df0037,0x61fd2633}},	//   _होना_, اعدت, प्रद, _nasl
  { {0xd656000b,0x26de2634,0xdb1c0032,0x4421026f}},	//   רירת_, atto_, sgrü, _boh_
  { {0xd455002d,0xdb01024c,0xf3f1001a,0x68ee0031}},	//   атсь, _belø, ộp_, őidé
  { {0x88bd0034,0xe27a0048,0xf745003c,0x44442635}},	//   zyśl, ещаш_, _щеко, _vm_
  { {0xe8110011,0xc3320009,0x443301a0,0xc7080009}},	//   ़ावा_, זול_, _elx_, _יִפֹ
  { {0xb5fb2636,0x3fe60014,0x09f70012,0x6e202637}},	// [68e0] rlát, лжав, دفقة_, _romb
  { {0xdfd20003,0xdb030028,0xb5fb0028,0xe8160037}},	//   صيص_, danþ, slát, ताया_
  { {0x0dca0047,0xf989000b,0x3e56001e,0xdb070029}},	//   елей_, פר_, nāto_, zajú
  { {0xed5a0047,0x6e65002d,0x7afa0097,0xb5fb0031}},	//   ное_, атіж, ættu, llár
  { {0xc2130009,0x7a2a0097,0xa5070048,0xdb180032}},	//   _ההר_, _nýti, леца_, ngvö
  { {0xdb070029,0x70560003,0x61fd17dc,0x61e4171a}},	//   vajú, _إنسا, _zasl, lfil
  { {0x533404b3,0xbda60003,0xa6f8000b,0xd6f8000b}},	//   рейт, _محذو, _בִּי, _בִּש
  { {0xf7530003,0xd6eb0009,0x3e560035,0x48aa12fa}},	//   _انفج, _אַמָ, dāto_, нтом_
  { {0xc0340001,0x69d6000e,0x88bd0002,0x61e4057c}},	//   иниј, igye, byśm, ifil
  { {0xdb0e13b8,0xa3ba0012,0x00f70009,0xd0f70009}},	//   zabá, _سائر_, נזים_, נמית_
  { {0x9b930351,0x3393000a,0xab930003,0x74130003}},	//   _المت, _المز, _المغ, _دولا
  { {0x44380052,0xdd910003,0x7a350066,0x7c2e0227}},	//   ehr_, توح_, _páte, ekbr
  { {0x673a000f,0x78a200b0,0x15f40011,0x7c38005e}},	//   sztj, _utov, इज़र_, ohvr
  { {0xb4e50037,0x961d001e,0x201a005e,0x3e560035}},	//   _नही_, _viņi, _õpi_, bāto_
  { {0xf8bf0013,0x61fd007a,0x0cd10044,0x62980061}},	//   _své_, _pasl, _सम्म, _évol
  { {0x53340406,0xb5fb000e,0x61e41a0e,0xf9930012}},	//   щест, rlás, gfil, صبر_
  { {0xb6a50020,0xa567000a,0x442100b6,0x7e93000d}},	// [68f0] _luậ, _حدثن, _toh_, _răpi
  { {0x57b4002d,0x61e40051,0xb5fb0028,0x661d013a}},	//   йбут, afil, plás, ljsk
  { {0x8db5002d,0x26110037,0x61fd003a,0xf1b9009b}},	//   аслі, णाली_, _tasl, ljše_
  { {0xddc20002,0x753d0002,0x661d013a,0xe4d50012}},	//   mnoś, ozsz, njsk, لتتب
  { {0xddc2003e,0xdb0e0028,0x7c2100b6,0xf1b92638}},	//   lnoś, gabæ, _polr, njše_
  { {0x39440097,0xc49c0009,0x4c9c0009,0x000000c4}},	//   _ýmsa_, עשות, עשוע,
  { {0xf991000a,0xea590001,0xddc20002,0x2903001e}},	//   يبة_, криј_, nnoś, ājam_
  { {0x3e56001e,0x89a60014,0xd2510003,0x60cd2639}},	//   vāto_, акъв_, تنع_, oram
  { {0xa3d60044,0x3d0f0044,0x26cc0164,0x7d16008e}},	//   _हाल_, ामों_, erdo_, äyst
  { {0xaae7000a,0x09b20044,0x94770003,0x99890029}},	//   _مسؤو, _ज़्य, _إدرا, chať_
  { {0xddc20002,0x61e40672,0xc2c40012,0xc7d60009}},	//   jnoś, yfil, _هيلي, בותי_
  { {0xddc2003e,0xe5670003,0x4a9a000b,0x764b002c}},	//   dnoś, قط_, _סינג, nigy
  { {0x99830010,0x7c660003,0x361a0009,0x9f4c00b8}},	//   ėjų_, لاسل, דורד, ledì_
  { {0xa93a000b,0xddc20002,0x913a0009,0xdddd0034}},	//   _שתספ, fnoś, _שעסק, gosł
  { {0xc9b60001,0x290f006f,0x3e7c01bd,0x7f160012}},	//   исањ, ågan_, líte_, _نيوز_
  { {0x98a2007a,0xc332000b,0x60cd263a,0x644a0df0}},	//   šką_, קון_, fram, zifi
  { {0xada90003,0x87ba0015,0x9f470029,0xe8fa0014}},	// [6900] _صديق_, вует_, ľný_, ъла_
  { {0x9f4701bd,0x30f80011,0x1cbb0009,0xe7320012}},	//   žný_, ्टतः_, _שמיע, يصا_
  { {0xd7dd0037,0x30750015,0x628f0017,0xddc20002}},	//   _मानच, сутс, _fico, cnoś
  { {0xa3d60037,0xb2bb000b,0x5de60063,0xade50024}},	//   _हाँ_, _במטר, ржда, йцік
  { {0xdb03263b,0x25a901e3,0x7d09263c,0xad9b0097}},	//   raný, ñala_, _cres, ndúa
  { {0x04430046,0x0ec50037,0x3e7c014a,0x8c430001}},	//   жељн, _विंड, díte_, жеље
  { {0x764b0101,0x661d0002,0xc5d6002d,0x7d0910f7}},	//   bigy, yjsk, _візь, _eres
  { {0xe80a0044,0x0a6a0014,0xd627004c,0xdb080248}},	//   _होता_, ърли_, _косе_, _nedå
  { {0xd0100003,0x1da70037,0xa3d6159f,0xca370009}},	//   كلة_, _क्षत, हला_, ינקה_
  { {0x91a60044,0xd7f0000a,0x29000010,0x44e000b8}},	//   _ट्रै, أكد_, _šias_, mò_
  { {0xdc3b000b,0x44e2001a,0x01da0003,0x7d090002}},	//   _שעבר, _hư_, _لوضع_, _zres
  { {0x3e7c119d,0x63bc0132,0xdddd0034,0x6aaa0032}},	//   bíte_, earn, wosł, mpff
  { {0xdce00039,0x628f1d54,0xddc20002,0x62840002}},	//   _izmē, _rico, wnoś, dmio
  { {0xddc20002,0x78a9003a,0x645500c1,0x63bc263d}},	//   tnoś, _çevi, unzi, garn
  { {0x807b000b,0xdddd0002,0x600b000b,0x78a60028}},	//   _שנוצ, rosł, _יִהְ, _atkv
  { {0x80c20037,0xddc20002,0xbdb50001,0x0dcb01d4}},	//   _लिखे, rnoś, _убиј, _руки_
  { {0x5fdd0044,0xddc20002,0x5187059a,0x98ad0034}},	// [6910] _मामल, snoś, рува, rzeć_
  { {0x60cd060e,0x9f470164,0x25e30011,0x7d0900b8}},	//   rram, _ganó_, ट्री_, _rres
  { {0x2bf6000b,0xda670003,0xf09f001a,0xf7700003}},	//   _המתן_, _ناحي, _trào_, وام_
  { {0x60c20027,0x9e090012,0x7a3c0031,0x9f4c00b8}},	//   _ovom, طيتك_, _hétf, vedì_
  { {0xaca30020,0x44e2001a,0x787d0061,0x5a160009}},	//   _trọn, _cư_, lève, _הקרן_
  { {0x44e2001a,0x7a380066,0xe8df001a,0xa444002d}},	//   _dư_, _víte, _chục_, онід
  { {0xad9d0002,0xa3dc0037,0xcef40012,0x5c380009}},	//   _paźd, ण्ट_, _وأفغ, שרון_
  { {0x61e90051,0x3e7c01bd,0xe1f9150a,0x6b7c0009}},	//   _öeld, títe_, уги_, כרונ
  { {0x3978003c,0xe534003c,0x44e000b8,0x7d090159}},	//   исью_, _деть, cò_, _ures
  { {0x78700006,0x12e7002d,0x68450015,0x3e7c0029}},	//   tävi, _відг, ённа, ríte_
  { {0x3e7c00f1,0x78a902e7,0x5b340012,0x9e660048}},	//   síte_, spev, _وعمر, йвод
  { {0x51950003,0xb9950003,0x4425000e,0xdb150bb3}},	//   _الإذ, _الإب, _hol_, gazí
  { {0x4425007a,0x8996000b,0x99850003,0xc2030037}},	//   _kol_, _הכנס_, _الشو, _शोएब_
  { {0xad1a0009,0x03a309c6,0xd12e0012,0x5d7a0009}},	//   אושר, зиро, _سمى_, טארק
  { {0x9f950051,0xcc760009,0x1dd80011,0xd2990024}},	//   _müük_, מעשה_, _डालत, итті_
  { {0xd9f90044,0x224d263e,0xb87b0064,0xdb1d0031}},	//   ्यित_, niek_, _opís, úzás
  { {0x3ae10065,0xdb180017,0x66000002,0xc7960012}},	// [6920] hóp_, ravé, _ramk, مشاب
  { {0xdb01000f,0x66000065,0xc172000b,0x60cb0028}},	//   _belü, _samk, לחן_, ágma
  { {0xdfa50003,0xc3fb000b,0x44e2001a,0xd9f90011}},	//   تحقي, _גליש, _sư_, ्यात_
  { {0x6d030044,0x05ba000a,0x75d30012,0xadb70012}},	//   लिंग_, ادات_, كيما, مهما_
  { {0x44250026,0xe8df0020,0x44e000c1,0x61f6003a}},	//   _bol_, _phục_, uò_, meyl
  { {0x6fd5007c,0xdb01000f,0xa5c60002,0x7fd5002d}},	//   _місц, _felü, dróż, _місі
  { {0x224d0070,0x539b007e,0xa3d60011,0x68e4263f}},	//   fiek_, ניקו, _हाई_, ltid
  { {0x44e20020,0xcb13000b,0x6480004a,0xdb1f0066}},	//   _tư_, ללו_, löid, ívát
  { {0x8a17000b,0x859b0009,0x3cf40011,0xb113003c}},	//   מחקו_, _תשמו, ेटों_, змыш
  { {0x7e6d0163,0xd4910020,0xdb010002,0xb3e90003}},	//   _skap, _gì_, _celó, _نعمل_
  { {0x68e40051,0xb4e80037,0xc7b30009,0xb05b0248}},	//   htid, _बहु_, הבת_, _ovän
  { {0x68e40005,0xb05b006f,0x98c4003a,0x4b7b0009}},	//   ktid, _nvän, ştık_, _גאבו
  { {0x412a007c,0x62650003,0x4425003a,0x7e93000d}},	//   _щодо_, _بالق, _yol_, _săpt
  { {0x6480004a,0x3940001e,0x9f340024,0x22950048}},	//   jöid, dzis_, _мелі, живя
  { {0x63ba00a2,0xf1b902a1,0xe81c0011,0x629a2640}},	//   _metn, ljša_, नाना_, _juto
  { {0x0f57000b,0x31790002,0x644e002c,0x7a350074}},	//   _ליום_, ższe_, aibi, _látn
  { {0x32070013,0xe918002d,0xf1b9009b,0x644e0175}},	// [6930] ěny_, боті_, njša_, bibi
  { {0x644e02d1,0x224d0070,0xddc90029,0x7538000b}},	//   cibi, ziek_, _zmeň, _לאחד_
  { {0x2baf01e1,0xd7590012,0x7e2b0024,0xe7ea0011}},	//   _ज्या, جلات_, ліда_, ज्या_
  { {0xdb01000e,0x25e10037,0x44252641,0x6f790009}},	//   _velü, _काफी_, _sol_, בְנו
  { {0x224d0029,0x6fb50012,0x99870073,0x290b004b}},	//   viek_, _ومحا, ėnų_, _urca_
  { {0xb87b0029,0x9cd8000b,0xdb1c0052,0x224d0002}},	//   _vpís, מודה_, rgrö, wiek_
  { {0xd4910020,0x224d2642,0x1635003c,0xdb010018}},	//   _vì_, tiek_, _девя, _reló
  { {0x200300c6,0xa4d5002d,0x644e000d,0xd7d90037}},	//   _haji_, _мобі, zibi, _ढाँच
  { {0x54550014,0x23690002,0x9f530025,0x2003016d}},	//   _дват, łaj_, dexé_, _kaji_
  { {0xe045002d,0x752f0002,0x9f580164,0xe81c0011}},	//   інни, dycz, _hará_, नाया_
  { {0x7d0d00a2,0xa6fb0009,0xfbd30011,0x764f0034}},	//   _aras, רִ֖י, _ताजम, ficy
  { {0x1d0a0014,0x366a0001,0x7d0d2643,0xa50a0148}},	//   аеми_, рамо_, _bras, аема_
  { {0x1ddb0044,0x3e56001e,0xbddb0054,0x2be00037}},	//   _भारत, nāti_, vièt, _नामा
  { {0xb05b006f,0x69db2644,0xf0640024,0x88bd0034}},	//   _svän, lgue, _екіп, wyśw
  { {0x78ad0010,0x7d0d0ffa,0x6e460012,0x26c7001b}},	//   epav, _eras, _ونتم, šnoj_
  { {0x3ebe0065,0x644e2645,0x69db2646,0xf6b60009}},	//   _ætti_, sibi, ngue, _והקש_
  { {0x7a35000f,0x9f5801a2,0x60250066,0x61e90052}},	// [6940] _láto, _sarà_, _témě, ifel
  { {0x63660029,0xdb080029,0x3940000d,0xaf360012}},	//   nčné, _vedú, rzis_, يرات
  { {0x660403fc,0xbddb0108,0x63ba0989,0x44e4004a}},	//   _kaik, mièr, _retn, lö_
  { {0xf1bf0020,0xbddb0108,0x63ba2647,0x61e90227}},	//   _hoán_, lièr, _setn, jfel
  { {0x3e56001e,0xdb151f13,0x660414d5,0x99f70009}},	//   gāti_, mazá, _maik, _וזכה_
  { {0x66041735,0xbddb0061,0x200300b6,0x139a000b}},	//   _laik, nièr, _gaji_, ׁבְע
  { {0x752f003e,0x7a3c000e,0x34b70037,0x539b000b}},	//   zycz, _léte, _अब्द, ביצו
  { {0x61e9000f,0x1cba0003,0xa9c3002d,0xa2260003}},	//   gfel, _نائب_, мськ, ترته
  { {0x3ea9001e,0x32020029,0x3e7208ca,0x60c42648}},	//   _čata_, ľky_, nátu_, nsim
  { {0x32020107,0xc173000b,0x9f4a0061,0x7b160012}},	//   žky_, וחח_, _abbé_, _وظائ
  { {0x09e6064f,0x907b000b,0x752f0002,0x6604055c}},	//   _можн, שטיי, wycz, _baik
  { {0x752f003e,0x98b2003e,0xe81c0011,0xd2520012}},	//   tycz, czyć_, नाडा_, _تنص_
  { {0x7bdc0052,0x5c070232,0x78ad01bd,0x3ce62649}},	//   fgru, оява, čový, ntov_
  { {0x26c70026,0x212b008b,0x7a3c0108,0x752f0002}},	//   ánok_, äche_, _déte, rycz
  { {0x8c1b000b,0x0dcb0345,0x752f0002,0x43940abb}},	//   סולי, _купи_, sycz, дарс
  { {0x99990014,0x3ce618b7,0x7d0d264a,0x5e440012}},	//   скат_, ktov_, _tras, _يَوْ
  { {0xcf9b0046,0x7c3a00c1,0x60c4264b,0xdb181ba5}},	// [6950] аје_, _oltr, gsim, daví
  { {0x7c280039,0x2909004a,0x3e560035,0x87d70012}},	//   _nodr, rvaa_, vāti_, تغرا
  { {0x629a000f,0x23fa000b,0x56950015,0xabfa000b}},	//   ítot, _ההתא, чает, _ההתר
  { {0x3e560039,0xfad6000b,0xcad6000b,0x7c3a13de}},	//   tāti_, _צורך_, _צורת_, _altr
  { {0xd5380012,0x721a0009,0xe45f0248,0x6ca40012}},	//   يثها_, _הורח, bröt_, وصول
  { {0xb4fc000b,0xb09a000b,0x03a50021,0x9cd80009}},	//   יפדי, _לישר, чико, קווה_
  { {0x68f9003a,0x7c2801bd,0x45f70012,0xbef80012}},	//   şadı, _dodr, _وأرس, _ورفض_
  { {0x62821c02,0x69c0218f,0xc1050012,0x7a350031}},	//   _choo, game, كوبي, _gátl
  { {0x98b2003e,0xc3cb000a,0xe8e0001a,0x6a640003}},	//   rzyć_, _نظام_, _đợi_, بطول
  { {0x98b20002,0x2d9e0066,0x6e3b0066,0x7a3c014e}},	//   szyć_, ětem_, _hlub, _réte
  { {0xe298002d,0xfd4d001a,0xbddb0061,0xdb1c0061}},	//   _дає_, _triệ, vièr, paré
  { {0x7c280070,0x200304d2,0x60c40079,0x8f1a0009}},	//   _zodr, žji_, ysim, צורת
  { {0x9cd50093,0xc19a0093,0xbddb0061,0x7a7a000b}},	//   הוָה_, _השני, tièr, _פרנס
  { {0xb0680003,0xc004002d,0x86c50012,0xe3a70012}},	//   _وصول_, _опік, _فيتن, عر_
  { {0x6604007a,0xbddb0061,0x44e4004a,0x261c0011}},	//   _taik, rièr, sö_, यादी_
  { {0x7a3c000e,0x28c70037,0x3e721d3d,0xaea80012}},	//   _téte, _लिखि, gátt_, _بطول_
  { {0xf1bf0020,0x60c4007a,0xb1460014,0xf6530009}},	// [6960] _toán_, usim, чнал, _רצח_
  { {0x3e72022d,0xaf9a01d4,0xb7da0012,0xa803004c}},	//   rátu_, стах_, صوصا_, нзул
  { {0x9f580054,0xdfcf0003,0x60c4264c,0xbf79001a}},	//   _març_, طين_, ssim, _đuốc_
  { {0xc869000b,0xfe720012,0x99890159,0x98a40073}},	//   אן_, ردا_, skaš_, lymą_
  { {0x10a30048,0x200c0018,0xdb180042,0x53980223}},	//   _пиян, _ódio_, raví, овля_
  { {0xd499002d,0x26c50010,0x04430021,0x9cd7000b}},	//   ірі_, kslo_, нечн, פוצה_
  { {0x78a900a2,0xcb070003,0xf4130009,0xd9f90011}},	//   _çevr, كيون_, תפו_, ्यंत_
  { {0xaf5b000b,0x85e70014,0xad660012,0x71460048}},	//   _הכלכ, _ндсв_, _فاذه, зхож
  { {0x3e560039,0xa3dd0037,0x98a40010,0xb17b16d1}},	//   nātu_, _डाल_, kymą_, _ubåt
  { {0xdefa0015,0x73e30001,0x320a0002,0x69c0264d}},	//   бым_, _поуз, śby_, same
  { {0xb5fb000f,0x98a40010,0x4e000011,0xed59264e}},	//   mláz, dymą_, _ईसाई_, _veže_
  { {0x0f57000b,0x3ebe0028,0x7a35000e,0x31790002}},	//   ליים_, _ættu_, _látj, ższa_
  { {0xab630034,0xe2450012,0xed590412,0x786f09bc}},	//   ężen, _تخلي, _teže_, røvr
  { {0x2903001e,0x2d800034,0x3e560035,0x78fb0009}},	//   ājat_, _dzie_, dātu_, _לפדו
  { {0xcc77000b,0xddc21740,0xb07b0009,0xa87b0009}},	//   פעלה_, dlož, _הנגז, _האגר
  { {0x1f5b0009,0xa75b0009,0xaf5b0009,0x629e264f}},	//   _לדוא, _לדור, _לכוכ, _dupo
  { {0x236d0002,0xdb1a0018,0x7e6e0034,0x3e720097}},	// [6970] łej_, _deté, łopó, rátt_
  { {0xf9900003,0xdfd10003,0xed580009,0xe53c0009}},	//   طبق_, ئيا_, _מבחר_, _לתחר
  { {0x26c70013,0xfbd2000b,0xa3c20037,0x48f90037}},	//   éno_, _בתי_, ्णन_, _उनको_
  { {0xdd910003,0x3e56001e,0x9d550012,0xe9190024}},	//   نوا_, bātu_, ونات, _домі_
  { {0xd5fb008a,0xdb01000f,0xe534002d,0x3e7c0066}},	//   _chú, _jelö, нець, mítl_
  { {0x3e48000f,0x61e22650,0x61ed2651,0x765d0602}},	//   lőtt_, _acol, lfal, hnsy
  { {0xd5fb001a,0x6e290227,0x32092652,0xdc8c0009}},	//   _thù, _toeb, oday_, צְדָ
  { {0x394d0065,0x6e3b0002,0x61ed2653,0x80a900b3}},	//   _þess_, _ulub, nfal, овив_
  { {0x7fd5007c,0xb5fb000f,0xa4d4002d,0xe7d50024}},	//   міні, bláz, _поті, міню
  { {0x6025002d,0x69c6000e,0x61ed0032,0xb0240081}},	//   єдна, óker, hfal, _phườ
  { {0x5b250012,0x73c40012,0x7b350012,0x7bc32654}},	//   _تفضل, _سينم, _تفاؤ, manu
  { {0x200b0656,0x26c5007a,0x7bc10028,0xee370024}},	//   ści_, rslo_, ðlun, дню_
  { {0x98a40010,0x25ef0037,0x2b5a0029,0x29030035}},	//   tymą_, ेज़ी_, ĺpce_, ājas_
  { {0xb0240020,0xb4fa000b,0xe29a027f,0x889a0009}},	//   _thườ, חפשי, жав_, _ובסי
  { {0xe7e2015f,0x09e6002d,0xfc030014,0x91e60365}},	//   _खाता_, мовн, ъпро, мове
  { {0x11da0003,0xed5a00de,0x61ed2655,0xdb010031}},	//   تورة_, _мой_, gfal, _felö
  { {0xdb010052,0x7bc8000e,0x20071cb9,0xa0c90012}},	// [6980] _gelö, ódus, _kani_, كذلك_
  { {0x7a3803eb,0x7a3c0061,0xf9910012,0x61e9005e}},	//   _títo, _méta, ابِ_, _öeln
  { {0x49ba000a,0x4ea5002d,0x68e90051,0x20072656}},	//   _واحد_, еріа, hted, _mani_
  { {0x2ca00005,0x68e900a2,0xd5fb001a,0x3e560035}},	//   _kuid_, kted, _phú, māts_
  { {0x8c460014,0x25e30037,0xdca305fb,0x64a30024}},	//   меде, ट्टी_, вачи, вача
  { {0x2ca00051,0x93c5001a,0x69c42657,0xad650012}},	//   _muid_, _nhằ, laie, رانه
  { {0xae0e015f,0x3e560039,0x4e0e0037,0x160e0037}},	//   ियान_, nāts_, ियाई_, ियार_
  { {0xd5fb001a,0x69c40061,0x38a417d4,0x7a3c18ac}},	//   _thú, naie, _kör_, _béta
  { {0x200700e7,0x3d180011,0xdb1c242b,0x68e90040}},	//   _bani_, दमों_, darí, gted
  { {0xdfd0000a,0x7a35000f,0x7a3c0108,0xa0670001}},	//   ديد_, _láth, _déta, мања_
  { {0x61ed00a2,0xdc8b000b,0x6d670010,0xdb1c0028}},	//   yfal, _וְאָ, ąraš, farí
  { {0x9980007a,0xa4d5002d,0x3e56001e,0x68e90132}},	//   nkių_, номі, dāts_, bted
  { {0x09360003,0xca37000b,0x442c2658,0x01360012}},	//   _تراج, _קנדה_, _kod_, _تعاد
  { {0x2056002d,0x3ff40012,0x7a310248,0xd007004c}},	//   _ютер, _أكثر, _lått, _жеље_
  { {0x7d0401a2,0x61ed05df,0xc108001a,0x442c2659}},	//   _esis, tfal, _hỗ_, _mod_
  { {0x38a40163,0xdb240031,0x442c265a,0x7a310248}},	//   _bör_, úrás, _lod_, _nått
  { {0xe9ff001a,0x2007003a,0x764200b6,0x261c0037}},	// [6990] hiến_, _yani_, dhoy, यारी_
  { {0xdb18000f,0x25bf0061,0x3e56001e,0xdb080052}},	//   zavá, _seul_, bāts_, _bedü
  { {0x2cad0989,0x2ca00070,0x4439001e,0xc1080081}},	//   _sted_, _zuid_, _ēs_, _lỗ_
  { {0x38a401ab,0xb8820066,0x9757000b,0x6480008e}},	//   _för_, řípa, ויבו_, nöin
  { {0x38a40163,0xc108001a,0xfe700003,0x4fc7096e}},	//   _gör_, _nỗ_, جدل_, _осва
  { {0xd378003e,0x442c007d,0x25b2003a,0x7a3c0061}},	//   _być_, _cod_, ıyla_, _réta
  { {0x2be00037,0x442c265b,0xc5fb0012,0xaac40012}},	//   _नारा, _dod_, _وعرض_, نتين
  { {0x6455000d,0xb9050001,0xdb1e0054,0x7bc32466}},	//   hizi, език, _depè, sanu
  { {0xe8f60015,0xd49b002d,0x2d5801ec,0xdb1c01e3}},	//   елы_, _єра_, _жить_, varí
  { {0x60db0051,0x442c265c,0x26c700d9,0x87250024}},	//   ruum, _god_, šnou_, емож
  { {0x7a350028,0x29020028,0x645515aa,0xa7fc003a}},	//   _láti, ækar_, dizi, nlıy
  { {0xdd12003a,0xd3360009,0x82f80012,0xeaf80012}},	//   nüşt, _ארעה_, _تركز_, _تركت_
  { {0x6455008b,0x7bc100c6,0x91ba000b,0x98e50003}},	//   fizi, _kelu, _זמני, _أكتو
  { {0x31560093,0x443e000f,0xe8d6000b,0x66090051}},	//   _אינן_, ót_, _נוצר_, _laek
  { {0xe80a0044,0x442700bd,0x6d460002,0x8b040066}},	//   _होगा_, ijn_, szka, ěřov
  { {0x60d6006f,0xdb26000e,0xe1ff0028,0x7d040010}},	//   trym, _épít, _skór_, _tsis
  { {0x44e90026,0xe0da1932,0x69c40061,0x8c96002d}},	// [69a0] jú_, ява_, raie, _проі
  { {0x69c40061,0x44e90029,0xb9080011,0x60c9265d}},	//   saie, dú_, _यम_, isem
  { {0x9b460012,0x88bd0034,0x69c4265e,0x442c265f}},	//   _أنجو, zyśp, paie, _rod_
  { {0xdb1e0025,0x8b570009,0x443e016d,0xe4c60337}},	//   _repè, _טייס_, _slt_, ейди
  { {0x7bc100c6,0x65940001,0xd6570009,0xc19b0009}},	//   _belu, њалу, עינת_, _משכי
  { {0xa3ab0037,0xdee606fd,0xa2a40011,0x7bc12660}},	//   कुल_, _поги, _चंद्, _celu
  { {0x3e75021e,0x7bc12661,0x25e10011,0x8cc10011}},	//   tått_, _delu, _काली_, रीबो
  { {0x99890026,0x6fdd0011,0x2a60005e,0x64430064}},	//   skať_, _माउं, nnib_, ahni
  { {0x0d860046,0xe2130003,0x1e57000b,0x442c0052}},	//   _члан, طبيع, _נשמר_, _tod_
  { {0x6aa1002a,0x7bc104a3,0x63b301bd,0x98f30012}},	//   _fulf, _gelu, čení, اثيا
  { {0x0857000b,0xa2e50003,0x8c2b0009,0x268a0009}},	//   תבים_, _لأنن, _מֵאֵ, ּנָּ
  { {0x11e90003,0x8b3b000b,0x200a001e,0xbb3b0009}},	//   _يعني_, _מתבצ, _labi_, _מעבי
  { {0x6480004a,0x0cab0048,0x94ab0148,0x645503c4}},	//   röin, ятни_, ятна_, tizi
  { {0x200a00c6,0xb3e00037,0x711b0009,0xd91b0009}},	//   _nabi_, नलिख, _מודפ, _מודל
  { {0xa6c70003,0xad9b0017,0x64552662,0x9b680476}},	//   _كوول_, teúd, rizi, ешта_
  { {0xa3dd0044,0x645501a2,0xb77b000b,0xa8a70803}},	//   _डाक_, sizi, _מאוש, ержк
  { {0xdb1c0017,0x200a00b6,0xb4df0011,0x90990048}},	// [69b0] tarã, _babi_, _थमे_, дват_
  { {0x44e90026,0xb8810066,0x7d7c0009,0x2a60005e}},	//   vú_, _říze, _צנזו, anib_
  { {0xd6db0019,0x78a2004a,0x26de2663,0x6fe20011}},	//   ята_, _luov, nuto_, _पारं
  { {0x7bc100c6,0xdb050d4a,0x44e90fe1,0x12e80009}},	//   _selu, _behö, tú_, _אַשּ
  { {0x78a201a2,0x40950003,0x7bc12664,0xdb1e0025}},	//   _nuov, _للحر, _pelu, _repé
  { {0x44e913b0,0x2ef50146,0x200a002c,0xdb1808af}},	//   rú_, _изгр, _gabi_, kavä
  { {0x7bc10065,0x68ed0583,0xf1b9009b,0xe452007e}},	//   _velu, ltad, ljši_, יֶה_
  { {0x60c902bd,0x44e9000e,0x7a3c0061,0x26de0e7c}},	//   tsem, pú_, _déto, duto_
  { {0xdb05008b,0x60c90061,0xf1b9009b,0xe9a80003}},	//   _gehö, usem, njši_, ردين_
  { {0x7bc70e6f,0x6c970012,0x68ed2665,0x04c80012}},	//   jaju, _أشرط, itad, _أولي_
  { {0x68ed0051,0x7bc70027,0x60c92666,0xdbf90034}},	//   htad, daju, ssem, _włók
  { {0x60c90051,0xe736002d,0x68ed2667,0xdb1c097c}},	//   psem, тею_, ktad, jará
  { {0xdb1c02ea,0xc0e50b2b,0x26de2668,0xab5c07ee}},	//   dará, _ролк, auto_, _ieļa
  { {0x3949001e,0xb5fb0066,0x2bba0012,0xc7a204a5}},	//   dzas_, tnác, باحة_, _кишк
  { {0x200a2669,0x629c0025,0xfaa6266a,0x7fd600af}},	//   _rabi_, _érot, табо, _סוקס_
  { {0xf2d2000b,0x66f60009,0x68ed03ad,0xdb1c097c}},	//   יעל_, _ימצא_, ftad, gará
  { {0xa3d10011,0x3e4f0034,0x71a309f8,0xfd120012}},	// [69c0] _वयं_, jęty_, рауз, _ضجة_
  { {0xd9430001,0xfd5f001a,0x937a0012,0x6843004c}},	//   јефи, huyể, _يصدر_, ануа
  { {0x76a9002d,0x7a380028,0xd62a01b6,0x290f0248}},	//   етів_, _líti, може_, ågar_
  { {0xee3a002d,0x75d30003,0xadb70003,0xed5a0015}},	//   ьне_, ليما, نهما_, мое_
  { {0xd4e30047,0x39490002,0x3e7c000e,0x200a0b70}},	//   ающи, czas_, níti_, _tabi_
  { {0x61e400a1,0x0fda0003,0x5c73002d,0x07a60001}},	//   lgil, _تبحث_, аліт, _јавн
  { {0xfbd3000b,0x7a3501cf,0x61e4005e,0x5c5b0009}},	//   בתו_, _látu, ogil, ודסק
  { {0x26de01a2,0x22810028,0x61e4266b,0x6cd60012}},	//   vuto_, sókn_, ngil, _لقرا
  { {0x6c060001,0xc27b000b,0x7a3801e9,0xa6970009}},	//   _изаз, ורקי, _cíti, _יכלה_
  { {0xdb1c1ba4,0x25a0016d,0x9f4500b8,0x26de266c}},	//   zará, _agil_, velò_, tuto_
  { {0xb7db000b,0x7bc716a0,0xf8370009,0x2bdc0011}},	//   וקיי, vaju, דנית_, _बाजा
  { {0xf773000b,0x79a30001,0x200a013a,0xd3370009}},	//   יקת_, _крше, žbi_, _שראה_
  { {0x7d160611,0xadf40011,0xdb18005e,0xd7e20011}},	//   _crys, ेज़न_, savä, _पांच
  { {0xd00f0003,0xe45f006f,0x7a35117f,0x00f7000b}},	//   _ولن_, msök_, _dátu, _סמוך_
  { {0x7bc7001c,0xe81f0037,0xdcc8001a,0x82a40001}},	//   raju, बारा_, hỉ_, иште
  { {0x7bc7007d,0x7d16266d,0xb7970009,0x68ed266e}},	//   saju, _frys, _בכוח_, ttad
  { {0xdb1c0164,0x7a350028,0xa294002d,0x68e0003a}},	// [69d0] rará, _gátu, раті, numd
  { {0xc104000a,0xad1a000b,0x39490164,0x351a000b}},	//   ؤولي, _נותר, rzas_, _נותנ
  { {0x95d90015,0x533509c6,0x660d13dd,0xc5d50024}},	//   едет_, _сент, _kaak, гіль
  { {0xe7ff0037,0xd2460012,0x68e00035,0xbb3a0009}},	//   _उसका_, _طن_, kumd, _נערי
  { {0x89da0093,0x58d40098,0xd7f1001a,0xd1260003}},	//   _אחרי, _коят, hĩa_, _ام_
  { {0x69c60065,0x6458006f,0x7a35266f,0xc4f80012}},	//   ðken, givi, _látt, ضعها_
  { {0x6e3d0033,0x9be4002d,0x7a380017,0xe45f006f}},	//   kksb, річк, _síti, esök_
  { {0x60cd2670,0x96f80103,0x8cc50012,0xb05b008e}},	//   osam, _шест_, _مقره, _evät
  { {0x3d94007c,0x60cd2671,0x64580051,0xd059002d}},	//   _витр, nsam, bivi, ерні_
  { {0xb97c000b,0x7d090051,0x7b08004a,0x7a380017}},	//   ונחי, _ises, ästä, _víti
  { {0x6d68000d,0xe739019c,0x339b00ae,0x000000c4}},	//   ăsaţ, хен_, _آخذة_,
  { {0x20cf001e,0x09e40024,0xd62a0024,0x6480008e}},	//   kļi_, _воїн, хоме_, röim
  { {0x681b001e,0x7bc500c7,0x61e40060,0xee370198}},	//   _kādē, _behu, vgil, уня_
  { {0xd0060098,0x3b0a0015,0x96000011,0x60cd2672}},	//   _беше_, него_, _ईस्ट_, dsam
  { {0x3e7c000e,0x629d00ba,0x61e42673,0x60080009}},	//   síti_, _biso, tgil, _יִקְ
  { {0x6e3d0b5a,0x3e7c000e,0xda650012,0x9695003c}},	//   cksb, píti_, لاقي, _крыш
  { {0x7afb000d,0x3e790028,0x60cd2674,0x61e42675}},	// [69e0] ăuta, rétt_, gsam, rgil
  { {0x660d003e,0x8406002d,0x2ca40097,0x7bc502a2}},	//   _zaak, _спож, ímdu_, _gehu
  { {0x44442676,0x7d090164,0x7644002c,0x7a35000e}},	//   _il_, _ases, _kliy, _játs
  { {0x5d6a0047,0x4422000e,0x64a600b3,0xb05b0029}},	//   нием_, _ők_, гада, _svät
  { {0x7a35000e,0x6c9a0009,0x89360012,0x20170031}},	//   _láts, ֲשֶׂ, _إعجا, íció_
  { {0x60db000d,0x7e62004a,0x444400b6,0x07a30400}},	//   drum, snop, _jl_, _гарн
  { {0x69c600c6,0xb05b004a,0x9f4a004a,0xb5fb19d5}},	//   _keke, _eväs, äjän_, dnán
  { {0xdd080026,0x80cf0037,0x60f80014,0x44442677}},	//   môže, _दिखे, вния_, _ll_
  { {0xdbf90002,0x64580872,0x660d13f2,0xc4860024}},	//   głów, pivi, _raak, _блак
  { {0xe45f0163,0x68e000a2,0x3cfb000b,0x660d01a3}},	//   rsök_, rumd, _אלמנ, _saak
  { {0x04930003,0x3ad30012,0x69c60227,0x22810031}},	//   _اللح, _هيلز, _oeke, iókj_
  { {0xd6d70047,0xdb08006f,0x6ce70024,0x9f5e0025}},	//   ыть_, _bedö, ліге, neté_
  { {0xd24f000a,0x629d01a2,0xd657000b,0xdca60003}},	//   _عنه_, _riso, ריכת_, تى_
  { {0xf993000b,0x9f5e0025,0x76590034,0xd7f8004b}},	//   _פרס_, heté_, ziwy, onăm_
  { {0xab952678,0x8c1b0009,0x69c62679,0x629d267a}},	//   рављ, עולי, _beke, _piso
  { {0xf12700e3,0x5398002d,0x200e0028,0x7a35000e}},	//   льзо, увся_, _hafi_, _hátr
  { {0xd49b00bc,0x60cd0052,0x2bcb0001,0x6280173a}},	// [69f0] _про_, usam, _пуно_, ilmo
  { {0xee3f0066,0x67d50024,0xf9880012,0x6480008e}},	//   lký_, рожу, انكي_, jöih
  { {0x629d009b,0x4c9a000b,0xb8680001,0xcdd5000b}},	//   _tiso, _שבתו, ујте_, ֹךְ_
  { {0xb5fb0066,0x69c60832,0x60cd267b,0x3aba0009}},	//   znán, _geke, psam, _שמרנ
  { {0x1d0907ae,0xb05b0248,0x644b0073,0xfbc50a41}},	//   тели_, _dvär, _įgij, абло
  { {0x69c600bd,0x26d10029,0xab5c001e,0xe29f0028}},	//   _zeke, ázok_, _ceļo, _hið_
  { {0xb5fb0066,0x441c0009,0x8c1c0009,0xdd050060}},	//   vnán, תווס, תווי, ısız
  { {0xa3e70011,0xc1050012,0x8b580009,0x44210d29}},	//   _भाव_, لوبي, טיוס_, _lnh_
  { {0x681b0039,0x7a3c0061,0xe29f0028,0x60db267c}},	//   _tādē, _méth, _mið_, urum
  { {0x60db267d,0xb8fd0011,0xc795003c,0x60c20034}},	//   rrum, _तट_, ирны, _dwom
  { {0x0e660dc2,0x90560009,0xf62605c6,0x69cf01e3}},	//   икон, שבתו_, адно, óces
  { {0x44210020,0x6fa70037,0x81a70003,0x7ae3267e}},	//   _anh_, _फ़्रू, _إحال, munt
  { {0x69c6267f,0x3ea9001e,0x44332680,0x200e008e}},	//   _reke, _čatu_, _box_, ömiä_
  { {0x99840003,0xc964002d,0x8b660003,0x7ae3002a}},	//   _الهو, _увій, لازم, ount
  { {0x366a0001,0xe29f0028,0xd5e4001a,0x69c62681}},	//   _иако_, _bið_, _chị, _peke
  { {0xee3f00f1,0xc332000b,0xceb80010,0xf55a0012}},	//   cký_, חול_, _įę_, _للعب_
  { {0xe29706e0,0x9e650012,0x067b0009,0x61f60060}},	// [6a00] рат_, _داون, _שנפל, _öyle
  { {0x3ea701e4,0x444401b3,0x7ae3004a,0x69c60070}},	//   _kunt_, _ul_, kunt, _weke
  { {0xdb050058,0x3ea70054,0x69c62682,0x2fc703fe}},	//   _afhæ, _junt_, _teke, _meng_
  { {0x3ea70065,0x645c2683,0xb5fb000e,0xbef60009}},	//   _munt_, liri, jnál, יצעו_
  { {0x24e70001,0x91bb000b,0x6480004a,0x9f5e0e90}},	//   имци_, _במכי, töih, reté_
  { {0x2baf0044,0x3ea00051,0x394d001e,0x80bf0037}},	//   _ज्ञा, _liit_, dzes_, _लौटे
  { {0x0b180003,0xcb070003,0xb05b006f,0xaa5802e3}},	//   اقبة_, ليون_, _tvär, лику_
  { {0x7a38060e,0x6480008e,0x969504a5,0xa695004c}},	//   _títu, söih, _груш, _груј
  { {0xe8df0020,0xddd40002,0x5186002d,0xc0e70012}},	//   _việc_, łaśc, шука, لفين_
  { {0x7afe0119,0x7a3c0061,0xa7fc003a,0xb5fb01bd}},	//   _oppt, _méti, anın, anál
  { {0x645c2684,0xe8df0081,0x38170009,0xcb6714ea}},	//   diri, _tiệc_, בקים_, _кафе_
  { {0x8c3c00a2,0xe7e20037,0x333b0009,0x44332685}},	//   _diğe, _खाका_, _שתאמ, _sox_
  { {0x7bc800c6,0xa3b50011,0x61f60040,0x7870008e}},	//   _kedu, फ़रल_, dfyl, sävy
  { {0xd7ef0003,0xe0fb000b,0xee3f00d9,0x7b670048}},	//   _يكن_, _סלול, ský_, атбе
  { {0xa3ab0037,0xeab40009,0xfaa90012,0x22462686}},	//   कुट_, מִּי_, اهري_, _klok_
  { {0xd9f80037,0x9f9b000b,0x61d80015,0xbae40012}},	//   ्जित_, _בסופ, имся_, تكفي
  { {0xe29f014d,0x224900b6,0x765d2145,0x1fa7003c}},	// [6a10] _við_, rhak_, misy, арег
  { {0x2fc7008a,0x29d70020,0xb5fb2687,0x62880054}},	//   úng_, ủa_, znál, ïdor
  { {0x78ba0066,0xd7590012,0xcef5004c,0x2246016d}},	//   _čtve, دلات_, спећ, _olok_
  { {0x3204003e,0x68e40d85,0xb6bc0024,0x99890034}},	//   jemy_, buid, тицi, okaż_
  { {0x69cd0051,0x32042688,0x9f4d0031,0x753d0031}},	//   maae, demy_, _önök_, nysz
  { {0x0136000b,0x2246002c,0xec78002d,0x1cb8000b}},	//   _הרשת_, _alok_, апі_, סלול_
  { {0x8b940014,0x68330066,0x7ae3004a,0x3e7c0031}},	//   оръч, _výdě, uunt, gíts_
  { {0x7e7b001c,0x3ea7006f,0x2019001e,0x394d1ee6}},	//   _ukup, _runt_, ēsim_, tzes_
  { {0x3ea701b3,0x98a30010,0x26de2689,0x0f1f0011}},	//   _sunt_, ąjį_, erto_, यम्स_
  { {0x3ea00051,0xd0090001,0x644a0168,0x3ea71f14}},	//   _siit_, ћене_, chfi, _punt_
  { {0x394d000f,0xa3ac0037,0x4426001a,0x915e001a}},	//   szes_, _गलत_, _đo_, _mắc_
  { {0x32040002,0xce4a004c,0x6480008e,0x97560009}},	//   cemy_, узме_, nöiv, מיתו_
  { {0xba74000a,0xdb15003e,0x361a000b,0xca740003}},	//   _بالت, kazó, אורד, _بالغ
  { {0x711a000b,0x765d0010,0x61e9268a,0xaf490012}},	//   _תוספ, aisy, lgel, _مشعل_
  { {0x765d002c,0x61e90070,0x46b50012,0x2005268b}},	//   bisy, ogel, _احتس, meli_
  { {0x645c039c,0x28c40037,0x68e40b45,0x2005064b}},	//   siri, लीवि, tuid, leli_
  { {0x61f60028,0x11d70003,0x20110604,0xd2950024}},	// [6a20] rfyl, صولة_, _bazi_, ірсь
  { {0x07ba0012,0x7a3821d8,0x2005268c,0x68e40853}},	//   اهضة_, _píts, neli_, ruid
  { {0x1ea9000a,0x7d1b0051,0x7afe1cfc,0x2d80001e}},	//   لاني_, _arus, _uppt, ļiem_
  { {0x80d80044,0x8f88000b,0x7bce00b6,0xceb20009}},	//   _मिले, בְנֵ, labu, פיד_
  { {0xdb05001a,0xed5a0003,0x7bc800b6,0x8c3d003a}},	//   _nghê, دشات_, _pedu, _tuşl
  { {0x69dd0028,0x2005048b,0xed590029,0x3e72022d}},	//   ósen, jeli_, úži_, ráty_
  { {0x753d003e,0x386f000e,0x6af30003,0x61e90347}},	//   zysz, égre_, كثير, fgel
  { {0x26180044,0x66060722,0xd7570012,0x7a380030}},	//   _बोली_, jekk, _طلقت_, _zítr
  { {0xed460001,0x7bce0a60,0x78260012,0x7546004c}},	//   _унап, kabu, معدل, _уназ
  { {0x6b810065,0x3137007e,0x2005253f,0x01370009}},	//   _fylg, צנים_, geli_, צרית_
  { {0x8f340046,0x4386000a,0x487b000b,0xbb860003}},	//   ценц, _الاق, רטיס, _الاي
  { {0x3f82001e,0xdb1a004a,0x9cf5002d,0x3cd20037}},	//   āku_, _vetä, озмі, _सिफ़ा
  { {0xb996000a,0x765d0101,0x67d401ef,0x91e301d4}},	//   _الشب, risy, _долу, _хоче
  { {0x50960046,0x765d0101,0x20050026,0x9f5e0ee3}},	//   _уређ, sisy, celi_, letí_
  { {0x765d1ff1,0x7ff70009,0x27e30034,0xdb150031}},	//   pisy, _הזוג_, ójne_, vazó
  { {0x628401a2,0x7f830003,0xeda70024,0x915e0081}},	//   glio, _علين, _ушко, _sắc_
  { {0xb0350001,0x5187059a,0x98bf0002,0x2dd80003}},	// [6a30] онаш, сува, rzuć_, _طبية_
  { {0x62840079,0x68e00035,0x7bce268d,0x4fb800af}},	//   alio, irmd, cabu, שֶּׂ
  { {0xedd50003,0xff530003,0xdb15268e,0x2bf60009}},	//   قياد, أخذ_, razó, _ומתן_
  { {0x9f5e0066,0x22810002,0xf127003c,0xa5f91ab7}},	//   jetí_, póki_, _льго, реду_
  { {0x915e001a,0xbbe90003,0xfdf8000b,0x7ae70107}},	//   _tắc_, لرغم_, מצאת_, lujt
  { {0x2005000d,0x61b30037,0x42d902ad,0x7d760012}},	//   xeli_, ीर्ष, афия_, غمور_
  { {0xdc3c0009,0xf43c0009,0x1a290187,0x7a3c0097}},	//   רעור, רגומ, ижки_, _létu
  { {0x6480004a,0x2a690051,0x7bce0004,0xe0d9150a}},	//   löit, nnab_, zabu, ави_
  { {0xaca3001a,0x7d1b00b6,0xdb1c0028,0x42380009}},	//   _trốn, _urus, rbré, מנהל_
  { {0xe588000b,0x7e6d0051,0x61e9268f,0x1f650024}},	//   _הָעָ, _ajap, sgel, жком
  { {0x64430002,0x6606146f,0x69c017d4,0x32b80012}},	//   mkni, tekk, bbme, _هدنة_
  { {0x27170020,0x8e56002d,0x59c40003,0x28f90015}},	//   _văn_, ітні, _فيمك, _ведь_
  { {0xa5bb0065,0x7af50052,0xda080012,0x14160024}},	//   tjór, etzt, _دينه_, оєвр
  { {0x6480004a,0x660611d1,0x64431a7f,0xd59a0009}},	//   jöit, sekk, nkni, יברל
  { {0xa3e70037,0x03a300de,0xeb9a0187,0x2bfb0011}},	//   _भाई_, диро, рив_, ल्यू_
  { {0xcb12000b,0x3eb80064,0x225f0031,0x08c60198}},	//   ולל_, írte_, niuk_, жбан
  { {0x7bce002c,0x2b5a0029,0x06970003,0x69cb2690}},	// [6a40] pabu, ĺpci_, _بنية_, _mege
  { {0xb9020011,0x76490060,0x7a3c0031,0x69cb2691}},	//   _धि_, _aley, _hétt, _lege
  { {0xdb05001a,0x1eda0003,0xeda606fd,0x870a0306}},	//   _nghè, شباب_, ошло, реев_
  { {0x69cb2692,0xd5b00012,0x5bb40011,0xf8a70012}},	//   _nege, رفت_, ुर्व, _ية_
  { {0xc27b0093,0xf653000b,0x8fe60012,0xb5fb0064}},	//   _כרטי, וצא_, _وأسم, liác
  { {0x8c430015,0x2bbf0037,0x251b0009,0x8cdb0011}},	//   мече, ्रया, יונא, _निरो
  { {0x69cb0347,0x6480008e,0x7649183d,0x99890034}},	//   _bege, löis, _fley, adań_
  { {0xcad7000b,0x76490028,0xe45f006f,0xb5fb0031}},	//   קופת_, _gley, nsör_, rnák
  { {0x661d0028,0x99970014,0x6480004a,0x32180066}},	//   _óska, окът_, nöis, ěry_
  { {0x64430163,0x3faa004c,0x29da0081,0xdced0060}},	//   ckni, шњим_, ừa_, _ayağ
  { {0xc7b30093,0xa6e7001a,0x501b0009,0x69cb2693}},	//   ובת_, _ngừ, בויו, _fege
  { {0x8b650003,0x69cb0518,0xa5f90015,0x2bbf0037}},	//   _عالم, _gege, щему_, ्रभा
  { {0xa06a0046,0x7e9b000b,0x6480004a,0xca970009}},	//   _када_, יסטו, jöis, _ודאי_
  { {0xaaa90037,0x7ae72694,0x2bb80012,0x69cb0227}},	//   _चूँक, tujt, قافة_, _zege
  { {0x3a2600bd,0xb5fb029d,0x9ee80003,0xd25b035c}},	//   _knop_, riáb, _افعل_, аца_
  { {0x7ae7022d,0xd5bb0024,0xdb1f0031,0xb21b0040}},	//   rujt, _тск_, övér, _skæb
  { {0x3fab0046,0x25a90051,0x37ab00ac,0xb9550014}},	// [6a50] ањем_, _igal_, атен_, чващ
  { {0x7e7d004a,0x24b8000b,0x7a3c000e,0x7ae70042}},	//   losp, _והזן_, _kéts, pujt
  { {0x6480004a,0xb5fb0029,0x10480024,0xaaa90011}},	//   röit, ciác, цяти_, _चूंक
  { {0x9f580028,0x8f9b0009,0x7bda0031,0x7e7d2695}},	//   _varð_, ביבי, _adtu, nosp
  { {0xe534002d,0x44252696,0x09b60009,0xe5070012}},	//   мець, _pnl_, _מפרט_, تباي
  { {0x113a0093,0x61ed1fc3,0x69cb2697,0xe4580024}},	//   _התשל, lgal, _sege, ожі_
  { {0xfe730003,0xeb990021,0x6bd60012,0xd0100012}},	//   _قدر_, щик_, سويس_, _جلّ_
  { {0x61ed13b9,0xefc8001a,0x765b003a,0xe9d10012}},	//   ngal, _đỉnh_, _umuy, رغب_
  { {0x7a3c0065,0xf4870001,0x69cb2698,0xb5fb0064}},	//   _rétt, _дужн, _vege, ziác
  { {0x8f75002d,0x1bf20037,0xa2dc01e1,0x69cb0347}},	//   зумі, _घायल_, _फिल्, _wege
  { {0x69cb2699,0x1e95000b,0xd4980024,0xa6950009}},	//   _tege, ּכָל_, _єру_, ּכָה_
  { {0x12fa000b,0x63b50002,0x291d0002,0x3ea4006f}},	//   _להעב, eczn, _trwa_, ömt_
  { {0xe1670003,0x04b6022a,0x80b00011,0x03a6004c}},	//   _بداي, ясня, _अंधे, зиго
  { {0x00ba000b,0xa5070001,0xdd560009,0x2ab10097}},	//   _המסמ, џера_, לברט_, _káb_
  { {0xd00e0351,0xc7b20009,0x28120012,0xe4520009}},	//   _إلى_, _אבו_, _سويس, תֶר_
  { {0x5756000b,0x673c083c,0x6480004a,0x61ed01ea}},	//   _מבצע_, ärje, töis, ggal
  { {0x41270048,0xb5fb0064,0xfd120012,0xdb1c01e3}},	// [6a60] пото_, siác, _أجب_, mbrí
  { {0xa3e70044,0x2bbf0037,0xe0d7002d,0x61ed0010}},	//   _भाग_, ्रणा, яву_, agal
  { {0x4c3b000b,0xc43b000b,0x39460708,0xd7ef0003}},	//   _התיב, _התיי, šos_, اكم_
  { {0x7a3c000f,0x8b8b000b,0xcb8b0009,0x443a269a}},	//   _létr, _לָכֶ, _לְכֹ, _hop_
  { {0x7cd7002d,0x443a0070,0x721b000b,0x2ca518c2}},	//   змір_, _kop_, _הוכח, _bild_
  { {0xf8bf0065,0x1eaa0012,0x9cd70009,0x9423004c}},	//   _bréf_, _هاري_, לונה_, емље
  { {0xd25a0014,0x044d0009,0x6ada0011,0x6bd30012}},	//   йци_, שׂוּ, _बटोर, رتور
  { {0xeaaf0003,0x69c404a3,0x66f70009,0x98b8085f}},	//   دعو_, nbie, _ממלא_, олит_
  { {0x63b5003e,0xc4c50012,0xb5fb0018,0xfce31671}},	//   yczn, _يتكو, onáv, _пото
  { {0x3957000b,0x3157000b,0x645d0010,0x2ca50028}},	//   פשים_, פיין_, _įsig, _gild_
  { {0x7a3c0061,0x7d040002,0xa2b10011,0x27e30034}},	//   _détr, _apis, _आंध्, ójna_
  { {0x60d60c88,0x645e00c1,0x33050012,0x8c3d004b}},	//   ksym, _ampi, _تذكّ, _ruşi
  { {0x62820051,0xd6570009,0xc27b0009,0xab5c0035}},	//   _ikoo, ליטת_, _פרדי, _ceļv
  { {0x443a03eb,0xf8b7000b,0xbddb0061,0xe1650003}},	//   _cop_, _צפוי_, thès, _تدمي
  { {0x1dcc0044,0x6ffb007e,0x3ffb000b,0xdddd001e}},	//   ारात, _ההופ, _הפוע, nosū
  { {0xaa580731,0x72050012,0x62340367,0x68e4269b}},	//   пису_, بورم, несу, frid
  { {0x61ed000f,0x2bbf0037,0xdbd7004a,0x58d9003c}},	// [6a70] rgal, ्रदा, tääk, юдая_
  { {0xc879007d,0x7c3a269c,0xbddb0061,0xb814004c}},	//   tuşi_, _notr, chèr, ндуј
  { {0x212b008a,0x68e40051,0xdbd70051,0xdc3c000b}},	//   ̣ch_, arid, rääk, _לעזר
  { {0xd2460012,0x28dd0011,0x6f790009,0xb6a40081}},	//   _شن_, _मिलि, חְנו, _nhẫ
  { {0x3eae0b04,0x1c220011,0xc879004b,0x69cf0035}},	//   _luft_, माचल_, suşi_, _iece
  { {0xf1c401bd,0x3cfc0009,0x1c440024,0x68e9008e}},	//   prší_, צלונ, ннім, vued
  { {0xfbd00003,0x764d003a,0x7c3a0002,0x69cf00b6}},	//   اته_, _olay, _dotr, _kece
  { {0x7c2803a0,0xca060014,0x3ebc0029,0x4254003c}},	//   _endr, днъж_, ívte_, етьт
  { {0x2cad0051,0x7a3c1ff6,0xf4090012,0xfbbf0011}},	//   _uued_, _pétr, _ويرى_, ्राम
  { {0xefc80020,0x69c4083f,0xf74516a3,0x09aa0011}},	//   _định_, zbie, деоо, _कल्य
  { {0x69c40002,0x2d8c0002,0xd436000b,0xcfb60009}},	//   ybie, ędem_, _קטעי_, ולתי_
  { {0x2b4f00a2,0xdbcc0065,0x60d6004a,0xdb1c0028}},	//   ımcı_, lóði, ysym, tarþ
  { {0x68e90164,0x2055076c,0x2a6d005e,0x76ac0060}},	//   qued, _откр, mneb_, _işye
  { {0x7d04009b,0xc19a0009,0xe8df0081,0x93c3004b}},	//   _vpis, _ושני, _chọc_, _ţărm
  { {0x7d04003e,0x63830867,0xb5fb0042,0x78bd098f}},	//   _wpis, вгра, vnáv, _atsv
  { {0x7ae10272,0xe7f00011,0x2a6d005e,0x629b008e}},	//   álta, _चाहा_, nneb_, nmuo
  { {0x78a700bd,0xda650003,0x7d040027,0xc693000b}},	// [6a80] _bijv, رافي, _upis, _באה_
  { {0xb8f60037,0x9f880028,0x6e290066,0x88c50012}},	//   _सब_, _kóði_, _aneb, عتقل
  { {0x907a000b,0x86c30012,0xaf0a0012,0xdfcf0012}},	//   קטעי, َيْن, تقام_, شين_
  { {0x93ee0044,0xa3d00037,0xc8690009,0xdd8a0048}},	//   _जाँच_, _वजह_, בן_, обед_
  { {0x6da305f8,0x6e3b043f,0xc8790060,0xe5a306bd}},	//   вица, _doub, luşu_, вици
  { {0x7c830015,0x6282269d,0x2a6d005e,0x22b50035}},	//   куще, _skoo, eneb_, _sāka_
  { {0x7c3a02b5,0xdb050081,0xdb0e0031,0xdb1c269e}},	//   _votr, _nghì, mbbó, maró
  { {0x20180535,0x41e6002d,0xc1140001,0xdb1c0002}},	//   _hari_, фіка, емиј, laró
  { {0x93ee0037,0x95830294,0xd7e60024,0x12770012}},	//   _जांच_, _алте, міно, بحوث_
  { {0x6c030001,0x764d1013,0x47341f02,0x80060048}},	//   _изуз, _slay, енос, фчие
  { {0x2bbf0037,0x764d269f,0x9b460003,0x26d80025}},	//   ्रसा, _play, _تناو, éro_
  { {0x752d0029,0xe2460012,0xbddb0025,0x2018016d}},	//   ťaze, _تخطي, thèq, _lari_
  { {0xdc3a00a2,0xbd450003,0x61560012,0x9da80048}},	//   _açıl, رنسي, _تنشئ, дъра_
  { {0x36d4002d,0x32bb0003,0xc2bb0012,0x3ce60159}},	//   _зокр, قدرة_, قارئ_, irov_
  { {0xd5ed0020,0xe5150011,0x200c26a0,0x287b0009}},	//   _chạ, _दैनि_, medi_, _ונגמ
  { {0xd5b8002d,0x2018002c,0xa0c50003,0x8e380012}},	//   _ось_, _aari_, فيرو, _يسير_
  { {0x69cf0164,0xdb1a0028,0x6e3b26a1,0xd0d40048}},	// [6a90] _vece, _netþ, _roub, котъ
  { {0x6e3b0013,0xdfd1000a,0x2a64000d,0x9cd8000b}},	//   _soub, ايا_, himb_, _חוזה_
  { {0x201800ec,0xd6db0014,0xe7190003,0x0c780012}},	//   _dari_, юта_, ثيات_, _تصيب_
  { {0x2bbf0037,0x69dd0058,0x539a000b,0x62800002}},	//   ्रवा, _udse, _מיתו, jomo
  { {0x628026a2,0xddc20035,0x6e290159,0x201815fe}},	//   domo, unoš, _vneb, _fari_
  { {0x200c0027,0x37c50003,0x7bc7006f,0xf8bf0061}},	//   jedi_, _سيرف, nbju, _crée_
  { {0xe7840046,0x27f8022d,0x11d5002d,0x5c380009}},	//   _ауто, žený_, ніпр, ורגן_
  { {0x7f940015,0xc212000b,0x99d50003,0x3ea900b6}},	//   _расх, ָ֔ה_, رتبا, _niat_
  { {0x9f5e0006,0x629b0010,0x5c750e99,0x321926a3}},	//   hetä_, rmuo, _злат, _masy_
  { {0x2a6d0051,0x629b004a,0x8c590012,0x32190034}},	//   sneb_, smuo, _علاء_, _lasy_
  { {0x628901e3,0x6280001b,0x9666004c,0xb5fb26a4}},	//   pleo, bomo, екне, jnás
  { {0xf6520003,0x531a000b,0xfb1a000b,0xf7720009}},	//   ائد_, _מועצ, _מועמ, רקט_
  { {0x61d60093,0x71d60009,0x22580012,0x22ae0034}},	//   _נוסף_, _נוסד_, _تجلب_, _ręki_
  { {0x8c3d003a,0xd5ed001a,0x6f150002,0x200c26a5}},	//   _tuşu, _phạ, _oszc, cedi_
  { {0xf8bf0149,0xa3c20037,0xe29a00b3,0xf6520012}},	//   _até_, ूरत_, зав_, _مئة_
  { {0xc3320093,0x1e1a0012,0x3ea91a82,0xdb1c0034}},	//   נון_, _رغبة_, _giat_, waró
  { {0x26d80029,0x68fb26a6,0x201826a7,0x2bbf0011}},	// [6aa0] árov_, ntud, _pari_, ्रशा
  { {0x7d57000b,0xb4fb000b,0x986a0003,0x291f004a}},	//   _נייד_, _צפיי, أحرف_, ivua_
  { {0x68fb0051,0x2bf7000b,0xb5fb1356,0x6d461fc7}},	//   htud, _אמין_, cnás, lyka
  { {0xc869000b,0xee3a16a9,0xdeba0009,0xd6cf0012}},	//   זן_, яне_, למעל, صقه_
  { {0xb5fb26a8,0x2372001e,0x68ed0b45,0xac1800ac}},	//   onár, šajā_, cuad, долу_
  { {0x7c3e0039,0x28b50037,0xc4d3000b,0x69d626a9}},	//   _jopr, _अंति, נגו_, laye
  { {0x6fd60037,0x38b60262,0xd3d70012,0xe8e00081}},	//   _मजबू, _hær_, ربوا_, _ruột_
  { {0xd257002d,0xc1040012,0x212000eb,0x69d60060}},	//   ець_, نوعي, ovih_, naye
  { {0x68fb000e,0x5066035b,0x200c0712,0x25d70009}},	//   gtud, етна, tedi_, _רומן_
  { {0x60c4007a,0x66040051,0x2a6a000e,0x14d7000b}},	//   ipim, _abik, őbb_, _נובל_
  { {0x442c00c5,0x628004a8,0x69d6003a,0x38b60262}},	//   _ind_, pomo, kaye, _lær_
  { {0x21200027,0x200c009b,0xddcd0034,0x69c60031}},	//   kvih_, sedi_, _ukaż, űkeb
  { {0x443e066e,0x5c070098,0x7524000d,0x22620034}},	//   _kot_, нява, _criz, ęską_
  { {0x7ae1000f,0x628626aa,0x9097002d,0x9f5e004a}},	//   álto, _akko, _звіт_, tetä_
  { {0x7bc7006f,0xe8140037,0x60c4005e,0x443e26ab}},	//   rbju, ड़ना_, epim, _mot_
  { {0xa7fc0060,0x7bd50030,0xf6990012,0x68ed179f}},	//   anıt, sazu, _تنبع_, tuad
  { {0x60f90047,0x067c000b,0x5dc8000b,0xa3c20037}},	// [6ab0] ьная_, _מנהל, _אֶתְ, ूरा_
  { {0x443e0274,0x6286000e,0x2bee0037,0x3cf80012}},	//   _not_, _ekko, _जाएं_, _أعيد_
  { {0xc8850052,0xbbbf0037,0xdb1a1356,0x6e2d0032}},	//   äßig_, ्रीक, _metó, _knab
  { {0x442c1c1d,0x38b60028,0x31c70024,0x660f26ac}},	//   _and_, _fær_, _ясов, neck
  { {0xed5800bc,0xd7e70024,0x660f0032,0x9479004c}},	//   ної_, _піво, ieck, мску_
  { {0xdddd0002,0xdb18005e,0xa49b01a0,0x660f0496}},	//   nisł, havõ, stòf, heck
  { {0x6d460002,0x3bbc000b,0x92f60012,0xf3f20009}},	//   zyka, המוד, نفوذ_, ׁ֣ה_
  { {0xd36e0003,0x442c26ad,0xe79a0030,0x68fb0c7c}},	//   تهى_, _end_, _běží, ttud
  { {0x03f90001,0x84150014,0xdb18005e,0xb5fb1032}},	//   _онај_, _имах, davõ, riál
  { {0x443e0bf8,0xf9820048,0x24540032,0x661b26ae}},	//   _got_, ргьо, _käme_, _hauk
  { {0xc7b2000b,0xdddb0066,0xf092000b,0xdb1c0097}},	//   יבי_, _zkuš, שני_, jarð
  { {0x7c3e1d54,0x6d460504,0x6d590002,0x2f54027f}},	//   _sopr, tyka, ozwa, утьс
  { {0x99d40003,0x7c3e26af,0xd9440012,0x0d99003c}},	//   _إتما, _popr, _مئوي, етры_
  { {0x661b0259,0xa2e60015,0x6d460002,0x6744000e}},	//   _lauk, когд, ryka, ítjá
  { {0xe739007c,0x7c3e0029,0xb4ce0011,0x7f190024}},	//   _цей_, _vopr, _शब्_, _цілу_
  { {0x26c50583,0x661b0a8c,0x69c4005e,0x3eb70035}},	//   mplo_, _nauk, _õiet, ēgtā_
  { {0x216702e2,0x7c3e004e,0x69d626b0,0xa3c10011}},	// [6ac0] вити_, _topr, raye, ंडा_
  { {0x69d60108,0x38b60989,0xddc90027,0x07150037}},	//   saye, _vær_, _rješ, _तनाव_
  { {0x7d090017,0xd5af057e,0x5c370009,0x443e26b1}},	//   _apes, ис_, _סרטן_, _rot_
  { {0x60db0051,0x9e660048,0x88c60012,0xddc9001b}},	//   ksum, ъвед, _لتسل, _pješ
  { {0x9cb30003,0x443e26b2,0xad6d0009,0x34b30012}},	//   لمنت, _pot_, ּכוֹ, لمنز
  { {0x8d5b0093,0x60db0002,0xb5fb000e,0x455b0009}},	//   וכני, dsum, giáj, וכנס
  { {0x442c008b,0x501b000b,0x69c90070,0xcc330012}},	//   _vnd_, _קולו, fbee, شروع
  { {0xf2d3000b,0x661b0759,0x8b650012,0x68e91a19}},	//   בעה_, _gauk, داهم, fred
  { {0xd010000a,0x660f26b3,0x443e26b4,0x6fd60011}},	//   ملة_, veck, _tot_, _मजदू
  { {0x442c032b,0x6e2d26b5,0x660f0d36,0x8d5b0009}},	//   _und_, _snab, weck, _חכמי
  { {0x1df90015,0x660f26b6,0xc7d70009,0x60db005e}},	//   нены_, teck, כויי_, asum
  { {0xe8020044,0xdd0e0037,0xdb1c0028,0x3ce909d2}},	//   र्ता_, िबंध_, varð, šave_
  { {0xb8840066,0x3f820002,0xc2370009,0x68e926b7}},	//   _zvíř, łku_, _שרדו_, cred
  { {0xdb18005e,0xfc670048,0x26d80031,0xdb1c0097}},	//   savõ, тъмн, áros_, tarð
  { {0xe5c726b8,0x3879000f,0x3d190037,0x0ff70012}},	//   _испо, ésre_, _मैने_, _شعوب_
  { {0x201c000e,0xba740003,0x6e2d0441,0x31c40472}},	//   _havi_, لاقت, _unab, исув
  { {0x51870bac,0x661d0097,0x1da70011,0x90d40012}},	// [6ad0] тува, _óski, _गणित, لآلا
  { {0xdbcd0028,0x44fb0018,0x7bd80064,0x25be0030}},	//   _góðu, vê_, javu, ětle_
  { {0xf7700003,0x1fa7011d,0x201c003a,0x7bd80a4a}},	//   يام_, траг, _mavi_, davu
  { {0x60c20d34,0x3618002d,0xc3320009,0x6d1e0011}},	//   _otom, кцію_, _הוט_, पिंग_
  { {0xda5a000b,0x76400002,0x97c70012,0x865c0009}},	//   _נכשל, _domy, _لتأم, ודאי
  { {0x201c00c1,0x73c40012,0x7bd826b9,0x68e926ba}},	//   _navi_, ليهم, gavu, vred
  { {0x9f34007c,0x8c42005c,0x9f9a005e,0xc43c0009}},	//   _кері, сеще, _jääk_, ותגי
  { {0x68e926bb,0xc3340009,0xf7720009,0x60db26bc}},	//   tred, שוק_, _הקל_, tsum
  { {0x69c900bd,0xe0d10003,0x00850015,0x3949002c}},	//   rbee, حزب_, ллио, nyas_
  { {0x04950003,0xc9840001,0xb4c10011,0x201c00b8}},	//   _صلاح, јући, ूठी_, _cavi_
  { {0xe8140044,0xbbbf0037,0x68e926bd,0x27ea0034}},	//   ड़ता_, ्रैक, sred, óbna_
  { {0xcf920093,0xc3320009,0x79590048,0xf1590048}},	//   מטי_, _לוב_, _пиер_, _пиеш_
  { {0x644126be,0x48e506bd,0x865a00af,0xfd1200ae}},	//   _koli, _солв, תדרי, حجج_
  { {0x97250003,0x61e20504,0x3ead26bf,0x16d90012}},	//   _مفتو, _zdol, _liet_, _كذبة_
  { {0x6441001c,0x09e606da,0xc8a80014,0x91e603e2}},	//   _moli, ловн, _ръце_, лове
  { {0x3ead01e4,0x224d000e,0x4255024d,0xf7720009}},	//   _niet_, nkek_, атут, _לקו_
  { {0x0e9b0009,0x7e9b0009,0x1e570009,0x19b90557}},	// [6ae0] _אשקל, _אסקו, _תשפר_, тусь_
  { {0x69cb0028,0x64411abe,0x7aea0097,0xc4d30009}},	//   ðger, _noli, yrft, _הגז_
  { {0x224d000f,0x291926c0,0x76400002,0xaf960001}},	//   kkek_, _essa_, _pomy, ушај
  { {0x31790002,0x5693002d,0x75d30012,0x4e1a0012}},	//   ższy_, баєт, ميما, عتاد_
  { {0xa0760015,0xcdf7000b,0x752d0064,0xe5340842}},	//   _бывш, רמני_, ťazn, рель
  { {0xd92b000b,0xcd970009,0xb5fb0031,0x644126c1}},	//   _אֵלָ, נדסת_, tiák, _coli
  { {0x3d160037,0x64411468,0x59b80011,0x290001a0}},	//   _पैसे_, _doli, _अलार, ltia_
  { {0xcb070003,0x25ad124c,0xb5fb000e,0x7bd8079f}},	//   ايين_, želi_, riák, savu
  { {0xc7b00003,0xa2bb0037,0x290026c2,0x644e00b0}},	//   يّة_, _शून्, ntia_, kkbi
  { {0x0d750015,0x3ead0070,0xe8df001a,0xbcaa0012}},	//   _тыся, _ziet_, uyền_, _أدرك_
  { {0xde59002d,0xa3c10037,0x2900004a,0xf837000b}},	//   вані_, ंडर_, htia_, אנית_
  { {0x9f65000e,0x63720031,0x2900008e,0xe73100af}},	//   ütés_, zűné, ktia_, קֵי_
  { {0x71e70003,0x24c70009,0x9be70024,0x4034004c}},	//   _صفوف_, ְּךָ_, лівк, _велс
  { {0x93b5001a,0xb9930012,0x33870048,0xe3c50012}},	//   _lãn, _الهب, губв, شْرَ
  { {0x56950098,0xce950014,0x7ac4002d,0x2d840052}},	//   _какт, _какъ, йсте, ümer_
  { {0xdb09032f,0x000000c4,0x000000c4,0x000000c4}},	//   înée,   ,   ,
  { {0x52d10011,0xda080012,0x99d40012,0x1958003c}},	// [6af0] _सब्स, طيله_, إتفا, гаты_
  { {0x7d0d0101,0xad1a0009,0xba3d0030,0x20070097}},	//   _ipas, _סותר, omůc, ýni_
  { {0x35b50046,0x2295002d,0xdb1e0e0a,0xfbab0024}},	//   абер, _виня, _depó, _ятий_
  { {0x2bbf0044,0x9f5c0066,0x51870177,0x26de10bb}},	//   ्रका, ývá_, _буга, isto_
  { {0x11da0009,0xa3c10011,0xb4c10011,0x89da0009}},	//   _שחשב, ंडल_, ूठे_, _בחרי
  { {0x26de16f9,0x6d5d001e,0x1be60048,0xcb69004c}},	//   ksto_, izsa, адши_, кале_
  { {0xd3d80003,0x0b160012,0x42550229,0x644126c3}},	//   ابها_, لقوة_, итит, _voli
  { {0x2f18002d,0x6458004a,0xdb24000e,0xdb1e000e}},	//   _щось_, ahvi, ásáh, _repü
  { {0xe0d60015,0x644126c4,0x71d80009,0xe9d90034}},	//   авы_, _toli, אוחד_, raź_
  { {0xd0090001,0x3e6f004a,0xddc20002,0x7c970012}},	//   њене_, yötä_, akoń, _إشرا
  { {0xd371000a,0xb0640052,0x6d4b0010,0x68ed022d}},	//   _بها_, lmäß, lyga, hrad
  { {0xd1310003,0xaf98003c,0x366a00b5,0xc1050012}},	//   _وما_, ытых_, тамо_, _نوصي
  { {0x52840003,0x69db0032,0xb0640032,0x661d0097}},	//   _النك, maue, nmäß, _ósku
  { {0xe3b20003,0xb05b0d4a,0x7e6b002c,0x7529001b}},	//   ترح_, _stän, higp, _mrez
  { {0x7d0d001e,0x05d50011,0xdb1e0018,0xb0640032}},	//   _epas, दराब, _repó, hmäß
  { {0x68ed0164,0x69db0374,0x290010bb,0x75460021}},	//   frad, naue, ttia_, _вниз
  { {0xa5b70093,0xe3b20003,0x98e60012,0xf8660430}},	// [6b00] _דלפק_, _ورد_, شكاو, авао
  { {0x69db0052,0x859b000b,0x23760003,0x60c926c5}},	//   haue, _בשפו, _ناجح, ipem
  { {0x444400c1,0x48790015,0x7bdc26c6,0x7dc60012}},	//   _io_, устя_, maru, لقان
  { {0x72db000b,0x7529121c,0xfee90003,0x7bc11af4}},	//   _בקטג, _brez, اعلى_, _aflu
  { {0x55bb000b,0x69db0052,0x444426c7,0xa5bb0031}},	//   דמנו, daue, _ko_, ndóa
  { {0x3ce90037,0x2c6d0027,0xb5fb0031,0x26de0034}},	//   _जिसे_, ožda_, riái, ysto_
  { {0x444401e5,0xdb1a000f,0x66e30a76,0xfbd30009}},	//   _mo_, _letö, _мора, חתו_
  { {0x7bdc00c6,0x444426c8,0x471b000b,0x3ce90604}},	//   haru, _lo_, _בולג, šava_
  { {0xba57000b,0x44440532,0xc05a0024,0x3eb80132}},	//   יסקו_, _oo_, він_, _hurt_
  { {0xb8fe0044,0x8bd8000b,0xe726002d,0xcfa607e8}},	//   _तब_, _תַּח, аємн, ишни
  { {0xbb1a0003,0x69db0052,0x7529211e,0x2fd8004b}},	//   _جزءا_, baue, _zrez, _merg_
  { {0x444405ab,0xe4db0013,0xf76f0003,0xdb1a000e}},	//   _ao_, zšíř, باً_, _betö
  { {0x444426c9,0x6e201cf5,0x3eb800b0,0x224b0032}},	//   _bo_, _mamb, _lurt_, öcke_
  { {0x7d020010,0xea01001a,0x444426ca,0x7c870434}},	//   itos, _đẩy_, _co_, руме
  { {0x883b000b,0x444426cb,0xe7570024,0x083b0009}},	//   _בתגו, _do_, _вищі_, _בעגל
  { {0x0f57000b,0x645d0010,0xb05b008e,0x68ed18d2}},	//   _כיום_, _įsim, _etäl, trad
  { {0xdb1a0052,0x7d0d0262,0x97c70012,0xb9990048}},	// [6b10] _getö, _upas, لتام, увах_
  { {0xd7f8007d,0x68ed0844,0x444426cc,0x351c0009}},	//   ngă_, rrad, _go_, _יוחנ
  { {0xfbd2000b,0x7d02004a,0xbcfb000e,0x6e2026cd}},	//   _מתי_, etos, széd, _bamb
  { {0x6e2026ce,0x56950015,0x444426cf,0x68ed26d0}},	//   _camb, щает, _zo_, prad
  { {0x95090003,0x44210051,0x4444219d,0xba9a0009}},	//   اقتك_, _kah_, _yo_, _תסרי
  { {0x44210051,0x9f350024,0xbc640024,0x63c80012}},	//   _jah_, _легі, овік, لِهِ_
  { {0x03a50015,0xb0640032,0x68e20159,0x442126d1}},	//   щико, smäß, _avod, _mah_
  { {0x7378000b,0xa1150003,0xeb78000b,0x0378000b}},	//   יגוד_, موعت, יעוץ_, יתות_
  { {0x97d9002d,0x69db1ee6,0x0fd9003c,0x60c90025}},	//   льну_, raue, льны_, upem
  { {0x44211316,0x3eb826d2,0xf1bf0030,0xdb1c10b3}},	//   _nah_, _yurt_, _znát_, scré
  { {0x9b95000a,0x33950003,0x2d820033,0xab950003}},	//   _الات, _الاز, _øker_, _الاغ
  { {0xb05b0163,0xd7f8000d,0x444426d3,0x0736000b}},	//   _stäl, agă_, _so_, צטרך_
  { {0xc9870001,0xd009004c,0x645d0073,0x644526d4}},	//   _тужи, _беле_, _įsij, _bohi
  { {0x6e221741,0x2a6d26d5,0x0c79003c,0x9f5e0030}},	//   zdob, lieb_, ассы_, letý_
  { {0x44440026,0x7d02000f,0x69d900b6,0x7c2e0028}},	//   _vo_, ztos, _kewe, _óbre
  { {0xe1f9007a,0xc332000b,0x6ec40003,0x444403e4}},	//   ngų_, הול_, _بتوق, _wo_
  { {0x394d03eb,0x444426d6,0x3eb80054,0x6e201948}},	// [6b20] nyes_, _to_, _surt_, _ramb
  { {0xd12f000a,0xa3d90044,0x69d90002,0x6e2026d7}},	//   عمل_, ारण_, _lewe, _samb
  { {0xb5fb0017,0x6e20002c,0x46ea02ac,0xc0a90012}},	//   riáv, _pamb, уден_, شاكل_
  { {0x54e60003,0x7d022634,0xed5a0015,0x69d926d8}},	//   مستق, ttos, лое_, _newe
  { {0xd625000a,0x7e7b006f,0x7c210c57,0x5e250012}},	//   تعلي, _djup, _balr, تعلق
  { {0x68460014,0x70560012,0x7e7b0035,0x395f0035}},	//   _унга, _انسا, _ejup, dzus_
  { {0x69d926d9,0xa3d90037,0xb7db000b,0x6441004a}},	//   _bewe, ारत_, _תקלי, ölii
  { {0x3ce90011,0xd257003c,0x69d9016d,0xc3330009}},	//   _जिले_, йцы_, _cewe, לוו_
  { {0x6fe20013,0x02660020,0xdfd0000a,0x69d901f6}},	//   jící, _đến_, وية_, _dewe
  { {0x50b70003,0xd7f8000d,0x2d57000b,0x661d0028}},	//   حديد_, ugă_, _השמש_, _óskr
  { {0xe2ca0098,0x2002003e,0x9e15002d,0x7bda001e}},	//   _след_, ęki_, одні, _ietu
  { {0x9f97000b,0xfb1b000b,0xa5f90015,0x91ba0003}},	//   מדיה_, _תואמ, шему_, _إطار_
  { {0x7bda0889,0xb05b0c60,0x68e200eb,0xc5f30009}},	//   _ketu, _stäm, _uvod, הדר_
  { {0xe0fb000b,0x6fb40012,0x44d60034,0x645d0073}},	//   _עלול, _بمثا, ił_, _įsik
  { {0x92b70012,0x29040060,0xe737004c,0xddc207a5}},	//   إحسا, ltma_, _геј_, dnož
  { {0x78ba0066,0x44d60002,0x44210f50,0x2bcf0011}},	//   _čtvr, kł_, _wah_, _स्ना
  { {0x3134002d,0x64450051,0xb5fb0031,0xbcfb0031}},	// [6b30] петр, _tohi, knáz, széb
  { {0x7bda007a,0x645c0358,0x44d60002,0x34b50037}},	//   _netu, chri, dł_, ंदीद
  { {0xb09b000b,0x625c0061,0x8db5002d,0xe1f90010}},	//   ניבר, _géog, ослі, ygų_
  { {0xc6d40012,0x3e72001b,0x9d550012,0xe7170009}},	//   ستمت, pšte_, ينات, מחבר_
  { {0x7bda09db,0x44d60034,0x47d50012,0x69d90034}},	//   _betu, gł_, _ويحر, _rewe
  { {0x3ce9009b,0x7bda0a4c,0xe3b10012,0x04dc0009}},	//   šavo_, _cetu, ورث_, נקול
  { {0x44d6003e,0x9f5f0006,0x2a6d0026,0xbb850012}},	//   ał_, ärän_, tieb_, غلبي
  { {0xe1f9007a,0x08c50001,0xef220002,0x04c90012}},	//   ugų_, обин, _dużą_, _نوري_
  { {0xa3d90044,0x8039002d,0x212b26da,0x2a6d0e17}},	//   ारा_, аїну_, ích_, rieb_
  { {0x7bda014d,0xf865002d,0x94770012,0x69d9016d}},	//   _getu, івно, _ادرا, _wewe
  { {0xe80b0044,0x53340063,0xc2c40012,0x752d126b}},	//   स्या_, _нефт, _فيلي, _araz
  { {0x68ee003a,0xf5060021,0x99350012,0xfbc90009}},	//   ündü, озмо, _وفات, _ית_
  { {0x2bc60037,0xafe50015,0x37e50015,0xe1f00012}},	//   रुवा, _долл, _долг, _أسم_
  { {0xf1b20009,0x2bcf0011,0x660d005e,0xb87b0097}},	//   _חסד_, _स्मा, _ebak, _svín
  { {0x645c0028,0x6fe20066,0x3ce60011,0x625c0025}},	//   rhri, sící, _झटके_, _féod
  { {0x44d60002,0x2176004c,0x03a3003c,0x3ced001b}},	//   ył_, оузр, фисо, ševa_
  { {0x752d1725,0x8bb60003,0x20c90012,0x11d70012}},	// [6b40] _graz, _وإدا, مبلي_, زولة_
  { {0x40960024,0x40e80009,0x10a60b4e,0xb5fb107f}},	//   ірат, מַעֲ, цизн, siát
  { {0x6e240101,0x11d60003,0xef1a020e,0x2bd00321}},	//   _kaib, _وتحد, рме_, _त्या
  { {0xb5fb26db,0xb87b0065,0x1ea90003,0x91f60012}},	//   chád, _hvíl, ماني_, _بأدا
  { {0x6e24002c,0x7bda00b6,0xa4d40024,0xddc20034}},	//   _maib, _petu, чолі, mnoż
  { {0x98a60066,0x8c430001,0xc953000b,0xf2c601b6}},	//   _proč_, деље, _חמש_, осин
  { {0xd25a0ac5,0xd2a60024,0x6c830012,0xbc670012}},	//   ици_, _тiль, بلوم, تمون_
  { {0xd378001c,0x61fb003b,0xd2b70009,0x69c41c5c}},	//   _neće_, ggul, חלקת_, ncie
  { {0x22b5001e,0x601f0010,0xb97a0009,0xdddd0064}},	//   _sākt_, kšmė, ינֵי, nosť
  { {0xa7fc00a2,0x3137000b,0xc8660003,0xbfaa0001}},	//   lnız, קנים_, تطبي, итне_
  { {0x22460036,0x3817000b,0xd7bb000b,0xb9e60024}},	//   _took_, חקים_, יציר, _діли
  { {0x28db0037,0xe667002d,0x6448014a,0x69c40002}},	//   मीडि, ітно, _hodi, jcie
  { {0x61e000a2,0x64b50011,0x70560012,0x2aaa0034}},	//   maml, ंदेश, _ونصا, róbę_
  { {0x61e02683,0xd00f0003,0xc1d30037,0xd197000b}},	//   laml, _لله_, तर्ग, _וכדי_
  { {0x6e240061,0x9f47003a,0x9f5e01e3,0x644826dc}},	//   _faib, ünü_, retó_, _modi
  { {0xddc400a2,0xa75b000b,0x2129009b,0x95cb0014}},	//   _iliş, _כדור, tvah_, _тука_
  { {0x50f50047,0x79c80003,0xf19401d4,0x2fcb0012}},	// [6b50] язат, توقف_, дить, لباً_
  { {0x644826dd,0xf72b0015,0xb5fb0017,0x69c426de}},	//   _nodi, ицей_, ciár, acie
  { {0xddc60039,0x87e40047,0x61fb003a,0x501b000b}},	//   likš, ьюте, ygul, שובו
  { {0xfb1a000b,0x8f8b0009,0x8ed80012,0x68e426df}},	//   _פורמ, בְדֵ, تذكر_, bsid
  { {0x672e0163,0x6a3a000b,0xddc20002,0xaa3a000b}},	//   _erbj, _הגרפ, lkoś, _התרח
  { {0x7c25008b,0x49140037,0x64550070,0x00ba0009}},	//   _jahr, _नैटो_, nkzi, _למשמ
  { {0x69dd00c6,0x62840010,0x99990029,0x644826e0}},	//   _kese, čion, _dosť_, _dodi
  { {0x22b5001e,0x645a1b3c,0x6b7c0009,0xdb7c0009}},	//   _sāks_, _elti, ירונ, ינוכ
  { {0x2bcf0044,0xe80b0044,0x5155002d,0x36040012}},	//   _स्था, स्था_, ятку, _توقف
  { {0x6448001c,0x6e240017,0x7c2526e1,0xfc300012}},	//   _godi, _saib, _nahr, _لحم_
  { {0x69c40002,0xa207003a,0xcc560009,0xe8030011}},	//   ycie, şmış_, _צבעי_, _लाना_
  { {0x442500c6,0xfbcf0037,0xe80b0037,0x4427002a}},	//   _hal_, _स्तम, स्ता_, ldn_
  { {0xd3780027,0x91ba000b,0x6fdc0011,0x49ba0009}},	//   _veće_, _המני, _फ़लू, _המנס
  { {0x8b080066,0xb042001a,0xb5fb000e,0xdb1c01e3}},	//   jdří, _thưở, gháb, scrí
  { {0x69dd066e,0x765b003a,0xb7da0009,0x82a60024}},	//   _bese, _oluy, _הקצי, завж
  { {0xb21b00c5,0x78b50039,0x69c426e2,0xdddd0064}},	//   _skær, _aizv, ucie, tosť
  { {0x7c25008b,0x15fb000b,0x68e40010,0x69dd245e}},	// [6b60] _fahr, _ההפע, usid, _dese
  { {0x3979007c,0xc0790020,0xd1790024,0xb4d80011}},	//   істю_, _điệp_, істі_, ाठी_
  { {0x3bbb0093,0x0dca002d,0x141b0009,0x41dc0011}},	//   _למיד, були_, _פוטב, बरदस
  { {0x9e650003,0x69dd0518,0x7c250107,0x7d560009}},	//   وانن, _gese, _zahr, ּיַד_
  { {0x7bde00c6,0xacf8002d,0x27e10480,0x9be60024}},	//   _kepu, інку_, bahn_, пійк
  { {0x442503eb,0xe8030011,0xdfd20012,0x3ced0011}},	//   _cal_, _लाया_, _سير_, _घिरे_
  { {0x442501a2,0x026a003c,0x64482123,0x8c1b0009}},	//   _dal_, йший_, _vodi, מוסי
  { {0x0f7b000b,0xcb13000b,0xdb010028,0x877b0009}},	//   _האלב, גלה_, _uglý, _האלי
  { {0x15e30037,0x64481cde,0xe8030011,0x645d0073}},	//   _ख़बर_, _todi, _लामा_, _įsiv
  { {0x61e026e3,0xe7860f09,0x645a26e4,0x05770012}},	//   saml, зумо, _ulti, _عملة_
  { {0x21270020,0x3e75015b,0xd9a90011,0x00570009}},	//   ̉nh_, sťte_, _कण्ट, פשטת_
  { {0x442526e5,0xb2bb0009,0x79820034,0xbb3b0009}},	//   _zal_, _המאר, żowy, _לעבי
  { {0xb05b008e,0xda650012,0x69340024,0x7d1d0227}},	//   _itäv, _تالي, _інку, uwss
  { {0x69dd01eb,0xd4910081,0x201a001b,0x2bb80012}},	//   _sese, ồ_, jepi_, كافة_
  { {0x9295002d,0x9f62004a,0x7bde26e6,0xcb340048}},	//   давц, ävän_, _depu, неръ
  { {0x7c25008b,0x58d90593,0x2f970009,0x9f7b0009}},	//   _wahr, ждая_, _מכון_, _לנוח
  { {0xc1050012,0x6441005e,0x64430034,0x7c250dd2}},	// [6b70] بوذي, ölis, yjni, _tahr
  { {0x2fc70020,0x69dd00f7,0x7bde0ad2,0x1fa70451}},	//   ùng_, _wese, _gepu, прег
  { {0xddc9001b,0xc7d70009,0x7f190012,0xe7190012}},	//   _vjež, פואי_, تياز_, تيات_
  { {0xd5b10012,0xf1c20073,0x442526e7,0x7e7d26e8}},	//   نفا_, nešę_, _sal_, nnsp
  { {0xece8002d,0x69dd0028,0xcd280012,0x04c80012}},	//   зділ_, ðsem, كسون_, كوني_
  { {0x5fe10044,0x113a000b,0xc1560009,0x7bc70034}},	//   _फ़िल, _ותשל, _חששו_, ncju
  { {0x3c2d000e,0x2909004a,0x6e670014,0xd5fb0081}},	//   jövő_, ltaa_, _етаж, _chụ
  { {0x56940959,0xe2910012,0x3a29016d,0x88c9028b}},	//   _заст, خذت_, ndap_, олив_
  { {0x29090006,0x2aa1000e,0x442526e9,0x97d90012}},	//   ntaa_, tóbb_, _tal_, يبدأ_
  { {0xaec5035c,0x8ee904ac,0xe47b0012,0x6fdd0011}},	//   мбол, омов_, _احرص_, यरिं
  { {0x2909004a,0x2aa10031,0x7bde26ea,0xe80205f3}},	//   htaa_, róbb_, _repu, र्टा_
  { {0x2cbf0051,0x22420028,0xf3e9000b,0x7bde26eb}},	//   _kuud_, ökkt_, _כף_, _sepu
  { {0x2d84003a,0xdb1c0032,0xbcfb0031,0x000000c4}},	//   çme_, sbrü, szén,
  { {0x78600272,0x2cbf0051,0xe8d6000b,0x2bba0012}},	//   _köve, _muud_, _חוסר_, تاحة_
  { {0x7860000e,0x6e460003,0xa2e60048,0xa3c50011}},	//   _jöve, _ينتم, ьовд, _एलन_
  { {0xe80b0037,0x3e720010,0xcb120009,0xceb80073}},	//   स्सा_, mšto_, כלל_, avęs_
  { {0x224b26ec,0xb4760012,0x7bde016d,0x404a004c}},	// [6b80] _dock_, _يُعث, _tepu, опао_
  { {0x3942004a,0x4f5a0003,0xf1b10012,0x3e7204d2}},	//   äksi_, يجاد_, اءِ_, ošto_
  { {0x7860000f,0xb6c5002d,0x3952004a,0x26050011}},	//   _növe, есій, syys_, _वामी_
  { {0xf2d30093,0x64920058,0xe8020011,0xf8bf01e3}},	//   _שער_, pæis, र्जा_, _fué_
  { {0x68fb019a,0x051a0012,0xc5360012,0x0caa0790}},	//   juud, تزاع_, بعاث, отки_
  { {0x3ddf0070,0xd5fb001a,0x62840010,0x3e720073}},	//   _eeuw_, _phụ, čiom, kšto_
  { {0x645d007a,0xab770012,0xe8030011,0xf41300af}},	//   _įsit, ومها_, _लाता_, דפו_
  { {0x72170014,0xc7a3004d,0xda660012,0x8fa3004c}},	//   джър_, _риск, باتي, _расе
  { {0x2bcf0044,0xf5030098,0xec7a002d,0x23cf0011}},	//   _स्वा, _изто, _дпа_, _स्वद
  { {0x7afc007a,0x0c26002d,0xc057002d,0xe8020037}},	//   kurt, _імен, дію_, र्चा_
  { {0x61e41b70,0xcff70009,0x501b0009,0x3b260012}},	//   kail, וציה_, חויו, _تعذّ
  { {0xc7b3000b,0x68f60058,0xaae50003,0x7afc26ed}},	//   כבת_, kryd, _أسلو, durt
  { {0x106a0003,0x3e721187,0x5c070048,0x78600031}},	//   _وحتى_, ašto_, мява, _zöve
  { {0x40eb0009,0xa99b0009,0xe5710009,0xd6df0034}},	//   _וַהֲ, _ובדר, אַל_, ółka_
  { {0x6ffb007e,0xd7fb0009,0x04640024,0x3ffb0009}},	//   _והופ, _והול, ттям, _ופוע
  { {0x290903fc,0x61e40010,0x645e00b6,0xda090012}},	//   ttaa_, gail, _elpi, ثيره_
  { {0xf8bf02d1,0xa294002d,0xa3cf0037,0xf9900003}},	// [6b90] _qué_, таті, वुड_, لبك_
  { {0xcf9b0046,0x2909004a,0x5c74027f,0x7afc26ee}},	//   оје_, rtaa_, _альт, burt
  { {0x8bd60093,0x0c74000a,0x29090006,0x03d60093}},	//   _אותו_, _جديد, staa_, _אותם_
  { {0x28df0044,0x7c280005,0xfe10001a,0x68f619d7}},	//   पीडि, _aadr, _lắng_, bryd
  { {0xceb4000b,0x64680051,0xed58002d,0x91f60009}},	//   דיף_, _äriü, мої_, _אמרו_
  { {0x7c2826ef,0x68fb004a,0xd8da000b,0xb4fc0009}},	//   _cadr, vuud, _מקשר, קפוי
  { {0xbef80003,0x661d26f0,0xaae40012,0xf77300ae}},	//   _يرفض_, kesk, نسيو, _شاس_
  { {0xfbb8000b,0xdd950015,0xdb0e0066,0x65950055}},	//   ופות_, _забы, ádán, _забу
  { {0xd3780027,0x39590028,0xf1b9001b,0x661d26f1}},	//   _veća_, áss_, ješe_, desk
  { {0xd198000b,0x1cb80003,0x661d0051,0x68fb019a}},	//   וכחי_, _قالب_, eesk, ruud
  { {0x68fb0006,0xbcfb000f,0x6e290051,0xe3b30003}},	//   suud, szél, _kaeb, _شرط_
  { {0x3f99001e,0xc7b20009,0x68fb005e,0xb9950012}},	//   āsu_, טבי_, puud, _كلاب
  { {0x916c0020,0xd6560009,0x61e426f2,0xd5b20009}},	//   _gồm_, גירת_, vail, ָׁם_
  { {0xe0060044,0xc4d2000b,0xfe10001a,0x7afc26f3}},	//   _शायद_, רגם_, _gắng_, turt
  { {0xa6960046,0x6a860014,0x68e926f4,0x96960a41}},	//   _приј, елва, lsed, _приш
  { {0x7afc0052,0x69c91748,0x2bd00011,0xb5fb0030}},	//   rurt, ncee, _त्रा, lhán
  { {0x6a8300f5,0xe2830867,0x68e926f5,0x867b0009}},	// [6ba0] улта, улти, nsed, _מרקו
  { {0xb88200f1,0x2bcf0037,0x4b260024,0x0446004c}},	//   _čísl, _स्ला, _змов, _чеон
  { {0xdfcf0003,0xe3b20012,0x68e90060,0x91e619c1}},	//   صين_, _حرة_, hsed, _поне
  { {0x7c28001c,0x61460001,0x63a1000e,0xfce6022a}},	//   _sadr, _зема, ülne, еодо
  { {0x7c2826f6,0x7e620248,0x645d0073,0xa9bb0009}},	//   _padr, rhop, _įsir, _מזכר
  { {0x69cb00bd,0x8c43004d,0xa5d00011,0x04430048}},	//   _afge, лече, _ड्रौ, лечн
  { {0x68e9012e,0xfbd3000b,0xe6c50012,0x9bc70012}},	//   esed, נתה_, _لتقي, رويك_
  { {0x5a340098,0x0dc90003,0x89380232,0x5eeb0009}},	//   тнит, _يبقى_, дпис_, _מַמְ
  { {0x661d26f7,0xbc760012,0xb05b008e,0x28da0011}},	//   vesk, _كهرب, _itär, _मौखि
  { {0xbc6a0003,0xb5fb0066,0x99820030,0x66020031}},	//   _عمان_, ghán, žků_, lgok
  { {0x1df90015,0x2eaa000b,0xfe100081,0xa5f914cf}},	//   мены_, ּשָּ, _vắng_, мену_
  { {0xea01001a,0x69c926f8,0xff7b0009,0x877b0009}},	//   _đầy_, ccee, לטימ, לאיי
  { {0x661d26f9,0x15a80048,0xc05a0024,0x7c870545}},	//   resk, еъри_, _нік_, еуве
  { {0x493b0009,0xb5fb26fa,0x661d26fb,0xd12f00ae}},	//   _מגדו, chán, sesk, _دمه_
  { {0x60c20006,0xab950129,0x82a70015,0xd25b010b}},	//   _huom, тиві, ешае, пца_
  { {0x9f9b000b,0x66e70066,0xbf9b000b,0x1f370009}},	//   _מסופ, _léká, _מיוש, _טרור_
  { {0x2cff0044,0x60c2008e,0xddc9004b,0x6aad26fc}},	// [6bb0] _ईमेल_, _juom, _aleş, rmaf
  { {0x75220034,0xb9940012,0xa98b0009,0x7d7c0009}},	//   dwoz, الْب, הָבִ, _מנחו
  { {0x60c20006,0xf412000b,0xe1d9002d,0x1fe10011}},	//   _luom, _דפי_, _одні_, _फ़ीड
  { {0x201e000f,0xcad6000b,0xa3d90037,0xd57501d4}},	//   heti_, _שורת_, ारक_, куль
  { {0x60c20010,0xddc926fd,0x5a3401ec,0x2d58002d}},	//   _nuom, _eleş, _снят, ниць_
  { {0x00f6000b,0x201e080a,0x224926fe,0x66020031}},	//   _במשך_, jeti_, ljak_, agok
  { {0xe7840014,0x5c38000b,0x61e2000e,0xdde3000e}},	//   _буто, תרון_, _beol, űről
  { {0x68e90051,0xc334000b,0xc1050003,0x4dd70012}},	//   tsed, רוק_, نوبي, _سترس
  { {0xd24e0003,0xd5140012,0x74f8003c,0xee84003c}},	//   تني_, _مبلغ, _петр_, _сыро
  { {0x60c2007a,0x68e9041e,0x85740479,0x62800040}},	//   _duom, rsed, _слух, anmo
  { {0x200b0002,0xf1d20037,0x0a150012,0xf7710012}},	//   ęci_, _ध्वन, _لواح, شاد_
  { {0x8cd80037,0x74d80011,0x3255004c,0xf1bb0011}},	//   नीको, नीकृ, _швер, _उलटन
  { {0x26fe0037,0xceb2000b,0xd0090001,0x7ebe0071}},	//   _उम्र_, ייט_, _желе_, _rūpe
  { {0xb4fa0093,0xdb0d0028,0x224900b6,0xac970012}},	//   ופשי, _þjóf, ejak_, َنَا_
  { {0xfe0a0044,0xe29a00fa,0xeb970001,0xe8480003}},	//   _वापस_, дав_, вир_, _سجون_
  { {0xc332000b,0xc0b90066,0xba1a0012,0x625c0025}},	//   סון_, řádá, بيرا_, _néol
  { {0x8e970009,0x41b30012,0xbebc0035,0x661d0097}},	// [6bc0] _בדקו_, لمفر, svīt, _ósky
  { {0xb21b00c5,0xed57000b,0xb05b031d,0x3cfb0009}},	//   _hjæl, _סביר_, _stär, _קלינ
  { {0x52aa0046,0xe8030037,0xf62a002d,0x645d0010}},	//   _овом_, _लारा_, діли_, _įsip
  { {0x75360034,0x66020073,0x201e26ff,0x6cd600ae}},	//   _kryz, ugok, zeti_, نقصا
  { {0x201e003a,0x2d8f0058,0xd46a004c,0x645c07a5}},	//   yeti_, _øget_, миде_, okri
  { {0x61e200b6,0x12ca0012,0x201e0097,0x63a90030}},	//   _seol, وظبي_, _úti_, řene
  { {0xcb070003,0x53ac0037,0x60c22700,0x60170009}},	//   نيون_, टेंश, _suom, _שחלף_
  { {0x75d30012,0x625c0025,0xb5fb0031,0xddc7004b}},	//   _نيفا, _géol, ghál, ălţa
  { {0xba9b0009,0x41180012,0x0c2606bd,0xa3e20011}},	//   וסקי, ريدج_, _иман, दरा_
  { {0xea01001a,0xa067004c,0xb4250012,0x331a0012}},	//   _đấy_, кања_, _معمو, _يزاد_
  { {0x3ffb000b,0x661b0051,0x57fb0009,0x00570009}},	//   ופיע, õuko, וליו, דשית_
  { {0x442c0eaf,0xcf93000b,0xb87b0028,0xc2e90003}},	//   _had_, יטת_, _hvít, _أعلم_
  { {0xda65000a,0xc693000b,0x442c2701,0xe9180024}},	//   _حالي, שאר_, _kad_, _чолі_
  { {0x3ea90036,0xd010000a,0x1fe10011,0x645c2702}},	//   _what_, _طلب_, _फ़ेड, gkri
  { {0x3ea90274,0x13b4000a,0x1fa30014,0x443e0051}},	//   _that_, لصفح, _кръг, _mnt_
  { {0xfe0a0037,0x442c01a9,0x32640024,0xaa640048}},	//   _वायस_, _lad_, атув, атук
  { {0x443e0108,0x2d8f0061,0xa9540024,0x75360034}},	// [6bd0] _ont_, _âge_, акті, _gryz
  { {0xf1b90708,0x1fd80003,0x7ff40003,0x94ab0012}},	//   neša_, نظمة_, لسما, _تطبق_
  { {0x6e2d002e,0x2bd90011,0xc2cb0012,0x2ef50223}},	//   _kaab, _ब्या, _تبخل_, узер
  { {0x443e0acb,0x20d70003,0xa2c00037,0x20070034}},	//   _ant_, _لتسج, वदर्, żni_
  { {0x6e2d002c,0x76880060,0x645a0032,0x442c2703}},	//   _maab, nıya, ötig, _bad_
  { {0xc1b8002d,0x07f80012,0xc1720009,0x9f650031}},	//   _шлях_, _لرفع_, _פחם_, átót_
  { {0xc5fb0003,0xf0920009,0x442c2704,0xe2990b12}},	//   _يعرض_, _הנם_, _dad_, нак_
  { {0x0b16000a,0xa3d30037,0x78bc003a,0x83160003}},	//   اقية_, हुत_, _zirv, اقير_
  { {0x64b500a2,0x290d000d,0x625c0061,0x68ed2705}},	//   eğiş, utea_, _géom, nsad
  { {0x290d007d,0xe8f60015,0x6d590002,0xb21b014f}},	//   rtea_, ыль_, mywa, _sjæl
  { {0x290d007d,0xfc300003,0xdb240060,0x99990073}},	//   stea_, _بحق_, örür, _kosų_
  { {0x98ad009b,0x01350012,0x8e860012,0x290d004b}},	//   mveč_, _معتد, الحه, ptea_
  { {0x6d590002,0x865a0009,0xa3f6003c,0xe2900012}},	//   nywa, גדרי, лявш, _بذل_
  { {0x68ed0058,0xbf650003,0x765d0002,0xab2a0430}},	//   dsad, _مدعو, aksy, нога_
  { {0x6eca0044,0xe739003c,0x06f50012,0x645c2706}},	//   _संयु, _чей_, _إستج, rkri
  { {0xddcf000d,0x3e720073,0x2900004b,0x78bc2707}},	//   ricţ, kšti_, tuia_, _sirv
  { {0x25d7000b,0x7e64002c,0x2d85003a,0x645c0010}},	// [6be0] _גופן_, _ilip, şler_, pkri
  { {0xa41b0037,0x6d590002,0x2900000d,0x20c90081}},	//   _पॉपप_, dywa, ruia_, _múi_
  { {0x98ad012e,0xf7720003,0x2d8f0058,0x68ed2708}},	//   jveč_, حاء_, _øger_, asad
  { {0xe8130037,0x1ea90003,0x442c02f6,0x99800029}},	//   त्ता_, ناني_, _sad_, ediť_
  { {0xf8c80020,0x20c9001a,0x68ed000e,0xa2b30011}},	//   _mức_, _núi_, csad, ूआरऍ
  { {0x62840002,0x626c000d,0xac1809e3,0xddc90159}},	//   lnio, cşor, току_, _vmeš
  { {0x26050044,0x442c2709,0x1fb50015,0x7863002d}},	//   _वाली_, _vad_, _встр, _укрз
  { {0x82a60015,0x200500c1,0x6d590002,0x6284270a}},	//   ышле, egli_, bywa, nnio
  { {0x61e60333,0x442c0708,0x2bcf0037,0xddc904d2}},	//   _mekl, _tad_, _स्का, _umeš
  { {0xdefa0047,0xb5fb0065,0x80aa0044,0xad1b000b}},	//   ным_, rhám, _जीमे, _אומר
  { {0xb8cb015f,0xf8c8001a,0x61e9000e,0x60c6016d}},	//   _की_, _bức_, bael, _lukm
  { {0x69dd0065,0x7bdc00bd,0x6e95007c,0x1eab0003}},	//   ðset, ebru, риму, عادي_
  { {0x2293000a,0x6284003e,0x7d020010,0x201801a0}},	//   _النس, dnio, nuos, _obri_
  { {0x6284003e,0x69ba0037,0x6f010066,0xd7ef0001}},	//   enio, ्शनी, bulc, _ћу_
  { {0x6d59003e,0x7e640065,0x309b000b,0xa7370003}},	//   zywa, _flip, _רשומ, _مثير_
  { {0x5bb80015,0x539b0009,0x9ef30012,0x7e642236}},	//   улся_, גילו, _اسوش, _glip
  { {0x7d020010,0x98750294,0xa0750560,0x28f8003c}},	// [6bf0] juos, алац, агач, леть_
  { {0xdb1f000e,0x2c6611df,0x33750472,0xa49b01a0}},	//   ívój, _pôde_, _вгор, atòr
  { {0x6d59003e,0x44230002,0x645a004a,0x5dd50012}},	//   wywa, mej_, ötie, لقائ
  { {0xcf980046,0x6d590002,0xa49b0054,0x61e601e0}},	//   ују_, tywa, ctòr, _gekl
  { {0x58870015,0xade80012,0x7d020073,0x61e9270b}},	//   _быва, افهم_, guos, vael
  { {0xc484007c,0x44231062,0x6d590002,0xb5fb000e}},	//   блік, nej_, rywa, nkáb
  { {0x6d590002,0x99800029,0x9f51003a,0xdc3c0009}},	//   sywa, rdiť_, üzü_, תעור
  { {0x7f840003,0x4423119d,0xb87b0097,0x6d590034}},	//   _الفن, hej_, _tvís, pywa
  { {0x44230026,0x0d670014,0xf06516e6,0x72b60012}},	//   kej_, _съвм, икип, جهيز_
  { {0x44231062,0xf8c8001a,0xa8550001,0xe7390001}},	//   jej_, _sức_, ртиј, вео_
  { {0xfe460047,0x38ab0033,0xf43a000b,0x200500c1}},	//   анно, jøre_, _שתעש, rgli_
  { {0x4431208f,0xed5a14bd,0xd1cb0148,0x20c90081}},	//   edz_, вом_, _чужд_, _túi_
  { {0xc0e51103,0x62960025,0x7bdc24b3,0xa6960009}},	//   _толк, voyo, tbru, שכרה_
  { {0xe3b20003,0xdde5001e,0x38ab0989,0x224d009b}},	//   قرأ_, āpša, føre_, ljek_
  { {0xddcd00a2,0xf8c80020,0x46a6029b,0x38ab0058}},	//   _ulaş, _tức_, _какв, gøre_
  { {0x768800a2,0x471a000b,0x6eca0037,0xb3470017}},	//   mıyo, _יוצג, _संतु, _seçõ

  { {0x7688003a,0x4423009b,0x7bdc0f85,0x70b60012}},	// [6c00] lıyo, bej_, pbru, لمرض
  { {0xa49b0054,0x26c700b6,0x4423270c,0x7d021598}},	//   stòr, _kuno_, cej_, vuos
  { {0x61e600a2,0x768800a2,0xbb460001,0x62840002}},	//   _tekl, nıyo, _тенк, pnio
  { {0xed5a035b,0x60c6002c,0x7d02270d,0xeabf00b8}},	//   кое_, _tukm, tuos, _giù_
  { {0x1bd40014,0xe5340055,0x7640008e,0xf9920012}},	//   боля, сель, ömyy, _ذبح_
  { {0x5c73007c,0xb6020066,0x7688003a,0xf53701b0}},	//   оліт, _řádk, kıyo, ינני_
  { {0xb5fb0013,0x7d020079,0xbbe90012,0xc3270012}},	//   nkác, suos, ارهم_, لكون_
  { {0xd2570047,0x6cd60003,0x6441270e,0x44230eb4}},	//   ицы_, _نقرا, _enli, zej_
  { {0x26da004a,0x15fb0009,0xb6bb0009,0x48aa0400}},	//   lppo_, _שהמע, _יצלי, ктом_
  { {0x32ca0020,0x0b1a0003,0x200a0051,0x00760009}},	//   _tùy_, _لقطة_, übi_, יתִי_
  { {0x44230026,0x50b7000a,0x27e7008b,0xf837000b}},	//   vej_, جديد_, _denn_, בנית_
  { {0x4423003e,0x6f030054,0x62840010,0xe37b0009}},	//   wej_, ànci, čios, _ברבר
  { {0x44232338,0x7688003a,0xa7fc0060,0xf5390030}},	//   tej_, mıyl, tkıd, íť_
  { {0x515b000b,0x2904270f,0xb5fb0031,0x25a903a7}},	//   _בכדו, muma_, ukáb, _vzal_
  { {0xeabf01a2,0xee870047,0xdb580047,0x4df80011}},	//   _più_, _выпо, ают_, ुलाई_
  { {0xd7bb0093,0x8f9b000b,0x59f80015,0x7afa0028}},	//   _בצור, _שיהי, иеся_, átta
  { {0x29042710,0x27c7003c,0x7e7d2711,0xfce4004c}},	// [6c10] numa_, ащег, misp, _доњо
  { {0x7e7d2712,0xe9180024,0x859c0009,0x764f1027}},	//   lisp, рофі_, _בשחו, ljcy
  { {0xc5d5007c,0x9f040012,0x64b40012,0x29040b83}},	//   біль, قولو, _بحير, huma_
  { {0x29040471,0xf2d2000b,0x87080024,0xee320009}},	//   kuma_, _מעט_, реїв_, ּֽא_
  { {0x29040039,0x61ed00b9,0x224d0027,0x76881c8b}},	//   juma_, maal, vjek_, zıyo
  { {0xa3be0044,0xbcfb000e,0x91ba000b,0x3156000b}},	//   ुँच_, lzés, _תמשי, _הישן_
  { {0xf8b2000b,0x7ebf001e,0x8c1c0009,0xbbf80024}},	//   _משך_, _rūpn, דווי, рхії_
  { {0xc24502e2,0x8e850003,0x569400fa,0x61ed2713}},	//   сник, _الره, _даст, naal
  { {0xa1120003,0x661b02a0,0x29042714,0x3209020d}},	//   كويت, _ibuk, guma_, igay_
  { {0x44230272,0x316d003e,0x6441002a,0x7cfe0028}},	//   _új_, rzez_, _unli, _lærð
  { {0x2bdd0037,0x20540014,0x27e72715,0xbcfb01c4}},	//   _न्या, ютър, _venn_, zzét
  { {0x27e7008b,0x7688003a,0x6ed3000d,0x212900b6}},	//   _wenn_, cıyl, _răbd, kwah_
  { {0xd3780027,0x05550a32,0x9f452716,0x24982717}},	//   _reći_, отря, malí_, torm_
  { {0x43f90015,0x7688003a,0xa3d30037,0xc0b2001a}},	//   ихся_, pıyo, हुल_, _mười_
  { {0xcaa60003,0xe79a0066,0x0b59003c,0x7fd60009}},	//   مصري, _těší, арты_, _פוקס_
  { {0x57560093,0xe8130037,0xbcfb000e,0x61ed0818}},	//   _לבצע_, त्रा_, gzés, gaal
  { {0xc693000b,0xd3780027,0x2f11000e,0x614305fb}},	// [6c20] _מאה_, _veći_, lág_, пета
  { {0x7d060006,0x6e26000e,0xf537000b,0x3209020d}},	//   muks, lekb, _פריז_, agay_
  { {0x7cfe0065,0x20b90015,0x44442718,0x9956001e}},	//   _færð, рыть_, _in_, _kļūt_
  { {0xdee50003,0x69da004b,0xfb1b0009,0x9e140024}},	//   تأكي, _ştef, _גוטמ, ідлі
  { {0xc0b2001a,0x753b01c5,0xba9b0009,0x65960012}},	//   _cười_, _cruz, _תסכי, حجار
  { {0x6aa40065,0x29042719,0x86ea0012,0x55bb0009}},	//   llif, vuma_, _معرف_, אמנו
  { {0x3ed8000b,0x7d06005e,0x4ed80009,0x753b00b8}},	//   _כַּא, huks, _כַּנ, _eruz
  { {0x60f81438,0x3254002d,0x66f7000b,0x2900271a}},	//   ания_, івпр, _למלא_, oria_
  { {0x768800a2,0xc05a002d,0xa3d80037,0x31340014}},	//   rıyl, гін_, ाडा_, цепр
  { {0x082a0014,0x7688003a,0x7d06271b,0x2ef40209}},	//   уции_, sıyl, duks, озор
  { {0x6aa400a2,0x309b000b,0xab960003,0xdd12001e}},	//   klif, רשימ, _الضغ, kļūt
  { {0x6d5d004a,0x1dbc0037,0x6e670014,0x38a20028}},	//   tysa, _ऋणात, стож, iðri_
  { {0x09360012,0x88c60012,0xbcfb0031,0xa2b90011}},	//   _دراج, _اتصل, ezér, ्दस्
  { {0x26d8271c,0x656f0002,0x7644003a,0x29000054}},	//   _otro_, rzch, _eniy, dria_
  { {0xf3f1001a,0xa87b000b,0x6017000b,0x7e62271d}},	//   _học_, _תאור, _החוף_, kkop
  { {0x2bd90044,0x63a90066,0x23d90011,0xbb840012}},	//   _ब्रा, řeno, _ब्रद, ألفي
  { {0xbcfb000f,0x10d8000a,0x61ed271e,0x2900271f}},	// [6c30] rzés, مبلغ_, raal, gria_
  { {0xd8770012,0xbcfb0031,0x91d90011,0x7e622720}},	//   حارب, szés, _फ्रै, ekop
  { {0xf3f1001a,0x61ed2721,0x6285119d,0x501b0009}},	//   _lọc_, paal, éhok, רובו
  { {0xf8c80037,0xf5ab0009,0x2c6b07c2,0x7c270040}},	//   रदाय, ְבַּ, _møde_, lejr
  { {0xccfb0001,0x2f11000e,0xb6bc0009,0x44442722}},	//   уће_, zág_, אצאי, _yn_
  { {0x6ab30037,0xf7730003,0x8c420538,0x351c0009}},	//   ुद्र, _فاز_, деше, טודנ
  { {0xfcb20029,0x2bf80009,0x6bec0009,0x4dfb0011}},	//   úšať_, זמון_, אַחַ, ्लाई_
  { {0x6b7c000b,0x9f430066,0x3ce0000d,0x5b7c0009}},	//   טרונ, _její_, ţiva_, טרוא
  { {0x7e8b0002,0xb1450024,0x6e260031,0x39450024}},	//   tępn, інол, vekb, іног
  { {0xef19011f,0xe3b30003,0x2bd90037,0xa8740015}},	//   амо_, _فرض_, _ब्ला, зующ
  { {0xdb1f004a,0x6e26000e,0x7c270002,0x7e69095d}},	//   äväs, tekb, dejr, _klep
  { {0x7d0603fc,0xa3bf0037,0x60db004a,0x2f11000e}},	//   tuks, ेशन_, ppum, rág_
  { {0x2f11000e,0x0ab80012,0x1c1e0011,0xd8750012}},	//   ság_, _اطلب_, _मॉडल_, _واتب
  { {0x6e26000e,0x66e50c1e,0x7d062723,0xf9b60009}},	//   sekb, _дока, ruks, _והנך_
  { {0xa3b40044,0x44442724,0x60cb0028,0x389a0009}},	//   जें_, _vn_, _hugm, _דיסנ
  { {0x44272725,0x61eb0052,0x7d0615ff,0xc3320009}},	//   hen_, _jegl, puks, וול_
  { {0xbcfb000e,0x01d70003,0x44272726,0x61eb2727}},	// [6c40] szér, توقع_, ken_, _megl
  { {0xf8bb0011,0xb8060012,0x44272728,0x394d2729}},	//   ैदिय, تبره, jen_, ixes_
  { {0xd6cf0003,0x96fa0003,0x97260003,0x46f60021}},	//   نقل_, شعار_, تفاو, ючат
  { {0xf3f10020,0xf8a9000b,0x61eb272a,0xd6260012}},	//   ực_, דש_, _negl, تعطي
  { {0x1ea9000a,0xa2b90037,0x4427272b,0xbc4a0001}},	//   حالي_, ्दर्, fen_, ичке_
  { {0x66e60146,0x61eb0051,0xe3b20012,0x3d1b0011}},	//   _мога, _aegl, ورغ_, मझते_
  { {0x61eb0052,0x60cb1000,0x7e62272c,0xcb67004c}},	//   _begl, _augm, pkop, жаје_
  { {0x41e6002d,0xa7a7002d,0x1fa7002d,0x7c270002}},	//   ціка, _єкта_, _єкти_, zejr
  { {0x61eb01a2,0x4427272d,0xbe130012,0x91b70048}},	//   _degl, ben_, _توقع, огът_
  { {0x60cb001c,0x7e69022d,0x3ea00b7c,0x4427272e}},	//   _dugm, _zlep, _akit_, cen_
  { {0xd838009b,0xbb860012,0xd6d4003c,0xda660012}},	//   joče_, _بلاي, яжны, _واصي
  { {0x60c30052,0x539b0009,0x645a005e,0x61eb0032}},	//   _einm, _דיבו, ötin, _gegl
  { {0xd3780027,0xc5f30009,0x5d850012,0xf3f10081}},	//   _veću_, ודר_, سلسل, _họa_
  { {0x27170066,0x6280272f,0x7faa0011,0x2bdd0011}},	//   něná_, limo, _करूँ, नुपा
  { {0xd838012e,0xf2d80009,0xcb340048,0x23650031}},	//   goče_, מַּל, меръ, álj_
  { {0x8cf50014,0x4789002d,0x4e780012,0x44330132}},	//   _езиц, _усім_, _وحيد_, _wax_
  { {0x44332730,0x44272731,0xe0d00012,0x5bc70012}},	// [6c50] _tax_, yen_, نزل_, _وتدف
  { {0x17fb0003,0x44272732,0x29880024,0xd8380159}},	//   شرطة_, xen_, істо_, ločb_
  { {0xc5d5002d,0x44272733,0x27170030,0x25ad0031}},	//   піль, ven_, děná_, _szel_
  { {0x442711c5,0x35b5004c,0x3ea60035,0xcfb70009}},	//   wen_, пбер, glot_, קלאי_
  { {0x61e20164,0xa5bb000e,0x628001c5,0x61eb2734}},	//   ñole, deók, dimo, _regl
  { {0x61eb0054,0x44272735,0x7af50053,0x19ba0009}},	//   _segl, uen_, oszt, _למרב
  { {0x2909004a,0x29ff0034,0x96f8004c,0xe784004c}},	//   luaa_, ałał_, _мерт_, _жуто
  { {0x7860000e,0x7e690002,0x394d0054,0x7af5000e}},	//   _rövi, _ulep, txes_, iszt
  { {0x44272736,0xe8060011,0xa3eb0011,0x5c750048}},	//   pen_, _शाखा_, मरा_, _елат
  { {0xe5c4007c,0xd0090046,0x7af50002,0x394d2737}},	//   _істо, љене_, kszt, rxes_
  { {0x786d0065,0x628f0034,0xf1b90035,0x4eb50009}},	//   _núve, _ojco, ieši_, ּהָב_
  { {0xeaae002d,0x60cb002c,0xe1ff0028,0xb5fb2738}},	//   _їй_, _tugm, _blóm_, skán
  { {0xe79a0066,0xd94500f5,0x7af50123,0x91870012}},	//   _měří, _хели, eszt, _بجام
  { {0xc1720093,0x3e620065,0xa156000b,0x6ab40037}},	//   _אחד_, _móti_, _מבנה_, ंग्र
  { {0xe9df0028,0x0339002d,0x09e60063,0x290b0064}},	//   _snúa_, оїть_, зобн, žiaľ_
  { {0x32d10020,0xc332000b,0x5efa000b,0x7f760009}},	//   _máy_, עון_, _הפקד, _מעצב_
  { {0xdfd20003,0xe7f20011,0xd8380159,0x7af50b89}},	// [6c60] فيذ_, _आजमा_, soče_, aszt
  { {0x44e9003e,0x2bdd0037,0xf3f1001a,0xb53b0009}},	//   dź_, नुमा, ựa_, _פגיש
  { {0xa7fc00a2,0x6e36003a,0xd00f0003,0xef1a0001}},	//   kkın, _kayb, الم_, сме_
  { {0x442a18c0,0xb5fb000e,0x8ca40011,0x69b40011}},	//   leb_, lhár, _चीजो, _आरपी
  { {0xb2bb000b,0xe8190011,0xb1430024,0x27170030}},	//   _למטר, न्हा_, _знял, těná_
  { {0x442a0005,0x251b0009,0x7eb100b0,0x1c1f0011}},	//   neb_, מונא, våpe, म्पल_
  { {0x66110006,0x9f58003a,0x29ff0002,0x62802739}},	//   ähkö, ürü_, słał_, timo
  { {0x442a0051,0xe6170015,0x46a3057e,0x61e4273a}},	//   heb_, _ндс_, _засв, nbil
  { {0xb21b0722,0x6e930012,0x9f4503a7,0x99d30012}},	//   _kjær, _ألقا, valá_, رتيا
  { {0x98730015,0x645a004a,0xc4c50003,0x7af50034}},	//   ельц, ötil, _قتلو, yszt
  { {0x7bdb0093,0x1faa0037,0x6562008e,0x6e36020d}},	//   _הקבו, _करोड, lyoh, _bayb
  { {0x442a005e,0x20020060,0x93250012,0x673a00b0}},	//   eeb_, şki_, _تركن, rvtj
  { {0x645a019a,0x4a570009,0x50460024,0xf1bf0030}},	//   _koti, _משאל_, _недб, žár_
  { {0x27e9008a,0x91bb0093,0xd3660003,0x19bb0009}},	//   _đang_, _המדי, نه_, _המדב
  { {0x9ee80012,0x7af50031,0xe8100011,0xf8370009}},	//   _بفعل_, uszt, ालना_, _זנות_
  { {0x61e4002c,0xfbdf001a,0xd6eb0009,0xbf650012}},	//   gbil, _đêm_, _הַזָ, _تدهو
  { {0xd49b007c,0xa3cc0037,0x02b70009,0x7af50031}},	// [6c70] _грн_, रखा_, להלם_, sszt
  { {0x3942008e,0xb5fb0064,0x2f150248,0x7d280031}},	//   äksy_, chár, tåg_, őssé
  { {0x61e40052,0xcdd50009,0xa5bb0031,0xab950024}},	//   bbil, ֥ךְ_, deói, _цині
  { {0xdbf70011,0x56940048,0x6448273b,0x68f60034}},	//   ील्ड_, нахт, _andi, bsyd
  { {0xc7b8001c,0x645a0054,0xe79a0066,0x6a3a0009}},	//   među_, _boti, _věří, _וגרפ
  { {0xdfc60003,0x38b4006f,0x9203001e,0x42d90148}},	//   _لي_, gärd_, žādu, офия_
  { {0x64550070,0xff0401ec,0x645a273c,0x24960012}},	//   ijzi, _пятн, _doti, بنود_
  { {0x628d0051,0x442a0b32,0xb1450198,0xe0d9150a}},	//   nnao, zeb_, днил, ови_
  { {0x61ef003a,0x62880025,0xa7fc0060,0x9f4a01a0}},	//   _mecl, édoi, rkın, _rebé_
  { {0x7e6d1aee,0xa3bf0037,0x95080012,0xa7fc0060}},	//   _alap, ेशा_, _رقمك_, skın
  { {0x6fa90003,0x752f0002,0x998f0030,0x442a0030}},	//   تهدف_, ewcz, _tagů_, veb_
  { {0xf1bf0011,0x38b40032,0x61ef004b,0x9c130035}},	//   ्शान, märe_, _necl, žādī
  { {0xe1f00003,0x442a0066,0x7ea30051,0xfdf6000b}},	//   _إسم_, teb_, lõps, וצרת_
  { {0x4e0a0037,0xd455002d,0x91ba0009,0x25de0011}},	//   _वाकई_, нтсь, _ומני, _क्री_
  { {0x61e4273d,0xda660003,0x03a30109,0xa6960001}},	//   tbil, واري, виро, _ориј
  { {0x442a273e,0x4e960012,0xfeba0012,0x61e4273f}},	//   seb_, _تشتر, _باتت_, ubil
  { {0xfaa304b3,0x8ffa0003,0xd838009b,0x442a0051}},	// [6c80] тато, قرار_, loča_, peb_
  { {0x7ebf0071,0x625c0c04,0xa84a0012,0x8c960024}},	//   _rūpi, _léop, غلام_, _ірпі
  { {0x69cb00c1,0xdb24004a,0xee3a0ec6,0x69d90227}},	//   _ogge, äräs, жне_, _ofwe
  { {0x9f470013,0x26dc001e,0x645a004a,0x75d40003}},	//   _není_, īvo_, _soti, ريتا
  { {0x28af0011,0x645a2740,0x6aa30018,0x80c90011}},	//   _जीवि, _poti, _ênfa, _हंगे
  { {0xd4670014,0xf1b9098f,0x69d90227,0x38b40032}},	//   миче_, nešu_, _afwe, färe_
  { {0xd838009b,0x7d0b0692,0x645a2741,0x7c2a2742}},	//   joča_, augs, _voti, refr
  { {0x32b7000a,0xd2500003,0xcb13000b,0x877b0009}},	//   ودية_, انة_, דלה_, _ואלי
  { {0x6d401bbd,0xd0100003,0xedd30012,0x64400035}},	//   _urma, هلة_, _شيلد, ēmij
  { {0x7e6d007a,0x64480065,0x29fe001a,0xf993000b}},	//   _slap, _undi, ịa_, כרח_
  { {0xd838012e,0xc4c50003,0xd9ee0037,0xeafa0012}},	//   goča_, _ستكو, जरात_, _ذرات_
  { {0xe731000b,0x78720040,0xa40e0011,0xeef70009}},	//   נֵי_, _hævd, _साँप_, ומטר_
  { {0x61ef01b3,0x6eca0011,0xb17d0064,0x16130011}},	//   _recl, _संकु, saťr, ण्टर_
  { {0xe8540012,0x3d060011,0xdddd0030,0x61ef0132}},	//   _سنبد, _हटने_, pisů, _secl
  { {0x69da000d,0xd25b0001,0xe72f0003,0x260f0011}},	//   _ştea, оца_, _نصي_, _डाली_
  { {0x96fb000b,0x4efb007e,0x6aa0006f,0xcb37000b}},	//   _ולהת, _ולהג, nomf, ואלי_
  { {0x4a5b000b,0x61e201e3,0x51870024,0xe77c0030}},	// [6c90] קדמו, ñola, фува, výší
  { {0x37ab0014,0xa7fc003a,0xd1170009,0xd7f10012}},	//   отен_, kkım, וקמה_, اكا_
  { {0x91c00011,0x61ef1c75,0x96fb00ae,0x000000c4}},	//   लेबै, _tecl, تعذر_,
  { {0x7bda0065,0xd7df0037,0x5fdf0037,0xe7df0037}},	//   _aftu, _प्रच, _प्रल, _प्रप
  { {0xece8002d,0x94250055,0x286b004c,0x2a69016d}},	//   дділ_, емле, _дрво_, mkab_
  { {0x44ed0066,0x344b0063,0x6ee70012,0x38b40032}},	//   iž_, ючен_, _يسأل, täre_
  { {0xe3c40012,0x03a20024,0xa7fc0060,0xfaa50e04}},	//   نْهَ, лишо, rkıl, нако
  { {0xa3b40044,0xda0f0037,0x682e0034,0x98a00034}},	//   जेट_, िलित_, ródł, twić_
  { {0xca1a0009,0xa7fc0060,0x349504a5,0xf8650024}},	//   הֵיכ, akım, _заар, евпо
  { {0x44ed0027,0xd8380159,0xd709003c,0x2a690522}},	//   dž_, toča_, пное_, hkab_
  { {0x2a690051,0x20180054,0x1fa90048,0x5b370012}},	//   kkab_, òria_, якои_, _تعذر
  { {0x7e79003a,0xd838009b,0x26c900b8,0x36190009}},	//   _çapı, roča_, _ciao_, הוֹד
  { {0x8c960024,0x78720040,0x2a560009,0xceb200af}},	//   ерві, _hæve, _רבנן_, טיט_
  { {0xe1ff000e,0x7dfb0011,0x3a2d2743,0x281500ae}},	//   _adó_, ्लॉग_, leep_, _أوغس
  { {0xd00e0351,0xfe720003,0xf1b9001e,0xf3f10081}},	//   _الى_, _مدة_, rešu_, _mẹ_
  { {0x26c90020,0xe0da02ca,0x3d000037,0x4758002d}},	//   _giao_, зва_, _रिले_, _юрія_
  { {0x41270098,0xd5b2000a,0x6e24002c,0x62840522}},	// [6ca0] ното_, _حفظ_, _ibib, riio
  { {0xfe0d0037,0x9f4c05b1,0x80a60012,0x351b0009}},	//   _हाउस_, zadí_, رمان, _צוינ
  { {0x7ed50024,0xb4be0011,0xdbc7005e,0x6d440064}},	//   вічч, ेदी_, _söök, _hria
  { {0x2bdd0037,0x42db000b,0x7e8b0034,0x645e2744}},	//   नुसा, _מקטע, tępi, _hopi
  { {0xe5340800,0x61f6003a,0xb7bc001e,0x443a0212}},	//   тель, mayl, reģi, _kap_
  { {0x61f6003a,0x3d200011,0xbd430012,0x68e42745}},	//   layl, _यहीं_, انوي, mpid
  { {0xc27a000b,0x443a2746,0xf2c6019c,0x39402747}},	//   ּרִי, _map_, нсин, lvis_
  { {0x443a000f,0xdbc70005,0x61f6003a,0xada60fdf}},	//   _lap_, _töök, nayl, _забл
  { {0x394003eb,0x7e970003,0x68e4004a,0x9f4c0004}},	//   nvis_, _أنقر_, npid, radí_
  { {0x443a000f,0xb97b0009,0x34fb0009,0xd0100012}},	//   _nap_, פניי, _מהמד, جلد_
  { {0x39400051,0xaae60012,0x2d9e0032,0x201e0097}},	//   hvis_, _أسطو, ßten_, rfti_
  { {0x63a400a2,0x7688003a,0x52d7000b,0xddc4009b}},	//   ğind, dıys, _נודע_, _sliš
  { {0x6d440149,0x7c3a0039,0x2f18000f,0xe611000b}},	//   _cria, _katr, ség_, יִם_
  { {0x443a03eb,0x69dc003e,0x3e620028,0xab950024}},	//   _cap_, śred, _sótt_, вигі
  { {0xa6e70020,0x6d440f32,0x43940103,0x883b0009}},	//   _chứ, _eria, гарс, _מתגו
  { {0x5d850012,0x673b0035,0xaa58004c,0x442e2748}},	//   _للعل, _ņujo, нису_, hef_
  { {0x99d40003,0x3940024c,0xf8070ed4,0x764d2749}},	// [6cb0] اتفا, gvis_, ечен, _inay
  { {0xf8b90003,0x2a691b4b,0xa9c401ec,0xc1040012}},	//   ذهاب_, skab_, усск, اولي
  { {0x442e00a2,0x9f4c0054,0x17f80012,0x6d440064}},	//   def_, nadà_, عركة_, _zria
  { {0xa2d60044,0x78a1000d,0x442e0070,0x5b560009}},	//   _मंत्, zolv, eef_, _סירב_
  { {0xc1f60093,0x443a274a,0x6e3d045f,0x9f470064}},	//   _במרץ_, _yap_, idsb, _mená_
  { {0x7d1d0052,0xe53c000b,0x7c3a000d,0x538b000b}},	//   itss, פתור, _catr, ּנֵ֣
  { {0x764d00a2,0xe29903a8,0xfbd40009,0x13090024}},	//   _onay, мак_, נתק_, єний_
  { {0x38b4006f,0x31250048,0xc245016e,0x7c2e274b}},	//   mära_, вдиг, тник, zebr
  { {0xa4d5002d,0x6e3d0033,0xdb080066,0x38b4006f}},	//   _розі, ddsb, _vzdá, lära_
  { {0x764d003a,0x7c3a00b6,0x29030133,0x6aad0052}},	//   _anay, _gatr, čja_, hlaf
  { {0x6e3b0005,0x5f050014,0x9e0a0003,0x78a1000e}},	//   _kaub, ъзна, ويدك_, rolv
  { {0x6d440026,0x645e0218,0x443a274c,0xd6e80009}},	//   _pria, _sopi, _sap_, עַתָ
  { {0x61e900c6,0xc5fa0009,0xba740012,0x1dd80011}},	//   mbel, ופרט, _حالت, भुगत
  { {0x232a007c,0xab2a01b6,0x69dd274d,0x91760009}},	//   моги_, мога_, _afse, _בענף_
  { {0x61f600a2,0x889a000b,0xf8c8001a,0x68fb0058}},	//   tayl, _קבצי, _cứu_, lsud
  { {0x69db0164,0x02be0011,0x6e3b020d,0x39401d48}},	//   ncue, ्देन, _naub, tvis_
  { {0xd5af0003,0x02d20011,0x61f60060,0x76880060}},	// [6cc0] _وفى_, _दूरभ, rayl, sıys
  { {0xa6e7001a,0x9f4c0064,0x3fe30024,0xe9650012}},	//   _thứ, ladá_, ижув, دافً
  { {0xf772000a,0xdfcf0003,0xd6d9002d,0x38b4006f}},	//   جاء_, زين_, еті_, gära_
  { {0x68e40051,0x7afa0028,0x84e60024,0xbd8a0012}},	//   ppid, áttu, водж, ونان_
  { {0xdd8f000a,0xceb3000b,0x6cd30012,0x5d170012}},	//   يوم_, ביא_, لقنا, نتوج_
  { {0x64890029,0x68fb274e,0x6282274f,0x61e92750}},	//   ožia, dsud, _smoo, ebel
  { {0x442e2751,0x7c3a2752,0xfbd30009,0xab27004c}},	//   ref_, _vatr, סתה_, воја_
  { {0x32630015,0xddcd0066,0xcc88001a,0x2f1c000e}},	//   итыв, _smaž, iới_, míg_
  { {0x28d80037,0x361b0009,0xb21b0040,0x20d80011}},	//   _भूमि, _קומד, _omæn, _भूमध
  { {0xdefa0015,0x244a0003,0x6e3b0052,0xf8c80081}},	//   мым_, _تجري_, _zaub, _nứt_
  { {0xc7f70009,0xbbd70009,0xbebd0035,0x68fb005e}},	//   כזית_, _סואץ_, ntīg, asud
  { {0x6489007a,0x69db0061,0x91e60345,0xf76f0012}},	//   džia, ccue, _роде, تاً_
  { {0x66de001e,0xcd070048,0xe61f0064,0x55070048}},	//   _sīkd, ъчни, dnôt_, ъчна
  { {0xdddb00a2,0x80d60037,0xd7ef0001,0xd2d10037}},	//   _oluş, _बढ़े, _њу_, _ढूँढ़
  { {0xf8c8001a,0x7b6400fa,0xd6cf0048,0x248d001b}},	//   _dứt_, атте, _ът_, đem_
  { {0x7e8b0002,0xbb3b000b,0x6a780097,0x82370012}},	//   tępu, ועלי, _líff, خرسا
  { {0xadf8000a,0x2ba90044,0xc05b002d,0x64890010}},	// [6cd0] _شريط_, _चुना, між_, ažia
  { {0xc6e7002d,0x38b40248,0x6e3b2753,0x62880031}},	//   відп, tära_, _saub, édor
  { {0x2fc70163,0x752922b9,0x44312754,0x4dd70012}},	//   äng_, _spez, mez_, نتشس
  { {0x443116ef,0xb9e4002d,0xacf90400,0x38b90025}},	//   lez_, _віри, енду_, mère_
  { {0x867c000b,0x7bc80010,0x38b90061,0x15140024}},	//   וראו, ždut, lère_, идця
  { {0x67380027,0x44312755,0x38b4005e,0x8339003c}},	//   _osvj, nez_, pära_, ечит_
  { {0x6d4201b3,0xe7300003,0x89d5002d,0x4fc40094}},	//   avoa, _وصف_, ліпш, _вста
  { {0xf3f10020,0x44310be4,0x83fc0027,0x6d41001e}},	//   _mọi_, hez_, _rođe, ālaj
  { {0x38b90061,0xd5140012,0x69db08cf,0x61e92756}},	//   hère_, _نبلغ, rcue, rbel
  { {0x61e600a2,0xead5003c,0x46e9046e,0x69db2757}},	//   ıkla, _божь, ндон_, scue
  { {0xf7710003,0xeb090003,0x63a4003a,0x82150003}},	//   صاد_, _أقصى_, ğinc, _مواص
  { {0xddc2001e,0x38b90061,0xee370024,0xc7b20009}},	//   lkoš, dère_, гню_, מבי_
  { {0x39462758,0x01fa0009,0x80d30011,0xa6830024}},	//   _gros_, _נפסל, _भूले, сляд
  { {0x44310e90,0x6abe0011,0x38b90025,0xddcb004b}},	//   gez_, ्द्र, fère_, ţişa
  { {0x38b90061,0x9f4c05b1,0xa09a0009,0xa3a90011}},	//   gère_, padá_, _איסט, _गुम_
  { {0x64890029,0x59c00011,0x3ce60064,0x62890227}},	//   ržia, शेवर, ypov_, nieo
  { {0x3a3f00b6,0x6604002c,0xf4960012,0xb5fb0030}},	// [6ce0] idup_, _idik, _مشدد, tkáv
  { {0x7b09003a,0x44310061,0x64890a05,0xdd7b0009}},	//   üstü, cez_, lžin, _נטיל
  { {0xf3f10020,0x7f860003,0x291f004a,0x141b0009}},	//   _gọi_, دلان, htua_, _אויב
  { {0x4ea5002d,0xb5fb0066,0xc869000b,0xbebd001e}},	//   аріа, skáv, הן_, rtīg
  { {0xadf3002d,0x2418003c,0xbebd0035,0xac180635}},	//   спіш, волы_, stīg, волу_
  { {0xdca3002d,0x64a30560,0x9f470060,0x29120060}},	//   бачи, бача, _genç_, muya_
  { {0xf413000b,0xfaa60048,0x291f016d,0x29122759}},	//   צפה_, лшин, etua_, luya_
  { {0x4431003e,0x5f930003,0x6f930003,0x62660003}},	//   zez_, _الفئ, _الفض, طابق
  { {0xa9c3007c,0x44310108,0x92370001,0xde170012}},	//   йськ, yez_, учју_, _حققت_
  { {0xb8dc0037,0x3137000b,0x6281000e,0xc6e60024}},	//   _आठ_, ננים_, éloz, лімп
  { {0x44310108,0x0057000b,0xa2e60015,0x0857000b}},	//   vez_, אשית_, _соед, אבים_
  { {0x443e14b3,0xd337000b,0x539b0009,0x38b90025}},	//   _hat_, _תראה_, _איבו, vère_
  { {0x5c070098,0x443116ef,0xe918002d,0xa4d5002d}},	//   лява, tez_, _ролі_, рогі
  { {0xdfcf000a,0x38b90061,0xa4d40024,0xfd1f00b8}},	//   _فيه_, tère_, сорі, rtì_
  { {0x8cd50037,0x4431275a,0x66e3004c,0xfe140011}},	//   _यूरो, rez_, _лоја, _डांस_
  { {0x44310108,0xe9d30012,0x38b90025,0x7d0b0097}},	//   sez_, صغر_, rère_, yrgs
  { {0x7c2814f8,0x38b90025,0x57f50430,0x11550024}},	// [6cf0] _obdr, sère_, ипат, шкаю
  { {0x95ff0037,0x2907048b,0x38b90061,0x7ff40012}},	//   ॉल्ट_, čna_, père_, مسما
  { {0x6ee70003,0x63680014,0x63a90052,0x57fb0009}},	//   اسئل, _бряг_, ßend, גלבו
  { {0x7c3e26af,0x63a90060,0xd6ab0012,0x2912275b}},	//   _zapr, ğend, ردام_, buya_
  { {0xed58002d,0x61ed275c,0xa3bf0011,0x59670048}},	//   лої_, mbal, ेशक_, _съна
  { {0x61ed0070,0x6b650188,0xac060048,0xa3d80011}},	//   lbal, икла, анша_, िशय_
  { {0x443e275d,0xc3040003,0xe9d10003,0x289a000b}},	//   _dat_, مبيو, يغة_, _יישא
  { {0x41050046,0x291f0b0c,0xa3a90037,0xaab50037}},	//   азив, ttua_, _गुण_, ंतिक
  { {0xe8f60047,0x291f004a,0x6e29020d,0x443e275e}},	//   алы_, utua_, _ibeb, _fat_
  { {0xb5fb275f,0x6489007a,0x00f6000b,0x443e2760}},	//   cház, džio, סמתך_, _gat_
  { {0x291f004a,0x61ed0227,0x6a780018,0x22400060}},	//   stua_, kbal, _hífe, ydik_
  { {0xa6de001a,0x61ed0070,0x78720058,0xf1c50037}},	//   _trưn, jbal, _nævn, वधान
  { {0x7c3e007a,0x38ab024c,0x99d40012,0x61ed2761}},	//   _papr, ført_, _اتما, dbal
  { {0x18661498,0x443e0054,0xa06603ff,0xd009011d}},	//   _ваши_, _xat_, _ваша_, _реке_
  { {0xf836000b,0x07d80003,0xe8190011,0x9ad60024}},	//   _כנסת_, _إذهب_, दलना_, рюгі
  { {0x8f9a000b,0x61ed002c,0x99e6002d,0x7c3e00b6}},	//   _ביצי, gbal, ржад, _wapr
  { {0x2ca70005,0xdb010006,0x2240003a,0x25d70009}},	// [6d00] kond_, _hylä, rdik_, _דופן_
  { {0xf00b0020,0xa4fb000b,0xb5fb0066,0xe0df001a}},	//   _đảng_, _שליט, skát, _tròn_
  { {0x21200d6c,0x443e2762,0x6d492763,0xef86004c}},	//   stih_, _rat_, _area, јлеп
  { {0x0bb70093,0x6d492079,0xb5fb000e,0x89d50024}},	//   _כלים_, _brea, lkár, _гірш
  { {0x443e0259,0xceb3000b,0x2bb5001a,0x88c60003}},	//   _pat_, קיד_, _ác_, _نتسل
  { {0x23ba0037,0xb5a90003,0x84380003,0xbfd30012}},	//   _इराद, دامك_, اكثر_, _ويُع
  { {0xd4670046,0x8bc30014,0x290d000d,0x6d41001e}},	//   рије_, осъд, erea_, ālai
  { {0x443e00bd,0x7f3b000b,0x44200066,0x61fb0010}},	//   _wat_, _בעלו, ři_, gaul
  { {0x6d490036,0xb273007c,0xb5aa000a,0x6296002c}},	//   _grea, ільш, _شارك_, inyo
  { {0x29000006,0xc7c60731,0x2ca70689,0x61ed0042}},	//   isia_, исни, cond_, zbal
  { {0x75220272,0xa2d60044,0x290d007d,0x752d00c1}},	//   ltoz, _मूल्, area_, _spaz
  { {0x290003fc,0xe8180037,0x7ebd000e,0xe6950015}},	//   ksia_, _दावा_, képe, симы
  { {0xf27b000b,0x7522000e,0xc27b0009,0xa183003c}},	//   _בראש, ntoz, _בראי, _мышл
  { {0x7ebd0061,0xb8ea0037,0x26d80017,0x017b000b}},	//   dépe, लग_, _ouro_, _שָׁל
  { {0xbebd0039,0xd838009b,0x58bb0009,0x00bb0009}},	//   rtīb, joči_, _שמוצ, _שמומ
  { {0x27770093,0x98a90002,0xbebd001e,0xadf50001}},	//   _כגון_, ować_, stīb, _упиш
  { {0xdebc0093,0x98ba0037,0xf8ba0037,0x89eb000b}},	// [6d10] _במהל, _उठाए, _उठाय, דַבֵ
  { {0x0854002d,0xae140037,0x6c840012,0x2bde0011}},	//   овую, _डाउन_, _وليم, _मलया
  { {0xec360093,0xddcd000d,0xd838009b,0x2ca70227}},	//   _האתר_, _flaţ, goči_, vond_
  { {0xb5fb000e,0x3618002d,0x69a20037,0x83fc001b}},	//   ljáb, ицію_, _कुकी, _rođa
  { {0x2ca70070,0x45450012,0x27f81ba1,0x5cf4003c}},	//   tond_, إنتق, _fern_, оящу
  { {0xe81e0037,0xb5fd0027,0x6d49000d,0xc484002d}},	//   _पाया_, _doša, _vrea, олік
  { {0xa3d80037,0x61fb2764,0x2ca70070,0x98a90034}},	//   िशत_, taul, rond_, ewać_
  { {0xeb98000b,0x6d4909f5,0xc7b2000b,0x76400010}},	//   ידור_, _trea, _זבל_, _gamy
  { {0x61fb0663,0x2ca70061,0xb5fb06ec,0x66de0035}},	//   raul, pond_, kjáb, _rīka
  { {0xa8550001,0x76400516,0x627b0034,0x66de0035}},	//   стиј, _zamy, dłoś, _sīka
  { {0xa5bb0028,0x5f750003,0x07a5027f,0x141a0009}},	//   sfól, صادر, санн, _תועב
  { {0x550b0037,0x64412765,0x29002766,0xb87b2767}},	//   _हटाए_, _hali, ysia_, _stíl
  { {0x627b0002,0x3f8b0002,0x98e50012,0xe5720012}},	//   głoś, ńcu_, _اكتو, سطح_
  { {0x225f000f,0x64430d4a,0x9f470840,0x28db0011}},	//   ljuk_, ndni, _menú_, _बढ़ि
  { {0xa3b40037,0x64412768,0xfbd20009,0x28bd0011}},	//   ड़ें_, _mali, לתם_, ्गनि
  { {0x236502eb,0x225f0182,0xda0a0012,0xb5fb0030}},	//   älja_, njuk_, طيئه_, skár
  { {0xa617000b,0x5e77000b,0x2fd60003,0x29002769}},	// [6d20] _הקפד_, _לתקן_, متاح, usia_
  { {0x76400002,0xbddb0054,0x6aa90070,0x2f56027f}},	//   _samy, ndèn, hoef, йтес
  { {0x6443006f,0x20c90012,0xdfcf0012,0x98a90034}},	//   ddni, شبكي_, فيك_, zwać_
  { {0x2902007a,0xb5fd001c,0x98a9003e,0x76a9002d}},	//   škai_, _poša, ywać_, атів_
  { {0x225f000f,0x6441276a,0x9f450042,0x361b0009}},	//   djuk_, _bali, valý_, רונד
  { {0x7522000f,0x3ead000e,0x3d090011,0x26d8020d}},	//   rtoz, _eket_, _सिरे_, _turo_
  { {0xbc19002d,0x64410f68,0x627b0034,0x26c0276b}},	//   річі_, _dali, złoś, _ohio_
  { {0x25ad003e,0x6e96000a,0x7d040027,0x225f000e}},	//   żeli_, _الرا, _ovis, gjuk_
  { {0x315a000a,0x6c1a0003,0x61fd0028,0x4ddb0009}},	//   اجعة_, _متاح_, ðsla, _תחמו
  { {0x6441039c,0x7c650003,0x0eea002d,0x96ea0021}},	//   _gali, _والل, льми_, льма_
  { {0xcb09002d,0xa6350024,0xdfd00012,0xf699004c}},	//   _вхід_, онні, بيد_, ивој_
  { {0x8f9b000b,0x7e920035,0x93b70009,0x64410353}},	//   ריטי, kāpu, _פלאו_, _zali
  { {0x261a0037,0x39590052,0x2d9f0025,0x98a6046e}},	//   _भारी_, ässt_, çue_, _лиде
  { {0xf4840014,0x6489015b,0xd91b0009,0x01370009}},	//   пусн, mžik, _עוול, _לרדת_
  { {0x2d840065,0x6ee60003,0xeabf001a,0x5f930001}},	//   úmer_, _استل, _phù_, _ништ
  { {0xb9250003,0xda090012,0x7d02276c,0xb7970009}},	//   يفزي, شيطه_, ksos, _לכוח_
  { {0x786d0026,0x6e2d0101,0x7d040003,0xb5fd0864}},	// [6d30] _súvi, _ibab, _فِيه, _bošn
  { {0x2a660101,0x5f950014,0x3ebf002a,0x27c7003c}},	//   _loob_, оизт, _shut_, бщег
  { {0xeabf001a,0x9f040012,0x2c6b0040,0x273a0035}},	//   _thù_, كولو, _mødt_, _jūn_
  { {0xe8150037,0x442c0225,0x6441276d,0x5f370009}},	//   _ढाका_, _abd_, _sali, מטבע_
  { {0xa3cb0037,0xbd450003,0xed590345,0xcd280012}},	//   रेन_, تنشي, рол_, مسون_
  { {0xc05b002d,0x2c6b0192,0x19560009,0xd49b003c}},	//   _сім_, _nødt_, _ובשל_, ыре_
  { {0x225f000f,0x8c1c0009,0xe81e0011,0xa7fc0060}},	//   tjuk_, אווי, _पाता_, ykır
  { {0x62650024,0xe9d91390,0x88e50148,0xfbd00012}},	//   івпа, шки_, ожие, ءته_
  { {0x225f000e,0xd0590024,0xe0d6003c,0xc6920009}},	//   rjuk_, арні_, овы_, _חאן_
  { {0xd0090001,0xa9880009,0x65b50064,0x7c970012}},	//   јене_, מָתִ, _výhľ, _اشرا
  { {0x225f000e,0x39490051,0x9b950012,0x66090042}},	//   pjuk_, hvas_, _بلات, _kdek
  { {0x8f1a0009,0x61550012,0xe7360198,0x63ad0060}},	//   סורת, _ونائ, цею_, ğand
  { {0xddcd0039,0x2c6b0262,0x63ad0060,0x9f450031}},	//   _plaš, _født_, şand, taló_
  { {0xdfdb0014,0x6d4d276e,0x55ba0009,0x045a0012}},	//   _съд_, _draa, שמשו, جلسة_
  { {0x43430014,0x32460014,0x68ed055c,0xd2520012}},	//   мерв, оевг, epad, ونس_
  { {0xd6d20003,0x7e7d0052,0x6d4d0647,0x656f0066}},	//   _تقع_, chsp, _fraa, bych
  { {0x68ed0101,0x8066002d,0x33d6002d,0x25df0011}},	// [6d40] gpad, оваж, _мінт, _गलती_
  { {0x1fb6002d,0x6ecc003a,0xe3b20003,0xdd0f0060}},	//   осер, _işbi, _يرد_, lışv
  { {0xddc00013,0xe8210037,0x3949001e,0xa3cb0037}},	//   _pomů, _माना_, avas_, रेम_
  { {0x8f9a000b,0xcf92000b,0xd62a072b,0xd7570012}},	//   ביעי, וטב_, роде_, تلمت_
  { {0x61e4003a,0xcd360012,0xe7ab0011,0x4444276f}},	//   mcil, تراب, _घुसप, _ka_
  { {0x86ea0003,0x61e4003a,0x44442770,0x7d0d0097}},	//   _نعرف_, lcil, _ja_, áasa
  { {0x656f0002,0x66de001e,0xab770003,0x9f430164}},	//   zych, _rīko, يمها_, _dejó_
  { {0xead30047,0xfbd30093,0x44382771,0x60f80048}},	//   мощь, ותו_, her_, бния_
  { {0xa2da0302,0x93bc000d,0x44382772,0x9a670012}},	//   _पूर्, _scăd, ker_, تميل_
  { {0x3957000b,0x1957000b,0x7e620027,0x5478000b}},	//   קשים_, קביל_, ljop, _פְּנ
  { {0x2a660051,0xe7db000b,0xb7db000b,0x3ce914f9}},	//   _toob_, יקיש, יקיי, _stav_
  { {0x44380070,0x656f0002,0x7e950002,0x7e62006f}},	//   eer_, tych, tąpi, njop
  { {0x1dca0037,0x44442773,0xe4e40024,0x60660012}},	//   िधित, _ba_, дісн, _وهؤل
  { {0x6a7c0061,0x6d4d0070,0x44442774,0x69b40011}},	//   _défe, _vraa, _ca_, _आरजी
  { {0x7c2a0248,0x6faa0011,0x6d4d0227,0xf1b92353}},	//   iffr, _जुलू, _wraa, _šš_
  { {0x4444000d,0xd8380238,0x66b4022a,0xa49b01a0}},	//   _ea_, leč_, _общу, rròq
  { {0x142b002d,0xac950001,0x44442775,0x3ce90248}},	// [6d50] _кіно_, _наиш, _fa_, _utav_
  { {0xa3cb0037,0xdb010029,0x44442776,0xe8d70009}},	//   रेड_, _vylú, _ga_, קובר_
  { {0xc6a7068f,0x44212777,0x2912016d,0x6d402778}},	//   орди, _ich_, arya_, _asma
  { {0x2259000a,0x29040051,0x9f410dc5,0x68ed2779}},	//   _الحد_, ksma_, nché_, ppad
  { {0xd126000a,0x73e50098,0x64450101,0x4a5a000b}},	//   _ثم_, полз, _kahi, _הדרו
  { {0xd838001c,0x61fd0107,0x7c380070,0x5cab0001}},	//   ječ_, _hesl, gevr, шњег_
  { {0x64450167,0x6d401835,0x2ddb0012,0x6d460159}},	//   _mahi, _esma, _نبذة_, _škat
  { {0x60d500a2,0x64450190,0x8b9c0009,0x139c0009}},	//   _hizm, _lahi, יבות, יבוע
  { {0x442101ab,0xdb0805b1,0x44381deb,0xa6340024}},	//   _och_, _vydá, yer_, _інфі
  { {0x26dc007a,0x66de0039,0x6445002c,0xa8740015}},	//   _buvo_, _tīkl, _nahi, дующ
  { {0x4444277a,0x66e80066,0xe739004d,0xf0920009}},	//   _ra_, _někd, щен_, תני_
  { {0x4444277b,0x443808a2,0x6da6096e,0x64570503}},	//   _sa_, wer_, зима, _anxi
  { {0x20010167,0x2902000e,0xee3700b3,0x31580012}},	//   kahi_, ákat_, чня_, _وجهة_
  { {0xb4b60037,0x7ebd0025,0x38b4008e,0x9f050012}},	//   जते_, répa, päri_, _فوتو
  { {0xd7fa000b,0x4444277c,0x60dd0052,0x6445277d}},	//   _ההצל, _va_, _ausm, _dahi
  { {0x60d5001e,0x35a6002d,0xb5fb000e,0x7ebd000e}},	//   _aizm, _найг, lján, lépn
  { {0xfc320003,0xe0d7002d,0x6ec50003,0xa0220028}},	// [6d60] _كحد_, зву_, _تتوق, _þökk
  { {0x8fa60098,0x4999002d,0x61e41338,0x07a60048}},	//   пазе, іття_, scil, пазн
  { {0x25bf052e,0x33db0009,0x7bdb0009,0x7d190227}},	//   _azul_, _לחיד, _לקיו, euws
  { {0x61fd277e,0x5693002d,0xf8a90009,0x0dca003c}},	//   _gesl, наєт, אש_, блей_
  { {0xa25b008a,0x3eba001e,0x48e30210,0x41b90011}},	//   _khôn, ēpt_, _появ, _आरएस
  { {0x7019002d,0x91bb000b,0x55bb000b,0xa9bb0009}},	//   _міст_, _למכי, זמנו, _לזכר
  { {0x5e96000a,0xd838009b,0xb5fb000e,0xbb470012}},	//   _فلسط, več_, dján, كلون_
  { {0xb954007c,0xd6d20012,0xfbd30009,0x5eeb0009}},	//   двищ, _أقر_, עתה_, _לַמְ
  { {0x48aa027f,0x6d40016d,0xc5eb0009,0xdfda0048}},	//   йтом_, _usma, _הַבֹ, йън_
  { {0x6c86000a,0x44380309,0xf806002d,0x44e20028}},	//   _علام, _úr_, ччин, _ið_
  { {0xdfd00012,0x35a50011,0x6445277f,0x74130012}},	//   ضيح_, _गुज़, _rahi, _أوما
  { {0x644500a2,0xd6d7064f,0x59be0037,0x4fbb0009}},	//   _sahi, ять_, ्धार, מציא
  { {0x644501e5,0x9f412780,0x91ba0012,0xc0ca004c}},	//   _pahi, rché_, _اطار_, _луке_
  { {0x753d003e,0x2902007a,0x6ab50044,0x26dc0164}},	//   rwsz, škas_, ंत्र, _tuvo_
  { {0x6d400028,0x3942002a,0x644500e6,0xa08b0009}},	//   æmar, _asks_, _vahi, _לְהִ
  { {0x69da007d,0x201e0010,0x60f90015,0x64451118}},	//   _şter, lgti_, жная_, _wahi
  { {0xc4cc0011,0x7e690227,0xe9e80012,0xf9930012}},	// [6d70] ाषाओ, _roep, سفلى_, ربر_
  { {0x201e007a,0x66de0039,0xd0110003,0x34fc0009}},	//   ngti_, _rīkj, ئلا_, _ההזד
  { {0x44e22781,0x629b0002,0x7e7b2782,0x61fd1783}},	//   _að_, ynuo, _plup, _tesl
  { {0xbdf80012,0xddd00073,0x1959003c,0x78730060}},	//   كرها_, _šešt, _дамы_, _sıvı
  { {0x04450014,0x8c450210,0xd4690430,0x984b0048}},	//   делн, деле, жиле_, _лява_
  { {0x629e0061,0xa3b10011,0xa022005e,0xad1c0009}},	//   épon, टअप_, öötl, מודר
  { {0x9f34007c,0x7e6900bd,0x44e20028,0x660d04d7}},	//   _пері, _toep, _eð_, _odak
  { {0x224900c6,0xb5fd009b,0x201e0213,0x8b580009}},	//   ndak_, _mošk, egti_, ליוס_
  { {0x212900c6,0x224900c6,0xf9910012,0xa9e40012}},	//   ntah_, idak_, ضبة_, رثين
  { {0xa889002d,0x660d00b6,0x20890024,0x2a7f2783}},	//   ійна_, _adak, ійни_, shub_
  { {0x0fc50024,0xaabf0011,0x38b40248,0xd37b0148}},	//   ьйон, ्षाक, märt_, _уча_
  { {0x49750024,0x7bc1001b,0xc2c40012,0xbebd0035}},	//   _олес, _izlu, _كيلي, ltīj
  { {0xaa880003,0xa25b001a,0xf2d20009,0x04b60024}},	//   _عنهم_, _phôn, _סעד_, дсвя
  { {0x02c60037,0xb8e10011,0x71880009,0x38b40248}},	//   लग्न, ंत_, _מְצַ, närt_
  { {0x20180029,0x91e60014,0x394d2784,0xdc880009}},	//   órie_, добе, lves_, פְשָ
  { {0x6489007a,0xc332000b,0xc7b2000b,0x7d0900c1}},	//   džiu, כול_, _שבה_, _oves
  { {0xa25b008a,0x63a400a1,0x41270014,0xee290012}},	// [6d80] _thôn, ğini, мото_, _رأيه_
  { {0x63a41a2d,0xb5fb0097,0x22460064,0x6d44016d}},	//   şini, hjál, žok_, _isia
  { {0x9f5e0061,0x72c600de,0x7d092785,0x545b0009}},	//   taté_, _обоз, _aves, _וכיצ
  { {0x11d60003,0xdddb0030,0x7d090159,0x7c2e2786}},	//   _يتحد, _kouř, _bves, lfbr
  { {0xa3cb0044,0xb21b0040,0x66e10035,0x648909ef}},	//   रेस_, _slæg, _sēkl, rživ
  { {0x394d000e,0x38b4006f,0x718b000b,0x7c3c2787}},	//   dves_, gärt_, _וְלַ, nerr
  { {0x2ac60001,0x6489022d,0xdee6004c,0xf743003c}},	//   мљив, mžit, _цоби, _иеро
  { {0xb21b0058,0x96950024,0x7c3c2788,0x6d440034}},	//   _glæd, _зруш, herr, _osia
  { {0xa2da0044,0xe4e90003,0x7c3c2789,0xd2b70009}},	//   _पंक्, _فعله_, kerr, ולקת_
  { {0x6a7c0108,0x63ad003a,0x5b360012,0x2ba90011}},	//   _défa, şana, _يعار, _चुका
  { {0x6d440006,0x3817000b,0x7bdb000b,0xdb0b003a}},	//   _asia, וקים_, _וקבו, ünüz
  { {0x64481daf,0xbe8b0024,0x787f0025,0xdddb0030}},	//   _hadi, існе_, _rêve, _bouř
  { {0x8d870001,0x7c3c278a,0xe5f70009,0x6448278b}},	//   фунд, ferr, וזכר_, _kadi
  { {0x91bb000b,0x443c0051,0xa9670001,0x61f60066}},	//   _ומדי, nev_, _циља_, ebyl
  { {0xa4d4007c,0x46a70047,0xe207003e,0x6281007a}},	//   торі, _ошиб, spół_, ūlom
  { {0xe0df01a2,0x6e450003,0xdd0e0011,0x83fc001b}},	//   _può_, _أنظم, _सिंध_, _dođi
  { {0x7eb80017,0x5cc7003c,0xf1940109,0x7c3c278c}},	// [6d90] cípi, _осоз, вить, berr
  { {0x7c3c0e0a,0x443c13f6,0xbc680012,0x7d1d278d}},	//   cerr, jev_, _يمين_, muss
  { {0xd148001a,0x443c278e,0xc4d20009,0x7d09001b}},	//   _lễ_, dev_, _תגי_, _sves
  { {0xb21b0058,0x9f4c000e,0x8de50012,0x7d1d278f}},	//   _emær, ladó_, ركته, ouss
  { {0x32040002,0xe3b80060,0x38b40248,0x986f0034}},	//   damy_, _ayı_, gärs_, eżą_
  { {0x351c000b,0x64c90037,0x443c0051,0x74150012}},	//   קוונ, िगेश, gev_, روعا
  { {0xd404002d,0x65790060,0x28d80011,0x7d1d0032}},	//   тячи, _şahı, _भूटि, huss
  { {0x320408ce,0x7e6d2790,0xcdf40012,0x23760012}},	//   gamy_, _noap, _لأكث, عميد_
  { {0xb5fb0028,0x8d770012,0xe0010024,0x05770012}},	//   rjál, _غارا, льнi_, _غارد
  { {0xd148001a,0x443c009b,0xb5fb0074,0xe8f6003c}},	//   _dễ_, cev_, ckáz, эль_
  { {0xdddb0066,0x69c20070,0xf8b20009,0xaf990024}},	//   _souř, _ezoe, רשי_, ятих_
  { {0x32040002,0x2909004a,0x6f7a000b,0xa2f60009}},	//   camy_, ksaa_, לְכו, _נמנה_
  { {0x7d1d002e,0x361a0009,0xa25b0025,0xd2b80012}},	//   guss, הורד, _chôm, _غامض_
  { {0x9f4c000e,0xccf20009,0x2cb10031,0xddc40060}},	//   gadó_, רכם_, gozd_, _eniş
  { {0xdd990029,0x20052791,0x42560373,0x987a0009}},	//   ĺňa_, mali_, нтат, _מאסט
  { {0x443c0013,0x61e92792,0x7ae1232f,0xda660012}},	//   zev_, ncel, _mult, رازي
  { {0x66061d73,0x9f580029,0xa69b000b,0x8ffa0012}},	// [6da0] makk, _verí_, _משקפ, كرار_
  { {0x25d7000b,0x68460003,0x32040002,0x39400002}},	//   _אופן_, عَال, zamy_, rwis_
  { {0x66e5007a,0xabfb000b,0xf7720003,0x1eda0003}},	//   _dėko, _מהיר, داء_, سباب_
  { {0x660611d7,0x6d7a0009,0x2005080d,0xc7d60009}},	//   nakk, ּאַח, hali_, גועי_
  { {0x443c066e,0x6448007a,0x629600a2,0xdb01003a}},	//   tev_, _padi, miyo, _eylü
  { {0x44e60020,0x629600a2,0x200504fc,0x32040034}},	//   _mô_, liyo, jali_, wamy_
  { {0x32040002,0x8c1b000b,0x64482793,0x44e62794}},	//   tamy_, לוסי, _vadi, _lô_
  { {0x9757000b,0xcb13000b,0x62961f3e,0xe6c60012}},	//   _אילו_, אלה_, niyo, _ستزي
  { {0x32040002,0x6e930012,0x91b70048,0x44e62794}},	//   ramy_, _إلقا, нгът_, _nô_
  { {0xd7f70047,0x62960101,0x645a0036,0x7d1d0269}},	//   ную_, hiyo, _unti, vuss
  { {0x6296003a,0x6e3d0058,0x7d1d0052,0xe8210037}},	//   kiyo, tesb, wuss, _मारा_
  { {0xb5fd0470,0x6e95002d,0xa3a90037,0x660600b6}},	//   _poši, тиму, _गुट_, gakk
  { {0x44e6001a,0x6296003a,0xa1130012,0x9ccb003c}},	//   _cô_, diyo, _مونت, зыва_
  { {0x6606008e,0x20050fa3,0x672b0031,0x515b0009}},	//   aakk, cali_, éljá, _מכדו
  { {0xd7f8000d,0xa8470012,0xa2c7004c,0x9f4c0031}},	//   mbă_, _سليم_, ељак, radó_
  { {0x67bb0093,0xd7bb000b,0x66e50010,0x7d1d2795}},	//   _ממוק, _מצור, _dėkl, puss
  { {0x38b40163,0x68e20010,0x518701b6,0xe5020011}},	// [6db0] värr_, _juod, хува, रीमि_
  { {0x68e20006,0xd6d90002,0x7d1b01a0,0x61e913ce}},	//   _muod, _sił_, àusu, zcel
  { {0x68e20006,0x83670003,0xd7f8004b,0xd7590012}},	//   _luod, _أدخل, ibă_, بلات_
  { {0xd6180003,0x9f5e0029,0x81c20035,0x20052796}},	//   فتها_, jatí_, ģējo, zali_
  { {0x44e6001a,0x49740048,0x3d1f0011,0x68e20073}},	//   _xô_, _бляс, _बमों_, _nuod
  { {0xd116000b,0xd7f8004b,0xc87f0032,0xe3b90635}},	//   _בקשה_, jbă_, _buße_, мбл_
  { {0xa3cb0044,0x14d8000b,0x61e9001e,0x0ebb0012}},	//   रें_, גוגל_, tcel, _فارغ_
  { {0x20050bca,0x6a7c0025,0x46b70012,0x224b207e}},	//   wali_, _défo, _أحسس, _jack_
  { {0x41020047,0x660611d1,0xd5c50024,0xa1e80012}},	//   азыв, vakk, хiдн, رريك_
  { {0x224b002a,0x200500c1,0x6abb06c4,0x7ebd08c5}},	//   _lack_, uali_, sluf, léph
  { {0x07a5007c,0x20182797,0x39460164,0xf484002d}},	//   танн, ória_, _esos_, _сутн
  { {0xc7d60009,0xd7f8004b,0x2c740032,0xa8020060}},	//   כותי_, abă_, _lädt_, çırm
  { {0x5d670015,0xb6a30472,0x66061167,0xfd1f00b8}},	//   виям_, риял, rakk, guì_
  { {0x44e60020,0xe1f90010,0x7d0d0010,0x8c46004c}},	//   _vô_, lbų_, _dvas, њеве
  { {0xe5170044,0x629600a2,0xc2b60001,0x2b1508b0}},	//   _तिथि_, tiyo, вљањ, льтр
  { {0x44e6001a,0x224d0182,0x5d860012,0x8f1a0009}},	//   _tô_, ndek_, _للبل, _חוקת
  { {0x629600a2,0x9f580054,0xe0da00f5,0xd6cf0012}},	// [6dc0] riyo, _serà_, два_, _بقي_
  { {0x62961067,0x66042798,0x62842799,0x0396003c}},	//   siyo, _heik, shio, _армя
  { {0x4033002d,0xc5fe001e,0x7d090027,0x6fb30003}},	//   реєс, ņēma_, šest, لمكا
  { {0x6a7c0061,0x644e279a,0xb5fb0031,0x63ad0060}},	//   _réfo, ldbi, gjáh, ğanl
  { {0x63ad003a,0xf6530009,0xa6130024,0xa3d40011}},	//   şanl, יצא_, рміч, सेन_
  { {0xdb1a000e,0x3a26000d,0x660411c2,0x6aca0011}},	//   _aztá, _scop_, _leik, ाग्र
  { {0x68e20006,0xa037000b,0xbc670012,0x9b430012}},	//   _suod, _שאלה_, ضمين_, لنوو
  { {0xeaaf0003,0x66040028,0x7eb8000e,0x24980052}},	//   يعي_, _neik, típu, hirm_
  { {0x58d8022a,0xfc1a0012,0xa9c30024,0x63a90060}},	//   ндия_, _يقرب_, иськ, ğeni
  { {0x68e2004a,0x63a905be,0x224d0efc,0x2c4500ae}},	//   _vuod, şeni, adek_, _مضمّ
  { {0xdc9b000b,0xf093000b,0x50d30003,0x501b000b}},	//   _קיבל, שנת_, جزير, וויו
  { {0xc7b30093,0xeb97000b,0x68e2004a,0x6f030284}},	//   יבת_, _בדבר_, _tuod, ânci
  { {0xbebd0039,0xceb3000b,0xddc4009b,0x66de001e}},	//   ktīv, שיר_, _poiš, _rīku
  { {0x66e5007a,0xf7540003,0xc9770009,0x8f540012}},	//   _sėkm, _منتج, _בגדי_, _منتش
  { {0xdee30046,0x35c70037,0x26c9001a,0xb5fd0027}},	//   _који, रेज़, _thao_, _košt
  { {0x442d0066,0xd6270003,0xa7fc0060,0x9f5c0030}},	//   ře_, _شعبي, vkıy, _jeví_
  { {0xf807007c,0x6a7c0061,0xead400b3,0xb5fd04d2}},	// [6dd0] вчен, _réfl, роть, _mošt
  { {0x9f580aa1,0xf8b90003,0x155a0009,0x95980009}},	//   _será_, رهاب_, _נכתב, _שכזו_
  { {0x224b0163,0x92950001,0x764d002c,0xde190012}},	//   _tack_, _банц, _kaay, فقات_
  { {0x271c0020,0xf7700003,0x8f9b0009,0x4b7a0009}},	//   ảng_, غال_, ויבי, _נארו
  { {0xed58007c,0x721a0093,0x621a000b,0x764d002c}},	//   кої_, _אורח, _אורק, _maay
  { {0x66e80013,0x60dc00a2,0x0c24002d,0xd7f40015}},	//   _něko, _girm, имін, _взры
  { {0x7ae50005,0xf8b2000b,0x9f580017,0x7d00000e}},	//   _juht, _השם_, _terá_, ámsz
  { {0x7ae5003a,0x23690027,0x4a450001,0x4374004c}},	//   _muht, ćaj_, унив, рушт
  { {0x20c20065,0x6604279b,0xe1f90010,0xc6920009}},	//   rðin_, _reik, rbų_, _האן_
  { {0x91bc000b,0x79890002,0x44230040,0x6604279c}},	//   ומחי, rzew, _øj_, _seik
  { {0xa2f50014,0x6282002a,0x79890002,0x4f640012}},	//   _спеч, _floo, szew, لاَف
  { {0x8afa0009,0xd6d20009,0x8e86004c,0x6282279d}},	//   _נהני, ֶׂם_, угме, _gloo
  { {0x61fd0065,0x26b6000b,0x65c10029,0x22400010}},	//   ðslu, רִים_, _náhľ, veik_
  { {0x399a000b,0xd8790003,0xd91a0009,0xb19a0009}},	//   _אינד, _سمعت_, _נוצל, _אינכ
  { {0x3878006f,0x6604279e,0xe7680012,0x7ebd0c48}},	//   örre_, _teik, _لحين_, zépi
  { {0x8f9a000b,0x7aa50012,0x61460479,0x20070097}},	//   _ריקי, لإقل, леба, ðnin_
  { {0x60dc0113,0x224000c7,0xc4c30011,0xc6930009}},	// [6de0] _pirm, reik_, षताओ, _לאה_
  { {0xa84a0012,0x6e29107f,0xceea130e,0x000000c4}},	//   علام_, _aceb, едже_,
  { {0xc3560048,0xe61a11d9,0x9aa60012,0xe0d50024}},	//   _съпъ, еде_, _ممدو, рють
  { {0xdfcf000a,0x127a000a,0x84e6002d,0x1eaa0003}},	//   سين_, _أحدث_, годж, راضي_
  { {0x6aa4279f,0x63a90032,0xa49b01a0,0xe5a307e8}},	//   mnif, ßenv, rsòv, бици
  { {0x25a90003,0xbebd0035,0x6721029c,0x628227a0}},	//   خدمي_, ltīt, kulj, _sloo
  { {0x6aa40051,0xe61a0ec6,0x78ab0031,0xb5fd27a1}},	//   onif, _пдв_, égve, _pošt
  { {0x75d6000a,0xcb130009,0xde1a0012,0xcb570009}},	//   _ميزا, צלח_, _سقطت_, רסקה_
  { {0xbebd0039,0xddcd0027,0x20180017,0x83fc001b}},	//   itīt, _slaž, ório_, _anđe
  { {0x83fc001b,0x290f0031,0x764d020d,0x7b050097}},	//   _vođs, ágai_, _saay, úttó
  { {0x2fd8006f,0xf65f0058,0x76960073,0x0a160012}},	//   ärg_, nlæg_, ašym, _موضح
  { {0x91e60047,0xc7d70009,0x45d507e8,0x17570009}},	//   _соде, טויי_, ионс, אסטר_
  { {0x7ae500b9,0x94ab0681,0xb5fb03d1,0x7e7d27a2}},	//   _suht, етва_, kjáv, rksp
  { {0x98a30014,0x7ae50269,0xa3cb0011,0x10a3031e}},	//   _личе, _puht, रेक_, _личн
  { {0xc879000d,0xa3d50024,0xb5fb0031,0xcc770009}},	//   _îşi_, ровч, djáv, נעלה_
  { {0xf65f00c5,0xdb0c0030,0x31a50012,0xf66b0012}},	//   dlæg_, íhán, لمزف, _سحبه_
  { {0xe9180024,0x44a70012,0x76420060,0x61ed27a3}},	// [6df0] лоті_, _محدّ, deoy, rcal
  { {0xf00b001a,0xa81b0012,0xf9900012,0x61fb0060}},	//   _đẳng_, عتذر_, سبق_, zbul
  { {0x2fc70163,0x501b000b,0xcfab0012,0xa0c40012}},	//   ång_, תובו, رائم_, حيلو
  { {0x5d550373,0x9e350024,0xdbff0011,0x16350048}},	//   икет, редч, ैण्ड_, редя
  { {0x2d580024,0x85e80024,0x2cd5003c,0x8d6504a5}},	//   лиць_, удів_, аждё, рвле
  { {0xc19a0009,0x65790132,0x09b600af,0x000000c4}},	//   _ישרי, rywh, _כפרט_,
  { {0xf4840001,0x7c840001,0xbebd001e,0xcc780009}},	//   ључн, ључе, ntīs, רגות_
  { {0xbebd001e,0x43040012,0xa3cb0011,0x6ce70024}},	//   itīs, حذوف, रेग_, _біже
  { {0x6d490006,0xd5380003,0xb4270012,0x44270012}},	//   _usea, _مثلا_, _معاو, _مراف
  { {0x5d840351,0x76960010,0x90e40003,0x61e200b8}},	//   _الكل, ršym, حسين, _egol
  { {0x61e60010,0x96660014,0x78a50028,0x20540015}},	//   žkla, акне, inhv, стыр
  { {0xc4c9000b,0x1e960015,0x660b002c,0x44eb0192}},	//   _חג_, ррор, nagk, _kø_
  { {0x6cc6002d,0xd2d40012,0x66e50073,0x9f5801a0}},	//   ийма, _اغلب, _dėki, _terç_
  { {0xceb9003e,0x629b007a,0x644327a4,0x65c30024}},	//   stęp_, liuo, neni, ібра
  { {0xe29a00c0,0xb09a000b,0x442727a5,0x889a01b0}},	//   вав_, _שיצר, ign_, _בבסי
  { {0x629b0010,0xd1320003,0x63be01bd,0xd2a7004c}},	//   niuo, يمز_, _vypn, аксе_
  { {0x644327a6,0xdebb0009,0x11d70012,0xf7f60012}},	// [6e00] keni, _במקל, لوفة_, لساد
  { {0xbebd0039,0x2f56035b,0x97560001,0x97c60365}},	//   stīt, итес, итељ, айзе
  { {0x66160013,0x629b0010,0x8fa60012,0xd9f70011}},	//   _kdyk, kiuo, جماه, ीरात_
  { {0xb17b006f,0x64430051,0xc8690009,0xd838001b}},	//   _igån, eeni, ון_, miče_
  { {0x2cb80227,0xbebd0035,0x798d0034,0xd62700ab}},	//   oord_, otīr, czaw, роче_
  { {0x2cb827a7,0xd7f20003,0x7ebd000e,0x62810073}},	//   nord_, _ذكر_, lépt, ūlot
  { {0xd4090003,0xf413000b,0xbb470003,0x2d80189c}},	//   اتهم_, קפה_, للون_, šie_
  { {0xd2570024,0xa2cc0011,0x7bc800d9,0x629b0073}},	//   аць_, _थीम्, _vzdu, giuo
  { {0x30a627a8,0x2cb81633,0x044a0001,0x635c000d}},	//   иров, kord_, _ипак_, _sănă
  { {0x644327a9,0x200702a1,0x31370009,0xb4fb0009}},	//   ceni, _ceni_, סנים_, _סלבר
  { {0xa8570009,0x08570009,0x6286008e,0x8b96004c}},	//   בייה_, בבים_, _olko, _трач
  { {0x3ea627aa,0x3cfd0011,0xefcc0060,0x539b0009}},	//   nnot_, रीके_, _ışığ, _ביבו
  { {0x59d20011,0xda650012,0x2cb827ab,0x98a00034}},	//   देशर, _دالي, ford_, stię_
  { {0xb97b0009,0xb5fb0031,0xbebd0035,0x7ea80060}},	//   _בנדי, eját, ttīs, lıpl
  { {0xd2d70003,0xe4510009,0x66e80030,0xe6590048}},	//   لغرب, הֶן_, _měkk, _бийч_
  { {0x3264002d,0x3fdb000b,0xa3cb0037,0x644327ac}},	//   отув, _בקוב, रेट_, zeni
  { {0x200700a1,0x3eb9002a,0x6443003a,0xbebd00cd}},	// [6e10] _yeni_, most_, yeni, erīg
  { {0x6a7c0108,0xd5ed0020,0x6d4d27ad,0x55bc0009}},	//   _défi, _hoà, _isaa, _במחו
  { {0x7d04008b,0x644327ae,0xdc3c0009,0x8c1a0009}},	//   _zwis, veni, _יעזר, _גותי
  { {0x63bb00a2,0x20070002,0x96940024,0x7c3a0032}},	//   ğund, źni_, оріш, _abtr
  { {0x1e58000b,0xfe700012,0x3e320012,0xa3d40011}},	//   ישאר_, بدل_, سفور, सेस_
  { {0x30850003,0x200c00b6,0x20850012,0x07f80012}},	//   _السف, jadi_, _السّ, _نرفع_
  { {0x26cd008a,0xa3d70044,0x660b0101,0x26c20002}},	//   _theo_, िधि_, pagk, ylko_
  { {0x7696007a,0x3a29002c,0x6d4d0872,0x200727af}},	//   ršyk, ngap_, _osaa, _seni_
  { {0x629b007a,0x3eb92282,0xe9d90015,0xa3cb0011}},	//   riuo, dost_, ыки_, रेज_
  { {0xac74000a,0xf992000b,0x14740003,0xa3d70037}},	//   _والش, פרי_, _والج, िधा_
  { {0x629b007a,0xe7390001,0x1878000b,0x23790012}},	//   piuo, ћем_, יעזר_, _حماد_
  { {0xceb20093,0xd336000b,0x2cb827b0,0x6609005e}},	//   ִים_, _לרעה_, word_, _jeek
  { {0x200c00b6,0x44a60012,0x95990560,0x959a0430}},	//   badi_, محسّ, атру_, утну_
  { {0x00f6000b,0xd8380027,0x58f6000b,0xab2a108b}},	//   _המסך_, tiče_, _המסע_, лога_
  { {0x9ef5000a,0x06f50003,0xc052000b,0x8fa204fb}},	//   _استش, _استج, _מזג_, _наше
  { {0x6609001e,0x7f760009,0xd838001b,0x4d160024}},	//   _neek, _לעצב_, riče_, _льот
  { {0x2b490002,0x273127b1,0x05ba0012,0xc4b90011}},	// [6e20] łach_, lán_, _حدثت_, ेताओ
  { {0x2731001a,0xb80a0003,0xe9d705f0,0x6f18068c}},	//   oán_, ايام_, ску_, ávco
  { {0x6d5b0005,0x5477000b,0x9cdb0009,0xfaaa0012}},	//   _arua, _הגיע_, _תקיפ, _مهدي_
  { {0x62860006,0xb5fb000e,0x3ea6001e,0x6b810623}},	//   _ulko, ljár, unot_, ølge
  { {0x3257000b,0x15130024,0x200c11d3,0x6d5b10b3}},	//   _הסכם_, здія, yadi_, _crua
  { {0xb5fb000e,0x6d480034,0x7aed0031,0x3ea627b2}},	//   njár, łdaw, _öltö, snot_
  { {0x3317000a,0x7f86000a,0x2731000f,0xd4670001}},	//   مزيد_, _الأن, ján_, сије_
  { {0x96950001,0xdd920003,0x32530014,0xc3330009}},	//   _друш, _فوز_, звър, פוח_
  { {0x2912002c,0xe1ef0003,0x7ebd0031,0x200c01a0}},	//   nsya_, رسي_, zéps, tadi_
  { {0x7ae8000e,0xdefa0015,0x97140103,0xbc190024}},	//   _tudt, лым_, омоц, _віці_
  { {0xb8ef0037,0x93f7000b,0x200c0133,0xb5fb000e}},	//   _वी_, _הצבא_, radi_, djár
  { {0x2715001a,0xddc4001e,0xf773000b,0x7afc009b}},	//   ính_, _maiņ, לקת_, dprt
  { {0xc05a0024,0xb5fb0097,0xfd670009,0x397a0012}},	//   _бій_, fjár, ֶ֑ךָ_, _حصاد_
  { {0xc917000b,0x201c01e3,0x7ebd0031,0xc0d30012}},	//   _פחות_, óvil_, gépr, _فينب
  { {0x3eb903eb,0xd5ed0020,0x309b000b,0xd6db0024}},	//   post_, _toà, _תשומ, _йти_
  { {0x46a40046,0x6d400070,0x9f5e0002,0x22940015}},	//   _најв, _opma, śród_, пися
  { {0x90990098,0x22580015,0x66090070,0x9fe70003}},	// [6e30] ават_, щиты_, _reek, مساه
  { {0x30150024,0x25a60097,0xa068004c,0x3cf80012}},	//   ідер, _þola_, бађа_, _اعيد_
  { {0x6d40001e,0x6447009b,0xbe150012,0xec360009}},	//   _apma, meji, قواع, _ואתר_
  { {0xaa590001,0x539a0009,0x44ef005e,0xad9d0034}},	//   _тиму_, _כיתו, _kü_, _weźm
  { {0xd1260351,0x2715001a,0x66090051,0x64550250}},	//   _تم_, ánh_, _veek, odzi
  { {0x22ac0066,0x645527b3,0xfb570009,0x660927b4}},	//   věka_, ndzi, ֶׁ֥ר_, _week
  { {0x15f90037,0x747c000b,0x66090574,0x64550f62}},	//   ंडार_, רנוג, _teek, idzi
  { {0x273127b5,0x44ef0051,0x23080003,0x7bc10107}},	//   ván_, _oü_, حتوي_, _vylu
  { {0xc42b0003,0x3ebf00b6,0x5ba60011,0x60e6003c}},	//   _مثال_, _ikut_, _ऐश्व, омым_
  { {0x273127b6,0x64550002,0x4879005c,0xd5c80009}},	//   tán_, jdzi, рсия_, _הֶעָ
  { {0xcdc9000b,0xbebd001e,0xd5ed001a,0xfe4600dc}},	//   _סך_, drīb, _soá, онно
  { {0x3f8b0002,0x9f5811f8,0x273127b7,0x645527b8}},	//   ącu_, _perú_, rán_, edzi
  { {0x2731024a,0x2d840042,0xbc850081,0x99dd0064}},	//   sán_, áme_, ưỡn, meňo
  { {0x273106ef,0xb4b60011,0x6b66003c,0x64550034}},	//   pán_, ड़ते_, окга, gdzi
  { {0x44ef0051,0x200a0054,0xe6c60012,0xda660012}},	//   _eü_, _rebi_, _وتعي, ياري
  { {0xd5ed0020,0x68e327b9,0x200a013a,0x0ae90012}},	//   _toá, _hind, _sebi_, صرفي_
  { {0xb5fb000e,0x68e327ba,0x600a0109,0x0ffa0012}},	// [6e40] pjár, _kind, инам_, لعاب_
  { {0x28cf0037,0x68e30066,0x7f5a004c,0x4fa619cd}},	//   _सीमि, _jind, ијет_, оизв
  { {0xc43b0009,0x68e327bb,0x63bb0060,0x20180064}},	//   _דתיי, _mind, ğunc, órii_
  { {0x5693002d,0x9e3a0012,0xcb130009,0x44ef0f1f}},	//   маєт, ؤساء_, _קלר_, _yü_
  { {0x2d58002d,0x8afc0002,0xc43a0009,0x7ae20ecb}},	//   силь_, _kręg, ֹתֶי, _riot
  { {0x6ce3002d,0x0b5a0012,0x3ead0040,0x04580012}},	//   міще, لشعب_, _ejet_, صلبة_
  { {0x442000a2,0x7ae227bc,0x7ebd000e,0xe7270012}},	//   ği_, _piot, képp, _تص_
  { {0x68e30149,0x32b70003,0x64550002,0x44200b71}},	//   _aind, يدية_, zdzi, şi_
  { {0xfe43007c,0xf2d3000b,0xdcea0066,0x5ca6010c}},	//   _інфо, ועה_, čněj, _диаб
  { {0x0b1a0003,0x6a7c0025,0x660f0034,0xdfda0048}},	//   _نقطة_, _réfu, wack, иън_
  { {0x44f00020,0x660f27bd,0xde590024,0xf1c60030}},	//   _hà_, tack, бані_, _řádu_
  { {0x6455003e,0x66020033,0x68e327be,0x7aa60012}},	//   wdzi, nbok, _eind, _بإطل
  { {0xd6d8007c,0x61a50044,0x1fb70037,0xd12f0003}},	//   ють_, खपृष, _अड्ड, _لمن_
  { {0x44f00020,0xee3f0004,0x66ca015b,0x38780248}},	//   _mà_, mným_, kýko, _norr_
  { {0x44f027bf,0x6455003e,0x57fb0009,0xf76f0012}},	//   _là_, rdzi, _דלוו, _لاي_
  { {0x44ef0051,0xd319004c,0x66740012,0x68e327c0}},	//   _tü_, _цeнт, _يدير, _zind
  { {0xf6d40003,0xee3f01bd,0x23e70024,0x3eb20031}},	// [6e50] _تزود, nným_, _мінв, ézte_
  { {0x660d0051,0x27e70033,0xee3f0030,0xd7fb27c1}},	//   _heak, ønn_, iným_, руа_
  { {0x0ff80012,0x660d016d,0x6728001b,0x752227c2}},	//   تعقب_, _keak, nudj, eroz
  { {0x44f00020,0x8bd6000b,0xd6180012,0x7afa0031}},	//   _bà_, _מותו_, قتها_, ítte
  { {0x63ad0039,0x248c0010,0xee3f05b1,0x44f00081}},	//   šinā, šimų_, jným_, _cà_
  { {0x317a0093,0xb97a000b,0x6d5d0028,0x69cf001e}},	//   _הרשמ, _הנשי, _ásam, _izce
  { {0x68e310c1,0xf62b0024,0x67280159,0x75220030}},	//   _rind, _візи_, judj, aroz
  { {0x67210027,0x0905003c,0x68e327c3,0x752227c4}},	//   vrlj, ппин, _sind, broz
  { {0x6aa90028,0x44f0001a,0x68e312bd,0xa5670012}},	//   rnef, _gà_, _pind, _بدأن
  { {0x27070031,0x6abb032f,0x320b0972,0xd8380919}},	//   tőn_, souf, źcy_, tiča_
  { {0xf0920009,0x27e90060,0x68e327c5,0x6aa90097}},	//   גני_, _şans_, _vind, pnef
  { {0x64900051,0x7d0927c6,0x8f9a0009,0xe7360198}},	//   _käig, _kwes, מיתי, чею_
  { {0x0ab80003,0x81a70012,0x9583003c,0x7d1c0035}},	//   _بطلب_, _بحال, еляе, _ārsk
  { {0x67280006,0x9c7c0027,0x443e0066,0x78fa000b}},	//   budj, _ličn, ýt_, _הפסו
  { {0x9359002d,0x87040003,0x9f5e0031,0x67d2004c}},	//   орту_, _قبيل, zatú_, _пољу
  { {0x64860065,0xc7b2000b,0x7d160010,0x3af10064}},	//   _aðil, _רבה_, šysi, _máp_
  { {0x66e80013,0xad9b0028,0xa96700f5,0xa9260024}},	// [6e60] _děku, lbún, пита_, ядал
  { {0x90c30047,0x76960010,0x859b000b,0x44f00081}},	//   ебуе, ašyt, _לשפו, _rà_
  { {0xb8f3015f,0xe73a0001,0xbc7b000b,0x66020262}},	//   _ही_, сее_, _הנית, tbok
  { {0x212900c6,0x4dda0012,0x6445005e,0x443e0018}},	//   buah_, موضح_, õhin, _sbt_
  { {0x78a10065,0x72db0009,0x05ba0012,0x9e650012}},	//   kilv, _לקטג, حدات_, ظامن
  { {0x44f0008a,0x290027c7,0x3ea20070,0x66020262}},	//   _và_, mpia_, hikt_, sbok
  { {0x5f2700b3,0xca960009,0x3af10081,0x75220030}},	//   _норм_, ּדִי_, _cáp_, sroz
  { {0x43830003,0x60f8004d,0x75220626,0xee3f01bd}},	//   عليق, ония_, proz, tným_
  { {0x7ae600a2,0x85060012,0xa5070048,0x6490005e}},	//   _mikt, _روان, _нета_, _käid
  { {0xb0be0037,0xf8be0037,0x8afc0002,0x3ea2001e}},	//   ्तिग, ्तिय, _pręd, eikt_
  { {0x66e80013,0x660d27c8,0xad9b0028,0x99e60063}},	//   _někt, _peak, gbún, _ежед
  { {0x7ae627c9,0x2720004b,0x20030097,0xee3f06dd}},	//   _nikt, mănă_, ðjir_, pným_
  { {0x3ea7000e,0xc6930009,0x4a5b0009,0xca970009}},	//   énti_, תאר_, _לדאו, _צדדי_
  { {0xb9db0093,0x649000b9,0x660d002a,0x81a50012}},	//   _החדש, _näid, _weak, _تحمل
  { {0x083b0093,0x7528003e,0x883b01b0,0x20180029}},	//   _העול, ądza, _התוו, óriu_
  { {0xe8df0020,0xd1bb0003,0x2735006f,0x02450012}},	//   ược_, ماذا_, vån_, بَرَ
  { {0x76960010,0x2249002a,0x82340012,0x260b0011}},	// [6e70] ršyt, reak_, عرفا, ारसी_
  { {0xed60007a,0x4f6b0015,0xa4d50024,0x69c602dd}},	//   įžti_, йшем_, _іоні, _dyke
  { {0x6e190003,0xf3f1001a,0x3f8700d9,0x644a27ca}},	//   قياس_, _lạc_, ánu_, defi
  { {0x3f8f003e,0x27350163,0x3952004a,0x66df0010}},	//   ągu_, rån_, änsä_, _būki
  { {0x3f870027,0x4a5a0009,0x78a10031,0xd7fb04a5}},	//   šnu_, _ודרו, yilv, _губ_
  { {0xd7e6000a,0xc9520009,0x0d3c0009,0xe1f70011}},	//   _لك_, _שמם_, צגוב, ीर्ण_
  { {0xf4100003,0x03250024,0xe738003c,0x58d40560}},	//   اؤه_, єдин, _неё_, _чорт
  { {0xfbd40009,0x51650024,0xf3f10081,0xbe650012}},	//   עתק_, двиб, _bạc_, _تهري
  { {0xd12e0003,0xc4f80003,0x2eee0052,0xdb1a05b1}},	//   لمي_, _فعلا_, _auff_, _vytá
  { {0x5d540842,0xad9b0097,0x2eee036c,0xef1914dd}},	//   _якут, tbún, _buff_, омо_
  { {0x6d4400c1,0x7e7b0066,0xc2eb0012,0x6e3d0032}},	//   _spia, _koup, _طعام_, ffsb
  { {0x29d50003,0xe5a60511,0xaf98003c,0x3bba0009}},	//   _قياس, дими, ятых_, _ומעד
  { {0x7ae61204,0x90890012,0x66ec0060,0x764b0031}},	//   _rikt, _ونصك_, _işke, iegy
  { {0x98f40003,0x61da0009,0xd9421728,0x200e0097}},	//   _أثنا, _וקנד, _реши, _gefi_
  { {0xfce304b3,0xa3d80037,0x7ae60010,0xd7fa0009}},	//   торо, ़ें_, _pikt, _והצל
  { {0x764b000e,0x645806dd,0x644a1654,0x4ea50a36}},	//   jegy, zdvi, zefi, _прња
  { {0x68e70070,0x7ae627cb,0xceb30009,0x2bc00011}},	// [6e80] _bijd, _vikt, _שיח_, _एडवा
  { {0xcce60003,0xeb0d0011,0x96f90009,0x2fc70132}},	//   _تسعي, _सबूत_, ַלְת, _kyng_
  { {0x64900051,0xf989000b,0x7ae609d4,0x78be0227}},	//   _väid, סר_, _tikt, ropv
  { {0x98a90002,0x29000dce,0xbf650012,0xdfcf0012}},	//   ytać_, ppia_, عدلو, جيم_
  { {0x64900051,0x41030014,0x20c20028,0xc2130009}},	//   _täid, _изяв, iðir_, _בהר_
  { {0x95970009,0x6fd60011,0x74140012,0xe1ff097c}},	//   וכנו_, _भरपू, روبا, ñón_
  { {0x17790047,0x64900051,0xcb670001,0x44f40d64}},	//   _есть_, _käib, даје_, _lä_
  { {0x5a340014,0x8f9b000b,0x3860000d,0x68e70070}},	//   хнит, _וילי, _şir_, _zijd
  { {0x3cfa0037,0xbea31240,0x644a27cc,0x44f427cd}},	//   ्ठों_, _ратк, pefi, _nä_
  { {0x3ea0000f,0xd7f70109,0x942309e8,0x9c7c001b}},	//   _amit_, мую_, _амфе, _kičm
  { {0x98a9003e,0xf76f0003,0x9346002d,0xe80f0011}},	//   stać_, لاَ_, _інде, िरता_
  { {0x64410002,0x2ca30070,0x20c20097,0x42540012}},	//   _zbli, wijd_, gðir_, _سنتر
  { {0x2ca300bd,0xb4e90011,0x99340012,0x7d0227ce}},	//   tijd_, यदे_, _أفتت, npos
  { {0xd7ef0001,0xdbfb0011,0x2eee0248,0x7d02093c}},	//   _ју_, ्रेड_, _tuff_, ipos
  { {0x2ca30070,0x4c9b0009,0x68e70227,0x5f730012}},	//   rijd_, קבלו, _rijd, _لاير
  { {0xbcfb000e,0xd7f8000d,0xc1050012,0xeb910009}},	//   tvéd, lcă_, فوري, נָם_
  { {0x6aad087a,0x44f4006f,0x5ea40012,0x7e7b27cf}},	// [6e90] rnaf, _gä_, _جميل, _roup
  { {0xd0110003,0xd7f8000d,0x2919000e,0x7d0d002c}},	//   الا_, ncă_, ásai_, _iwas
  { {0x64450051,0x229a001e,0x2fc70058,0x79960034}},	//   õhim, lūku_, æng_, azyw
  { {0x68e70227,0x7d0d0d61,0x6fd10011,0x9295004c}},	//   _wijd, _kwas, _हरसं, _чамц
  { {0x68e700bd,0x79960002,0xa5090001,0x1d0905fb}},	//   _tijd, czyw, чела_, чели_
  { {0x64900005,0x752b0227,0x27380031,0x673a0841}},	//   _täie, rugz, kén_, kttj
  { {0x2738000f,0xce950014,0xb0be0037,0x28be0037}},	//   jén_, _завъ, ्तरग, ्तरि
  { {0xd24e0003,0x7d0200b0,0x273827d0,0x67d407a7}},	//   منى_, bpos, dén_, _росу
  { {0x04c90012,0xf9910012,0x225927d1,0x95540012}},	//   _فوري_, طبة_, _mask_, _لخلا
  { {0xc9520009,0x7d1b008e,0x44f409ee,0x3ea0071d}},	//   נמי_, _ivus, _rä_, _smit_
  { {0x20110013,0x3dc9002c,0x2738000e,0xac380012}},	//   _mezi_, _ayaw_, gén_, _تسقط_
  { {0xd7f8007d,0xdd1e007d,0xc4c9000b,0x63bb003a}},	//   acă_, _câşt, _הג_, ğunl
  { {0x20c20065,0x02160009,0xb80f0011,0xa3c90011}},	//   rðir_, _נחסם_, िराम_, ोधक_
  { {0xf9880012,0x27380478,0x628f27d2,0x44f419ae}},	//   _تنهي_, bén_, _alco, _vä_
  { {0xcbc50012,0x6286005e,0xcb6700b5,0xb6a60048}},	//   نزفي, ökog, наре_, _пикл
  { {0x7d020002,0x44f400e6,0x8f9a0009,0xa3d40011}},	//   ypos, _tä_, _מיצי, सेट_
  { {0x9556000a,0x6aa40051,0x98a4001e,0x08390009}},	// [6ea0] _أخبا, riif, lumā_, ּעֲל
  { {0x224d0070,0x79960002,0xbcfb0061,0x50650012}},	//   heek_, rzyw, uvée, َالِ
  { {0x160a0003,0xd437000b,0x03a60695,0x0e5a0009}},	//   كياً_, _אריק_, _чино, ּדְב
  { {0x644e0b4a,0x20070028,0x2bb60011,0x040f0081}},	//   lebi, ðnir_, _अखबा, _đêị_
  { {0xe89b0060,0x271c0081,0x64a614f1,0x24580367}},	//   _çağı, ảnh_, нада, даль_
  { {0x644e00a2,0x98a4001e,0x6723013a,0x7d0202d5}},	//   nebi, kumā_, šnja, rpos
  { {0x98a40039,0x851c0037,0x644e21ed,0xba9a0009}},	//   jumā_, _निकट_, iebi, ּסִי
  { {0x6564002c,0x7f3b000b,0x66e30001,0xdb220002}},	//   _orih, _מעלו, _боса, _śród
  { {0x444427d3,0xdcfa0012,0x644e27d4,0x66d60031}},	//   _ob_, _رفضت_, kebi, kákb
  { {0xf3f10020,0x3137000b,0x644e0027,0x80ca0037}},	//   _hạn_, ענים_, jebi, _सीखे
  { {0xd7f8000d,0x7d0d00b6,0x7bc8003a,0x395f03d3}},	//   rcă_, _swas, _uydu, avus_
  { {0xd7f8007d,0x644e0051,0x9bb7000b,0x444427d5}},	//   scă_, eebi, _אהבה_, _ab_
  { {0x22510066,0x27381007,0xc27b0009,0xf27b0009}},	//   ánků_, sén_, _מראי, _מראש
  { {0x645a00b6,0x2738000e,0x61430001,0x91e300de}},	//   _jati, pén_, _сеља, _соче
  { {0x5b24064f,0xd32401d4,0x905b0009,0x444427d6}},	//   льта, льти, _זכות, _db_
  { {0x9ee90003,0x8d950012,0xd25811a2,0x645a27d7}},	//   _تفعل_, _للبش, нцу_, _lati
  { {0x2b520002,0x7ebd000e,0x644e27d8,0x78270012}},	// [6eb0] łych_, képz, bebi, فعال
  { {0x7e6d0065,0xd91b000b,0x644e0017,0x6f0d0034}},	//   _hnap, פובל, cebi, _łaci
  { {0xf3f1008a,0x752f0002,0x78a50027,0x225912c5}},	//   _bạn_, lucz, rihv, _task_
  { {0x9f580f70,0x765d0058,0x395f0010,0xf7480012}},	//   _però_, ndsy, yvus_, علني_
  { {0xddc4007d,0x8a160009,0x645a09fb,0x98a40035}},	//   _iniţ, _בחרו_, _bati, zumā_
  { {0x0445004c,0x7d1c0035,0x67220035,0x6da40012}},	//   текн, _ārst, ņoja, دمهم
  { {0xb21b0058,0x60c127d9,0x9f4101e3,0x224d092c}},	//   _ulæs, volm, rchó_, teek_
  { {0x9f5e000f,0x6d5d0010,0x644e27da,0xb1450024}},	//   ható_, _šsau, zebi, внил
  { {0x644e00a2,0xb6040066,0x75d50012,0xb3eb0012}},	//   yebi, ndář, _شيئا, _فعال_
  { {0x98a4001e,0x7e6d1cf5,0xd9440012,0x2129016d}},	//   tumā_, _anap, ائيي, irah_
  { {0xb4cd0037,0x3209002c,0x753d0031,0x29040060}},	//   रती_, kbay_, etsz, apma_
  { {0xdc0a0037,0x98a4001e,0x656427db,0x645a27dc}},	//   वर्ड_, rumā_, _prih, _zati
  { {0xe1f0000a,0x361a000b,0xd497001a,0x69cb0052}},	//   _اسم_, וורד, ằng_, ügel
  { {0x98a4001e,0x9f5e000e,0x2ca7004b,0x61fd0b6e}},	//   pumā_, gató_, nind_, _afsl
  { {0x644e27dd,0xaac60003,0xd6aa0003,0x80ca0011}},	//   rebi, نترن, _يدعم_, _सीटे
  { {0x7afc000f,0xb21b0028,0x61fb27de,0x2ca727df}},	//   _érte, _slær, ncul, hind_
  { {0xc212000b,0x3eb9000e,0x3ea6004a,0x66d80066}},	// [6ec0] יהן_, érte_, viot_, níke
  { {0x7c850046,0x6bd60012,0xe9d71f33,0xe3d60012}},	//   _буџе, _لتجر, тку_, _لتجع
  { {0x22a8003a,0xee3a0a76,0x3ea6008e,0xc2c60012}},	//   aşka_, дне_, tiot_, _ليدي
  { {0x68ed039c,0x26c3001c,0x9bb70093,0x787e0066}},	//   _žodž, čkog_, _יהיה_, _závě
  { {0x645a27e0,0xf5ad0009,0x64580097,0x3ea61016}},	//   _pati, ּבוּ, _óvis, riot_
  { {0x3ea6004a,0x9f580028,0x14180012,0x03160011}},	//   siot_, _ferð_, ريبة_, _तबाह_
  { {0x9f580028,0x03960014,0xd4670001,0x3ea6008e}},	//   _gerð_, ърдя, тије_, piot_
  { {0xcb13000b,0x1dd30011,0xaa630024,0xfb83003c}},	//   בלה_, _सरलत, атьк, рышн
  { {0xda770048,0xdb1e008e,0x7aeb07c2,0x9c7c090a}},	//   тящ_, _hypä, _digt, _liči
  { {0x2bbb0037,0xf3ca0012,0xd46a0012,0xf9930009}},	//   _ऊँचा, _قبضه_, _تحرم_, ירח_
  { {0x32090101,0xd497000b,0x9b8a0012,0xd838001b}},	//   ybay_, _שכבת_, _تنال_, niči_
  { {0xad9b0028,0x752f0002,0x91690081,0x442127e1}},	//   lbúi, tucz, hứa_, _sdh_
  { {0x9f5e000f,0x7e6d009b,0xf6530009,0x70560012}},	//   tató_, _vnap, בצר_, _لنشا
  { {0x3af827e2,0x273c01e3,0x752f0034,0x9c7c0073}},	//   _kép_, kín_, rucz, _biči
  { {0xa3dd0037,0x273c0029,0x5439000b,0xd49800fa}},	//   तें_, jín_, עֲשׂ, тря_
  { {0x3166001c,0x7e6d0027,0x273c134c,0xda700012}},	//   _kroz_, _unap, dín_, يُّ_
  { {0x3af827e3,0xdddb1141,0xc8d90024,0x2129016d}},	// [6ed0] _lép_, _služ, емає_, urah_
  { {0x20b40037,0xad1c000b,0xb602000e,0x7d1b0d85}},	//   ुविध, _חוזר, őáll, áusu
  { {0x2ca7007d,0x22460002,0x27e7006f,0xb8fa0037}},	//   vind_, _obok_, änn_, _डी_
  { {0xbebd0039,0x64580065,0x9f580028,0x67230027}},	//   drīk, _óvir, _verð_, šnjo
  { {0x961d0039,0x45450003,0x7aeb0058,0xcad6000b}},	//   _noņe, انتق, _rigt, _תורת_
  { {0xb4cd0037,0x2611001a,0x85b80003,0x64900051}},	//   रते_, ạo_, خامس_, _läin
  { {0xbebd001e,0x4429003a,0x2ca727e4,0xdd030060}},	//   grīk, ğa_, rind_, ırım
  { {0xf3f10020,0x2ca7007d,0x66d6000e,0x44291c95}},	//   _tạo_, sind_, káka, şa_
  { {0x7aeb00c5,0x10150198,0x2174003c,0xddc60034}},	//   _vigt, льня, ауэр, zekł
  { {0xd7090047,0x69cb0042,0x20550148,0x66d60031}},	//   нное_, _vyge, утир, dáka
  { {0x16aa0a25,0x69cb0002,0x7c38006f,0x8fa50012}},	//   евни_, _wyge, _övri, امجه
  { {0xb8030011,0x8f880009,0x02a40a36,0xa5f70a36}},	//   _श्रम_, דְשֵ, _крчм, леџу_
  { {0xf3f1001a,0x721a0009,0xd2560009,0x273c11e7}},	//   _lạm_, _נוסח, _תשנה_, zín_
  { {0xc952000b,0xc1740003,0x6f650012,0x6aa927e5}},	//   _למד_, _خدمت, _مهتم, lief
  { {0xeb9a022a,0xa6f90009,0x78ad00d0,0x000000c4}},	//   хив_, _אִ֥י, čivě,
  { {0xb2950001,0xcb670001,0x225f00b6,0x66d6000e}},	//   ајућ, ћате_, nduk_, báka
  { {0x41270098,0x7d04001e,0x213f00b6,0x27ff003a}},	// [6ee0] лото_, ģisk, ntuh_, _şuna_
  { {0x07170037,0x78250003,0x459b000b,0x759b01b0}},	//   _दबाव_, لعمل, _נסיע, _נסיג
  { {0xa6e90020,0xdfcf0012,0xbcfb0025,0x3f8e08d0}},	//   _thự, كيك_, nvén, áfu_
  { {0xdb1e0061,0x44f9001a,0x98a40010,0x42560103}},	//   _évén, _bè_, mumą_, _стот
  { {0x63b60039,0xa613002d,0x98a40010,0xa6a90012}},	//   šanā, сміч, lumą_, خالق_
  { {0x6adc0044,0x273c0029,0x2a600051,0xb8f80037}},	//   मग्र, pín_, ldib_, ात_
  { {0x69dd0065,0xb5fb0004,0x7b460012,0x98a40073}},	//   ýsen, ndác, ائتل, numą_
  { {0x201a002c,0x6f030054,0x6b810033,0x6f4b0009}},	//   lapi_, ínce, ølgi, _אֲמַ
  { {0x39400f68,0x54360012,0xd7f00012,0xcc360012}},	//   ntis_, _مرار, يكة_, _مراع
  { {0x3157000b,0x3957000b,0x8d930003,0xc057002d}},	//   ניין_, נשים_, _الكش, гію_
  { {0x39400051,0x2902001e,0xdfd00012,0xed650073}},	//   htis_, ūka_, تيد_, _mažų_
  { {0x6028001e,0x61f60012,0x66d60031,0x6445005e}},	//   līmē, _إساء, táka, õhiv
  { {0xb5fd27e6,0x201a00b6,0xda650012,0xe1ff0034}},	//   _inšt, kapi_, _خالي, _znów_
  { {0x31370093,0xa7860012,0x645e27e7,0xdff60557}},	//   _ערוך_, _مشبو, _capi, _сядь
  { {0x201a00b6,0x98a40010,0x40eb000b,0x4394035c}},	//   dapi_, gumą_, _אַהֲ, барс
  { {0x92580103,0x5a340148,0xaa58004c,0x4a55004c}},	//   ласт_, йнст, лису_, јкас
  { {0x2eed0052,0x1da40011,0xf807003c,0x39400073}},	// [6ef0] _rief_, _खेलत, гчен, gtis_
  { {0x6d4d0101,0xe3b8003a,0xddc40027,0x201a00b6}},	//   _ipaa, _adım_, _uniš, gapi_
  { {0x23fa0093,0x14b80003,0x20d4004a,0x501b0009}},	//   _בהתא, _حديث_, päin_, גובו
  { {0x645e2459,0xdbff0011,0xfd1f00b8,0x44f901a0}},	//   _zapi, ॉर्ड_, osì_, _pè_
  { {0xddc50001,0x621a0009,0xa3e20011,0xfd1f00b8}},	//   јбли, _בורק, नेस_, nsì_
  { {0x63850047,0xd4d8002d,0xf3f1001a,0x2909004a}},	//   игла, льщі_, _tạm_, mpaa_
  { {0xe1f10003,0x3f870051,0x2909004a,0xf8b2000b}},	//   يسة_, änud_, lpaa_, _ושם_
  { {0xfbd00012,0xca850048,0xa8020060,0x79960034}},	//   أته_, ргий, çınm, _żywa
  { {0x225f003a,0xe9d90014,0x661627e8,0xc6920009}},	//   rduk_, ъки_, _reyk, _ואן_
  { {0xe8e00020,0xa3b50037,0xa3570003,0xdd3d0034}},	//   _địa_, जपा_, _مخصص, _dąży
  { {0xe7390046,0x6d4d002c,0x325501ec,0x7d0423e3}},	//   њем_, _apaa, _ввер, _stis
  { {0x98a40010,0xbcfb000e,0x55e60048,0x8f360009}},	//   vumą_, rvén, ионб, סארו_
  { {0x645e27e9,0xc4c60012,0xbca60012,0xd6560009}},	//   _papi, لتسو, لمحي, בירת_
  { {0xc19a000b,0xafe50015,0x98a40010,0xab2a029b}},	//   _בשני, _колл, tumą_, кога_
  { {0xa3a90037,0x93bc000d,0x2aba001e,0x4375002d}},	//   _खेद_, _scăz, lība_, бутт
  { {0x60280039,0xeab7057e,0x98a40073,0x02060ad3}},	//   zīmē, айс_, rumą_, рзан
  { {0x201a00c6,0xdc0c0010,0x2aba001e,0xe1f70339}},	// [6f00] tapi_, lėči, nība_, ргу_
  { {0x64900051,0xd826010c,0x60260646,0x7f46003c}},	//   _käim, рджи, рджа, иезж
  { {0x547b000b,0xe61a0001,0x41d50011,0xb4c40011}},	//   _סטטו, вде_, _दरअस, ौती_
  { {0xdfcf000a,0x201a0101,0x291f004a,0xcd06035c}},	//   ذين_, sapi_, ksua_, ачки
  { {0x7ae427ea,0x8d5609e8,0xa2c305f3,0x73fa00ae}},	//   mmit, ртеч, लवर्, نّشر_
  { {0x65690052,0xd7060003,0xa4380015,0x66dd000e}},	//   _dreh, _نظري, узку_, méke
  { {0x66dd000e,0x83fc0027,0x8cc50037,0x2d8b1396}},	//   léke, _nađe, ाक़ो, zyce_
  { {0xe8df0020,0xc2740001,0x649001a3,0x7146022a}},	//   ước_, слиј, _säil, ахож
  { {0xe0860003,0x22910028,0x7ae427eb,0x3134003c}},	//   لجدي, _tákn_, imit, щепр
  { {0x61e00066,0x7e6027ec,0x653b0009,0x7ae427ed}},	//   _úmlu, _hamp, _בעמד, hmit
  { {0xb8fd0044,0x501b000b,0x6d4d0070,0xcff7000b}},	//   _थी_, כויו, _spaa, יציה_
  { {0x2018003a,0x7bda001e,0x2aba001e,0x2d8b0002}},	//   _leri_, _iztu, bība_, tyce_
  { {0x7e6000c6,0x2aba001e,0xda7b0009,0xaae50012}},	//   _mamp, cība_, _שנדר, _اسلو
  { {0x442d008b,0x66dd000e,0x69cf0002,0x90970024}},	//   ße_, déke, _ryce, _квіт_
  { {0x442d003a,0x6020000e,0x24180015,0x92a70001}},	//   ğe_, zámí, росы_, ајал
  { {0xbea40001,0x442d27ee,0x7e6002a5,0xb77b0009}},	//   _мајк, şe_, _namp, _יאוש
  { {0x51f80015,0x6b5c079d,0x661d27ef,0xdd910012}},	// [6f10] рную_, _pågå, mask, _رود_
  { {0xa3d70037,0xdb1a0061,0x7ae414d5,0x9874004c}},	//   _सरल_, _exté, amit, олуц
  { {0x46bb0044,0x7ae4002a,0x7ce0006f,0xa857000b}},	//   _उदाह, bmit, förf, שיבה_
  { {0xd2460351,0x656904b4,0x645527f0,0xe738002d}},	//   _عن_, _preh, lezi, реї_
  { {0x2a760093,0x63bb00a2,0xbebd001e,0x66d605b1}},	//   _הערך_, ğunu, brīv, záko
  { {0x20180089,0x58d40014,0x00f6000b,0x63bb003a}},	//   _geri_, _моят, _למשך_, şunu
  { {0xd795000a,0x3ea9004a,0x69d90002,0x6f950003}},	//   _الأخ, _omat_, _szwe, _الأض
  { {0x13b8000b,0xfbb8000b,0xda170037,0x16340015}},	//   יהול_, יפות_, तरित_, _меся
  { {0xf3f10020,0x1c0b0044,0x65940046,0xcaa40003}},	//   _lại_, _स्थल_, _дату, تصوي
  { {0xbcfb0028,0x3ea900b6,0xf1b90027,0x2aba001e}},	//   rvél, _amat_, jaše_, rība_
  { {0x66dd0031,0x2aba001e,0x3f91119d,0x645527f1}},	//   zéke, sība_, ázu_, dezi
  { {0xbebd001e,0xa9270010,0x6b60000e,0xdc0c0010}},	//   esīb, _pažį, ságá, rėči
  { {0x24850051,0xddcb0002,0x99f60009,0x25d50009}},	//   _kolm_, legł, _הזנה_, מוֹן_
  { {0x2b93001a,0xfc030264,0xb4c40011,0x88c40012}},	//   ọc_, зпро, ौते_, _وتول
  { {0x66e60838,0xf6520003,0x661d27f2,0xe29a0472}},	//   _лока, _فئة_, bask, гав_
  { {0x66dd000f,0x272300a2,0x6490005e,0x201827f3}},	//   téke, mın_, _käik, _seri_
  { {0x44fd0020,0x2723003a,0x32190415,0x28a40011}},	// [6f20] _gì_, lın_, _desy_, गोवि
  { {0xc6100037,0x645500c1,0x7e620002,0xaa7b0029}},	//   ार्य_, cezi, wdop, _chýb
  { {0x272300a1,0xf989000b,0x91c90037,0x2018045a}},	//   nın_, ער_, _हुसै, _veri_
  { {0xc3330093,0xb4db0054,0x4ea50024,0x6d4205d3}},	//   _צור_, ntàn, оріа, ttoa
  { {0x7bda0002,0xceb3000b,0x0bf40024,0x963b0009}},	//   _sztu, היא_, оплю, רגנט
  { {0xb896000a,0x6ab20044,0x272300a2,0x40960003}},	//   _السع, ुक्र, kın_, _السر
  { {0xa3e20044,0x6286019a,0xbb470003,0x6d4227f4}},	//   नें_, _koko, ملون_, stoa
  { {0x2723003a,0xe81c0011,0x20d4005e,0x66d80097}},	//   dın_, _पड़ता_, käik_, míko
  { {0xdee30047,0xd010000a,0x49740024,0xbebd0035}},	//   _хоти, ولة_, ілос, irīt
  { {0xc173000b,0xf98f0012,0x30a30024,0x27230060}},	//   פחת_, عبي_, зрюв, fın_
  { {0xbebd0039,0x44fd00c1,0x7bda001e,0x75220052}},	//   krīt, _sì_, _uztu, lsoz
  { {0xa2f7000b,0x05dc0037,0x6286001e,0x62650003}},	//   _המאה_, _बराब, _noko, _وانق
  { {0xa3e60037,0x3f9e0002,0x66dd000e,0x661d2287}},	//   बेस_, sztu_, tékb, rask
  { {0x44fd0020,0xfaf30003,0x2723003a,0x66040027}},	//   _vì_, كثر_, bın_, _efik
  { {0xf8bf0061,0xd7f8000d,0xd2d70003,0x2723003a}},	//   éée_, ndăm_, مغرب, cın_
  { {0x3ea900c6,0x7afa0723,0x201a005e,0x201e27f5}},	//   _umat_, _mutt, _õpib_, lati_
  { {0xe1f00003,0x764d002c,0xfe700003,0x7afa0362}},	// [6f30] فسك_, _ibay, _أدى_, _lutt
  { {0x7ce0000e,0x798d00b6,0x6490004a,0x201e27f6}},	//   görd, ryaw, _näih, nati_
  { {0x69c1003e,0xf3f10020,0x23a70044,0x200100c1}},	//   _śled, _tại_, _केंद, rchi_
  { {0x7c2827f7,0x200100c1,0x9179001a,0x3eb905df}},	//   _addr, schi_, hất_, nnst_
  { {0x272300a1,0x3eb90036,0x7afa0006,0x7ce00248}},	//   zın_, inst_, _autt, börd
  { {0x272300a1,0x69dd1456,0x201e12a2,0x4ddc0009}},	//   yın_, _izse, jati_, אחדו
  { {0x2b93001a,0xd6db0014,0x9f34002d,0x7afa0802}},	//   ục_, _бта_, _нері, _cutt
  { {0x64900051,0x59990009,0xdb200030,0x65860097}},	//   _päik, ֹשֻׁ, ítán, ðuhó
  { {0xc9850003,0xe8f60015,0x05bb0012,0xa9fa0009}},	//   تشغي, олы_, _صدرت_, יִית
  { {0x7d040039,0x64900005,0x272300a2,0x28a40037}},	//   ģist, _väik, tın_, गोलि
  { {0xa3a90044,0x752400c1,0x656d016d,0x661b0227}},	//   _खेल_, _sviz, _arah, _keuk
  { {0x272300a2,0x7af8000e,0x25f00011,0xceb20009}},	//   rın_, _évti, ुँची_, ֵים_
  { {0xdce0007d,0x272300a2,0x7ce00052,0xb4db0054}},	//   _urmă, sın_, höre, rtàn
  { {0x272300a2,0xb4db0054,0x6722001e,0x201e033c}},	//   pın_, stàn, ņoji, cati_
  { {0xe5190037,0x57240003,0x6e290975,0x35de0011}},	//   नीति_, _فريق, _odeb, नेज़
  { {0x07d8000a,0x28dd0044,0x6e2d000e,0x83fc0027}},	//   _اذهب_, _नीति, óabl, _mađa
  { {0x3eaf27f8,0xd9430086,0x70860024,0x64c60012}},	// [6f40] digt_, мети, огаз, _ويبل
  { {0x7ce0006f,0xd0260024,0x3eaf27f9,0x66d60031}},	//   före, імей, eigt_, kákk
  { {0xc815002d,0x160a0003,0x628627fa,0x7e64008e}},	//   яєть, لياً_, _toko, _kaip
  { {0xc869000b,0x0eca0037,0xfee90003,0x7bde009b}},	//   כן_, रविड, معنى_, _izpu
  { {0x7e640101,0xadb70003,0x201e029a,0xe4c60223}},	//   _maip, يهما_, yati_, ойди
  { {0x6e2900a2,0xcf2f003a,0x7afa096c,0x7e6427fb}},	//   _edeb, üşüm_, _putt, _laip
  { {0xddc9009b,0x201e27fc,0xd4c50012,0x6d46005e}},	//   _vneš, vati_, أغني, htka
  { {0x7e640101,0xee37002d,0x201e00b6,0x98a40010}},	//   _naip, _мнс_, wati_, irmą_
  { {0x26cb00c1,0x1d070594,0xa50710ef,0xba9b0009}},	//   voco_, _мети_, _мета_, יסקי
  { {0x7afa01a2,0xdb1e0061,0x9179001a,0x7c280058}},	//   _tutt, _expé, uất_, _uddr
  { {0x57fb0093,0x7afa0006,0xe758002d,0xa2c70037}},	//   יליו, _uutt, щині_, ावश्
  { {0xc6a7002d,0x569400b3,0xc7b80027,0x656d27fd}},	//   ірни, дают, gađa_, _prah
  { {0x19b60003,0xfaf8001e,0xc2e90012,0x201e27fe}},	//   _بحاج, _trīs_, _اعلم_, pati_
  { {0xcce70003,0x14cb0015,0x3eaf0227,0x645827ff}},	//   تسجي, рыми_, zigt_, nevi
  { {0x69d60119,0x6458001e,0x386d003a,0xc6d70003}},	//   _øyeb, ievi, _ğer_, _وتعت
  { {0x539b0009,0x656d2800,0xbf9b0009,0x079b0009}},	//   בילו, _trah, _כיוש, _כסול
  { {0x66d80029,0x1ec40012,0xb5fd001b,0xd1300012}},	// [6f50] ríkl, _تقيّ, _naša, َمِ_
  { {0xa3cd0037,0x44b40015,0x7ce002f1,0xf1b904d2}},	//   रथम_, _обыс, töre, naša_
  { {0x7d0901a2,0xa7fc003a,0x46150012,0x3eaf15dd}},	//   _stes, ydın, كوار, tigt_
  { {0x9f4a000e,0x9f980028,0xd35a0009,0x9258003c}},	//   áján_, ráða_, _פדרל, _дают_
  { {0x41e7007c,0x527a000b,0x427a000b,0xa4d5002d}},	//   _фіна, _הנרא, _הארג, поді
  { {0xf538000b,0x3eaf0572,0x60fa0009,0x9b450012}},	//   קטור_, sigt_, _להשק, كنتو
  { {0xe2910003,0xda710012,0x68fd0601,0x66dd0031}},	//   فذة_, ُّع_, _husd, zéka
  { {0xb3bc000b,0x3bbc000b,0x78ba2801,0x7d0003a7}},	//   ימוכ, ימוד, entv, ímsk
  { {0xdb0a022d,0xa7fc003a,0x7d09079d,0x314b0009}},	//   čnéh, rdın, _utes, ׁתֵּ
  { {0x48790015,0x64582802,0x7c970012,0x6e3d0032}},	//   ссия_, cevi, _بشرا, egsb
  { {0x201c00c1,0x64900051,0x80880012,0x80480009}},	//   _devi_, _käiv, تضيف_, חֲרֶ
  { {0xc3320093,0x98ad009b,0xa7fc0060,0x68f50073}},	//   _טוב_, mreč_, ldıl, _lizd
  { {0xdd920003,0x76590034,0xc7b8001b,0x7e641545}},	//   روس_, iewy, rađa_, _vaip
  { {0xe0d8002d,0x8fa506da,0x68f50060,0xa7fc0060}},	//   _дві_, _нале, _nizd, ndıl
  { {0x7d0f000f,0xa3e60044,0xccf2000b,0x68fd0052}},	//   apcs, बें_, תכם_, _ausd
  { {0xe61f0026,0x244f003a,0xdb0f000e,0x68f509d4}},	//   skôr_, lımı_, ójár, _aizd
  { {0x8ffa0003,0x7e9b000b,0x68f5003a,0x7ae92803}},	// [6f60] مرار_, _לסקו, _bizd, imet
  { {0xd12f000a,0x244f003a,0x3ead0051,0xf7ea0012}},	//   امل_, nımı_, _amet_, مرضى_
  { {0xd4c5000a,0x3b0a0046,0x7ae90005,0xabfb007e}},	//   _تغيي, _ћемо_, kmet, _להיר
  { {0xb5fd01ff,0xdfcf0003,0x4b7b0009,0x76a90024}},	//   _paša, ديم_, _האטו, отів_
  { {0x244f003a,0x64580761,0x7ae91c7c,0x8e470012}},	//   kımı_, tevi, dmet, سلوك_
  { {0xd5af0012,0x2bb80011,0xa3d4003c,0x7ae22804}},	//   دفه_, इपला, молч, _shot
  { {0x7ae21de4,0xe81f0011,0xa09b0009,0x2f012805}},	//   _phot, _मज़ा_, _פילט, _nóg_
  { {0x64580039,0x77bb000b,0x201c001e,0x6b810051}},	//   sevi, _המלח, _sevi_, älgi
  { {0x7afe000d,0x41530015,0xfcd60012,0x6cd60012}},	//   _lupt, евыс, _فيرج, _فقرا
  { {0x67220039,0x26c3001c,0x7ae90051,0x859b000b}},	//   ņoju, čkom_, amet, _השמו
  { {0x7ae90017,0x16350063,0x82fa0012,0x7a360060}},	//   bmet, меня, _طراز_, gütü
  { {0x20070065,0xba17000a,0xeb97000b,0xbfa7003c}},	//   _efni_, _فيما_, _מדבר_, ятые_
  { {0xd12f0003,0x2bd20037,0x244f003a,0xcd070024}},	//   _ممن_, _दुबा, bımı_, ячни
  { {0xe7be0037,0xe2f90024,0x3ae10064,0x76590034}},	//   ्थाप, жеві_, rópe_, zewy
  { {0x67d3007c,0x66d80028,0x2cb1000e,0x17f70012}},	//   _пошу, ríkj, rizd_, _عروة_
  { {0xd7bb000b,0x3264002d,0x68f5003a,0xb5fb000e}},	//   _לצור, нтув, _sizd, zdáj
  { {0x518702e2,0xdce9009b,0x64480054,0xa954002d}},	// [6f70] чува, _sreč, òdic, нкті
  { {0x7ae900a2,0xdce92806,0x351c0009,0xd7950048}},	//   zmet, _preč, _הוזנ, мизъ
  { {0x649003fc,0x59f90015,0x44231577,0x7bc00032}},	//   _päiv, _меня_, maj_, ßmut
  { {0xe7300003,0xddcd009b,0x442c2807,0xd6180012}},	//   اصل_, _znaš, _add_, كتها_
  { {0x290b000e,0x249e0010,0x244f0060,0xc5680012}},	//   _utca_, šymų_, yımı_, كحول_
  { {0x2a690005,0xdce90010,0x2c6d000e,0x66dd05b1}},	//   ldab_, _treč, ködő_, kéko
  { {0x6e2d001c,0x26c30027,0x66dd000e,0x7ae92808}},	//   _odab, čkoj_, jéko, tmet
  { {0x2a690005,0x66dd000e,0x03780009,0x439c0009}},	//   ndab_, déko, לתות_, מבוג
  { {0x64900005,0x4423237c,0x6efa0066,0x244f003a}},	//   _käit, kaj_, _vůbe, tımı_
  { {0x39492809,0xf8bf0011,0xaf050198,0x26cf280a}},	//   itas_, ्विय, мпол, logo_
  { {0xb904015f,0x229c0065,0x7d0d03e9,0xd2510003}},	//   _भी_, _líka_, _atas, _لنا_
  { {0x66d80028,0x656d0029,0x3949280b,0xbd460012}},	//   víkk, ťahu, ktas_, ونجي
  { {0xa3e00044,0x95830047,0x20bf0037,0x0d830024}},	//   _तरह_, вляе, ्वाध, влян
  { {0x649000b9,0x673a0054,0x78fa007e,0x7ce0006f}},	//   _näit, butj, _ולספ, föra
  { {0x9f43004a,0x316d0284,0xddcd009b,0xb5fd1774}},	//   äjä_, lvez_, _vnaš, _našo
  { {0xa3e20044,0x79960034,0x628b280c,0x3949280d}},	//   नेट_, _żywi, _jogo, ftas_
  { {0x628b012e,0x9e650012,0xb5fb0031,0x09290012}},	// [6f80] _mogo, _ساين, zdák, كسلي_
  { {0x917a0020,0xddc40004,0xe73a0024,0xb9060011}},	//   _cấp_, _kniž, жеж_, _पठ_
  { {0xdfcf0003,0xd47b000b,0xb4da0037,0xbc7b000b}},	//   ليك_, _ואיל, ़ती_, _ונית
  { {0x645c00a1,0x628b013a,0x9fe50012,0x64630035}},	//   leri, _nogo, رسله, ītiņ
  { {0xfe790013,0xfee90003,0x6fcf0037,0xdb1e0002}},	//   _dnů_, أعلى_, _सुसं, _typó
  { {0x64900051,0x7d1b0034,0x70560012,0x430a05c8}},	//   _täiu, _dwus, _تنسا, охим_
  { {0xbcfb000f,0xf6260001,0xd3700012,0x73070012}},	//   lvét, _одво, اهب_, وقوف_
  { {0xa7fc00a2,0xafe300b3,0x2912002c,0x63a3000e}},	//   rdım, _росл, opya_, _ünne
  { {0xa80200a2,0x4444280e,0x9f65008e,0x628b280f}},	//   _çıka, _oc_, ätös_, _dogo
  { {0x66dd000e,0xf74a002d,0x74130003,0x645c2810}},	//   téko, оїми_, _لوكا, jeri
  { {0x6e2000c6,0xf8370093,0x75290470,0xa837000b}},	//   _kemb, ונית_, _zvez, וריד_
  { {0xe7e60044,0x3949007a,0x44230002,0x6e2000b6}},	//   _करना_, ytas_, waj_, _jemb
  { {0x442305bd,0x6490004a,0xa7fc003a,0x41e20037}},	//   taj_, _näis, ndık, _परिस
  { {0x6e201b61,0xe4e40024,0xb9db0009,0xb5fb0031}},	//   _lemb, вісн, _וחדש, zdáh
  { {0xdfd0000a,0xbcfb000e,0x46ce0011,0x442316e5}},	//   _حيث_, evét, ़वाह, raj_
  { {0x4423184c,0xdb0e000e,0xb5fd0010,0xbb840003}},	//   saj_, ájáb, _rašo, خلفي
  { {0x7d0d000f,0x4423012e,0xddc4179a,0x645c0935}},	// [6f90] _utas, paj_, _zniž, beri
  { {0x753d0034,0x645c2811,0x39492812,0xb5fd2813}},	//   musz, ceri, rtas_, _pašo
  { {0x3ae10065,0x9f040003,0xf7730003,0x8704002d}},	//   hópa_, نولو, خاذ_, вяче
  { {0xb5fd2814,0xaedc0024,0x9e670012,0x26cf00b8}},	//   _vašo, обхi, بائن, uogo_
  { {0x64900005,0x27ff003a,0x7aed2815,0x6e200b2c}},	//   _täit, _şunu_, ňatk, _demb
  { {0x611a000b,0xd91a000b,0xb5fd0042,0x64900038}},	//   _מושה, _מושל, _zašl, _häir
  { {0x628b0470,0x8c1c0009,0x565b0012,0x66c80060}},	//   _pogo, חווי, _وشرح_, lıke
  { {0xc3340093,0x7ce00028,0xc1e30037,0x6e2000b6}},	//   דוק_, jörn, _खराब_, _gemb
  { {0xd84e001a,0xf1b90010,0x6445000d,0x316d0061}},	//   _vọng_, rašo_, _ochi, uvez_
  { {0x93bc007d,0xa8740015,0xe7390001,0x645c0698}},	//   _adău, вующ, пео_, xeri
  { {0x765d003a,0xbcfb000e,0x4c9a0009,0x69d600b0}},	//   fesy, zvét, _צבעו, _øyen
  { {0x8f9a0009,0x64452816,0xe6ca0011,0x645c2817}},	//   פירי, _achi, रवेज, weri
  { {0xdb0a0066,0x26de001e,0x8d760003,0x753d0102}},	//   čníh, ēto_, راحا, gusz
  { {0x66d80028,0xb4da0037,0x7c210031,0xbcfb0031}},	//   ríki, ़ते_, _jelr, evés
  { {0xfbc70003,0xb5fd001e,0xd8740003,0xfddc0037}},	//   ات_, _pašl, _جانب, _बर्फ
  { {0x6445007d,0x7546002d,0x64900574,0x645c2818}},	//   _echi, _зниз, _päis, seri
  { {0x6e260101,0x66250012,0x6e202819,0xdced017b}},	// [6fa0] makb, _شريك, _remb, _zrač
  { {0x38a40028,0xe9df0054,0x07a602ad,0x6e26281a}},	//   _mörg_, _abús_, назн, lakb
  { {0x6f0b007d,0x6e2000c6,0x96fa0003,0xe4c90012}},	//   _încă, _pemb, سعار_, _تبين_
  { {0xd7ef0003,0x64900051,0x212901bd,0x1ea90012}},	//   حكم_, _täis, bsah_, واني_
  { {0x6fd00037,0xf9fb0009,0x11d600ae,0x54fa05f3}},	//   _तुरं, _מהכמ, _ستحد, एआइए_
  { {0x765d0002,0xcb340014,0xfb66004c,0xa7fc0060}},	//   zesy, векъ, ењим, rdık
  { {0x61e2000f,0x37e3002d,0x25a6000e,0x7c21281b}},	//   _szol, _борг, szol_, _delr
  { {0x7549000e,0x29020137,0xb5fb0018,0x7c21005e}},	//   öszö, _kuka_, ldáv, _eelr
  { {0x5bbd0011,0x912a0012,0x7ce00097,0x6e26016d}},	//   _ईश्व, أسبق_, vörn, dakb
  { {0x2902120d,0x5d130012,0x7aed281c,0x23690034}},	//   _muka_, _إِلا, zmat, łaja_
  { {0xd497000b,0xdfd00003,0x290202df,0x21290042}},	//   _רכבת_, شيح_, _luka_, zsah_
  { {0xdced009b,0x6445281d,0x65620032,0x6f03281e}},	//   _vrač, _schi, owoh, ínci
  { {0xf8bf0013,0x65620052,0xba170012,0x66dd0031}},	//   _svém_, nwoh, _أيها_, lékk
  { {0x753d0002,0xb1e50012,0xbddb0025,0x3ea0281f}},	//   rusz, _شأنه, ffèr, _elit_
  { {0x2902071a,0x75f6003a,0x765d002c,0x7aed2820}},	//   _auka_, _yüzü, pesy, tmat
  { {0x3fdb000b,0xe7db000b,0x5fdb000b,0x290200b6}},	//   _מקוב, _מקוש, _מחוק, _buka_
  { {0x200b003e,0x44212821,0x60f90015,0x19580015}},	// [6fb0] ście_, _teh_, дная_, наты_
  { {0x290f001e,0x2aba001e,0x58d8003c,0x55bc0009}},	//   īga_, mību_, едуя_, _ממחו
  { {0x2aba001e,0x7aed2822,0xbfab0048,0x14d80009}},	//   lību_, ňati, чтае_, _אוזל_
  { {0x6aa40cc1,0x66d60031,0xe6040012,0x6d4b2823}},	//   chif, lákr, هِمَ, ttga
  { {0x2aba001e,0x8d650015,0xb5fd0027,0xd469004c}},	//   nību_, твле, _hašk, диле_
  { {0x01360093,0x5fb20037,0x6e26000e,0x22980028}},	//   _ברשת_, ुपाल, zakb, _fékk_
  { {0x4c920001,0x9f47004a,0xfaa50015,0x98a90002}},	//   ријс, änä_, како, erać_
  { {0xe7e60044,0xb5fb000f,0x7bda0002,0x6f0905b1}},	//   _करता_, ldáu, _dytu, _čech
  { {0x7ce0006f,0xdce9004b,0xaa56004c,0x6e260031}},	//   förl, _creă, тињу_, vakb
  { {0x2ebc0044,0x2aba001e,0xd3a70426,0x5ba70d6d}},	//   ोक्त, dību_, _преп, _през
  { {0x6e260101,0xddc20035,0x75f60060,0xbea6155d}},	//   takb, mdoš, _tüzü, ванк
  { {0x98a9003e,0x96960001,0x64432824,0xc4c90009}},	//   brać_, трош, lgni, _וג_
  { {0x05631103,0x6145115e,0xdbdc0097,0x7ce00248}},	//   авян, _рела, _háði, börl
  { {0x7f850003,0xdd0c0034,0x66d60031,0x44272825}},	//   _للتن, _półg, gákr, nan_
  { {0xddc2001e,0x290200b6,0xab2a0024,0x628f016d}},	//   idoš, _suka_, ьова_, _boco
  { {0xdd92000a,0x44272409,0x2aba001e,0x3ea0002c}},	//   _نوع_, han_, bību_, _ulit_
  { {0x44272484,0x41270098,0x2aba001e,0x394d2826}},	// [6fc0] kan_, кото_, cību_, ntes_
  { {0xb7960001,0x6f0300b6,0x394d2827,0x44272828}},	//   крећ, _kunc, ites_, jan_
  { {0x03a6002d,0x9182001a,0xdc9b000b,0x5c37000b}},	//   _рино, iết_, _חייל, _ברין_
  { {0x2492001e,0x3ea0000e,0x6f030fb3,0xe126003c}},	//   žamā_, óit_, _munc, _имми
  { {0x7d040070,0x7bda0002,0xb5fd01bd,0x95c70177}},	//   _juis, _sytu, _zašk, куша_
  { {0x7d040006,0x64430163,0x61e62829,0x66dd0031}},	//   _muis, ggni, _izkl, tékk
  { {0x2d8001b3,0x2aba001e,0x3d190011,0x69dd0032}},	//   ţie_, zību_, _बढ़ने_, üsen
  { {0x68fc0272,0xdee6024d,0x46130012,0x2cb80132}},	//   _hird, _роби, _نوفر, hird_
  { {0x60f80014,0x7ce002f7,0x81430012,0x31c60048}},	//   нния_, törl, لنين, ъскв
  { {0x7bda003e,0x38a4006f,0x66d80028,0x4427282a}},	//   _tytu, _före_, ríku, can_
  { {0x38a400a2,0x883b000b,0x6e950129,0x752d282b}},	//   _göre_, ותיו, гину, _svaz
  { {0x2aba0039,0x52760003,0x7ce0003a,0xc7b80027}},	//   tību_, _جائز, sörl, nađi_
  { {0x98c60047,0x394d02be,0xc237000b,0x7d040ebe}},	//   _искл, ctes_, _יראו_, _cuis
  { {0xd1970093,0x6abd0037,0x2aba001e,0xc5f30009}},	//   _בכדי_, ्क्र, rību_, ידר_
  { {0x2aba001e,0xda350015,0xeb040015,0xcf8f0001}},	//   sību_, левы, ичто, _тј_
  { {0x5a340de1,0x68fc0132,0xb5fb0031,0x4427282c}},	//   инст, _aird, reáb, zan_
  { {0x3eb903fb,0x68fc282d,0xb5fb000e,0x4427282e}},	// [6fd0] mist_, _bird, gdát, yan_
  { {0x4814002d,0xb5fd2156,0x26c30042,0x25d80009}},	//   имус, _tašk, čkou_, _בוחן_
  { {0x8c1a000b,0xfaf8001e,0x7e6d0feb,0x4427282f}},	//   _אותי, _drīz_, _kaap, van_
  { {0x442713b9,0x7e6d054e,0xdbdc0097,0xb5fd001b}},	//   wan_, _jaap, _ráði, _kaši
  { {0x9182001a,0x7c2500a8,0x2d990010,0x44272830}},	//   yết_, _kehr, nyse_, tan_
  { {0xdfc6000a,0xb5fb000e,0x68fc2831,0x7d760003}},	//   _هي_, ldás, _gird, امور_
  { {0x7c25008b,0xddc2001e,0xa3550012,0x3eb909d7}},	//   _mehr, rdoš, اختص, kist_
  { {0x69dd0006,0x36d50015,0x7afd0066,0x7c250052}},	//   _kyse, _собр, _jist, _lehr
  { {0x6f030027,0x394d05d1,0x44272832,0x3eb92833}},	//   _sunc, utes_, pan_, dist_
  { {0xf9920093,0x69dd002a,0x62860d64,0x97350009}},	//   צרי_, _myse, ökor, ְרָא_
  { {0x5b1509f0,0x7ce0006f,0x3eb90028,0x7afd004a}},	//   _смет, börj, fist_, _oist
  { {0x7d0409a4,0x7afd2834,0x87560009,0x3eb92835}},	//   _puis, _nist, נברג_, gist_
  { {0x38610052,0x6e240033,0x7d040e0a,0x673a235a}},	//   kehr_, _veib, _quis, artj
  { {0x3ebe000f,0xe8bf0037,0x6e240052,0x7ce00028}},	//   őtt_, ्वोच, _weib, mörk
  { {0x7afd0416,0xc052000b,0x42560e0f,0x3eb90051}},	//   _bist, _הזו_, лтат, bist_
  { {0xaf020014,0x442506be,0xaac50012,0x68fc0035}},	//   _упъл, _lel_, لتقن, _sird
  { {0x95560003,0xceb30009,0x91ee0011,0x11e6076b}},	// [6fe0] _إخبا, _ליה_, चेंज_, ужам
  { {0x4425034e,0xb4660021,0x7bcf0028,0xe9d70129}},	//   _nel_, _скол, ánuð, уку_
  { {0xef1a0098,0x6ac60003,0x96ba0001,0x9fa20028}},	//   хме_, _مقدم, нуду_, níða_
  { {0x39400108,0xfbd3000b,0xcd2a0015,0xb4db2836}},	//   puis_, _לתת_, ежде_, gràf
  { {0x61e60039,0xf653000b,0x68fc001e,0x270c0066}},	//   _uzkl, מצא_, _tird, _měna_
  { {0x7afd0026,0x442a0005,0x40950001,0x44252837}},	//   _zist, nab_, _крст, _cel_
  { {0x8fa60046,0xd491001a,0x44252838,0x20070159}},	//   _саве, _dò_, _del_, žnic_
  { {0xbea3002d,0xaae60003,0xd91a04ad,0xddc905b1}},	//   _ласк, دستو, ньо_, _oceň
  { {0x6e93000a,0xe693000a,0x5e930003,0x442a033f}},	//   _القا, _القد, _القط, kab_
  { {0x2e240020,0x7e6d004a,0x31570012,0x442a2839}},	//   _đườn, _saap, اجية_, jab_
  { {0x32460003,0x442a044f,0xd7f7003c,0xd8d70009}},	//   _مناف, dab_, лую_, רויט_
  { {0x442a0051,0x2d990010,0xcff70009,0x2f2e0034}},	//   eab_, tyse_, טציה_, ręg_
  { {0x9cb50003,0x200b0034,0xa1130012,0xb5fd283a}},	//   لمحت, ścia_, _هونت, _paši
  { {0x30760001,0x673a009b,0x442a12c3,0xa98b0009}},	//   _људс, prtj, gab_, _רָאִ
  { {0xab84002d,0x7e620033,0xd8db0009,0xb09b0009}},	//   бутк, keop, _רקור, _איגר
  { {0x442a0051,0x78ba02a1,0xadf60011,0x7c25283b}},	//   aab_, litv, ेशान_, _wehr
  { {0x442a21f1,0xd491001a,0x96180003,0xa63c0009}},	// [6ff0] bab_, ừ_, _صغير_, _נגזר
  { {0xdddb13b4,0x78ba009b,0x9c47002d,0x94170009}},	//   _použ, nitv, _схил, _עַ֖ד_
  { {0x7afd012e,0xb4fa0009,0x46150012,0x3d190011}},	//   _tist, _שפתי, لوار, _बढ़ते_
  { {0x7afd0d1f,0xdce90027,0xaa670373,0x2f380012}},	//   _uist, _kreć, _сток, اثلة_
  { {0x442503eb,0x070b0037,0xdb030066,0x8e080024}},	//   _pel_, _संभव_, rzní, унів_
  { {0xd4910020,0xb9ba000b,0x78ba009b,0x113a000b}},	//   _tìm_, _יצרת, jitv, _בתשל
  { {0xd498000b,0x78ba283c,0x98a00010,0x4425283d}},	//   רכות_, ditv, usią_, _vel_
  { {0xddc4039c,0x442500bd,0x5275002d,0xc7b8001b}},	//   _laiš, _wel_, руку, nađu_
  { {0x84470003,0x3c470012,0x38a40248,0x16b30011}},	//   _مخال, _مضاف, _höra_, ूचीब
  { {0x40950015,0x38a4006f,0xf5940012,0xddc4001b}},	//   ррит, _köra_, _الْج, _naiš
  { {0xaec60015,0x442a0051,0x29020028,0x8e860339}},	//   ибол, vab_, íkar_, агне
  { {0xfd4c0020,0x442a00c6,0x6da60003,0x6e2b002c}},	//   _nhiề, wab_, لمجم, nagb
  { {0x442a0289,0x9fa20028,0x78ba009b,0xee3700b3}},	//   tab_, síða_, bitv, шня_
  { {0x61e600a2,0x49b80012,0xfdf60009,0x74160012}},	//   ükle, _حامد_, יצרת_, شورا
  { {0x00ba000b,0xa4430012,0x753d0034,0x6b7c004b}},	//   _במסמ, تَّو, arsz, _găgă
  { {0xfd4c001a,0x442a2466,0xb6d30012,0x76d30012}},	//   _chiề, sab_, _وقوع, _ويوض

  { {0x61460109,0x7ce0066d,0x7bde0034,0x442a005e}},	// [7000] реза, höri, _wypu, pab_
  { {0xd59b0009,0x34b30012,0x130a003c,0xdbdf0097}},	//   _סביל, _وميز, _иной_, _tíði
  { {0xa7fc00a2,0x4c3b000b,0x09e20037,0x643b000b}},	//   ldır, _בתיב, _पर्य, _בעינ
  { {0x2eed283e,0x97560009,0xe7370545,0xf1b90035}},	//   _chef_, ייעו_, рец_, lašu_
  { {0xa7fc00a2,0x68eb000e,0xa8060015,0xc237000b}},	//   ndır, üldé, _взгл, _דרכו_
  { {0xe71a000a,0x7ce0006f,0xb5fd0010,0xd5770009}},	//   _ليست_, föri, _našu, יתנה_
  { {0x38a40163,0x78ba012e,0xe78700d9,0x91830081}},	//   _göra_, vitv, yšší, _iếp_
  { {0xcb13000b,0xa3e90011,0xd6220557,0x93770b2b}},	//   חלה_, _बरस_, сiда, рбът_
  { {0x3952007a,0xe5a3002d,0x78ba283f,0x044606bd}},	//   ntys_, _дити, titv, _везн
  { {0xc953000b,0x31570009,0xec770198,0x6c330012}},	//   קמת_, סיין_, _кпу_, _وفقا
  { {0x78ba012e,0xbebd001e,0xdce90027,0xddc40073}},	//   ritv, ksīt, _sreć, _raiš
  { {0xddc4001e,0x8b9b0009,0x32930012,0xdce9001b}},	//   _saiš, _שבאת, _وللأ, _preć
  { {0x2a64012e,0x1cbb0003,0xd4070024,0x09e3004c}},	//   memb_, ناسب_, ияви, _доцн
  { {0x66c8003a,0x3944001e,0x7c2802a1,0x20d30012}},	//   lıkl, mums_, _jedr, _وتوج
  { {0xfd4c001a,0x39441eb3,0x501b0009,0x60170009}},	//   _phiề, lums_, _יוגו, _דחוף_
  { {0x3ffb000b,0xb3450017,0xdce90027,0x6e360002}},	//   _בפוע, luçã, _treć, _gdyb
  { {0x59a60037,0xe4e7002d,0x3944001e,0xf8070ee6}},	// [7010] गनिर, _вінн, nums_, ачен
  { {0x645e0051,0x656d002c,0x2bd20037,0x628d0051}},	//   õpil, _isah, _दुका, sjao
  { {0x7ea60028,0xb065004a,0x7fb90012,0xfd4c0081}},	//   _hópa, lmää, دهار_, _thiề
  { {0x39440039,0x63ad0039,0xcd350003,0xd6180003}},	//   kums_, ģinā, مرتب, لتها_
  { {0x39440039,0xee38002d,0x2bdb0037,0x66c8003a}},	//   jums_, рні_, _मुता, dıkl
  { {0x229c0028,0x40950012,0x1d180009,0x04590012}},	//   _ríki_, _الآر, סקור_, الغة_
  { {0x8c540003,0xb3450017,0xb065004a,0x1cb80003}},	//   تئنا, duçã, hmää, جانب_
  { {0x224b0052,0xa7fc003a,0x85050012,0x36d4003c}},	//   ück_, ydır, _هورن, _доср
  { {0x3944001e,0xb5fd0035,0x200309df,0x26d92840}},	//   gums_, _pašu, žjim_, doso_
  { {0x91830020,0x7c2801e0,0xf1b20009,0xa069004c}},	//   _xếp_, _gedr, פסי_, ћана_
  { {0x7ced0164,0x3ae10028,0xd62a096e,0x656d2841}},	//   gúre, hópi_, лоне_, _asah
  { {0x975a000b,0xba740003,0x7d0100e2,0x3952008e}},	//   נדרט, _وانت, _hils, ytys_
  { {0xceb2000b,0xc1080081,0x39440035,0xc5d60024}},	//   ליט_, _hỗn_, cums_, сінь
  { {0x7d0902d1,0x98a70013,0xb3450017,0x4dda0009}},	//   _mues, čně_, cuçã, רחשו
  { {0xb5fd001c,0x03a30015,0xf1b90010,0xb8dd0037}},	//   _zašt, пиро, rašu_, ीच_
  { {0x7d090061,0x8f9a000b,0x224900b6,0xbebd0035}},	//   _oues, _תיקי, ggak_, usīt
  { {0x7d0902d1,0x09fa0012,0x6d400031,0x04460148}},	// [7020] _nues, افذة_, ámad, _лепн
  { {0x6d460947,0x765b016d,0x39522341,0xdb0a0031}},	//   muka, _abuy, rtys_, szfé
  { {0x3606000a,0xc815002d,0xa3bc0037,0x6d4b006f}},	//   مواف, юєть, _अधि_, _ägar
  { {0x5286000a,0x7c2e02d1,0xdfcf000a,0xcf250003}},	//   _الحك, labr, رين_, تركي
  { {0xa2f7000b,0x7d090164,0xc213000b,0x6e290051}},	//   _למטה_, _cues, _מהר_, _deeb
  { {0xd5ed0020,0x3944001e,0x657b0107,0xb5fd0010}},	//   _hoạ, vums_, _druh, _rašt
  { {0x3e7f004a,0x7c282842,0x6d4601b7,0xd7960012}},	//   _jätä_, _vedr, huka, _الزخ
  { {0xb5fd039c,0x6d4600c6,0xb065004a,0xc1140001}},	//   _pašt, kuka, ymää, омиј
  { {0x7e97000a,0x7d09275e,0x96b90024,0x82330012}},	//   _انقر_, _gues, _туру_, سريا
  { {0xdb030272,0xd5ed0020,0x307a000a,0x98a40010}},	//   szná, _loạ, احظة_, ksmą_
  { {0xb4e40037,0x201e0010,0x74130012,0x60db0009}},	//   नती_, rbti_, _رونا, רקינ
  { {0xb5fb000e,0xdced0027,0x64580028,0xcf93000b}},	//   beál, _krać, lfvi, לטת_
  { {0xf1940047,0xe9ff0081,0x644a0b82,0xf4870198}},	//   _филь, _trạm_, ogfi, бувн
  { {0x442e00bd,0x7bc60030,0xb06503bd,0x7ae42843}},	//   naf_, _ěkuj, rmää, elit
  { {0x443f00a2,0xb065019a,0x39401d2d,0xa8570009}},	//   ğu_, smää, eris_, _ליגה_
  { {0x6d460101,0x7ea60028,0x97c50012,0x7ae42844}},	//   buka, _hópn, _بتهم, glit
  { {0x656d00c6,0x8638000b,0x442e00b6,0xce380009}},	// [7030] _usah, _הרחב_, kaf_, _האחת_
  { {0x51f80015,0x40180009,0x37ab004c,0xf8070223}},	//   сную_, שֵּׁ, лтен_, счан
  { {0xf7090020,0x394003eb,0x984c001e,0xa295002d}},	//   _lần_, aris_, dēļu_, _дані
  { {0x7d090164,0xb7db000b,0x518700fa,0xde59002d}},	//   _pues, נקאי, _луга, раді_
  { {0x6e290005,0x7d010039,0x7d091386,0x2a760009}},	//   _veeb, _pils, _ques, _וערך_
  { {0x83390015,0x644a14b5,0x7d090164,0x6aad0052}},	//   ачит_, ggfi, _vues, lhaf
  { {0x3ea20065,0x6d460002,0xc49c000b,0x6ec40031}},	//   ykkt_, zuka, רשות, lőbe
  { {0x3f77007d,0x29030164,0x6aad0052,0x7c2e13a3}},	//   _rău_, _hija_, nhaf, zabr
  { {0xf7090020,0x7d090005,0xd9fb0037,0x3f77000d}},	//   _cần_, _uues, ्शित_, _său_
  { {0x47c5002d,0xf709001a,0x7c340024,0x3ea92845}},	//   жбов, _dần_, _неух, _alat_
  { {0x61eb003e,0x7ae4004a,0x6ecb0034,0x27170081}},	//   _wzgl, ylit, rębn, _măng_
  { {0x60c80051,0x7ce00052,0x29190051,0x27170081}},	//   andm, hört, _otsa_, _lăng_
  { {0xf7090020,0xd656000b,0x61eb001e,0x7c2e00da}},	//   _gần_, חירת_, _uzgl, tabr
  { {0x27170020,0x2bdb0037,0x3f77000d,0x229c0028}},	//   _năng_, _मुहा, _tău_, _líkt_
  { {0x232a002d,0xe2ba0001,0x3ea92846,0x7c2e2847}},	//   роби_, аћај_, _flat_, rabr
  { {0x7ce00065,0x7d0a08b0,0x6aad0032,0x6aa3004b}},	//   vöru, _книг_, ghaf, _înfl
  { {0x29030039,0x2717001a,0x7ae423ba,0xdcf60012}},	// [7040] _bija_, _băng_, rlit, _وأخب
  { {0x3e7f0006,0x7ce00052,0x2717001a,0x290b199c}},	//   _tätä_, töru, _căng_, _duca_
  { {0xb4d60037,0x6f660012,0x8e0a0048,0x6aad0032}},	//   िकी_, تهام, анев_, bhaf
  { {0xdced001c,0x6aad0732,0x7ce40054,0xad660012}},	//   _prać, chaf, mòri, قاته
  { {0x200701a2,0x62862848,0x290301e3,0x200309df}},	//   _ogni_, _inko, _fija_, žjih_
  { {0xb5fd0039,0xb4e40044,0xccb7002d,0x54b7002d}},	//   _pašr, नते_, огії_, огія_
  { {0xb6a6002d,0xc27a0009,0x2aaa004c,0xe73717af}},	//   _дивл, ֹרִי, итио_, _мер_
  { {0x5a340c7b,0x5fb70009,0x27050035,0x751a0012}},	//   чнит, _והלא_, _lēns_, _نقرأ_
  { {0xdddd003e,0x21040037,0x09e30001,0x99660024}},	//   zesł, रदेश_, моћн, ітил
  { {0x9597000b,0xf709001a,0x91bb0009,0x19b70012}},	//   _וכמו_, _vần_, ימפי, غطية_
  { {0x6ec4000e,0x6d42002a,0xa2e60015,0x5bc60012}},	//   zőbe, lroa, _дожд, _بقال
  { {0xf709001a,0x7eb60035,0x99860012,0x98ab0035}},	//   _tần_, kšpu, _ولاو, ālāk_
  { {0x442c0064,0xcd070198,0x95c50012,0x443a2849}},	//   _ked_, ючни, سيسه, _bdp_
  { {0xdc080039,0x255e0039,0xa0670014,0x6ec4000e}},	//   rēķi, mālā_, _мача_, vőbe
  { {0x442c0846,0x43950024,0x8c1b0009,0x6aad0032}},	//   _med_, чавс, שולי, thaf
  { {0x3ea90101,0xeb91000b,0x7ce0066d,0xc1050003}},	//   _ulat_, עָם_, förs, كوري
  { {0x35b40014,0x7eb6001e,0x255e001e,0xaa7b0029}},	// [7050] _обър, gšpu, nālā_, _akýc
  { {0xab87007c,0x442c284a,0x67350097,0x718b0009}},	//   _думк, _ned_, _ófjö, יְבַ
  { {0x44310b1a,0x6aad0028,0x3cf80003,0x44f80012}},	//   maz_, phaf, _بعيد_, _بريج_
  { {0x7d0d00b6,0x4431284b,0xcb880009,0x59ca0011}},	//   _kuas, laz_, _וְשֹ, ापार
  { {0x27170020,0x867c0009,0xc27a0009,0x61c60011}},	//   _tăng_, יראו, _פרשי, लपृष
  { {0x443100c1,0xd5ae0003,0x7d0d284c,0x51fa0009}},	//   naz_, طفى_, _muas, _להרצ
  { {0x394900b6,0x7ced0164,0x9982001e,0x643c0009}},	//   luas_, gúra, _iekš_, בעונ
  { {0xdb120031,0x6d42284d,0x442c284e,0xe3b000ae}},	//   égéh, broa, _eed_, خره_
  { {0x8d870012,0x442c284f,0x26dd0034,0x7cf21489}},	//   _بشأن, _fed_, mowo_, lære
  { {0xdce4003e,0x78a90046,0xa3b60037,0x23770003}},	//   _ksią, ског_, _चेक_, _واضح
  { {0xbb48000a,0xeb090003,0x2bdb0037,0xe7390001}},	//   _ولكن_, _اقصى_, _मुला, љем_
  { {0x26dd0034,0x99800064,0x64410097,0x443a2850}},	//   nowo_, _žiť_, ólin, _sdp_
  { {0xd2590035,0x66dd0031,0x0d99003c,0xd0090681}},	//   ciņa_, rékp, отры_, _леле_
  { {0xdce4003e,0x711a000b,0x7ce40054,0xf1b20009}},	//   _osią, _הוספ, tòri, _אסד_
  { {0x7cf22851,0x26dd0002,0xafe22852,0xdb83003c}},	//   værd, kowo_, _пошл, нгри
  { {0x7ce00163,0xdc3d0039,0x8f9a000b,0x6ec4000e}},	//   törs, kšķu, _ליצי, sőbb
  { {0xe2971103,0x26dd0002,0x39490b45,0xf1c00035}},	// [7060] чат_, dowo_, guas_, ēšot_
  { {0x26c20082,0xb0630029,0xf709001a,0x55bb0009}},	//   liko_, jväč, _lầm_, _למפו
  { {0xc5f60037,0xdc9b007e,0xb4e80037,0x442c2853}},	//   ेश्य_, _הסיכ, बती_, _red_
  { {0x26c20101,0x62990002,0x645c02f1,0xfe720012}},	//   niko_, _nowo, lfri, عدا_
  { {0x3ae10065,0x4a7b000b,0x627b000b,0xb3a9003a}},	//   hóps_, _הרכב, _הנכנ, çını
  { {0x6ef10040,0x8d5b0009,0x7cf20474,0xd2590035}},	//   våbe, מכני, bære, viņa_
  { {0x442c045d,0x7d1b0006,0x60c1003a,0x26dd1b37}},	//   _ved_, _etus, dilm, bowo_
  { {0xb9090020,0x4a530014,0x32530014,0x7f3b000b}},	//   _nghị_, екъс, евър, _לעלו
  { {0x6299003e,0x4431003a,0x9d430048,0x6a130012}},	//   _dowo, yaz_, _петд, ربير
  { {0x7c3a00c5,0xe29f0028,0xd259001e,0x3ea610d8}},	//   _udtr, _miða_, riņa_, lkot_
  { {0xf093000b,0x61e60028,0x8c1b000b,0x7d0d137d}},	//   תנת_, _lykl, _הובי, _suas
  { {0x6443003a,0x7d0d00b6,0x76ab0063,0xc1d80011}},	//   _öniz, _puas, стов_, _भु्ग
  { {0x60c12854,0xf27b000b,0x2d800392,0xceb3000b}},	//   bilm, _לראש, _crie_, תיר_
  { {0x2d800070,0x2418003c,0x26c20073,0x26dd0034}},	//   _drie_, зоры_, aiko_, zowo_
  { {0x905b000b,0x6e2d0051,0xc053000b,0xa85b0009}},	//   _הכות, _teab, _נזק_, _הדוכ
  { {0x66e40046,0x644e002c,0x7cf200e2,0x6fbd0011}},	//   _поја, agbi, være, ्पसं
  { {0x443101c5,0x75d50012,0x80270012,0x6e3c0009}},	// [7070] paz_, _زيدا, كرام, _התחד
  { {0x3944001e,0x3ac50035,0x3ea60035,0x35b60011}},	//   irms_, lēpt_, ekot_, _आइज़
  { {0xc6e70024,0xe8d70009,0x07470024,0x26dd0034}},	//   підп, לומר_, яхам, towo_
  { {0xff170009,0x60c10060,0x3ea6016d,0x1e140024}},	//   פקדת_, zilm, gkot_, емця
  { {0xb6090039,0xf6500003,0x427a0009,0x527a0009}},	//   višķ, ائم_, _וארג, _ונרא
  { {0x62990052,0x26dd0002,0xd0060012,0xbdf80012}},	//   _sowo, sowo_, _لل_, سرنا_
  { {0x6299003e,0xb3d60037,0xfc300012,0x26dd0034}},	//   _powo, _मुफ़्, احه_, powo_
  { {0x26c22855,0xfeb800ae,0x6e3b0ea4,0x000000c4}},	//   xiko_, _فاقت_, _udub,
  { {0x7ce00052,0x60c1039a,0x645c0132,0x3ead0060}},	//   körp, tilm, yfri, _ilet_
  { {0xb4bc0044,0xa3ad0037,0x47590048,0xc7a5209d}},	//   _आगे_, कना_, ормя_, диок
  { {0x60c100a2,0xf709001a,0x6e460001,0x6d4b09dd}},	//   rilm, _tầm_, менз, luga
  { {0x2d80007a,0xfa900060,0x291f008e,0xb4d60011}},	//   _prie_, çütü_, ppua_, िक्_
  { {0xdc13003a,0x99670001,0x2007017b,0xce360009}},	//   _ağım, _хтел, žnih_, וארת_
  { {0xb8080003,0x26c22856,0xa5bb2857,0xf7450048}},	//   _فيهم_, siko_, mból, _жеко
  { {0x3ead0006,0x6d4b0065,0x290f0028,0x6fb20003}},	//   _olet_, huga, _huga_, _لموا
  { {0x6d59002c,0x67210159,0x29072858,0x7afb2859}},	//   ktwa, mplj, _hina_, nmut
  { {0x290f00ec,0x7afb0031,0x7cd60012,0x29071870}},	// [7080] _juga_, imut, _يتخذ, _kina_
  { {0x25fe0037,0xfc060015,0x63a30028,0xb8660012}},	//   रेणी_, _оппо, kynn, بارو
  { {0x61e6003e,0xe29a0046,0x29071633,0x2253004a}},	//   _wykl, _дан_, _mina_, änkö_
  { {0x9f960093,0x7ae9000e,0x56930024,0x5f060024}},	//   ודעה_, jlet, каєт, єзда
  { {0xfbc30037,0x6d4b00b6,0xb3c30011,0xa5bb0031}},	//   _वेबम, guga, _वेबख, jból
  { {0xcdb70009,0xf1e10011,0x25e60011,0x6ad60011}},	//   ופנה_, _पड़न, ड़ेगी_, डक्र
  { {0x63a309d9,0xbddb0061,0xd4670001,0x66090097}},	//   gynn, ngèr, фије_, þekk
  { {0x2907083c,0x7afb000e,0x2b40009b,0xd13a0015}},	//   _aina_, gmut, čic_, охо_
  { {0x7c3e285a,0x760b000b,0xb86a0001,0x286a0fdf}},	//   _odpr, _וּבַ, ојне_, орно_
  { {0x7afb0051,0x859b000b,0x29072570,0x5d9b0009}},	//   amut, _ושמו, _cina_, _ובמה
  { {0x290701ab,0xc1080020,0x291d008b,0xa7fc003a}},	//   _dina_, _mỗi_, _etwa_, ldız
  { {0xc1080020,0x6d480002,0x2907285b,0x8f370009}},	//   _lỗi_, ądan, _eina_, ואטו_
  { {0xe4e7002d,0x6ce7002d,0xc05a002d,0x8afb0009}},	//   дівн, діве, _дій_, _והאי
  { {0xdce40002,0xfc640014,0x67d407d1,0x61fd0042}},	//   _księ, късн, _полу, ýsle
  { {0xad9b0029,0xc108001a,0xbddb0025,0x7d08285c}},	//   ncúz, _nỗi_, ggèr, _mids
  { {0x539b000b,0x66c8000e,0x7d082400,0x79820034}},	//   חילו, tűke, _lids, _krow
  { {0x63a3003e,0x660d0051,0x6448052e,0x429b0009}},	// [7090] zynn, _igak, ódic, קסמב
  { {0x3ead00c5,0x7ae9000f,0x63a3004a,0x6d5a000d}},	//   _slet_, zlet, yynn, ătat
  { {0xdb55003c,0x69b00011,0xb4db0011,0x2c140011}},	//   _явны, आईडी, ़वी_, तुओं_
  { {0x64430017,0x23fa0009,0x57fb0009,0x33fa0009}},	//   _ônib, _מהתא, קלאו, _מהתנ
  { {0x721a000b,0x7ae9003a,0xc56b0012,0xd01b0024}},	//   _מורח, vlet, تحال_, _мфв_
  { {0x66c8003a,0xdd8e0003,0x443e0132,0xdce9001b}},	//   lıkt, صوى_, _cdt_, _pređ
  { {0x7afb0222,0x6d4b285d,0x25a90aa3,0xf8b20009}},	//   tmut, suga, šal_, _גשם_
  { {0x9f050003,0x69dc003a,0xfbd00003,0xfaf10012}},	//   _أورو, ğren, جته_, دثت_
  { {0x2bdf0044,0x79820ccb,0x270c0066,0x7afb285e}},	//   _पुरा, _crow, _měnu_, rmut
  { {0xc172000b,0x79821e40,0xa7fc0060,0x660d016d}},	//   נחי_, _drow, ldıy, _agak
  { {0xdce9001c,0xf092000b,0xd2510003,0x7ea60028}},	//   _uređ, אני_, _منا_, _hópi
  { {0x7ea60029,0x67210027,0x629d285f,0x52840012}},	//   _kópi, rplj, _noso, _للمك
  { {0x7982002a,0x66c8059b,0x0ab80003,0x6f090002}},	//   _grow, dıkt, _تطلب_, _miec
  { {0xc19a000b,0xc952000b,0x7cf20028,0xd1b80012}},	//   _משני, _עמו_, færa, _غانا_
  { {0x7c3e0149,0xeb9a0055,0xfaf601ec,0xd8760012}},	//   ópri, чив_, ечаю, _سميت_
  { {0x8a060046,0xe2970046,0xc332000b,0x68e1000e}},	//   езбе, нас_, טול_, lold
  { {0x200b0002,0x21670129,0xcb090009,0x68e1005e}},	// [70a0] ściu_, нити_, ֶל_, oold
  { {0x2bdb0037,0x23db0011,0xd5c00011,0x9c7c03a7}},	//   _मुका, _मुकद, _शेषज, _akčn
  { {0x5457000b,0xf457000b,0x6aa90623,0xdfcf0012}},	//   _אביב_, _אייר_, kkef, ميك_
  { {0x7d0800c5,0xdce4007a,0x6ef6000e,0x68e12860}},	//   _sids, _priė, lább, hold
  { {0x7ea60056,0x6c9a0009,0x2d58003c,0x98740035}},	//   _cópi, ּשֶׂ, филь_, ažās_
  { {0x6ecb0002,0x628b2861,0x9dd70009,0x5d8300ae}},	//   rębi, _ango, עוסק_, الول
  { {0x6f09007d,0xd62a0731,0x75222862,0x290a020d}},	//   _fiec, _нове_, spoz, _iiba_
  { {0x290a000f,0x7982003e,0x6ee30051,0xafe3003c}},	//   _hiba_, _prow, sõbr, _сосл
  { {0xf9920003,0xdceb003a,0x60f80048,0x7d080923}},	//   ابع_, aygı, мния_, _tids
  { {0xdfda0014,0xe5060003,0x68e1000e,0xd53b000b}},	//   зъм_, _أبري, gold, _מתמט
  { {0x9cb3000a,0xf8b3000b,0xc5fb0037,0x4f660012}},	//   _حملت, רשת_, ृश्य_, رادف
  { {0x7b190032,0x2bdb0011,0x6aa92863,0xfb1700ae}},	//   säuß, _मुगा, ckef, _أقنع_
  { {0xbcfb0061,0x31660064,0xa0a6004c,0x25a62030}},	//   ntég, _upoz_, _падд, nyol_
  { {0x629d02a0,0xd7940012,0x3f580018,0x6f940012}},	//   _soso, _للتخ, péu_, _للتض
  { {0x629d2864,0xc2c50003,0xb8e60011,0xee3f0030}},	//   _poso, نيسي, ैच_, lkým_
  { {0x290a0017,0x2d842865,0x6d5a004b,0xa2d40012}},	//   _aiba_, _orme_, ătar, هيّت
  { {0x629d01e3,0x7e7d0032,0x7cf200b0,0x6f092866}},	// [70b0] _voso, mdsp, mærn, _riec
  { {0x6f09003e,0x5b150098,0x7520000e,0x673a005e}},	//   _siec, _имот, ímze, ostj
  { {0xdfd10003,0xe70b0003,0x5bc70003,0x6d5d00a8}},	//   جيا_, ستان_, _ستدف, ltsa
  { {0x6ee7000a,0x52a70003,0xb2a70003,0xf5ab0009}},	//   رسال, _أصدق, _أحده, ּבַּ
  { {0x2a6d005e,0xba9a0009,0x68e10676,0x3a360009}},	//   veeb_, _חסרי, yold, _שרשם_
  { {0xe733000a,0x6f090002,0x84580014,0xd4660001}},	//   _مصر_, _wiec, ерът_, више_
  { {0x6d5d0005,0x8c1c000b,0x20120029,0xbcfb0061}},	//   htsa, לוגי, ániť_, atég
  { {0x7ea60017,0x7aed20df,0x6d4f001b,0xaa56004c}},	//   _tópi, nlat, kuca, вићу_
  { {0xe9d9007c,0xe8f90015,0x442700b6,0x68e10102}},	//   ьки_, мли_, pbn_, told
  { {0x7e7b008b,0xa2c10037,0x39490017,0x673a0028}},	//   _haup, रोत्, iras_, fstj
  { {0x6ef6000f,0x645e0054,0x22980066,0xaa7b0029}},	//   vább, òpie, _léky_, _akým
  { {0x39490010,0x99850003,0x68e12867,0x7cf6004b}},	//   kras_, _للصو, sold, râre
  { {0x7e7b00c6,0xdcb7001a,0xee3f0042,0x394d2868}},	//   _maup, ẳng_, ckým_, ques_
  { {0x7e7b0051,0x98a20538,0xc05b0024,0x97c50012}},	//   _laup, _више, _хід_, _لتعم
  { {0x6ef80066,0x6ef6000e,0xe29f0028,0x6e960003}},	//   líbe, rább, _boð_, _للغا
  { {0x394906fe,0xe7e50011,0x0d860148,0xe2860048}},	//   fras_, _कड़ा_, _алин, ълби
  { {0xe611000b,0x39492869,0x94261728,0x6441286a}},	// [70c0] _לִי_, gras_, _импе, _odli
  { {0xfbd20012,0x61e601a4,0xd0230024,0xb5fb286b}},	//   _نتج_, ükli, имуй, reát
  { {0x63a7003e,0xe0d5007c,0xb4c00037,0xdced0027}},	//   cyjn, ують, ूची_, _građ
  { {0x76a9007c,0x39490844,0x36060003,0xcf920009}},	//   нтів_, bras_, نواف, יטב_
  { {0x7ae40006,0x4438000d,0x290a00b6,0xdce0001e}},	//   moit, oar_, _tiba_, _apmā
  { {0x7ae40218,0x5453002d,0x55bb000b,0xad250012}},	//   loit, ивіт, ומנו, ارنو
  { {0xf413000b,0x38a4003a,0xf70a001a,0x7ea60028}},	//   ספה_, _dört_, _hầu_, _hópu
  { {0xf7770093,0xc333000b,0xfbd3000b,0x38a40028}},	//   _בעלי_, בוה_, יתו_, _vöru_
  { {0x63a70002,0xb6a30014,0x20070066,0x984a0014}},	//   zyjn, _титл, žnit_, мяна_
  { {0x7ae4004a,0x7e7b009b,0x673a09d8,0xddc40034}},	//   hoit, _zaup, tstj, _wciś
  { {0xf8370093,0x7ae4004a,0xbcfb0061,0xde59002d}},	//   כנית_, koit, ntée, нані_
  { {0x7c380149,0x7ae40006,0x38a4006f,0x443d0002}},	//   lavr, joit, _körs_, _św_
  { {0x3ea00108,0x673a0028,0xdd860012,0x2bdb0011}},	//   _doit_, sstj, حو_, _मुजा
  { {0x39490149,0x7d1d0054,0x6d5d286c,0x3d150011}},	//   vras_, _ésse, rtsa, _फंसे_
  { {0x9f580006,0xc3390013,0xd0f7000b,0xcb340014}},	//   ärä_, žívá, _שמות_, иеръ
  { {0x443800bd,0xf70a0020,0x63a70002,0x39490a71}},	//   aar_, _bầu_, ryjn, tras_
  { {0xf70a0020,0x63a70002,0x89340003,0xa3c90037}},	// [70d0] _cầu_, syjn, لعلا, _लेन_
  { {0x2edb0044,0x51f80015,0xf70a001a,0x6ef6000e}},	//   यक्त, тную_, _dầu_, mába
  { {0xf4120093,0x6ef6000f,0x2007004a,0xdced001b}},	//   _לפי_, lába, äni_, _urađ
  { {0x4ea70098,0xa295002d,0x753d000e,0xc6a70048}},	//   ърза, _самі, ossz, ързи
  { {0x6ef61007,0xb6bc0009,0xd1260012,0x5fa90011}},	//   nába, וצאי, _دم_, _चॅनल
  { {0x753d000f,0xd8380864,0x61eb0034,0x000000c4}},	//   issz, jač_, _rygl,
  { {0xd5bf001e,0x9f34002d,0xbb850012,0xbcfb0025}},	//   _šādu_, _весі, البي, ctée
  { {0x6ef6000e,0xdce90027,0x4438286d,0x60c8005e}},	//   kába, _oseć, zar_, eidm
  { {0x6ef6000f,0x10170037,0x38a417d4,0x00e50014}},	//   jába, _तलाश_, _görs_, лжин
  { {0x3ea00108,0x38750001,0x94770012,0x68e5180e}},	//   _soit_, ућит, _جدرا, nohd
  { {0x1eca0098,0xb5fd007a,0xa6ca0098,0x61eb0002}},	//   елни_, _rašy, елна_, _wygl
  { {0xcb12000b,0x9a880003,0xaca30081,0x4438286e}},	//   _הלא_, _لَمْ_, _ruộn, war_
  { {0x3ea003fc,0x7ae40006,0x68e5004a,0x6ef6000e}},	//   _voit_, voit, kohd, gába
  { {0x628f01a2,0x38b60058,0x2a7f0051,0x44381cda}},	//   _anco, _kære_, ldub_, uar_
  { {0x2ca50065,0x6d4b0032,0xc8da0009,0x753d0031}},	//   ölda_, hrga, _אקסט, assz
  { {0x2a7f0051,0x2d960015,0x6f0d286f,0x670c0011}},	//   ndub_, _брос, _giac, _सूचक_
  { {0x753d000f,0x7ae4104b,0x38b60623,0xd186003c}},	// [70e0] cssz, roit, _lære_, ылай
  { {0x7ae40006,0x4b26002d,0x395f2870,0x3f5c0097}},	//   soit, _ймов, itus_, tíu_
  { {0x395f0051,0xc209000b,0x6d4b055b,0xe7320012}},	//   htus_, פה_, erga, صصا_
  { {0xbcfb0061,0x395f0213,0xb6360012,0x539b0009}},	//   rtée, ktus_, اعات, _ניכו
  { {0xd259001e,0x64a62871,0xdca600db,0xbcfb0025}},	//   ciņi_, лада, лади, stée
  { {0xfce3002d,0xbd870003,0x6aa3000d,0xbcfb0025}},	//   бочо, انون_, _înfr, ptée
  { {0x3f780009,0x9c630012,0x38a40248,0x38b60040}},	//   _בָּע, صهيو, _förr_, _værd_
  { {0xdee60015,0x60c80032,0x66e617af,0x7c38001b}},	//   _соби, widm, _соба, savr
  { {0xd010000a,0xc4560012,0xc05a0024,0xed630030}},	//   يلة_, _مضاع, нін_, ěží_
  { {0xbcfb000e,0xc1730009,0x2bdf0011,0x2ee60227}},	//   ztéb, צחת_, _पुका, loof_
  { {0x2a660019,0xd83805dd,0x395f2872,0x6f0d0ea7}},	//   _бълг, rač_, atus_, _piac
  { {0x91860003,0x44442873,0x6ef606ef,0x51860012}},	//   _مجتم, _ad_, tába, _مشتق
  { {0x6f0d0026,0xa2f7000b,0x6909001b,0x889403b0}},	//   _viac, _עמדה_, _džej, _вилх
  { {0x6aa200bd,0x764400a2,0x3157000b,0xd00f0012}},	//   _hoof, _ediy, _עיון_, _فله_
  { {0x3267002d,0x6ef6000e,0xc3480048,0x64550035}},	//   лтав, sába, ляте_, rgzi
  { {0x44442874,0x6ef6000e,0x8aa401b6,0x600b0009}},	//   _ed_, pába, бруд, _נִגְ
  { {0x383505f7,0x40870f80,0xc1050012,0xbcfb0025}},	// [70f0] инар, лужб, لوري, rtéb
  { {0x14190003,0x26cb1bb3,0x3d180011,0x656d020d}},	//   _جيدة_, lico_, _पढ़े_, _ipah
  { {0x6d40006f,0x3f872875,0xa615003c,0x0615003c}},	//   _avma, ínu_, амеч, адею
  { {0x17f8000a,0x628f002a,0x395f0010,0xd5b10003}},	//   اركة_, _unco, ytus_, يفا_
  { {0xa5640003,0xd5480003,0x9a3a0009,0x2d640012}},	//   مدون, هجوم_, _שתשק, مطوّ
  { {0x212900b6,0x7b750003,0xddd60002,0xd469020e}},	//   mpah_, لطبا, _abyś, тике_
  { {0xeb9900be,0xab760012,0xbc380012,0x26cb0159}},	//   тий_, لموا_, اسها_, kico_
  { {0xf53f0163,0x38b6045d,0x34d20037,0x26cb01cd}},	//   kså_, _være_, _सद्द, jico_
  { {0x3e86000e,0x20240028,0xe0d90489,0x395f1598}},	//   nítő_, _árið_, кви_, utus_
  { {0x1f650015,0xf992000b,0x229c0066,0x05de0037}},	//   аком, קרי_, _díky_, _फुटब
  { {0x44442688,0x656d008e,0x26cb23d9,0xa8560009}},	//   _rd_, _apah, fico_, ביתה_
  { {0x444400b1,0x66e60dc2,0xe73604a5,0x97560009}},	//   _sd_, рома, шею_, סירו_
  { {0xf53f0260,0x91840012,0xbce60012,0x89370012}},	//   gså_, _هجوم, لأسو, _إعصا
  { {0x7cf20950,0x19ba0009,0x91ba01b0,0x7ae42876}},	//   mærk, _שמסב, _במני, čite
  { {0xdc08001e,0x394d00b6,0xd7880012,0xc0520009}},	//   mēģi, lres_, _مخيم_, _וזו_
  { {0x3eb9008b,0x394d2877,0xdc080035,0x78a30031}},	//   chst_, ores_, lēģi, _honv
  { {0xa96a0003,0x3b070014,0xb69b000d,0x3e86000e}},	// [7100] ضمام_, рето_, omân, gítő_
  { {0x394d0108,0x444400c5,0xdb18000f,0x3d0f0044}},	//   ires_, _ud_, szvé, ादों_
  { {0x394d0052,0x6287001e,0xee3a1009,0x7c3c2878}},	//   hres_, ējoj, вне_, marr
  { {0x9f470013,0x33db000b,0x394d0002,0x95ca00f5}},	//   _nyní_, _יחיד, kres_, кула_
  { {0x27e60034,0x6ef60031,0xdb160097,0x6aa22879}},	//   łon_, hábo, ðbær, _roof
  { {0x7c3c0065,0x7ce0169c,0x394d287a,0x88540009}},	//   narr, töry, dres_, _לֹֽא_
  { {0x9f5c0006,0xa6960046,0x6ef60028,0x6efd000e}},	//   ävä_, _крај, jábo, lébe
  { {0xc3330093,0xa3c70037,0x8c3c003a,0x0f7b0009}},	//   קוח_, _उधर_, _doğa, _באלב
  { {0x99970014,0xb1130015,0x26cb10f3,0xdce00073}},	//   икът_, омыш, vico_, _apmą
  { {0xc8490009,0x61eb0032,0x98e30012,0x394014b0}},	//   ְׂרָ, ügli, يكيو, isis_
  { {0x38170093,0x3ea400bd,0x6ec70003,0xa8570009}},	//   יקים_, _komt_, لتحق, סיטה_
  { {0x6efd000f,0xa1860015,0x03770009,0x5186004c}},	//   kébe, _выкл, _כתבת_, _вука
  { {0x6efd000e,0x26cb1d13,0xb2bb0009,0x6562287b}},	//   jébe, rico_, _במאר, ntoh
  { {0x14cb0015,0xba3b0025,0x1bbb0012,0x6458287c}},	//   тыми_, _coïn, نازع_, ngvi
  { {0x60fb000b,0x70fb0009,0x26cb287d,0x0ac70048}},	//   _שהוק, _שהוח, pico_, ащам
  { {0xbf9b0009,0x4f9b0009,0xa79b0009,0x9f9b0009}},	//   _ייוש, _יבוצ, _ישוח, _יסופ
  { {0x26c90027,0x443c0027,0x78270003,0x6efd000e}},	// [7110] _imao_, kav_, لعال, gébe
  { {0xdca40001,0x443c287e,0x37ab0048,0x68400030}},	//   _мањи, jav_, ктен_, vádí
  { {0x3e86000f,0x443c0051,0x46150003,0xbe150012}},	//   sítő_, dav_, موار, مواع
  { {0x2295000a,0x99840010,0x3e86000e,0x394d287f}},	//   _الحس, namų_, pítő_, yres_
  { {0xce380012,0x69d80060,0x27e20034,0x2bdf05f3}},	//   شأنا_, şver, ękny_, _पुजा
  { {0x394d0108,0x7cf20058,0x9b450003,0x3e47001a}},	//   vres_, værk, منتو, ốt_
  { {0x67d4002d,0x3f850061,0xd259001e,0x63800031}},	//   _дору, _élu_, ziņu_, váná
  { {0x394d2880,0x4bfc000b,0xcb14000b,0x99840010}},	//   tres_, כלוס, חלק_, jamų_
  { {0xdc08001e,0x443c2881,0x99840073,0x65150012}},	//   tēģi, bav_, damų_, _طوائ
  { {0x48790014,0x24810052,0xdcf90012,0xb3a90060}},	//   усия_, _nahm_, _صفات_, çısı
  { {0x14d6000b,0xd70a0015,0xf8b20009,0xb69b0397}},	//   _פועל_, лное_, פשט_, rmân
  { {0xd259001e,0x1bf60009,0x7b150030,0x63800031}},	//   tiņu_, _הצער_, _všud, sáná
  { {0xe7f40037,0x38b6071a,0x291900b6,0x621a0009}},	//   _अर्थ_, _læra_, _nusa_, _עוסק
  { {0xf8ab0037,0x78ba04a3,0xf9920009,0x25fe0011}},	//   _छविय, chtv, _מרד_, रेगी_
  { {0x29192882,0x3eb30031,0x2ca50ec4,0x7cf20474}},	//   _ausa_, ántó_, _mold_, næri
  { {0x7c3c05eb,0xcb670001,0xdb12000e,0x6efd000e}},	//   sarr, љате_, ógép, tébe
  { {0x10160003,0xfaa300b3,0xdeb7000b,0xb6bb0009}},	// [7120] مباد, чато, _לפקח_, _תצפי
  { {0xeb9a0046,0x6efd000e,0xb8650012,0x3ce10011}},	//   _био_, rébe, قامو, खकों_
  { {0xbb86000a,0x6efd000e,0xd00f0012,0xa0670048}},	//   _الجي, sébe, فلك_, саха_
  { {0xb6c5002d,0xe7370103,0x3ec50024,0x6562008e}},	//   осій, сец_, осіб, ttoh
  { {0x6b800039,0x443c2883,0x14ca003c,0x9cca003c}},	//   āmgu, tav_, лыки_, лыка_
  { {0x38b60065,0x7cf20028,0x2ca5170b,0x9d1b0009}},	//   _færa_, færi, _cold_, אוסט
  { {0x961d0039,0xdb15000f,0xc27a0009,0xb7da0012}},	//   _saņe, ozzá, ָרִי, _صورا_
  { {0xd00f0003,0xd357000b,0x443a009b,0xc2120009}},	//   _ألف_, ציפי_, _lep_, ּה֙_
  { {0xae1b000b,0xd9fa0037,0x2ca50132,0xb3a90060}},	//   _תומכ, ्धित_, _fold_, çırı
  { {0xf993000b,0xad1b000b,0x397b0009,0x2ca5096c}},	//   פרת_, _עובר, נטינ, _gold_
  { {0xd0100003,0x6448045a,0xd3b90024,0xbed90048}},	//   بلد_, _iddi, _куці_, идох_
  { {0xfaa3035b,0xeb97000b,0x6e2200b6,0xcff7000b}},	//   _нахо, _לדבר_, ncob, מציה_
  { {0xfe030011,0x61f60012,0x3a391fcd,0x7c3a2884}},	//   रेंस_, _اساء, _resp_, _ketr
  { {0x9f34002d,0x3f980051,0x443a27d8,0xdcfb001b}},	//   _декі, ärus_, _cep_, _vruć
  { {0xdddd000f,0x87260003,0xa0a30001,0x671d0011}},	//   reső, _اعتم, _хајд, _बंधक_
  { {0x443a00b6,0x29192885,0xe3c40012,0x83ab0009}},	//   _eep_, _pusa_, سْقَ, אֱמֶ
  { {0xdb0a000e,0x6115002d,0x5187077e,0xa1590400}},	// [7130] gyfé, іджу, щува, разу_
  { {0x69c0003a,0x7c3a2886,0x10070048,0x99d40012}},	//   izme, _netr, бяем, أتفا
  { {0xb065004a,0x83670003,0xc1040012,0xb8d40012}},	//   llää, _ادخل, أولي, ستكش
  { {0xdced0010,0xd6180003,0x2ca512c5,0x64482887}},	//   _praė, متها_, _sold_, _addi
  { {0xee38002d,0x5d670014,0x867c0009,0x7c3a2888}},	//   сні_, стез, טראו, _betr
  { {0x61fd0039,0x9179001a,0x6d3c0009,0xe38b0009}},	//   _izsl, hật_, נתונ, ָאֵֽ
  { {0x68fa0093,0x7ae90647,0x04560012,0x20230034}},	//   _כלשה, toet, زلية_, ąpią_
  { {0x6e3b0028,0x64482889,0x3949004c,0x7c3a005e}},	//   ðubl, _eddi, азио_, _eetr
  { {0x2ca5002a,0x7649002c,0xc1050003,0x6d920028}},	//   _told_, _idey, يوبي, rðað
  { {0x7ae4001c,0x25ed0037,0x7c3a0347,0xb5fb0031}},	//   čita, _घड़ी_, _getr, pfáj
  { {0xe7390046,0xc0520009,0x6d44288a,0x69c009df}},	//   јем_, וזי_, _svia, azme
  { {0xdce4001e,0x7d1b00e6,0x8d66003c,0xb9950012}},	//   _oriģ, _kuus, овме, _ولاب
  { {0xbcfb000f,0xe29f0028,0xa3c50037,0x21a50294}},	//   rtén, öðu_, उज़र_, _филм
  { {0xc1050003,0x69dc003a,0x6c360003,0x7d1b01a3}},	//   _بوتي, ğret, تفسا, _muus
  { {0x25fe0011,0x86c60012,0xd2aa004c,0xdce00073}},	//   रेजी_, _ويتن, акве_, _esmė
  { {0x26cf009b,0x6e3b0626,0x6d440073,0x6d400031}},	//   jigo_, _neub, šiai, ámas
  { {0x26cf288b,0x5c160012,0x9e650012,0x6d480034}},	// [7140] digo_, _وبدأ, _راين, ądas
  { {0x09030198,0x4425288c,0x99820073,0x70f60557}},	//   дпун, _nfl_, _sekų_, ічає
  { {0xf7720003,0x2d8d00c1,0x2564000e,0xfaa60dc2}},	//   باء_, _aree_, löl_, _дано
  { {0xcfa90003,0xa3e30011,0x4425288d,0x645c288e}},	//   حاكم_, _फुट_, _afl_, lgri
  { {0x2d8d0164,0x85760012,0xc5760012,0xcce60012}},	//   _cree_, تدائ, تطاع, يستي
  { {0x7af60006,0x734a002d,0xddcf000d,0x7ae9009b}},	//   llyt, ачив_, lecţ, čete
  { {0x6d420149,0xb4ca0037,0xa2c10037,0x7af6000e}},	//   ssoa, _लगी_, रोक्, olyt
  { {0xf413000b,0xc2980794,0x2d8d24b7,0xf96a003c}},	//   ופו_, ских_, _free_, арой_
  { {0x25640028,0xd0d40048,0x69c0001b,0x92570012}},	//   jöl_, зопъ, uzme, زشير_
  { {0x6cd60012,0x25640032,0xc0e70012,0x6f1c0034}},	//   _بقطا, döl_, يفين_, _kurc
  { {0xb4d60037,0x2d800caa,0xd6d10012,0xd7940048}},	//   ाची_, _asie_, فقد_, чинъ
  { {0x216a0a76,0xdee70012,0x22400031,0xa96a00fc}},	//   _види_, تأخي, jaik_, _вида_
  { {0x291f1bc5,0xcb130009,0xf5aa00af,0x88c600ae}},	//   cqua_, _חלף_, ׁבֹּ, _وتتل
  { {0x645c00b6,0x7af60031,0x1867004c,0xa067004c}},	//   ggri, elyt, _даљи_, _даља_
  { {0x6d400065,0xaca30020,0x92a70001,0xe1f90010}},	//   ámar, _xuốn, ојал, _šų_
  { {0x6d48003e,0x73040024,0x645c288f,0xf1bf0064}},	//   ądar, дчуж, agri, žšej_
  { {0xa2c10037,0xb9550014,0xce380009,0x6909001b}},	// [7150] रोग्, яващ, _ואחת_, _ožet
  { {0xddc9000d,0xb5fb0028,0xad3a0024,0x62010060}},	//   _aceş, tgáf, _свiт, _ızlı
  { {0xa3c90044,0x2fc70020,0x26cf0149,0x224000b6}},	//   _लें_, àng_, tigo_, baik_
  { {0x6f1c032b,0x8f9b000b,0xb7db0009,0xde590024}},	//   _durc, ייבי, סקאי, саді_
  { {0xaa9a0009,0xba9a0009,0x5a9a0009,0x429a0009}},	//   _הברכ, _הסרי, _השרא, _הסרב
  { {0xf4840001,0xbd18002d,0xcd7c000b,0xc058002d}},	//   дућн, іції_, שְׁכ, _міс_
  { {0x5c38000b,0xeab10003,0x7ae4009b,0x8fa50012}},	//   חרון_, فعة_, čitn, _عمره
  { {0x33dc000b,0x2d8d2890,0xc2450138,0xd36e0012}},	//   יחוד, _tree_, чник, اهي_
  { {0xddc4012e,0xdced0010,0x84670014,0x3a3f016d}},	//   _obiš, _apač, _мъже, raup_
  { {0xa9220028,0x25bd003a,0x6d5900b6,0xa9fa0009}},	//   _óþek, ızlı_, muwa, מִית
  { {0xc5e90093,0xf7710003,0x3ea9002a,0x82150012}},	//   _עד_, راد_, _boat_, _فواص
  { {0x23fa000b,0xabfa000b,0xc4c90009,0x3ea90132}},	//   _הפעמ, _ההער, _גג_, _coat_
  { {0xeab00003,0x645c2540,0x6d440073,0x721a0009}},	//   _جعل_, tgri, šiav, _הונח
  { {0xa50a0345,0xdc13003a,0x270d0066,0xc2120009}},	//   сега_, _aşım, _měny_, _נהג_
  { {0x883a000b,0x232a002d,0x9cd6000b,0xf7490003}},	//   _התצו, соби_, לושה_, _البي_
  { {0xaa7b0065,0xdbd7015e,0x3ea917e1,0xfaa30365}},	//   _skýr, määr, _goat_, насо
  { {0x3e5b0093,0xddcf007d,0x865b000b,0xae5b0009}},	// [7160] _הדפס, recţ, _הדפי, _הכפר
  { {0xb4ca0037,0x6f1c0c63,0xe3660048,0x6d462891}},	//   _लगे_, _purc, _екои, mska
  { {0x7c3e0039,0xec37000b,0x27210028,0x63a50032}},	//   _iepr, _מאיר_, _jón_, ähnl
  { {0xcb9b000b,0xeab20003,0x27212892,0x639b0009}},	//   _הסטט, _أعد_, _món_, _הסטנ
  { {0x7c3e00b6,0x6d46005b,0x26890012,0x6d59020d}},	//   _kepr, nska, تخلي_, guwa
  { {0xf7460098,0xe3b20012,0xdbd7079b,0x24852893}},	//   _него, فرع_, käär, _calm_
  { {0x2ca51b3c,0x62862894,0x6d590034,0xe4570009}},	//   öldi_, _kako, auwa, ליסט_
  { {0xb7db0093,0x62660003,0x5fdb0009,0xda660012}},	//   _הקלי, سابق, _החלק, سابي
  { {0xdee3002d,0x69c42895,0x4c160012,0xaca30081}},	//   _чоти, nzie, _فباس, _cuồn
  { {0x55bb000b,0xc0570024,0x62862896,0xed5f0073}},	//   _הממו, пію_, _lako, ėžta_
  { {0xf0930009,0xdc8b0009,0x831a0012,0x6d462897}},	//   גנת_, _לְאָ, _اقصر_, eska
  { {0x443e01e4,0xa3cd0037,0x6286238e,0x57fb0009}},	//   _het_, _शेष_, _nako, מליו
  { {0x6287001e,0xbcfb2898,0x6f030025,0xe8df0081}},	//   ējot, stém, ïnci, guồn_
  { {0x69c40871,0xe5040012,0xd1970009,0xe5710009}},	//   dzie, ّبِي, _מכדי_, כַל_
  { {0x443e01e4,0xe1ff000e,0xb4bd0037,0x3f82001e}},	//   _met_, _szó_, _आती_, ākus_
  { {0x7cf20065,0x3fdb000b,0xcff70009,0x5fdb0009}},	//   færs, _לקוב, _מצוה_, _לחוק
  { {0xa3cd0011,0xb115004c,0xaca30081,0x6d4614d8}},	// [7170] _शेर_, дмаш, _xuồn, cska
  { {0x55bc0093,0x04590003,0x7c3e01e0,0x443e2899}},	//   _למחו, _بلدة_, _gepr, _net_
  { {0x69c4289a,0x5f790012,0x8c2800af,0x442b0972}},	//   azie, تماس_, _מֵרֵ, _ęc_
  { {0xae010037,0x6ee70003,0x7c280070,0xff500003}},	//   _ईरान_, أسئل, _afdr, اخل_
  { {0x443e289b,0x2c6f0060,0xef200034,0xdce2068c}},	//   _bet_, yıdı_, ężar_, atoč
  { {0x443e289c,0x319a000b,0xe5780024,0xeb99025c}},	//   _cet_, _ובשנ, язі_, жик_
  { {0x6d460039,0x6d59289d,0xdca200de,0x93590024}},	//   zska, suwa, тащи, ірку_
  { {0x6d46003e,0x41b5002d,0xfbd00003,0xdbd700ff}},	//   yska, дсот, دته_, väär
  { {0x272103eb,0xcda9000a,0x443e289e,0x38550014}},	//   _són_, _بهذه_, _fet_, мънс
  { {0x443e289f,0x764d003a,0xfd130012,0x917a0081}},	//   _get_, _aday, _أجر_, _hập_
  { {0xf8b2000b,0x6d440010,0xabb50012,0xbcfb0031}},	//   דשי_, šiat, _تماث, aték
  { {0x443e06e7,0x644328a0,0x62870035,0x64410097}},	//   _zet_, lani, ējos, ðlin
  { {0x443e0036,0xe8ee029b,0x62990070,0x35fa0012}},	//   _yet_, _ал_, _inwo, تردد_
  { {0x6f040274,0x917a0020,0xfd5f001a,0x443e001a}},	//   _whic, _lập_, _huyệ, út_
  { {0x6f041791,0x6d4628a1,0x5ea60012,0xaec60198}},	//   _thic, sska, _يمتل, _обкл
  { {0xdb24000f,0xdb1d000f,0xfaf5002d,0x69c40347}},	//   éséh, ázás, ечую, tzie
  { {0x3f830051,0x7c3e0066,0xbc1a0024,0x21670dc2}},	// [7180] _asju_, _tepr, _міні_, мити_
  { {0xc059002d,0x6aab0058,0x7ae90027,0xfd5f001a}},	//   зії_, _logf, četa, _luyệ
  { {0x443e0058,0x4c9b007e,0x6d490d41,0xdc9b0009}},	//   _ret_, _ושיע, _avea, _וייל
  { {0x917a0020,0xc869000b,0x1a5a0003,0x443e28a2}},	//   _cập_, ין_, _بشدة_, _set_
  { {0x6e3b0028,0x443e28a3,0x627b0009,0xc27b0009}},	//   ðubi, _pet_, _ונכנ, _ורכי
  { {0x3e4e0020,0x84380003,0x2a600051,0x16030011}},	//   ột_, أكثر_, lgib_, रेटर_
  { {0x230a0012,0x6aab0040,0xd7f20012,0xeb97004c}},	//   يتبي_, _bogf, _شكر_, диј_
  { {0x3e86007a,0x443e051c,0xd3790024,0x2a60005e}},	//   _būtų_, _wet_, ячі_, ngib_
  { {0xfd5f0020,0x291800c6,0xbc660001,0x6f03000d}},	//   _duyệ, _kira_, _овак, înce
  { {0x299b0093,0xb4bd0037,0xbcfb28a4,0xe5770048}},	//   קסימ, _आते_, rték, _юзу_
  { {0x9057007e,0x08570093,0x5ed50015,0xd6d50015}},	//   וסיף_, ובים_, ежну, ежны
  { {0x2293000a,0x5694027f,0x72060012,0x9f650031}},	//   _للمس, вают, _قوام, étét_
  { {0x2d840013,0xfe37000b,0x90a60012,0x86370009}},	//   _jsme_, ורכי_, _يحتم, ורכב_
  { {0x26c2012e,0xbca50012,0x79fb0009,0x6f1c0031}},	//   ahko_, رمزي, _ולדח, írcs
  { {0x5f940014,0x36d507a1,0x905b0009,0xe6c70012}},	//   _чийт, _покр, _וכות, _يتبي
  { {0xe1880020,0x6ee70003,0x5f040001,0xdee70012}},	//   _kỳ_, _تستل, _изја, _تأتي
  { {0x349504b3,0x752d000e,0x98b900b3,0x75d50012}},	// [7190] _запр, _utaz, плат_, _سيدا
  { {0x4427003a,0xd91b0009,0xab2b0012,0x6d5d14ae}},	//   _ün_, קובל, _وسجل_, musa
  { {0x644304b4,0xdfd1000a,0x97240012,0x2ca50097}},	//   vani, ديا_, نفلو, öldu_
  { {0x64430656,0xf7700003,0xdd910003,0xf70a0081}},	//   wani, شام_, ُوا_, _bầy_
  { {0x41e7002d,0x644328a5,0xa5640012,0x6d5d28a6}},	//   _ціна, tani, ندون, nusa
  { {0x29181209,0x113a0009,0xab650048,0xd0060012}},	//   _gira_, _מתשל, евкл, _مل_
  { {0xa3c90044,0x917a001a,0x6d5d05cf,0x3eb90028}},	//   _लेख_, _tập_, husa, kkst_
  { {0x71590406,0x2918003a,0x6d5d28a7,0x43720012}},	//   прос_, _zira_, kusa, اهير
  { {0x99d50003,0xe9d900b3,0xfbd60011,0xfd390012}},	//   عتبا, яки_, _डेनम, _ركاب_
  { {0xa3c10044,0x80b90037,0xc1050003,0x6d5d057c}},	//   ्छा_, इसें, عودي, dusa
  { {0x04c80003,0x66d60010,0xfd5f001a,0x64411609}},	//   _تولي_, eška, _tuyệ, _ieli
  { {0x39490708,0xee37002d,0xcf56000b,0x644128a8}},	//   ksas_, нню_, עברת_, _heli
  { {0x3ead00bd,0x644128a9,0x6d5d040d,0x865a0009}},	//   _moet_, _keli, gusa, הדרי
  { {0xb9560009,0x31560009,0x38b60040,0x3eb90097}},	//   _ניצח_, _ניצן_, _værk_, akst_
  { {0xd5b80039,0x644100c6,0xc052000b,0xa8560009}},	//   ņā_, _meli, _עזה_, _טיסה_
  { {0xef19003e,0xfd4a0014,0x0566002d,0xaea90012}},	//   _niż_, _език_, _звин, _يطيل_
  { {0xb8560001,0x30560001,0xbcfb000e,0x7afb0079}},	// [71a0] еђењ, еђет, ztéi, ilut
  { {0x7afb0065,0xdcfb0027,0x38b60097,0xe8f728aa}},	//   hlut, _oruđ, _kæri_, елу_
  { {0xc43b000b,0x3ebf0052,0x291806b6,0x4c3b0009}},	//   _מתיי, _blut_, _vira_, _מתיב
  { {0x92b60003,0x11d6002d,0x3ea6001e,0xd3570009}},	//   _أحدا, _зігр, ujot_, _איטי_
  { {0x3ead0070,0x644128ab,0x721b0009,0x291828ac}},	//   _doet_, _beli, _מוכח, _tira_
  { {0xa7fc0060,0xb8f60012,0xdca30f28,0x644128ad}},	//   ngıc, _أكسب, лачи, _celi
  { {0x7afb0068,0xd467004c,0x6d5d0032,0xaba70012}},	//   flut, хије_, zusa, فهوم_
  { {0x64410005,0x6d5d002c,0xbf160012,0xdbd2005e}},	//   _eeli, yusa, _أورب, müür
  { {0x63b50002,0xc8661e8e,0xbcfb0025,0x2cac28ae}},	//   zyzn, нтни, luée, _todd_
  { {0xd6fb0044,0x29180163,0x6d5d0051,0x99800010}},	//   ृष्ठ_, öra_, vusa, lbių_
  { {0x64410028,0xde59002d,0x290c0060,0x0f230842}},	//   ðlim, мані_, rmda_, льям
  { {0x8289007c,0x7d1a002c,0x64410604,0xfa360012}},	//   _осіб_, _hits, _zeli, _أراد
  { {0x7d1a0f32,0xa2c40011,0x3d1e0011,0x7e7d28af}},	//   _kits, रसन्, _यूआइ_, resp
  { {0x6d5d1bc2,0x66040034,0x38b60097,0xf9930009}},	//   rusa, _dzik, _færi_, _תרס_
  { {0x58f7000b,0x78b5000e,0xd0f70009,0x27f30042}},	//   _רצון_, özve, _רמות_, čané_
  { {0x539b000b,0x7d1a0051,0x57fb0009,0xb7fb0009}},	//   הילו, _lits, _מלוו, _מפות
  { {0x39490010,0x645a0d85,0xdddd0035,0x224217b8}},	// [71b0] usas_, ótic, iesū, _dekk_
  { {0xd8790003,0x3ebf153b,0x8fe70048,0x4c950148}},	//   ظمات_, _slut_, нцед, _риос
  { {0xa857000b,0x6447001e,0xd8740003,0x394928b0}},	//   תיבה_, maji, طالب, ssas_
  { {0xc5d5007c,0x22420028,0xa75b0009,0x7e6200b0}},	//   кіль, _gekk_, לדבר, ggop
  { {0x3ead0227,0x3135004c,0x644128b1,0xe569104f}},	//   _voet_, _јегр, _peli, филд_
  { {0x6447001e,0x71d60009,0x04c90012,0xbcfb0025}},	//   naji, _יורד_, بوتي_, buée
  { {0x644123f7,0xd4980009,0x747c0009,0xdc8c00af}},	//   _veli, תכות_, פנהג, לְהָ
  { {0x644700b6,0x7afb00e6,0x539c0009,0x1dd20011}},	//   haji, ulut, ליוו, _देवत
  { {0xa1560001,0x644728b2,0x7d740012,0x8d740012}},	//   вању_, kaji, _مالط, _مالا
  { {0xe0d60015,0x409502ad,0x7afb0b0e,0x5d170012}},	//   квы_, трит, slut, _أبرز
  { {0x60090015,0x6d4d004a,0xf092000b,0x66040031}},	//   ьном_, _avaa, בני_, _szik
  { {0x8c3c003a,0x38b60028,0x6d5908de,0xcce90009}},	//   _doğu, _væri_, orwa, _וכ_
  { {0xfe0c0044,0xb8950003,0x41d00011,0x40950012}},	//   सेंस_, _للإع, _सेंस, _للإر
  { {0x7646007a,0x3956000b,0xc156000b,0xa1560009}},	//   saky, _ישנם_, _ישנו_, _יבנה_
  { {0x316d0108,0xccf2000b,0x99800010,0xfaf60024}},	//   ltez_, יכך_, ybių_, вчаю
  { {0x7db60955,0x65d60012,0x3f8e0097,0x6aa91ff3}},	//   _асоц, _ليعط, æfum_, njef
  { {0x316d02da,0xcb090009,0xceb30009,0x224200b0}},	// [71c0] ntez_, ַל_, _כיה_, _vekk_
  { {0x8c3c003a,0x672300b6,0x4b260001,0xf55b000b}},	//   _yoğu, _kunj, _имов, _קדימ
  { {0x7d1a0065,0x2a75000e,0xe4570009,0x54570009}},	//   _rits, íííí, _בייט_, _בסין_
  { {0x44440274,0x628b28b3,0x672308fd,0x66d60c71}},	//   _he_, _nago, _munj, iško
  { {0x444428b4,0x9182001a,0x7d1a14d5,0x6f1b016d}},	//   _ke_, iệt_, _pits, _diuc
  { {0xfd0f0012,0x66d60035,0x444428b5,0x75240a82}},	//   يجو_, kško, _je_, _muiz
  { {0x628b0101,0xbcfb0061,0x8cb30037,0xbc890012}},	//   _bago, quée, _अवरो, عضهم_
  { {0xbcfb000f,0x444428b6,0xd2500012,0xe7eb0011}},	//   ltét, _le_, حنة_, _जुटा_
  { {0x66d6007a,0xf2d30093,0xc05a002d,0x20c4005e}},	//   eško, יעה_, мін_, _töid_
  { {0x7d1a00bd,0x6c4a0003,0x25c40060,0x937a0012}},	//   _uits, _آلاف_, ırlı_, _يصار_
  { {0xb0b7000b,0x96b60011,0x0f980012,0x6e470248}},	//   דפיס_, _अकाउ, رَحة_, _örbä
  { {0x644700b6,0xda650012,0x89a60012,0xe3160012}},	//   waji, _ماهي, _لإتم, _شباب
  { {0x11540014,0x444428b7,0x64470f58,0xb4d70003}},	//   _склю, _be_, taji, نغست
  { {0x628b012e,0x75240070,0x444428b8,0x628028b9}},	//   _zago, _duiz, _ce_, lemo
  { {0xf3f80009,0xa3cd0011,0xf5480081,0xd91b0009}},	//   גִּל, _शेख_, hụ_, _קוול
  { {0x444428ba,0x7f5c01a0,0x60170009,0x628028bb}},	//   _ee_, àrqu, _בחוף_, nemo
  { {0x8cb30037,0xe2f8002d,0xbcfb01e3,0x26d928bc}},	// [71d0] _अवलो, теті_, ruéb, miso_
  { {0x444428bd,0x63b800b0,0x659a0009,0xbcfb0031}},	//   _ge_, kyvn, _ניתק, gtét
  { {0x62800033,0x6ee8003a,0x28680048,0xa5c70097}},	//   kemo, lıba, ърто_, _fróð
  { {0x6d590002,0x26d90010,0x629d002a,0x96290012}},	//   trwa, niso_, _unso, ركتك_
  { {0xee38002d,0x644528be,0x22490070,0x6d4b0052}},	//   тні_, _kehi, maak_, usga
  { {0x628b0101,0xe7330003,0x395f004a,0x55bc000b}},	//   _sago, _نصر_, vuus_, ומדו
  { {0xbcfb000f,0x91820020,0xdce0001e,0xfc640014}},	//   ltés, yệt_, _apmē, ръчн
  { {0xf414000b,0x395f004a,0x316d0061,0xc2070011}},	//   ספק_, tuus_, ttez_, _शराब_
  { {0xbcfb0272,0x316d0061,0xdb15000e,0x99dd0042}},	//   ntés, utez_, gyzé, raňo
  { {0x6aa6006f,0x61fd014a,0x316d042f,0xe739046d}},	//   ökfr, _mysl, rtez_, нео_
  { {0x395f0006,0x628b10ff,0x628001c5,0x316d042f}},	//   suus_, _tago, bemo, stez_
  { {0xfe720003,0x316d0061,0x628001c5,0xed5a28bf}},	//   حدد_, ptez_, cemo, ном_
  { {0x444401b3,0xbcfb000e,0x644502c3,0x752428c0}},	//   _pe_, jtés, _behi, _quiz
  { {0x672300b6,0xa0690014,0x97c50012,0x6445004b}},	//   _tunj, _чака_, _متعم, _cehi
  { {0xb5fb0272,0x7ae4009b,0x444428c1,0x5ea60003}},	//   lgál, čitv, _ve_, _ممثل
  { {0x9f9b0051,0x16660001,0xc332000b,0x38b60993}},	//   _määr_, _свим, מול_, _lært_
  { {0xbcfb000e,0x444428c2,0x1a0602e3,0xfe370009}},	// [71e0] ttét, _te_, упам, _גרפי_
  { {0x7e6902d1,0x291c006f,0x64450052,0x3ea00028}},	//   _acep, öva_, _gehi, _hnit_
  { {0xe8d60009,0x66c60031,0xbcfb0031,0xa78c00af}},	//   נוער_, _iókb, rtét, ֽאדֹ
  { {0xbbb20044,0x394d28c3,0x71260012,0xaafa0024}},	//   ीनीक, kses_, _مرسل, _їхнє_
  { {0xdcb1001a,0x7ae428c4,0x4d730012,0x628028c5}},	//   _bỏ_, mnit, مطور, vemo
  { {0x0b8a0014,0x260a0037,0x7ae42478,0xbcfb057d}},	//   есии_, ़ेगी_, lnit, ltér
  { {0xbcfb0028,0xb5fb000e,0x27f7022d,0xd00701ef}},	//   bréf, egál, čené_, _бере_
  { {0x7ae407f6,0x8c3c003a,0xd7f8000d,0x7d1e28c6}},	//   nnit, _coğr, ugăm_, _lips
  { {0x8c3c00a2,0xc27b000b,0x26d900c1,0x38b60028}},	//   _doğr, גרפי, viso_, _fært_
  { {0x7ae425d6,0x3d000037,0xe5060012,0x22490227}},	//   hnit, ोगों_, _إبري, zaak_
  { {0x64450101,0x394d28c7,0x201800e6,0x6562008e}},	//   _rehi, ases_, äri_, luoh
  { {0x644500c6,0x7ae9013a,0x9e150024,0xe80a0011}},	//   _sehi, četk, идні, हेगा_
  { {0x25bf000f,0x7ae40d09,0x76b80365,0x91b70012}},	//   ául_, dnit, уляр_, _مطور_
  { {0xd3660003,0x644a00b6,0x40342115,0x5f941728}},	//   يه_, nafi, _текс, _викт
  { {0xd6d1000a,0x60da00b6,0x2bbb0012,0xdb5804ba}},	//   _وقت_, mitm, راسة_, лют_
  { {0xa6ab0003,0xdb24000e,0xbcfb000e,0xc2c50003}},	//   _سابق_, árás, gtér, جيري
  { {0x200b003e,0xdcb10020,0x19580015,0x64450051}},	// [71f0] ęcie_, ử_, латы_, _tehi
  { {0xbcfb28c8,0x61fd0042,0xd1b80012,0x99d40012}},	//   rtés, _vysl, دافا_, حتفا
  { {0x64570aa1,0x800700de,0x3e350012,0x61fd0034}},	//   óxim, учае, لفار, _wysl
  { {0x8b3a000b,0x66f70037,0xaa95002d,0xbb3a000b}},	//   _שתרצ, ीतिक_, _тимч, _שערי
  { {0xa2ba0037,0x5eec0009,0xd469004c,0xada50223}},	//   _एकत्, עַבְ, виле_, ралл
  { {0x6b550048,0xd7fb07a7,0x394d005e,0x6d4f28c9}},	//   атих, _зуб_, vses_, isca
  { {0xeab10003,0x38b601fb,0x749c0009,0xa8a80009}},	//   قعة_, _vært_, תיופ, _עֹשִ
  { {0x394d28ca,0x8e480012,0xc3340009,0xa535003c}},	//   tses_, _ملفك_, זוק_, _внач
  { {0x52a60015,0xf27c000b,0x3219004a,0x6d4f0002}},	//   рвым_, תרחש, äsy_, jsca
  { {0xb8f20003,0x764b002c,0x718c0009,0x394d28cb}},	//   يكيب, lagy, תְהַ, rses_
  { {0xd7ee0012,0xb8ed0011,0xdc9a0009,0xb5fb0031}},	//   ِكٍ_, _रत_, _שיעל, sgál
  { {0xd491001a,0x6f0d190a,0x49d9003c,0x61d9003c}},	//   ồn_, _chac, _идею_, _имея_
  { {0xcb120093,0x10a50048,0xa9690048,0x8d630048}},	//   _ולא_, _вилн, _рила_, овяе
  { {0x8c4300fa,0x764b0b7c,0x5cf60198,0x1d0a003c}},	//   жере, hagy, ряму, теги_
  { {0xd0110003,0x98f40003,0x7ae4142f,0xbcfb0bdd}},	//   _بلغ_, _اثنا, tnit, ttér
  { {0xd1320003,0xcb670001,0x644a0031,0x6aad0097}},	//   قمر_, јате_, zafi, gjaf
  { {0x2d8c001e,0x3cfa0003,0x225d0002,0x41270048}},	// [7200] ādes_, _لعدد_, ówka_, иото_
  { {0xe3ba007c,0x6cd30012,0xbebd0073,0xbcfb28cc}},	//   _або_, _وقيا, _liūd, stér
  { {0x5c5b0093,0x628f00c1,0x7e26010c,0xb4c20011}},	//   _בדיק, _faco, адеж, ंसी_
  { {0x539b0093,0x6d440002,0xad660003,0x29010018}},	//   _סיכו, _kwia, لاته, alha_
  { {0x66090002,0xdd920012,0xc8780060,0xa2a40011}},	//   _czek, توش_, liğe_, कास्
  { {0xcb540012,0xd84301e9,0x7bce0034,0x61430681}},	//   منتظ, ručí_, ozbu, _фера
  { {0x6609000f,0x69dd0029,0x7b050028,0x14180012}},	//   _ezek, úsen, róun, ديثة_
  { {0x02b6000b,0x8f37000b,0x5a340048,0x6562008e}},	//   יהֶם_, _כאלו_, щнит, puoh
  { {0x60f80098,0x8d2a002d,0x63bc09d8,0x6e930012}},	//   лния_, _розв_, hyrn, _بلقا
  { {0xc173000b,0x20070002,0x21770009,0x7c650012}},	//   קחת_, żnie_, סתיר_, _هامل
  { {0x627e0002,0xbb860012,0x73360012,0x6d4f0132}},	//   _złoż, _خلاي, _ضرائ, wsca
  { {0x7bdb0093,0xa3e30011,0x644828cd,0xfaa328ce}},	//   _בקבו, नपर_, _hedi, _махо
  { {0x99340003,0x628f042f,0x6448029a,0xdcf70012}},	//   _افتت, _raco, _kedi, لأسب
  { {0x91bb000b,0x19bb000b,0x6448238e,0x399b0009}},	//   _במדי, _במדב, _jedi, _שיגד
  { {0x628f0017,0xaa590447,0xbae50003,0xcb350048}},	//   _paco, ливу_, مكسي, себъ
  { {0x1b190047,0xaf330003,0x7ed40003,0x6f02000d}},	//   ужбы_, _بروت, _وزيا, jloc
  { {0x5187002d,0x6d440002,0x7af40024,0xc1050012}},	// [7210] шува, _gwia, ізує, موري
  { {0xd70f0037,0x66090002,0xa7fc003a,0x4ddc0009}},	//   िष्ठ_, _rzek, ygıl, _שחזו
  { {0x3395000a,0xab950003,0xff530012,0x6d440034}},	//   _الجز, _الجغ, تخذ_, _zwia
  { {0x95550003,0x539a000b,0x2b5e0066,0x2bf60009}},	//   مختا, _עירו, átce_, _למתן_
  { {0x8e98000b,0x64480347,0x05870063,0x6b9a0032}},	//   ידאו_, _bedi, руем, _artg
  { {0xdfc628cf,0x8c420048,0x04420e5f,0x2a69005e}},	//   _في_, пеше, пешн, lgab_
  { {0xbcfb0108,0xde670014,0xd47c0009,0xc6a70048}},	//   crée, _възп, דאול, _краи
  { {0x3a980015,0xa7fc003a,0xf7720009,0x6448020d}},	//   атью_, rgıl, _מקל_, _eedi
  { {0x627e0034,0xe8f90223,0x000000c4,0x000000c4}},	//   _ułoż, лли_,   ,
  { {0xdb030034,0x66d60159,0x77390048,0x26dd0034}},	//   tynó, mški, лямс_, liwo_
  { {0xc878003a,0x30fa0037,0xa0880009,0x53340024}},	//   _öğe_, ्ततः_, בְרִ, _дехт
  { {0x5b150001,0x66c60028,0xd491001a,0x877a0009}},	//   _умет, _bóka, _hà_, נארי
  { {0x59c40003,0xa2a40037,0xf2d2000b,0x66080002}},	//   _ويمك, कार्, _צעד_, ędko
  { {0x66d60010,0x7db5002d,0xa2d30037,0x00c80024}},	//   iški, ісяц, बोर्, _клік_
  { {0xd4910020,0x78a30033,0xb8d40003,0x7521001e}},	//   _mà_, _innv, _بتنش, _milz
  { {0xd4910020,0xc878003a,0x7bce28d0,0x6e2409df}},	//   _là_, riğe_, rzbu, _ugib
  { {0x95560003,0xe2970083,0xe8ea004c,0xa5bb0420}},	// [7220] _اخبا, щат_, гмад_, scór
  { {0xb4660046,0x6c860003,0xbcfb0061,0xb4db0054}},	//   _укол, _الدم, trée, ssàr
  { {0x644e28d1,0xf7720012,0x78b52629,0xee3a11d9}},	//   mabi, ثاء_, _dozv, гне_
  { {0x644e28d2,0xf413000b,0x644828d3,0x6efd122d}},	//   labi, _מפת_, _sedi, lébr
  { {0x1dd20037,0x644828d4,0x673b001b,0xa5f8004c}},	//   _देखत, _pedi, _čuje, јелу_
  { {0x6fca0044,0xd577000b,0x644e28d5,0xdb090029}},	//   ानमं, מתנה_, nabi, ľnýc
  { {0x91830020,0x644825f2,0xdb0901bd,0xad1b0009}},	//   _tệp_, _vedi, žnýc, נוצר
  { {0x539b0009,0xeb97004c,0x3202008e,0x926a052c}},	//   ריקו, сић_, _kyky_, урка_
  { {0xb6bb000b,0xa3df0037,0xd91a025c,0x644e28d6}},	//   _עצמי, _देन_, льо_, kabi
  { {0x89330012,0xf8af0012,0xf20d0011,0xa2d80011}},	//   أعيا, ّةَ_, ाइज़_, नोत्
  { {0x2d80007a,0x395f00b6,0xd491001a,0xda7a0014}},	//   _apie_, arus_, ồm_, _бял_
  { {0xeeab00b3,0x2002001e,0x9d550012,0x6aa20132}},	//   уток_, āki_, ينجت, _unof
  { {0x200b003e,0x8afb0009,0x644e0097,0x7af30031}},	//   ęcia_, _גלאז, fabi, űjtö
  { {0x19e70009,0x1fa60ba0,0xe4e70024,0x6efd10b3}},	//   _ל֥וֹ_, _григ, сімн, gébr
  { {0xf8db000b,0x2ac70001,0x78b50042,0x200a005e}},	//   _תחומ, бљав, _rozv, übid_
  { {0xada60029,0x7e6d00b6,0xcb370009,0x8fe50012}},	//   _spúš, _ucap, מאלי_, _بأهم
  { {0x78270003,0xdce20029,0x78b528d7,0x1e580009}},	// [7230] معال, dvoľ, _pozv, _השחר_
  { {0x764f0002,0x9055002d,0x99d40012,0x9c470472}},	//   lacy, івец, ستقا, _ухил
  { {0x56950015,0xddcd0002,0xcc760009,0x301b0012}},	//   жает, _udał, _ועתה_, اتذة_
  { {0x8f9b000b,0x57fb000b,0xa2b30037,0x395f0b02}},	//   טיבי, נלאו, _इकट्, yrus_
  { {0x9cf5002d,0x98c5003a,0x94250686,0x752112a3}},	//   озді, ştır_, омле, _pilz
  { {0x2d990051,0xd01b0014,0x66d6003d,0x84670048}},	//   ivse_, _бфб_, rški, съде
  { {0xd491008a,0x764f0002,0x44250052,0xb3850024}},	//   _và_, kacy, _vgl_, ілил
  { {0x395f134f,0x92b50012,0xf9890012,0x644e28d8}},	//   trus_, تحتا, لنبي_, zabi
  { {0x644e00a2,0x3f9c0051,0xdab60012,0x5ac60024}},	//   yabi, _arvu_, تهيت_, ільм_
  { {0x212b0036,0xe0d90014,0x2dd80012,0xf7710012}},	//   _much_, рво_, _طبقة_, واج_
  { {0x644e009b,0x06ea0015,0xa856000b,0x16aa0294}},	//   vabi, имок_, חיתה_, авни_
  { {0x98aa0039,0x57fa000b,0x224b0a5f,0x02440012}},	//   āmām_, ילתו, _neck_, _فَمَ
  { {0x26c2004a,0xa50a022a,0x1d0a0048,0x7afb28d9}},	//   rkko_, иема_, иеми_, mout
  { {0x2eb60037,0x7ae928da,0x7afb1a26,0xf7450bda}},	//   _अक्त, lnet, lout, _деко
  { {0x212b032b,0x644e28db,0x6efd0025,0xa5bb0c8b}},	//   _auch_, rabi, rébr, scóp
  { {0x212b0052,0x7ae928dc,0x3160052e,0x1be70024}},	//   _buch_, nnet, triz_, ідти_
  { {0x644e28dd,0xfee90012,0x7ae918c9,0x39520073}},	// [7240] pabi, _دعوى_, inet, usys_
  { {0xd5e00011,0xb8660012,0xfd120012,0x34b30012}},	//   _पेयज, تارو, _تجب_, _يميز
  { {0xd7ff000d,0x212b0052,0x29051b3f,0x7f860012}},	//   _ţări_, _euch_, illa_, تلان
  { {0xbcfb0061,0x7afb0061,0x98af001e,0x2eb90037}},	//   préc, jout, īgā_, _आवृत
  { {0xddc80002,0xcd330003,0xddcd0002,0x3f860029}},	//   _żołn, وروب, _gdań, ňou_
  { {0x3123002d,0x764f0002,0xab940024,0x20070034}},	//   _одяг, zacy, зикі, żnia_
  { {0xd4670046,0x7ae90052,0x7afb0227,0xbc670012}},	//   ције_, fnet, fout, زمين_
  { {0xfbe80020,0x8c1b000b,0x290528de,0x7f3b0009}},	//   _đề_, סוקי, ella_, _כעלו
  { {0xcb130093,0x764f0070,0x68fa000d,0xb97a0009}},	//   ולה_, vacy, totd, ׁנֵי
  { {0x1d0a0098,0x3f9c0027,0x397b000b,0x764f0034}},	//   _тези_, _prvu_, סטינ, wacy
  { {0x660d000f,0x66e40031,0x8ca70037,0x7ae90480}},	//   _szak, zőke, चारो, bnet
  { {0x57fb0009,0xd6db0d7c,0x290528df,0x7afb0ae5}},	//   שלטו, рто_, alla_, cout
  { {0xf6530093,0x764f0002,0x65620032,0x656f0602}},	//   וצר_, racy, nroh, _ächt
  { {0x212b0002,0x6fb60003,0x20d30012,0x50d30012}},	//   _ruch_, _ومشا, _يتوج, _يزور
  { {0x57f30046,0x212b0742,0x4394096e,0xab940024}},	//   _општ, _such_, марс, мирі
  { {0x690b03eb,0x66e4000e,0x25a6009b,0x83f8003c}},	//   güen, tőke, _šole_, цесс_
  { {0x660d003a,0xd52d001a,0x645a28e0,0x69c028e1}},	// [7250] _uzak, _dựn, _odti, nyme
  { {0xcf9b1154,0x8fc70003,0x7aed0029,0x656228e2}},	//   ије_, يزان, čati, droh
  { {0x629c001e,0x80bc0011,0x602d0031,0xbcfb0025}},	//   ēroj, _एवरे, _hőmé, créa
  { {0x23fa000b,0x0f7b000b,0xabfa000b,0xc7b3000b}},	//   _להתא, שראל, _להתר, ובע_
  { {0x29051359,0xaaa90011,0x656228e3,0xed440024}},	//   ylla_, कासक, groh, дніп
  { {0x6fca0037,0x91ba000b,0xccfb0001,0x6c350003}},	//   ानां, _המשי, шће_, أفغا
  { {0xc6e7002d,0xe7300003,0x7afb039e,0xd0fa0011}},	//   _діап, _لصق_, tout, ्तरण_
  { {0xd2a90047,0x2d84003a,0x66e4000e,0x52a90001}},	//   ские_, çmek_, zőkb, свим_
  { {0xa3db0011,0x290501a0,0x2a620031,0xb9920012}},	//   _ढेर_, tlla_, ókba_, فليب
  { {0xa0690001,0x18690001,0x88c905c6,0x98bd0011}},	//   љана_, љани_, слов_, ोसिए
  { {0xb8e3015f,0x07a5002d,0xd62a0015,0x6443230d}},	//   _एक_, чанн, йоне_, mbni
  { {0xe298007c,0x6a94002d,0x6b7a0009,0xa5c20097}},	//   _має_, _оріє, _לרענ, _þókn
  { {0xe0ce007c,0xacea0003,0x28f90024,0xd2d40012}},	//   _зв_, مرسل_, _ледь_, _تغلب
  { {0x913a000b,0x40870001,0x213f00b6,0xc19a0009}},	//   _העסק, _фудб, mpuh_, _לשני
  { {0x03a30015,0x7cf6000d,0x68e128e4,0x9bc90009}},	//   ниро, târz, mild, זֶּ֖
  { {0x2a6d0051,0xc3230863,0x8b230c1e,0x61e90064}},	//   ngeb_, емск, едсе, _žela
  { {0xc9660014,0x25db0011,0xa2cd0011,0x05db0011}},	// [7260] явай, _खेली_, _सतर्, _मेलब
  { {0xb4660015,0x759b0009,0x68e128e5,0x764228e6}},	//   _экол, _פסיג, nild, wboy
  { {0x94bb0009,0xdee60024,0x1cbb0009,0xdfcf0012}},	//   _המית, пожи, _המיע, هيك_
  { {0xd6d9002d,0x690b08bf,0xc8690009,0x25a00159}},	//   оті_, qüen, טן_, _kril_
  { {0x86230015,0x4c9400de,0x68e128e7,0xba9b0009}},	//   ньше, дилс, kild, _הסכי
  { {0x7afb0159,0x65620032,0x89eb0009,0x394028e8}},	//   čute, rroh, _הַלֵ, mpis_
  { {0x7982003e,0x68e1003a,0x6fb60012,0xe6460024}},	//   _spow, dild, _عمرا, _невп
  { {0x994c0026,0xd379002d,0x3f980028,0x66c60097}},	//   _môže_, ючі_, ærum_, _bókm
  { {0xeaaf0012,0x3914003c,0x35ca004c,0x64430248}},	//   اعى_, ммир, _угао_, bbni
  { {0x69c00002,0x68e10028,0x2d57000b,0x7d570009}},	//   ryme, gild, _משמש_, _מימד_
  { {0xdc3b0093,0x7c3b0009,0xc43b0009,0x67d40024}},	//   _העבר, _התבס, _התבי, фону
  { {0xcb8b0009,0xd2500012,0x69060097,0x6b9c001b}},	//   _לְדֹ, _شنت_, iðei, dvrg
  { {0x68fe00bd,0x79820002,0xa0a600ac,0x18a605f7}},	//   kopd, _upow, _надд, _надм
  { {0x2ceb0015,0x99dd0066,0xb1130024,0x721b0009}},	//   сьмо_, raňt, _зміш, _הודח
  { {0x187b000b,0x987b0009,0x307b000b,0xa87b000b}},	//   _הטוב, _האוט, _האונ, _האור
  { {0x59de0321,0xbcfb1f8d,0xa0070012,0x97c50012}},	//   _नेहर, ntéz, _عقيل_, _تتهم
  { {0xc2c4000a,0x6e290032,0xa6e30097,0xb5fb0031}},	// [7270] ريكي, _rgeb, öðus, ggát
  { {0x66f20035,0xdb030025,0x798d28e9,0x7e7d2537}},	//   māka, lynô, rwaw, lfsp
  { {0x2fc70020,0x66f2001e,0xd91b0009,0x28380012}},	//   áng_, lāka, מומל, سألة_
  { {0xa634007c,0x2bd60037,0xde580024,0xd3560009}},	//   енці, _डेटा, заці_, _קירי_
  { {0xa4d5002d,0x7e870010,0xfe700003,0xacf9002d}},	//   моді, _įspė, ادم_, онду_
  { {0x2fc70020,0xddc9000d,0x64430032,0xd6180012}},	//   ơng_, _aceţ, ubni, ستنا_
  { {0x20c90028,0xfc460066,0x644328ea,0x5e450012}},	//   _búin_, _říci_, rbni, _يَسْ
  { {0xcf92000b,0x2d9f0bf8,0x23260063,0x7aed1966}},	//   _בטל_, _true_, мощи_, nnat
  { {0xf487035b,0x61ed0027,0x89a90024,0xac270de4}},	//   _нужн, _žalb, іков_, _ефек
  { {0x629d0026,0x9f880028,0xdbcc0028,0x57e90015}},	//   ôsob, _kóða_, kóða, ждом_
  { {0x68e100a2,0xdbcc0028,0xc052000b,0x3cf10037}},	//   rild, jóða, כזי_, ँचने_
  { {0x39400028,0xabfa0009,0x33fa0009,0x1bfa0009}},	//   ypis_, _והער, _והענ, _ולעב
  { {0x68e10113,0x82d6000b,0x66f2001e,0x7afc0031}},	//   pild, _קונג_, gāka, _írta
  { {0xa25b0081,0x7e7d0b82,0x7aed0d4f,0x893400ae}},	//   _xlôv, afsp, enat, _أعنا
  { {0x46f60345,0x29160012,0x141a0012,0x883a0009}},	//   _очит, _تقود_, زيرة_, _ותצו
  { {0x66f2001e,0x39400027,0xda660003,0x06f60012}},	//   bāka, tpis_, باسي, _تستج
  { {0x21270020,0x74f60003,0xf1de0037,0xa9260024}},	// [7280] _kinh_, _يأخذ, _नेशन, ддал
  { {0x39400010,0xa3df0011,0xa3bf0011,0xdcfb001b}},	//   rpis_, _देव_, ुना_, _osuđ
  { {0x21270020,0xdc8b000b,0x93c4001a,0x6d400028}},	//   _minh_, _וְכָ, _chẳ, ímaf
  { {0xb6c5002d,0x2733001a,0x2127001a,0x75d60003}},	//   нсій, _mãn_, _linh_, ويضا
  { {0xb5fb10b5,0xdc390060,0x7ae4079f,0x1be30011}},	//   lgár, _açıd, miit, _केबल_
  { {0x2127001a,0x2365009b,0x40950001,0x7ae428eb}},	//   _ninh_, šlje_, _прст, liit
  { {0x66f2001e,0x9f880028,0x656b0132,0x136a0024}},	//   zāka, _góða_, augh, ішки_
  { {0x2360009b,0x5fdb0009,0xb7db0009,0x8c1b0009}},	//   čij_, _וחלק, _וקלי, חוצי
  { {0xadba0003,0x2127001a,0x78bc019a,0x225d0002}},	//   _بهذا_, _binh_, _korv, ówki_
  { {0x7aed0416,0x55bb000b,0x3cf80037,0x66f20035}},	//   znat, _וממו, ंकों_, vāka
  { {0xa3ca0037,0xd0100003,0x442c0027,0x7ae40574}},	//   रैश_, طلح_, _igd_, kiit
  { {0x66f2001e,0xa1c6010c,0x19c60867,0x25a60159}},	//   tāka, _обед, _обем, _šola_
  { {0x7ae40005,0xceb3000b,0x3e040048,0x99d30012}},	//   diit, דיר_, вярв, _لتوا
  { {0x66f20039,0x26150011,0xa0c40012,0x61e909df}},	//   rāka, नेगी_, _سيعو, _želo
  { {0xa3df0302,0x66f20035,0xc0590024,0x6566016d}},	//   _देश_, sāka, _хіі_, arkh
  { {0x2bb60037,0x326401b6,0x75280034,0xdb180009}},	//   _अपना, ктув, _lidz, לֵּך
  { {0x2bff0044,0xa3df0044,0xb115035c,0xc115004c}},	// [7290] _शुरू_, _देर_, емаш, емај
  { {0x2ec70037,0x79a40014,0x67d5002d,0xbb950024}},	//   लस्त, ърсе, нозу, _заощ
  { {0x3cf80003,0x645528ec,0x66c60097,0xb9070011}},	//   _تعيد_, mazi, _bókh, _बग_
  { {0x2d4d0027,0x645528ed,0x99670014,0xa25b0025}},	//   ože_, lazi, _отгл, _clôt
  { {0xaa3a000b,0x0eb80003,0x78bc28ee,0x5e560012}},	//   _מתרח, بالغ_, _forv, رلوس_
  { {0x645501a2,0xd13e003e,0xa8a40001,0xeb990209}},	//   nazi, żące_, _ирск, зик_
  { {0x780d0037,0x0c360003,0x69cb0058,0x6d42004b}},	//   _हरेक_, ركية_, øgef, apoa
  { {0x21270020,0xa3c20037,0x2d4d0107,0xda650012}},	//   _sinh_, ्नत_, kže_, راعي
  { {0x6455080a,0xe8ca0011,0x7bce0032,0x15f30011}},	//   kazi, िसूच, _übun, _आखिर_
  { {0x6f0401ab,0xb88101bd,0xe5700012,0xf9920009}},	//   _skic, _číse, _خطف_, נרי_
  { {0xf8b2000b,0x2127001a,0x645528ef,0xbcfb0025}},	//   אשי_, _vinh_, dazi, grém
  { {0x61ea0272,0x7ac40015,0x539a0009,0x27330081}},	//   ámlá, _исче, _מיעו, _vãn_
  { {0x6729003e,0x21270020,0x29010005,0x91a80012}},	//   _miej, _tinh_, koha_, _يهمك_
  { {0xbebd007a,0x2bb60011,0x91ba0009,0xd1680009}},	//   _siūl, _अपमा, _ממני, _חֻקֹ
  { {0xdee60109,0x60d60009,0xbcfb0025,0x66e609c2}},	//   _поки, _רוצא_, crém, _пока
  { {0x629b007a,0x2d96002d,0x6729084b,0x3d160011}},	//   nduo, _зрос, _niej, _पीने_
  { {0xdca60fbb,0x65960012,0x645500b8,0x316d0025}},	// [72a0] _запи, _أجبر, bazi, nuez_
  { {0x645501a2,0xc059007c,0xc1060003,0x15fb0009}},	//   cazi, дії_, رواي, _מהפע
  { {0xb80a0003,0x6d4d0070,0x66f2001e,0xc2090009}},	//   أيام_, _zwaa, nāko, צה_
  { {0xddc00066,0x68e5004a,0x66c60028,0xbb3b0009}},	//   _zemř, aihd, _bóki, _מעטי
  { {0x67290052,0x7e270024,0xe4a60024,0x6d590032}},	//   _diej, ніша_, ерйо, gswa
  { {0xd6270024,0xf99300af,0x6f03099e,0x000000c4}},	//   хоче_, _גרש_, încr,
  { {0x7ac60047,0xb4fb0009,0x3cf10011,0xa3c20011}},	//   еспе, הפסי, ँचते_, ्नि_
  { {0x7528003e,0x7e530003,0xd2500003,0xc3330009}},	//   _widz, _منفص, جنة_, נוח_
  { {0x66e4000f,0x45360024,0xa7fc0060,0xf2d30009}},	//   tőkn, _їхат, ygıs, טעה_
  { {0xa3c20044,0xdce2009b,0x61db000b,0xada90003}},	//   ्ना_, oroč, פקיד, _تدفق_
  { {0xa3df0044,0x64550a5a,0x4a460024,0x94790024}},	//   _दें_, vazi, _знев, _юсту_
  { {0x7c46001e,0x56940055,0x316d0025,0x64650035}},	//   ūrrē, гают, buez_, ēriņ
  { {0x645501a2,0xdce60060,0x66f50073,0x6f1d28f0}},	//   tazi, evkı, nąka, rmsc
  { {0x62990002,0xdb1f0028,0xdce20107,0x66f2001e}},	//   _zawo, ðvör, kroč, bāko
  { {0xa7370003,0x2f12000e,0x645528f1,0x10370009}},	//   _كثير_, sága_, razi, _אטום_
  { {0xdce2012e,0x929d0002,0x6d4d0227,0x20070034}},	//   droč, połe, _twaa, żnik_
  { {0xe9f8002d,0x4efc0009,0xfe700012,0xe1f00012}},	// [72b0] енті_, _מההו, _ادى_, مسك_
  { {0x629b0010,0x25d80009,0x91640012,0xdb18008e}},	//   zduo, _רוזן_, اهله, lyvä
  { {0xec360093,0x47d50003,0x6d44000d,0x6d401120}},	//   _באתר_, خيار, ţial, _atma
  { {0xf412000b,0xb8c80037,0xcdd50009,0x59b00011}},	//   _כפי_, _खो_, ֣ךְ_, जमार
  { {0x9f5c0006,0xa3d30037,0x67290164,0x3eb90070}},	//   _hyvä_, सैन_, _viej, ijst_
  { {0x67290034,0x657d0032,0xdb18008e,0x7a400030}},	//   _wiej, itsh, hyvä, rátů
  { {0xdb180006,0xa3d10037,0xa2d80037,0xeb960024}},	//   kyvä, वनि_, नोक्, вищ_
  { {0xeab10003,0xada60029,0x22490070,0x290c0150}},	//   شعب_, _slúž, nbak_, elda_
  { {0x36d40015,0x629b0010,0x61e9080a,0x6910005e}},	//   _сотр, rduo, _želj, käel
  { {0xa3d10037,0x656f022d,0x3ebf0227,0x25a60159}},	//   वना_, duch, _hout_, _šolo_
  { {0x366a15db,0x99560024,0x656f28f2,0x644b001b}},	//   мано_, дiли_, euch, čnič
  { {0xfe720003,0x66f2001e,0xdee6024d,0x0bb60009}},	//   جدد_, rāko, томи, _בלעם_
  { {0x316d0108,0x629c001e,0xf1d90037,0x3ebf0025}},	//   quez_, ērot, _बेचन, _mout_
  { {0x7d03012c,0x8fe50012,0xb4db01a0,0x2fd50012}},	//   nons, _لأعم, spàn, _لتبح
  { {0x6d400028,0x29070060,0x656f1e5d,0x316928f3}},	//   ímab, _ikna_, auch, eraz_
  { {0x2365000f,0xc3320093,0x656f28f4,0xda6600ae}},	//   álja_, שון_, buch, ضاري
  { {0x3b070014,0x656f0164,0x88c50030,0xba290012}},	// [72c0] тето_, cuch, aměř, فسكم_
  { {0x7d030033,0x6b9b0002,0x07a60055,0x4fa6004c}},	//   jons, ługa, казн, кизв
  { {0x2249000e,0x3ebf28f5,0x7d0328f6,0xc00f0081}},	//   bbak_, _bout_, dons, _đuối_
  { {0xcfa9000a,0x2bf7000b,0xdd110066,0xe357000b}},	//   عالم_, _ימין_, mýšl, _בשטח_
  { {0x916d0020,0xfe370009,0x290c0097,0xf53f265a}},	//   _tốt_, דרני_, ylda_, rvåg_
  { {0x5c730024,0xf8bf0081,0xdce22588,0x7d0328f7}},	//   иліт, _quét_, proč, gons
  { {0x3ebf00bd,0xe737002d,0xc0e30024,0x25e90011}},	//   _fout_, _аес_, _торк, _चेनी_
  { {0xb9980447,0xeb970001,0xf8ca0011,0x2bba0011}},	//   евих_, тић_, िस्प, _उपना
  { {0xc878003a,0x5b230012,0xa834004c,0x6d400d77}},	//   liği_, جفيل, лепљ, _utma
  { {0x1be30044,0x52bf0044,0xc953000b,0x30a6035b}},	//   _केवल_, _एक्स, סמת_, трив
  { {0xdb18004a,0xa3bf0037,0x0857000b,0x645803ec}},	//   tyvä, ुनः_, כבים_, mavi
  { {0xe246000a,0x6458007a,0x7c27000f,0xdce6001e}},	//   _شخصي, lavi, _újra, vukā
  { {0xbcfb000f,0x20020002,0x40960003,0xb8960003}},	//   nség, łki_, _للشر, _للشع
  { {0xdb18004a,0x657d0068,0x62860032,0x753d0031}},	//   syvä, rtsh, _abko, _észe
  { {0x656f008b,0x68e828f8,0xf093000b,0x6d4600b6}},	//   such, midd, _כנס_, apka
  { {0xc878003a,0xbcfb000e,0x645828f9,0xc2c50012}},	//   diği_, kség, havi, ديري
  { {0x52150001,0x443e28fa,0xa3e40011,0xf9900012}},	// [72d0] удат, _oft_, _पेस_, يبك_
  { {0xc878003a,0x0efb0037,0x645817fa,0x897b0009}},	//   fiği_, एक्स_, javi, ורמצ
  { {0x05db0011,0x97340012,0x69cb0040,0x35db0011}},	//   _मेजब, لعنص, øgeb, _मेज़
  { {0x929d0002,0xf7730009,0x0bb60009,0x31690060}},	//   koła, שקף_, _עִיר_, praz_
  { {0xadbc002d,0xbcfb28fb,0x6d5d1d25,0xde580024}},	//   мацi, gség, nssa, тачі_
  { {0xb97a0093,0x629d000f,0x64580010,0x6d5d28fc}},	//   _אנשי, _haso, gavi, issa
  { {0x3ebf0108,0x629d002c,0x69c60033,0x7d030470}},	//   _tout_, _kaso, øken, rons
  { {0x66eb0002,0xf8bf0025,0x6458008e,0x7d0328fd}},	//   ięks, _tués_, aavi, sons
  { {0xe6050012,0x1be30011,0x0b160012,0xbcfb0025}},	//   _إِذَ, _केरल_, دقية_, préh
  { {0x40950014,0x2ecc0011,0xe8f6003c,0x9b8b0012}},	//   урит, ास्त, ллы_, _يخاف_
  { {0xd251000a,0xab94002d,0x660d003a,0x28d90037}},	//   _هنا_, _вихі, _ayak, योगि
  { {0xc332015a,0x656b13c1,0x1db70011,0x28b10011}},	//   _הוא_, orgh, _आपात, जाहि
  { {0x7ae90026,0x672d00b6,0x7afb009b,0xa0690264}},	//   miet, _diaj, čutl, _зала_
  { {0x7ae90039,0x515a000b,0xa3ca0037,0x64a60001}},	//   liet, _טכנו, रैक_, ћава
  { {0x6b63002d,0xbcfb000e,0x76590034,0x290528fe}},	//   йкра, zség, kawy, mola_
  { {0xd00e000a,0xe2970a25,0x7ae90879,0x290500b6}},	//   _علي_, лас_, niet, lola_
  { {0x200b0002,0x216728ff,0x44200081,0x3f8a016d}},	// [72e0] ęciu_, лити_, ̀i_, _spbu_
  { {0xc878003a,0xa90a0012,0xb8650012,0x3c460012}},	//   tiği_, ريال_, لامو, _حَدِ
  { {0x2f19000f,0x64580010,0x3f51001e,0xe3b20012}},	//   sége_, vavi, nšu_, _طرد_
  { {0xbcfb2900,0xc878003a,0x7ae9001e,0x92b60003}},	//   tség, riği_, jiet, _إحدا
  { {0x9c8701e9,0xbddb0025,0x7ae92901,0xd4360009}},	//   _určí, ccèd, diet, ְטֵי_
  { {0x2f150163,0xbcfb0bff,0x629d0002,0x3f51001e}},	//   råga_, rség, _zaso, kšu_
  { {0xbcfb000f,0xa3e40037,0x929d0002,0xb3860012}},	//   sség, _पेश_, woła, اجته
  { {0x61e9102c,0x69c60033,0x5a340014,0xfbd3000b}},	//   _želi, økeo, шнит, מתו_
  { {0x2bb60037,0x3f51001e,0x6b950034,0x64582902}},	//   _अपवा, ešu_, zwzg, pavi
  { {0xf993000b,0xb97b000b,0x3942001e,0xb60301bd}},	//   צרת_, עניי, īks_, ýšen
  { {0x3f51001e,0x33f60015,0x7ae92903,0xbcfb0025}},	//   gšu_, _счас, biet, nsée
  { {0x2f5b0009,0xfa360012,0x93fb0009,0x6f0f0031}},	//   עדכנ, _إراد, _אלבי, ulcc
  { {0x29052904,0x672d052e,0x3f512905,0x629d2906}},	//   bola_, _viaj, ašu_, _raso
  { {0x66c60028,0x6d400028,0x89db0009,0x219b0009}},	//   _bóks, ímaa, _אחדי, _נבוא
  { {0xa3df0044,0xa3d42907,0xe4e4002d,0x2d8c004b}},	//   _देख_, борч, сіян, ădea_
  { {0x6b9b0002,0x8c1b0009,0x5bb8003c,0x6d550034}},	//   ługo, תולי, ылся_, _łzam
  { {0xdcfb0027,0x42e40003,0x0855027f,0xb06b2908}},	// [72f0] _upuć, حسِّ, иваю, فصال_
  { {0x95840002,0x3d0e0037,0xa3d40037,0xe1f00012}},	//   żący, ितों_, हना_, أسف_
  { {0x629d004a,0x7a2b003a,0x5f950014,0x49170009}},	//   _taso, _kötü, риет, נקבל_
  { {0xbcfb0061,0x7ae90132,0x25a90060,0x29052909}},	//   sséd, xiet, _kral_, zola_
  { {0x286b0001,0x69c60033,0x4a5a000b,0x7ae9290a}},	//   _прво_, økel, _בדרו, viet
  { {0x7ae9003e,0x3949290b,0x41de0011,0xe3b10012}},	//   wiet, mpas_, _नेटस, قرب_
  { {0x2fc7006f,0x7ae9290c,0xe29914ea,0xfc640048}},	//   ängd_, tiet, вай_, съчн
  { {0x2bb60037,0x3949290d,0x25ed0011,0xd2a9003c}},	//   _अपरा, opas_, _आइपी_, ткие_
  { {0xc8b50015,0x8c3c003a,0x78890012,0x5e440012}},	//   асны, _bağd, نَةِ_, _طَلْ
  { {0x6ad20037,0xd198000b,0x008201ef,0xa8050048}},	//   _सत्र, רכזי_, ольо, изпл
  { {0x200200a2,0x6d44290e,0xf092000b,0x7ae9290f}},	//   şkin_, _stia, חני_, piet
  { {0x28d90037,0x3f51001e,0x2656004c,0x29052910}},	//   योजि, ršu_, шњос, sola_
  { {0x20d5007c,0xe0ce0014,0xacea0012,0x66f20035}},	//   _війс, _дв_, نرسل_, nāki
  { {0xc5f20093,0x20f40037,0xf5070015,0x61da0009}},	//   קדם_, _आदेश_, инял_, _בקנד
  { {0xca560001,0x230a0012,0x161a0011,0xe29f0097}},	//   итањ, نتري_, नेजर_, _bað_
  { {0xd7fa000b,0x7a2b003a,0x57fa0009,0x5ffa01b0}},	//   _בהצל, _götü, _שלקו, _בהצה
  { {0xe297010c,0x39490e10,0x88e6004d,0x232725cd}},	// [7300] шат_, gpas_, ажае, роти_
  { {0x66c60028,0x69cb0040,0xe0d71a4e,0x66f20035}},	//   _tóks, øgea, аву_, dāki
  { {0xf7720003,0x39492911,0xe7370048,0x8f760024}},	//   تاء_, apas_, аех_, рузі
  { {0x4733007c,0xe5c6007c,0x4aca0037,0xfaa619f8}},	//   ініс, исло, _रविव, _тамо
  { {0xa5da0003,0xe2970014,0xbcfb0061,0x67220079}},	//   خبار_, _тая_, ssée, rmoj
  { {0x53340014,0xfb660001,0x6722001e,0x3160003a}},	//   бект, ањим, smoj, msiz_
  { {0xdb1c004a,0xbcfb0025,0x316d2912,0x66e40031}},	//   pyrä, prév, erez_, pőkh
  { {0x2fc7031d,0x8f9b0009,0x645c2550,0x8c3c0060}},	//   änge_, _בילי, hari, _sağd
  { {0xbcfb0025,0x31600060,0x66f20035,0x6ac30012}},	//   nséc, nsiz_, cāki, تقيم
  { {0x28a60037,0x753d000e,0xdbdc05b1,0x60c32913}},	//   _कोशि, _észa, lším, _conm
  { {0x1037000b,0xf837000b,0x224d000e,0x6d400463}},	//   יטים_, ינית_, bbek_, íman
  { {0x28a60037,0x3160003a,0x64572914,0xeb970009}},	//   _कोरि, ksiz_, _sexi, _כדבר_
  { {0xbd6b0014,0x60dd001e,0xe5c4022a,0xceb30009}},	//   ърне_, ūsma, осро, קיש_
  { {0xaffc0024,0x9e140024,0x7bc1008e,0x63f70012}},	//   _полi, ідрі, äluo, لأزر
  { {0xd0f50044,0x3ea00108,0x2ba90011,0x88bb0009}},	//   ीकरण_, _fait_, किया, _במגז
  { {0x5a350014,0xdee40001,0x645c2915,0xd7bb0009}},	//   снат, _моји, aari, _יצור
  { {0x7afa0065,0x645c00ea,0xe29f0028,0x4efc0009}},	// [7310] étta, bari, _vað_, _שהחו
  { {0x4499064f,0x58bb0003,0xf8b10009,0x5ce40012}},	//   _свою_, خارج_, ּשׁ_, _وكيل
  { {0x26c4012e,0x32070002,0xfc4601bd,0x7ff40012}},	//   _bomo_, łny_, číte_, يسما
  { {0x26c42916,0x3949006f,0x765d0363,0xa3aa0011}},	//   _como_, ppas_, nasy, गटन_
  { {0x6da5007c,0x64410052,0x8c4507e8,0xa2b60009}},	//   сила, _pfli, беле, _הפרד_
  { {0x316d0061,0x0136000b,0x66f2001e,0xbcfb0e90}},	//   vrez_, _לרשת_, rāki, crét
  { {0x765d1067,0x66e4000e,0x2259005e,0x39460018}},	//   kasy, sőki, _kesk_, _atos_
  { {0x316d0108,0xc3340093,0x395f0005,0x2bf8000b}},	//   trez_, חוק_, tsus_, ימון_
  { {0xf991000a,0x645c0175,0x690b0017,0xd2b80009}},	//   سبة_, yari, qües, שלחת_
  { {0x1477000a,0x71d8000b,0x83870015,0x316d0061}},	//   _خارج, יוחד_, _выде, rrez_
  { {0x395f0108,0x85040003,0x7aed104a,0xbea604ba}},	//   ssus_, _بولن, kiat, банк
  { {0x2b810002,0x765d0115,0x645c0a83,0xc4c90009}},	//   móc_, gasy, wari, _אג_
  { {0x2169077e,0x7afe1007,0xaa360009,0x2bba0011}},	//   _сили_, épte, _הטנק_, _उपहा
  { {0x2d820027,0xf1b2000b,0x3ea0002a,0xe8020037}},	//   rtke_, _מסד_, _wait_, _रुका_
  { {0x69cb0058,0xaadb0011,0x7af60248,0x2d822917}},	//   øgen, _बताक, tnyt, stke_
  { {0x3160003a,0x6ee50003,0x7aed2918,0x645c2919}},	//   tsiz_, _وسيل, giat, sari
  { {0x5d86000a,0x8066002d,0x18360012,0xb1160012}},	// [7320] _الخل, йваж, مراح, مورغ
  { {0x316000a2,0xc2120009,0xbcfb0025,0x20ca0012}},	//   rsiz_, להן_, rséc, دبري_
  { {0x44440036,0xbbb60037,0xbcfb000c,0xdbdc0030}},	//   _if_, _अपेक, rrét, tším
  { {0x539b000b,0x66760003,0xe8e0001a,0xf6e5002d}},	//   _עיכו, إدار, _thủy_, оцін
  { {0x2cea0047,0xa3c20037,0xdb230030,0xdbdc06dd}},	//   лько_, ्नक_, _írán, rším
  { {0x3ea00013,0x765d00a2,0xc953000b,0x6aa401a4}},	//   žit_, zasy, _ממש_, ldif
  { {0x66f2001e,0x25a60227,0x798414df,0x765d0060}},	//   lāku, svol_, ltiw, yasy
  { {0x26c400c1,0x6738000e,0xdee60001,0xc333000b}},	//   _uomo_, ívju, _уоби, הוה_
  { {0x4444291a,0x66f20039,0x19ba0003,0x8db6002d}},	//   _of_, nāku, اطعة_, _усві
  { {0x7aed0b6d,0xf1b30009,0x97c60012,0x656f01e9}},	//   ziat, פסת_, متجم, vrch
  { {0xa3e80044,0x765d0de6,0x645a001e,0x48a70015}},	//   _मेल_, tasy, _ieti, стым_
  { {0x4444291b,0x539b000b,0xd337000b,0x4b370009}},	//   _af_, _תיאו, _הראה_, _הראל_
  { {0xd24f000a,0x645a0889,0x3946002c,0x7aed291c}},	//   _أنه_, _keti, _utos_, viat
  { {0x897b000b,0x7aed0002,0x765d002c,0x98a300bb}},	//   _ערוצ, wiat, sasy, _ниче
  { {0x645a00a2,0x765d002c,0xd00f0003,0x1bd400b3}},	//   _meti, pasy, _كله_, поря
  { {0x4444014d,0x2ba90037,0x69cb0058,0x5b15002d}},	//   _ef_, किता, øgeo, імат
  { {0x1ef80003,0x64400034,0x02440012,0x7afc0031}},	// [7330] _دعوة_, śmia, سَلَ, _írtu
  { {0x88bc0066,0x39820028,0xa0a70001,0xa3ab0011}},	//   změn, iðs_, љшал, खिम_
  { {0x661b003e,0xc4d20009,0xbcfb0031,0xdb080031}},	//   _szuk, _חגי_, srés, _erdé
  { {0xbcfb291d,0x66f2001e,0xa615003c,0xe8b50011}},	//   prés, bāku, омеч, _अच्च
  { {0x645a0950,0x356b0014,0xbebd0073,0x05640024}},	//   _beti, урен_, _siūs, звін
  { {0x4f5b0003,0xf1b20009,0x2489001b,0xdfc60012}},	//   _مجرد_, _קסם_, đamo_, _قي_
  { {0x36d50001,0x2f12000e,0xfd100012,0xaed50024}},	//   _довр, sági_, رجه_, _довш
  { {0xcf92000b,0xa3de0066,0x66f2001e,0x645a0051}},	//   _קטן_, běží_, nākt, _eeti
  { {0x69d600a2,0xd4b90024,0x49950024,0xe0d9083a}},	//   _üyel, _клац_, ішит, иви_
  { {0x645a087e,0xe6c50027,0xa0690001,0xdd0e0060}},	//   _geti, _češć, јана_, mışl
  { {0xa3e823b5,0x69100005,0xdbf20013,0x6d44000d}},	//   _में_, päev, _příp, ţiat
  { {0xd62a011d,0x41b50012,0x7afd0030,0x2d9e0034}},	//   ионе_, _ومار, _njst, łtem_
  { {0x645a003a,0xdd0e003a,0x69cb0058,0xef18001e}},	//   _yeti, nışl, øgel, ēļ_
  { {0x6aa20002,0x1cb90009,0x28040031,0x66f20035}},	//   _zaof, ׁמָע, épné_, vāku
  { {0xd372000a,0xea5a0001,0xf3f1001a,0xeb9a00b3}},	//   ظهر_, ирај_, _mẹo_, шив_
  { {0x8c3c003a,0x7bce0002,0x25b50164,0xbddb0025}},	//   _mağa, rybu, ñaló_, rbèr
  { {0xf1aa0012,0x08c6291e,0x02ca0011,0x6aa4291f}},	// [7340] جازه_, обан, _रवीन, rdif
  { {0x66f2001e,0x186a035c,0xe8e0001a,0x78a32920}},	//   rāku, ражи_, _thụy_, _janv
  { {0x66f2001e,0xee3a2921,0x79840a83,0xbb860012}},	//   sāku, ане_, stiw, _بلجي
  { {0x645a2100,0x268a0003,0x2fc7006f,0x0f290012}},	//   _seti, شخصي_, änga_, مثنى_
  { {0x6596000a,0x753d000e,0x22650066,0xba480010}},	//   تجار, _észl, řský_, grįž
  { {0xafe60594,0xa7fc0060,0x53340bda,0xdb6a0357}},	//   _догл, rgız, пект, арил_
  { {0xdfd20351,0x3d090037,0x66f20035,0x84e70012}},	//   _غير_, ाक़े_, nāks, تفوق_
  { {0x78a300bd,0x24980070,0xd1410002,0xc3270003}},	//   _aanv, herm_, knąć_, يكون_
  { {0x11d80003,0x645a05b6,0x27ea0073,0x673c2411}},	//   صودة_, _teti, žinė_, _hurj
  { {0x78a30663,0x2365009b,0x39820028,0x79b7000b}},	//   _canv, šlji_, rðs_, קליד_
  { {0x2a660014,0x320a0002,0x4a460426,0x907b0009}},	//   _дълг, łby_, _днев, סטטי
  { {0xd6d90002,0x7ee7002d,0x539b000b,0x3ea62922}},	//   ół_, іцне, _כיבו, ndot_
  { {0x3ea6001e,0x2607002d,0xc333000b,0x66f20035}},	//   idot_, ючог, _חוף_, vākt
  { {0x3ea60006,0x0e340024,0x69cb0040,0xc9530009}},	//   hdot_, ьняю, øgem, _חמס_
  { {0x2ac70001,0xb9230003,0xac190538,0xd25b0426}},	//   ољав, _تفوي, сову_, ица_
  { {0x290c001e,0xa3ab0037,0x98850066,0x7ee40003}},	//   loda_, खित_, _vůči_, _يكون
  { {0x0975002d,0xe84b0012,0xe1f00012,0x60c70e76}},	// [7350] ягаю, لجان_, نسك_, _pojm
  { {0x3ea6004a,0x66f2001e,0x37ab0083,0x55bc0009}},	//   edot_, sākt, итен_, _כמחו
  { {0xc49a000b,0x4c9a0009,0x6d492923,0xdc9a0009}},	//   _השתת, _הבתו, _stea, _הסתכ
  { {0x539a000b,0xfba90037,0xdd0e003a,0x41ca0037}},	//   _פירו, किसम, tışl, िहास
  { {0xdd9b002d,0x2aba0009,0x81680048,0x7aba0009}},	//   рше_, _המרא, _мррб_, _הצרו
  { {0x113a000b,0xaaa30037,0xece8002d,0x04c80003}},	//   _לתשל, _खोजक, оділ_, يوني_
  { {0xccf40009,0x54580009,0xf36b0009,0x69c6008e}},	//   וכס_, חסון_, ׁדַּ, äken
  { {0xc7b20093,0x93fc000b,0x1bfc000b,0x4bfc0009}},	//   _אבל_, ילוי, ילוב, ילוס
  { {0x394d0108,0xcb14000b,0xf4870024,0x225f0073}},	//   upes_, ולק_, _мужн, rauk_
  { {0x394d001e,0xedb40012,0x290c2924,0x7e7d0529}},	//   rpes_, _تحفظ, goda_, egsp
  { {0x9f580065,0x9f450006,0xaa95002d,0xd0090014}},	//   ærð_, _älä_, _нижч, сене_
  { {0x141a000b,0xc7d6000b,0x66da0014,0xf7d60009}},	//   _הועב, פורי_, сьор_, פורש_
  { {0xf3f7001a,0xd13b0001,0xf1a700f5,0x2d840025}},	//   ộng_, _тхе_, _френ, îme_
  { {0x3cf60037,0xe4470003,0x6cd60003,0xe5720009}},	//   ँचें_, عض_, أقسا, עַר_
  { {0xe8d60009,0xd1410034,0x69c600b0,0x00ba0009}},	//   _מוסר_, snąć_, økev, _למסמ
  { {0x66f2001e,0x3946022a,0xf65f0040,0xb1461e8e}},	//   rāks, знаг, skær_, знал
  { {0x867b000b,0xe0da0014,0x38610052,0xcf250003}},	// [7360] _הרפו, бва_, fahr_, _تروي
  { {0x3d050037,0x7afb0004,0x3ea40846,0x88550009}},	//   शकों_, hnut, _samt_, לֹ֣א_
  { {0x98aa000d,0x4c3b000b,0x7afb2925,0x645e2926}},	//   _aibă_, _לתיב, knut, _iepi
  { {0xeaf90037,0x3ea6001e,0xc6a30055,0xc56a0012}},	//   ्कृत_, udot_, ерши, محتل_
  { {0x1ea9000a,0xa3e40037,0x2ca502ef,0x7afb2927}},	//   تالي_, _पेज_, _bald_, dnut
  { {0xeaf60037,0x2d860070,0x93f60009,0xfce30024}},	//   ुक्त_, rtoe_, ּצֵא_, ночо
  { {0x290c0604,0xd467004c,0xbc670012,0x44260012}},	//   voda_, чије_, سمين_, أرشف
  { {0x645e2928,0x7afb0027,0x6ffb0009,0xe3af0012}},	//   _lepi, gnut, _הפלג, ارو_
  { {0x2ca50058,0x61e42929,0x3f67001b,0xe1660012}},	//   _fald_, nzil, eđu_, أدبي
  { {0x645e0039,0xf98f000a,0x290c004a,0x46130003}},	//   _nepi, ابي_, uoda_, _أوكر
  { {0xf8b3000b,0xd7f70015,0x3f630015,0x9f58003a}},	//   גשת_, зуя_, нтяб, _özür_
  { {0x333b0093,0xe8b90037,0xaa570003,0x501b000b}},	//   _התאמ, _उच्च, _فلما_, מויו
  { {0x690f0040,0x61e40031,0x4ac30012,0x62820227}},	//   røer, jzil, _سيوق, _icoo
  { {0xdb010052,0xdcef000d,0x61e4292a,0x690f0040}},	//   _erlä, ducă, dzil, søer
  { {0x98a3004c,0x40eb0009,0x645e292b,0xa3bc0011}},	//   _чије, _לַהֲ, _depi, _आपः_
  { {0x6ffb0093,0x38170093,0x68ee0054,0xba3d0066}},	//   _להופ, _מקום_, _ambd, jdůl
  { {0x3ced0037,0xf1940021,0x44290081,0xc69400af}},	// [7370] _अगले_, нить, ̀a_, _טאק_
  { {0x6d4d05cf,0x66f20035,0x91e4004c,0x6f0f292c}},	//   _itaa, lākp, хође, locc
  { {0xbcfb032f,0xdb08107f,0x000000c4,0x000000c4}},	//   nsém, _ardí,   ,
  { {0x6d49007d,0xa9230010,0x39860017,0xadf5004c}},	//   ţeau, ėžim, bôs_, мпеш
  { {0x3e88000e,0xa2c00011,0x69c6008e,0xe60e0430}},	//   lító_, वान्, äkel, тд_
  { {0x88bc0066,0x2481005e,0xdb030030,0x8e080024}},	//   směj, ühm_, rvní, чнів_
  { {0xf8b20093,0x7869000e,0x7afb1cc7,0x2ca5292d}},	//   _בשם_, _jövő, tnut, _vald_
  { {0x61220061,0x7bdc0009,0x660d005e,0x2ca50032}},	//   rôle, מקוו, üaks, _wald_
  { {0x307502e3,0xd6e00034,0xb5fd0bb7,0x7afb292e}},	//   мунс, ółmi_, _odši, rnut
  { {0xe0d10003,0xe1ff0031,0x7afb292f,0x40950148}},	//   ئزة_, _adók_, snut, фрит
  { {0x5f06002d,0x7afb0042,0x443a016d,0x645e2930}},	//   дзна, pnut, _rgp_, _repi
  { {0x3e880031,0x645e2931,0xeb9000ae,0x613109b8}},	//   dító_, _sepi, _حظك_, lılğ
  { {0x18690489,0xc3320009,0x69c600b0,0x628a0031}},	//   _дали_, _סוד_, øket, őfok
  { {0xddc4000d,0x2a7f0e0c,0x78a717fa,0x913a0009}},	//   _adiţ, lgub_, _najv, _ועסק
  { {0xdc450073,0x645e0030,0x7d0e016d,0x6f0f00b8}},	//   jūči, _vepi, robs, bocc
  { {0x6008000b,0x7b3c0027,0xd8080009,0x6aa92932}},	//   _מִפְ, _očuv, _מִפָ, ndef
  { {0x8c3c00a2,0xd7f8000d,0x6aa60060,0x645e2933}},	// [7380] _bağl, _ţă_, _vakf, _tepi
  { {0xddc4000d,0xeb9a0001,0x76490097,0x5c160012}},	//   _ediţ, _дио_, _afey, _يبدأ
  { {0x7fd50024,0x130a003c,0x7b3c001b,0x8c3c0060}},	//   ніці, _мной_, _ačuv, _dağl
  { {0xf42a0006,0xe61a020e,0xfe720012,0x39860018}},	//   _enää_, оде_, ئدا_, pôs_
  { {0xa2b10037,0xdd900012,0x7e530024,0x7e62162e}},	//   _अफ़्, اوت_, твіє, raop
  { {0xa533002d,0x6aa913a1,0x64a3004c,0xb4d80011}},	//   вніч, edef, ваља, ासे_
  { {0x8f75002d,0xbb470003,0xb17d0029,0x06560012}},	//   _путі, ولون_, vzťa, _ينسح
  { {0xf96a0015,0x416a0001,0x816a0024,0xd2500012}},	//   орой_, ојом_, ороб_, دنة_
  { {0x05ba0003,0xcb13000b,0xdd140029,0xc4860001}},	//   _بدأت_, כלה_, dĺžn, _олак
  { {0xa1270003,0x69cb0040,0x6e3b2934,0x7e602935}},	//   وكيل_, øgei, _zgub, _hemp
  { {0xd83802a1,0xf4570009,0x6d4d2936,0x389b0009}},	//   ječe_, _חיבר_, _staa, חיינ
  { {0xd83809d2,0x6d402937,0x3e880031,0xfe7f01a0}},	//   deče_, _kuma, vító_, viïs_
  { {0x7e6000c6,0x8cc20037,0xd6570009,0x94ab0048}},	//   _memp, लापो, ויכת_, отва_
  { {0x7e600577,0x28a60011,0xa193004c,0x6f0f00b8}},	//   _lemp, _कोचि, _рашч, socc
  { {0x6d400101,0x3d160037,0xa87b000b,0x929501ef}},	//   _luma, _पीछे_, _ואור, навц
  { {0x8c3c00a2,0xba770012,0x3e880031,0x5fcb0011}},	//   _sağl, باست, rító_, ाहरल
  { {0x3e88000f,0x26d9007a,0xeabf001a,0xaf080012}},	// [7390] sító_, ūros_, _chùa_, _تقيم_
  { {0x6cd50012,0xa1150012,0x98740048,0xf0fb0011}},	//   _أقدا, روات, клуц, ्वेद_
  { {0x47580024,0x8cc20011,0xc7a90009,0x6d402938}},	//   дрія_, लानो, ּׁנָ, ímav
  { {0x6d400101,0x501b0009,0x37080012,0x36d4004c}},	//   _buma, חובו, وْلُ_, кохр
  { {0xbdf80003,0x3ea90feb,0x7bd50042,0x78b20097}},	//   ورها_, _maat_, lyzu, íkvó
  { {0x3ea90070,0x515a0009,0xa3ab0011,0x6d402939}},	//   _laat_, _מכשו, खिल_, _duma
  { {0xfc640048,0xd6e00034,0x3ce00011,0xb8d50011}},	//   тъчн, ółki_, _कतरे_, ढ़ा_
  { {0x7e6000b6,0x2249066c,0x9b920012,0x33920012}},	//   _gemp, ncak_, اليت, اليز
  { {0x6d4001e5,0x7afa0065,0xddc404e5,0x6aa9293a}},	//   _guma, étti, _odiš, rdef
  { {0x47c50015,0xa3df0037,0x7b31001e,0x24550012}},	//   ебов, थना_, _jāuz, _أناس
  { {0x325500c0,0x69c60033,0x929d0034,0x6d400032}},	//   _звер, øker, wołu, _zuma
  { {0x68e60035,0xcfd20012,0x92670012,0x7e60293b}},	//   īkda, ايَة, _آدام, _xemp
  { {0x58d50075,0x5d670015,0x99840012,0x4a720012}},	//   _подт, ниям_, _للنو, _صُور
  { {0xcdf6000b,0x09f6000b,0xa0c50012,0x26d9293c}},	//   תמשי_, _אמנם_, _سيبو, akso_
  { {0x232a05fb,0x7a2a000e,0xd83809d2,0x141a0012}},	//   зови_, köté, teče_, سيرة_
  { {0x97d8000a,0x3ea900bd,0x8c3c003a,0x07d80012}},	//   _تظهر_, _gaat_, _rağm, _تذهب_
  { {0xc3320093,0x7e600cfb,0xc9860003,0xa3bc0037}},	// [73a0] רון_, _remp, عشري, _आपक_
  { {0x6d40293d,0x80a60012,0x7e60293e,0x53a60451}},	//   _ruma, عمان, _semp, _заоб
  { {0xdb0f000e,0x7e601162,0x6d40293f,0x9cd70009}},	//   ődát, _pemp, _suma, _נוטה_
  { {0x040b0020,0x6d400101,0xc869000b,0x9daa0048}},	//   _lượn, _puma, מן_, зъка_
  { {0x7e60008e,0xe2a60097,0xe5720012,0xd65700af}},	//   _vemp, öðun_, اطؤ_, גינת_
  { {0xdb050052,0xeb180011,0xa1160012,0x5ba60479}},	//   _erhä, दत्त_, _أوست, ериз
  { {0x9103057b,0x2f19000e,0xc4d3000b,0xc9170009}},	//   _спре, ségi_, רגו_, _נחלת_
  { {0x6d401617,0x539b0009,0x6b830248,0xaae00011}},	//   _tuma, פיפו, _ånge, नसिक
  { {0xb9970047,0x828b000b,0x343a0012,0x80c40011}},	//   евых_, הְיֶ, _فساد_, रापे
  { {0x94a90003,0x3ea92940,0xc1730009,0xc0570024}},	//   _يطلق_, _saat_, נחת_, нію_
  { {0x32e4001a,0x20180028,0x5cf5002d,0x273a0010}},	//   _đườ, æri_, _ряту, _būna_
  { {0x7bdb000b,0x657d0038,0x57fb0009,0xcf930009}},	//   _מקבו, tush, לליו, נטר_
  { {0xc2e90003,0x99d30003,0xceb3000b,0xe9730012}},	//   _تعلم_, _متوا, איר_, _مهند
  { {0x91bb000b,0xbca50012,0x7ae40038,0x63ad0034}},	//   _ממדי, خمسي, ehit, łane
  { {0x25bf000d,0xad1b000b,0x20c90012,0x936b0009}},	//   ţul_, פולר, _تبني_, ּ֣לֶ
  { {0x41e7007c,0x3da7007c,0x3f8b000d,0x6ec70012}},	//   ніза, _зроб, ăcut_, _ستبق
  { {0x5a350014,0x8b030030,0x41e70024,0x6d4008d0}},	// [73b0] тнат, ířil, хіва, ímat
  { {0x6f1d008b,0xd5640014,0x394f001e,0x5214002d}},	//   llsc, _стъп, īgs_, удут
  { {0xb5fb000f,0xc1040003,0xf5360009,0x6f1d0034}},	//   zaál, دولي, _שנתי_, olsc
  { {0xd3560009,0x2f740012,0x2727005e,0x877b0009}},	//   _שירי_, اطلس, kõne_, לאבי
  { {0xada50015,0xee2e002d,0x443e016d,0xe5a52941}},	//   талл, рн_, _bgt_, тили
  { {0xd378001c,0xdb1c0065,0x6f1d0032,0x69cb0040}},	//   šće_, lyrð, hlsc, øgeu
  { {0xdb05006f,0xe4ac0009,0xeab10012,0x3942005e}},	//   _erhå, לֹהָ, لعة_, _zuks_
  { {0x9f340024,0x3bbc0009,0x6aad2942,0x8f340189}},	//   _бесі, למוד, ndaf, _бесц
  { {0xceb2000b,0x69c60033,0xf400000d,0x30790003}},	//   _דין_, økep, ăţii_, وحدة_
  { {0xf9920009,0x8e380012,0x80c40011,0xadf4004c}},	//   סרי_, _أسفر_, राये, _спуш
  { {0x22950003,0x29010017,0xe00b0011,0x040b0081}},	//   _للاس, inha_, _सुखद_, _vượn
  { {0x67010011,0x92eb0012,0x4425001b,0x798d14df}},	//   लचिक_, _عراق_, _izl_, ktaw
  { {0x040b0020,0xd6560009,0xa2b50011,0xe9ce091c}},	//   _tượn, כירת_, _उफ़्, _тк_
  { {0xe9d8007c,0x64a60001,0xb2240024,0x7e66005e}},	//   _які_, њава, _сміл, sakp
  { {0x58f6000b,0x5f060014,0x2d9e00f1,0xdddd0002}},	//   _במסע_, _изка, ňte_, gasł
  { {0x29010017,0x501a0009,0x9f490034,0x673b0073}},	//   enha_, _קוקו, łków_, _niuj
  { {0x61e903e4,0x4a430055,0x7ae405e5,0xd9430048}},	// [73c0] nzel, рнув, rhit, иети
  { {0x7d7b000b,0x6aab0028,0x62330001,0x9ffa0012}},	//   _קניו, _lagf, ређу, وراء_
  { {0xcc77000b,0xdd1c0029,0x3c770009,0xcc570009}},	//   _בעיה_, _nášh, _בתים_, _שבטי_
  { {0x753a0052,0xd6d9002d,0xad660003,0x2901008e}},	//   _sitz, нті_, ناته, anha_
  { {0xa2c00037,0x7afa0028,0x5de60048,0xbe850012}},	//   वास्, éttu, ъжда, اجمو
  { {0xf9930009,0xd6e20034,0x15130024,0x25d70009}},	//   _דרש_, _siłę_, адія, כונן_
  { {0x6458001e,0x8bc30014,0x61e9110c,0x53a30012}},	//   rbvi, исъд, ezel, لموك
  { {0xfbd3000b,0x1eaa0012,0x32530048,0xddcd004b}},	//   שתה_, _غازي_, авър, _neaş
  { {0x7f4302d1,0x7ae3000d,0xc3330009,0x4938003c}},	//   _aunq, _înte, סוח_, нзию_
  { {0x753a0070,0x88bc0066,0x6f1d0227,0x80dc0011}},	//   _uitz, jmět, wlsc, यसें
  { {0x03a3007c,0x88bc0066,0x287b000b,0x2378000e}},	//   _вихо, dmět, ונימ, _írj_
  { {0x7f4300c1,0x6f020168,0x93f70009,0x73360012}},	//   _dunq, nnoc, _בצבא_, _شرائ
  { {0x61e90002,0x753d0031,0xb5fd136f,0xe89401c6}},	//   czel, _észt, _keša, _баль
  { {0x71d7000b,0x6fb40012,0xe7b40012,0x69cb005e}},	//   _בודד_, _ممتا, _ممتد, ägem
  { {0x24180015,0xa3ab0037,0xac18026d,0x389b0009}},	//   воры_, खिए_, вору_, _חיונ
  { {0x628401a2,0x69d6003a,0x248d0066,0xf8370009}},	//   ggio, _üyes, řem_, _בנות_
  { {0xc1050003,0x2aea0037,0x7bd80010,0xef1f0060}},	// [73d0] هوري, जोएँ_, hyvu, mlü_
  { {0x798d00b6,0xc0d4000b,0x273b0010,0xf7730012}},	//   rtaw, נֵּה_, _kūno_, لاص_
  { {0x798d003e,0x1bd5002d,0x291e004a,0x661b00b6}},	//   staw, _соня, ilta_, _syuk
  { {0x612b0005,0xe758002d,0x8f14002d,0xf7700012}},	//   külg, тиці_, афіч, زام_
  { {0xa4d5002d,0xc3320009,0xa91d2943,0x94d50842}},	//   лоді, _לוט_, stži, лодц
  { {0xd006000a,0x05740003,0x4ddc000b,0xe7c20037}},	//   _هل_, شاهد, וחדו, षमाप
  { {0xb5fd0027,0x30a40048,0xef1f0060,0x57a40024}},	//   _deša, _тряв, klü_, _кшта
  { {0xdd1c0026,0x88bc0066,0x7ae20503,0x5985002d}},	//   _vášh, změt, _clot, глиб
  { {0xa91d0066,0xd838009b,0x8d790012,0xf5790012}},	//   huže, veča_, _سماء_, _سماع_
  { {0x03b70012,0xddc9004b,0xe9a80012,0x07a5004c}},	//   _لإصد, _edeţ, ئدين_, гаон
  { {0x25a9010a,0x92590048,0x8384003c,0xcb55004c}},	//   _asal_, _зает_, _выче, _свећ
  { {0xeab00003,0xa91d0027,0x291e10ae,0xa68302ad}},	//   _وعن_, duže, alta_, блюд
  { {0x55f60015,0xcdf60015,0xa2c00011,0xa3ab0011}},	//   учну, учны, वार्, खिक_
  { {0x612b0060,0xc5fa0009,0x4df504a5,0xdce92944}},	//   nüld, תפשט, ряют, _oveč
  { {0x3bd50047,0x75ea000e,0xdb010017,0x7d030993}},	//   аютс, _közé, _islâ, inns
  { {0x224d000e,0xe7f90011,0x7ce20064,0x42550ba0}},	//   ncek_, ्पना_, _dôra, итут
  { {0x6b9b007d,0x612b000f,0x71650003,0xd9460003}},	// [73e0] ăuga, küld, لالك, ائري
  { {0xbd5b000b,0x155b000b,0x61220025,0x98b9004b}},	//   _רכיש, _רכיב, rôlo, _rusă_
  { {0xd12f0003,0x2d820027,0x69cb0058,0x645c2945}},	//   أمل_, luke_, øger, mbri
  { {0x76a9007c,0x2bb5001a,0xb5aa0012,0x91e60048}},	//   ктів_, _ích_, فاتك_, _боме
  { {0x80c40037,0x2d822946,0xb5fd001b,0xbcfb0025}},	//   रादे, nuke_, _peša, rsév
  { {0x7bd8007a,0x291e000e,0x7d7b0009,0xfbaa003c}},	//   tyvu, _óta_, תנסו, етий_
  { {0x2d8f0054,0xd0f70009,0xef1f0060,0xaa7b0030}},	//   atge_, _עמלת_, ylü_, _mlýn
  { {0x5fbb000b,0x7d031891,0x3ea22947,0xf7d70009}},	//   _אצלנ, anns, jekt_, _גולש_
  { {0x88bc0066,0xf2d30009,0xf50a003c,0x7ebb008e}},	//   dměr, מעה_, _знал_, _läpä
  { {0x50f40365,0x78a12948,0xa0a610eb,0xa3a600ae}},	//   рзот, gelv, ушил, _محصن
  { {0x6ecb0037,0xd117000b,0xc917000b,0x3ed50012}},	//   _सचमु, רקיה_, רחית_, لقدر
  { {0x7c250052,0x8cc20037,0x753d000e,0xa635002d}},	//   ühre, लावो, _észr, инні
  { {0xab630002,0xef1f003a,0x612b034f,0x645c2949}},	//   ążen, rlü_, lüle, fbri
  { {0xd12f0003,0xc953000b,0x3ead024e,0xa91d001b}},	//   _فمن_, _המס_, žet_, tuže
  { {0x24190015,0x612b030f,0xac19294a,0x3ae7005e}},	//   товы_, nüle, тову_, _lõpe_
  { {0xddc00013,0x8c1b0009,0x4a550400,0xbc1b0009}},	//   _nemů, גולי, ркас, גולש
  { {0x3946007a,0x612b0052,0xe9750003,0xddc90584}},	// [73f0] _juos_, hüle, شهاد, _odeš
  { {0xd378001c,0x3d0e0037,0x29070051,0x656f0347}},	//   šća_, ाकों_, õna_, msch
  { {0x656f0347,0xa2950024,0x7e550012,0x5d3a0009}},	//   lsch, _кані, لناص, _שתתא
  { {0x7d1a0005,0x628a000e,0xde950001,0x8aa70294}},	//   _akts, őfor, радњ, _срод
  { {0x656f0358,0x9e64002d,0x78a1000e,0xe7300003}},	//   nsch, свід, yelv, أصل_
  { {0x88bc0066,0xd838009b,0x656f294b,0xb97a0009}},	//   změr, ječo_, isch, _בנשי
  { {0x656f0052,0x612b0060,0xa2dc0011,0x25fc0011}},	//   hsch, rüld, _नवम्, _लेनी_
  { {0x2bf8000b,0x41b50003,0xc2450695,0x645c017b}},	//   טמון_, لمعر, шник, zbri
  { {0xa4870003,0x9c870003,0x656f0070,0x72b60009}},	//   _مجان, _مشاه, jsch, בִיב_
  { {0xd12e0003,0x612b000e,0xe0d60015,0x656f01e0}},	//   ومي_, lülb, ивы_, dsch
  { {0x316d0108,0xef19001e,0x62750003,0xa91d0027}},	//   ssez_, guļo_, _نهائ, tužb
  { {0x61260028,0x2d820051,0x7e6b002c,0x656f0832}},	//   rðla, tuke_, nagp, fsch
  { {0x95830047,0x7ae90f33,0x78a1000e,0x656f04a3}},	//   оляе, mhet, pelv, gsch
  { {0x2d82049d,0x7afb0010,0x88bc0066,0xf623002d}},	//   ruke_, liut, směr, ідро
  { {0xfaf600b3,0x660d0c60,0x78fa01b0,0x06760048}},	//   ачаю, _exak, _בפסו, _купя
  { {0x656f0052,0x645c0ad2,0x75460024,0x6b83294c}},	//   bsch, sbri, _книз, iung

  { {0x44320020,0x7866057b,0x6b830052,0x4420001a}},	// [7400] ̀y_, иказ, hung, ́i_
  { {0x6b8300c6,0x3d0f0011,0x290500b0,0x98560472}},	//   kung, िवों_, nnla_, рташ
  { {0x6b83039c,0x747b000b,0x4444000e,0x62990bb2}},	//   jung, _בניג, _ig_, _obwo
  { {0x6b830a69,0xa2a70011,0x6a960024,0xed5a05d4}},	//   dung, _फ़ोल्, _троє, вод_
  { {0x7ceb0052,0x61ed0002,0x6f090027,0x7ae9000e}},	//   _dürf, czal, _djec, dhet
  { {0x612b003a,0x7ae9000e,0x6f090e2f,0x03b60003}},	//   tüle, ehet, _ejec, لإعد
  { {0x27270005,0x7afb00c1,0x6b831858,0xadf20011}},	//   sõna_, fiut, gung, _आइकन_
  { {0x7c28009b,0x7ae9028e,0x612b294d,0x444402fb}},	//   _vzdr, ghet, rüle, _lg_
  { {0x0906002d,0xd9f80037,0xe61a0024,0xc05a0024}},	//   ичом, ूपित_, _рда_, кін_
  { {0x44440733,0x6b9e0119,0xa3b90037,0x6b831441}},	//   _ng_, _oppg, चिम_, bung
  { {0xe727002d,0x7d1801bd,0x7ac60063,0x351b0009}},	//   иємн, movs, _всле, _יומנ
  { {0x656f0358,0x39460010,0x7ae9294e,0xa2d30012}},	//   tsch, _tuos_, chet, _ويلت
  { {0xd9540003,0xca97000b,0x28c90037,0x656f0052}},	//   _انتخ, _כדאי_, रामि, usch
  { {0x656f1bba,0xdb0d004a,0x22620002,0xa99b0009}},	//   rsch, äköi, ńską_, _סבור
  { {0x7f84000a,0x67220010,0x326705fb,0x656f294f}},	//   _العن, kloj, итав, ssch
  { {0x403b000b,0x083b000b,0xd258069b,0xf2c4002d}},	//   _בגוג, _בעול, ицу_, осун
  { {0x90990014,0x8d950012,0xb9250012,0x6b830032}},	// [7410] лват_, _الخش, مفري, zung
  { {0x261a0037,0x7ae9000e,0xdced0027,0xf9570009}},	//   _बड़ी_, zhet, _kvač, יסמת_
  { {0x7e6b0101,0xba3b2950,0xd1170009,0xf7730012}},	//   tagp, _païs, סקבה_, تاذ_
  { {0xa3d00037,0x7ceb0052,0xb5fb0018,0xbcfb0031}},	//   _वॅट_, _bürg, mbáb, csér
  { {0x444400c6,0x612b0031,0x6ee60031,0x6b832951}},	//   _yg_, rülb, _jóba, wung
  { {0x7d18009b,0xd7e60012,0xb4e10011,0x84580048}},	//   govs, _فك_, दसे_, арът_
  { {0x7e6b0101,0x7ae92952,0xbcfb0061,0xee870015}},	//   pagp, thet, nséq, _вызо
  { {0x6f1b0027,0x6b832953,0x9f050012,0x7ceb0032}},	//   _ukuc, rung, _اورو, _hürd
  { {0xdce901bd,0x6b832954,0x7ceb0060,0x7ae92955}},	//   _uveď, sung, _kürd, rhet
  { {0x64450020,0x70c90001,0x6b832956,0x7ae92957}},	//   _nghi, угог_, pung, shet
  { {0x6d41002c,0x7e692846,0xe73a035c,0x1ec60012}},	//   _iila, _keep, лео_, مقدّ
  { {0x67170037,0xe5a60014,0x6d412958,0xaab40012}},	//   तविक_, бими, _hila, _وإنش
  { {0x6d4b0108,0x6d410a60,0x63bf0034,0x6eba0009}},	//   _égal, _kila, łynę, אזרח
  { {0xdff90044,0x3a36000b,0x62890051,0x98e50012}},	//   ्पाद_, _פרסם_, lgeo, _دكتو
  { {0xd3b50047,0x67550003,0x60c30033,0x6aa40052}},	//   ость, _اختر, _innm, teif
  { {0x44440002,0x23090003,0x9e6606a5,0x0e660001}},	//   _wg_, لتقي_, _увид, _укин
  { {0xc3320093,0x80c40037,0x6aa402dc,0xab270686}},	// [7420] לול_, राले, reif, сота_
  { {0xb4e60044,0x6d4113b9,0xc9850003,0xdb150029}},	//   _पते_, _nila, تشفي, ľbác
  { {0x6b9e1cfc,0xe3b8003a,0x25fc0011,0xd6d90034}},	//   _uppg, _ayın_, _लेती_, _siła_
  { {0x6d41002c,0x6722008e,0x2bbd0011,0x7ceb005e}},	//   _aila, uloj, ्मना, _pürg
  { {0x7ce60065,0xa5960014,0x3f8500b6,0x6d411738}},	//   _aðra, срещ, hulu_, _bila
  { {0xdcb10020,0xb5fb0066,0x7dc50012,0xdb070097}},	//   _cả_, lbác, تتمك, ðlög
  { {0x6d4100c6,0xcec30066,0xbb3a0009,0xe3af0012}},	//   _dila, áří_, ְעִי, فري_
  { {0xa3b90044,0xa3c90044,0x39900054,0x71780001}},	//   चित_, _ऊपर_, tàs_, абир_
  { {0x52730001,0xdb1f000e,0xab630002,0x7c960055}},	//   чују, ívás, ążan, _грец
  { {0xd8f8002d,0x19a70014,0x39900054,0x7ceb003a}},	//   рної_, стъп_, ràs_, _küre
  { {0x74160012,0x9f350024,0x64a30048,0x3eb20060}},	//   _اوضا, жені, _хаха, _bayt_
  { {0xf1bf000e,0xa91d0027,0xceeb0012,0x66ca0009}},	//   _szám_, ruža, اردن_, אמֹ֔
  { {0x2fc7008a,0x87170009,0xda650012,0xaa7b0097}},	//   ̣ng_, מקטע_, _ذاني, _flýj
  { {0x44270020,0xa2d40037,0x42370009,0xcc540048}},	//   _ơn_, यॉर्, _הנדל_, звръ
  { {0xb097000b,0x2378000b,0x5f730003,0xe0fb01b0}},	//   _הדוח_, יָּמ, _فاير, _גלגל
  { {0x7ceb003a,0x6ee60097,0x8f5700af,0x63ba0aaa}},	//   _sürd, _tóba, _פסחא_, ætna
  { {0x3ea600e6,0xa3ce0011,0xc0470012,0x31580012}},	// [7430] deot_, _शपथ_, مخاو, مجلة_
  { {0x6e2d001c,0x28c90037,0xfc470066,0x7e690574}},	//   _izab, राधि, číst_, _seep
  { {0x7ae3007d,0xf7700003,0x6d5d0051,0xead5002d}},	//   _înto, فان_, lpsa, _донь
  { {0x7ceb2959,0xdb1f004a,0x52a70003,0x6d5d0a22}},	//   _würd, äväk, _اصدق, opsa
  { {0xb5fd007a,0x7ceb003a,0x6f190002,0x16a60024}},	//   _iešk, _türd, rowc, івши_
  { {0x7aed000f,0xa509004c,0xbca50012,0xc0cb004c}},	//   lhat, јека_, زمبي, _суме_
  { {0xd52d001a,0xad1c000b,0x7e69005e,0x62890227}},	//   _mừn, אוגר, _teep, tgeo
  { {0x6d4100c6,0xce940014,0x78830031,0x7aed295a}},	//   _wila, _насъ, kívü, nhat
  { {0x44240020,0x6d410006,0xdcb10020,0x6c750001}},	//   ́m_, _tila, _tả_, _млађ
  { {0x4f950511,0xb1160012,0x10a519cd,0x99320012}},	//   орму, يقيا_, цион, وفيت
  { {0x628f00c1,0xa6ca0ac5,0x1eca0ac5,0x04c80003}},	//   _occo, ална_, ални_, _دولي_
  { {0xa91d095d,0x3f8504fe,0xc4c90009,0x7d1e005e}},	//   drže, rulu_, _בג_, _skps
  { {0x7aed000f,0x2732001a,0x04b60223,0xb0f50012}},	//   dhat, háng_, освя, _وأتش
  { {0x25a0003a,0x628f295b,0xde030024,0x31560012}},	//   çili_, _acco, єпри, _بلوج_
  { {0x6d5d0006,0xd52d001a,0x7fd5002d,0x443e008e}},	//   apsa, _dừn, _філі, ät_
  { {0x7aed000f,0x0d860015,0x0326002d,0xbf360012}},	//   ghat, _длин, ідан, _برتغ
  { {0x7ceb00a2,0x2ca7295c,0x291a013a,0xe8fa15f5}},	// [7440] _süre, kend_, topa_, ала_
  { {0xe0860003,0xed590066,0xddc0009b,0x6ab60037}},	//   تجري, íže_, _nemš, _अफ्र
  { {0x232a007c,0xab2a007c,0x7aed000e,0x464a06bd}},	//   _вони_, _вона_, bhat, азен_
  { {0xe5c60015,0x7d1c235a,0x8f9a0009,0x61300032}},	//   жско, lors, ייעי, wäld
  { {0xc27b000b,0x7ae40010,0xd7370009,0x7d1c17c9}},	//   _דרכי, mkit, קטנת_, oors
  { {0x6ca30014,0xbca40012,0x7ceb295d,0x55bb0009}},	//   дръж, سمعي, _türe, ימנו
  { {0x28cd0037,0xe749001a,0x2480003a,0x7ae403ec}},	//   ़ानि, _sẵn_, ğim_, okit
  { {0x7ae4295e,0x248000a2,0xe0430024,0xbb170012}},	//   nkit, şim_, _інти, يزيا_
  { {0xc3330093,0x6e930003,0x7ae40010,0x60f80014}},	//   ווה_, _تلقا, ikit, йния_
  { {0x7aed000f,0x20070002,0xd1300012,0xa99b0009}},	//   zhat, źnie_, عمد_, סביר
  { {0x7ae4004a,0x4c060003,0x6e2d0fe5,0xc0530009}},	//   kkit, _بِال, _szab, וזת_
  { {0x7996003e,0x41e6002d,0x6286000e,0xd6c60012}},	//   ktyw, _міла, ókod, رق_
  { {0xd6270003,0x6a9b0009,0xd3370009,0x7e2b0024}},	//   تعدي, _כשאנ, _וראה_, ріна_
  { {0x99fb000b,0x6d5d0028,0xbcfb0025,0xa91d0030}},	//   _דפדפ, rpsa, xpéd, trže
  { {0x7aed000f,0xa2ce0011,0xd52d0081,0xdb1a295f}},	//   that, थाप्, _cứn, _arté
  { {0xd838077d,0x25b00006,0x7aed0051,0x7d1c000e}},	//   ječi_, ällä_, uhat, aors
  { {0xd52d001a,0xb5fd0066,0x7aed0ba9,0xf1940015}},	// [7450] _từn, _vešk, rhat, мить
  { {0xa2a10037,0x7aed000e,0x7ae4002c,0x7d1c00c1}},	//   _कॉन्, shat, akit, cors
  { {0xb4e70037,0xb5fd2960,0x2ca72961,0x33ab0048}},	//   पसी_, _tešk, vend_, _тъпо_
  { {0x15ff0037,0xb4b30037,0xec36000b,0x6f1d2962}},	//   _उधार_, _जोड़_, _מאתר_, nosc
  { {0x7cf0006f,0xa3b90037,0x6d4522fc,0x63a101e9}},	//   _därf, चिव_, _kiha, _spln
  { {0x11da0093,0xdfc60003,0x7d760003,0x89da000b}},	//   _החשב, _كي_, أمور_, _החשי
  { {0xcc7c0093,0xa2e50015,0x044200de,0xab630002}},	//   שְׂר, зойд, нешн, ążon
  { {0x20c90037,0x6d451738,0x6595024d,0x05cb0011}},	//   रावध, _liha, _набу, ामाब
  { {0xceb20093,0x7d1c00a2,0x2d580024,0xdd580055}},	//   _אין_, yors, _мить_, _матч_
  { {0x8bb70012,0xf9920009,0x60e9004c,0x612b0031}},	//   _وإضا, ערי_, смом_, züln
  { {0x7ae4007a,0x80cd0044,0x16010011,0xef1a0024}},	//   ykit, ताबे, _लेबर_, ймо_
  { {0xd1380911,0x13b60009,0x79960034,0x7b2c0032}},	//   amą_, _מהעל_, ytyw, eßun
  { {0x7cf00005,0x63be024e,0x69dd005e,0x7aeb0035}},	//   _järg, _srpn, äsed, _ilgt
  { {0x7cf00005,0x63510039,0xf1b2000b,0x2c570066}},	//   _märg, _jāno, _נסו_, vědí_
  { {0x6d4500c6,0x929d0002,0xcc870015,0xb5fd2963}},	//   _diha, woły, ябре_, _deši
  { {0x7ae40010,0x7d1c2964,0x3f7a0009,0xdb010032}},	//   ukit, sors, _האקס, _erlö
  { {0x612b000f,0x7ae42965,0xcb120009,0x929d0034}},	// [7460] rüln, rkit, גלן_, ciłe
  { {0x15fb0093,0xf617000b,0x7ae42966,0x45fb0009}},	//   _להפע, _מחפש_, skit, _להפג
  { {0x6d5b0149,0xc2c60003,0x2d8f006f,0x7ae40b02}},	//   _atua, _فيدي, _äger_, pkit
  { {0xf1bf0065,0x614602e2,0x2fc7006f,0xee3a17db}},	//   _frá_, _нема, ånga_, бне_
  { {0xd138007a,0xe4e6002d,0xb2bb0009,0xcad70009}},	//   ymą_, зійн, _המכר, _זוכת_
  { {0x44250013,0xd838009b,0x7aeb2967,0xbcfb0025}},	//   _byl_, seči_, _algt, ppée
  { {0xab3808b0,0xdcb1001a,0xd52d001a,0x28c90011}},	//   опку_, ổi_, _hữn, रारि
  { {0x6aa90070,0x7cf02968,0xbc0d000b,0xd2500012}},	//   geef, _färg, יהוָ, خنة_
  { {0x6b9b004b,0x11d80012,0x612b2425,0x7e6d2969}},	//   ăugi, زودة_, küll, _reap
  { {0x60f8007c,0x4778002d,0x7e7b0034,0xb9db0009}},	//   іння_, обою_, _zdup, מחפש
  { {0x3f78001e,0xd13809bb,0xb5fd02a1,0x7cef0623}},	//   nču_, rmą_, _reši, _sørg
  { {0xd1380073,0x7cf00248,0x6f02296a,0xb5fd296b}},	//   smą_, _lärd, nioc, _seši
  { {0x6d4500c6,0xd24f000a,0x612b0052,0x81d30024}},	//   _piha, _إنه_, füll, _поїх
  { {0xd12f007c,0x3157000b,0xd23b000b,0x7e6d002a}},	//   _їх_, _ציון_, _הגדל, _weap
  { {0x78b5048b,0x309b000b,0x50b70003,0xb09b0009}},	//   _razv, _השומ, _ردود_, _היור
  { {0x5398002d,0x7c2501bd,0x291e296c,0x2d9f0025}},	//   явся_, _vyhr, lota_, çues_
  { {0xdb24000f,0x63bc009b,0x867c000b,0xddc6001e}},	// [7470] írás, avrn, _הרחו, pakš
  { {0x63ad003e,0x3cf80037,0x7cef0058,0x04670015}},	//   łani, ्चों_, _køre, _этим
  { {0x56950015,0x2d99000e,0xc917000b,0x4c9a0009}},	//   дает, ltse_, לחמת_, _ובתו
  { {0x3eb90058,0x7afd0052,0x9f4c000e,0xa6c90003}},	//   ndst_, _umst, álás_, توصل_
  { {0x83fc001c,0x7cf0006f,0x3f78001e,0xe81d0037}},	//   _među, _färd, aču_, _बुरा_
  { {0x2d9900ff,0x69d60060,0x62870073,0x7c2e0031}},	//   itse_, _üyey, ėjom, őirő
  { {0xeb990015,0xe7840001,0x76650003,0x612b0060}},	//   ций_, _путо, _يُسم, nülm
  { {0xa91d296d,0xc7b20009,0x2d99005e,0x61300248}},	//   drža, _בבל_, ktse_, mäla
  { {0xed580012,0x6ed10011,0x91b00081,0x2d990031}},	//   _فشلت_, धानु, _đãi_, jtse_
  { {0xddc40010,0x8f750024,0xd378001b,0x2d8b296e}},	//   _neiš, мумі, šći_, duce_
  { {0x7cf00005,0x27350163,0x92590015,0x395f000d}},	//   _järe, gång_, _дает_, spus_
  { {0xa2e4002d,0x98a2001e,0xfb380003,0x63050012}},	//   _поєд, ēkā_, _فأنت_, _توصل
  { {0xba740003,0x02440012,0xa2cc0011,0xdce9001b}},	//   _سانت, _كَمَ, हास्, _cveć
  { {0x58d4005c,0xc172000b,0xdb240066,0x7cef0623}},	//   _почт, _יחד_, ěsíc, _føre
  { {0xdfce0003,0x7cef0040,0xeb930009,0xe81d0011}},	//   _نيو_, _gøre, ךָּ_, _बुला_
  { {0x39470065,0x1fc90037,0x99e3014a,0x2d8b0066}},	//   _hins_, िमीड, žňuj, buce_
  { {0x39460014,0xd5af0012,0x453616a3,0x3b070048}},	// [7480] днаг, _نفي_, _охот, фето_
  { {0x49990015,0xb606009b,0x26c9001b,0x7cf00032}},	//   ятся_, rošč, _znao_, _bäre
  { {0x7cf00163,0x4f7a0015,0xca4a0012,0xdc3c0064}},	//   _värd, ющая_, _ولده_, _páči
  { {0xc6a30046,0xeda6002d,0x7cf0006f,0x4ea30001}},	//   врши, дшко, _däre, врша
  { {0xee090009,0x290c03ce,0xa91d001b,0x60e90031}},	//   ּמוֹ_, ynda_, ružj, ásmó
  { {0xcdf70009,0xa3e50011,0x6f02296f,0x20070034}},	//   ומני_, बैक_, sioc, źnia_
  { {0x612b0005,0x68e300a2,0xe2080002,0x7cf0005e}},	//   külj, önde, _wróć_, _kärb
  { {0x41e6002d,0x27e70262,0x291e0034,0x84170009}},	//   діоа, ønne_, wota_, וקצב_
  { {0x7e970003,0x7d032970,0x291e2488,0x2d540038}},	//   _تنقر_, bins, tota_, _näe_
  { {0x64360003,0x54360003,0x16040037,0xc057002d}},	//   _قراء, _قرار, _शेयर_, мію_
  { {0x394703eb,0x311f0037,0xddc40010,0x290c0028}},	//   _dins_, भवतः_, _reiš, rnda_
  { {0x39470065,0xfbd3000b,0xd57c0024,0x27350248}},	//   _eins_, _שתף_, _вiдк, rång_
  { {0x7bda004a,0x39472971,0x7ae3000d,0x3eab2972}},	//   ätun, _fins_, _înti, rect_
  { {0x612b0060,0x2d992973,0x3eab14e0,0x67242974}},	//   tülm, rtse_, sect_, _ekij
  { {0x6d480005,0x98a30001,0x7cf0006f,0x01370009}},	//   _mida, _рије, _bärb, _חרגת_
  { {0x41e7002d,0x612b003a,0xa3b60011,0xef190035}},	//   міза, rülm, _छनन_, tuļu_
  { {0x44290020,0xb5fd0013,0xda0e0037,0x05790012}},	// [7490] ́a_, _ješt, ापित_, _عمدة_
  { {0x60b50012,0x3f8c0030,0x7d030227,0x5a340ce1}},	//   عمائ, oudu_, xins, тнут
  { {0xdb1a02d1,0x3f8c0027,0x7d032975,0x7cf00032}},	//   _artí, nudu_, vins, _färb
  { {0x7cf0004a,0x6d482976,0x9db9003c,0xa7fc0060}},	//   _väre, _aida, зыку_, ybın
  { {0x6d4800c6,0x61f60002,0x7cf00052,0x4a5a0009}},	//   _bida, czyl, _wäre, _מדרו
  { {0x6d480149,0x98c40015,0xdddd0034,0x6d4b0025}},	//   _cida, _иссл, obsł, _égau
  { {0xaa7b0028,0xa3c10037,0x6d482570,0x2735006f}},	//   _flýt, ूमि_, _dida, tånd_
  { {0x645a014d,0x764d0101,0xdb05031d,0x69c22977}},	//   _efti, _ngay, _erhö, _broe
  { {0xc9a60047,0x80b60037,0x3179000e,0x6d482978}},	//   евые_, _उसमे, ész_, _fida
  { {0xddc4007d,0x27320066,0xe8f604b3,0xe0d10003}},	//   _afiş, dána_, ель_, ازة_
  { {0x2f390009,0xb9070011,0x78b800b8,0x39471f5f}},	//   ּגָד, _यक_, _davv, _vins_
  { {0xbbbd0011,0x39470132,0x7ceb2979,0x1dcb0011}},	//   ्मीक, _wins_, _büro, ामंत
  { {0xc3320093,0x69c200bd,0xe1ee0001,0x672b0033}},	//   _עוד_, _groe, _сг_, ilgj
  { {0x399909ec,0x3f8c0030,0x94d60012,0x89da0009}},	//   mès_, budu_, ريزش, _מחני
  { {0x03a30015,0x46a60024,0xaad30011,0x3cf10011}},	//   лиро, _зайв, थापक, ीफ़े_
  { {0xfbd2000b,0x61e4004a,0x80cd0011,0x6ffa0009}},	//   נתן_, tyil, तावे, _מהצפ
  { {0x2718009b,0x39990f4c,0x7cf0005e,0x08c606bd}},	// [74a0] nčne_, nès_, _värb, нбан
  { {0x3c66002d,0xb5f7000b,0x4223002d,0x61f60120}},	//   _яког, _נציג_, удув, rzyl
  { {0xd00f0003,0xd12f0003,0xb8950014,0x40950014}},	//   ملك_, حمل_, ъртъ, ъртт
  { {0x6d481d6f,0xfe720003,0x6b7b0009,0x6aad297a}},	//   _sida, ادا_, _צרכנ, ceaf
  { {0x867b000b,0x6d48093d,0x86230109,0xc3330009}},	//   פרסו, _pida, льше, _תור_
  { {0xd3780027,0xb5fd0029,0xa91d24ad,0xb4ea0011}},	//   šću_, _rešt, držo, मसे_
  { {0x27320066,0x29050fa8,0xa3d4022a,0x6d48297b}},	//   zána_, dila_, тойч, _vida
  { {0x8f9b0093,0xfbd3000b,0xd00f0003,0x6d4811f7}},	//   _מילי, רתה_, _الف_, _wida
  { {0x6d4800ec,0x7c280002,0x6e930012,0x8b3b0009}},	//   _tida, _wydr, _حلقا, התקצ
  { {0x27320013,0x69c20070,0x6d481835,0x69fb0009}},	//   vána_, _vroe, _uida, פליק
  { {0x28d20037,0x889b0009,0xe5050012,0x7bda008e}},	//   ताबि, הביי, _شبكي, ätul
  { {0x69c2297c,0x7ae9288e,0x3f822410,0x7ceb005e}},	//   _troe, cket, čku_, _püro
  { {0x916d008a,0x95cb0046,0x3999297d,0x7ce60028}},	//   _một_, чуна_, cès_, _aðri
  { {0x81b7000b,0x27321adb,0x47d40012,0xa91d0ca4}},	//   _נהוג_, rána_, _ليتر, yuži
  { {0xd7ef1154,0x672b0028,0x9f4701bd,0xdcef004b}},	//   _су_, ylgj, šné_, escă
  { {0x9f97000b,0x7f830003,0x5ae70012,0xe60500ae}},	//   _נדחה_, _إلين, رثأف, _لِعَ
  { {0x02e101e1,0x6aad002a,0x612b13f9,0xdcf60064}},	// [74b0] _नवीन, reaf, lüli, _zvyč
  { {0xa91d001b,0x8a440012,0xec6b003c,0xcdf80009}},	//   tuži, ائِم, _эрик_, _רמזי_
  { {0x61300006,0x5f950014,0x2d800029,0x6c56000b}},	//   mäll, тиет, šiel_, _ביתא_
  { {0x916d001a,0xb6020066,0xa91d017b,0xa6ab0012}},	//   _cột_, _čárk, ruži, ثائق_
  { {0xe7300003,0x2a76000b,0xe44e0048,0x7cf00248}},	//   حصل_, _בערך_, иж_, _hära
  { {0xf4840046,0x2a6900b6,0xed58000b,0xd6180012}},	//   гућн, lbab_, עבור_, رتنا_
  { {0x23b20003,0x61140014,0x7ae9006e,0x29050c81}},	//   لموس, _сдру, tket, vila_
  { {0x63ba0058,0xb5fb0030,0x29050034,0x63510035}},	//   ætni, rbáj, wila_, _jāni
  { {0x613002fe,0x7cf00248,0x7ae3004b,0xb9920012}},	//   käll, _lära, _întu, لليب
  { {0x39990207,0x6130004a,0x3eaf2653,0xf994000b}},	//   rès_, jäll, legt_, ארץ_
  { {0x12e7007c,0x2d8f001c,0x8ae7002d,0x27270051}},	//   _підг, luge_, _підл, sõnu_
  { {0xd356000b,0x73090012,0xb8e80011,0x612b0031}},	//   _סיני_, _تقصف_, _लो_, sülh
  { {0xd7f8007d,0x7ceb003a,0xc8f50014,0x613018c2}},	//   ază_, _türl, _издъ, fäll
  { {0x7d0702a1,0x2a6900b6,0x7cf00248,0x7c240f75}},	//   gijs, ebab_, _bära, şire
  { {0xb4b20044,0xb8f50037,0xe29a002d,0xfc030109}},	//   _ऐसी_, हा_, мав_, апро
  { {0x2ed00037,0x7cf00248,0x7a380097,0x7c2c0031}},	//   _सचेत, _dära, _nútí, _önrő
  { {0xee3a0014,0xdddb000d,0x9c7c009b,0x43430447}},	// [74c0] _юни_, _reuş, _hoče, ретв
  { {0xb95b0020,0x28d20037,0x7d070133,0xf0630001}},	//   _trìn, साधि, cijs, икуп
  { {0x8f760024,0x9cd70009,0x27320030,0x6f040034}},	//   тузі, _סוטה_, náno_, _kmic
  { {0x2d80001e,0x79890002,0x6d4b0061,0x69c40010}},	//   šiem_, krew, _égar, _šiem
  { {0x2c060037,0x9c7c009b,0x6b83006f,0xd657000b}},	//   _हेतू_, _loče, _ångr, דינת_
  { {0xed570001,0x27390029,0x3dfb0009,0xa7860012}},	//   њој_, méne_, ולנד, _لشرو
  { {0x1b770003,0x3cfa0037,0xccf30009,0x69dd297e}},	//   نصية_, _उतने_, שכו_, äsen
  { {0x27320066,0xdb0f000e,0x7d07017b,0xf4130009}},	//   dáno_, ődöt, zijs, יפו_
  { {0xe572000a,0x7ceb003a,0x645c0227,0xe3b80060}},	//   _خطأ_, _sürm, kcri, _ayıt_
  { {0x30a3002d,0x6f04210c,0x98c60024,0xc1730009}},	//   арюв, _amic, тсил, סחת_
  { {0x61300006,0xf0930009,0xd0100012,0x88770009}},	//   väll, בנת_, صلح_, כתיב_
  { {0x0f7b000b,0x877b000b,0xcf93000b,0x4bfb000b}},	//   ורטל, ואטי, סטר_, _קלאס
  { {0x61300163,0xceb3000b,0x6d400010,0xa2f7000b}},	//   täll, ביר_, įman, _במאה_
  { {0x7cf00005,0x2716001e,0x612b000e,0x6018027f}},	//   _pära, rāna_, lülv, _поля_
  { {0x0137000b,0xada3119d,0xe8d70009,0xe4510009}},	//   _שרות_, _zaúč, _בוגר_, מֶן_
  { {0x61300006,0x3264002d,0x7bc500eb,0x7cf0005e}},	//   säll, итув, _vrhu, _vära
  { {0xf9900003,0x78bc1371,0x7d090025,0x2369001b}},	// [74d0] قبل_, _barv, éess, ćaji_
  { {0x3eaf0032,0x690b0034,0x7cf00248,0x78bc297f}},	//   wegt_, dżec, _härn, _carv
  { {0x8cd00037,0xdfa70003,0xf7700012,0x7cef0040}},	//   दारो, ضحاي, قان_, _børn
  { {0x98b9001e,0x7cf0006f,0x9694002d,0x9757000b}},	//   _pusē_, _järn, иріш, דיאו_
  { {0x78bc0058,0x27320066,0xa2b80011,0x7bd8004b}},	//   _farv, záno_, ्यन्, ăbuş
  { {0xb4bd0011,0x3e710081,0xa5240024,0x2d8f2980}},	//   इये_, ạt_, амід, ruge_
  { {0xeab10003,0xc8780060,0x67d40955,0x7cf401a0}},	//   معة_, dağ_, _кору, _bàrb
  { {0x27320013,0x5c38000b,0x2489003a,0x92b50003}},	//   váno_, כרון_, şam_, احثا
  { {0x6ca70003,0x356b0024,0x3f9e0097,0x7aed2981}},	//   _لصال, _іран_, ettu_, ikat
  { {0xb4b20044,0x239b0012,0x2ee00025,0x9c7c2982}},	//   _ऐसे_, _يخضع_, _soif_, _poče
  { {0x6e36003e,0xc5e9000b,0x7aed22a0,0x76490073}},	//   _szyb, _צד_, kkat, ūlyč
  { {0x7c250052,0x5215002d,0x7cf401a0,0x271809df}},	//   ühru, _йдет, _vàre, očna_
  { {0x2718009b,0xf9850048,0x98a50e98,0x29100097}},	//   nčna_, _сгло, _биле, ðlað_
  { {0xdc430030,0x7aed2107,0xb97a0009,0x9c7c0bb7}},	//   _léči, ekat, _טרנז, _toče
  { {0x01360093,0x04570003,0x711a0009,0xc0580024}},	//   _גרסת_, الفة_, _אוספ, _річ_
  { {0x7aed0175,0x7cf0006f,0xfaf5002d,0x3f8a0018}},	//   gkat, _gärn, ачую, ábue_
  { {0x61e91daf,0x20b70037,0xddcf000d,0x78bc2983}},	// [74e0] nyel, _असाध, racţ, _parv
  { {0x4a43002d,0x67290029,0xb5fd0029,0x7aed0532}},	//   снув, _akej, _rešp, akat
  { {0x60dc0052,0xdc9b0009,0x90360024,0x1cb70009}},	//   örmi, _אייל, ухач, _גליל_
  { {0x2fd80051,0x7aed006f,0xe57a0015,0x28d20037}},	//   ärgi_, ckat, езд_, साहि
  { {0x78bc015e,0xc27b000b,0x6286000e,0xfce601d4}},	//   _tarv, _ארכי, ókom, лодо
  { {0x7ae3007d,0x3f9e0065,0x412a002d,0x7bde004a}},	//   _într, yttu_, _чого_, äpuo
  { {0x7469002d,0xf7670012,0xec690024,0xe3b80060}},	//   трів_, _دا_, трік_, _ayır_
  { {0xaba70012,0xa3ac0011,0x61fb0032,0x3af10031}},	//   اهيم_, _गहन_, fzul, _pápa_
  { {0xdce4003e,0x61302984,0x61e9000e,0x6ed80011}},	//   _zwią, välj, gyel, यानु
  { {0xc19b000b,0x81b70009,0xa99b0009,0xbc6a0012}},	//   עשיי, נהיג_, עביר, _أمان_
  { {0xf093000b,0x7cf02985,0x98c30015,0x33660001}},	//   זנת_, _pärn, ссыл, _свег
  { {0x69c4007a,0x63ba003e,0x8c1b000b,0x7ceb2986}},	//   kvie, _istn, _אובי, _türk
  { {0xceb3000b,0x91e6002d,0x62870010,0x9aeb01b0}},	//   זיר_, _щоде, ėjot, _רַבִ
  { {0x6d56003a,0x6130006f,0x7a370024,0x644303a7}},	//   _duya, sälj, _спір_, _únik
  { {0x69c4001e,0x7ae20872,0x7aed2987,0x8aa70024}},	//   evie, _koot, tkat, лрад
  { {0x20070002,0x7cf0006f,0x75d50012,0x28d20011}},	//   źnik_, _härl, _نيبا, तावि
  { {0x9f470013,0x3c12000f,0x19950014,0x90990014}},	// [74f0] ání_, tővé_, разя, кват_
  { {0x7aed2988,0x7ae21326,0x7bc82989,0xb0cd0011}},	//   skat, _loot, _ordu, ़ाएग
  { {0x7c290052,0x9f470066,0xcc760009,0xb8dd0011}},	//   ßerd, šní_, _דעתה_, _आस_
  { {0xf7700003,0xef0e002d,0xb8ec0037,0x7c290060}},	//   سام_, ім_, _शो_, ğerd
  { {0x69c4001a,0x427a000b,0x527a0009,0xb9e40024}},	//   cvie, _בארג, _שנשא, _ліри
  { {0x612b0052,0xbd450003,0x6b65003c,0xdf770012}},	//   gült, جنتي, акка, _مدرب
  { {0x2bc50037,0x3ea900b6,0x4c920001,0xd91a0009}},	//   विधा, _obat_, цијс, _יושל
  { {0x89d50012,0xff070024,0x46580012,0xa2e50c6c}},	//   لتخط, _сягн, _مؤكد_, роид
  { {0xa2a10037,0x2d8b0066,0x7bc80032,0x61300248}},	//   क्ष्, _íce_, _erdu, fälh
  { {0xe9a80012,0x60e6003c,0x61fb07bc,0xa855004c}},	//   ادين_, имым_, rzul, штиј
  { {0x3dc901e5,0x8cd90037,0x3ebf001e,0x69c4189c}},	//   _araw_, मानो, _kaut_, zvie
  { {0x69c40603,0xfe46027f,0xed5a14bd,0x9f960009}},	//   yvie, инно, ком_, סדרה_
  { {0xdce200f1,0x23690027,0x6d260012,0xad260012}},	//   zpoč, ćaju_, لعسك, لرسو
  { {0x3ebf2954,0x3dc9262e,0x317f0060,0x272e0097}},	//   _laut_, _draw_, msuz_, rýni_
  { {0x28d20037,0x8c4601d4,0xed430024,0x044604ac}},	//   तारि, реве, інсп, ревн
  { {0xf1a90044,0x16010037,0x33930003,0x69c41609}},	//   _कहान, _लेकर_, تلفز, tvie
  { {0x26d20101,0xa91d0010,0x71650003,0x30560001}},	// [7500] _inyo_, erži, مالك, ађет
  { {0x7d7b0009,0x27390042,0xe8f70188,0x63b60034}},	//   _שניו, ména_, алу_, łyni
  { {0x6286000e,0x69c4298a,0x798d01ea,0x3ebf0032}},	//   ókok, svie, araw, _baut_
  { {0x7c290052,0x46a60048,0x3ebf004b,0x3af80031}},	//   ßere, радв, _caut_, _képe_
  { {0x28760047,0x26c00017,0xadfa0012,0x994a0012}},	//   _выбр, _maio_, خراط_, _للحل_
  { {0xed59119d,0x8cd90011,0x6da3004c,0xfbaa0024}},	//   íži_, मायो, циља, втий_
  { {0x3ebf0061,0x7cf0006f,0x3af80066,0x2ca7003a}},	//   _faut_, _närm, _lépe_, _önde_
  { {0x39a6002d,0xbab804f0,0x77bb000b,0x3878031d}},	//   ашов, угих_, _במלח, _herr_
  { {0xb5a90003,0xed5a002d,0xdcfb0027,0xfaf70009}},	//   _مالك_, _роз_, _zvuč, יצקי_
  { {0x26d20101,0x859b0009,0x54780009,0xc0510009}},	//   _anyo_, _בשמו, _תְּנ, ּ֖י_
  { {0x7ae20005,0x2718012e,0x68e305eb,0x0857000b}},	//   _toot, nčno_, _dond, יבים_
  { {0x3dc90002,0x6d4f0061,0x7cf0006f,0x370701b6}},	//   _praw_, _écar, _därm, рчов
  { {0x6f0303eb,0xae010321,0x26c50030,0x8f1000b5}},	//   ènci, _लेखन_, ělo_, нaтa_
  { {0x3e75001a,0x2bbd0037,0x68e3298b,0x248d0032}},	//   ất_, ्मचा, _gond, ßem_
  { {0xa93b0009,0x7cf0079b,0xead5003c,0x9cd70009}},	//   _שתופ, _kärj, бовь, סולה_
  { {0x8e85000a,0x68e300bd,0x7cf0015e,0x8c1b000b}},	//   _الظه, _zond, _järj, דולי
  { {0x4c950014,0x7e7d1fc3,0xd9990012,0x50670012}},	// [7510] _липс, masp, طنات_, لطاق
  { {0xd879000a,0x20670001,0xd1300012,0x2bb70011}},	//   امات_, рђав, ِمْ_, _आनला
  { {0xa054002d,0x7e550012,0x83190012,0x25ad298c}},	//   івці, مناص, _مقدر_, _spel_
  { {0x798d003e,0x2bbd0037,0xc7d70009,0x9f040012}},	//   praw, ्मघा, יובי_, يولو
  { {0xadbc002d,0x3ebf0061,0x929d0002,0xbb3a0009}},	//   кацi, _vaut_, siłk, _תערי
  { {0x3f83000e,0x9c7c298d,0xdb070097,0x195600af}},	//   ájuk_, _poča, ðlæg, _לבשל_
  { {0xf8b2000b,0x1368004c,0x69c60040,0x9b68004c}},	//   _משם_, ашњи_, æken, ашња_
  { {0x4c3c000b,0x32b90003,0xfbd00003,0x2d840066}},	//   כתוב, ادثة_, بته_, ámek_
  { {0x61ed298e,0xc6920009,0x26c00018,0x7e7d005e}},	//   nyal, _מאן_, _raio_, dasp
  { {0x3959008b,0xe8f60047,0x9f4e0066,0xa3d70011}},	//   _muss_, йлы_, ěním_, ामद_
  { {0xfbd0000a,0x63f40012,0x64b30011,0x0b780012}},	//   _يتم_, _وأمر, ंजीश, _نصنع_
  { {0x1efa000a,0xe3b00003,0x613d0061,0x68e3051c}},	//   اعدة_, _ترك_, dèle, _wond
  { {0xd2560093,0xa2560093,0x01650046,0xdce4003e}},	//   _השנה_, _הבנק_, _укло, _zwię
  { {0x69cb0052,0x64a60001,0xd7c90012,0x9d46003c}},	//   _irge, љава, _موته_, сегд
  { {0x7f850003,0x6f950003,0x93590024,0xf74605fb}},	//   _البن, _العض, ирту_, _леко
  { {0x87050012,0x7cf0008e,0x443a0030,0x61e20d6b}},	//   _وبيل, _kärk, _vzp_, äolo
  { {0xd5b10020,0xe0560003,0x4efb0009,0x7cf0019a}},	// [7520] ắc_, مخاب, _תהפו, _järk
  { {0x7cf01a7d,0xa8560001,0x27320066,0xa3d70037}},	//   _märk, стај, dáni_, ामा_
  { {0x9c7c142f,0x2d82298f,0xa3ba0012,0x38780097}},	//   _bočn, lske_, _صادر_, _verr_
  { {0x6e93000a,0xf729007c,0x4e960003,0xee7a0003}},	//   كلما, ацій_, إشار, اصات_
  { {0xb0b70011,0xa2b80011,0x7c3a0031,0xf1b60011}},	//   _असंग, ्यस्, _sztr, _अनइन
  { {0xb8f60003,0xa3cc0037,0x26c02990,0xed59001b}},	//   _اكسب, लिप_, žio_, _duž_
  { {0x6c830012,0x9f470042,0x9bc6003c,0x290c2991}},	//   سليم, šná_, сёлк, vida_
  { {0x6017000b,0xfbd3000b,0x7c3a0159,0xbf160012}},	//   _החלף_, לתו_, _vztr, _اورب
  { {0x2d82013a,0x60f8010c,0x865b0009,0x290c2992}},	//   jske_, иния_, _תדמי, tida_
  { {0x3ae70051,0x7e7d00b6,0xe5f70009,0x8d5b0009}},	//   _lõpp_, wasp, _הזמר_, _עכבי
  { {0x69cb008b,0xdeb50015,0x66b50015,0xe8380024}},	//   _erge, обны, обну, рпні_
  { {0xf837000b,0x7ae6003a,0x690b0002,0xc7f7002d}},	//   מנית_, _nokt, eżel, снює_
  { {0xeb140044,0xc5170012,0x80db0011,0xdd080064}},	//   तचीत_, مبست, नामे, _môžn
  { {0xa99b000b,0xc19b000b,0x555809e8,0x985c0035}},	//   _עבור, _עשוי, саря_, nāļi_
  { {0xa87b000b,0x89370009,0xdb1a0025,0x80cc0011}},	//   _גאור, _הרגע_, _asté, _सफ़े
  { {0x27390066,0x2f97000b,0x7d6b0024,0x2d760034}},	//   méno_, _הכהן_, _йшов_, kłe_
  { {0x315b0012,0x2d820031,0x9c7c2993,0x7ae62994}},	// [7530] اجرة_, cske_, _ročn, _dokt
  { {0x46a50037,0x4ddc000b,0x27320066,0x7cf0006f}},	//   ग्रह, _תחזו, váni_, _närh
  { {0xdfd10003,0x61ed0893,0xe7b50003,0xa857000b}},	//   بيا_, syal, تماد, ציאה_
  { {0x61ed00a2,0x6be80009,0x3e7d0073,0x9635028b}},	//   pyal, _הַשַ, kštų_, онец
  { {0x23a10002,0x85a70001,0x2d760002,0xc58b003c}},	//   wój_, сјед, głe_, ущее_
  { {0x27322995,0x4aa60011,0x690b0034,0xdd7c0009}},	//   ráni_, क्सव, ożem, נטול
  { {0x7ae6003a,0xdcfd001e,0x9c7c013a,0x2d760034}},	//   _yokt, lusē, _točn, ałe_
  { {0x6595002d,0x93f8000b,0xddc4001e,0x0ae90012}},	//   _мабу, מצוא_, _reiž, شرعي_
  { {0x4429003e,0x6f0f0a04,0xc8b5003c,0xe8f91a4e}},	//   ła_, dicc, осны, или_
  { {0xa3cc0037,0x9f850829,0x16b20011,0x2d8200eb}},	//   लिम_, огод, ज़्ब, vske_
  { {0xf0920093,0x6d41003a,0xa91d01e9,0xf7460d7c}},	//   וני_, _ihla, držt, жено
  { {0x7cf00006,0xdcfd001e,0x78820066,0x2f5401d4}},	//   _tärk, kusē, tíví, ятьс
  { {0x2385001e,0xf626002d,0x2d842996,0x7c2d0060}},	//   lēj_, ідго, éme_, şard
  { {0xa06902ca,0x6d5b004a,0xdbc70028,0xc0cb0001}},	//   _така_, _muua, töðv, _људе_
  { {0xab890009,0x6d5b005e,0x7a0b0035,0x69c9092c}},	//   יָּ֖, _luua, sētī, lvee
  { {0x6008000b,0xed5a0014,0xf26a005c,0x61300052}},	//   _לִפְ, _кои_, риал_, hält
  { {0x3d1a0037,0xdb050040,0xe9da0578,0xb5fb01e3}},	// [7540] _बदले_, _ophæ, шка_, lcán
  { {0xe0d72997,0x613008af,0xfc320012,0xd24f0012}},	//   ову_, jält, _يحد_, ئنك_
  { {0x09b60037,0xba760003,0x68e71396,0x7cf000e5}},	//   _अन्य, _واحت, _dojd, _näri
  { {0x27e70163,0x4c3b000b,0x501a000b,0x7ceb0d8b}},	//   änna_, _כתיב, בועו, _fürs
  { {0xf5b60003,0x613002f1,0x3dcd2998,0xef130009}},	//   تصاد, fält, _crew_, וּס_
  { {0xc5f3000b,0x75d30003,0x9c570001,0x3dcd002a}},	//   ודד_, بيها, ошћу_, _drew_
  { {0xbcfb0061,0x2d760034,0x9cdb0009,0x69c917c9}},	//   mpét, słe_, יקספ, evee
  { {0x60c300bd,0x7cf0006f,0xd6d20012,0xb7db0009}},	//   _aanm, _däri, _تقر_, _דקלי
  { {0x3dcd002a,0xaaa60037,0xa3b60011,0xf1bf0031}},	//   _grew_, क्षक, _छनक_, _száz_
  { {0x80d00044,0x9980007a,0xd8f8002d,0x6bd60003}},	//   _डोमे, _šių_, сної_, _وتار
  { {0xb4b60044,0x3cde0037,0xdfd00003,0xe0b7000b}},	//   ज़ी_, खाने_, ريح_, חליט_
  { {0xcf270012,0x74130012,0xb1e60012,0x2cb80227}},	//   ترخي, _توما, _وأشه, eerd_
  { {0x6b550010,0x25a62999,0xa3b40011,0xe3b80060}},	//   _išga, ntol_, फ़िक_, çın_
  { {0x4aa60037,0x2cb81e9d,0x7c2d0b71,0x9f4e0030}},	//   क्रव, gerd_, şare, ěnám_
  { {0xd7e6002d,0x26110011,0xc3340009,0x6f0f0a11}},	//   _філо, _देनी_, ֤וּ_, picc
  { {0xc3340009,0xda0c0011,0x26c50035,0x2f18003c}},	//   פוּ_, _सेहत_, ēlos_, _мощь_
  { {0x68e7012e,0x67ff000e,0x3eb91d2d,0x8d770012}},	// [7550] _pojd, _tájé, mest_, _باعا
  { {0x2d990005,0xa2cc0037,0x8b080066,0x3eb9299a}},	//   muse_, _दोस्, _pořá, lest_
  { {0x6569008b,0x2d990005,0x7e7b0061,0xb065004a}},	//   _steh, luse_, _peup, lkää
  { {0xf8b70037,0x95d90015,0x8e850012,0x41da0011}},	//   _अस्प, йдет_, سلته, बमास
  { {0x443e000f,0x2d990005,0xbdf80003,0xb065004a}},	//   _azt_, nuse_, يرها_, nkää
  { {0x7cf00005,0xcd98000b,0x3cde0037,0x7cf40054}},	//   _päri, קדות_, खाये_, _fàrm
  { {0xad1c000b,0x59c90037,0x3eb909de,0x62800132}},	//   בוגר, रिवर, kest_, famo
  { {0x61300006,0x66b40015,0xa3cc0037,0x7cf0004a}},	//   sält, _обсу, लित_, _väri
  { {0x443e000f,0xfc460065,0xf991000a,0x3eb900c8}},	//   _ezt_, _þínu_, ربة_, dest_
  { {0x2d991b6d,0x4805002d,0x6f0d003a,0xf5aa0066}},	//   duse_, зпов, _amac, ížeč_
  { {0x2cb80070,0xccf2000b,0x60c30027,0x2d990061}},	//   verd_, _רכב_, _vanm, euse_
  { {0xd5b1001a,0xdce4009b,0x4c3a000b,0x7cf00269}},	//   ắn_, _vtič, _התעב, _järv
  { {0xcb120093,0x2d990005,0x60c30054,0x2cb80070}},	//   _אלא_, guse_, _tanm, terd_
  { {0xb60601e9,0xa7fc0060,0x27320030,0xd83e0159}},	//   _ukáž, mcın, vánu_, ščam_
  { {0xdce40027,0x58f6000b,0xc4d20009,0x987a0009}},	//   _utič, _ממסע_, עגל_, _האצט
  { {0x3eb9007d,0x7cf00eca,0x61340054,0x2d99299b}},	//   cest_, _närv, vàli, buse_
  { {0xc332000b,0xa7fc003a,0xe717000b,0xd6eb000b}},	// [7560] תון_, ncın, _מחקר_, _הַיָ
  { {0x49990047,0x63ad0002,0x26c4299c,0x8c46057e}},	//   ются_, łany, _samo_, _непе
  { {0xc209000b,0x5477000b,0x628b0082,0x4abd0037}},	//   נה_, _מגיע_, _odgo, ्याव
  { {0xe73a0047,0x794d0002,0xcff6000b,0xe5c60015}},	//   щее_, _dźwi, הצעה_, зско
  { {0x2718012e,0x237f0027,0xbcfb0e6a,0x4a570009}},	//   nčni_, ćuje_, mpér, _משכל_
  { {0xd1320003,0x7ae4299d,0x3f850692,0x2bba0012}},	//   _أمس_, ljit, kslu_, ماعة_
  { {0x6602000e,0x26c40027,0x60231271,0xb9000011}},	//   szok, _tamo_, _здра, था_
  { {0x7af6007a,0x7ae40027,0x539b0009,0x70530012}},	//   nkyt, njit, ציפו, _أنفا
  { {0x7af60010,0xd7f8004b,0xc0ca004c,0x59cf0011}},	//   ikyt, rcăm_, буне_, _हज़ार
  { {0x2d990005,0x8dfb0009,0x3eb91262,0x7cfd0025}},	//   vuse_, _ההמת, west_, _père
  { {0x6f1d0164,0x645a0058,0x3eb9299e,0xdb1e0fc9}},	//   érco, _igti, test_, _espé
  { {0x2d990005,0x7bdb0093,0x3817000b,0xa3b50037}},	//   tuse_, _לקבו, לקים_, _चैट_
  { {0x2732000f,0x3eb9299f,0xbae30012,0x69dd03bd}},	//   vánt_, rest_, _سكوي, äset
  { {0x3eb90005,0x91bb000b,0x48e3022a,0x2d9929a0}},	//   sest_, _למדי, _почв, ruse_
  { {0x6e240149,0x2d990005,0x8fa30046,0x113b000b}},	//   _exib, suse_, _заје, _התגל
  { {0x78ba000f,0xf4080003,0x2d99000d,0x8037000b}},	//   letv, سيقى_, puse_, _מנוע_
  { {0x442d0002,0x672f0002,0xb9550014,0xed880073}},	// [7570] łe_, mocj, дващ, žųjų_
  { {0x78ba0058,0x51f80015,0xdb030029,0x98b80073}},	//   netv, чную_, rtné, _mirė_
  { {0x8fb9000a,0xdb030636,0x3f8706dd,0xaa590012}},	//   تهاء_, stné, énu_, _ولدا_
  { {0x6f1d0052,0xff040024,0xf7730009,0x644301a0}},	//   nnsc, нячн, תקף_, _úniq
  { {0xd1380010,0x6f1d0052,0x7cf00a50,0x388f0035}},	//   klą_, insc, _värv, tērē_
  { {0xe5700003,0x11da000b,0x89da0009,0x2fc60034}},	//   اطن_, _וחשב, _וחשי, łoga_
  { {0x68e30028,0x3cde0037,0x1ae50024,0xeab10012}},	//   öndu, खाते_, дойм, نعة_
  { {0x5f740012,0x1ddd0011,0xe2990048,0xd1380034}},	//   _سافر, ममात, цаи_, elą_
  { {0xceb20093,0xe9d90024,0x8cdd0011,0x6594004c}},	//   _בין_, іко_, पादो, _пату
  { {0x27180159,0x6f1d29a1,0x6e2d0034,0xa7650a36}},	//   včni_, ensc, żabs, мкод
  { {0x7bc1001c,0x26110037,0x7cf00051,0xdb010040}},	//   _uslu, _देती_, _märt, _oplø
  { {0xa7fc00a2,0x3f850065,0x7c2900a2,0xa3cc0044}},	//   mcıl, rslu_, ğerl, लिस_
  { {0x7cef0262,0xbd360048,0x443c0073,0x6abb00b8}},	//   _ført, дхвъ, _šv_, meuf
  { {0x3e7c0020,0x6130006f,0xf1bc0037,0xcd960009}},	//   ật_, jälp, ्टरन, ודשת_
  { {0xa7fc003a,0x03a301ec,0xe3a70012,0x270a0012}},	//   ncıl, киро, خر_, _وقتٍ_
  { {0x765b0020,0xff26002d,0x7cef0058,0x9c7c01bd}},	//   _nguy, _імпо, _kørs, _počk
  { {0x045a0003,0x7af603ec,0xe8ea0024,0x08c6064d}},	// [7580] _وجدت_, rkyt, омад_, мбан
  { {0xbcfb0061,0x3f9a0042,0x7af629a2,0x61eb0b77}},	//   spér, tupu_, skyt, ägla
  { {0xf9890093,0xd12f0012,0x6ea50011,0xeccb0011}},	//   שר_, جمل_, _कामु, ायरफ
  { {0xf8a9000b,0x9c7c017b,0x9eda0012,0xdb0a0060}},	//   יש_, _točk, غذاء_, ünür
  { {0xe4e6002d,0x2abb0009,0xb2bb0009,0xd5b00012}},	//   дійн, _ומכא, _ומכר, افت_
  { {0x94aa0024,0x7cf00032,0x236a004c,0x8e200024}},	//   ітла_, _gärt, ојио_, бiв_
  { {0x98a30001,0xa2a50011,0x7cf00248,0x290e016d}},	//   _шире, ङ्क्, _härs, _rmfa_
  { {0x60c70002,0x7cf01fa1,0xa2d50011,0x98be0073}},	//   _zajm, _kärs, भाग्, imtą_
  { {0xcb070003,0x9c7c009b,0x78ba1c21,0x6ea50011}},	//   بيين_, _loči, tetv, _काबु
  { {0x7c2d003a,0x7af70227,0xa1ab0009,0x6f02016a}},	//   şara, ëxtr, חֱטִ, lhoc
  { {0xd5b10020,0xd0100003,0x656d29a3,0x07e30024}},	//   ắm_, الج_, _stah, вцям
  { {0x6b9c0065,0x79960002,0x7cef024c,0xb3850012}},	//   durg, kryw, _førs, _أجله
  { {0xdb1a0149,0xc9f60003,0xe731000b,0x90e60012}},	//   _estã, _تساع, רֵי_, _يستن
  { {0xa2b80044,0x718b000b,0x20290028,0xd23b0009}},	//   ्यक्, _וְהַ, átið_, _וגדל
  { {0x7c3401d4,0xd00f01d4,0x309b0009,0xb09b0009}},	//   верх, _рф_, _ושומ, _ויור
  { {0xa3cf0044,0xaf08000a,0xcf270003,0x87270003}},	//   शित_, _يقوم_, _ترتي, _تعتم
  { {0xdb07000e,0x79960002,0x86550024,0xcb340048}},	// [7590] ntjé, gryw, _яких, тетъ
  { {0x272400a2,0x7b67005c,0x3eb20002,0x25d6000b}},	//   mına_, _отме, _zbyt_, _נותן_
  { {0x83670003,0x5ef00037,0xd0110012,0x291e29a4}},	//   _تدخل, _आवश्_, دلا_, inta_
  { {0x539a000b,0xfe700012,0xa2a50011,0xa7fc0060}},	//   _צירו, لده_, ङ्ख्, vcıl
  { {0x6560003a,0x2724003a,0x60c729a5,0xc9870012}},	//   _cumh, nına_, _tajm, _تشجي
  { {0xa3c30066,0xf9920009,0xd469003c,0x961d0035}},	//   _září_, _תרם_, чике_, _neņe
  { {0xe3b10003,0xeb9901d4,0x29110060,0xa158004c}},	//   ارت_, чий_, _imza_, _цару_
  { {0xf772000b,0x20140002,0x84580009,0x2b460025}},	//   _תקן_, ócił_, ובוס_, _choc_
  { {0x9f520066,0xf1c8001a,0xa6340024,0x28db0011}},	//   ází_, _cỡ_, _анті, बालि
  { {0xdb1a03eb,0x78a90046,0xe3b8003a,0xca1a0009}},	//   _està, чког_, çık_, לֵיכ
  { {0xb4bd0037,0xc5140003,0x79960002,0xd6d90002}},	//   ेयी_, _شبكت, zryw, _siły_
  { {0x7b030051,0xc2c50012,0x59df0011,0x27240060}},	//   _jõud, _سيتي, नमार, fına_
  { {0xdb030066,0xf1c8001a,0x20050002,0xa3d70011}},	//   ntní, _gỡ_, szli_, ामक_
  { {0xb0ce0044,0x4e160009,0x18a50048,0x9c7c29a6}},	//   _होंग, תחשב_, _чакм, _poči
  { {0xb6020013,0x1c39002d,0x7cf0006f,0xf092000b}},	//   _žádn, дять_, _särs, _ענה_
  { {0x7b030005,0x2724003a,0x3f47005e,0x79960034}},	//   _nõud, bına_, nõud_, tryw
  { {0x2724003a,0xc3550048,0xa2270048,0xc896004c}},	// [75a0] cına_, търъ, ежта_, ерењ
  { {0xe4f40037,0x7cf00a9d,0x1c1f0011,0x02bd0011}},	//   _अवधि_, _värs, यपाल_, ्युन
  { {0x7cf0006f,0x395803d3,0x447b0009,0x6c7b0009}},	//   _färr, _virs_, _מניע, _מריד
  { {0x44440082,0xa856000b,0xdb1a0029,0x3f47005e}},	//   _iz_, גיעה_, _ostá, jõud_
  { {0x64410035,0xc6930009,0x9c7c1831,0x395829a7}},	//   ļlie, ראד_, _močv, _tirs_
  { {0x6367003a,0xab940024,0x98a40073,0x03c6033d}},	//   _sına, викі, _ėmė_, есим
  { {0xccf3000b,0x50430345,0x02bd0011,0xbc670012}},	//   רכו_, _берб, ्यून, رمين_
  { {0x6bd30003,0xc7d7000b,0xe6ca0037,0xdbcf0028}},	//   اتور, _אולי_, ियोज, nþág
  { {0xc0ca004c,0x29020035,0x66e40011,0x9b430012}},	//   пуне_, ūkam_, गानक_, دنيو
  { {0xf2df0020,0x3958006f,0x444429a8,0x291e1ce8}},	//   _nhân_, örs_, _oz_, unta_
  { {0xdb1a084f,0x7d15000e,0x8cdd0037,0xaba50012}},	//   _está, vizs, पारो, _لإنه
  { {0x6d4e00c6,0x501b000b,0xdbc70051,0x2724003a}},	//   emba, לויו, _pöör, tına_
  { {0x44440cbd,0xaa570003,0x9df80083,0x6d5a29a9}},	//   _az_, _كلما_, енят_, _kita
  { {0x272400a2,0xf2df0020,0x98a5000d,0x88c60003}},	//   rına_, _chân_, rolă_, _ستتل
  { {0x272400a2,0x9cd70093,0x2bd30037,0x68f5003a}},	//   sına_, עולה_, थिया, özde
  { {0xdbc70005,0x083b000b,0x5334011d,0x403b0009}},	//   _töör, _מעול, гест, _מגוג
  { {0x444429aa,0x7b030005,0x3f9e0027,0x32550294}},	// [75b0] _ez_, _nõue, lutu_, твар
  { {0xa3e00037,0x31bb0009,0x5a340198,0x32440012}},	//   दमा_, הזמנ, унут, انكف
  { {0x690b003e,0x2d8b0002,0xdb050040,0x3a390034}},	//   dżet, lsce_, _ophø, _wysp_
  { {0x3ee40098,0x6d5a0005,0x645e0010,0x8f9b0009}},	//   лючв, _aita, žpil, ליבי
  { {0xa2a60037,0xfcab0009,0x64a50f80,0x3f9e005e}},	//   _छात्, ִיֵּ, вала, hutu_
  { {0x273c001a,0x2d990164,0x26c90027,0x273900d9}},	//   hính_, irse_, žao_, ménu_
  { {0x628200bd,0xdb030107,0x7c290052,0x6d5a29ab}},	//   _beoo, stní, ßerh, _dita
  { {0x6d5a09d7,0x4034003c,0x673d0227,0xe9d90a21}},	//   _eita, _сесс, jlsj, дки_
  { {0x2d8b0002,0xa2a20011,0x6d5a0018,0x7d200031}},	//   jsce_, _गार्, _fita, ózsá
  { {0xd9450001,0xd12e0003,0x05190012,0xc8db0011}},	//   ђени, يمي_, _غياب_, बाइट
  { {0x52b50003,0x14d60009,0x78bc005e,0xddc4004b}},	//   _لماذ, _שועל_, õrva, _ofiţ
  { {0x7b740003,0x690b0002,0x6d5a0052,0xeafb0012}},	//   _إطلا, ożes, _zita, _عرضت_
  { {0xf2df0020,0x7ae90027,0xd6e80009,0x444429ac}},	//   _phân_, mjet, תַתָ, _sz_
  { {0xed57010c,0x7ae929ad,0x7afb29ae,0x3f9e29af}},	//   коя_, ljet, lkut, butu_
  { {0xd3b90024,0xb8f50011,0x3f87004b,0x7cf00248}},	//   нуті_, ाए_, ânul_, _därp
  { {0xf74a0012,0x61f6008e,0xc3231003,0x61e401a0}},	//   _تلبي_, tyyl, амск, txil
  { {0xf2df0020,0xfd120003,0x690b0034,0x7ae9001b}},	// [75c0] _thân_, _نجد_, jżes, ijet
  { {0x4255020e,0x443a29b0,0x41030232,0xd59b0009}},	//   утст, _typ_, азув, _קביל
  { {0x444429b1,0x6d5a08a3,0x7fd5002d,0x50b5003c}},	//   _uz_, _rita, ліці, ысту
  { {0x127a0003,0xdfcf0012,0xdb010097,0xa3d50011}},	//   _تحدث_, غين_, _pplý, िटन_
  { {0x6d5a001c,0x6f1d052e,0x84e60024,0x05b40012}},	//   _pita, érci, кодж, امتح
  { {0x3f9e003a,0x6564004a,0xb5fb000e,0x1d330024}},	//   yutu_, _muih, tbáz, анія
  { {0x69c4003e,0x73c30003,0xf1ca0028,0x17c70345}},	//   lwie, ليوم, kráð_, _игри_
  { {0x6d5a0002,0x3ea20033,0x69c40002,0x7afb00b6}},	//   _wita, _økt_, owie, gkut
  { {0xcb130093,0x4432003e,0x7c29003a,0x7c3a0034}},	//   ילה_, ły_, ğeri, _wytr
  { {0xa3cf0037,0x6d5a000d,0x7afb019a,0x88bc0030}},	//   शिश_, _uita, akut, dněc
  { {0x2739000f,0x889b000b,0x69c40052,0xd0f70009}},	//   ként_, וביי, hwie, דמית_
  { {0x7c24003a,0x753d0035,0x973d001b,0x3f9e29b2}},	//   şirs, _īszi, kuće, rutu_
  { {0x973d0027,0x41060001,0x6722001e,0xf194027f}},	//   juće, _издв, inoj, _силь
  { {0x69c40002,0x2d800002,0xf653000b,0xbd450012}},	//   dwie, _dwie_, יצר_, انسي
  { {0x7ceb0052,0xd259001e,0x8aa704ad,0x0b880024}},	//   _kürz, meņa_, крад, ксти_
  { {0x9057000b,0x99800002,0x2cad0066,0xa0570009}},	//   _בסוף_, dził_, řed_, _בסוד_
  { {0x973d001c,0x690b0002,0xdb1a006f,0x45d50001}},	// [75d0] guće, dżer, _istä, _сопс
  { {0xce38000b,0x67220071,0x5f770012,0x273903a7}},	//   _באחת_, enoj, ناصر, rénu_
  { {0xccf2000b,0x69c40002,0x75350031,0x6e3b016d}},	//   _הכי_, awie, mozz, _syub
  { {0x07a400bc,0xdb230051,0x75351161,0xb6070097}},	//   раїн, örüh, lozz, _gráð
  { {0xa634007c,0x5a9a0093,0x1a9a000b,0xa1840015}},	//   анці, _אשרא, _אירע, _высл
  { {0x70740003,0x7ae90052,0xf7730012,0x6722008e}},	//   _نافذ, wjet, _نار_, anoj
  { {0xa3cc0044,0x2246000e,0x4fc4003c,0xb4b80009}},	//   लिए_, _azok_, _кста, דלופ_
  { {0x7535000e,0xdb1a006f,0x5c5c0009,0x05c30011}},	//   hozz, _nstä, ודוק, षबाब
  { {0x7535000f,0x9c7c0042,0x6abd0011,0xaaab0011}},	//   kozz, _počt, ्यौर, _छानक
  { {0x7ae9049d,0xd7e90015,0x7afb29b3,0x57e9096e}},	//   sjet, емое_, skut, едом_
  { {0x69c40002,0x7ae9001b,0x53a40012,0x6564008e}},	//   zwie, pjet, _نملك, _suih
  { {0x7aa4002d,0xc4c9000b,0x8f9a0009,0x99d50012}},	//   _виїз, _מג_, עירי, _متتا
  { {0xe0ce0098,0x6aa4079d,0xd3560009,0xf2df0081}},	//   _лв_, vgif, _עיני_, _châm_
  { {0xdb1a0006,0xc9920003,0xddc2009b,0xf9920009}},	//   _estä, _الوظ, ncoš, _פרו_
  { {0x2739000e,0xbc190024,0x798d016d,0x141a0012}},	//   tént_, віті_, esaw, ريرة_
  { {0x69c4003e,0xdce4001b,0xf3890081,0xf4120009}},	//   twie, _otić, iả_, צפן_
  { {0x91e30014,0x98ac001e,0xa09a0003,0x09e316a9}},	// [75e0] боте, lodā_, فضاء_, ботн
  { {0xcc360003,0x27390c0b,0x51560695,0xb6090035}},	//   _مرجع, béns_, утбу, iešķ
  { {0xdb1a0006,0x6aa40163,0x6f0429b4,0x9f4701bd}},	//   _ystä, pgif, _klic, šný_
  { {0xdb9b000b,0xeafa0003,0x67220035,0x60c10423}},	//   _אסטר, _أردت_, unoj, helm
  { {0xa3cc015f,0x62860039,0x6d5e1831,0x7d181eb9}},	//   लिक_, _ieko, _kipa, tivs
  { {0x60c10006,0xa7860003,0xa3f4002d,0x6f040054}},	//   jelm, _مشرو, иплі, _llic
  { {0x60c1000f,0xe3af0003,0x93930003,0xa021005e}},	//   delm, كري_, مجيا, ööle
  { {0x7cf403eb,0xaa7b0026,0x3bbb000b,0xb7db0009}},	//   _càrr, _inýc, תמקד, _אקלי
  { {0xbef7000b,0x7b030051,0x36f7000b,0xdced29b5}},	//   _עצמו_, _jõua, _עצמם_, _stač
  { {0xd8f8002d,0x5bc60003,0x19b70003,0x57b405cc}},	//   тної_, _متصف, اطية_, абот
  { {0xd36f0003,0x2b40009b,0x3cfb000b,0x6f04031d}},	//   _فهل_, klic_, _רלבנ, _blic
  { {0x291a007d,0x9f35002d,0x7b17000d,0xa8570009}},	//   hipa_, ремі, nţul, טייה_
  { {0x7b030051,0xf2df001a,0x75350031,0x291a29b6}},	//   _nõua, _giây_, tozz, kipa_
  { {0x656f0061,0x6d5e29b7,0x2bd10011,0x6f0429b8}},	//   _éche, _cipa, हिला, _elic
  { {0x6d5e29b9,0x753510f7,0x99470012,0x9be40024}},	//   _dipa, rozz, _حلول_, бітк
  { {0x80a70044,0x41e7002d,0x98a70066,0x7cf40054}},	//   _चाहे, ліза, _okně_, _màrq
  { {0x443e29ba,0xad270012,0xeef80009,0x7abb0009}},	// [75f0] _lyt_, _مردو, _תמחר_, עצמו
  { {0x10070015,0x6fa80037,0x798d016d,0x4a540281}},	//   ляем, _कमां, rsaw, скус
  { {0xf7700003,0x443e29bb,0x155a000b,0x99760002}},	//   كان_, _nyt_, _שכתב, nęły_
  { {0x62860369,0x7c290052,0xa2640048,0x84e30011}},	//   _geko, ßeru, _гърл, खावट_
  { {0xa684007c,0x60c1000e,0x07080012,0x6130008e}},	//   слід, yelm, ديني_, häly
  { {0xf5760003,0x443e06bb,0x53a50012,0x31af0060}},	//   جموع_, _byt_, لمتك, müz_
  { {0x60c10017,0xf389001a,0x9cdc000b,0x7aed1fc7}},	//   velm, uả_, תקופ, ojat
  { {0xf389001a,0x2418000b,0xd5460081,0xfbd00012}},	//   rả_, טחון_, iến, ثته_
  { {0x31af00a2,0x0905002d,0x54a70003,0xb8830029}},	//   nüz_, ипин, _محاف, príč
  { {0xbc680003,0x2903000e,0xe8f9002d,0x6f041767}},	//   _ممكن_, ója_, тло_, _slic
  { {0x7b17007d,0x26c20e68,0x28a60037,0x60c112b8}},	//   lţum, teko_, _खारि, relm
  { {0x7f4d0108,0x6d5e29bc,0xb7f80011,0x98360009}},	//   _chaq, _sipa, ूनतम_, יטתו_
  { {0x8f36000b,0x6b450029,0x63a318c7,0x8afa0009}},	//   שארו_, lógo, lunn, _שהני
  { {0xdca60046,0x88bc0066,0x48670014,0x628629bd}},	//   јави, lněn, _съдб, _seko
  { {0x07a5022a,0x833a0024,0x8cd80011,0x8cc50011}},	//   _тайн, вчат_, मयबो, ाज़ो
  { {0x7c3e022d,0x44240d9d,0xc0580024,0x2b400132}},	//   _vypr, ăm_, _січ_, ulic_
  { {0xdb070065,0x7c3e0002,0x6d5e29be,0x61fb00b6}},	// [7600] ðmát, _wypr, _tipa, nyul
  { {0xb05a0003,0xd5fb000b,0xd5b1001a,0x63a30779}},	//   نشاط_, _ספיר, ắt_, kunn
  { {0x34b70093,0xc059002d,0xcd290003,0xdc9b007e}},	//   _דפים_, гії_, _حسين_, _בסיכ
  { {0x7d1c00a1,0x7aed0002,0x88bc0066,0xe9a60ef0}},	//   lirs, cjat, jněn, _камп
  { {0xed590066,0x62860028,0x88bc0066,0x86c30012}},	//   ůže_, ðkom, dněn, زيون
  { {0x63a31dbd,0x2bba0012,0x6bd60012,0x186a004c}},	//   funn, ناعة_, لتعر, _јави_
  { {0x9be6002d,0xdb07000e,0xb5fb29bf,0xb4e60011}},	//   рілк, ltjá, ncár, _बची_
  { {0x2b930020,0x7b030051,0x64480029,0xb6a31f02}},	//   ịch_, _lõun, _vzdi, _мисл
  { {0x6c960003,0xdb07000e,0x5e9b0009,0x32530048}},	//   _نشاط, ntjá, _שבמק, овър
  { {0x63be0033,0x61eb08ec,0x7b03005e,0xa3c80011}},	//   _oppn, ägli, _nõun, ोटा_
  { {0x69d9008b,0x47351932,0x27320066,0xf0930009}},	//   _erwe, йнос, lány_, חנת_
  { {0x88bc0066,0x31af0060,0x0a67004c,0xdb230060}},	//   cněn, yüz_, _крши_, ürüc
  { {0xceb30093,0x973d0027,0x7e2b002d,0x7e470021}},	//   חיר_, guća, тіна_, рхне
  { {0xc0d30012,0x25ee0011,0x89330012,0xe3b30012}},	//   _وينب, _आपनी_, _وعوا, يرز_
  { {0xd7fa0001,0x9b680001,0x7aed29c0,0x2732024a}},	//   _јул_, ишта_, tjat, hány_
  { {0x905b000b,0xe1d20011,0x7aed29c1,0xdb1a054f}},	//   _בכות, सिंघ, ujat, _astú
  { {0x9f530002,0x20670001,0x6f1d0358,0xa2a90037}},	// [7610] ńców_, ађев, misc, _टास्
  { {0x26110037,0x27320066,0x88bc0066,0x7c290052}},	//   _देगी_, dány_, zněn, ßers
  { {0xa2670014,0x83f90024,0x95540012,0xa7fc0060}},	//   _въгл, _сенс_, _بخيا, mcıs
  { {0xb8fe0044,0xec360093,0x7bda000b,0xa857000b}},	//   _दो_, _לאתר_, _עקרו, ביבה_
  { {0xd0870015,0x88bc0066,0x26110037,0x6b6a0034}},	//   _выби, vněn, _देखी_, _węgl
  { {0x63a303d5,0xfbd10003,0xa5f60001,0x6f1d0480}},	//   tunn, كتب_, сељу_, hisc
  { {0xc952000b,0x63a3004a,0x6f1d0052,0x88bc0030}},	//   _ממך_, uunn, kisc, tněn
  { {0xcac90047,0xd5b90037,0xff070024,0x7ae20034}},	//   угие_, ेबाज, _тягн, _cnot
  { {0x88bc0013,0x20d50024,0x95c80024,0x6f1d29c2}},	//   rněn, бінс, _вуха_, disc
  { {0x60c5008b,0x7ae2009b,0x88bc0066,0x2001005e}},	//   nehm, _enot, sněn, _ühik_
  { {0x88bc0aec,0x6f1d01e0,0x7d1c29c3,0x68f529c4}},	//   mněl, fisc, virs, _mozd
  { {0x98ac000d,0x6f1d0358,0xcb550001,0x6d4329c5}},	//   todă_, gisc, _увећ, llna
  { {0x2f55007c,0x2d840108,0xa3cf0037,0x45260012}},	//   ютьс, ème_, शिक_, مرسِ
  { {0x07f90003,0xa3ab0037,0x7ae2009b,0x4aa70011}},	//   _مربع_, कंप_, _znot, _गाँव
  { {0x65610149,0x2bda0037,0x27320066,0x7d1c29c6}},	//   _milh, भिया, zány_, rirs
  { {0x6e960003,0xdb07000e,0x64410914,0x6aa929c7}},	//   _الظا, ttjá, _myli, ngef
  { {0xe9da0015,0x9c820010,0x6aa90032,0x7cf00032}},	// [7620] ыка_, ščia, igef, _märz
  { {0x27320013,0xf617000b,0x6aa90052,0xdb07000e}},	//   vány_, _לחפש_, hgef, rtjá
  { {0x26d201e5,0x3ceb0037,0x63be0851,0xdb1a0029}},	//   _kayo_, चाने_, _uppn, _vstú
  { {0xf772000b,0x76a9002d,0x7b030051,0x064a0012}},	//   פקד_, итів_, _jõul, هلاً_
  { {0xdd8f0003,0x99d60003,0x26d2023e,0x65610e84}},	//   فون_, _اتجا, _mayo_, _bilh
  { {0xd1320003,0x26d2002c,0x68f5009b,0xa0670048}},	//   _رمز_, _layo_, _gozd, _гара_
  { {0x973d0027,0xb606009b,0x6aa910c7,0xd4990024}},	//   dućn, lišč, fgef, ррі_
  { {0x79a60048,0xb6060159,0x49740229,0x929d0034}},	//   брое, oišč, олис, ykłe
  { {0xe29f0065,0x656129c8,0x599a0009,0xbda50012}},	//   óða_, _filh, אשִׁ, _وحكو
  { {0x973d001c,0xdd8f0003,0xa2da0037,0x656f0061}},	//   gućn, _أول_, _पोस्, _écha
  { {0x6f1d0518,0x320200d9,0x04db0009,0x61e40073}},	//   tisc, šky_, _תקבל, _šild
  { {0xb7db000b,0x8cbb0011,0x25d9003c,0xadd9003c}},	//   אקטי, श्नो, аммы_, амму_
  { {0x7afd29c9,0x7cfd0054,0xe8940021,0x64410052}},	//   öste, _sèri, _даль, _zyli
  { {0xd1300003,0xb606009b,0xd257000b,0x3ead0002}},	//   _تمت_, dišč, _השדה_, żet_
  { {0x249f003a,0xd91b0009,0x68b70009,0xb4fb0009}},	//   ğum_, _גוגל, _הלוא_, נפלי
  { {0xae9b0003,0x291e29ca,0x6378003c,0x8c1b0009}},	//   _إضغط_, lita_, ссёр_, אולי
  { {0x291e004a,0x6f020029,0x98e50003,0x50f50365}},	// [7630] oita_, dkoc, يكرو, озат
  { {0xb8820029,0xc867003c,0x99840012,0x88bc0030}},	//   _šírk, стаи, سلمو, kněm
  { {0xf84b022a,0x83190012,0x291e005e,0xf53f1d48}},	//   учай_, _نقدر_, iita_, stås_
  { {0x17f8000a,0xd7580003,0x9f560028,0x141a000b}},	//   حركة_, مجنا_, ægðu_, _כותב
  { {0x291e01e5,0x7b2c0060,0x65610018,0x3f8e0097}},	//   kita_, oğun, _pilh, áfur_
  { {0xdb030025,0x64410073,0x04b50024,0x361c00af}},	//   muné, _pyli, ісля, נוגד
  { {0xd4980009,0x3cfc0009,0x5ea50012,0x8cbb0011}},	//   זכות_, רפוב, _ومسل, श्यो
  { {0x69c90036,0x8c160003,0xbd6b0001,0xd2510012}},	//   twee, غيير_, _брже_, ونغ_
  { {0x2d9e0002,0x88bc0066,0x8d740012,0x05740012}},	//   ątek_, mněj, _فالا, _فالد
  { {0x6aa90052,0xc9840001,0x88bc0066,0x26d2002c}},	//   sgef, чући, lněj, _sayo_
  { {0xb17b0163,0x26d2002c,0x711a000b,0x6aa90028}},	//   _fråg, _payo_, שותפ, pgef
  { {0xc7d6000b,0x7b33000d,0x88bc0066,0xceb20009}},	//   קורי_, dăug, nněj, ֽים_
  { {0xee37002d,0x2003009b,0x291e29cb,0x6f0929cc}},	//   жня_, šji_, bita_, _mlec
  { {0xd5b1001a,0xd2560009,0x865a0009,0xb65a0009}},	//   ắp_, _ושנה_, ידרי, ידרש
  { {0x26d2002c,0xdb07006f,0x1c1f0011,0xc7460012}},	//   _tayo_, ktjä, यपटल_, _وضعي
  { {0x28ac0044,0xb606012e,0x98ac007a,0x0b46002d}},	//   _चाहि, tišč, rodą_, інан
  { {0x628b000f,0x3b070014,0x88bc0066,0xdce0000d}},	// [7640] _mego, цето_, dněj, _jumă
  { {0xb606009b,0xa2da0037,0xbca60003,0x76440060}},	//   rišč, _पोर्, _بمدي, _iyiy
  { {0x69dd0052,0x62990002,0x69cf0962,0xe79a0012}},	//   _erse, _odwo, _esce, شخاص_
  { {0xb5aa0003,0x63a10029,0xe73a0015,0xbebb0227}},	//   لاتك_, álne, шее_, piëe
  { {0xdce0007d,0xf2df0020,0x64450051,0x753c0070}},	//   _numă, _châu_, ühin, oorz
  { {0x33980003,0xc5cb0009,0xcc87004c,0xb6030064}},	//   منتج_, שֶׁ֨, обље_, úšan
  { {0x261a0044,0x88bc0066,0xe6c60012,0x628b11c5}},	//   _मेरी_, bněj, _وتري, _bego
  { {0x291e0002,0x3945019f,0x444429cd,0x88bc0030}},	//   wita_, ells_, _my_, cněj
  { {0x753c003e,0x444429ce,0xc0c6004c,0xf9c60024}},	//   korz, _ly_, ољни, іщин
  { {0xeb9a0014,0x64410051,0x6f090002,0x44442145}},	//   _виж_, ülik, _zlec, _oy_
  { {0x291e29cf,0xdce9001b,0x395901a0,0xe1ff0081}},	//   rita_, _steć, ïssa_, _ngón_
  { {0x3869003a,0x86740024,0xa2da0011,0x8f9b0009}},	//   _şart_, млює, _पोल्, סיכי
  { {0x444401e5,0xc6930093,0xdb030029,0xd4910081}},	//   _ay_, ואר_, ytnú, _hòa_
  { {0x444429d0,0x224b0052,0xe4e4002d,0x24f40009}},	//   _by_, ücke_, місн, הֶֽם_
  { {0x59d20011,0x7b780009,0xb6030030,0x307b0009}},	//   तिकर, מָּצ, _zmáč, _דאונ
  { {0xb8820029,0x929d0002,0x8b9b0009,0x539b0009}},	//   _šípk, okła, יבלת, יסלא
  { {0x5d840003,0x88bc0066,0x44290081,0x764d0060}},	// [7650] _قليل, vněj, ̃a_, _uzay
  { {0x6f0900bd,0xaa7b0029,0x673d001d,0xb97b0009}},	//   _slec, _iným, losj, ינמי
  { {0x6d470133,0x88bc0066,0xf8680003,0x30780012}},	//   mlja, tněj, زمني_, تحقة_
  { {0xdb0329d1,0xae020011,0xcc560009,0xf4560009}},	//   stnú, रैकन_, _מבתי_, _מיתר_
  { {0x628b01a2,0x2a76000b,0x237f0027,0x44441528}},	//   _rego, _מערך_, ćuju_, _zy_
  { {0x628b03eb,0x88bc0066,0xdb07006f,0x4a5a0009}},	//   _sego, sněj, stjä, _לדרו
  { {0x7b030005,0xe4c80003,0x84580014,0xcfb40014}},	//   _nõuk, زبون_, орът_, _обръ
  { {0x16160037,0x6aad0028,0x656f0061,0x8cbb0011}},	//   _देकर_, ngaf, _écho, श्तो
  { {0x91b0001a,0x257001a0,0x6445079b,0x63670031}},	//   _đại_, _gàl_, _lyhi, _bűnc
  { {0x00f6000b,0xdb1a0029,0xa3bb0012,0x07f90012}},	//   ִ֖ים_, _istý, _ناصر_, مرجع_
  { {0x929d0002,0xbca40003,0x6d4102a0,0x753c0778}},	//   akła, _زمني, _ikla, vorz
  { {0x753c003e,0x656d00b6,0x91f70012,0x27f80248}},	//   worz, _buah, _وأشا, ärna_
  { {0x753c29d2,0x9af20012,0x28ac0011,0xed5a15c8}},	//   torz, _سكوت, _चालि, йом_
  { {0x91f6000b,0xb97a000b,0x2d9e022d,0x25ee0011}},	//   _ממנו_, _הנסי, čte_, _आपसी_
  { {0x3eb1004a,0xa9040012,0x5ea60012,0x63860048}},	//   ältö_, _زبون, _فمثل, ягва
  { {0x7e9a0003,0xd7fa000b,0x63ae0058,0x5ffa0009}},	//   _انظر_, _להצל, _åbne, _להצה
  { {0x6d470133,0xc332000b,0x63a3015d,0x5bb80011}},	// [7660] blja, גון_, hrnn, _आह्व
  { {0xd24f000a,0xb1430001,0x6b6a0002,0xcdb70009}},	//   انك_, енул, _węgi, _צפיה_
  { {0x78a30028,0x3cfb000b,0x444429d3,0x6cfb0009}},	//   ónva, _הלינ, _uy_, _הפיס
  { {0x6d41002c,0x929d0002,0x60c80002,0x248c0066}},	//   _akla, ykła, zedm, _sedm_
  { {0x628402d1,0xa4d4002d,0x5de60048,0x0cd409e8}},	//   mbio, долі, яжда, долю
  { {0xb4d60044,0x98ac0034,0x672b0031,0xe38a03d2}},	//   िये_, bodę_, angj, бщил_
  { {0xf2140037,0x99890002,0xdc9b0009,0x69c20227}},	//   _तेज़_, czał_, ציקל, _spoe
  { {0x6d4129d4,0x7bdb0009,0x79a60aa2,0x33970012}},	//   _ekla, מקצו, прое, أخوة_
  { {0x60d5003a,0xd528001a,0x79960002,0x67220010}},	//   _yazm, _cộn, nsyw, mioj
  { {0x6722007a,0x79fb000b,0x290a0b95,0xe9180024}},	//   lioj, צליח, óba_, іоні_
  { {0x6d47048b,0xc4d3000b,0x656d0c56,0x547b0009}},	//   vlja, _רגע_, _suah, _הטבו
  { {0x67220073,0x6d410030,0x39d20011,0xeb910009}},	//   nioj, _zkla, सिफ़ि, _יָד_
  { {0xcb13000b,0x6ce7002d,0x673d29d5,0x62840034}},	//   _אלף_, піве, rosj, dbio
  { {0xeb050037,0x4153002d,0x219b0009,0x8cbf0011}},	//   रस्त_, _звіс, _פבוא, ल्पो
  { {0x58bb0093,0x00bb000b,0x88bb0009,0xcc540014}},	//   _המוצ, _המומ, _המוז, евръ
  { {0x5bb80015,0xc2c50012,0x2ae50011,0xdb1a0018}},	//   ялся_, بيري, काएँ_, _istó
  { {0xd2340014,0x6d4700eb,0xd3570009,0xaa580024}},	// [7670] ентъ, plja, לילי_, зиту_
  { {0xb4d60037,0x98ac0002,0xb17b0009,0x80c70011}},	//   ियो_, todę_, צטבר, रजें
  { {0x06990003,0xf6d5002d,0x6f0d009a,0xacfc0009}},	//   قناة_, діля, _klac, _להזכ
  { {0xd4910020,0x99890002,0xe9df29d6,0x200f0034}},	//   _còn_, rzał_, _trú_, ągi_
  { {0xb6bc000b,0x9f5c1f13,0x2007013a,0x99890034}},	//   מצאי, ává_, šni_, szał_
  { {0xee38007c,0xd528001a,0x26cb0017,0x6f0d01a0}},	//   чні_, _rộn, heco_, _llac
  { {0x6f0d00a2,0x7af90002,0x6d4101bd,0xcc780009}},	//   _olac, _powt, _vkla, הגות_
  { {0x6441003e,0xd2a9003c,0x44240012,0xbed4004c}},	//   żliw, цкие_, عروف, _посј
  { {0xc27c000b,0x0b160003,0x59e00011,0x51920012}},	//   זרחי, بقية_, नियर, نليذ
  { {0x4805007c,0x6f0d29d7,0x273901a8,0x5e440012}},	//   дпов, _alac, mény_, _أَكْ
  { {0xf092000b,0x629d124c,0x1eca0345,0x6f0d29d8}},	//   כני_, _odso, олни_, _blac
  { {0xe1f10003,0xeab00003,0x628f000d,0x2cfa0011}},	//   _لست_, _معه_, _neco, ्सॅल_
  { {0xe8f50003,0x6f0d0002,0xee3a002d,0xcb12000b}},	//   _يستخ, _dlac, інг_, _בלא_
  { {0xcb6a0001,0x60250001,0xd8250001,0xf9920009}},	//   жаве_, _одла, _одли, _ירד_
  { {0x628f0036,0xc952000b,0x8cbf0037,0x7fd5002d}},	//   _beco, _שמו_, ल्यो, _цілі
  { {0x63a1000e,0xac070024,0x333f0025,0x26c0001b}},	//   álna, єнта_, noux_, _ubio_
  { {0x5eeb000b,0xd6eb000b,0xa09a0003,0x8d56002d}},	// [7680] _וַיְ, _וַיָ, قضاء_, _оточ
  { {0xc0a90003,0x26170037,0x8cbf0037,0x79960034}},	//   كامل_, _पेटी_, ल्मो, rsyw
  { {0xc2090009,0xc66a004c,0x6b450031,0x2d800035}},	//   סה_, ошле_, lógu, ģiem_
  { {0x628f00bd,0x464a0014,0xa3e10037,0xcff6000b}},	//   _geco, озен_, दिन_, וצעה_
  { {0x67220010,0x7c250064,0x333f29d9,0xe62900af}},	//   rioj, úhrn, doux_, ּחוֹ_
  { {0xd37a057b,0x2cfa0037,0xc6170009,0xe5890009}},	//   очи_, ्सेल_, וחני_, פָנָ
  { {0x69dd0058,0x29270064,0x68fc29da,0xbebb0227}},	//   æsen, ývať_, _iord, diën
  { {0xc2980001,0x539b0009,0x501b0009,0xdee3003c}},	//   чких_, קיפו, _וולו, _иоси
  { {0x68fc29db,0xdceb0060,0xbebd0073,0xfe43083a}},	//   _kord, argı, _smūg, _анто
  { {0x15fb0009,0xba570009,0x45fb0009,0x8dfb0009}},	//   _והמע, וספו_, _והמג, _והמת
  { {0x68fc012e,0x7c650003,0xb4bc0037,0xdb0a0245}},	//   _mord, _كامل, ेजी_, ttfä
  { {0x9f500028,0xef110009,0x01da0012,0x6d5c0b8f}},	//   ðaða_, ָּט_, _ووضع_, emra
  { {0xdb030029,0x2f020028,0xe0da0223,0x02bc0011}},	//   ntný, _nógu_, _мвд_, ्जीन
  { {0xbebb0070,0x68fc1733,0xf1b90035,0x628f29dc}},	//   ciën, _nord, _īš_, _seco
  { {0x98be000d,0xd6db002d,0xb0650574,0x3eaf03ce}},	//   altă_, _дтп_, rjää, yggt_
  { {0xc9870001,0xe667035c,0x35b50339,0x8f9b0009}},	//   дужи, _отпо, _збир, _ויהי
  { {0x443f0002,0x5a350014,0x7e6d0051,0x973d0027}},	// [7690] łu_, хнат, _igap, jući
  { {0x7b17007d,0x64450051,0x3cfa0037,0xba540001}},	//   nţur, ühik, ्सों_, твуј
  { {0xf770000a,0x44270163,0x18a4002d,0x75230052}},	//   لان_, _än_, таєм, vinz
  { {0x8db50024,0x61e229dd,0x98ac0030,0x6d4a29de}},	//   ескі, _orol, todě_, elfa
  { {0x973d001c,0x427a0009,0xee2e0476,0x68fc29df}},	//   gući, _מארג, ун_, _ford
  { {0x19b60093,0xabd50001,0x7871000e,0xa3bd0011}},	//   _אפשר_, ециј, _művé, ेबल_
  { {0x9f050003,0x7afd29e0,0x8d62003c,0x24090198}},	//   _كوسو, _kost, ывше, янки_
  { {0x7afd004a,0x64480010,0xe29905c8,0x68fc15c5}},	//   _jost, _dydi, чаи_, _zord
  { {0x1d350014,0x7dc70012,0xbebb0227,0xdb1a0040}},	//   _зная, _تتأك, tiën, _optæ
  { {0x5d54004c,0x6c840012,0x64c50012,0x2b4025aa}},	//   _акут, _للكم, _سيصل, zoic_
  { {0x7afd0070,0xeb900012,0xb8d70011,0xbebb0227}},	//   _oost, _نظن_, _छा_, riën
  { {0x7afd29e1,0x93270012,0x6448005e,0x6da6214d}},	//   _nost, _غران, üdim, нима
  { {0xbd360014,0xaa070012,0xff160009,0xdb03004b}},	//   ехвъ, _تظاه, תקרת_, punâ
  { {0x80c10037,0x2574006f,0x98a5001e,0x53990009}},	//   र्मे, _väl_, rolē_, ּיּו
  { {0x7afd066e,0xd3720003,0xdddb2156,0xb8d30011}},	//   _bost, اهر_, _neuž, टल_
  { {0x20050073,0x7afd29e2,0xdb0303a7,0x68fc29e3}},	//   myli_, _cost, ytný, _sord
  { {0x05770012,0x947a0024,0x41aa0048,0x2b400bb5}},	// [76a0] _كمية_, _нсну_, яван_, roic_
  { {0x290e0028,0x3d090011,0x973d001b,0x61eb0248}},	//   ófa_, वसों_, vući, ågla
  { {0xa4b7000b,0xcd020002,0x6441005e,0x68fc0fdb}},	//   _אליה_, ęść_, ülit, _vord
  { {0x68fc01e4,0x67100037,0x6568006f,0x216a01d4}},	//   _word, ासिक_, _sidh, _ними_
  { {0x6f1d0054,0xd491001a,0xd6d90034,0x45d403b0}},	//   èrci, _bè_, _dał_, толс
  { {0x7afd29e4,0xb4bc0037,0xdb030064,0x24e7004c}},	//   _zost, ेजे_, rtný, емљи_
  { {0xa3ab0037,0x1fb5011d,0xdb0301e9,0x3d080011}},	//   कूल_, _истр, stný, _सकने_
  { {0x6e930003,0x88bc0066,0xa6db0028,0x6296002c}},	//   _ملفا, hnět, koða, nayo
  { {0x88bc0013,0xcb13000b,0xe73705fb,0xcf570009}},	//   knět, טלה_, _чет_, _טבלת_
  { {0x60f8002d,0x7e0b0009,0x859b0009,0xfd970009}},	//   єння_, _מִבֶ, _משמו, _נדבך_
  { {0xb3e90003,0xf53f006f,0x082a003c,0x88bc0030}},	//   _يعمل_, från_, яции_, dnět
  { {0xbebb0070,0x8a460003,0x7b03005e,0x1dd40011}},	//   ciël, _كَان, _jõut, _धनात
  { {0xc333000b,0x8afb000b,0x80c10011,0x2d9929e5}},	//   _גוף_, _מהאי, र्डे, usse_
  { {0x25a4000f,0xd24f000a,0x3ea029e6,0xe0d30001}},	//   ámla_, _انه_, _edit_, _бошњ
  { {0xf0930009,0xa2950024,0x8ae70024,0x2c340009}},	//   _ענק_, каві, ніал, דָּם_
  { {0xa3e10044,0x7b030051,0xdb180029,0x6296002c}},	//   दित_, _nõut, ftvé, gayo
  { {0x7afd29e7,0xe29f0028,0x4ac20037,0x9f5f000e}},	// [76b0] _vost, óði_, व्यव, sztó_
  { {0xf8b10009,0xd8740012,0x7c380018,0xb17b0248}},	//   ֹשׁ_, هامب, çarã, _från
  { {0x56950047,0xad1c0009,0xdb070030,0x230b0012}},	//   вает, _מוזר, lují, _فتحي_
  { {0xc7b3000b,0x539a0009,0xf7840012,0x63a80064}},	//   טבע_, _קירו, النَ, ádne
  { {0x20050034,0xdb070030,0xfe9c0009,0xe5780024}},	//   zyli_, nují, ליאמ, езі_
  { {0xf9920093,0x7c34003a,0x03a50055,0x7f850012}},	//   _דרך_, _çerç, вико, _للسن
  { {0xdb070066,0xdce50159,0xe6890012,0x9cd800af}},	//   hují, _nihč, _ينسى_, גווה_
  { {0x2d8d00bd,0x99d50003,0x67d40024,0xdb070030}},	//   _twee_, نتخا, _щосу, kují
  { {0x26cf0002,0x12e80009,0xbebb0227,0xdb070030}},	//   mego_, תֽוֹ_, riël, jují
  { {0xdb070013,0x60090838,0x41020015,0x245c0030}},	//   dují, дном_, изыв, námé_
  { {0x7b030005,0xc952000b,0xe73a0de1,0x61ed0073}},	//   _jõus, שמי_, ден_, _šald
  { {0xe2900351,0x26cf003e,0xfbd2000b,0x27e7004a}},	//   _هذه_, nego_, _כתב_, änny_
  { {0xc3320093,0xaa880003,0xb0b30011,0x50b30011}},	//   _דוא_, _أنهم_, ुभाग, ुभाष
  { {0xa3b50044,0x98ba001e,0x2b4002a1,0x97c50024}},	//   _जमा_, kopā_, čice_, _айке
  { {0x7b030005,0xa8480012,0x6296020d,0x88bc0030}},	//   _nõus, _كلهم_, tayo, rnět
  { {0x26cf003e,0x3f85007d,0x2d80007d,0xf772000b}},	//   jego_, mplu_, ţiei_, _דקה_
  { {0x88bc0066,0x973d0027,0x26cf0002,0x6d4329e8}},	// [76c0] pnět, guću, dego_, kona
  { {0xb17b0248,0x6d4329e9,0x3f850060,0x629629ea}},	//   _trån, jona, oplu_, sayo
  { {0x6296002c,0x3f9c0061,0xdb18000e,0x26cf0018}},	//   payo, évu_, stvé, fego_
  { {0xd7ef0003,0xbe660003,0x6d4e29eb,0xa8560009}},	//   تكم_, نهاي, llba, דיעה_
  { {0xdb1e003e,0xe7690003,0x9db70003,0xdd8f0003}},	//   _wspó, رحمن_, ندوز_, قون_
  { {0x80c10044,0x6b550073,0x361b0009,0xdfa60012}},	//   र्दे, _išgy, וונד, _لحري
  { {0x25ee015f,0x6731000f,0x94230001,0xdb070066}},	//   _आपकी_, ókjá, имље, zují
  { {0x26cf003e,0x61d8022a,0x6d4e0032,0xca320009}},	//   cego_, емия_, hlba, ֹם֙_
  { {0x6d4329ec,0x24980034,0x6b4500ce,0x056609ca}},	//   bona, karm_, tógr, _аван
  { {0xf993000b,0x998d0002,0xdb070066,0xdb1c0034}},	//   סרת_, dzeń_, vují, owró
  { {0xf8b30009,0x6e950560,0xb4ae0011,0xd1410034}},	//   בשת_, лину, कली_, djąć_
  { {0x752700bd,0xb2260015,0xc7b3000b,0x60dc0061}},	//   wijz, _имел, סבר_, _larm
  { {0x6f030149,0x5bcb0011,0x9196004c,0x600b0031}},	//   ênci, ाब्व, _рјеш, tömö
  { {0x26cf0002,0x06240148,0xdb070030,0x7bdc0031}},	//   zego_, рфюм, rují, _árus
  { {0x212b0061,0xac190538,0xdb070030,0x98a3004c}},	//   èche_, хову_, sují, _тије
  { {0x237e000e,0xdb070030,0x5334004c,0xdb1c0025}},	//   ítja_, pují, аест, ntrè
  { {0x998d0002,0x6d4301ea,0xba55004c,0x3df4003c}},	// [76d0] czeń_, yona, увај, _взыс
  { {0x26cf003e,0x2bab0037,0x31bb0009,0x50670012}},	//   wego_, _छिपा, וזמנ, نطاق
  { {0x3d08015f,0x26cf003e,0xd260001e,0xdb070028}},	//   _सकते_, tego_, ļņas_, ðmót
  { {0x59f90014,0x5ea40012,0xe7e30011,0x26cf01e3}},	//   _земя_, لممل, गिता_, uego_
  { {0xdb1e0065,0x3f52000e,0x26cf29ed,0xddc503e2}},	//   _uppá, dául_, rego_, убли
  { {0x7544002d,0x621a000b,0x7b030051,0x3f47005e}},	//   аніз, _טורק, _tõus, tõus_
  { {0x5f94007c,0xe7870046,0xf8b2000b,0x6d4329ee}},	//   _вист, _југо, _לשם_, rona
  { {0xe9d929ef,0xf1b70011,0x6d4329f0,0xfc5800af}},	//   еки_, _आमदन, sona, כבוש_
  { {0xd4c70003,0xc6920009,0x68b50009,0x6d4329f1}},	//   _لغاي, _לאן_, ְלֹא_, pona
  { {0x67240027,0x28c60011,0x08d50048,0x6604005e}},	//   _smij, र्पि, уция, äike
  { {0x28ab0037,0xa0880009,0xf1d80011,0x63c20030}},	//   _चयनि, כְרִ, _बैठन, ěvní
  { {0xeef5000b,0xef120009,0x98a50060,0xa3e70011}},	//   אמֹר_, ֶּר_, rmlı_, पिन_
  { {0xaa0b0003,0x929a0009,0xe29f0097,0x9f4e0031}},	//   _تزال_, _ניסת, óðu_, ónév_
  { {0x998d0002,0x9d560003,0x7afb026e,0xdb1c0034}},	//   rzeń_, انست, ljut, ywró
  { {0xf092000b,0x998d0002,0x88ba0009,0xdb1c0025}},	//   _פנה_, szeń_, _נזקי, ltré
  { {0x7afb00c6,0x26de001e,0x2aec0011,0x28c60011}},	//   njut, ētos_, झाएँ_, र्नि
  { {0xdb1c101c,0x60dc29f2,0xdb0a29f3,0xb9960012}},	// [76e0] ntré, _parm, énés, الطب
  { {0xe9d7003c,0x61e600b0,0x98a50073,0x7afb005e}},	//   ыку_, åkli, rolė_, hjut
  { {0x60dc0006,0xa686011f,0x66e60a25,0x94bb000b}},	//   _varm, глед, ложа, _אמית
  { {0x69cb01e4,0x8f45002d,0xd6d9002d,0xee3a17af}},	//   _opge, ахід, кті_, нне_
  { {0x6a9b0009,0xf7170012,0xbea306bd,0x257901a0}},	//   _אשכנ, دينغ_, сачк, _cèl_
  { {0xfbd20003,0xb4ae0011,0x23b40012,0xd6570009}},	//   متع_, कले_, لمتس, ניסת_
  { {0x9f4b000e,0x798208ce,0x4fd80009,0x5bc30012}},	//   őjét_, _stow, _בַּד, مقول
  { {0x61e4005e,0x7b03005e,0x3f520097,0x660d0031}},	//   ovil, _jõup, fáum_, önké
  { {0xcb670001,0xda660003,0xee370014,0x64b60012}},	//   ћање_, داثي, _бнт_, _محار
  { {0x46130012,0x7afb005e,0xa3e10011,0x91bb0009}},	//   _اوكر, ajut, दिश_, עמיי
  { {0x47350838,0xac970003,0x61e7001e,0x8cbf0011}},	//   инос, _إنما_, ājla, _लॉगो
  { {0xd6db002d,0xa3e10037,0x03d7000b,0x41e60012}},	//   хто_, दिर_, _תואם_, _مستف
  { {0x7d010060,0xdb070031,0xa2d30012,0x39451d91}},	//   _yols, rtjü, _دينت, bols_
  { {0x61db000b,0x28c60037,0x30760001,0xb9db0009}},	//   _נקוד, र्मि, _судс, _נחוש
  { {0x25a00f66,0xa9230066,0x69c00d33,0xa87b01b0}},	//   _evil_, ížej, ltme, _ארוח
  { {0x2bac01e1,0x67bb000b,0x7f830003,0x73f80012}},	//   _घटना, _נמחק, _الين, دِّر_
  { {0x765a0002,0xd1bb0003,0x3f9e29f4,0x69c029f5}},	// [76f0] ętyc, عارا_, lstu_, ntme
  { {0xd257000b,0xb9c40003,0xba57000b,0x31c40001}},	//   רשמה_, إقلي, רסמו_, љств
  { {0xdfd10003,0xccf2000b,0x69c0005e,0x4fd50048}},	//   تيا_, _וכי_, htme, ржет
  { {0xaf4b0012,0x3f9e29f6,0x5064033d,0x7d0129f7}},	//   رشال_, istu_, стуа, _sols
  { {0xdb070065,0xfda70001,0x7d0129f8,0xaa9a0009}},	//   stjó, ујем, _pols, _בברכ
  { {0x63a50066,0x290f001e,0x3f9e29f9,0x6d4729fa}},	//   áhno, īgas_, kstu_, noja
  { {0x6e95002d,0x99920002,0x2d84003a,0x61140001}},	//   _вибу, czył_, _etme_, _удру
  { {0x29030164,0x7afb005e,0xdc0f0030,0xdb03005e}},	//   _hoja_, ujut, _něče, htnö
  { {0x7afb0005,0x2903001c,0xdb180013,0xa2dd0037}},	//   rjut, _koja_, ctví, _पसन्
  { {0x64450051,0xf840001a,0x2b400470,0x661d001e}},	//   ühis, ườn_, čica_, dzsk
  { {0x6d4701ff,0xdb1c0061,0x69c0002a,0xdc190034}},	//   doja, stré, atme, _yłąc
  { {0xd5e60015,0x29030017,0xf7460ae9,0xabfa0009}},	//   ажми, _loja_, ремо, _בהער
  { {0x28c60011,0x20c60011,0x69c014e0,0x39452693}},	//   र्डि, र्डध, ctme, pols_
  { {0xed5a0001,0x2d84001e,0x2ed20011,0xf9900012}},	//   тог_, īme_, _सस्त, _ربه_
  { {0x6a96002d,0xab2a0447,0xdb030051,0xe29a0469}},	//   ирає, вова_, punä, кав_
  { {0x883a007e,0xfb160012,0x25a0061d,0x1dc50011}},	//   _בתצו, جورج, _tvil_, लझात
  { {0xc0760046,0xcb67011f,0xe9da0014,0x290301bf}},	// [7700] аћењ, рате_, ъка_, _boja_
  { {0x865b0093,0x11d70003,0x14260024,0x659b0009}},	//   _בדפי, ؤولة_, _вдом, _שייק
  { {0x61e429fb,0x98be0035,0x1dde0011,0xe043047a}},	//   svil, notā_, मिकत, онфи
  { {0xeab2000a,0x539b0093,0x99920002,0xfc57000b}},	//   _بعد_, _ביטו, rzył_, _כביש_
  { {0x6f040002,0x45d60014,0x99920002,0xd83809d2}},	//   _moic, рцет, szył_, mače_
  { {0xdc19003e,0x1d890003,0xbd870012,0xa4d40024}},	//   _włąc, ائني_, جنون_, сокі
  { {0xed570001,0x2bb70003,0x28c60011,0xf8c60011}},	//   јој_, لاية_, र्णि, र्णय
  { {0xa3e70044,0x3eda0003,0x2ba70037,0x5fdb000b}},	//   पित_, _جورج_, _गिरा, _בחלק
  { {0x28c60037,0x7d010028,0xd257002d,0xb997003c}},	//   र्थि, ölsk, иць_, авых_
  { {0x30a3002d,0x57b40015,0x55bb0009,0x4c980009}},	//   орюв, ббот, _בממו, _תֹּא
  { {0x79890002,0x69c029fc,0x19570009,0xad1b0009}},	//   apew, stme, שביל_, _שובר
  { {0x28c60044,0xb0c60037,0xf53f079d,0x3f9e29fd}},	//   र्ति, र्तग, pråk_, rstu_
  { {0x661d0066,0x6d4722c2,0x12fb0009,0x55070048}},	//   uzsk, toja, _שהדב, ачва
  { {0xf806002d,0x6d470d66,0xd6570009,0x40940012}},	//   _вчин, uoja, ייכת_, _الثر
  { {0x68fc0051,0x9f59000e,0x290311f8,0x97d70012}},	//   ördu, áró_, _roja_, _نظير_
  { {0xd838009b,0x200f014a,0xd3700003,0xc2140009}},	//   gače_, íliš_, ِهِ_, ֖הּ_
  { {0x9c7c012e,0xcad70009,0x2903005e,0x7bda0097}},	// [7710] _zače, סומת_, _poja_, ætur
  { {0x3eb90028,0x82340012,0x87da0011,0x2ba70011}},	//   lgst_, زرقا, _बनाऊ, _गिला
  { {0x2007000d,0x28c60011,0x161f0011,0x2d8b0159}},	//   âni_, र्धि, _मेजर_, lpce_
  { {0xc7f70009,0x501b0009,0x35f50198,0xa3ea0011}},	//   יזבת_, כובו, йпер, मिन_
  { {0xa2f6000b,0x97580009,0xd8380159,0x7c3b09b8}},	//   _המרה_, ביאו_, načb_, ğuru
  { {0x28c60037,0x9f5f004a,0x03950014,0x15a80014}},	//   र्दि, lytä_, брия, ръци_
  { {0x1d060048,0xdfd80048,0xab2901c6,0x9b750012}},	//   сещи_, _кът_, лока_, حاتص
  { {0x5c38007e,0xd438007e,0xec38000b,0xe4380009}},	//   יטוב_, יטוי_, יאור_, ירוח_
  { {0xd5ed0020,0x93240003,0xceb2000b,0x9c7c001b}},	//   _ngà, ترون, _מין_, _sače
  { {0x29030065,0xe8f9026d,0x98be0035,0x70150009}},	//   ðja_, уло_, totā_, ֶחָד_
  { {0x6f0400c1,0x201129fe,0x201e0073,0x57460048}},	//   _poic, ázi_, gzti_, йноб
  { {0xceb2000b,0x2732009b,0x69dd03a2,0x1ae40024}},	//   ּים_, kšne_, _osse, _моєм
  { {0x9985000a,0xda780098,0x7afd0051,0x6f0429ff}},	//   _التو, _тях_, östu, _voic
  { {0xd5fa000b,0x4d39003c,0x63a808ca,0xaa58004c}},	//   אפשר, аяся_, ádno, _тичу_
  { {0x6729012e,0x58f6000b,0xb09a000b,0xd83800d9}},	//   _omej, _למסע_, _עיקר, tače_
  { {0xf74301b6,0xc0520009,0xfaf50024,0x673b001b}},	//   _нещо, _מזו_, очую, _njuj
  { {0x171b000b,0xdb070051,0xe7170009,0x7bc3005e}},	// [7720] _תופע, dujä, _לחקר_, htnu
  { {0x64480154,0xb5fb0009,0x2f310034,0x5046004c}},	//   üdis, _עליכ, iągu_, безб
  { {0x4477000b,0x69dd2a00,0xa156000b,0x889a0009}},	//   _לעיל_, _esse, צבעה_, רבעי
  { {0xbda6000a,0xdfcf0003,0x7bde0027,0x9956001e}},	//   محتو, عين_, _ispu, _kļūs_
  { {0xdee50003,0x7bc30029,0xa50a0294,0x1d0a0294}},	//   تألي, etnu, леда_, леди_
  { {0xe0c70003,0x69c40213,0x8e570009,0x865b0009}},	//   _عز_, mtie, זינג_, נדסי
  { {0x62990832,0x889b0009,0xf3ca0012,0xeb4a0048}},	//   _bewo, _תבלי, ابته_, лчик_
  { {0x11d80003,0x2b40009b,0xa037000b,0xe29f0028}},	//   لوبة_, čico_, _האלה_, _koða_
  { {0x3a200052,0x69c42a01,0xeab10009,0x84960012}},	//   nzip_, ntie, וֹי_, _هجائ
  { {0xf8d80037,0x7ae40855,0x9d46003c,0x89db0009}},	//   ड़िय, hdit, _уезд, נחיי
  { {0x32ca0047,0xd6d50015,0x70540003,0x645a001e}},	//   _было_, ожны, تندا, _uzti
  { {0x30570093,0x2057000b,0xdd12001e,0xa3e70037}},	//   משיך_, מייל_, kļūs, पिस_
  { {0xceb3000b,0x8cbf0037,0x201e000e,0x7ae403c1}},	//   היר_, ल्को, szti_, ddit
  { {0x301a0012,0x7b2c0060,0x80ca0011,0xa91b0097}},	//   _متعة_, uşun, स्मे, _etþj
  { {0x93880047,0x69c40039,0x7ae20051,0x24180015}},	//   йста_, etie, _kaot, боры_
  { {0xe29f0028,0xd1381063,0x7ae200ff,0x3b550024}},	//   _boða_, lną_, _jaot, ікар
  { {0x909902ac,0x69c425de,0xd13817c1,0x7b2c0060}},	// [7730] иват_, gtie, oną_, mşul
  { {0x29c20065,0x672f0002,0x6341001e,0x7bc3022d}},	//   iða_, licj, mēne, ytnu
  { {0x47d5000a,0xb9010037,0x660f006f,0x80ca0037}},	//   تيار, _दस_, lyck, त्ये
  { {0x672f0002,0xdb030029,0xdb1806dd,0xbebb0227}},	//   nicj, sunú, ytvá, ciët
  { {0x69c400bd,0xf7700003,0x629908ce,0xd2460012}},	//   ctie, رام_, _rewo, _آن_
  { {0xd1380002,0xdb1802d2,0x25a909d2,0x09f60009}},	//   jną_, ntvæ, šalo_, _ומשם_
  { {0xd138003e,0x9b450003,0x64980024,0x9f600031}},	//   dną_, ينتو, стір_, őség_
  { {0xc9a90098,0xd138007a,0x9c18000b,0x130900fa}},	//   авие_, eną_, מחוק_, рний_
  { {0x29c20028,0x11d60012,0x28c60011,0x20d50024}},	//   gða_, قوية_, र्वि, оінс
  { {0x6d4a0002,0x660f0066,0x3ea91470,0x69250024}},	//   cofa, dyck, _adat_, імна
  { {0xe8f6002d,0xf8b2000b,0x29c20028,0x69c4001e}},	//   ілю_, ושי_, aða_, ztie
  { {0xd5a7002d,0xdb180058,0xe7370024,0x21f50012}},	//   _вiдп, etvæ, жею_, _وكاس
  { {0x18a511ed,0xa3ea0011,0xfe460024,0xd54a0012}},	//   _далм, मिथ_, інго, لجسم_
  { {0x3f660061,0x98a5001e,0x3ea90054,0xddc90002}},	//   _cœur_, bilā_, _edat_, _sześ
  { {0x61e903fc,0xccf20009,0xb3a90009,0x9c7c001b}},	//   lvel, וכם_, יֹּ֙, _jača
  { {0xa3ea0044,0x7ae40039,0x6f1d0052,0x25ad0066}},	//   मित_, udit, chsc, šela_
  { {0x09060014,0xfce6064f,0xd838009b,0xf2d2000b}},	// [7740] опан, _допо, mača_, וען_
  { {0xb8560001,0x10890009,0xe8f70b12,0x29072a02}},	//   ођењ, שָּֽ, олу_, _jona_
  { {0x28c60037,0xdfa60012,0x97a50024,0x9c7c017f}},	//   र्षि, تحذي, зріл, _nača
  { {0xd1380002,0xdb1c000d,0x29c20028,0x645e2a03}},	//   zną_, strâ, yða_, _izpi
  { {0xd13807ff,0xbdf70012,0x6da30472,0xdd900012}},	//   yną_, قروا_, дича, روث_
  { {0x28c60044,0xbebb0070,0x68e32a04,0xe5890009}},	//   र्शि, niër, _nand, זָקָ
  { {0xb8fe0011,0x26c001e3,0x7eb60012,0x62841217}},	//   ढ़_, _ocio_, _ومسؤ, ocio
  { {0xf1a60094,0x39a6002d,0xe73a0014,0x68e30070}},	//   орон, ошов, _теб_, _aand
  { {0x29070054,0xd1380002,0xfcd60012,0x80c10011}},	//   _bona_, tną_, _ويرج, र्के
  { {0x29c2014d,0x4fc60015,0x09f7000b,0xa3ca0011}},	//   rða_, осма, קמים_, लझा_
  { {0x7ae20005,0x287b000b,0xdb0e000e,0x187b000b}},	//   _taot, ינימ, ntbó, יטיב
  { {0xd1380002,0x3f660061,0x80ca0011,0x660f2a05}},	//   sną_, _sœur_, स्ते, tyck
  { {0xbebb0070,0x63750010,0x224b0052,0xfa360003}},	//   fiër, _išna, ückt_, _براد
  { {0x32d5001a,0x62861748,0x25fc0011,0xad670012}},	//   _ấy_, _afko, _ऊपरी_, تاجه
  { {0xc04f007c,0x7d080058,0xa7570012,0xd0100012}},	//   _ці_, _mods, _وضعت, _سلة_
  { {0xdb500003,0xdb070672,0x53350024,0x8c1b0009}},	//   نَّ_, frjá, чебт, בולי
  { {0x68e3003a,0x291e00ff,0x672d2a06,0x394c0132}},	// [7750] _yand, ohta_, _imaj, oods_
  { {0x29070065,0xa5080001,0x98ac0010,0xda080012}},	//   ðna_, _мења_, rodė_, غيله_
  { {0x3cfe0037,0x645a0028,0xc1040003,0x9743001b}},	//   लाने_, ýtit, بولي, šćuj
  { {0xdb070029,0x62842a07,0x30570009,0x00570009}},	//   hujú, ccio, חשבך_, חשבת_
  { {0xbafa000b,0xd6180003,0x9758000b,0x8afa0009}},	//   _ההרש, يتها_, קידו_, _ההרי
  { {0xb97a000b,0x0395118d,0x2db80009,0x2ddc0009}},	//   _לנשי, прия, קלון_, שַׁב
  { {0xdb070026,0xeb990800,0x7ed70003,0xce950014}},	//   dujú, щий_, _وزرا, _навъ
  { {0x11d9000a,0x2732009b,0xdc3c000b,0x29072a08}},	//   موعة_, kšna_, יעור, _sona_
  { {0x94ab0003,0xd8381328,0x68e315cf,0xdb1c1c56}},	//   _نطاق_, vača_, _pand, ntrá
  { {0x2ba50039,0x61e92a09,0x9c7c001b,0x62840034}},	//   pēc_, rvel, _tača, zcio
  { {0x6f1b0656,0xd8380d1f,0x765a0034,0xc1740009}},	//   _kluc, tača_, ętym, וחץ_
  { {0xd00e0003,0xa6db0028,0xd2510003,0xe73a0063}},	//   الَ_, koðu, _كنا_, сем_
  { {0xe9ce007c,0xee37002d,0x427a000b,0x645e0002}},	//   _як_, зня_, _האנג, _szpi
  { {0xc0e5003c,0xd838001b,0xdb070064,0x1d190024}},	//   _хокк, sača_, cujú, оюсь_
  { {0x78fa0009,0x629d2a0a,0xb09a0009,0xe3b10012}},	//   _לפסו, _beso, _היצר, َرِ_
  { {0x98a5007d,0x26d90835,0xdf290012,0x000000c4}},	//   bilă_, ceso_, _وأين_,
  { {0x28c20044,0xdebb000b,0x61ed0027,0xbebb0070}},	// [7760] _शामि, _המפל, _šalj, piër
  { {0xdb1c01a0,0xc0e30024,0xddcd001b,0x62842a0b}},	//   strà, ноук, _ugaš, scio
  { {0xbc7b000b,0x7ceb0009,0x547b0009,0xd47b0009}},	//   _לנית, _הַכֶ, _לטיו, _לאיל
  { {0xb5aa000a,0xa6db0028,0xdb070029,0xdb0e000e}},	//   ماتك_, boðu, zujú, rtbó
  { {0x5fdd0037,0x7d082a0c,0x9f630031,0x5ea30012}},	//   _फैसल, _pods, évén_, رمول
  { {0x6022000f,0xac970003,0x5cc30048,0xdb070064}},	//   _címé, كنها_, есъз, xujú
  { {0x9ca70012,0xdb070064,0x6e220031,0x7d082a0d}},	//   سهيل_, vujú, szob, _vods
  { {0xdee3007c,0x612000a2,0xa6b50015,0xe80f0037}},	//   _поси, _bölg, _осущ, ाहना_
  { {0xf743035c,0xcad70009,0x63b800d9,0x51f80024}},	//   _чето, לוקת_, suvn, іною_
  { {0xf55a0003,0x78a10cac,0xf9930009,0x98a5004b}},	//   _الطب_, galv, ערת_, vilă_
  { {0x80c10044,0x61200028,0xdb1c2a0e,0x26d900b8}},	//   र्टे, _tölf, ztrá, teso_
  { {0x3f8a0039,0x9bfb000b,0xc7b3000b,0xdb1c0058}},	//   ību_, _להבט, עבר_, ltræ
  { {0x26d92a0f,0x61200060,0x78a10035,0xdb070064}},	//   reso_, _gölg, balv, pujú
  { {0x60180098,0x26d90101,0x25640028,0x98ba0066}},	//   _моля_, seso_, jöld_, ropě_
  { {0xd838009b,0xccf80066,0x7d570009,0xa6e30097}},	//   mačo_, _mně_, פילד_, áðst
  { {0x403b000b,0x083b000b,0xc7d7000b,0x60da003a}},	//   _לגוג, _לעול, _זוהי_, letm
  { {0x629d009b,0x7ae62a10,0x531b0009,0x645a0097}},	// [7770] _veso, _dakt, צומצ, ýtir
  { {0xe79b0003,0x290a00b6,0x612b0002,0x60da13a1}},	//   مخصص_, _coba_, ożli, netm
  { {0xdb1c2a11,0xdc880009,0x290a0e6b,0x6f1b06dc}},	//   strá, _מְרָ, _doba_, _pluc
  { {0x63b5012e,0xde190003,0xb7db0009,0x80c10011}},	//   mrzn, يقات_, מקבי, र्जे
  { {0x6f1b0070,0x84e50015,0xa2a00011,0xf7480012}},	//   _vluc, долж, _गज़्, ألني_
  { {0x7ae62a12,0xf9fa0009,0xfbe10011,0xf3b70009}},	//   _zakt, _והשמ, _पनाम, ִּ֔י_
  { {0x67d42a13,0x9c7c0027,0x78a107f6,0x60da0060}},	//   _пору, _tačn, valv, detm
  { {0x7b150029,0x291c14c9,0x27f801e9,0x25a6004b}},	//   _záuj, _alva_, šený_, bsol_
  { {0xe29f014d,0xc2450055,0x61200074,0x3ead0262}},	//   _með_, ьник, _föld, _idet_
  { {0x6fa90001,0x36e60011,0xdb0a0248,0x00820365}},	//   овог_, _जोड़ी_, xtfö, кльо
  { {0x6d410227,0xb0cf0011,0x68e72a14,0x78a12a15}},	//   _ijla, स्यग, _majd, ralv
  { {0xdb030029,0x09f90003,0x3b640012,0x99d50012}},	//   hrnú, _وفاة_, _كُلِ, _يقات
  { {0x7ae6039c,0x78a11082,0x0ab40012,0x7e760012}},	//   _rakt, palv, _أحمد, بادئ
  { {0x68e70ba1,0xcdb60009,0xf8cf0011,0x28cf0011}},	//   _najd, ופשה_, स्मय, स्मि
  { {0x58940003,0x2722001a,0xf0920009,0x3cfe0011}},	//   _أجهز, _nóng_, _ינג_, लाते_
  { {0x8f9a0093,0xc052000b,0xcfb6000b,0xbec8001e}},	//   _ויקי, _שזה_, _חלקי_, _brīž
  { {0xc332000b,0x61ed2a16,0x80c20011,0x64452a17}},	// [7780] דון_, gval, _लादे, _exhi
  { {0xa5b70093,0x7ae600c6,0x7ae9004a,0x2722001a}},	//   _קליק_, _wakt, hdet, _bóng_
  { {0x69c90006,0x3ce701e1,0x33660001,0x0446004d}},	//   htee, _छोटे_, _овог, _ценн
  { {0x69c90005,0x7ae60002,0xa25b0061,0xbefa0003}},	//   ktee, _uakt, _icôn, غراض_
  { {0xa5da000a,0x1dda0003,0x63bc087a,0x7ae92a18}},	//   تبار_, تباع_, lurn, ddet
  { {0xa3ea0044,0x3ea00065,0x2732009b,0xa5070001}},	//   मिल_, _leit_, kšno_, деља_
  { {0xdb1c0058,0x61200028,0x69c9004a,0xc8780060}},	//   rtræ, _völd, etee, neğe_
  { {0xf8ce001a,0x69c9002a,0xdb1c0399,0xd00b0009}},	//   _cứng_, ftee, stræ, _וּמֹ
  { {0x7b730003,0xd5d60012,0xdb1c0fcc,0x28c20011}},	//   خطوا, _تتأث, mträ, _शादि
  { {0x3d0d0044,0x69fb000b,0x63bc0028,0x7b180097}},	//   _सकें_, קליק, kurn, _síul
  { {0x9c830107,0x8c3c003a,0xe7590024,0x3d020011}},	//   _účas, _beğe, зині_, शाने_
  { {0xb3690003,0xdb1c031d,0x63bc196c,0x6722004a}},	//   _فإنك_, nträ, durn, nhoj
  { {0x8c3c00a2,0x69c900bd,0x8a030048,0x6a160012}},	//   _değe, ctee, _изце, _تبار
  { {0x63b50002,0xa3e30011,0x29030248,0x63bc2a19}},	//   trzn, _पैड_, öjat_, furn
  { {0x63bc001c,0xd7e6002d,0x58bb000b,0x3ea00070}},	//   gurn, _ціло, _ומוצ, _feit_
  { {0x61ed2a1a,0xa3b60044,0xf8ce0020,0xeb910009}},	//   _šali, _जिन_, _xứng_, רָם_
  { {0x41790003,0x2722001a,0xd56705f8,0xaa580024}},	// [7790] سماح_, _sóng_, _отоп, диту_
  { {0x3ea0008b,0x7ae9000e,0x3f870017,0xf8b10009}},	//   _zeit_, zdet, ínuo_, ָשׁ_
  { {0x753501a2,0x6365000e,0x61ed2a1b,0x7ae90774}},	//   mizz, lóne, sval, ydet
  { {0x7535034e,0x19950021,0x69c9004a,0xf9930012}},	//   lizz, _памя, ytee, _لبس_
  { {0x2ee900b6,0xa3e70011,0x69c90132,0x25a90025}},	//   _maaf_, पिक_, xtee, éal_
  { {0x753500c1,0x2edc0037,0x236605b1,0xe3b10012}},	//   nizz, _बस्त, _ahoj_, هرب_
  { {0x4fc405fb,0xc7c4193d,0xfbd10012,0x86990557}},	//   _иста, _исти, اتت_, _нквс_
  { {0x69c90006,0xc2c50003,0xcc78000b,0x213e002a}},	//   ttee, ريخي, וגות_, enth_
  { {0x7ae90272,0x9135002d,0xe1f10003,0x28cf0037}},	//   rdet, ехні, اسب_, स्थि
  { {0x3ea0008b,0x69c92a1c,0xc51b0012,0x7bca0132}},	//   _seit_, rtee, _بغرض_, btfu
  { {0x309a000b,0x6be40003,0xa5bb000e,0x69c91165}},	//   השתמ, _لكلم, szól, stee
  { {0xc4c9000b,0x28cf0037,0x6120000e,0x6f0d0cfa}},	//   _לג_, स्ति, _kölc, _coac
  { {0x6b810051,0xceb2000b,0x59c40003,0x3ea02a1d}},	//   _hulg, ניך_, _لينك, _veit_
  { {0x52380003,0x3ea00052,0x59d80011,0x4aa50011}},	//   _تسمح_, _weit_, _बैटर, _ऐ़डव
  { {0xf8b2000b,0xc878003a,0xd91a000b,0x6b812a1e}},	//   _עשה_, teğe_, _מוסל, _julg
  { {0x62890058,0xf7d60009,0x63bc0097,0xd83e0030}},	//   nceo, _נופש_, rurn, íčem_
  { {0xda1f0011,0x22460060,0xcdaa0012,0xe9d7016e}},	// [77a0] यनित_, çok_, _عهده_, нкт_
  { {0x753501a2,0x63bc0f92,0x22590002,0x8d760012}},	//   cizz, purn, _dysk_, _ثابا
  { {0xdc9b0009,0x7c9b0009,0xa3e70011,0x031a0012}},	//   _מייל, _משיג, _मैप_, _فتحت_
  { {0x26c2002c,0x73e301d4,0xe5c6070f,0x70530012}},	//   ngko_, _союз, еско, دنما
  { {0xed5a0046,0xceb3000b,0xc27b000b,0xdb1c1ad3}},	//   под_, ריד_, _מרכי, rträ
  { {0x61e6001c,0x2b40007d,0x53e605cc,0xdb1c0c60}},	//   _iskl, lnic_, ециа, strä
  { {0x6d5c0028,0xe3af0012,0xd9430c1e,0x22590034}},	//   ilra, مري_, _сери, _zysk_
  { {0x200d003a,0xca320009,0x28c20011,0x6d5c0032}},	//   çmiş_, ָם֙_, _शाहि, hlra
  { {0x98ac001e,0xa3e70011,0x7bca0987,0x1ddf05f3}},	//   eidā_, _मैन_, stfu, _पैंत
  { {0xf1b3000b,0x2b402a1f,0x104a0024,0xd8f80024}},	//   נסת_, hnic_, зями_, фної_
  { {0x443801ab,0x3137000b,0x89370009,0x5bc50012}},	//   _är_, תנים_, תריע_, _لتنف
  { {0x8c1b000b,0xd7bb0009,0x657a0132,0x0b460024}},	//   _מובי, הצטר, _hith, _янен
  { {0x753500c1,0x4b370009,0x67d30030,0xb71404a5}},	//   tizz, _אראל_, mějš, удящ
  { {0xe4e4002d,0x2b400027,0x93970012,0x636501e3}},	//   лісн, čicu_, فجرا, róne
  { {0x75350d20,0x3957000b,0x657a2a20,0x7b67003c}},	//   rizz, _רשום_, _mith, етае
  { {0x3f870065,0x67d30066,0x443f000d,0x5c740048}},	//   ínum_, nějš, ău_, улст
  { {0x7b640015,0xbb3b0009,0x78a5005e,0x645a0073}},	// [77b0] утре, פעמי, tahv, _lyti
  { {0x3da40014,0xba740012,0xc2370009,0xda4b0009}},	//   _сръб, طاقت, גרמו_, הֲבָ
  { {0x7b1c0061,0x4427006f,0x78a50051,0xe8df0081}},	//   _réun, _ån_, rahv, _ngục_
  { {0xf770000a,0x8ccd0037,0xdb010042,0xb5950024}},	//   مان_, द्रो, _ovlá, видш
  { {0x6b810051,0x64630027,0x7aed2a21,0x1bf90011}},	//   _sulg, štić, mdat, ऍमऍल_
  { {0x271e0044,0xdbdd0065,0x7aed27ba,0xb8200011}},	//   _पत्र_, ráæt, ldat, मनाम_
  { {0xfaf10003,0xb3e80012,0xcb690012,0xe6950012}},	//   لثة_, فعيل_, ومته_, _للأد
  { {0xe29f0065,0x657a002a,0x52750014,0x6b812a22}},	//   _boði_, _eith, купу, _vulg
  { {0x22590040,0xea880012,0x63b80159,0x6b810034}},	//   æsk_, رخين_, arvn, _wulg
  { {0xcda80012,0x3f83005e,0x6b81005e,0x70850048}},	//   _أهله_, _kuju_, _tulg, ъгоз
  { {0x28c60037,0x69cd0574,0x34940001,0x7aed2a23}},	//   र्टि, htae, _сахр, kdat
  { {0xa295007c,0x7afd00b0,0x81c30035,0xeb980024}},	//   _раді, _nnst, ģēju, _чиї_
  { {0xf772000b,0xee320009,0x7aed2a24,0x7aeb0040}},	//   יקט_, ֹֽר_, ddat, _iagt
  { {0x32dc001a,0xe0d90024,0xb19a0009,0xdbdc0097}},	//   _ậy_, _цвк_, _חיסכ, _báða
  { {0xa1560001,0xdb010042,0xf8b60009,0x03a3003c}},	//   _шаљу_, _zvlá, _ספקי_, ииро
  { {0x7aed002c,0x78a3024c,0x2b040011,0x2aec0011}},	//   gdat, _henv, वायु_, ढ़ाएँ_
  { {0x7aeb1223,0x98a50002,0x2b402a25,0x60260025}},	// [77c0] _magt, wilę_, rnic_, _témé
  { {0x7aeb006f,0xa9060012,0xf1b90073,0x7afd2a26}},	//   _lagt, خبرن, irš_, _enst
  { {0x98ac000d,0xa3ba0012,0xdff50024,0x1cb70009}},	//   lidă_, _غادر_, ляць, _בליל_
  { {0x7aeb0101,0x9c7c0027,0x28c60011,0x75210032}},	//   _nagt, _tačk, र्जि, _allz
  { {0x67d30066,0x2ca70052,0xd7070048,0x61e62a27}},	//   vějš, fand_, ънце_, _uskl
  { {0xd94612f2,0xda4b0009,0x8d63091c,0x9c7c2a28}},	//   _реги, _חֲלָ, авче, _kači
  { {0x67d30066,0x4fa3002d,0x7bce2a29,0xd8d70009}},	//   tějš, _висв, ntbu, _שולט_
  { {0x657a0036,0xf413000b,0x645a05b1,0xdd920012}},	//   _with, שפה_, _vyti, _نور_
  { {0xcb670001,0xdb1c0061,0x78a32a2a,0x11d80012}},	//   њање_, guré, _benv, رودة_
  { {0x31050037,0x61e40052,0xd1050011,0xbce50012}},	//   रायः_, iwil, रायण_, _مأمو
  { {0x61ed0010,0x7aed27bc,0x2d570009,0x61e42a2b}},	//   _šalt, ydat, _ישמש_, hwil
  { {0x78a30070,0x9c7c0082,0xb8f90037,0xd838017b}},	//   _eenv, _nači, _डॉ_, nači_
  { {0xfb1b0093,0xa3ea0037,0x7e470024,0x61e40227}},	//   _קודמ, मिक_, тхне, jwil
  { {0xba3b0070,0xc27b0009,0x78a32a2c,0x69c02a2d}},	//   _beïn, _חרדי, _genv, mume
  { {0x6365000e,0x2d840d41,0x94740012,0xd00f0024}},	//   lóna, _lume_, لدفا, _тф_
  { {0x2bb8000a,0x69cd0006,0x0857000b,0x3ea40058}},	//   ضافة_, ttae, _שבהם_, _nemt_
  { {0x2d84007d,0x60f90047,0x28a70015,0x58d50345}},	// [77d0] _nume_, нная_, вшег, лоат
  { {0xdce80013,0xd499002d,0x7bda0027,0x9dd6000b}},	//   _vidě, _якої_, _optu, _עותק_
  { {0xba3b00bd,0x56950015,0x442a0002,0x7aed2a2e}},	//   _geïn, гает, czb_, pdat
  { {0x69cd0065,0x4e940003,0x141a000b,0x2ca70052}},	//   ptae, لشهر, _נורב, wand_
  { {0x7bda0039,0xd1380010,0x4ed4002d,0x63650097}},	//   _aptu, kią_, рюєт, jóna
  { {0x9c7c0029,0x3fb70003,0xdb030028,0x7aeb0f8f}},	//   _zači, _لإرس, rsní, _sagt
  { {0x7aeb0101,0x31340047,0x78a30061,0xa5bb0031}},	//   _pagt, _терр, _renv, szóh
  { {0x3ea40058,0xbc7c000b,0xdb1c0025,0x39e9004c}},	//   _gemt_, ונות, turé, едио_
  { {0x78b20028,0x6d55000e,0x2ca70503,0x80ca0011}},	//   _ákvö, koza, pand_, स्के
  { {0x78a8000e,0xfd100003,0x600905f0,0x645a005e}},	//   gadv, _وجل_, еном_, ütik
  { {0xc1d00037,0x6bb4002d,0xdb1c0061,0xec150012}},	//   _सङ्ग, _всіє, suré, _حواد
  { {0xc9f50003,0x8cd60037,0x2ca52a2f,0x8b9a0009}},	//   _مستع, म्नो, _held_, _נבנת
  { {0x6d430108,0x2d840061,0xef170593,0x9a840048}},	//   onna, ême_, умя_, _тухл
  { {0xd1380002,0x3eba0010,0x27220054,0x9c7c001b}},	//   cią_, ėpti_, _dóna_, _sači
  { {0x9c7c007a,0x2ca528f8,0x9f060003,0xb8f70011}},	//   _pači, _meld_, _موثو, ाभ_
  { {0x28cf0044,0xa3b60044,0x98ac000d,0x2732009b}},	//   त्रि, _जिस_, pidă_, kšni_
  { {0xd5af0003,0xd8382a30,0xf8a70011,0x6724001b}},	// [77e0] _ففي_, vači_, _ग़ाय, _ilij
  { {0x8ca50037,0x28cf0037,0x68e12a31,0x859b0009}},	//   करणो, स्लि, neld, _רשיו
  { {0x6724001c,0x9c7c007a,0x9b460003,0x0577000b}},	//   _klij, _tači, _مندو, _תגים_
  { {0x643b000b,0x68e10e44,0x44220035,0x6d432a32}},	//   _טעינ, held, _āk_, enna
  { {0xdd8f000a,0x36360003,0x4dd30003,0x01660003}},	//   كون_, دراس, متوس, _مُحَ
  { {0x3fa60003,0xdb180028,0x68e10118,0xb5fd0159}},	//   _مصرف, ruví, jeld, _izšl
  { {0xd499002d,0x68ef0066,0x68e10647,0xd826003c}},	//   трі_, řidá, deld, _сдви
  { {0x25ec0037,0xd1380002,0xdc08001e,0x63650f9b}},	//   _आईपी_, wią_, dēļa, tóna
  { {0xda040037,0xdb0a0061,0x2ca50052,0x86460001}},	//   रमित_, nsfé, _feld_, _снаж
  { {0x68e10b7d,0x2ca501e0,0x9e4b0009,0xdb010248}},	//   geld, _geld_, _אֲבִ, _avlä
  { {0x672400bd,0x3957000b,0xd1380915,0xad1b000b}},	//   _blij, רשים_, rią_, _רובר
  { {0xd1380010,0x39890028,0x68ee10d8,0xcf270012}},	//   sią_, _fús_, _labd, اردي
  { {0x6d552a33,0x3d160011,0x6f1d29a1,0x68e12a34}},	//   toza, _नकशे_, rksc, beld
  { {0x7e7d0026,0x672428c0,0xf9930009,0x2eed0159}},	//   _úspe, _elij, _הרס_, žef_
  { {0xa3ea0037,0xd5280081,0xdb030097,0x6d551a3e}},	//   मिट_, _cổn, runö, roza
  { {0x57fb000b,0x322b002d,0xab62003a,0xf2070048}},	//   _טלוו, нізм_, şünc, лязо
  { {0x2d84000e,0x29112a35,0xba3b0227,0x6d5a2a36}},	// [77f0] ímet_, _poza_, _geïl, _okta
  { {0xdb080030,0x3eb80035,0x63650097,0xc274004c}},	//   ělát, _ērta_, jónn, слуј
  { {0xa2d00037,0x7aee004a,0x645e005e,0x6724008e}},	//   _डॉक्, öntä, üpil, _ylij
  { {0x539a0093,0xef1f003a,0x2564006f,0x6d5a2a37}},	//   _שירו, nkü_, höll_, _akta
  { {0xdbde0065,0x63650026,0x66050055,0x3f660025}},	//   _síða, fónn, рпла, _vœux_
  { {0x91ba0009,0x0bb50048,0x8b050034,0x66190034}},	//   _במשי, ащия, _mięś, rywk
  { {0x0d18000b,0x2ca50070,0x6341001e,0x68e12a38}},	//   רקוט_, _veld_, lēni, veld
  { {0x63a10029,0xd2510003,0x11d90003,0x8c38000b}},	//   álny, ينغ_, نوعة_, טטוס_
  { {0x13060015,0x629b0010,0xaa450686,0x25640248}},	//   рный_, rbuo, репл, föll_
  { {0x6724001c,0xbdf80003,0xe8f601d4,0xdb1c162e}},	//   _slij, _حرفا_, аль_, strø
  { {0x6c84000a,0x1bb80003,0x52b50003,0x63480066}},	//   _المم, _مانع_, _نماذ, měnn
  { {0x539a0093,0x25a0007d,0xa856000b,0x67f0000e}},	//   _ייעו, ţile_, ייתה_, lójá
  { {0x7b740003,0xaa880003,0x645e0034,0x78b50159}},	//   _اطلا, _إنهم_, _sypi, _odzv
  { {0x78a70013,0x4a44002d,0xdb0a0052,0xc244002d}},	//   _nejv, _унів, zufü, _унік
  { {0xbb560003,0x7ce80009,0xa9560009,0x913a0009}},	//   لنسب, נַשֶ, _דיסק_, _בעסק
  { {0x95860406,0xc3230001,0xc7b2000b,0xf7720012}},	//   _клие, омск, _ובה_, _بات_

  { {0x645e0002,0xb6060010,0x2f5b0009,0x88ca0024}},	// [7800] _wypi, ukšč, _בדקנ, клав_
  { {0xd528001a,0x09030001,0xba3b0070,0xb6060073}},	//   _tổn, опун, _geïm, rkšč
  { {0x2ba50037,0xb7e60024,0x94bb0009,0x78a709ef}},	//   गीदा, ржек, _במית, _dejv
  { {0xb5aa000a,0x3f870065,0xe8060037,0x8f45002d}},	//   ناتك_, _munu_, षमता_, бхід
  { {0xcd06011f,0x68ee0073,0xa5bb0031,0x550609e8}},	//   ички, _tabd, szóv, ичка
  { {0xb7960001,0x7bc30028,0xa533002d,0x21a30c1e}},	//   _враћ, funu, оніч, _фирм
  { {0xb2260028,0x9c7c0066,0x237f01bd,0xfba7003c}},	//   kvæð, _načt, ňuje_, атый_
  { {0xb024008a,0x7ae40add,0x7bf70048,0x3eab2a39}},	//   _ngườ, neit, рнър_, xact_
  { {0x9c7c0331,0xdb1d000e,0x7bc3001e,0x69c42a3a}},	//   _raču, ézés, aunu, nuie
  { {0x7bde01a2,0x3f8700a2,0x9c7c001c,0x33d6002d}},	//   _oppu, _bunu_, _saču, _відт
  { {0x7ae42a3b,0x25ec0037,0xe838002d,0x61eb0054}},	//   keit, _आईडी_, упні_, _esgl
  { {0x61240054,0xdc3b000b,0x7ae422df,0xe29a05c6}},	//   _dòla, _בעבר, jeit, _рад_
  { {0xb9940003,0x9f65000e,0xc3050003,0x7bde167a}},	//   _التب, ítés_, _دبلو, _appu
  { {0x621b000b,0xfbd30012,0x7c840365,0x61200060}},	//   _בודק, يتز_, жуте, _bölm
  { {0x80aa0044,0x92a70046,0x6b88002a,0x7ae40017}},	//   टरने, ијал, _judg, feit
  { {0xa87b007e,0x307b000b,0x6d580107,0x987b0009}},	//   _באור, _באונ, hova, _ברוק
  { {0x69c402d1,0x673d2928,0x6d560028,0x7bc30060}},	// [7810] guie, misj, ófað, zunu
  { {0x6d5800d9,0x3ea92a3c,0xd46b0012,0x3d150011}},	//   jova, _heat_, _لحجم_, _तकें_
  { {0x7ae4008b,0x7e690540,0x9a870024,0x6d47001b}},	//   beit, _szep, _вугл, mnja
  { {0xbf58002d,0x673d0033,0x7784002d,0x7ae42a3d}},	//   арії_, nisj, іліз, ceit
  { {0x67f0000e,0x3ea90132,0x69c4004b,0x6aad016d}},	//   tójá, _meat_, cuie, maaf
  { {0x0d98000b,0x2a76000b,0x64980014,0xc27a000b}},	//   סכום_, _לערך_, атър_, _תרשי
  { {0x16a70011,0xbbf50012,0xe4d60012,0x62860064}},	//   _ख़ूब, إستث, صويت_, ľkon
  { {0x68e5004a,0x7bc32a3e,0x0ae9003c,0x63652a3f}},	//   lehd, runu, удий_, róno
  { {0x673d0033,0x7bc32a40,0x63480030,0x9f520030}},	//   disj, sunu, měnl, ízí_
  { {0x7ae40052,0x6d5800f1,0x3f870027,0xd5140012}},	//   zeit, cova, _punu_, _وبلغ
  { {0xbb85000a,0x14190003,0xdb180028,0x753c001e}},	//   _الصي, _حياة_, duvæ, virz
  { {0x6d4700c6,0x2d81004a,0x28360009,0xfeba0012}},	//   enja, _aihe_, מנתך_, دادت_
  { {0x98780039,0xcb12000b,0x6120006f,0x7ae42a41}},	//   kšķi_, _מלא_, _dölj, veit
  { {0x4095000a,0xb2260065,0x7ae4008b,0xd656000b}},	//   _الغر, svæð, weit, מירת_
  { {0x61200163,0xc7950003,0x232a0294,0x89340012}},	//   _följ, _اشتب, гови_, _بعنا
  { {0xe7ec0037,0x04430594,0x70a70011,0x6d582a42}},	//   _जनता_, чесн, _ग़ुल, zova
  { {0xdb0e000e,0xe0da0867,0x6d470027,0x7ae42a43}},	// [7820] ájék, лва_, bnja, reit
  { {0x6d58022d,0xd00a0014,0x7ae42a44,0x61460024}},	//   xova, лезе_, seit, щеза
  { {0xf989000b,0x6d5814f9,0xdfcf0012,0x1d170009}},	//   תר_, vova, فيل_, _הקיר_
  { {0xc68f0003,0x99800029,0x3f9a00b6,0xdb030248}},	//   ِّن_, dziť_, rppu_, nsnä
  { {0x9c7c012e,0x69c42a45,0x09f60024,0xdbe30097}},	//   _načr, quie, _учня, _héða
  { {0xdb1c005e,0x6d5815e4,0x63480030,0x61e92743}},	//   htrü, uova, těno, dwel
  { {0x2bb70003,0x661d0002,0x63a4001b,0x3cf70012}},	//   ماية_, zysk, ćino, صعود_
  { {0xfbd30093,0x070c0037,0x6d5822bc,0x9b440012}},	//   פתח_, _सचिव_, sova, تنعو
  { {0xc8cf0044,0x4420001e,0xdb1c0a8e,0x673d2a46}},	//   स्कट, ņi_, ltró, visj
  { {0x3ea9002a,0x644f0002,0x57b400b3,0x6440003a}},	//   _seat_, _ście, обот, şmiy
  { {0xa3e70044,0x6d47012e,0x515b000b,0xf1b90029}},	//   _मैं_, vnja, רכיו, vyše_
  { {0x487b000b,0x672203ec,0x0dcb0247,0x52860012}},	//   טטיס, nkoj, луги_, _الإك
  { {0x6d4702a1,0x2018005e,0xa2f70009,0x67222a47}},	//   tnja, ärib_, _למאה_, ikoj
  { {0xea77000b,0x673d0033,0x3f98001e,0x71730012}},	//   _הגדר_, sisj, _otru_, _فهنا
  { {0xb8de0037,0x6722004a,0x3cf00011,0x5c04003c}},	//   ेल_, kkoj, _इसने_, пята
  { {0xd3700003,0xc2c50012,0xc3340009,0xc2140009}},	//   ّهِ_, تيري, קוּ_, ֗הּ_
  { {0x60870003,0x201e0010,0x5ee80009,0x88870012}},	// [7830] مشاك, lyti_, _הַתְ, مؤام
  { {0x6d402a48,0x67220035,0xdb18079b,0xf8070472}},	//   émat, ekoj, luvä, йчен
  { {0xc1040003,0x7e990012,0x201e0073,0x69c00032}},	//   ثولي, لنار_, nyti_, hrme
  { {0xe2f9002d,0x68e5004a,0x959903cc,0xdb18005e}},	//   _темі_, sehd, атку_, nuvä
  { {0xceb40009,0x2f740012,0x69c00040,0xd5bb09c6}},	//   פיס_, أطلس, jrme, усе_
  { {0x201e007a,0xa19404ad,0x0395022a,0x2d810052}},	//   kyti_, _харч, ория, öhe_
  { {0xdb1c2a49,0xeb9901d4,0xad1c0009,0x7bd50032}},	//   ctró, ший_, רוור, ntzu
  { {0x201e007a,0xb065004a,0x63650366,0xa8480012}},	//   dyti_, hdää, pónm, _الفم_
  { {0xe6130003,0x61e90227,0x02050024,0x3eaf0040}},	//   _عشر_, uwel, ізон, magt_
  { {0xe0d60015,0x78a90001,0x7bc72a4a,0xdca4004c}},	//   овь_, шког_, kuju, _нађи
  { {0x18690ac5,0xa93a000b,0x073a0012,0x69c02a4b}},	//   рани_, שתתפ, لسحب_, arme
  { {0xa6db0028,0xdb18005e,0x213e0132,0x373a0024}},	//   eiðb, guvä, aith_, рчою_
  { {0x20d5002d,0xe9ce0024,0x22920012,0x7e6d0034}},	//   _дійс, _юк_, _غلوس, _czap
  { {0x61200052,0x2bc60011,0x23dd0011,0xfbdd0011}},	//   _völk, रूवा, _महाद, _महाम
  { {0xe3a70003,0xe1f90010,0x0caa0011,0x9c290009}},	//   بر_, lvų_, _क़ीम, בֵּ֥
  { {0x79830052,0xab66002d,0x5f760012,0x6f042a4c}},	//   _hinw, івал, _باتر, _unic
  { {0x6aab000f,0xdb1c0813,0x80aa0024,0x7bc70073}},	// [7840] _megf, gurá, ивав_, auju
  { {0x6aab000f,0xa3ba0011,0x67292a4d,0xb09a0024}},	//   _legf, _अटल_, _alej, ртає_
  { {0x61ef1278,0x7bc7001b,0xa1560009,0x6ecd0031}},	//   _escl, cuju, קבעה_, zőbő
  { {0xd6d9002d,0xdb1c000e,0x9e66065d,0xa02600e6}},	//   йті_, rtró, овед, ltöö
  { {0x2ee6002a,0x6df60012,0x88c60012,0x3f870097}},	//   reof_, تكشا, _وتسل, ínur_
  { {0xdb1c03eb,0x7af6007a,0x412a064f,0x6729000e}},	//   ctrò, ldyt, _того_, _elej
  { {0xdcfa0039,0x7af60010,0x66e60012,0x8afa0009}},	//   _citā, odyt, _وأرق, ֹהִי
  { {0x7af6007a,0x6729009b,0xa0370009,0x539b0009}},	//   ndyt, _glej, _ואלה_, ביקו
  { {0x90d5001a,0x05d10037,0x69b20011,0x7bc7001b}},	//   rìn, _समयब, ेंटी, zuju
  { {0x201e007a,0xdce80039,0x6d5c2a4e,0x7af6008e}},	//   tyti_, _vidē, jora, hdyt
  { {0xf0930093,0x7af60010,0x99e30029,0x2918048b}},	//   ונת_, kdyt, ĺňaj, _mora_
  { {0x201e007a,0xc878003a,0x79830052,0xd7f8000d}},	//   ryti_, neği_, _einw, rvă_
  { {0x201e007a,0xceb3000b,0x7bc700b6,0x3f98001e}},	//   syti_, ויר_, wuju, ūru_
  { {0x7bc7051f,0x01330012,0x201e0073,0xa3a7004c}},	//   tuju, _يعود, pyti_, жјак
  { {0x68e82a4f,0x389b000b,0x442501bd,0x2aab004c}},	//   medd, _דיונ, ál_, итао_
  { {0x7bc702df,0x28dd0011,0x6d400025,0x7bd50032}},	//   ruju, न्नि, émar, rtzu
  { {0x8c3c00a1,0x5a350014,0xa4870003,0x7bd50052}},	// [7850] _deği, чнат, _وجدن, stzu
  { {0x6729001e,0x9967002d,0xdb0a0052,0x6365000e}},	//   _slej, італ, erfü, tónk
  { {0x7af6007a,0xd7c80012,0xa2950024,0x67292a50}},	//   bdyt, قوله_, _нані, _plej
  { {0xf770000a,0xe1f90010,0xcc760009,0x53190009}},	//   نان_, yvų_, _מעתה_, _הוֹצ
  { {0xd2460351,0x80d80037,0xc1780010,0xed4e0001}},	//   _أن_, न्हे, kmė_, ео_
  { {0xd0060351,0x427a000b,0x68e80033,0x3eaf1111}},	//   _كل_, _לארג, jedd, sagt_
  { {0xdb18005e,0x61e22a51,0x63652a52,0xa4bc00af}},	//   htvõ, _apol, lóni, שֶׂי
  { {0xc87800a2,0x1309002d,0x67290058,0x4acb0011}},	//   ceği_, сний_, _ulej, िलिव
  { {0x63650b45,0x95670048,0x7b1c0025,0x61ed2a53}},	//   nóni, _дъжд, _réut, nwal
  { {0x2cb10002,0xa8190012,0x3ead0227,0x7c070012}},	//   jazd_, متجر_, _heet_, _وباك
  { {0x25a906db,0xaf0a0012,0xe8f60024,0x3f850025}},	//   _awal_, مقدم_, їлю_, _élus_
  { {0xd5b80039,0xf7720003,0x61ed2a54,0xe7370024}},	//   ņām_, عاد_, kwal, зею_
  { {0x7ae90051,0xa026004a,0x3ead0087,0x63650028}},	//   meet, ttöö, _meet_, jóni
  { {0xc27a000b,0x6d5c0603,0x865a0009,0x6a240012}},	//   _פרסי, uora, מדרי, _تفهم
  { {0xf0920093,0x69c90feb,0x836a0012,0x290717ca}},	//   _אנו_, luee, مصرف_, _inna_
  { {0xa0260005,0x69d6004a,0x63650b45,0x291807bd}},	//   stöö, ttye, fóni, _sora_
  { {0x63b5000f,0x61fb1b74,0x229c0066,0x7bc30042}},	// [7860] aszn, nvul, jáků_, hrnu
  { {0x0e57000b,0x61fb004a,0xdcb1001a,0xa6db0028}},	//   _משפט_, ivul, ửa_, miða
  { {0xc878003a,0xa6db0028,0xe9ff001a,0xf1a90009}},	//   teği_, liða, _tiếc_, רס_
  { {0x2d850d2f,0xdfcf0012,0x62860064,0x69d6020d}},	//   _aile_, طيه_, ľkok, ptye
  { {0x5dda05fb,0x5e5a0012,0xbdf70012,0x7ae9005e}},	//   сфер_, حجاج_, كروا_, deet
  { {0x2b91001a,0x63480066,0x644f0002,0x75890024}},	//   _bác_, měni, _ścia, ісів_
  { {0x2b91008a,0x9c7c012e,0xbea6002d,0x3ead2394}},	//   _các_, _obče, _навк, _feet_
  { {0x93fb0093,0xb9981128,0x290703d5,0xe73a0014}},	//   מלצי, ових_, _anna_, _уеб_
  { {0x2d8505a3,0x68f5003a,0x05760012,0xd6cf0012}},	//   _file_, _yazd, _فائد, _حقق_
  { {0x859b0093,0x3a37000b,0xe58b000b,0x29180028}},	//   _לשמו, פרים_, _הָאָ, ðra_
  { {0x7d080e46,0x61ed003e,0x69c4008b,0x4c9b0009}},	//   _inds, zwal, hrie, _השבע
  { {0x2d85007d,0x69c42a55,0xa6db0097,0x68e81a15}},	//   _zile_, krie, fiða, sedd
  { {0x98be0010,0x7bca0028,0x8afb0009,0x31e50012}},	//   entą_, lufu, _להאי, _يسهّ
  { {0xc16f007c,0x14df0037,0xda7b000b,0x2d8525cf}},	//   _її_, प्पण, _הנדר, öle_
  { {0x2b910020,0xf8db000b,0xd8db000b,0x60db000b}},	//   _xác_, _החומ, _הקור, _הקונ
  { {0xae9b0003,0xe3b00003,0x539b000b,0x7ff30012}},	//   _اضغط_, طرف_, מילו, _أسوا
  { {0x76bc000b,0x69c419a5,0xdebc000b,0x8ccd0011}},	// [7870] _המחפ, grie, _המחל, _सालो
  { {0x395e0039,0x63650dee,0x61ed00f7,0x3202004a}},	//   nots_, róni, rwal, äkyy_
  { {0x290700a2,0x68f50027,0x3d100011,0x2d85004b}},	//   ına_, _vazd, ढाने_, _rile_
  { {0x2b91001a,0xe6bf0011,0xdb07008e,0x248f0073}},	//   _rác_, ्लिङ, usjä, šomą_
  { {0xff500003,0x69c4000d,0x41e4002d,0x12fa0009}},	//   دخل_, crie, _піра, _והרב
  { {0x3ead00bd,0x85e8002d,0x644e009b,0xfdf80009}},	//   _weet_, ядів_, šniš, פצות_
  { {0x67260065,0xc952000b,0x395e001e,0x3ead019a}},	//   ykkj, _סמל_, dots_, _teet_
  { {0xb4ac0044,0x2564000f,0x394c002a,0xe1f10003}},	//   _कड़ी_, lölt_, ends_, نسخ_
  { {0xdb24000f,0xedd50003,0x2018004a,0x1dd10321}},	//   érés, _زياد, ärin_, _समित
  { {0x2b910020,0x3eb8001e,0x8d740012,0x05740012}},	//   _tác_, _ērti_, _كالا, _كالد
  { {0x61200065,0x69c40026,0x7ae90051,0x916c001a}},	//   _tölv, zrie, peet, uốn_
  { {0x98ad00a2,0x26cf0167,0xcf3a002d,0xe28e0001}},	//   ının_, nggo_, ічні_, _ја_
  { {0x6120000f,0xb5fd0029,0xee3701d4,0xc3320009}},	//   _költ, _myšo, дня_, _בוא_
  { {0xdce80010,0x28d40011,0xe045004c,0x68450288}},	//   _didė, _दायि, _онли, _онла
  { {0x3cf00044,0x6601001e,0xb09a0009,0x289a0009}},	//   _इससे_, ālka, _ויצר, _ויצא
  { {0x6d430167,0x61ed0010,0xa6db0028,0x82f50048}},	//   hina, _šaly, liðn, нчуц
  { {0x79870070,0xb6bb0009,0xaa4307e8,0xdb070097}},	// [7880] _bijw, _וצפי, ветл, yrjö
  { {0xa6db0028,0x69c6009b,0x25640028,0xbca60012}},	//   niðn, škeg, tölu_, _تمدي
  { {0x28dd0044,0x6f1b0061,0xc059002d,0x5fc50011}},	//   न्धि, _bouc, пії_, _विफल
  { {0xf4130093,0x7d1a0005,0x6d43007a,0x3f9c001e}},	//   _ספר_, _sots, eina, īvu_
  { {0xdd8f000a,0x61200028,0x9f65000e,0x6f1b0061}},	//   لون_, _sölu, ítás_, _douc
  { {0x6d4e0052,0x628b0031,0xfe370009,0x7bca1683}},	//   nnba, _aggo, ורני_, tufu
  { {0xfbcf000a,0x3219008e,0x7bd8005e,0x6d4e2a56}},	//   لتي_, äsyn_, utvu, inba
  { {0x1b77000a,0xa6db0028,0xdee60012,0xcc570009}},	//   وصية_, eiðn, _تأسي, ובצי_
  { {0x63650065,0x44230002,0x51f8002d,0x395e001e}},	//   jónu, zyj_, їною_, tots_
  { {0x61200065,0x394c002a,0x66e10037,0xb5fd0042}},	//   _tölu, unds_, ग्नक_, _myšl
  { {0x395e001e,0xcb6a035b,0x8c260012,0x99820030}},	//   rots_, _даже_, _تفاه, šků_
  { {0xd80b0009,0xb2260198,0x43930024,0x612011af}},	//   קִיָ, _омел, _раїс, _köls
  { {0x66640014,0xaac50003,0xde640014,0x0e6b0012}},	//   върз, _أتمن, върп, تصدي_
  { {0xb3470149,0xe4e4002d,0x6353000d,0xdb150031}},	//   _opçõ, кісн, măna, mszé
  { {0x61e60010,0x98130012,0x3dc60132,0xd30f0081}},	//   _apkl, _لبيا, hrow_, _mệnh_
  { {0x68f800c5,0xd30f001a,0x44230002,0x8c1b000b}},	//   _havd, _lệnh_, ryj_, חולי
  { {0x83840015,0xe2a60097,0x0975003c,0xfb1b0009}},	// [7890] тыре, óðan_, егаю, קוממ
  { {0x6f1b11ff,0xe6a70011,0xceb90030,0x25760040}},	//   _souc, खर्ज, _moře_, vælg_
  { {0xa3d6015f,0xa3e70037,0x6f1b1f62,0x2564000e}},	//   _समय_, _मैच_, _pouc, rölt_
  { {0x6d4300b6,0xcaa70003,0x5f740012,0x7e550024}},	//   wina, _تصدي, نانر, нвеє
  { {0xd30f001a,0x6d432a57,0xba9a0009,0xaa9a0009}},	//   _bệnh_, tina, _מסרי, _מברכ
  { {0x0d84007c,0xc4c90037,0x8cda0037,0x3ea6002c}},	//   влін, रलेख, प्लो, abot_
  { {0x61320058,0xdb15000e,0xac960003,0xf8b20009}},	//   _sælg, eszé, رنيا_, _תשל_
  { {0x7bc70051,0xdb1c2a58,0xae0f0011,0x86c40012}},	//   irju, orrá, ामान_, _ليفن
  { {0x6120000f,0x2734001a,0xa2d00037,0x20d50024}},	//   _tölt, _hãng_, _धार्, нінс
  { {0x61322a59,0x63a9001c,0x63ba009b,0x9873001e}},	//   _vælg, ćenj, štni, ežāk_
  { {0xd0090469,0xbd68004c,0xa7790009,0xf6490009}},	//   чене_, _црте_, ּרָפ, _פצ_
  { {0xdb0a0163,0xdb1c0061,0x3f910060,0xabfa0009}},	//   gsfä, ntrô, _muzu_, _מהער
  { {0xa6db0028,0xa2270003,0x9a270012,0x27340081}},	//   miðl, _تراه, _تعان, _lãng_
  { {0x721a000b,0x7afb0051,0xdd8f0012,0x61320040}},	//   _מונח, ldut, صوف_, _kæle
  { {0x7aed002a,0x63650028,0x98ba000d,0x27340081}},	//   feat, sónu, hipă_, _nãng_
  { {0x14170003,0xdcb1001a,0x62860029,0x7afb2a5a}},	//   ريقة_, _lẻ_, ľkov, ndut
  { {0xc332000b,0x64620002,0xc5f60012,0x7afb0073}},	// [78a0] און_, _świę, _أثبت, idut
  { {0x3e5b0009,0xa856004c,0x7afb008e,0x865b0009}},	//   _מדפס, нтеј, hdut, _מדפי
  { {0x2bba0003,0xe1ff000e,0x1efa000b,0xe29a0024}},	//   _عادة_, _szót_, ּלְע, _нан_
  { {0x539b000b,0x60c60010,0xef1a00ac,0xdb9b0009}},	//   _מיטו, ėkmi, яме_, _מסטר
  { {0x7d1e0039,0x39450028,0x3ea62a5b,0x82360012}},	//   _kops, kils_, rbot_, _أرجا
  { {0x66030001,0x3dc62a5c,0x3ebf008e,0x3eb80035}},	//   упља, rrow_, _edut_, _ērtu_
  { {0x7bce002c,0xe4a5002d,0xbb3a0009,0xc4d30009}},	//   nubu, тріо, ּעִי, אגו_
  { {0xb7db000b,0x5fdb000b,0xf4130009,0xd4090012}},	//   _מקלי, _מחלק, רפה_, بتهم_
  { {0x612d0029,0x28dd0037,0x7bce00b6,0x3f8900b6}},	//   _súla, न्वि, hubu, _riau_
  { {0x8afd0066,0xadb70003,0x7bc70028,0xd4910081}},	//   voře, _أهلا_, yrju, _hàn_
  { {0xe759002d,0x39960058,0x3137000b,0x59c20011}},	//   дині_, _læs_, גנים_, _शिवर
  { {0xe292000a,0xceeb0003,0xf4570009,0xd6db003c}},	//   _إذا_, أردن_, _איבר_, что_
  { {0x5ce7002d,0x61460061,0x6ce7002d,0xbb3b000b}},	//   нюва, _célè, ніве, _צעדי
  { {0xc05a002d,0x7177002d,0x7bc7009b,0x98c0001e}},	//   _ній_, _збір_, trju, āpēc_
  { {0x7aed114a,0x28970009,0x6604084a,0xab950024}},	//   teat, _אדון_, _erik, тибі
  { {0x2b090037,0xdb0a0248,0x07f70012,0x6beb0009}},	//   वाएँ_, arfö, _أروع_, הַמַ
  { {0xa6db0028,0xf9930003,0x98c72a5d,0x99d70012}},	// [78b0] niðm, ابر_, فغان, عترا
  { {0xb9c40003,0x7bce01ea,0x859a0009,0xe7ef0011}},	//   اقلي, bubu, _קשתו, ज़िला_
  { {0xd491001a,0x7aed021b,0x853c0009,0x80d80011}},	//   _bàn_, peat, _מגזי, _माने
  { {0xdcb1001a,0xdcfe000d,0x30780012,0x93270012}},	//   _sẻ_, _tipă, رحلة_, _أردن
  { {0xf7700003,0x69db101c,0xa6db0097,0x62670012}},	//   حال_, xtue, viðl, _ساحق
  { {0xcd98000b,0x05770003,0xa63c000b,0xe4c20015}},	//   עדות_, راشد, הגדר, айши
  { {0x14d20037,0xdce4001e,0xdcb1001a,0xf8b20009}},	//   _सारण, _etiķ, _vẻ_, _כשם_
  { {0x05c90011,0x64410034,0x7afb008e,0x07090012}},	//   _रिपब, źliw, udut, _تيري_
  { {0xc6920093,0x39450108,0x44290039,0x69db008e}},	//   _כאן_, tils_, ņa_, utue
  { {0x6d410052,0xc27c0009,0xb9020024,0x61320097}},	//   _umla, הרחי, азьк, _tæle
  { {0xf0920093,0x7bdc006f,0x5bc70012,0x7d1e001b}},	//   יני_, xtru, _ستاف, _rops
  { {0x7d1e0027,0x66042a5e,0x4427052d,0x0caa0011}},	//   _sops, _prik, myn_, कर्म
  { {0xb6ba0093,0x442701d5,0x7d1e0729,0xceb20009}},	//   וצרי, lyn_, _pops, סיך_
  { {0x6da30146,0x96a20037,0x23600864,0xbb44008e}},	//   рира, _क्रॉ, čije_, äävä
  { {0x44270163,0x6b8b0058,0x073a0012,0x8cb5003c}},	//   nyn_, _kigg, _يسبب_, ысяч
  { {0xc7d6000b,0xef26003a,0x7bce0225,0x2ca50060}},	//   _סופי_, çüde_, rubu, ılda_
  { {0xe9da007c,0xd4910020,0x7bce002c,0x6d472a5f}},	// [78c0] ька_, _nào_, subu, bija
  { {0x64590002,0x6f0d05bd,0x6ab6003a,0xb5b70009}},	//   _świe, _znac, sayf, _שליח_
  { {0xd2aa0015,0x69c90070,0x61fc001e,0x8cd70011}},	//   _окне_, hree, ārli, _बातो
  { {0xd00f0003,0x25ad000d,0xe5c6072b,0xf7290024}},	//   تلم_, ţele_, вско, нцій_
  { {0xa697000b,0x45f30003,0x99860012,0xe1ff0034}},	//   דכנה_, لأوس, _للحو, _wzór_
  { {0x6da30001,0xa6db0028,0xc5f30009,0x63750073}},	//   шиља, viðm, ידד_, _išny
  { {0x6b8b2a60,0x2bb70012,0xd9431fbe,0xa3b70012}},	//   _bigg, ناية_, _тери, ناير_
  { {0x51f80047,0x236d009b,0x28d40011,0x96a20011}},	//   ению_, glej_, _दाहि, _क्लॉ
  { {0xcb13000b,0x87550014,0x63a90027,0x7de50003}},	//   שלח_, _сърц, ćeni, _مسلم
  { {0x65630017,0xc27b000b,0xf1b3000b,0x240a0014}},	//   conh, ורפי, ססת_, _онзи_
  { {0x4427006f,0x63a40027,0x26ee0011,0x660219b3}},	//   cyn_, ćins, ज़ूर_, lvok
  { {0x16bf0037,0x2d8c2a61,0x01da0012,0xe9ff0081}},	//   ्लेब, _hide_, _يوضع_, _giặc_
  { {0xa2d70037,0x62860029,0x15ec0037,0xb5fd0010}},	//   _यात्, ľkos, फ़िगर_, _ryšk
  { {0x2cb82a62,0x6286068c,0xdb1c0032,0xd13000ae}},	//   gard_, žkos, hrrä, _دمت_
  { {0xa5cc0037,0xc977000b,0x2569000e,0xd00f0003}},	//   _समझौ, _שגוי_, múlt_, _وله_
  { {0x8b080066,0x93fb000b,0x68fc0562,0x2d8c0040}},	//   vyří, וללי, _aard, _lide_
  { {0x68fc003e,0x3a750001,0x8837001e,0x27ea00b6}},	// [78d0] _bard, улар, ģēša, _apbn_
  { {0xacf50046,0x4427004a,0x3da40014,0x612d0028}},	//   _спољ, yyn_, _тръб, _núll
  { {0xb4c10037,0x6563000e,0x80780009,0x47940012}},	//   ुली_, vonh, תְּה, لجنس
  { {0x2d8c0108,0xdbd10005,0x65950594,0x64410031}},	//   _aide_, _müüg, гаду, úliu
  { {0xdcb10020,0xbb3a0009,0x5dd4003c,0x7afd004b}},	//   _hỏi_, _נעשי, ающу, _iast
  { {0xd491008a,0x3eb90051,0xbebd001e,0x98ba0010}},	//   _vào_, hast_, _plūs, tipą_
  { {0xcb690001,0x25ef0037,0xd466004c,0xeb910012}},	//   наке_, _इनकी_, лише_, حظت_
  { {0x3eb90d2e,0x69c91730,0x2b980025,0x2cb82a63}},	//   jast_, tree, _déc_, zard_
  { {0x68fc282d,0x3eb90c16,0xc334000b,0x237f0002}},	//   _yard, dast_, יוק_, rmuj_
  { {0x6e24005e,0x442b004c,0xdcf6004b,0x7afd2a64}},	//   äibe, _оцем_, ăcăm, _last
  { {0x7e760034,0x68450048,0x9f86003c,0x7afd004b}},	//   _szyp, унна, лгод, _oast
  { {0x3eb90065,0x2cb81649,0xe5a6035c,0x75212a65}},	//   gast_, ward_, лими, _holz
  { {0xd4910020,0x26de0002,0xc0e50014,0xb0620051}},	//   _làm_, ęto_, _болк, ääru
  { {0x7afd0005,0x3f8d0108,0x2d8c02eb,0x3eb90227}},	//   _aast, _lieu_, öde_, aast_
  { {0xb8f70037,0xc1720009,0x87260012,0xab960012}},	//   िल_, _החג_, _معظم, الرغ
  { {0x2cb81e36,0x3eb92a66,0xc0520009,0x60080009}},	//   sard_, cast_, _לזו_, _יִפְ
  { {0x9f5e0108,0x68fc2a67,0xda650012,0xa3b30011}},	// [78e0] _été_, _pard, لاكي, जीत_
  { {0x63ad001c,0x98be007d,0xd5b8001e,0x7afd1e59}},	//   ćanj, mită_, ņās_, _east
  { {0x68fc117e,0x78b5000d,0x98be000d,0x2d8c2a68}},	//   _vard, _dezv, lită_, _ride_
  { {0x4789002d,0xbefa0003,0x2d8c2a69,0x7afd2a6a}},	//   всім_, عراض_, _side_, _gast
  { {0xe4e6002d,0x3f8d0061,0x98be000d,0x2b982a6b}},	//   гійн, _dieu_, nită_, _séc_
  { {0x61460014,0x25a600b6,0x68fc06fe,0xd1320012}},	//   _сега, rpol_, _uard, _امس_
  { {0xc4d3000b,0x2d8c2a6c,0x4ff80009,0xc7f80009}},	//   צגה_, _vide_, _בִּנ, _בִּר
  { {0x3cf00044,0xfbac0037,0x2d8c2a6d,0xe76a0012}},	//   _इसके_, टीएम, _wide_, _أحسن_
  { {0xe4d60003,0x3eb90554,0x612d000e,0x914a05f7}},	//   _متاب, vast_, _túll, ечна_
  { {0xdcb1001a,0xa6db0028,0xc2370009,0xdbd1005e}},	//   ửi_, miði, טרפו_, _püüg
  { {0x04930351,0x7c93000a,0xb5fd0010,0xa6db0028}},	//   _المح, _المص, _ryši, liði
  { {0x8c1b000b,0x7c250052,0x9a6a0012,0x539b0009}},	//   _רואי, ähre, _كمال_, _נידו
  { {0xa6db0028,0xdb0a0989,0x2918006f,0x8cdb0037}},	//   niði, dsfø, öras_, _नामो
  { {0x01fb0009,0xfbac0011,0x7afd2a6e,0x3eb92a6f}},	//   _נפול, टीऍम, _sast, sast_
  { {0x8ca40037,0x3eb90070,0xf1bf0066,0x7afd0f43}},	//   कड़ो, past_, _svá_, _past
  { {0xf8d40011,0xfbb70009,0x98be004b,0xdb150031}},	//   _दाँय, טפלת_, bită_, pszí
  { {0x98be000d,0x7afd2a70,0xc2c40012,0x2a980012}},	// [78f0] cită_, _vast, صيلي, ائفة_
  { {0xf1c80003,0x2b490029,0x7afd10ca,0xfe700012}},	//   اولى_, siac_, _wast, _عدي_
  { {0x7a480035,0xa6db0097,0xf48b0367,0x2b461804}},	//   lītī, eiði, _ящик_, _omoc_
  { {0x672f003e,0x8c1a000b,0xd3660012,0xf1bf0030}},	//   nkcj, _סורי, _ذه_, _tvá_
  { {0x9f5c0066,0xf8d40011,0x752101a0,0x7aba0009}},	//   ívá_, _दांय, _polz, _בצרו
  { {0x6fc50011,0xc7b70012,0xd6260024,0x63f50012}},	//   _विलं, _مصرع, роше_, لأبر
  { {0xc6a70001,0xd5380003,0xbae50012,0x9cd80009}},	//   _брзи, دثنا_, لكثي, אווה_
  { {0x13090055,0xcc080012,0x66280030,0x8b250337}},	//   тний_, ازون_, íská, рдие
  { {0x11d60003,0xdce1001e,0x6d4a004b,0x52750024}},	//   لوية_, _eklā, bifa, шуку
  { {0xbb44004a,0x98be000d,0x6009020e,0x39450f80}},	//   äärä, vită_, вном_, рног
  { {0xe73a1103,0x386e0002,0xa2f5004d,0xb4c30011}},	//   вен_, _cyfr_, _впеч, ्ली_
  { {0xfe670003,0x2007009b,0x539a000b,0x98be000d}},	//   قد_, _vrni_, _סינו, tită_
  { {0x471a000b,0x29c80012,0x49cb0048,0x16b60011}},	//   דורג, _مِنَ_, _чуем_, _अजीब
  { {0x6459003e,0x98be007d,0x6abb0052,0x18a50001}},	//   _świa, rită_, lauf, _такм
  { {0x98be000d,0xc2b60001,0xd46a011d,0x6ab60048}},	//   sită_, иљањ, тиве_, исах
  { {0x3f9c000e,0x6abb0052,0x9f5d01bd,0xce5a0012}},	//   ívum_, nauf, _trvá_, _لشخص_
  { {0xe0da0146,0xc8960001,0x81a50012,0xe1fa0048}},	// [7900] ква_, арењ, محلل, ъга_
  { {0x78bb0061,0x399b0017,0xf992000b,0x867b0009}},	//   _œuvr, _mês_, קרב_, _ברפו
  { {0xd00f000a,0x98aa000d,0x6abb0052,0x5ea60012}},	//   ولك_, _albă_, kauf, لمال
  { {0x7c2e0052,0x98be0010,0x539b000b,0xa856000b}},	//   _übri, mitą_, _שיכו, ביעה_
  { {0x22a60066,0x6f06000e,0x97570009,0xb4c30011}},	//   níků_, jébő, סינו_, ्लू_
  { {0x80dd0037,0x4a570009,0xebc6004c,0x03c600ef}},	//   _पाये, _כשכל_, аљин, асим
  { {0xdb15000e,0xd499002d,0x6d4a2a71,0xbd430012}},	//   lszá, урі_, rifa, تنوي
  { {0x98a50010,0x6616004a,0x66092a72,0xd00f0012}},	//   filį_, äyks, _frek, _تلف_
  { {0xdb15000e,0xd5e90003,0x24f6022a,0x66092a73}},	//   nszá, _معلن_, _вчер, _grek
  { {0x3f980039,0x6b840052,0xdb180097,0xdb150031}},	//   _kuru_, hmig, msví, iszá
  { {0x78ba0028,0x65670029,0x3f9800b6,0x88bb0009}},	//   ratv, vojh, _juru_, כזיי
  { {0x98be0010,0xdb15000e,0x29f60002,0x91e600f5}},	//   ditą_, kszá, _tła_, _воде
  { {0x9757000b,0x78ba0010,0x7bce1316,0x51f60012}},	//   שיכו_, patv, erbu, _خسار
  { {0x5e77000b,0xc5f3000b,0xc27b0009,0xa3b30011}},	//   יתכן_, חדש_, _סרגי, जीव_
  { {0x717b0009,0x01370009,0xa97b0009,0xb97b0009}},	//   _שנוס, _דרגת_, _שאוכ, _שנוי
  { {0x394c0ce3,0x69c20011,0x4ea7004c,0x69cd2a74}},	//   lids_, _लिखी, _трка, trae
  { {0x6d4800bd,0x926b0001,0x6ce7002d,0xdb15000e}},	// [7910] _omda, трва_, _кіне, gszá
  { {0x2eff0061,0x6b8421ba,0xadd6000b,0x6f020480}},	//   _sauf_, amig, _פותח_, edoc
  { {0xb8ef0011,0x2988004c,0xdb150031,0xc1040012}},	//   _षय_, рсто_, aszá, تولي
  { {0x69c02a75,0x671a0011,0x7bd50060,0xb6a40081}},	//   ksme, धायक_, muzu, _ngẫ
  { {0xdef80047,0x06c8002d,0xa3d30011,0xd4910081}},	//   рых_, ргій_, हूर_, _hài_
  { {0xa6db0028,0xee38002d,0xe4e7002d,0xbdf8000b}},	//   miðu, шні_, рідн, שֶׁה_
  { {0x7bd5003a,0xa6db0028,0xadc3001a,0x3f982a76}},	//   nuzu, liðu, _trắn, _guru_
  { {0x394c001e,0xcc58007e,0xfc58000b,0x54580009}},	//   eids_, יבוי_, יבוש_, יבוב_
  { {0xe1f10003,0x6abb0052,0xe2a60028,0x13060015}},	//   سسة_, rauf, óðin_, сный_
  { {0x9be7007c,0x23e7007c,0x64a40001,0x6abb0052}},	//   _відк, _відв, _мађа, sauf
  { {0xc689000b,0x2911003a,0x40491498,0xe1880003}},	//   _נא_, ıza_, упно_, جئين_
  { {0x2295000a,0xe73a0015,0xaa950003,0xcc76000b}},	//   _الإس, уем_, _الإث, _הגעת_
  { {0x52850003,0x2b4d0002,0x98be0034,0x7d012a77}},	//   _الشك, miec_, witą_, _kals
  { {0xa009000a,0xba740012,0xdce32047,0x7bd52a78}},	//   _مقتل_, _بامت, konč, fuzu
  { {0xd4910020,0x1dd10037,0x2018079b,0xe3a70012}},	//   _bài_, _समझत, ärit_, ثر_
  { {0xd4910020,0xdb15000e,0x2b9c0066,0x2b4d0512}},	//   _cài_, tszá, _víc_, niec_
  { {0x3b070014,0x61320058,0xd491001a,0x200a2a79}},	// [7920] щето_, _fæll, _dài_, _srbi_
  { {0xdb15000f,0x11d70012,0x6b84005e,0xb4c30011}},	//   rszá, صومة_, smig, ्लो_
  { {0xdb15000e,0xca29000b,0x8f760024,0xdce30159}},	//   sszá, עם_, буді, gonč
  { {0xee3a0046,0x98b8003a,0xd6d9002d,0x07450024}},	//   лне_, ızın_, иті_, охім
  { {0x6901004a,0x7d01134f,0xd7050012,0x7ee30012}},	//   öydä, _bals, تظلي, سكون
  { {0x6d4e2a7a,0xac970012,0xdb050025,0x69c00248}},	//   niba, منها_, _athè, vsme
  { {0x7d0104f3,0xccf30009,0x9bf40024,0xa3180198}},	//   _dals, פכה_, ізич, ижку_
  { {0x2360009b,0x5a340014,0xe44f0003,0xc2980001}},	//   čijo_, жнит, عضو_, шких_
  { {0xcb670046,0x6d4e060b,0x9b170009,0x569b0009}},	//   љање_, kiba, מחקה_, _תימצ
  { {0x6d4e00b6,0x8637000b,0x61e4057c,0xce370009}},	//   jiba, _הרמב_, itil, _האמת_
  { {0xab960003,0x2b4d0002,0x9c7c0a45,0xac970012}},	//   _الصغ, biec_, _obči, _انما_
  { {0x6d58001e,0xd5ed001a,0xc3050003,0x2b4d0002}},	//   lnva, _ngạ, _وبنو, ciec_
  { {0x8b65000a,0xe667005c,0xe918002d,0x394c019f}},	//   _بالم, стно, _волі_, pids_
  { {0xd6570009,0x91f70009,0xab95004c,0x29020035}},	//   מיכת_, _למדו_, жављ, ēkas_
  { {0xdfa60003,0x1b770012,0x6b9a01a0,0x22401831}},	//   _احتي, مدرج, _jutg, ezik_
  { {0x90570009,0x33750024,0xb065008e,0xe6160159}},	//   _לסוף_, ігар, seää, žišč
  { {0xd491001a,0x61320058,0x7bd50030,0x22400031}},	// [7930] _vài_, _tæll, suzu, gzik_
  { {0x2be20044,0xce380009,0x3d020011,0x27050081}},	//   _पहचा, _לאחת_, लयों_, _ồn_
  { {0xd491008a,0xa295002d,0xd0110012,0x3ff50012}},	//   _tài_, _мані, بلا_, تكار
  { {0xa6db0065,0x660d2a7b,0x78790009,0xd4880009}},	//   miðs, _krak, בָנו, _לָרֹ
  { {0x35e7007c,0xceb4000b,0x2cb2006f,0x2dcb0001}},	//   сцев, ליף_, _ändå_, ућен_
  { {0x2b4d0002,0x2c830061,0x5fbb0012,0xdce30064}},	//   wiec_, cédé_, _مدرج_, ponč
  { {0xeab1000a,0x98a50010,0x7d012a7c,0x9f350024}},	//   وعة_, nklą_, _vals, _деві
  { {0xdb180051,0x644f0002,0x29031e15,0x5c380009}},	//   kuvõ, _ścis, _haja_, מרון_
  { {0x612d000e,0x7e7b0002,0xaac40012,0x28d40011}},	//   _múlv, _uzup, ستين, _दाखि
  { {0xe3b30003,0x95570012,0x59da0011,0xbd6b004c}},	//   _فرص_, _اخرا, यंतर, _србе_
  { {0x3d1d0037,0x2b4d0002,0xb69b0284,0x3854003c}},	//   माने_, piec_, rdân, зъяс
  { {0x61e418c7,0x0a150012,0xb7da0009,0x3e8a05c8}},	//   ytil, _وواح, סקרי, ийно_
  { {0x5fc50044,0xc3320093,0xaa7b0066,0xe57a0109}},	//   _विकल, _קוד_, _zbýv, изм_
  { {0xd009003c,0x6b5e0035,0x3f8608ca,0x6d8b0034}},	//   _веке_, mīga, zmou_, _mżaw
  { {0x7af60006,0x69cb02d1,0x6fb50003,0x660d1d2d}},	//   teyt, ágen, _بمعا, _erak
  { {0x163a000a,0x69d60164,0x52aa0014,0xe297022a}},	//   _نسخة_, tuye, рвам_, жат_
  { {0x7af60065,0x61e40061,0x6b5e001e,0x290308e4}},	// [7940] reyt, util, nīga, _baja_
  { {0xb17b0163,0x3ea50066,0x29050d64,0x290301e3}},	//   _spår, ělte_, ndla_, _caja_
  { {0xdb1c0028,0x2240000e,0x071e0037,0xeb9a0001}},	//   burð, szik_, _बचाव_, _њим_
  { {0xeab20003,0x69d60061,0xd47b0009,0x547b0009}},	//   _تعد_, puye, _כאיל, _כטיו
  { {0xd491001a,0xad660003,0x1af70009,0x35b30024}},	//   _màu_, ياته, _ומכל_, дбір
  { {0x69c40039,0xa1160012,0x2d930025,0x6b5e0035}},	//   msie, _بوست, _xixe_, dīga
  { {0xf1c50010,0xa4b7000b,0xcb120009,0x7ae92a7d}},	//   rašų_, קלקה_, ֵל֙_, ffet
  { {0x4420001c,0xdddb003a,0xc1b8002d,0x31c60400}},	//   ći_, _uyuş, блих_, осов
  { {0xb9970015,0xf1aa0012,0x69c42a7e,0x9b4300ae}},	//   овых_, جابه_, nsie, بنيو
  { {0x02170009,0xe7d10011,0x4c160012,0x6120008e}},	//   קחים_, _हिमप, _وباس, _pöly
  { {0xa2e60046,0x25a9015d,0x889b000b,0xb97b000b}},	//   _можд, _stal_, יביי, שניי
  { {0x69c41043,0x93fb0009,0xdb18005e,0xa6db0097}},	//   ksie, _כלבי, tuvõ, viðs
  { {0x35d20037,0x6b5e001e,0x34950015,0x95d800de}},	//   _सिफ़, cīga, загр, одят_
  { {0xfa77000b,0x3af50081,0x158a0009,0xdce30030}},	//   _ועדת_, _ấp_, ינָֽ, dlně
  { {0xdb1c0065,0x4fb30003,0xdb180051,0x734b0024}},	//   turð, _قصير, suvõ, ачав_
  { {0x290300c6,0x75280039,0xbfa3001a,0xc2140009}},	//   _saja_, _lodz, _miễ, ֔הּ_
  { {0xeb91000b,0x69c4001e,0xa2dc0037,0x5ee80009}},	// [7950] תָם_, gsie, _फार्, _וַתְ
  { {0xc178002d,0x48ab0367,0x752813ce,0x7bd82a7f}},	//   оїх_, ртам_, _nodz, kuvu
  { {0x29030005,0xb4fa000b,0x28dd01e1,0x5f950014}},	//   _vaja_, _הפתי, _मासि, чиет
  { {0x4439001e,0x6d540034,0xdb180040,0xdb140097}},	//   _ās_, ągał, lsvæ, _þaða
  { {0x20d70012,0xe1ff01e3,0xfb1a0009,0xdca50790}},	//   _وتسج, _usó_, _הורמ, пали
  { {0x25d8000b,0x75280002,0x64a50867,0xd6580009}},	//   קוון_, _codz, чака, חידת_
  { {0x7bd80039,0x9c7c009b,0xc172000b,0x6136004b}},	//   guvu, _obču, _נחל_, _pâln
  { {0xb3840012,0xd6870048,0xfc5c0009,0xbfa30081}},	//   وجيه, _дузп, יכומ, _diễ
  { {0xe4e7007c,0xe9d10003,0xda0e0011,0x6ce70024}},	//   _міжн, رغة_, सियत_, _міже
  { {0x7528003e,0xa2cb0037,0x6b5e001e,0x8a160009}},	//   _godz, तृत्, rīga, פחתו_
  { {0x98be0066,0x9be70024,0xf9940009,0x2d4d0030}},	//   litě_, _фізк, ורץ_, ržel_
  { {0xdc88000b,0x547a000b,0x290302a1,0x1dcf0011}},	//   _וְנָ, _הטעו, žja_, _हटात
  { {0xdb18014d,0x6f04001e,0x98be0066,0x7d05003a}},	//   fsvæ, _vaic, nitě_, _bahs
  { {0xb4d60037,0xdb1c0028,0x6b89000e,0x69da0009}},	//   हले_, rsrí, lmeg, _הַהו
  { {0x799d008b,0x7aef003a,0xf9900003,0x7d05016d}},	//   _ausw, _bbct, _شبه_, _dahs
  { {0x3f670014,0xf1c70037,0x69c42a80,0x2f55003c}},	//   _нищо_, _लिखन, tsie, _отыс
  { {0x7f3b000b,0x78bc02b4,0x97570009,0xdb1c005e}},	// [7960] _לעקו, _perv, _משקף_, kurö
  { {0x4103002d,0xb09a002d,0x69c42a81,0x6aa42a82}},	//   нзув, стає_, rsie, scif
  { {0x78bc00bd,0x7528003e,0xdc9b0009,0x4c9b01b0}},	//   _verv, _rodz, _לסיכ, _לשיע
  { {0x61320065,0xeafa0003,0xdce30066,0x6d5c001e}},	//   _mæli, _اردت_, plně, lnra
  { {0xddcb00a2,0x60c1000f,0xceb3000b,0x6722004a}},	//   ğişi, kalm, תיד_, rjoj
  { {0xdd99002d,0xc27b0009,0x673b005e,0x994f0060}},	//   іші_, _לרכי, _eluj, müş_
  { {0x60c1000e,0x26c20864,0xe3af0012,0x8cc70012}},	//   dalm, kako_, هري_, سويق_
  { {0xbfa3001a,0x75280002,0x6b89000e,0xd00f0012}},	//   _viễ, _wodz, gmeg, _حلف_
  { {0xadc30020,0xa3d60037,0x25760003,0xfb1b000b}},	//   _trạn, _समझ_, _فهرس, מוקמ
  { {0xe1ef000a,0xb0340339,0xd7fa0294,0x60c1125b}},	//   اسي_, днош, бум_, galm
  { {0x6443003e,0xc057002d,0x28dd0011,0xd8780012}},	//   czni, зія_, _मारि, تمدت_
  { {0x0857000b,0x987b000b,0x60c10051,0xcc57000b}},	//   לבים_, מריק, aalm, _צבאי_
  { {0x6133003a,0x0e340015,0xd259001e,0xdb180040}},	//   _yılı, еняю, paņa_, tsvæ
  { {0x27340020,0x8afd0066,0x3f9c0035,0xa5f8004c}},	//   _lãnh_, voři, _tuvu_, џеру_
  { {0x961d0039,0xdb180028,0xb97b0009,0x317b0009}},	//   _izņe, rsvæ, _הנגי, _האגד
  { {0xb7db0093,0x905b000b,0xc99b0012,0xdb180097}},	//   _הקהי, _לכות, مخطط_, ssvæ
  { {0x7d05003a,0x612d000e,0x671a0011,0x64580097}},	// [7970] _tahs, _túlt, धारक_, _þvin
  { {0x55bc000b,0x673b004b,0x98be0030,0xfc3f0030}},	//   _המזו, _sluj, vitě_, _řím_
  { {0x67210037,0x98aa0002,0xed600010,0x68fa0035}},	//   यापक_, óbę_, ėžti_, ietd
  { {0x60c1000e,0xf7700003,0xc7d70009,0xdb180248}},	//   zalm, هان_, לובי_, nsvä
  { {0x2fc7001a,0x28dd0037,0xc1780010,0xed4e0001}},	//   ũng_, _मालि, klė_, во_
  { {0xac390024,0x7ae201e3,0x98be0030,0x7bd50ea6}},	//   жчих_, _acot, ritě_, orzu
  { {0xbbe80003,0xdb18006f,0x628601e9,0xdb0101e3}},	//   كريم_, ksvä, ýkon, _atlá
  { {0x7aed1cec,0x42d50024,0x643c0009,0x613f0025}},	//   nfat, фіку, מעונ, _mêle
  { {0x64430053,0x20d50024,0x61450024,0xc2c80012}},	//   szni, мінс, депа, سبيل_
  { {0xe125007c,0xdb1a0248,0x6b890031,0xdb180248}},	//   ємни, _avtä, smeg, esvä
  { {0x6b5e001e,0xfbd00012,0xe4350012,0xe7320012}},	//   cīgo, _متن_, _تفاد, نصح_
  { {0xc4c90093,0xd3d80003,0x7bd50002,0x2d9f0051}},	//   _כג_, _ربما_, drzu, _kuue_
  { {0x7bd2001e,0x7bd50032,0xae030011,0x60c12a83}},	//   ījuš, erzu, लिटन_, palm
  { {0xe29f0065,0x98a50010,0xba160012,0x26c21424}},	//   _raða_, yklę_, _آيوا_, sako_
  { {0x26c2009b,0xe9720003,0x2b4012e5,0xfc3f0030}},	//   pako_, _جهود, thic_, _říj_
  { {0xc7d60093,0x29070065,0x7e760006,0xf092000b}},	//   _חוקי_, _hana_, _tyyp, _בנו_
  { {0x61e92a84,0x090603e1,0x87050012,0x79400032}},	// [7980] ntel, мпан, _سبيل, _löwe
  { {0x66040005,0x7afb004a,0x20110027,0xe29f0028}},	//   _isik, heut, _brzi_, _vaða_
  { {0x1fa5002d,0x2b400c63,0x7afb271d,0x29072a85}},	//   еріг, phic_, keut, _mana_
  { {0x2fc7000d,0x0ab60003,0x48fa0011,0xdfcf0012}},	//   ânga_, _تحدد, _उसको_, شيه_
  { {0x7bdc00c6,0x7afb008b,0x26c00149,0x6da30339}},	//   luru, deut, _meio_, вича
  { {0x7ae22a86,0xdb0a0248,0x236d0030,0x3ea62a87}},	//   _scot, nsfö, čeje_, scot_
  { {0x7bdc00c6,0xdce7001e,0x69cf0066,0xe73a002d}},	//   nuru, nojā, ácen, _дев_
  { {0x539b000b,0x61e92a88,0x7dc60012,0xbf160012}},	//   חיקו, ftel, _يتذك, _تورب
  { {0x29070f44,0x05760012,0xbb470012,0x2d4d0030}},	//   _bana_, _قائد, بلين_, užek_
  { {0x23690604,0xd40a0012,0x3ea9004b,0x63ba0064}},	//   čaja_, _وتضم_, _sfat_, štny
  { {0xdb0a0163,0xe8d7000b,0x29072a89,0xf84a002d}},	//   dsfö, וויר_, _dana_, ючий_
  { {0xf093000b,0x274b002d,0xdce7001e,0xdb15000e}},	//   כנת_, ічно_, dojā, sszú
  { {0xceb3000b,0x61e9000d,0x925a0012,0xdb180248}},	//   כיר_, ctel, _بشار_, rsvä
  { {0xc05a002d,0x961d001e,0xc27b0009,0xdb0a0248}},	//   _мій_, _uzņe, _ורדי, gsfö
  { {0xf9870003,0x6604019a,0x9f590f9b,0x9b1b0012}},	//   _تنوي_, _esik, író_, يترز_
  { {0x61320065,0xd13807ff,0xe3b00003,0x2b170011}},	//   _mælu, lką_, شرف_, थाएँ_
  { {0xf99f03eb,0x7d1a0070,0x2907003a,0x25fe0037}},	// [7990] _què_, _onts, _yana_, _शैली_
  { {0xd13809bb,0xe0d00012,0x00db0012,0xda080081}},	//   nką_, لزم_, تبرت_, _mỏ_
  { {0x3ebf0108,0x25ad0070,0x61e9000e,0xdb070031}},	//   _peut_, _stel_, ztel, apjá
  { {0x98bf00a2,0xf1a70037,0x2907013a,0x69cf01c7}},	//   ırın_, _कंपन, žna_, _दिली
  { {0xd246000a,0xfad6000b,0x3ebf0061,0x31a4003a}},	//   _إن_, _אורך_, _veut_, _göz_
  { {0xb638000b,0x91ba000b,0x38780028,0x61e9000e}},	//   ורדס_, _ממשי, _fyrr_, vtel
  { {0x7afb004a,0xd1380002,0x36d50751,0xfaa504ad}},	//   teut, dką_, _повр, найо
  { {0x7d1a008b,0xda080020,0xd498000b,0x395e2a8a}},	//   _ents, _bỏ_, וכות_, ents_
  { {0x51550047,0xc9550015,0x61e92a8b,0xedd50012}},	//   етну, етны, utel, _سياد
  { {0x60c50052,0x7bdc003a,0x7fd50024,0xd1160011}},	//   nahm, yuru, німі, तागण_
  { {0xc172000b,0x29070051,0xdbd70269,0x6d552a8c}},	//   רחי_, _vana_, _jääv, diza
  { {0x395e1e0b,0xc7d6000b,0x9f480058,0x7bdc003a}},	//   ants_, עורי_, _opnå_, vuru
  { {0xf652000a,0x6464000d,0xdb0a006f,0x26c00017}},	//   ائج_, ătiţ, tsfö, _veio_
  { {0xd1380002,0xdce7001e,0xa9090012,0x63a80030}},	//   cką_, tojā, _ريبل_, ídno
  { {0x629c0066,0x31a4003a,0x7bdc005e,0x61320097}},	//   ěrov, _söz_, uuru, _mælt
  { {0x23270046,0xa856000b,0x6b8d000e,0xdce7001e}},	//   носи_, _ריקה_, gmag, rojā
  { {0xfe720003,0xd1860015,0xe9da1aab,0x6b630109}},	// [79a0] _حدث_, елай, яка_, укта
  { {0x186a0014,0x8cc10037,0x69c9004a,0x7cf3003a}},	//   пази_, वरणो, isee, nırı
  { {0x3d1d0037,0xc7af0003,0x32da0060,0x9f9a0009}},	//   मारे_, مّل_, nüyü_, ִסְפ
  { {0x69c903d5,0xd6d20012,0x8bd70009,0xf4130009}},	//   ksee, اقش_, _אוטו_, _עפר_
  { {0xba9b000b,0x6a9b0009,0x20d60024,0xf1a70011}},	//   _מסכי, _משכנ, _півс, _कूपन
  { {0xa3d40044,0xdd8f0003,0xafe607a1,0x23600034}},	//   _हटा_, مون_, _погл, lnij_
  { {0x769600a2,0x69c90006,0x7cf3003a,0xd75a0012}},	//   _büyü, esee, dırı, _فلست_
  { {0xfbd3000b,0x290a002c,0xff260014,0xbbd00011}},	//   אתה_, _haba_, _ямбо, _सटीक
  { {0xd1380034,0x8afd0030,0xdb1c0248,0x05661a4e}},	//   tką_, vořt, msrä, _зван
  { {0xd1380010,0xd1340001,0xda080081,0x6d4324ef}},	//   uką_, тноћ, _vỏ_, chna
  { {0x2360003e,0x6b8d0002,0xdd8f0003,0x9d2b0009}},	//   knij_, ymag, _اول_, _מֵאִ
  { {0xda08001a,0xd138044c,0xdc3b0009,0x7c3b0009}},	//   _tỏ_, ską_, _מעבר, _מתבס
  { {0x23600002,0x82330012,0x6b43005e,0x56940367}},	//   dnij_, _مروا, _jõge, лают
  { {0x10740015,0x69c60010,0x2360001b,0x68460025}},	//   _иллю, škes, čiju_, _cédé
  { {0x9982007a,0x291f001a,0x2360143a,0xa9260035}},	//   škų_, _đua_, fnij_, iežā
  { {0xa87b007e,0x6b8d002c,0x487b000b,0x307b000b}},	//   _מאור, umag, _מטוס, _מאונ
  { {0x68460061,0xeed60009,0x290a2a8d,0x49752a8e}},	// [79b0] _fédé, _בֵית_, _baba_, влас
  { {0x3eb9008b,0xdbd7008e,0x49b80012,0x315b0012}},	//   lbst_, _pääv, عاقد_, أجرة_
  { {0xb9090302,0xf99f0061,0x28e20037,0xf3cb0012}},	//   _या_, _près_, _पारि, _عبده_
  { {0x6fd60011,0xec360009,0x7cf30060,0x613f0025}},	//   मंजू, _יאתר_, zırı, _mêla
  { {0x5b140014,0xdd9b0015,0x228407e8,0x05a80024}},	//   _смят, чше_, _бург, евій_
  { {0xc5f4000b,0x5ff50294,0x61ed1b56,0x39820097}},	//   רדס_, _изгу, mtal, yðsa_
  { {0x3ce90044,0xf99f0108,0xdfd80098,0x6c520001}},	//   _जाने_, _très_, _път_, икљу
  { {0x5f940046,0x3f890020,0xb7940003,0x8c1c000b}},	//   _бист, _nhau_, _مؤقت, לווי
  { {0x3392000a,0x7cf300a2,0x15f40003,0x13060015}},	//   جليز, tırı, _مسلح, тный_
  { {0x63a10051,0xfd130012,0xe4d70012,0xe7a90fdf}},	//   _tuln, _حجر_, _ستطب, мвол_
  { {0xf74600f5,0x3f6a0b22,0xe51e0011,0x0889003c}},	//   вено, дино_, पारि_, ьбой_
  { {0x23be0066,0x290c0248,0x61ed2a8f,0x69c92a90}},	//   vůj_, adda_, ktal, psee
  { {0x69c60066,0xcb36000b,0xa2660029,0xc6030024}},	//   šker, _שאני_, omôž, азяй
  { {0x23600002,0xa3bf0011,0xde03004c,0x98a204a5}},	//   wnij_, ुओं_, јпри, _кише
  { {0x290a080f,0x33d50024,0x73ac0009,0x23600034}},	//   _raba_, літт, ּימֵ, tnij_
  { {0xdb01006f,0xf8b90081,0x2d9a0132,0x61ed2a91}},	//   _utlä, _đũa_, _wipe_, ftal
  { {0xc3320093,0x9e66002d,0xdb1c006f,0x60c30070}},	// [79c0] בון_, _швид, vsrä, _kenm
  { {0x3ce90037,0xe0d71496,0xf53f0248,0x58960012}},	//   _जाये_, кву_, spår_, نجاز
  { {0x838a007c,0x290a0051,0x10150024,0xc896004c}},	//   _обов_, _vaba_, льця, трањ
  { {0xa2660029,0x6d412a92,0x7c210260,0x6b43005e}},	//   emôž, _alla, ålre, _põge
  { {0x290c006f,0x7bda0029,0xa4d40024,0x7ae4020d}},	//   ydda_, štud, голі, mgit
  { {0x7ae40005,0xcdb7000b,0x6fb60003,0x6286009b}},	//   lgit, דפסה_, _لمسا, _izko
  { {0x9f5c000e,0x8d5b0009,0xb9060011,0x6d41016d}},	//   ívó_, וכסי, फल_, _dlla
  { {0x6d410164,0xd5b20012,0x7ae42a93,0x68e123e6}},	//   _ella, _نفر_, ngit, _öldr
  { {0x7bca002a,0xe5a60129,0x35a6031e,0x4974003c}},	//   ssfu, _ризи, _разг, ллис
  { {0x3ea00061,0xe5060012,0x41da0011,0xd917003c}},	//   _agit_, _جبري, यूएस, вью_
  { {0x3137007e,0x41d40037,0xc953000b,0x290a0029}},	//   דריך_, _दिवस, שמת_, ľba_
  { {0x60c30070,0x44380262,0xbb44008e,0x6d582a94}},	//   _eenm, dyr_, äädä, liva
  { {0x6d58004a,0x291a0012,0x9f470025,0x3eb90032}},	//   oiva, _يقصد_, îné_, rbst_
  { {0x61ed07c7,0x5d850012,0x66160097,0xc6930009}},	//   vtal, السل, _dryk, יאר_
  { {0x78fb000b,0x2d4d0027,0xe2f9002d,0xa99b0009}},	//   _חלופ, džet_, неві_, _קבור
  { {0xa0970093,0xc334000b,0x98a30002,0xb097000b}},	//   _בדוק_, נוּ_, _moją_, _בדוח_
  { {0x61e0003a,0xa6e30028,0xab940024,0xba740012}},	// [79d0] numl, íðut, риті, لاكت
  { {0x58b8000a,0x6d58001c,0xd8b80003,0x3ad3001a}},	//   نامج_, jiva, ندما_, ệp_
  { {0x7d080010,0xd7d50001,0xf8070048,0x644a0031}},	//   iūrė, ужењ, ъчан, jzfi
  { {0x673d0119,0x61e0001e,0x23660027,0xf43a0009}},	//   nksj, kuml, _njoj_, _נגרמ
  { {0x22da000b,0xdd2c0010,0x7d080010,0x61e02a95}},	//   _אחרא, _dėžu, kūrė, juml
  { {0x04c90003,0x3cdc0037,0xa63c000b,0x6d582a96}},	//   روبي_, _बाज़ा, וגדר, giva
  { {0xe4e4002d,0xbbf50003,0x6d4b0010,0xc3c80003}},	//   річн, استث, _įgal, نظيم_
  { {0x4429001c,0x13050001,0x6575000e,0x42090001}},	//   ća_, узим, hozh, енио_
  { {0xdb15000f,0x6575000e,0x4e940003,0x2bae0002}},	//   lszó, kozh, _نشكر, _ręce_
  { {0x6d580027,0x25760058,0xc27c000b,0x4a7c0009}},	//   civa, jælp_, ורחי, ורחב
  { {0x25b20975,0xf4080012,0xb5fd0073,0x90560009}},	//   _styl_, _ليلى_, _ryšy, ָ֑יו_
  { {0x29cf0039,0xdb15000e,0x6d460010,0xf7460015}},	//   kļa_, gszü, _įkai, уемо
  { {0xcb120093,0x8e56002d,0x8e550024,0x60c3172d}},	//   _ללא_, утні, атрі, _tenm
  { {0xe6e00037,0xafe50014,0x44380262,0x6da300f5}},	//   _पञ्ज, _бокл, tyr_, сира
  { {0x6286003e,0x65630033,0x443e2a97,0x8c4306e0}},	//   _szko, innh, át_, бере
  { {0x6d58001c,0x66160623,0x61ba0012,0xd2520012}},	//   ziva, _tryk, فهرس_, منز_
  { {0x7ae40051,0xc332000b,0x98a70035,0x5ad30012}},	// [79e0] rgit, זון_, _zonā_, صْلا
  { {0x11d7000a,0x6b5e001e,0x6d580054,0x637a0227}},	//   اولة_, rīgi, xiva, eïnt
  { {0x3ce90044,0xdfcf0003,0x7ae40033,0x2d4d0066}},	//   _जाते_, كيل_, pgit, ržet_
  { {0x7bce0f85,0xcf7a0012,0xfe460048,0xe5c6003c}},	//   msbu, رصاص_, лнео, гско
  { {0xfe720003,0x6609000e,0x539b0009,0x99860012}},	//   حدا_, _csek, _ריכו, _ملحو
  { {0x6d580061,0xde930001,0x18a309cc,0x245804a5}},	//   uiva, љашњ, _гарм, каль_
  { {0x0d170093,0x26c42a98,0x2bb70012,0xb6080030}},	//   טקסט_, _temo_, هاية_, dušš
  { {0x6abb0033,0x7c650012,0x2481005e,0x395a2a99}},	//   gbuf, جاهل, ühma_, lips_
  { {0xd1300003,0x0e66048c,0x6d5800e6,0xcb370009}},	//   قمة_, _скан, piva, טאקי_
  { {0x61e000a2,0x71f70012,0x3ea90064,0x929d0034}},	//   ruml, اريس_, ľate_, jdłu
  { {0xf5930003,0x44380f85,0x3ea904d2,0x60c80d1c}},	//   _اللج, _ær_, žate_, radm
  { {0x32ba0003,0xbaba0003,0x929d0002,0x395a002a}},	//   _أداة_, _أداء_, edłu, hips_
  { {0x2d4d0027,0x66e60011,0x9f540024,0x65750031}},	//   džer_, _कारक_, свяч, tozh
  { {0x3d0f0037,0xdb151436,0x1dc60011,0x70940048}},	//   ायें_, sszü, रीयत, _калф
  { {0x7a480039,0x27f701bd,0x4c950024,0x89630012}},	//   sūtī, čená_, ривс, _دُون
  { {0x290e0065,0x236d009b,0x29cf0035,0x2d9e2a9a}},	//   _hafa_, čejo_, tļa_, _lite_
  { {0xa4d5002d,0xb9550014,0xdb0a2a9b,0xccf80066}},	// [79f0] _копі, аващ, ppfæ, _obě_
  { {0x17fb0003,0x6b5e0035,0xdb150031,0x26cb0c9d}},	//   فرصة_, mīgu, tszó, laco_
  { {0x29010101,0x28870001,0x6d452a9c,0x659a0009}},	//   reha_, ућав, _ilha, _שיתק
  { {0x7ff4000a,0xa6150047,0x87d80012,0xcae30011}},	//   إسلا, имеч, ابلس_, _गाइड_
  { {0xdb15000f,0x398b0260,0x2d9e2a9d,0xf7740009}},	//   sszó, løse_, _bite_, זקף_
  { {0xabd51154,0x11da0093,0x8cba0044,0xb0e20037}},	//   ациј, _בחשב, ्रयो, _पाएग
  { {0xf5380009,0xd9280009,0x2d9e2a9e,0x0445028b}},	//   רטור_, _עֵשָ, _dite_, рейн
  { {0xb33b00a2,0x66092a9f,0xeab70009,0x54580009}},	//   _hiçb, _tsek, נִ֔י_, טסון_
  { {0x6d450017,0x8cba0037,0x89350012,0xeb920009}},	//   _olha, ्रमो, لعدا, חָז_
  { {0x3d0f0037,0x59da0037,0xe9ff0081,0x69db1217}},	//   ायों_, यूटर, _giấc_, rrue
  { {0xdcec0030,0xff2616fd,0x98be0073,0xe76607eb}},	//   _řiďt, амно, antį_, ивоп
  { {0x2f56002d,0x61fd2aa0,0x6d450577,0x80a70011}},	//   ртос, _opsl, _alha, _फ़्रे
  { {0x7d030070,0xe5a61a44,0xa2c90011,0xb5220011}},	//   oens, риги, ़रन्, मालय_
  { {0xc0e200b3,0x60c7024e,0x2d9e2aa1,0x82340012}},	//   _дошк, _nejm, öte_, _درما
  { {0xdd140064,0x61fd2aa2,0x26cb0a19,0x7d032aa3}},	//   _túžb, _apsl, baco_, iens
  { {0x6d45000e,0xa3d70011,0xfaa30223,0xf1b90035}},	//   _elha, _सिर_, жато, opš_
  { {0x3b070098,0xdcfa0066,0xb77b000b,0xeb9704ac}},	// [7a00] шето_, _chtě, _שאפש, рит_
  { {0x6fb60012,0xa63b0009,0x2018016d,0x6b5e0035}},	//   لمطا, _סגיר, _prri_, līgt
  { {0x98a7000d,0xe8d60009,0xe6c60012,0xd2590035}},	//   _zonă_, שוער_, لتشي, maņu_
  { {0x28e20044,0x2d9e2aa4,0x91e60de4,0x3ea90009}},	//   _पाकि, _site_, _коме, ְכוּ_
  { {0x10a60198,0x3f820034,0xe737004c,0xb2bb0009}},	//   _вигн, ilku_, јеч_, _במכר
  { {0xdd0e003a,0x5cf6002d,0x7d032aa5,0x6d5c2aa6}},	//   _dışi, ряду, gens, nira
  { {0xaaaa0037,0x6d5c0051,0x60fb0009,0x61e42aa7}},	//   _कलाक, iira, _שהלק, luil
  { {0xcfb7000b,0x60c70066,0x6d5c1642,0x42040012}},	//   _כללי_, _zejm, hira, مِعْ
  { {0x7d03008b,0xcb670001,0xb954002d,0xfce600bb}},	//   bens, јање_, йвищ, _возо
  { {0x09f70093,0xd91a003c,0x2d9e004b,0x27130081}},	//   סמים_, тьи_, _uite_, _ện_
  { {0x13060098,0xb8ce0037,0xdce1001e,0x98a50035}},	//   _взем, _कल_, _eklē, eklē_
  { {0xd491008a,0xc2e90003,0xf43b000b,0x61e4079b}},	//   _này_, _معهم_, _שתאש, kuil
  { {0x443c0029,0x3f85001e,0x224d0002,0x539b000b}},	//   lyv_, ēlu_, czek_, _סידו
  { {0x6b5e0039,0xe3b30012,0x04c90012,0x61e4008e}},	//   rīgu, قرر_, طوري_, duil
  { {0x61e40061,0xb0b70009,0x09290012,0x93970012}},	//   euil, _דפוס_, _حسني_, لجرا
  { {0x442d001c,0x389b000b,0x4fb30003,0xb09b0009}},	//   će_, _ביונ, _بصور, _ביור
  { {0x443f0039,0x63a80002,0x28a70015,0x33740024}},	// [7a10] ņu_, _ludn, ашег, ігур
  { {0x2b4603eb,0x6d5c080a,0x867c0009,0x32d70081}},	//   _lloc_, cira, _ברחו, ủy_
  { {0x2d830416,0x36e10037,0x644e0002,0x57f50109}},	//   mlje_, _काफ़ी_, czbi, спет
  { {0x6b610039,0xdb010119,0x7d032aa8,0x61e40a70}},	//   lēgv, _utlø, wens, buil
  { {0x25a900b6,0x7afd005e,0x2d8308ef,0x9e071240}},	//   _jual_, õstm, olje_, рчел
  { {0xe578002d,0x24e9002d,0x3a36000b,0x29070051}},	//   азі_, умки_, _הרשם_, õnad_
  { {0x32090503,0x2b462aa9,0xf9920009,0x612d0031}},	//   lway_, _bloc_, _זרם_, _túlz
  { {0x99840010,0x660d00b9,0x6d5c2aaa,0xdcf70060}},	//   kymų_, _osak, zira, ıcıy
  { {0xb3080003,0xf7720009,0xb062005e,0xdb0e0025}},	//   شغيل_, _זקן_, äänu, édéf
  { {0x5d85000a,0x9984007a,0x7d540015,0x39450055}},	//   _الطل, dymų_, _двух, сног
  { {0x6d5c0082,0x224d0b95,0x29112aab,0x32091e40}},	//   vira, szek_, _maza_, hway_
  { {0x2bf6000b,0x6d5c1642,0x29112aac,0xfe670012}},	//   _למען_, wira, _laza_, كد_
  { {0xab74000a,0x9b74000a,0x25a902d1,0x23740003}},	//   _بالإ, _بالص, _cual_, _بالح
  { {0x61e40006,0x7ae92aad,0xc6920009,0x98a50048}},	//   vuil, lget, פאם_, _уике
  { {0x39420039,0x8c4306e6,0x98b80002,0x88550009}},	//   īkst_, пере, órą_, _לֹ֤א_
  { {0x61e4004a,0x3ea0080a,0x3942001e,0x2d830027}},	//   tuil, žiti_, ūkst_, alje_
  { {0xcb12000b,0xd9f90037,0xd259001e,0x2d830604}},	// [7a20] הלן_, ्बित_, paņu_, blje_
  { {0x1e57000b,0xeeeb001a,0x40960086,0xa6170009}},	//   _לשפר_, ượng_, брет, _פקיד_
  { {0x7d370009,0x9b460012,0x5ea60012,0x661b005e}},	//   _הניב_, _هندو, ممال, _aruk
  { {0x661b03a0,0x63a808e1,0x69d80011,0xab2a004c}},	//   _bruk, ídnu, _मिली, _сома_
  { {0x9916007c,0x6b841a7f,0x95860024,0x98a70073}},	//   _льві, mlig, блде, _zoną_
  { {0x290500eb,0x661b086d,0x28e20011,0x8bc60aa2}},	//   jela_, _druk, _पाटि, бсид
  { {0x1cbb000b,0x7ae90052,0xd3d70003,0xd37a05c8}},	//   אמצע, fget, مبيا_, лчи_
  { {0x661b013f,0x7ae92aae,0x6b842aaf,0x8c1b0009}},	//   _fruk, gget, nlig, רוקי
  { {0xd5b20003,0xcb13000b,0xeaaf0012,0xd1ba0012}},	//   _رفض_, ללה_, رعي_, داعا_
  { {0x3a370093,0x63a8000f,0xf8ba0037,0x3cf10029}},	//   צרים_, _tudn, ेरिय, ľový_
  { {0x6c86000a,0x2d830604,0xdb15000e,0x6b842ab0}},	//   _الام, vlje_, mszö, klig
  { {0x8f470015,0x6b842a4f,0x99840010,0x389b0009}},	//   сход, jlig, tymų_, טיינ
  { {0xa3cb0037,0x6b7b0009,0x32960012,0x25a92ab1}},	//   रीन_, _גראנ, _الشأ, _qual_
  { {0x660d012e,0x6b650010,0x2d83079b,0x9f410030}},	//   _vsak, mėgi, ulje_, ruhé_
  { {0x853b000b,0x8bd80009,0xb8fc0011,0x6fb40012}},	//   נגלי, יַּח, तः_, _بمبا
  { {0xfb580003,0x322b0024,0x660d0073,0xbae50012}},	//   مؤقت_, лізм_, _tsak, تكري
  { {0x6d480272,0xd1350001,0xe6b50037,0x90a70012}},	// [7a30] _olda, онаћ, ंडीज, محام
  { {0x6b61001e,0x98f5001a,0x32092ab2,0xdcee004b}},	//   lēgt, hỉn, rway_, robă
  { {0xe787002d,0x3f15022a,0xe4ee0011,0x7feb0012}},	//   будо, ждес, _जाति_, طراف_
  { {0x501b0009,0xa6fb0009,0x6d482ab3,0xdb0f008e}},	//   טובו, רִ֑י, _alda, äjär
  { {0xbef8000b,0xd629011d,0xa1950365,0x6b650073}},	//   מצאו_, роле_, _мамч, jėgi
  { {0x527a000b,0x33d90015,0x97a70024,0xe4e70024}},	//   _כנרא, афию_, _грал, сідн
  { {0x7d070002,0xd1300012,0xc7c40024,0x2369004b}},	//   iejs, _ثمّ_, _нсти, onaj_
  { {0xa3cb0044,0xf1d40037,0x7ae9000d,0x661b11ce}},	//   रीय_, _दिखन, uget, _truk
  { {0xeab20093,0xc9a60015,0x4225002d,0x395e2ab4}},	//   וֹת_, овые_, ідов, fits_
  { {0xa7d30037,0xe8f6027f,0x7ae90032,0xdce30035}},	//   _डिफ़ॉ, оль_, sget, ilnī
  { {0x1cb80003,0xa3cb0037,0x7afd2ab5,0x02d90012}},	//   _طالب_, रीम_, _obst, _نواب_
  { {0xbf870020,0x26cf002c,0x7c2a0054,0x8f190009}},	//   _điền_, nago_, _àfri, בוֹת
  { {0x80ba0037,0x2378000e,0xe0ce011d,0xadb70012}},	//   _श्वे, _írja_, _ов_, يهَا_
  { {0x2369001c,0xaa880003,0x7e9a0009,0x200e008e}},	//   čaju_, _انهم_, יסרו, ämiä_
  { {0x64a30001,0xf9920009,0x141a0012,0x3d090011}},	//   дара, _חרג_, جيزة_, ाज़े_
  { {0x67240416,0xf092000b,0xeeeb001a,0x6b840192}},	//   _unij, _קנה_, ưỡng_, ulig
  { {0xa3cb0037,0x6b842aaf,0x6d4329c5,0x6b610035}},	// [7a40] रीब_, rlig, kkna, lēgs
  { {0x6d430227,0x6e3b0032,0x7afd0b82,0x601a209d}},	//   jkna, äube, _ebst, ицер_
  { {0xb9020044,0x7aef0006,0x6b842244,0xb1170012}},	//   _नए_, äntö, plig, تقلا_
  { {0xdfcf0003,0xf9890009,0xc4b40011,0x63b303a7}},	//   ئين_, דר_, ुर्ख, žené
  { {0x80e60012,0xc3330009,0x929d0034,0x63a22ab6}},	//   _وأسل, _חור_, wełn, _rion
  { {0xdd8f000a,0x8e200024,0x9e0b0009,0x9876004c}},	//   نون_, лiв_, שִׁ֖, _дубљ
  { {0x26cf0101,0xb4930001,0x395e00e5,0xfbcf0012}},	//   bago_, мишљ, vits_, نتي_
  { {0xdb15000e,0xaf030001,0x3ce00060,0xa8570009}},	//   sszö, _опсл, şiv_, _וילה_
  { {0xf3f9007d,0x14bf0037,0x416a0001,0x61f60034}},	//   ăţi_, ्रमण, ијом_, ntyl
  { {0x929d003e,0x201c080a,0x23690eb3,0xf8af0012}},	//   pełn, _prvi_, znaj_, َةٍ_
  { {0xf8b3000b,0x60ca0028,0x8d770012,0xe81d0011}},	//   ושת_, _vefm, _بملء_, फिया_
  { {0x80ba0044,0x395e11aa,0x28ac0011,0x2b4d0025}},	//   _श्रे, sits_, _फ़्रि, chec_
  { {0x8f9b000b,0x94ab025c,0x657c0192,0x2369001b}},	//   ייטי, итва_, forh, vnaj_
  { {0x23690034,0x2240020d,0x3f8608ca,0x47d400ae}},	//   wnaj_, dyik_, hlou_, _فيتر
  { {0x93bc004b,0x33261ae7,0x7d07292e,0xd01000ae}},	//   _drăg, _knox_, rejs, _ألب_
  { {0x7bdb0093,0x27f30029,0xf1ab0012,0xeea70012}},	//   יקלו, žaní_, لائه_, _بحثً
  { {0x7d070002,0xc8d9002d,0x48ab0015,0x657c1791}},	// [7a50] pejs, ймає_, атем_, borh
  { {0x6d4e0052,0xcd000002,0x929d0002,0x929b0009}},	//   chba, ęści_, zeło, שימת
  { {0x26cf002c,0xb8d30011,0x98b80034,0xfe190011}},	//   tago_, _ऑल_, órę_, दिवस_
  { {0x4758002d,0xbf58002d,0xcf580024,0xfec40012}},	//   орія_, орії_, оріч_, ِينَ
  { {0xdd140029,0x98aa0002,0x0f180012,0x2252010f}},	//   _dĺžk, _sobą_, تغلب_, czyk_
  { {0xfe700003,0xf1c40037,0x1d090014,0x7bd50034}},	//   خدم_, _लौटन, секи_, oszu
  { {0x26c20002,0x64a20001,0x26cf0164,0x6d432ab7}},	//   ybko_, наша, pago_, rkna
  { {0x3f860054,0x7aed2ab8,0x32b90012,0xe6b50011}},	//   clou_, ngat, حدثة_, ंडोज
  { {0xc2e80003,0x20190035,0x5f140011,0x5d55209d}},	//   زعيم_, āsim_, _नोट्_, _екат
  { {0x98aa0002,0x2eb60037,0x9875004c,0xe3b30012}},	//   _tobą_, ूर्त, зумљ, _قرص_
  { {0xf3f0000a,0x9f95000b,0xf51a0009,0xdb010018}},	//   _لأن_, ּדָה_, _לֵאל, _eulá
  { {0x7bda082b,0xabfa000b,0x98a50010,0x33fa000b}},	//   átum, _להער, yklė_, _להענ
  { {0xf5b6002d,0xae1e0037,0x25a50f66,0x64a60024}},	//   ясню, पियन_, _kill_, зага
  { {0xb2260028,0xdb1c2233,0x91ba0009,0xa3d70011}},	//   stæð, mpré, _המסי, _सिख_
  { {0xf7462317,0x20540048,0x93bc004b,0x1866085f}},	//   _неко, _отър, _grăd, _наши_
  { {0x883a000b,0x21f40051,0x6d80004a,0x8b9502e3}},	//   _לתצו, täh_, töas, друч
  { {0xe2970014,0x6b650010,0x87250012,0x93bc004b}},	// [7a60] зат_, jėgu, _زعيم, _trăg
  { {0x865b0009,0xe9d70024,0xf8bd0011,0x409609c6}},	//   _לדפי, яку_, ोरिय, прет
  { {0xdb180065,0xb53b000b,0xdb0a0033,0x5d3b000b}},	//   msvö, _הגיש, ppfø, _התיא
  { {0xdc8b000b,0x61e92ab9,0x2d872aba,0x000000c4}},	//   _לְכָ, kuel, elne_,
  { {0xceb3000b,0xbb44004a,0x539b0009,0xcb9b0009}},	//   גיד_, äämä, _ליטו, _לסטט
  { {0x45360198,0xdce30035,0xebc6004c,0x3f8603a7}},	//   яхет, donē, пљин, slou_
  { {0x69dd0026,0xa84a0012,0x6bd60012,0xa026008e}},	//   ásen, _الأم_, ستغر, isöö
  { {0xb7db0093,0x25ad002a,0x98a30055,0xf9140011}},	//   _לקלי, _fuel_, _чисе, _थोड़ा_
  { {0x05ac0044,0x6443003a,0x25a51e22,0xf0f90011}},	//   _टूलब, _üniv, _fill_, ौजूद_
  { {0x7bd50002,0x7aed000e,0x7dbb000b,0x753a0052}},	//   yszu, zgat, _לצמצ, ötzl
  { {0x7bda013a,0x75280034,0xfcd30012,0x4cbb00af}},	//   štuj, _indz, _سينج, _הזבו
  { {0xa5f90015,0x61e4017b,0x98a70030,0x39820097}},	//   оему_, kril, _koně_, eðst_
  { {0xd337000b,0x61e92abb,0x97570009,0x877b0009}},	//   _מראה_, cuel, ליטו_, מאטי
  { {0x61db000b,0xe29b0009,0x7bd50032,0x645c0097}},	//   _פקוד, _השדר, tszu, _þris
  { {0xe2a60028,0x97ad003a,0x01330003,0x78fb000b}},	//   íðna_, üştü, _سعود, _לפגו
  { {0x98130012,0x6d5e2abc,0xb3bb0009,0x7aed02b8}},	//   _أبوا, _empa, ממלכ, ugat
  { {0xad550003,0xd7f8000d,0x7bd5000e,0x391506a5}},	// [7a70] _ينبغ, ltă_, sszu, ммар
  { {0xd7f8000d,0x7aed200d,0x69c02a6d,0x63a60097}},	//   otă_, sgat, ipme, _eikn
  { {0xd7f8007d,0x2ef50024,0xacfa0009,0x7d0a0060}},	//   ntă_, дзер, _והתכ, defs
  { {0xf7730003,0xf1dd0037,0xdb07004a,0xd7f8000d}},	//   راض_, _मिलन, ömäs, ită_
  { {0xf7700003,0x25ad167a,0x95990842,0x5d79003c}},	//   دال_, _quel_, отку_, ойдя_
  { {0xc212000b,0xf1b2000b,0xa618000b,0xc984002d}},	//   _שהם_, _בסך_, פקוד_, _зуси
  { {0x25a501ab,0xe9ff001a,0x753a2abd,0xec680009}},	//   _vill_, _khắc_, _dotz, ּ֑וֹ_
  { {0x25a50742,0x79880227,0xb2250511,0x6b650073}},	//   _will_, eldw, дмил, mėgs
  { {0x25a501ab,0x6609003a,0xecbf0011,0x25ad005e}},	//   _till_, çekl, ्राफ, _uuel_
  { {0xdb1c0061,0xc6920009,0x15150024,0x69080009}},	//   rpré, _יאן_, _ідея, ִּתְ
  { {0xdb1c03eb,0x65630149,0xe2f9002d,0xf8b60009}},	//   spré, minh, _межі_, ופתי_
  { {0x501a000b,0xe9ff001a,0xe8050037,0xb75a0024}},	//   קורו, _nhắc_, _रहना_, ішнє_
  { {0x6b89014d,0x236d0026,0xa294002d,0xd7f8000d}},	//   mleg, mnej_, _заці, ată_
  { {0xfce6002d,0x236d04f4,0x2480003a,0xe9180024}},	//   ього, lnej_, şime_, _ночі_
  { {0xd7f8007d,0x628f0027,0x443e2696,0x6da30ed0}},	//   ctă_, škoć, ât_, тира
  { {0xe9ff0020,0x37870014,0x236d0512,0xe1f90073}},	//   _chắc_, _общо_, nnej_, otų_
  { {0xe1f9007a,0xed5a00de,0x61e403ae,0x0e660024}},	// [7a80] ntų_, _мои_, uril, _ікон
  { {0xe1f9007a,0x93c5001a,0x628601e9,0x69d62abe}},	//   itų_, _khắ, _vyko, rsye
  { {0x6286003e,0xdfcf0003,0xa00a0003,0x6b890028}},	//   _wyko, ليل_, تقال_, kleg
  { {0xe1f9007a,0x644307ff,0x064a0003,0xddc20002}},	//   ktų_, dyni, يلاً_, czoś
  { {0x99d60003,0x236d10d3,0x88c60012,0x8f9b0009}},	//   _تتجا, dnej_, _يتسل, קיני
  { {0xef1f000e,0x4c940015,0xd6570009,0x6b82013e}},	//   elül_, нилс, וינת_, _skog
  { {0x93c50020,0x64432abf,0x6b890795,0xf1a70011}},	//   _nhắ, _ünit, fleg, _कूटन
  { {0x27f70145,0x6b892ac0,0xda140001,0xcc77000b}},	//   žení_, gleg, едињ, ועצה_
  { {0x6d4727e8,0xe1f90073,0xbb830012,0x26c60132}},	//   ykja, gtų_, خليي, mboo_
  { {0xd8f8007c,0x93bc000d,0x236d0034,0xb034004c}},	//   чної_, _crăc, anej_, енош
  { {0xc057002d,0x93c5001a,0x79880431,0x236d0b7f}},	//   дія_, _chắ, rldw, bnej_
  { {0xd7f8007d,0x122a0015,0x236d084b,0x57fb0009}},	//   rtă_, _моей_, cnej_, חלטו
  { {0xd7f8007d,0xdb080164,0x569400b3,0x8b9b0009}},	//   stă_, _judí, кают, _ובאת
  { {0xd7f8000d,0x2bbb0012,0xd1c900ae,0x661d2ac1}},	//   ptă_, قارة_, _ربهم_, rvsk
  { {0xe7e5015f,0x6d470028,0xac180339,0xb8e40011}},	//   _किया_, rkja, мору_, ौर_
  { {0x65630017,0xa7380012,0x16000011,0x75d50012}},	//   zinh, _يثير_, ोबार_, _كيبا
  { {0x64430002,0x29182ac2,0xd91b003c,0x290c0018}},	// [7a90] zyni, _bara_, жье_, oeda_
  { {0xddc20002,0xdb010052,0x661d0028,0x236d047f}},	//   szoś, _zulä, _áski, znej_
  { {0xe9ff001a,0x29182ac3,0x65630018,0xef1f0060}},	//   _thắc_, _dara_, vinh, ylül_
  { {0x290c00c1,0xe1f90010,0xc49a000b,0xc2eb0003}},	//   heda_, ytų_, _משתת, _بعدم_
  { {0x236d0026,0x291820b5,0xed4e0015,0x16220011}},	//   vnej_, _fara_, го_, मियर_
  { {0x236d0002,0x290c284b,0x867c0009,0xa0c50012}},	//   wnej_, jeda_, קרגו, _سيرو
  { {0x673b0108,0x236d2338,0x290c0010,0x65632ac4}},	//   _touj, tnej_, deda_, rinh
  { {0xcb120009,0x3cff0011,0x8fa50012,0x6b510248}},	//   ָ֜ה_, श्ते_, _أمره, _fåge
  { {0xe1f90010,0x236d083f,0xda160011,0x6b892ac5}},	//   utų_, rnej_, तिगत_, rleg
  { {0x290c0051,0xe1f90010,0x236d083f,0xd1020011}},	//   geda_, rtų_, snej_, र्पण_
  { {0xe1f9007a,0x13f5002d,0x3cf80012,0x236d28f3}},	//   stų_, _їздя, _تعقد_, pnej_
  { {0x44260026,0x8c1a000b,0x141a0009,0xe1f90073}},	//   _čo_, _מועי, _מועב, ptų_
  { {0x3ea40248,0x61ed0e64,0x97560009,0x290c2ac6}},	//   ämt_, jual, תירו_, beda_
  { {0x98aa0066,0x93c5001a,0x290c2ac7,0xdd920012}},	//   _době_, _thắ, ceda_, اوس_
  { {0xeb9a111e,0x232a0001,0x6ff50003,0x7ff50012}},	//   зив_, пови_, _أستط, _أستا
  { {0xc7960015,0xdbd60051,0xdb060031,0xdb050031}},	//   _ярлы, _rääg, _kiké, _puhá
  { {0x61fb2ac8,0xda660012,0x29182ac9,0x2d840025}},	// [7aa0] ntul, راري, _para_, îmes_
  { {0x9657000b,0xdce30010,0xbd460012,0xdb060031}},	//   _נשיא_, monė, _أندي, _miké
  { {0x61fb0051,0x29182aca,0xb9080011,0xd3da0012}},	//   htul, _vara_, _यय_, _عبدا_
  { {0x60c3003a,0x98b1004b,0x61fb2acb,0x03bb00af}},	//   ınma, _poză_, ktul, _מצטל
  { {0x79810002,0x61ed00b6,0x4f650012,0x29182acc}},	//   kolw, cual, خالف, _tara_
  { {0x59b50044,0x3ead286c,0x20070097,0x3cfb0011}},	//   _अंतर, _eget_, _opni_, ल्ले_
  { {0xf8a7015f,0x6f040bd3,0xdee614a1,0x66e60400}},	//   _कृपय, _obic, _пови, _пова
  { {0x2d8500a2,0xe8050037,0x6ffb000b,0x31c60fa4}},	//   _ekle_, _रहता_, _מפלג, нсов
  { {0x3f820002,0x61fb15de,0x32b70012,0xbab70012}},	//   doku_, gtul, ردية_, رديء_
  { {0x09f7000b,0xccf80066,0x290c01e3,0x9e63004c}},	//   עמים_, _změn_, ueda_, _свуд
  { {0x61ed007d,0xf65f0065,0x1957000b,0xc953000b}},	//   zual, _þær_, גביל_, רמת_
  { {0x290c012e,0x95820002,0x98aa0066,0xdcee0030}},	//   seda_, żąda, _sobě_, pobě
  { {0x7d1a015e,0x69c40002,0x61fb000d,0x290c00b6}},	//   _kats, jpie, ctul, peda_
  { {0x2d540051,0x02170009,0xba170009,0xc6930009}},	//   _näed_, _נחום_, _נחוץ_, טאר_
  { {0xef1f00a2,0x69c4001e,0xc8850052,0xdb1c0029}},	//   nlük_, epie, ößte_, aprí
  { {0xe3b00003,0x3ea9013a,0xa3e80011,0xcb090012}},	//   صرف_, žati_, _बिन_, بيرن_
  { {0xb5a701d4,0x6e242acd,0x52150048,0x98aa0030}},	// [7ab0] _прой, _grib, ъдат, _tobě_
  { {0x35f80003,0xdb01006f,0x6f0f1d98,0x6f1d0347}},	//   _أريد_, _utlö, lecc, ldsc
  { {0xdcb10020,0x2d83007a,0x7f19002d,0xa3b00011}},	//   _bản_, moje_, ділу_, _टूल_
  { {0x0cbb0011,0x2d830073,0x37c40012,0x22950012}},	//   ॉर्म, loje_, اينف, _للجس
  { {0x61fb000d,0x64580029,0xd7740012,0x82d60009}},	//   xtul, ezvi, دالع, _בורג_
  { {0x2d830010,0x2bb90012,0x398b0040,0x20d40012}},	//   noje_, وابة_, røsk_, _متفج
  { {0x2ef50046,0x2d830010,0x8cd30011,0xdc6c0009}},	//   _извр, ioje_, डरबो, ּ֣וֹ
  { {0xb33b00a2,0x3eb9003a,0xd1380002,0x6f0f0054}},	//   _biçi, _üst_, eją_, jecc
  { {0xfe730003,0x11d60003,0x29550014,0x2d832156}},	//   _صدر_, نوية_, вънр, koje_
  { {0x2d83007a,0xd6841128,0x6b8d0052,0xa1560001}},	//   joje_, _сусп, hlag, кању_
  { {0xf8b20093,0x69c4003e,0xf992000b,0x61fb2ace}},	//   ישי_, zpie, שרי_, stul
  { {0xd1380002,0x366a0001,0x6b8d1e9d,0x61fb2605}},	//   ają_, дамо_, jlag, ptul
  { {0xee3700b3,0x6b8d2acf,0x06750048,0xa3d40011}},	//   вня_, dlag, гуря, सीन_
  { {0x6f1b0039,0xd1380002,0xd256000b,0x6da60001}},	//   _lauc, cją_, _בשנה_, ђива
  { {0xccf2000b,0x69dd013e,0x0c79003c,0x6b8d1588}},	//   יכם_, _avse, есты_, flag
  { {0x6b8d0101,0xc052000b,0xed59001e,0x6f1b0404}},	//   glag, _כזו_, īža_, _nauc
  { {0x7e9a0012,0x03a31fbe,0xef1f0060,0xe1fa04a5}},	// [7ac0] _تنظر_, рито, zlük_, ьга_
  { {0xd5b70044,0xdcb10020,0x672d0eb4,0xf8e10037}},	//   _इंतज, _sản_, _znaj, पणिय
  { {0xc059002d,0x6609002c,0x69c42ad0,0x8fa60ec6}},	//   нії_, _apek, spie, важе
  { {0xdcb10020,0x4477000b,0x0bb7000b,0x54770009}},	//   _bảo_, _יעיל_, _שלכם_, _יגיע_
  { {0x6b840061,0x628e0002,0xa66d000b,0xcf930009}},	//   moig, ębok, ּדוֹ, בטא_
  { {0xde930001,0xad9b0028,0xa8060294,0x365b0009}},	//   јашњ, rtúg, _изгл, וכננ
  { {0x86ea0003,0x98be0010,0x6609002c,0x3f6a05f8}},	//   _يعرف_, nktą_, _epek, _живо_
  { {0x6f1b0061,0xfbd30009,0x61e92ad1,0x67a50012}},	//   _gauc, בתה_, frel, _محقق
  { {0xdb0d000e,0x7d1a0b3a,0xe61a0048,0xb6060159}},	//   ókén, _tats, _юда_, ndšč
  { {0xba9b000b,0x6b8d04d2,0x63ab0795,0xde250012}},	//   וספי, zlag, _eign, _حرفً
  { {0x61e9000d,0x34b7000b,0x14170003,0x6f0f0840}},	//   arel, _ספאם_, _ليلة_, tecc
  { {0x2d830002,0x2d540051,0xd1380002,0x7bdc0c62}},	//   woje_, _näeb_, sją_, dsru
  { {0x2d83007a,0x61e9003a,0x6f0f2ad2,0x6f1d01c1}},	//   toje_, crel, recc, rdsc
  { {0xe9ff001a,0x64450052,0x63ab0002,0x99890034}},	//   _nhạc_, ähig, _zign, zwał_
  { {0x8937000b,0x99890002,0x2d832ad3,0x28370012}},	//   _ברגע_, ywał_, roje_, _لأية_
  { {0x97a40015,0x291c0af1,0x16cc0011,0xd3780024}},	//   _крыл, _hava_, ारोब, вчу_
  { {0xd6fa000b,0x291c0051,0x6f1b0168,0x49b80012}},	// [7ad0] _אִיש, _kava_, _rauc, نالد_
  { {0xef1f003a,0x6b8d2ad4,0x29190012,0xa968004c}},	//   ldü_, slag, عقاد_, виђа_
  { {0x6c35000a,0x7ae20006,0x6b5e0039,0x29c2001a}},	//   _صفحا, _odot, lūgu, hưa_
  { {0x7c2a0065,0x7bc70027,0xef1f0060,0xdb050097}},	//   _áfra, mpju, ndü_, _athö
  { {0xdef80015,0xfce504b3,0x99890034,0x23690034}},	//   тых_, голо, rwał_, miaj_
  { {0x75d20003,0x7ae22ad5,0x0d840024,0x44252ad6}},	//   حيوا, _adot, алін, _prl_
  { {0xdcfc001e,0x6f1b0052,0x26d92ad7,0xb8e90011}},	//   norā, _tauc, kaso_, ैर_
  { {0xe4e30037,0xb88200f1,0xaad30037,0xdce30010}},	//   कृति_, číta, तरिक, minč
  { {0x224900ec,0x77640014,0xdce32ad8,0x20d50024}},	//   nyak_, _търж, nonī, лінс
  { {0x3a262ad9,0x61e601bd,0x8cca0011,0x69db2ada}},	//   _drop_, ákla, _स्पो, rsue
  { {0x63ab0101,0x3a260070,0x628b0002,0xb97c0009}},	//   _tign, _erop_, _wygo, ונזי
  { {0xf092000b,0x628b0002,0x69c10107,0xdb08000e}},	//   מני_, _tygo, _člen, _tudá
  { {0xcdf60015,0x09e50015,0x6d412adb,0x9b160009}},	//   ычны, _солн, _kola, _תחנה_
  { {0xdce32adc,0xe1f6004c,0x60d52add,0x2249020d}},	//   kinč, _сгш_, _nezm, dyak_
  { {0xdd8f0012,0x5faf0011,0xf9920009,0xa2e60adc}},	//   سوف_, _जंगल, _הרג_, ловд
  { {0xe7f70011,0x6441008e,0x7bdc03bd,0x8cca0610}},	//   ँढना_, älia, rsru, _स्नो
  { {0x0eaa007c,0x60d5001e,0x17570009,0x7bdc2ade}},	// [7ae0] _який_, _bezm, _תספר_, ssru
  { {0x67050037,0x6d41001e,0x7bda000e,0x6b5e001e}},	//   ष्ठक_, _nola, átus, lūgt
  { {0xdcb10020,0x3cfb000b,0xd46a0001,0x409629ef}},	//   _cảm_, _אלינ, _чине_, урат
  { {0x4f950024,0xf1bf2adf,0x27e70097,0x7d1e2ae0}},	//   арчу, _irán_, ánna_, _haps
  { {0xdee30014,0x7d1e2ae1,0xe9ff0081,0x43790009}},	//   сочи, _kaps, _thạc_, _יְשׁ
  { {0x645c0029,0x60d5003a,0xa3cb0011,0x3f8f005e}},	//   ozri, _gezm, रीक_, algu_
  { {0xab5c0039,0x4ab80044,0xa818000b,0xb7960001}},	//   _atļa, _अलाव, _בֵּי, _браћ
  { {0x291c0039,0x7d1e00b9,0x3a26019f,0x75d60012}},	//   _sava_, _laps, _prop_, _ميرا
  { {0x8f9b0009,0x2258003c,0x29c70012,0xa2260012}},	//   _טילי, типы_, هِيَ_, اربه
  { {0x7d1e2ae2,0x0217000b,0x6d4e0070,0x25aa0012}},	//   _naps, נחים_, jkba, _أدري_
  { {0x3137000b,0xb8dc0037,0xb4c20037,0x661d0028}},	//   אריך_, _अल_, ूरी_, _áskr
  { {0x60c400a2,0x3a260108,0x6d4e0227,0x6d410227}},	//   _şimd, _trop_, ekba, _zola
  { {0xe292000a,0x5ce7007c,0xb5fb000f,0xef1f003a}},	//   _اذا_, люва, zzáf, rdü_
  { {0x7c870014,0x74ca0011,0x23690034,0x4a5b0009}},	//   губе, _स्मृ, wiaj_, _אדדו
  { {0x07040037,0x26d9002c,0x3c780009,0x03d50024}},	//   रभाव_, paso_, דָּב, ржбю
  { {0xe3150001,0x60da003a,0x6d4e281a,0xc3340009}},	//   јмањ, latm, akba, סוּ_
  { {0x5a350014,0x3e070024,0x32b80012,0x62340198}},	// [7af0] шнат, _сяйв, ادفة_, бету
  { {0x660d0101,0x23690002,0x7bc7005e,0x29071d3d}},	//   _ipak, siaj_, ppju, ýna_
  { {0xdb1f000e,0x60d500d9,0xdb1c01bd,0xa3cb0011}},	//   ívók, _vezm, sprá, रीख_
  { {0x644a003e,0xdce30010,0x7d1e0066,0x398b036e}},	//   dyfi, rinč, _zaps, løst_
  { {0xa91c0029,0x644a0028,0xa3ae0011,0xdce319b3}},	//   voľn, eyfi, ओआई_, sinč
  { {0xa50914cf,0xe5a504ba,0x64480032,0xfbc50024}},	//   тека_, шили, ädig, абко
  { {0xeab10003,0x251c0009,0xa9540024,0x8cc10011}},	//   يعة_, גווא, _укрі, रुषो
  { {0x660d0042,0xdd050060,0x93bc004b,0xd5b50011}},	//   _opak, ısıy, _grăm, ंदाज
  { {0x5f440012,0x09f60012,0x7c280b40,0xc3340009}},	//   _انقل, لفية_, _erdr, מוק_
  { {0xaa080003,0x32d3001a,0xd6d90002,0x61ed2ae3}},	//   ازيل_, ảy_, _koło_, iral
  { {0x6b510163,0x644a0002,0x660d2ae4,0xb4c10011}},	//   _någo, cyfi, _apak, ंडी_
  { {0x2d910066,0xf43a0009,0x4c3a0009,0x60da005e}},	//   elze_, _בתעש, _בתעב, aatm
  { {0x4384000a,0x7bc50065,0xbb840003,0x04b6002d}},	//   _النق, _athu, _الني, исвя
  { {0x2d872ae5,0x18a5047a,0x61ed2ae6,0xfbc60557}},	//   none_, _калм, dral, ибго
  { {0x6f092ae7,0xdfd10003,0x6d4e0ad2,0xaba60003}},	//   _obec, _بيع_, rkba, لإره
  { {0xd00e0003,0x1efa0012,0x58940012,0xc4d10011}},	//   _آلي_, _شعبة_, _اجهز, हरुख
  { {0x44200020,0xc332000b,0x42230015,0xd1320012}},	// [7b00] ̉i_, חון_, одтв, يمر_
  { {0xe3ba0015,0x7e9b0009,0xc0e60a32,0x6f092ae8}},	//   _ибо_, _בספו, рожк, _abec
  { {0x661b035f,0x46ba0011,0x86c60012,0xa3d70011}},	//   _asuk, _इलाह, ليان, ़ीम_
  { {0xb8ed0037,0xf1bf0066,0x3f78013a,0x6c7b0009}},	//   _ष्_, _král_, ačun_, _יריד
  { {0x2d872ae9,0x63a42aea,0x25b70012,0x98de0024}},	//   fone_, mmin, لهند_, _освi
  { {0xb5fb000f,0xcbe60014,0xacf8002d,0xe5e50003}},	//   szág, ации, унку_, إثني
  { {0x6ca30014,0x69c90227,0xdb0d0032,0xd37a0048}},	//   оръж, epee, nmaß, кчи_
  { {0x644a2aeb,0xa3cb0011,0x501b0009,0x0b18004c}},	//   ryfi, रीट_, _בולו, ужић_
  { {0xd1300003,0x99820066,0x644a2aec,0x8f8b0009}},	//   كمة_, íků_, syfi, _יְמֵ
  { {0x63a400a2,0x7a0a001e,0x8dfb000b,0x62990002}},	//   hmin, mētā, _בהמת, _dzwo
  { {0x63a411a0,0x60da003a,0x7a0a001e,0xb7c2002d}},	//   kmin, ratm, lētā, блiк
  { {0xdce3001e,0x7bca0052,0xe7f70011,0x3e4a0073}},	//   minā, mpfu, ँढता_, kėtą_
  { {0xdce30039,0x60da003a,0x6722001e,0xbb3b000b}},	//   linā, patm, idoj, _שעדי
  { {0x89db0009,0xd5780009,0x3e4a0073,0x61ed2aed}},	//   _יחדי, אָֽר, dėtą_, vral
  { {0xdce30039,0xfb670001,0xb19b000b,0xa99b0009}},	//   ninā, ањам, _שיוכ, _שבור
  { {0xe7380046,0x67200027,0x23bc000e,0x883b000b}},	//   _већ_, _namj, _díj_, _יתוו
  { {0x88c70003,0x2d87002a,0xba990024,0xdcef0030}},	// [7b10] لتال, yone_, уває_, _řeče
  { {0x61ed0176,0xdcf8001e,0xa2b30011,0xa3d70011}},	//   rral, ilvē, _अलक्, ़ीड_
  { {0x7d15003a,0x2b810002,0x6f01000e,0x628f0002}},	//   mezs, rócz_, jábó, _wyco
  { {0xdce3001e,0x2d870070,0x6e290650,0xe81e0011}},	//   dinā, wone_, _preb, _बनना_
  { {0x6d450005,0xfe700003,0xcb360009,0x9f040012}},	//   _koha, وده_, _הארי_, تونو
  { {0x05640024,0xb4c10011,0x356b0048,0x09b60009}},	//   овін, ंडे_, ърен_, _לפשט_
  { {0x75580009,0xd1300012,0xeb020011,0x2d872aee}},	//   שבונ_, _تمّ_, लभूत_, rone_
  { {0x4478000b,0xcc78000b,0x2b15002d,0x6e292aef}},	//   יעול_, יגות_, ськр, _treb
  { {0xaa490015,0x7a0a001e,0xcdf40003,0xdce30035}},	//   уппа_, cētā, _وأكث, ainā
  { {0x00c90015,0x69c9004a,0xdce3001e,0x67200027}},	//   ылок_, rpee, binā, _zamj
  { {0x0495000a,0xdce30039,0x7c950003,0x6c850003}},	//   _الاح, cinā, _الاص, _الضم
  { {0x2f56007c,0x6b550097,0x9756004c,0x69c92af0}},	//   стос, _fága, стољ, ppee
  { {0xa3b00011,0xacea0012,0xdcfc0034,0x236d0034}},	//   _टूट_, ُرسل_, horą, miej_
  { {0xd4910020,0xc0cb0001,0x987a004b,0xdb0d0032}},	//   _kỳ_, _руде_, nţăm_, tmaß
  { {0x63a40005,0x7a0a0039,0x61e20107,0x85790014}},	//   tmin, zētā, _zvol, рсят_
  { {0x236d003e,0xdcb10020,0xdb0d0052,0x6b890227}},	//   niej_, _cải_, rmaß, noeg
  { {0xdce30039,0xbb430001,0xeb970015,0x9757000b}},	// [7b20] zinā, четк, сит_, _לשקף_
  { {0x8c4900a2,0xa3e80044,0xb4c10037,0x6e3b000b}},	//   _başı, _बिल_, ंडो_, _עתיד
  { {0x236d003e,0xbcb70009,0x1bec0011,0x8ffa0012}},	//   kiej_, _לפיו_, _जटिल_, طرار_
  { {0x66020006,0x27fa0119,0xd00f0003,0x644e0010}},	//   ttok, _åpne_, علن_, mybi
  { {0xd5b1001a,0xcf250012,0xdb1c0032,0x6d45016d}},	//   _bí_, ترلي, rprä, _yoha
  { {0x7a0a001e,0xdb1c0052,0xdce3001e,0x8e20002d}},	//   rētā, sprä, tinā, кiв_
  { {0x61f6003a,0x6602282f,0xf8631271,0x61e22af1}},	//   luyl, stok, _евро, _svol
  { {0xf0630047,0x236d0002,0xdce3001e,0xb2180012}},	//   _эксп, giej_, rinā, لقبض_
  { {0xdce30039,0x61f6003a,0x6f01000e,0x44270260}},	//   sinā, nuyl, sábó, avn_
  { {0x8c49003a,0xdce3001e,0x290a0029,0x644e0010}},	//   _yaşı, pinā, ýba_, kybi
  { {0x23810010,0xa7150024,0x236d0034,0x6d4524ed}},	//   lėje_, омні, biej_, _roha
  { {0x236d0002,0x644e0010,0x29020066,0x64410872}},	//   ciej_, dybi, řka_, älim
  { {0x2381007a,0x6e220039,0x61e20066,0x3ead004a}},	//   nėje_, _šobr, _uvol, äet_
  { {0xe3b30003,0xdce3000d,0x6d5d0073,0x67d415f5}},	//   كرر_, mină, _įsak, _доку
  { {0x71650012,0xf3970012,0x644e0073,0x63ba0031}},	//   _بانك, مؤرخ, gybi, _jutn
  { {0xa91c0026,0x443f001c,0x92b70003,0x656e020d}},	//   koľk, ću_, صحرا, aibh
  { {0xdb080029,0xc2c40012,0xc8d90024,0x19bb0012}},	// [7b30] _budú, سيلي, имає_, اطرة_
  { {0x236d003e,0xba9b000b,0x3ead001e,0x32d7001a}},	//   ziej_, רסמי, žets_, ầy_
  { {0xdcb10020,0x44272af2,0x225f000e,0xd8790003}},	//   _tải_, _én_, zzuk_, جمات_
  { {0xdddb014a,0x18a40024,0x75212af3,0x93bc004b}},	//   _využ, чаєм, _salz, _grăi
  { {0x6b8900bd,0xf12700c0,0x98a70002,0x95c40012}},	//   voeg, _льво, _inną_, كينه
  { {0x8c4900a2,0x67d51498,0x60de001e,0xd8b80012}},	//   _taşı, _могу, capm, _هدفا_
  { {0xd5b10020,0x8c420014,0xdb1c021e,0x6b891730}},	//   _ví_, деще, språ, toeg
  { {0x6d5c022d,0x39e911ed,0x19c50024,0x23810073}},	//   zhra, адио_, обим, bėje_
  { {0x4424001a,0x24890002,0x32160012,0x644e0034}},	//   ̉m_, łam_, قييد_, zybi
  { {0x764f0002,0x63ba000e,0xb4b80011,0x60090b12}},	//   dycy, _futn, _छले_, аном_
  { {0x8c190003,0x236d0002,0xe73a0014,0x07a600b3}},	//   _خيار_, piej_, аен_, жанн
  { {0xc4c90093,0x61ee003a,0x99540029,0x16aa0103}},	//   _יג_, ünlü, mäť_, ивни_
  { {0x200a00a2,0x65a00052,0x2bb5001e,0x25b20060}},	//   çbir_, höhe, _vācu_, _ünlü_
  { {0x644e0914,0xdcf80030,0x7afb005e,0x6e2d2af4}},	//   tybi, dově, lgut, _drab
  { {0xa34a00ac,0xd91a0009,0x97c50012,0x3a290060}},	//   азва_, _כוסל, _بقبو, evap_
  { {0xfbe7008a,0x3994004a,0x644e0914,0x7afb2af5}},	//   _để_, mäsi_, rybi, ngut
  { {0xb5fb0029,0xcb12000b,0x2480003a,0xf4b60012}},	// [7b40] rzác, ולן_, ğimi_, _وإدخ
  { {0xc8960046,0x2480003a,0x50960001,0x23810010}},	//   орењ, şimi_, оређ, vėje_
  { {0xe0d5002d,0x93bc000d,0x8cb90011,0x61f60060}},	//   яють, _trăi, ्डरो, suyl
  { {0x23810010,0x11d6002d,0x60080009,0xd00f0012}},	//   tėje_, _мігр, מִנְ, ضله_
  { {0x6b81000f,0xeda60001,0xdb1c000e,0x6445004a}},	//   élge, ошко, őzón, ähin
  { {0x23810010,0x1cba000b,0x61e41407,0xc43a0009}},	//   rėje_, ׁמְע, msil, ֹתֵי
  { {0x6b5c0061,0x23810010,0x3994004a,0xe8190011}},	//   _lége, sėje_, jäsi_, _फैला_
  { {0x2381007a,0x8cca0037,0x93b70009,0xdb040025}},	//   pėje_, _स्रो, חלקו_, umiè
  { {0x20050034,0xbb470012,0x61e42af6,0x9f4d0018}},	//   etli_, تلين_, nsil, judá_
  { {0x3a37000b,0x61e40038,0x32370009,0x64360012}},	//   קרים_, isil, קטין_, _وراء
  { {0x88bb000b,0xb19b0009,0x6d5a079b,0x3dc90034}},	//   ימיז, שייכ, _ilta, _staw_
  { {0xd6db0046,0xc1780010,0xaba50003,0x61e4019a}},	//   што_, snė_, _فإنه, ksil
  { {0xdb06004a,0x6b5c2af7,0x39472af8,0xaa570012}},	//   _mikä, _végd, _fons_, _ولما_
  { {0xc5f30093,0x6ad30037,0x65a0004a,0x7e9b0009}},	//   ודש_, तर्र, yöhe, יסכו
  { {0x29c0001a,0xc7970012,0x236b004c,0xdc3d0064}},	//   _hòa_, _وشعب, ајао_, páčt
  { {0xa3dc0037,0x6f0d0027,0x6e2d0c7f,0xdce30034}},	//   तीय_, _ubac, _trab, miną
  { {0x60dc00c6,0x6d5a165d,0x6d480051,0x61e4002c}},	// [7b50] _berm, _olta, _ooda, gsil
  { {0x6d48001e,0xd7f8000d,0xceb4000b,0x60dc00b6}},	//   _noda, ouă_, _קיץ_, _cerm
  { {0xd7f8000d,0xdce7001e,0x6d410051,0x7ae0002c}},	//   nuă_, cijā, ölau, kamt
  { {0xdcf80013,0x441a000b,0x8c1a000b,0xf6e7002d}},	//   pově, _פורס, _פורי, іцен
  { {0xf770000a,0xbb3a000b,0x7dc40003,0x433a000b}},	//   خال_, _הערי, وتوك, _הערב
  { {0xabd50001,0x6d48042f,0x200501bd,0x8d650434}},	//   пциј, _coda, ytli_, явле
  { {0x9cd80009,0xf9920009,0x6d480495,0xdfd10012}},	//   חווה_, _נרל_, _doda, _سيء_
  { {0xb5fb000f,0x3994004a,0x96f80015,0xe9d90695}},	//   zzáa, väsi_, _мест_, бки_
  { {0xddc6003e,0xe1f10003,0xf6280024,0xde580024}},	//   zykł, رسة_, _міфи_, _даті_
  { {0x3994004a,0x99540029,0x6b5c057d,0x60c50e22}},	//   täsi_, päť_, _rége, nchm
  { {0x52b50012,0xc1720009,0xd1480012,0x661d0034}},	//   _فماذ, תחי_, تشين_, ewsk
  { {0x6d4800bd,0x0056000b,0xa856000b,0xed590027}},	//   _zoda, פשרת_, פירה_, _duže_
  { {0x3994004a,0xa3d70037,0x200505b1,0x539a0009}},	//   säsi_, ़ीर_, stli_, _פינו
  { {0xc1040003,0xe1640003,0x6b5c000e,0x1ddd0037}},	//   _يوني, _يدوي, _vége, नीयत
  { {0x68e10005,0x6b550065,0x03a60001,0x63a92af9}},	//   mald, _lágm, зиво, omen
  { {0xdce7001e,0x91b1001a,0x6b5c000e,0xbb430469}},	//   rijā, _đáp_, _tége, неск
  { {0x7f770093,0xdfa5000a,0xd29a002d,0xb1830066}},	// [7b60] _מעקב_, _تحوي, стві_, šťuj
  { {0x63a903c0,0x11d70012,0x64a61390,0x776d0064}},	//   hmen, سومة_, _напа, _zmax
  { {0x351b000b,0x8d850003,0x63a92afa,0x73e3003c}},	//   _פוטנ, _تشين, kmen, _поэз
  { {0x68e12afb,0xc7d6000b,0xdfcf0003,0xc7af0012}},	//   hald, פוני_, اين_, هّل_
  { {0xf3f1008a,0xa3b50037,0x68e11b4b,0xd2b70009}},	//   ợc_, _छूट_, kald, _מלכת_
  { {0x68e12afc,0x63a92afd,0x6a9b0009,0xdd8f0012}},	//   jald, emen, _לשכנ, هون_
  { {0x7ae0002c,0x2d980031,0x6d5a2afe,0xccf80030}},	//   tamt, ilre_, _vlta, _směs_
  { {0x5a340014,0x7b630015,0xb40d000b,0x0b8a0001}},	//   днит, етье, ׁלוֹ, љски_
  { {0xa3dc0044,0x93bc007d,0x6d482aff,0x7f3b0009}},	//   _तौर_, _arăt, _toda, _פעמו
  { {0x7ae008fa,0x68e10f29,0x865b0009,0x6d48008e}},	//   samt, gald, _הדמי, _uoda
  { {0xa91c0026,0x7ae00027,0xbd290012,0x07e30024}},	//   koľv, pamt, _بأقل_, нцям
  { {0x29c0001a,0xdc3b0009,0xf8af0012,0xc43b0009}},	//   _tòa_, _לעבר, دةً_, _לתבי
  { {0x7d030163,0xf1bf001a,0x91a6001a,0xa3c20011}},	//   _önsk, _trái_, _trò_, _एंड_
  { {0x4a53002d,0x187400b3,0x23810010,0x68e11209}},	//   _якіс, _огля, dėja_, cald
  { {0x4395007c,0xab95002d,0xc19b000b,0x6d550070}},	//   давс, диві, _השגי, rkza
  { {0xa87b007e,0x88bc0066,0x187b000b,0x307b000b}},	//   _לאור, zděl, _לטוב, _לאונ
  { {0x248d003e,0x7afd0054,0x23810073,0x88bc0030}},	// [7b70] łem_, òsti, gėja_, yděl
  { {0x99d40003,0xa8a707e8,0x4ddc0009,0x865c0009}},	//   عتقا, прек, _החזו, _לדחי
  { {0xb4d9015f,0xf9900003,0x63a90c9e,0x60c503c0}},	//   ारी_, ابق_, ymen, rchm
  { {0x60c50052,0xfec40012,0x91790081,0x64451545}},	//   schm, ّينَ, _bận_, ähim
  { {0xb5fb000e,0x9179001a,0x5a34002d,0x9f5f00b8}},	//   zzán, _cận_, _знят, ittà_
  { {0xe618002d,0x62800010,0x518705fb,0xccf80030}},	//   яді_, _žmog, _хума, _směr_
  { {0xea000020,0x63a92b00,0x68e12b01,0x7d7c0009}},	//   _đại_, tmen, vald, זנגו
  { {0xd1c90048,0xeb930009,0xab790012,0xf4140009}},	//   олие_, ךָ֥_, تمعا_, תפק_
  { {0x80e10044,0x32090101,0xf8e10037,0x4ea70001}},	//   _फ़ाइ, ntay_, _फ़ाय, _хрва
  { {0x6e280009,0x57e912fa,0x3f8f2b02,0x63a92b03}},	//   _מֵעַ, одом_, logu_, smen
  { {0x212b0066,0x63a92b04,0xc9520009,0x24550012}},	//   ěch_, pmen, דמי_, _تناس
  { {0x7c940003,0x68e12b05,0x80a50011,0x60080009}},	//   _أشكا, sald, _करने, הִשְ
  { {0xb5fb0031,0x69cb0248,0x68e12b06,0x25bf01a4}},	//   szán, _utge, pald, _juul_
  { {0x25bf0051,0x91ba0009,0xa0c50012,0x19ba00af}},	//   _muul_, _ומסי, _غيبو, _ומסב
  { {0x3f8f0005,0x141a0003,0xa507003c,0xdbf20030}},	//   kogu_, غيرة_, ьера_, přít
  { {0xf0920093,0xf4120009,0xe9da11e0,0x21270081}},	//   _שנה_, כפל_, жка_, _hanh_
  { {0xe297029b,0x2fcd0027,0xe3b8003a,0xb2260028}},	// [7b80] дат_, _čega_, _asıl_, mræð
  { {0xb2260028,0x15fc0011,0x6b5c0025,0x23810073}},	//   lræð, उंसर_, _méga, rėja_
  { {0x6b5c0061,0x653b0009,0x5d3b0009,0x21270081}},	//   _léga, _ועיד, _ותיא, _manh_
  { {0x61fb0269,0x2bc40011,0xa3c10011,0xdb24008e}},	//   kuul, _लंबा, ंदन_, ärär
  { {0x6b5c0061,0xe81d0011,0x21270081,0x6441008e}},	//   _néga, यौता_, _oanh_, äliv
  { {0xdfd2000a,0x7ae40006,0x61fb004a,0x9179001a}},	//   _ليس_, lait, duul, _vận_
  { {0xab942b07,0xdff5003c,0x7d1c2b08,0xc10e0081}},	//   никі, _пять, iers, _bỗng_
  { {0x9179001a,0xdb0f004b,0x7ae42b09,0x7d1c2b0a}},	//   _tận_, _zicâ, nait, hers
  { {0x8bb3000a,0x61fb002c,0x7d1c2b0b,0x6d0e0011}},	//   خصوص, guul, kers, िभाग_
  { {0x7ae40108,0xd6d90002,0x2127001a,0x224b006f}},	//   hait, _dołu_, _canh_, äcka_
  { {0x21270020,0xb2260065,0xd0f7000b,0x9cd7000b}},	//   _danh_, fræð, ומית_, _חובה_
  { {0xb2260065,0x7ae4004a,0xa91c0029,0xf1bf01e9}},	//   græð, jait, voľu, _krát_
  { {0x996616dd,0x93bc000d,0xf6280024,0x7d1c2b0c}},	//   _откл, _trăs, міри_, fers
  { {0xb4d90044,0x88bc0013,0x1a9b0009,0x23a10031}},	//   ारे_, zděj, _וידע, mója_
  { {0xeb930003,0x23a1000e,0x7ae40ca7,0x734b0024}},	//   نظر_, lója_, fait, очав_
  { {0xc334000b,0xed590d1f,0x644301a0,0xa91c0064}},	//   עוּ_, _muža_, _ànim, roľu
  { {0xf1bf0020,0x4429001a,0x439404ba,0x5e440012}},	// [7b90] _quá_, ̉a_, татс, _لَيْ
  { {0x51f80047,0x2127001a,0x75280450,0x7d1c2b0d}},	//   ьную_, _xanh_, _nadz, cers
  { {0x9cd60093,0x6ec30011,0x47d40012,0x3f8f0073}},	//   _אותה_, रखपु, َيْر, togu_
  { {0x30a401b6,0x18770009,0xf1bf0030,0x7c25001b}},	//   трув, ועבר_, _brát_, _ishr
  { {0x23810010,0x8f9c000b,0xa2f60009,0x63ad2b0e}},	//   lėjo_, קידי, _אמרה_, mman
  { {0x11da000b,0x237f0027,0x78a20066,0xdca50de1}},	//   _מחשב, čuju_, řova, нали
  { {0xaf070098,0x68e5004a,0x07f80012,0x21270081}},	//   _очак, mahd, _يرفع_, _ranh_
  { {0x753a0052,0x04560012,0xce950048,0x68e5008e}},	//   _entz, علية_, _забъ, lahd
  { {0x443e0020,0x8cca0037,0x7d28004a,0xc0e50021}},	//   ̣t_, _स्को, össä, нопк
  { {0x29030051,0xfd100012,0x23810073,0xa7fc0060}},	//   üja_, _نجم_, kėjo_, rzın
  { {0xa91c0029,0xb5fb000e,0xdc030042,0x63ad2937}},	//   voľt, szál, očít, kman
  { {0x6d8904b4,0x7d1c003e,0x23810010,0x7d050052}},	//   hľad, wers, dėjo_, _achs
  { {0x3f9e0039,0x63630051,0x7ae40d66,0x7d1c2b0f}},	//   ētu_, _mõnd, vait, ters
  { {0x18690014,0xd1380002,0x7bc102bd,0x61e92b10}},	//   _нали_, gląd_, _kulu, msel
  { {0x69cf0039,0x61e902eb,0x6f1d01e0,0x6fc60011}},	//   _atce, lsel, besc, _रूपं
  { {0x7bc100b6,0xc3230001,0x38580012,0x29d60012}},	//   _mulu, лмск, _تشهد_, فيرس
  { {0x7bc100b6,0xf2d20009,0x00da0012,0x5e460012}},	// [7ba0] _lulu, טען_, كبات_, _أَخْ
  { {0x41030048,0x63ad2b11,0x61e92b12,0x7bc1008e}},	//   лзув, aman, isel, _oulu
  { {0xdfcf000a,0xc059002d,0x75280002,0x61e90052}},	//   ميل_, мії_, _radz, hsel
  { {0xeaa70351,0x5de60098,0x61e92b13,0xaa461913}},	//   _مع_, ежда, ksel, _земл
  { {0xfe720003,0x67050011,0x62830032,0xb2bb00af}},	//   ددا_, ष्टक_, ßnot, _ממכר
  { {0x7bc100a2,0x96d00037,0xb606009b,0xb5040011}},	//   _bulu, _ड्रॉ, mešč, श्चय_
  { {0x6aa2000e,0x6d580a50,0xc4d30009,0xb6060159}},	//   _szof, rkva, נגה_, lešč
  { {0xa3e20044,0x67c80013,0x6b9b0065,0x23a1000e}},	//   नीय_, _něja, glug, tója_
  { {0xd130000a,0xc333000b,0x6f1d00c1,0x3667096e}},	//   لمة_, רוח_, vesc, _зато_
  { {0x63ad1120,0x65a00052,0x61eb000e,0xb034004c}},	//   zman, wöhn, ágli, внош
  { {0x63ad0a99,0x74130012,0xec130012,0xa3dc0011}},	//   yman, _مولا, _مولد, तीश_
  { {0xb5fb000f,0x63630051,0x23810010,0xdb1c000e}},	//   szám, _kõne, vėjo_, ipró
  { {0xf710001a,0x28d10037,0xdb09000e,0x2d720035}},	//   _tầng_, _द्वि, _önál, aņem_
  { {0x6b510163,0xb5240047,0x63630005,0xac19002d}},	//   _någr, льск, _mõne, могу_
  { {0xb5540003,0x6575000e,0x0197000b,0x5ba7036f}},	//   دَّث, rizh, _רכוש_, ераз
  { {0x6b5513f1,0x409b000b,0x23810010,0xddd00066}},	//   _pági, _מבוס, rėjo_, řeši
  { {0xb5fb000e,0x2018253d,0xcfb80009,0x9f5a0025}},	// [7bb0] zzáj, _apri_, _אלהי_, cupé_
  { {0x644101a3,0x867c0009,0x7e7c0009,0x291e2b14}},	//   älis, _מרחו, _מאחז, neta_
  { {0x4ae00037,0xc0ab0003,0xb8080003,0x2d540051}},	//   नराव, سائل_, فيلم_, _päev_
  { {0x5727000a,0x7ff40003,0x86c40012,0x65a00032}},	//   عراق, اسلا, هيمن, höhl
  { {0x5e58002d,0xed4e0001,0x59b20037,0x2d72001e}},	//   ниця_, ао_, ीदार, zņem_
  { {0x4a5a0093,0x7bc102a0,0x61e90b4b,0xd6180012}},	//   _חדשו, _pulu, vsel, عتنا_
  { {0xd7f80046,0x64980098,0xdb1e0061,0xac160001}},	//   _пут_, нтър_, _supé, воју_
  { {0x9f5f004a,0x03950014,0x61e92b15,0x6b5c0025}},	//   nttä_, ърля, tsel, _dégo
  { {0xdcbb0047,0x9f4d0029,0xd7f8004b,0x07080012}},	//   _еще_, budú_, eră_, _سيلي_
  { {0x7bc12262,0x64480032,0xd7f8004b,0x6b9b2b16}},	//   _tulu, ädik, fră_, slug
  { {0xf7720003,0x8cca0037,0x62990002,0xebe40024}},	//   لاح_, _स्टो, _wywo, _боєп
  { {0xbbd60009,0x3f84005e,0x78ba0097,0x6d530035}},	//   _יועץ_, õmu_, _útve, šdaļ
  { {0xd7f8007d,0xdb1c0052,0xcb12000b,0x25f70011}},	//   ară_, rprü, _כלא_, उंटी_
  { {0x2d54004a,0xdb1c00f7,0xa0590003,0xb606009b}},	//   _näet_, sprü, _يؤثر_, vešč
  { {0xf990000a,0xeb9a0d60,0x69cb14ef,0xfce3016e}},	//   _ابن_, див_, ígen, росо
  { {0x332d2b17,0x6b5c0025,0x27f8068c,0x0b1a0012}},	//   ndex_, _négl, árne_, بقرة_
  { {0xe81d0037,0x558a0001,0x98bc0066,0x68e32b18}},	// [7bc0] यौरा_, _обим_, _nově_, _kend
  { {0x3d110037,0xa3c10037,0x68e300b6,0x9f46000e}},	//   द्दे_, ंदा_, _jend, puló_
  { {0x68e300c6,0xd12f0003,0xd70a003c,0x6b510248}},	//   _mend, تمل_, днее_, _vågr
  { {0x20070054,0xe1f90010,0x4f660012,0xe8130011}},	//   ània_, krų_, خاطف, _ठहरा_
  { {0xe7ee0044,0x33200054,0x5f050011,0xb5aa0012}},	//   _चटका_, meix_, _वास्_, واتك_
  { {0x68e30005,0x7ae20005,0x2385001e,0x33200054}},	//   _nend, _seot, vēja_, leix_
  { {0xa3dc0037,0x6b550028,0x5f060103,0x7d7b0009}},	//   तीं_, _lágu, _изва, ונסו
  { {0x040d0020,0x33200054,0x8c430001,0x2d540051}},	//   _hướn, neix_, реће, _käes_
  { {0x68e32b19,0x24920002,0x6d5c0028,0x1d260103}},	//   _bend, łym_, kkra, _имам
  { {0xd7f801b3,0x6f160013,0xdbd90017,0x2385001e}},	//   tră_, _abyc, _açõe, rēja_
  { {0x9f5f0006,0x3957000b,0x3157000b,0xdd8f0003}},	//   yttä_, דשים_, דיין_, _بول_
  { {0xf093000b,0xa5f90015,0x6d5c003a,0x2385001e}},	//   ינת_, нему_, ekra, pēja_
  { {0x6d5c0065,0x33200054,0xa25a0003,0xcf930009}},	//   fkra, deix_, _تشاء_, שטר_
  { {0xd12f000a,0xd257000b,0xceb3000b,0x6fca0037}},	//   _ومن_, _בשדה_, ייר_, _संपू
  { {0xc04f002d,0x30a30014,0x478b0001,0x64740021}},	//   _ті_, _кръв, _осим_, агру
  { {0x332003eb,0x68e80655,0x68e30227,0xf744004c}},	//   geix_, ladd, _zend, _већо
  { {0xeab0000a,0x6b5c0061,0x6458008e,0x8f380009}},	// [7bd0] قعك_, _régl, hyvi, _יאהו_
  { {0x7bc1000e,0x64581598,0x6d5c2b1a,0x98f40012}},	//   ílus, kyvi, ckra, لثما
  { {0x2fe40003,0xc7f50001,0xe8d70009,0x2d83001b}},	//   لكلف, узећ, דובר_, mnje_
  { {0x2907003e,0x11d70012,0xd3660012,0x99d70012}},	//   żna_, _لتسد, _طه_, _لتسا
  { {0xd2460351,0xe730000a,0x6b5c000e,0x637e0035}},	//   _ان_, تصل_, _végl, cīni
  { {0x672d0006,0x865c000b,0xac090b05,0x97c50012}},	//   _laaj, ודדי, енка_, _مقسو
  { {0x7bc50005,0x7d1e0005,0x68e32b1b,0xbee30011}},	//   _juhu, õpsa, _rend, _ख़ून_
  { {0x8c160003,0xe1f90010,0x03250594,0xfaa50024}},	//   ايير_, trų_, удин, лайо
  { {0xdce70010,0x11d60003,0x68e32b1c,0x63bd2b1d}},	//   siję, هوية_, _pend, _misn
  { {0x70e10037,0x3af3001a,0xdb0f0018,0x2d83001b}},	//   _फ़ोल, ợp_, _ficç, jnje_
  { {0x2d830133,0x200100b6,0xdee61832,0xc4d20009}},	//   dnje_, nuhi_, лони, _הגב_
  { {0x68e32b1e,0x61ed2b1f,0xfc460030,0xfa350012}},	//   _wend, ksal, žích_, _مرتد
  { {0x9f600097,0xc3320009,0x68e326c1,0x6d5c2b20}},	//   _þrír_, _לוא_, _tend, tkra
  { {0x8e75002d,0xca360009,0x7a7a0009,0xa2db0011}},	//   руюч, _תנסה_, _ארנס, नरक्
  { {0x332003eb,0x63bd00c6,0x49b80003,0x20010051}},	//   teix_, _bisn, _شاهد_, juhi_
  { {0x6e29012e,0x6e360002,0x61fb003a,0x11da0012}},	//   _oseb, _tryb, orul, فورة_
  { {0x332003eb,0xd3870800,0x61ed002c,0xd3b9002d}},	// [7be0] reix_, уйте_, gsal, турі_
  { {0x6d5a0051,0x290509d7,0xbd460012,0xb8820030}},	//   ötad, ngla_, _إندي, římn
  { {0x61ed0a60,0x97c50012,0x29c90081,0xdb060031}},	//   asal, لتنم, _lúa_, _kikü
  { {0x23850039,0x42d5002d,0xf729002d,0x6db90064}},	//   dējo_, _віру, кцій_, _dňam
  { {0xe5050044,0x040d0020,0x8ccb0037,0x6b550028}},	//   _राशि_, _tướn, तुको, _lágs
  { {0x64581dc8,0x16c10037,0xad9b19ce,0x7ae61c52}},	//   tyvi, _एल्ब, ltúr, _hekt
  { {0x98a30039,0x6b840051,0xa928001e,0x50b501d4}},	//   _tajā_, onig, režģ, _всту
  { {0x29c90065,0xad9b0029,0x59db0037,0x3b5407e8}},	//   _búa_, ntúr, मीकर, ркир
  { {0xdcfc001e,0x97570009,0xa6860229,0xb6a3003c}},	//   norē, _עימו_, _слад, _гитл
  { {0x361b000b,0x672d0269,0x660203ec,0x69c00025}},	//   _אומד, _saaj, muok, _émeu
  { {0x69c60006,0x66020006,0x63060003,0x88bc0066}},	//   _luke, luok, _موال, jdět
  { {0xa3c10037,0x70e10037,0xdb1a000e,0x07470024}},	//   ंदर_, _फ़्ल, _futá, ухом
  { {0x6280007a,0x9b93000a,0x33930003,0x9f5f01bd}},	//   _žmon, _النت, _النز, nuté_
  { {0x7bc50176,0xbd450003,0x403400fa,0xaa570012}},	//   _puhu, جنسي, _векс, _حلها_
  { {0xc19b0009,0x2d8302a1,0x25e60011,0x76590034}},	//   _רשוי, rnje_, जीबी_, zywy
  { {0x4c9b000b,0x25660061,0x61170060,0x2d760034}},	//   גבלו, _rôle_, ağlı, dłem_
  { {0x66020010,0x2d8304d2,0x49750069,0xcb370009}},	// [7bf0] juok, pnje_, алас, נאמי_
  { {0x629d014a,0x25660025,0xd944004c,0x2001016d}},	//   _vyso, _pôle_, беђи, tuhi_
  { {0x629d003e,0xdef10003,0xc917000b,0xf8b10009}},	//   _wyso, قًا_, רחבת_, ַשׂ_
  { {0x3ce50989,0x200100b6,0x98140012,0x6ee70012}},	//   _selv_, ruhi_, إبلا, اسال
  { {0x26dc000b,0x66020010,0x5187002d,0x2d760002}},	//   תקדמ, guok, _бува, ałem_
  { {0x6e29066e,0x2385001e,0xf1a90011,0x7c350159}},	//   _vseb, tējo_, _कठिन, ovzr
  { {0x67d40047,0x97a700b3,0x7ae92b21,0x14d80009}},	//   _госу, _брал, taet, נוהל_
  { {0x27fc0029,0x986a0060,0x23850035,0x9f5f0025}},	//   ávne_, lığa_, rējo_, buté_
  { {0xe6671128,0xde670014,0x69c00061,0x69251832}},	//   _ство, _съвп, _émet, ампа
  { {0x2385001e,0xdb0a0029,0xc1050003,0xa2d50011}},	//   pējo_, ľnéh, جودي, युत्
  { {0x2d840066,0x93190003,0x98a5046d,0xdb0a01e9}},	//   émem_, _لقاء_, рине, žnéh
  { {0x6830000e,0x80480009,0xbf5a0024,0x75232b22}},	//   lódá, אֲשֶ, трої_, lenz
  { {0x3ea90002,0x92b70012,0xc603003c,0xb5fb0031}},	//   _czat_, _إحضا, озяй, zzáv
  { {0x69c60033,0x68e705b1,0x3ea20033,0x752314f5}},	//   _ruke, _nejd, _økte_, nenz
  { {0x63630005,0xf992000b,0x66020010,0x61e21528}},	//   _sõna, _ורג_, zuok, _zwol
  { {0xdb02001a,0x75232b23,0x2d760034,0x6b842b24}},	//   _khoá, henz, głej_, unig

  { {0xbf9b000b,0x2fc72b25,0x6d412b26,0x88e6003c}},	// [7c00] _ביקש, _hung_, _onla, ижае
  { {0x2fc701e5,0xb17b006f,0xf657000b,0x6134000e}},	//   _kung_, _svår, _כספי_, pülő
  { {0x75231397,0x04460015,0x46ea0048,0x51170024}},	//   denz, _тенн, вден_, роєю_
  { {0x2d9801a2,0x6d412b27,0x69c6004a,0x660216e1}},	//   lore_, _anla, _tuke, tuok
  { {0xa5bb0002,0x2fc72b28,0xa4d40024,0x3e340012}},	//   dwój, _lung_, болі, إفتر
  { {0x660203ec,0x75232b29,0x2d982b2a,0x91e30fb1}},	//   ruok, genz, nore_, _форе
  { {0xed570001,0x7b66010c,0xf8aa0011,0x84380012}},	//   рој_, итие, _करिय, اكبر_
  { {0x6d410844,0xe3af0003,0xfbd3000b,0x9f5f0061}},	//   _enla, وري_, חתה_, puté_
  { {0x4efb0093,0x1efb000b,0xc2070012,0x1ab3003c}},	//   _שהמו, _שלמע, لقين_, объя
  { {0x2fc700b6,0xf8aa0037,0x6b5c000e,0x6d890029}},	//   _bung_, _कराय, _mégi, eľan
  { {0x2fc70020,0x0137000b,0x7afd0010,0x3137007e}},	//   _cung_, ברית_, ųsta, בנים_
  { {0x2fc70020,0xdcf80010,0xdcf5001e,0x3f8600d9}},	//   _dung_, tovė, pozī, nnou_
  { {0x2d980036,0x51180024,0x61e20034,0x3f862b2b}},	//   fore_, _болю_, _uwol, inou_
  { {0x645c0028,0x61fd05b1,0xa15709ce,0x7bc808d3}},	//   fyri, ásle, _вашу_, _kudu
  { {0xdcfa0039,0x7bc800b6,0xe5160037,0x3f860066}},	//   _aktī, _judu, द्धि_, knou_
  { {0x8c1b000b,0x75230052,0x58bb000b,0x2bbb0003}},	//   כולי, zenz, _במוצ, ئاسة_
  { {0x98a3003e,0x3f86014a,0x3f991448,0x78eb003c}},	// [7c10] _mają_, dnou_, mosu_, вьев_
  { {0x2d980108,0xc4b80037,0xc1050003,0xd2b7000b}},	//   core_, ेखाओ, صوصي, שלמת_
  { {0x2fc7210a,0xd8790003,0xe727002d,0xf6d5002d}},	//   êng_, دمات_, иєдн, біля
  { {0xf770000a,0x15f50003,0x68e70002,0x3f9916d3}},	//   وان_, مستح, _wejd, nosu_
  { {0xfb1a000b,0x7aed02bd,0x98a7001e,0x75232b2c}},	//   _גורמ, maat, _manā_, tenz
  { {0x645a0052,0x200e0054,0xb5fb000e,0x7bc82b2d}},	//   ätig, àfic_, lzás, _budu
  { {0xad1c000b,0x752315aa,0xf1b2000b,0xdb1d0025}},	//   דוור, renz, _מסך_, _aisé
  { {0x2fc7001a,0x765d004a,0x75230b6d,0x2d980027}},	//   _rung_, kysy, senz, zore_
  { {0x2fc72b2e,0x7c3a0480,0x98a30034,0x2bc00011}},	//   _sung_, _ertr, _dają_, _शंघा
  { {0x97d900b3,0x0fd90015,0x95540012,0x670a0011}},	//   льму_, льмы_, _وخلا, _वाहक_
  { {0x3319002d,0x657c004a,0x7aed00e6,0xb97c0009}},	//   _біля_, virh, kaat, כנזי
  { {0x3212004a,0xdb02001a,0x3204047f,0x501a0009}},	//   ytyy_, _thoá, bumy_, נורו
  { {0x2d9801a2,0x98a500a2,0x8e55002d,0xceb20009}},	//   tore_, rklı_, отрі, ֤ים_
  { {0xceb20093,0x61d60093,0xdce3001e,0x69db2913}},	//   פים_, _הוסף_, minē, mpue
  { {0x2d9801a2,0x645c0051,0x6e2d003a,0xa1120012}},	//   rore_, _ürit, _esab, _رويت
  { {0xd1130044,0x3212004a,0xad9b0029,0x256b0260}},	//   त्रण_, ttyy_, stúp, _følg_
  { {0xcf93000b,0xdd1c0066,0x3f8600d9,0x52aa0048}},	// [7c20] _מטה_, mážd, vnou_, увам_
  { {0x636a0028,0x3212004a,0x6b5c000e,0xb6370009}},	//   _sýnd, rtyy_, _végi, _פריס_
  { {0xe0d5002d,0x3212004a,0x19b9002d,0x6557000b}},	//   юють, styy_, руть_, _הביא_
  { {0x7bdc0164,0x7aed0070,0xdcf5001e,0xb8ff0011}},	//   mpru, caat, mizā, _ध्_
  { {0xdcf5001e,0x2005002c,0x539b000b,0x7bc81ec7}},	//   lizā, huli_, _תיכו, _sudu
  { {0x52e00037,0x63b60028,0x02e00037,0x78ba000e}},	//   नर्स, lmyn, नर्न, _útvo
  { {0x3d090037,0xdcf5001e,0xc4d30009,0x6ea40011}},	//   _सारे_, nizā, הגו_, _औरकु
  { {0xd326007c,0x51f80047,0x2d870051,0xd9f80015}},	//   ськи, анию_, anne_, аниц_
  { {0x6e3b00a2,0x41b40012,0x9f630031,0x637e0073}},	//   _grub, يمبر, _ívás_, gūna
  { {0xb5fb000e,0x7bc8177e,0x2c190011,0x6f0d00b8}},	//   zzás, _tudu, _पहलू_, _scac
  { {0x63b60028,0x04960003,0x2005000d,0xadb70003}},	//   kmyn, _الضح, guli_, _اهلا_
  { {0x3f670594,0x9e150024,0xd6db003c,0xd5be0035}},	//   стоб, одмі, ыто_, žāda_
  { {0x7aed0176,0x539b000b,0x7a360012,0x05790012}},	//   vaat, _גיאו, _دعائ, لمحة_
  { {0x661d004a,0x41b60014,0xa4d40024,0xb69b004b}},	//   _äske, _усет, зорі, ngâi
  { {0x317b000b,0x8bf80009,0x49170009,0x6fcf0011}},	//   _תרומ, יִּפ, _הקול_, _संयं
  { {0x63b60028,0xe3b00003,0xc2c40012,0x3d1a0011}},	//   gmyn, فرق_, كيفي, म्बे_
  { {0xe8000037,0x9f5f00d9,0x2a9b0012,0x9c7c001b}},	// [7c30] लंका_, nutí_, ائزة_, _bečk
  { {0x9c7c012e,0xf1c2001e,0x7aed0038,0xb8820042}},	//   _večj, jošā_, saat, čína
  { {0x63a42b2f,0x6d452b30,0x67650012,0x7aed1545}},	//   blin, _inha, يُطل, paat
  { {0x645a0006,0x66fb0037,0x63a4149c,0xf1c80011}},	//   ätie, ्लिक_, clin, रदान
  { {0x67c80066,0x64400035,0x998928f3,0x6b580097}},	//   _ději, āmie, evať_, _tígr
  { {0x9989003e,0xabd50001,0x0d840024,0xdb090018}},	//   stał_, оциј, плін, omeç
  { {0x1b49120f,0x155c0009,0xb5fb0031,0xf5920012}},	//   изки_, רכוב, nyáb, بلوج
  { {0x6fcf0044,0x88bc0066,0xe1f90479,0x2d9e19cc}},	//   _संबं, vděp, аги_, _ekte_
  { {0x7afd0010,0x4a45002d,0xb5fb000e,0xc3340009}},	//   ųsto, інов, zzár, פוץ_
  { {0x8f000024,0x20052b31,0x36040012,0x41b20012}},	//   дiї_, tuli_, _رومف, ومير
  { {0x69db02d1,0x63a42518,0xfd100003,0xcea90009}},	//   spue, ylin, _سجل_, _סי_
  { {0x60dc00a2,0xae0d0037,0x6d450052,0x65a00052}},	//   ırma, _समान_, _anha, höht
  { {0xf3f1008a,0x8f9a000b,0xdb06000e,0xa3e50011}},	//   ận_, שירי, _kikö, बीर_
  { {0x6b891d5f,0xa50a0001,0x63a42b32,0xb6ba0009}},	//   lneg, јева_, wlin, יצרי
  { {0xdb06000e,0x66060c55,0xf1bf0029,0xdb0a0066}},	//   _mikö, sukk, _fráz_, žníh
  { {0xf8b2000b,0x03670015,0x7f4403f6,0x69cb0052}},	//   _קשה_, оиск_, _uniq, _kuge
  { {0x7aeb000f,0x63b60028,0x99890029,0xfaa300b3}},	// [7c40] _megt, rmyn, zvať_, дато
  { {0x6b9b002a,0x8a030015,0x7aeb23cb,0x63a42b33}},	//   houg, ьзуе, _legt, slin
  { {0x69cb0005,0x9ffa0003,0x9c7c009b,0xdfcf0003}},	//   _luge, شراء_, _večk, نيل_
  { {0x80da0044,0xee3a0751,0x6b8906a4,0xe29a14bd}},	//   _प्रे, ине_, jneg, _вам_
  { {0xa4d4002d,0xf773000b,0xe297002d,0x6b8906a4}},	//   полі, וקא_, _маю_, dneg
  { {0xfe9b000b,0xf3f1001a,0xdcf5000d,0x69c30a5f}},	//   סיסמ, ợt_, miză, _nine
  { {0xdcf5007d,0x69cb0052,0x7bc20132,0xddce0034}},	//   liză, _auge, _piou, ódła
  { {0x69cb007d,0x39580061,0x0b8a0001,0x938a0001}},	//   _buge, _hors_, јски_, јска_
  { {0x1d0a0001,0xa50a0001,0x69c32b34,0xf77f0060}},	//   _вези_, _веза_, _bine, viç_
  { {0x6b5c0061,0x5503027f,0xdc3e015b,0xd1300012}},	//   _régu, _опуб, líče, رمج_
  { {0x69d90070,0x6b892b35,0x2d9c2b36,0xc3da0012}},	//   _etwe, bneg, move_, _ضباط_
  { {0x69c32b37,0x39580108,0xa2d30003,0x317e0052}},	//   _eine, _lors_, _قيمت, sitz_
  { {0x3ead00c5,0xf77f003a,0x224b006f,0x69c31d9f}},	//   ået_, riç_, äckt_, _fine
  { {0x3958007a,0x2385001e,0x80da0037,0x04c90003}},	//   _nors_, vēji_, _प्ले, صوري_
  { {0x69cb008b,0xe9670001,0xc8db0009,0x8bd80009}},	//   _zuge, _фајл_, _דקוט, מַּח
  { {0x569508b0,0xe8e0001a,0x2d9c013a,0xd6d10012}},	//   _найт, _đền_, hove_, _ثقة_
  { {0x2d9c09ea,0x49d80015,0xe9d00012,0xc3980024}},	// [7c50] kove_, ждую_, نغل_, ікує_
  { {0x98be0010,0x290c03ce,0x6b8906a4,0x69c301a0}},	//   nktį_, ngda_, zneg, _xine
  { {0x2d9c2b38,0x4421016d,0x6602016d,0x77692b39}},	//   dove_, _uph_, erok, _plex
  { {0x6b5c000e,0x35f90012,0x501b00af,0x4395107e}},	//   _mégs, مرتد_, שואו, _хамс
  { {0x7bda01a2,0x6b89012e,0x66270003,0x224d003a}},	//   _attu, vneg, تراك, _çek_
  { {0xa3e20037,0x6b890002,0x1fdb0003,0xe578002d}},	//   नीक_, wneg, _نظرة_, озі_
  { {0x6b8911d5,0xe5720009,0xad1c0009,0xb8e10011}},	//   tneg, עַד_, יוגר, ुश_
  { {0xf1af0011,0x42d50024,0x66022b3a,0x3704004c}},	//   _जीतन, чіку, brok, _очув
  { {0x443e0065,0xdb21000e,0x256f000e,0x6b9b2b3b}},	//   _ert_, _átír, _küld_, roug
  { {0x290c006f,0xf9910012,0x84470012,0x6b892b3c}},	//   ggda_, عبة_, _وخال, sneg
  { {0xc7a60046,0x237f0002,0xe73a010c,0x07a60109}},	//   зинк, piuj_, бен_, занн
  { {0xfb380003,0x69cb0154,0x224b0248,0x3f9d0034}},	//   _وأنت_, _tuge, äcks_, nowu_
  { {0x3ea40028,0x9c7c0ecf,0x12280024,0x6b5c0031}},	//   æmt_, _reči, _моїй_, _végt
  { {0xd256000b,0xe80c0037,0x89da0009,0xf6520009}},	//   _משנה_, _हमला_, _החסי, עצם_
  { {0x80aa0044,0x443e0066,0x2b5901a0,0xa8480012}},	//   _करें, ít_, _bosc_, _ولهم_
  { {0x57fa0093,0xd7fa000b,0xe51b0037,0x1dcb0037}},	//   _הלקו, _ההקל, प्ति_, ादात
  { {0x02060047,0x9c7c009b,0xe8fa0762,0x98a70034}},	// [7c60] язан, _veči, йла_, _daną_
  { {0xdce3007a,0x3cf70037,0xdcf5000d,0x2385001e}},	//   minė, ीलों_, riză, mēju_
  { {0xf992000b,0xdce30010,0xc726004d,0x155b0009}},	//   ערב_, linė, здей, _הכיב
  { {0xe5c60001,0x0dca00fa,0x28bd0011,0xe50e0011}},	//   пско, буки_, ्ख़ि, _साहि_
  { {0xe53408b0,0xdce30010,0x433b000b,0x7ae40960}},	//   дель, ninė, _העכב, mbit
  { {0x6602004a,0x7a8b0009,0x2d9c00b8,0x2bb40011}},	//   rrok, _הָלַ, uove_, ंगका
  { {0xcb980003,0x6ba70017,0xdee61add,0xebd60009}},	//   ينتش_, _órgã, _нови, הֵ֥י_
  { {0x2eed00bd,0x1c020037,0x67c80066,0xdce30010}},	//   _geef_, रूगल_, _mějt, kinė
  { {0xa6aa0012,0x7ae42b3d,0x784e0031,0x2d9c0412}},	//   _طارق_, ibit, _fővá, pove_
  { {0x497308b0,0xa978002d,0xdce30010,0xc173003c}},	//   ельс, ійну_, dinė, ельщ
  { {0x6e240010,0x04db0009,0xc9530009,0xa3ac0011}},	//   _apib, _הקבל, תמת_, गता_
  { {0x290200a2,0x69da0066,0xf3f1001a,0xdb040061}},	//   şka_, _čten, ậm_, blié
  { {0xdce30010,0xda340015,0x79810f85,0xe8000011}},	//   ginė, _целы, bilw, लूजा_
  { {0xe5c40015,0x7bc6004a,0x6d5a004a,0xca330001}},	//   ессо, _aiku, _jota, _чешћ
  { {0x8937007e,0x01370009,0x8f550012,0xd91b0009}},	//   _מרגע_, _זרות_, _ينتش, _הוול
  { {0x63710163,0xdce30010,0x657e0503,0xdb1d0042}},	//   _mång, binė, _emph, _tisí
  { {0x6d5a0051,0x6371006f,0x7bc600b6,0xd1380010}},	// [7c70] _oota, _lång, _diku, odą_
  { {0x63630051,0x6d5a2b3e,0xd1380914,0x02440012}},	//   _mõni, _nota, ndą_, عَلَ
  { {0xd1380010,0x2d8300eb,0xb9c40012,0x63a21ade}},	//   idą_, mije_, رقمي, _okon
  { {0x2d8300eb,0xcb0b003c,0x87080024,0xa0970009}},	//   lije_, _уход_, зеїв_, הדבק_
  { {0xbb3a000b,0x8b3a0009,0xcb560009,0xe60e0048}},	//   _וערי, _ותרצ, _חסרה_, ъд_
  { {0x4d64002d,0x2d83080a,0xb9250003,0x69dd2b3f}},	//   нків, nije_, _تفسي, _itse
  { {0x26d200a2,0x9cd80009,0x6d5a2b40,0x23850035}},	//   ıyor_, הווה_, _dota, zēju_
  { {0xa2b40037,0xd1380010,0x6d482b41,0x93fc0009}},	//   _आरम्, edą_, _enda, צלחי
  { {0x69c7219b,0x3f820051,0x6d890042,0x6b8d2b42}},	//   _kije, viku_, ožad, inag
  { {0x2385001e,0x63712891,0xceb2000b,0xdce30010}},	//   vēju_, _fång, _יין_, vinė
  { {0x6b5c000f,0x6d5a0051,0x6371006f,0x69c70027}},	//   _végr, ötam, _gång, _mije
  { {0xdce3007a,0x69dd0005,0x69c70027,0xfe670003}},	//   tinė, _otse, _lije, ند_
  { {0xfbbe0037,0x27e00027,0x7bc60051,0xc2c40003}},	//   ्दसम, _čine_, _riku, _كيمي
  { {0x63a20013,0x3f820051,0xdce30010,0x22420058}},	//   _zkon, siku_, rinė, ække_
  { {0x64a30046,0x69dd0039,0x8c95002d,0xdce30914}},	//   вара, _atse, ерті, sinė
  { {0x63a900a2,0x238500cd,0xdce30073,0xe6060012}},	//   nlen, pēju_, pinė, _قِبَ
  { {0xcf93000b,0x7bc60028,0x256f0051,0x69c72b43}},	// [7c80] _שטח_, _viku, _süle_, _bije
  { {0x69c7001c,0x2d830331,0x990a0003,0xf3f1001a}},	//   _cije, cije_, تغرق_, ợp_
  { {0x443c000e,0xb8f60037,0x63a92b44,0x6d5a149c}},	//   _év_, _हल_, klen, _rota
  { {0xf989000b,0xd1380010,0xdb1d0017,0x1e860015}},	//   בר_, zdą_, _visã, млем
  { {0x6371006f,0xf1af0011,0x2bd20011,0x6d5a2b45}},	//   _sång, _जीवन, _दूता, _pota
  { {0xf389001a,0x9c46002d,0x63a92b46,0x6b840574}},	//   uản_, дхил, elen, liig
  { {0xa2d50044,0x63a900a2,0xa2a20011,0xf9930009}},	//   युक्, flen, _कुत्, _ירש_
  { {0xdb0d0149,0x6d5a0005,0xf6260001,0xd00f0003}},	//   rmaç, ötaj, _одбо, _خلف_
  { {0x44250051,0xedd30012,0x20052381,0x64412b47}},	//   _epl_, _ليقد, erli_, _erli
  { {0x7bde001b,0x6d482b48,0xd1380073,0x7c2a003c}},	//   _otpu, _unda, udą_, _мозг_
  { {0xd138007a,0x6606004a,0x7d1e0051,0x2d8300eb}},	//   rdą_, erkk, õpsu, vije_
  { {0x09e6002d,0xd7cf0037,0x63a2022d,0x63bb0164}},	//   _жодн, _संरच, _ukon, cmun
  { {0x9f650061,0x2d830604,0x6d8901e9,0xa5bb0034}},	//   étés_, tije_, yžad, dwór
  { {0x6371038e,0xe8940055,0x550e0011,0x47d40012}},	//   _måne, _паль, सलिए_, _كيتر
  { {0x69c7077d,0xd0100003,0x6606004a,0x40eb000b}},	//   _rije, _صلة_, arkk, _וַחֲ
  { {0x69c70027,0x57fb000b,0x2d830604,0x2d840054}},	//   _sije, _ולהו, sije_, émer_
  { {0xe1f00003,0x2d83013a,0xdb1d0064,0xa4d50024}},	// [7c90] لسل_, pije_, _cisá, _попі
  { {0xf6520009,0x4ddc0009,0x63a92b49,0xb06b0012}},	//   _עצי_, _וחזו, zlen, يصال_
  { {0x69c70027,0xd7f8000d,0x7afd0073,0x63a904af}},	//   _vije, nsă_, ųsti, ylen
  { {0xf8df015f,0x28df0044,0x20df0044,0x7afd0058}},	//   _प्रय, _प्रि, _प्रध, _udst
  { {0x69c7001c,0x85e8002d,0x200c013d,0x63a90712}},	//   _tije, ддів_, hudi_, vlen
  { {0xee38007c,0x660b0070,0x63a90052,0x75d20012}},	//   ьні_, rugk, wlen, ديوا
  { {0xdca20001,0x64a20838,0x03a50138,0x63a92b4a}},	//   лаши, лаша, нико, tlen
  { {0x2385001e,0x63bb1cb9,0x63a91f5b,0x4b0c0009}},	//   vējs_, umun, ulen, ַּחֲ
  { {0x63a92b4b,0x63bb2b4c,0x6d5a005e,0x9c7c0030}},	//   rlen, rmun, ötak, _sečt
  { {0xa3b60044,0x63bb0065,0x7d790012,0x44270012}},	//   _चीन_, smun, _عمار_, _يراف
  { {0x3ea900c6,0xc9520009,0xe73a0229,0xf8a904a5}},	//   _ayat_, אמי_, пен_, явок_
  { {0xf0920093,0x660005b1,0xd6d20012,0x3c390030}},	//   רנט_, ámko, طقس_, zývá_
  { {0x8cc70037,0xd7f8000d,0x6a670003,0x66080002}},	//   ाशको, asă_, _تطال, ądko
  { {0x2369009b,0xd5b20003,0x6363005e,0xf3890081}},	//   ekaj_, افس_, _mõnu, iảm_
  { {0xc4d20093,0x6ea00037,0xa5bb0002,0x3f6a0001}},	//   רגל_, _गुरु, twór, _нико_
  { {0xdce3001e,0x636a01e9,0x3d090011,0xe9da0bda}},	//   finī, _výno, _साझे_, зка_
  { {0x6b840005,0xdcfc001e,0xe1f90010,0xfbc9000b}},	// [7ca0] riig, airā, nsų_, ֶת_
  { {0x850e0044,0xe1f90010,0x6fd40011,0x23690159}},	//   _साइट_, isų_, _बंदू, akaj_
  { {0xdce3001e,0x2f3a0009,0xc0a90012,0xa3c10011}},	//   ainī, ּגְד, وامل_, ूदा_
  { {0x68e300a2,0x44442b4d,0x65ad0029,0xf4570009}},	//   ında, _ir_, súhl, _ניכר_
  { {0x6d5e0039,0x1634118d,0xbbbe0011,0x24920035}},	//   _kopa, теля, ्दीक, šamā_
  { {0xb8820066,0xc5f30009,0xa2c00011,0x256f005e}},	//   _říms, נדו_, लेण्, _küla_
  { {0x5334010c,0xb4660012,0x6d5e1247,0x6724071e}},	//   вейт, عدته, _mopa, _obij
  { {0xd3770015,0x44441520,0x8c1b0009,0x31c80011}},	//   ечь_, _mr_, לוצי, रद्ध
  { {0xc29800be,0x238c0030,0x6d530097,0x7d010097}},	//   ьких_, něji_, ýjað, ólsk
  { {0x444402e9,0xc27b000b,0x15fb0009,0x02e00011}},	//   _or_, פריי, _מהמע, _ग्रह_
  { {0xa7fc003a,0x645a004a,0xc1730009,0xdce30035}},	//   ayın, ätil, רחת_, zinī
  { {0x2002080a,0xd7f8000d,0x93c7001a,0xc6a7193d}},	//   čki_, rsă_, _chặ, ерги
  { {0x753a0052,0x44442b4e,0x71f70012,0xcf930009}},	//   _katz, _ar_, _كروس_, רטר_
  { {0x238c0066,0xd7f8000d,0x70540012,0xb4eb0011}},	//   ději_, psă_, _لنتا, मरे_
  { {0x3ce00037,0x850e0037,0x6d5e12ca,0x1fa700dc}},	//   कड़े_, _साईट_, _dopa, _приг
  { {0xe3b30003,0x2369009b,0x80370012,0x57f30048}},	//   ارس_, ukaj_, _أسوأ_, _спът
  { {0x69ca000f,0x61e4002c,0xd6e8000b,0x28c30011}},	// [7cb0] _kife, gpil, _אַתָ, वेनि
  { {0x7c28187e,0x72040012,0x23692b35,0x93bc004b}},	//   _opdr, اولم, skaj_, _spăl
  { {0x63630005,0x6b82048b,0x7af60060,0xe787004c}},	//   _sõnu, _omog, bayt, нудо
  { {0xdddd0002,0x35a90037,0xb7db0009,0xb4bf0011}},	//   mysł, _चीज़, פקדי, ेशी_
  { {0x63ad03b4,0x7c28001e,0x5f040011,0x26c20030}},	//   mlan, _apdr, _वयस्_, _úkol_
  { {0x63ad2b4f,0xceb4000b,0xdb000061,0xfc310012}},	//   llan, ניס_, lomè, لحب_
  { {0xd4e4002d,0x98a70066,0x6c320003,0x03950048}},	//   уючи, _daně_, لفوا, крия
  { {0x91c6001a,0x661d0348,0x0b450001,0x3f862b50}},	//   _đúp_, ktsk, тнин, ciou_
  { {0x45d5002d,0xe1f90010,0x63ad2b51,0x826c0009}},	//   _розс, usų_, ilan, ּ֣חַ
  { {0xeeeb001a,0x63ad2b52,0xf1a90012,0x2abc0009}},	//   ướng_, hlan, باعه_, המחא
  { {0x2d8703fb,0x66e6007c,0x61e40039,0x63ad2b53}},	//   mine_, кона, zpil, klan
  { {0xdddd0002,0x2d9100c1,0x61e4004a,0xd4880009}},	//   dysł, enze_, ypil, _אָנֹ
  { {0x9f5f0006,0x7afd0028,0x64410028,0x42040003}},	//   yttö_, óstu, ælin, _مِنْ
  { {0xdb1d03fc,0x44442b54,0x2ca90030,0x6b820159}},	//   _lisä, _pr_, řadu_, _zmog
  { {0xddca000e,0x61fd1204,0x577a0003,0xf8a50011}},	//   ínűl, _avsl, _يصبح_, _ऑडिय
  { {0x673b039c,0x98a70066,0xcf260003,0x67240864}},	//   _nauj, žně_, _شرعي, _ubij
  { {0x3f860017,0x64450052,0x23d20011,0x61e42b55}},	// [7cc0] viou_, _erhi, _दूरद, upil
  { {0x7ae9003a,0x61fb2b56,0x61e42b57,0xda650012}},	//   hbet, isul, rpil, دافي
  { {0x2d872b58,0xa2a20011,0xe3ba003c,0xd00f0012}},	//   dine_, _कुर्, _обо_, قلل_
  { {0x753a0052,0x63ad075e,0x2d872b59,0xb8050012}},	//   _satz, clan, eine_, ابله
  { {0x7ae900c5,0x63a4104b,0x9f590061,0x268d0009}},	//   dbet, moin, éré_, ּנוּ
  { {0xe5e50003,0x6e29003a,0x2d872b5a,0x7bcb0c23}},	//   اثني, çebi, gine_, _aigu
  { {0x69ca01a2,0x3c3c0066,0xe9df001a,0xc4d30009}},	//   _rife, dává_, _trúc_, סגה_
  { {0x63a410a6,0xd2140001,0xdb1a0054,0x5b260024}},	//   noin, гмић, _autò, тька
  { {0x61fb002c,0x7bcb23f4,0x5e250003,0x32530014}},	//   gsul, _digu, _معلق, ивър
  { {0x63710163,0x673b01e9,0x71740012,0x672f0034}},	//   _måna, _zauj, اهدا, wecj
  { {0x63ad00a2,0x63a4004a,0x3d170011,0x7bda052e}},	//   ylan, koin, _नाते_, ítul
  { {0x673d0033,0x63a40ebe,0x57fb0009,0x661d146a}},	//   udsj, join, ולטו, ttsk
  { {0x76420061,0x661d2b5b,0x5f9406e0,0x637501e3}},	//   nvoy, utsk, рият, _dánd
  { {0x58d31128,0x7e60006f,0x660f0052,0xb7d80012}},	//   _кошт, ämpa, ruck, _كوتا_
  { {0xdb040028,0x672f0002,0x7bc02b5c,0xfaff0035}},	//   tmið, pecj, ommu, žīmu_
  { {0xa057000b,0x6117003a,0x00570009,0xdb500012}},	//   _יסוד_, aşlı, _ישות_, يَّ_
  { {0xdb040028,0xa7fc003a,0xc1b90021,0xae9b0012}},	// [7cd0] rmið, zyıl, елах_, _تضغط_
  { {0xdb1d03fc,0xd7e7007c,0xdb040065,0xd6d90002}},	//   _sisä, відо, smið, _małe_
  { {0x201e0006,0xa9c4002d,0x7ae9059b,0x31340560}},	//   ntti_, рстк, ybet, рехр
  { {0xd6db002d,0x201e004a,0x6d5a0051,0x8f14002d}},	//   єте_, itti_, ötav, ифіч
  { {0xfe700003,0x98b1000d,0xed4e00b3,0xaf04002d}},	//   يده_, _bază_, бо_, рпіл
  { {0xb5fb000e,0xd6580009,0x7d1c0248,0x59640048}},	//   tyáj, כידת_, _örsl, _къса
  { {0x3c3c0066,0x2d872b5d,0xdd030010,0x1dda0011}},	//   vává_, rine_, ūrėd, _यूनत
  { {0x2d871d7e,0x1cb8000b,0x2742000e,0x9c7c0159}},	//   sine_, כלול_, ténő_, _večp
  { {0x68f5000f,0x2d8702e7,0xe1f10003,0xe6100003}},	//   _kezd, pine_, حسب_, _وشك_
  { {0x7ae6003a,0xa7fc003a,0xf389001a,0x6c1b0012}},	//   ıkta, ayım, iải_, _يتضح_
  { {0xf389001a,0xbfc60014,0xfb150003,0x378a05fb}},	//   hải_, лбок, _مواج, ебно_
  { {0xeeeb0020,0x201803eb,0xf8b2000b,0xfbd20009}},	//   ường_, ària_, משי_, _התא_
  { {0x5fcf0044,0x63a4004a,0x7988002c,0x877a000b}},	//   _संकल, voin, bidw, תארי
  { {0x3958006f,0x90450012,0x68f52b5e,0x2b9a0035}},	//   örst_, _منته, _nezd, rīce_
  { {0xa3e60037,0x63a42b5f,0x141a0012,0xfc030024}},	//   _बढ़ा_, toin, عيرة_, йпро
  { {0xf0920093,0x2903000f,0x6b892b60,0x3f8b0025}},	//   _לנו_, _adja_, nieg, ébut_
  { {0x256f0005,0xc7a90003,0x63780017,0x6d5e0051}},	// [7ce0] _küll_, _جدول_, _líng, öpak
  { {0x63a417e5,0x1e570009,0xdce30030,0xdb00113e}},	//   soin, _עשיר_, rhně, romé
  { {0x6b89003e,0xf3f10020,0xa8060001,0x4f0a022a}},	//   kieg, ật_, узел, енен_
  { {0x5f760003,0xdfcf0012,0x97a50024,0x2f1d0031}},	//   دائر, سيه_, аріл, vágó_
  { {0xef210039,0x6b892b61,0x9daa0048,0xab650035}},	//   daļā_, dieg, нъка_, _daļā
  { {0xceb30093,0x6da3035c,0xda4b0009,0x201e051b}},	//   ציג_, бича, _אֲלָ, ytti_
  { {0x251b000b,0x44260003,0xf8b80011,0x26000011}},	//   תוצא, ارتف, _अरिय, _रिकी_
  { {0x4093000a,0xb8930003,0x6b890002,0x24430060}},	//   _الفر, _الفع, gieg, _dım_
  { {0x65610017,0x75d60003,0xb9980001,0xc1741f95}},	//   _folh, _إيطا, квих_, илищ
  { {0x99d30003,0x6f042b62,0xdb1e0004,0x3a370009}},	//   حتيا, _adic, _kupó, נרים_
  { {0xa3c40044,0x0577000a,0x6b890002,0x201e0a17}},	//   एगा_, _حملة_, bieg, utti_
  { {0xa3d80037,0x201e14c1,0x236d0029,0x68e4003a}},	//   ादन_, rtti_, ckej_, _şidd
  { {0x61e2000f,0xf1ba001a,0x9162001a,0x115403e1}},	//   _utol, _thơ_, hử_, _вклю
  { {0xda7b000b,0xa158004c,0xdde30031,0x823b0009}},	//   _אנדר, _јаку_, örűe, _נעוצ
  { {0x80db000b,0xd8db0009,0xc9530009,0x68fa0270}},	//   _אחוז, _אקור, _למס_, matd
  { {0x1dd40037,0xf1a4002d,0x501b0009,0xdb210064}},	//   ददात, ґрун, _נוחו, _štúr
  { {0x3d95002d,0xd8f50001,0xb9c50012,0x3f8b2b63}},	// [7cf0] _випр, изањ, لقري, micu_
  { {0x2d8a0164,0x6d5a0051,0x2fcd0052,0x6e2d002c}},	//   cibe_, ötat, _sieg_, _ipab
  { {0x69ce00c6,0xdb1e0164,0xf9900012,0xc6d5004c}},	//   _dibe, _cupó, سبك_, ажећ
  { {0x3f8b001c,0x99d70003,0xe4480012,0xdb040478}},	//   nicu_, _متسا, _إلَى_, pliá
  { {0x8afa0009,0x6b89001e,0x12fa01b0,0xbafa0009}},	//   _שהשי, vieg, _בהרב, _בהרש
  { {0xe0d40001,0x2cad0066,0x95c40012,0x3da90048}},	//   _горњ, ředu_, مينه, ъкло_
  { {0x636a0065,0x6b8901e0,0xc4f80012,0xf8a90011}},	//   _sýni, tieg, اعها_, _कडिय
  { {0x98aa0066,0x290a000e,0x442c00b6,0x3f8b0220}},	//   žbě_, óban_, _dpd_, jicu_
  { {0xc9550015,0x3f8b0027,0x9f46000e,0x3f9c0025}},	//   атны, dicu_, zsló_, évue_
  { {0x636a0029,0x236d0029,0x2003009b,0x2d8a0018}},	//   _výni, skej_, šjim_, xibe_
  { {0xb8dd0037,0x6e2d00b6,0x7c8400fa,0x9179001a}},	//   _आर_, _apab, _луце, _cẩn_
  { {0xc7a6002d,0x366a0001,0x8fa60138,0x07a6077e}},	//   римк, вамо_, раме, рамн
  { {0x7afb0006,0x200c21ba,0xd2350048,0x6d89115a}},	//   maut, ardi_, _ъндъ, ržan
  { {0xeeeb0020,0x427a000b,0x7afb2b64,0xda780048}},	//   ưởng_, _באנג, laut, _щях_
  { {0x637802d1,0x6b660014,0x67290002,0x61e90010}},	//   _líne, аква, _obej, lpel
  { {0x28a90037,0x7afb2b65,0x7aed002c,0xb89a0009}},	//   _कड़ि, naut, gbat, _שבקש
  { {0x6d5a0051,0x7bcf2b66,0x7f3b0009,0x42530012}},	// [7d00] ötas, _dicu, _יעקו, ينفر
  { {0xd5fb0009,0x8dfb0009,0xdebb0009,0x81100011}},	//   _שפיר, _שהית, _במפל, ालेख_
  { {0xa8560046,0x7afb1880,0x4999002d,0xc059002d}},	//   штај, kaut, уття_, лії_
  { {0x7649014d,0xf8b20093,0xe6660024,0x7afb2b67}},	//   _brey, חשב_, итло, jaut
  { {0x7afb0010,0x764901e3,0x16a700b5,0x67290030}},	//   daut, _crey, авци_, _dbej
  { {0x100a0003,0xcd270024,0x7bc42b68,0x7afb2b69}},	//   _لترى_, ижче_, lmiu, eaut
  { {0x9cd70093,0x998d003e,0x319b000b,0x7d7b000b}},	//   בוצה_, steś_, _סבלנ, כנסו
  { {0x7afb1611,0x8bd70009,0x200c001b,0xc354004c}},	//   gaut, סופו_, vrdi_, скиј
  { {0x7c3a003e,0x7e60006f,0x63780097,0xd2500012}},	//   _wstr, ämpl, _gíne, سند_
  { {0xf9920003,0x200c009b,0x6448009b,0x7cf80009}},	//   تبع_, trdi_, _trdi, _תִּק
  { {0x7c3a012e,0x40340014,0x7afb0052,0xc9b70009}},	//   _ustr, щенс, baut, שהית_
  { {0x61e60027,0x8c1b0009,0x6ba5004b,0x6d89001b}},	//   _otkl, _יובי, ăugâ, ažal
  { {0x2907000e,0xdb001994,0x69db10df,0xdb04008e}},	//   ónak_, nomí, cque, iliä
  { {0x7bcf01a2,0x1a7b000b,0xac190c6d,0xd6d90034}},	//   _sicu, _שְׁמ, логу_, _mała_
  { {0x61e6001e,0x49bb0009,0x99990064,0xef1f0031}},	//   _atkl, _שמוס, ísť_, niük_
  { {0x5398002d,0x8877000b,0xdce30002,0x34940024}},	//   ався_, _כתוב_, mkną, іатр
  { {0xf1ba0037,0x7aed2b6a,0xd7bc0009,0x3d170011}},	// [7d10] _उठान, rbat, _בצהר, _नाले_
  { {0x63750065,0x7afb000e,0x9f5800c1,0x256f003a}},	//   _mána, zaut, _avrà_, _mülk_
  { {0x66d50003,0x5335022a,0x3ed50012,0x39a40024}},	//   ميائ, _лент, مقار, ішув
  { {0x75351161,0x07080012,0x87070223,0x201c01a0}},	//   lezz, ليمي_, ряже, àvia_
  { {0x63750028,0xd6d90002,0x69db2233,0x7afb03ec}},	//   _nána, _cała_, xque, vaut
  { {0x2707001a,0x0d840024,0xce380009,0x753500b8}},	//   ốn_, олін, יאדת_, nezz
  { {0x84580048,0x7b060031,0xd7e40024,0x92a90034}},	//   ирът_, _áttö, _міто, bołó
  { {0xd498000b,0xf1db0037,0x753500c1,0x76490028}},	//   יכות_, _बढान, hezz, _trey
  { {0x7535000f,0x8e850003,0xcd2b0012,0x28c30011}},	//   kezz, _الذه, _لسان_, वेरि
  { {0x7afb0006,0xb9550001,0x69db2641,0xc5170012}},	//   saut, стић, rque, _خبرت
  { {0x6d4100b6,0x69db2b6b,0x7afb2322,0xe4500012}},	//   _iala, sque, paut, _يضم_
  { {0xe3b00003,0xa856000b,0x2d9e0066,0xf092000b}},	//   _قرن_, צירה_, čtem_, לני_
  { {0x82d6000b,0x254b0010,0x6d410d94,0xbb3a0009}},	//   _הונג_, kėlė_, _kala, _תעני
  { {0x6d4121f1,0xf1db0037,0x92b40012,0xdcb10081}},	//   _jala, _बढ़न, _بحما, _kỷ_
  { {0xf3f10020,0xdd8f0003,0xc0c80001,0x6d412b6c}},	//   ập_, روف_, _куће_, _mala
  { {0x6d410101,0xef1a0223,0x9f580031,0x69d92b6d}},	//   _lala, _сми_, özül_, _kuwe
  { {0xb77b000b,0x9f5f01e9,0x50d60012,0x20d60012}},	// [7d20] _תאפש, nutý_, مزار, متاج
  { {0x865b0093,0x63a90184,0xe8f70109,0x6d412b6e}},	//   _עדיי, hoen, йлу_, _nala
  { {0xa2b40037,0x636a0097,0x66080034,0x28c305f3}},	//   _आरक्, _sýnu, ądku, वेलि
  { {0x7c3e001c,0xc7d6000b,0x66040028,0x6d41002c}},	//   _ispr, צוני_, _kvik, _aala
  { {0x9e14002d,0x63a90070,0x61e60348,0x2003009b}},	//   ідкі, doen, _utkl, šjih_
  { {0x2fd80051,0xd2b70009,0xdb00135b,0x2d9a005e}},	//   _turg_, _ללכת_, romí, õpe_
  { {0x6d412484,0xdc2a0012,0xa3d80011,0x985c0035}},	//   _dala, استه_, ादि_, nāļa_
  { {0x5f960351,0xd0070046,0x6f960003,0xdb0000d9}},	//   _الرئ, _ћете_, _الرض, pomí
  { {0x7afd0065,0x6d412b6f,0x8b570009,0x39a60024}},	//   ðsta, _fala, מיקס_, йшов
  { {0xa3d80044,0xad650003,0xbd290003,0x6d412b70}},	//   ादा_, _واله, _نأمل_, _gala
  { {0x753510f7,0xb9000011,0xdbf10030,0xdb00004b}},	//   vezz, _थल_, _přín, româ
  { {0x443e032b,0xb09b000b,0x389b000b,0x83c602ad}},	//   _ist_, ריטר, ריטנ, _убеж
  { {0x75351b8d,0x6d410060,0x6d670073,0xbe8b0488}},	//   tezz, _yala, žraš, усне_
  { {0x7bda00a2,0xdceb001b,0x6d5a008e,0x660208ef}},	//   _kutu, čići, ötap, isok
  { {0x7aed007d,0x9fe6000a,0x7bda0051,0x3ea0002a}},	//   _întâ, _استه, _jutu, _exit_
  { {0x657c0052,0x28970009,0xb0970009,0x62801a4d}},	//   ahrh, _לדון_, _לדוח_, ozmo
  { {0xeab30003,0x6b8d2b71,0x60f9003c,0x5a9b0009}},	// [7d30] سعر_, riag, иная_, ְׁבו
  { {0x7bda0017,0x88950014,0xaac50011,0x443e2b72}},	//   _outu, оизх, लेषक, _ost_
  { {0x610b0039,0xb9c40012,0x32cf0060,0x98170012}},	//   vēlē, أقلي, _köyü_, إبطا
  { {0x637802d1,0x42990012,0x6d412b73,0x764d01a6}},	//   _vínc, _ننجح_, _sala, _kray
  { {0x443e2b74,0x787f0031,0x7ed40012,0x8f9c0009}},	//   _ast_, _kávé, أزما, נידי
  { {0xdcf50039,0xd5fc000b,0x7bda00b6,0xdd9b0015}},	//   mizē, נפור, _butu, ыше_
  { {0xdcf50039,0x6d432b75,0xad1c01b0,0x443e0132}},	//   lizē, rdna, טוגר, _cst_
  { {0x69d90101,0x6d410160,0x99e50015,0x63780f9b}},	//   _puwe, _wala, ожид, _kína
  { {0x443e02b5,0xa2a20037,0x93bc000d,0xc334000b}},	//   _est_, _कुञ्, _apăs, לוק_
  { {0x63780065,0xdcb1001a,0x672d0164,0x66060097}},	//   _mína, _tỷ_, _abaj, _ækka
  { {0x764d00a2,0x66040028,0x63a92b76,0xf6490009}},	//   _aray, _svik, poen, _שצ_
  { {0x22490070,0xd6d90002,0x02b90037,0x1eca00f5}},	//   kvak_, _mało_, _आरंभ, илни_
  { {0x99d70003,0xceb20009,0xe6170337,0xceb60012}},	//   _اتصا, ֥ים_, одя_, تحدث
  { {0xd5af0012,0x59c50012,0x31c7004c,0x637529fe}},	//   َفَ_, _بيتك, _усев, _káno
  { {0x3d1b0044,0xdb001007,0x6375029d,0xa3df0011}},	//   _बारे_, lomá, _jáno, _धूम_
  { {0x3f8f0027,0xa0880009,0xb5fb0031,0x764d0d29}},	//   jigu_, _לְפִ, gyás, _fray
  { {0xc3320093,0x61ed0101,0xe6c60003,0x27e00027}},	// [7d40] וון_, gpal, _بتغي, _čini_
  { {0xa1c3002d,0x3f8f0071,0xb8b6004c,0x9f5f01e3}},	//   дбуд, eigu_, осећ, butó_
  { {0x19b9002d,0x7c3e0eb3,0xcf46003c,0x2d570009}},	//   суть_, _uspr, жней, _ושיש_
  { {0xd3780027,0x464a0048,0x62800034,0xd6d90034}},	//   _kuće_, изен_, yzmo, _dało_
  { {0x98b8000d,0xdcf5001e,0x637c000e,0x8f9b0009}},	//   _bară_, cizē, _jéne, סיני
  { {0x6f09003a,0x1dbc0037,0xcbe60014,0x98ac000d}},	//   _edec, ोगित, оции, nedă_
  { {0xd8230046,0xdb0003eb,0x475a1103,0x602302e3}},	//   _одри, tomà, _края_, _одра
  { {0x93bc007d,0xc4d3000b,0x443e2b77,0x7ae42b78}},	//   _apăr, וגו_, _vst_, ncit
  { {0x613f0073,0x2e240097,0x7ae42b79,0xd37b0009}},	//   kšlė, jöf_, icit, ירקט
  { {0x31780002,0x6f090002,0x5d780009,0xd5780009}},	//   órz_, _zdec, _פָּנ, _פָּר
  { {0x68fc00b6,0x6fe1001e,0x313701b0,0x01370009}},	//   _merd, _pēca, חנים_, חרית_
  { {0x764d1791,0xc43b0009,0x68fc0060,0x478b123c}},	//   _pray, _כתבי, _lerd, рсом_
  { {0x8f9b0009,0x8d6b004c,0x25740248,0xd94619c1}},	//   שיכי, ајва_, _täll_, _меди
  { {0xdcf50039,0x22590040,0x63b60031,0xd49b0198}},	//   vizē, åske_, elyn, арб_
  { {0xa3b10037,0xbc480015,0xb9c30012,0xa4d40024}},	//   _फ़ीड_, очте_, _تقوي, дорі
  { {0xe5170044,0x03c4002d,0xdcf5001e,0x22490070}},	//   _ताकि_, дсум, tizē, tvak_
  { {0x29d5000a,0x68fc00c6,0xc1750014,0x637c0d85}},	// [7d50] سياس, _berd, плащ, _géne
  { {0x3d040037,0xdcf5001e,0x799a0032,0x68fc2b7a}},	//   रणों_, rizē, nntw, _cerd
  { {0x2d912b7b,0x68fc0070,0x80070015,0xb6020066}},	//   mize_, _derd, ючае, řáte
  { {0x657a0036,0x68fc0070,0x6d45002c,0x17f80003}},	//   _alth, _eerd, _haha, تركة_
  { {0x7afd0039,0xf774000b,0x735a000b,0x6d4514d5}},	//   _iest, וקף_, _הכרח, _kaha
  { {0x11da0093,0x2d9100a2,0x63ad000d,0x6d472b7c}},	//   _לחשב, nize_, loan, ndja
  { {0xc57c000b,0xe4e4002d,0x7dc00052,0x7afd0bcb}},	//   שרות, фічн, lösc, ðsto
  { {0x03a8000a,0x6d450161,0xdb00084f,0xc0520009}},	//   يديو_, _laha, tomá, _אזל_
  { {0x68fc003a,0xe664003c,0x929d0034,0x68000031}},	//   _yerd, _отфо, kałe, _tájá
  { {0x8d770003,0x61e60107,0xdb002b7d,0x3ce50011}},	//   _بارا, íkla, romá, कडों_
  { {0xa3bd0044,0xf992000b,0xd491001a,0xa5bb0028}},	//   ेगा_, תרי_, _kèm_, rtól
  { {0x91790020,0x69d50052,0x7afd2b7e,0x4cba0009}},	//   _lần_, _lize, _nest, _המעג
  { {0x6d45050a,0xe8b80037,0x2007017b,0xd4970081}},	//   _baha, _अर्च, šnih_, ồng_
  { {0x6d450f50,0xe9a80012,0x7afd036c,0x69d50159}},	//   _caha, _ودون_, _aest, _nize
  { {0x69c32b7f,0xdbf10066,0x69080009,0xe1080009}},	//   _ihne, _přán, _וּפְ, _וּפָ
  { {0x46a6002d,0xbea6002d,0xd00e0003,0x96fa0003}},	//   _найв, _найк, _إلي_, _اعثر_
  { {0x171b0093,0x2d840108,0xdb0d0028,0xe9d700b3}},	// [7d60] _הופע, èmes_, rmað, зку_
  { {0x7afd03fb,0x91790020,0x7ae42b80,0x3a990024}},	//   _eest, _cần_, scit, іттю_
  { {0x07fa0003,0x69d5155c,0xb4d80037,0x7afd2b81}},	//   صراع_, _dize, िशी_, _fest
  { {0x68fc0782,0xd7ef0003,0xdfcf0003,0x99890002}},	//   _werd, اكن_, هيل_, grał_
  { {0x68fc00c6,0x69d52b82,0x69c30032,0x91620081}},	//   _terd, _fize, _ohne, hứ_
  { {0x7bc20036,0x91790020,0x7afd1528,0x200519b3}},	//   _shou, _gần_, _zest, ksli_
  { {0xd4670046,0x317b0009,0x25fd0011,0x99890034}},	//   зије_, _פרלמ, रीबी_, brał_
  { {0x309b000b,0xaa540014,0xfaff0025,0x889b0009}},	//   _השלמ, двиш, _noël_, _הבלי
  { {0x628401a2,0x25740163,0xc333000b,0xd6eb000b}},	//   nzio, _välj_, תוח_, _הַבָ
  { {0x4e7b0009,0x867b0009,0xcce50012,0x27370081}},	//   _האמצ, _הרמו, _قسمي, _ần_
  { {0x7bc20036,0x7bde0051,0xc953000b,0x2d910066}},	//   _thou, _nupu, גמת_, vize_
  { {0xe6950015,0x929d0002,0x6d452b83,0x74130012}},	//   димы, wałe, _saha, _سوها
  { {0xbaba0003,0x32ba0003,0x6e3d0070,0xe8dc0011}},	//   _اداء_, _اداة_, uwsb, _बलूच
  { {0x7afd095d,0xa2cd0037,0xd5b1001a,0x62840002}},	//   _sest, _दृष्, ố_, dzio
  { {0x63ad000d,0x91bb000b,0x718b000b,0x19bb000b}},	//   toan, _המגי, _לְהַ, _המגב
  { {0x68b7000b,0x69dd1219,0x69d51457,0xbbb90024}},	//   _מלוא_, _puse, _size, ігає_
  { {0xa2cd0037,0xaa580447,0x63ad2b84,0x2bb80012}},	// [7d70] _दृश्, питу_, roan, سافة_
  { {0x291e0010,0x64580010,0x6d89009b,0x7e7c0009}},	//   ngta_, _švie, ežav, _לאחז
  { {0x628401a2,0xf1c80003,0x63ad000d,0x29012b85}},	//   azio, أولى_, poan, raha_
  { {0x290100c6,0x56950015,0xe6950003,0xef1f1c8b}},	//   saha_, мает, ولاد, enüz_
  { {0xa3aa0037,0x85e80003,0x69d5000e,0x91790081}},	//   खकर_, كّنك_, _tize, _tần_
  { {0xdd91000a,0xee38002d,0x361c0009,0x625a0009}},	//   ضوع_, яні_, מודד, _וכשה
  { {0xdbf10066,0x8c4200de,0xdb00008e,0xa6db0097}},	//   příj, веще, komä, meðf
  { {0xdce10039,0xdb4e0003,0xa0c40003,0x291e0f31}},	//   _dolā, لَى_, _سيقو, egta_
  { {0xdb00006f,0x3a2900b6,0x929d0034,0x44272b86}},	//   domä, ntap_, wałb, stn_
  { {0x98bc0039,0xa189002d,0xfe700012,0x3a290060}},	//   _savā_, ібна_, _صدق_, itap_
  { {0x07a600be,0x8fa60014,0x645e004a,0x64410027}},	//   данн, дане, äpit, _usli
  { {0xd7ca0012,0x73c40012,0x7bde004b,0xdbcc0097}},	//   توجه_, _كيلم, _rupu, jóðn
  { {0x8e55002d,0x8db60024,0x7bde2b87,0xaa4517de}},	//   нтрі, дсві, _supu, _целл
  { {0xa3b60011,0x7bde1642,0xe00d0011,0x7d032b88}},	//   _चीज_, _pupu, _हिंद_, nans
  { {0x2d840010,0xfce30055,0x5fd90011,0x33d60024}},	//   ėme_, тосо, _बंगल, діат
  { {0x7d030006,0xd7fa000b,0x05dd0037,0x2eff0061}},	//   hans, _והקל, मदाब, _neuf_
  { {0x39470070,0xef190034,0x6fe80030,0x6f02001b}},	// [7d80] _kans_, óże_, _věce, vaoc
  { {0xda650003,0xf9c7002d,0x637c0061,0x62841fee}},	//   راقي, дгук_, _ména, rzio
  { {0xdce30066,0x0577000b,0x39472b89,0xc2090009}},	//   skně, _חגים_, _mans_, שה_
  { {0x91790020,0x44442b8a,0x628400c1,0x7d0309d4}},	//   _vấn_, _is_, pzio, eans
  { {0x6d89013a,0xeb3b0009,0xb5aa0012,0xc6e50024}},	//   ržav, _ועכש, ياتك_, хієп
  { {0xf2000011,0x91620081,0x91790081,0xc3e60012}},	//   लीफ़_, iữ_, _tấn_, وثبو
  { {0xac970003,0x67240027,0x91620081,0xe71a0012}},	//   ونها_, _ocij, hữ_, _ويست_
  { {0x8c430001,0xe7370024,0xdcf80035,0xbf130012}},	//   теће, _оес_, tivē, _لوفب
  { {0xc29800b3,0xd6260003,0x7d032b8b,0x44442b8c}},	//   яких_, _تعزي, bans, _ls_
  { {0x44442b8d,0x7d032b8e,0xe6c50012,0xa5bb2b8f}},	//   _os_, cans, _ستقي, rtók
  { {0x394702b5,0xa5bb0028,0x645c0010,0xa0a600b3}},	//   _dans_, stók, _šrif, ьшил
  { {0xc7ab0003,0xd2520012,0x6d482b90,0x657e2b91}},	//   تدخل_, _لنص_, _hada, _alph
  { {0xdb0d03eb,0x44442b92,0xe4e7002d,0x91620081}},	//   llaç, _as_, дібн, gữ_
  { {0x4444281b,0xb2bb0009,0x22400034,0xe81f0011}},	//   _bs_, _ומדר, dwik_, मूडा_
  { {0x17f70003,0x6d482b93,0x91790081,0x236b004c}},	//   _قرية_, _mada, _lẫn_, ојао_
  { {0x6d480218,0xc2c50012,0x69d81387,0x6d890064}},	//   _lada, فيزي, _hive, ežat
  { {0x99d90003,0x4efc0009,0x92940024,0x53440048}},	// [7d90] سواء_, _והחו, ватц, ъхра
  { {0x41b50012,0x929d0034,0x753c0034,0x673d005e}},	//   رمار, nała, cerz, lesj
  { {0x69d8000f,0x63a40027,0xe5700012,0xd7e40024}},	//   _mive, činj, _خطي_, вічо
  { {0x7d030002,0xcc760009,0x69d82b94,0x6d4801a4}},	//   wans, _נערה_, _live, _aada
  { {0x6d4810e3,0x7ed40012,0x28c30011,0xed59091c}},	//   _bada, نزها, वेजि, зол_
  { {0x91790020,0xdb0d0018,0x63a2008e,0xf9fa0009}},	//   _dẫn_, flaç, _ajon, _מהשמ
  { {0xabd50001,0x8d740003,0x637c0061,0x7bcd004a}},	//   нциј, خانا, _séna, omau
  { {0x39470108,0x1309007c,0x753c0d23,0xca48001a}},	//   _sans_, чний_, zerz, _bờ_
  { {0xca48001a,0x26090011,0xd7940048,0x7bcd0032}},	//   _cờ_, _सिटी_, _ритъ, imau
  { {0x661d0051,0x9980003a,0x7af60066,0x64de0011}},	//   dusk, iriş_, zbyt, _मलेश
  { {0x7b6705cc,0xf1b2000b,0x673d2b95,0xe1080009}},	//   _отде, רסי_, fesj, וּרָ
  { {0x70dc0037,0x99890002,0xf1b90584,0xa3c20011}},	//   _बल्ल, eważ_, duše_, ूषण_
  { {0x69c70006,0xab18007c,0x661d0051,0x63bb05ac}},	//   _ohje, _цієї_, gusk, mlun
  { {0x63bb008b,0x7d01000f,0x66d600a2,0x69d82b96}},	//   llun, _jels, _hükü, _give
  { {0x6d89007a,0xdca307e8,0xb97a0009,0xb8640012}},	//   ežas, гари, _מנסי, _لايو
  { {0x29050101,0x11da0003,0x753c0b6d,0x38780623}},	//   lala_, كورة_, serz, ørre_
  { {0x63bb0052,0xfbd20009,0xdb060030,0xd2a707b9}},	// [7da0] ilun, רתן_, ámém, екте_
  { {0x63bb0052,0x7ae90042,0x29052b97,0x3afe0081}},	//   hlun, hcet, nala_, ắp_
  { {0x44442b98,0xacfb0009,0xa3df0011,0xb9b50048}},	//   _us_, _מהיכ, _धूल_, тстъ
  { {0x29052b99,0x6d482b9a,0xdee60434,0x66e60760}},	//   hala_, _sada, ходи, хода
  { {0x7d01000e,0x63bb0052,0xa2d60003,0xe4e60024}},	//   _bels, dlun, _سيست, нійн
  { {0x91790020,0xa3d80011,0x29fd0064,0xf2d30009}},	//   _vẫn_, ादक_, dňa_, _תעש_
  { {0x20070066,0x63bb0028,0x29052b9b,0x69d82b9c}},	//   ánit_, flun, dala_, _rive
  { {0x5a340232,0x6d4800b6,0x32660de1,0x600b0009}},	//   внит, _wada, етов, _מִמְ
  { {0x7d012b9d,0xdb0d0018,0xbea30048,0xdd200011}},	//   _fels, slaç, _батк, _बांध_
  { {0xf8ab0020,0x82330003,0xbd8a0003,0x661d057c}},	//   ười_, اريا, _عنان_, vusk
  { {0xb4250003,0x67220811,0x98b80034,0x6c560024}},	//   _لعنو, ogoj, _parę_, _ятає
  { {0xca48001a,0xcaf60003,0x67222b61,0x4c9b0009}},	//   _tờ_, _أساب, ngoj, _צבאו
  { {0x69d80149,0x95cb0048,0xdd910012,0x29052b9e}},	//   _tive, зува_, لوح_, bala_
  { {0x7ec9001e,0x6f060002,0xe6110009,0xa9670048}},	//   _rūpī, aakc, יִל_, _пича_
  { {0x61e2004a,0x4395002d,0x41c30003,0x66d6003a}},	//   _huol, вавс, _حقوق, _yükü
  { {0x201e0005,0x58bb000b,0x61e2004a,0x00bb0009}},	//   muti_, _ממוצ, _kuol, _ממומ
  { {0xdb1b0017,0x4fd8000b,0x201e2b9f,0x9fad0030}},	// [7db0] fluê, _אוהב_, luti_, _něé_
  { {0xe2900003,0x51840024,0x20070018,0x9a3b0009}},	//   حذف_, луха, ânio_, התמק
  { {0x39a40001,0x4917000b,0x201e2ba0,0x7ae20035}},	//   уштв, תקבל_, nuti_, žota
  { {0x7d010623,0x98140012,0x29fd0064,0x224d0ca4}},	//   _sels, ابلا, yňa_, _šeku_
  { {0x61e20d66,0xa91c0064,0x63a80030,0x213e0132}},	//   _nuol, zhľa, édne, keth_
  { {0xe4e7007c,0xa91c0026,0x201e21f1,0x7d072ba1}},	//   хідн, yhľa, kuti_, najs
  { {0x63bb0028,0xf9920009,0xa9880009,0x20d70012}},	//   tlun, _כרך_, _נָשִ, _ستسج
  { {0x63bb003a,0x660d0027,0x637c0061,0x25740052}},	//   ulun, _ovak, _déno, _hält_
  { {0xd36e0003,0x63bb1137,0x2d810018,0x99dd0064}},	//   تهي_, rlun, _olhe_, yvňu
  { {0x63bb0065,0x99d50003,0x85200011,0x7dc401a0}},	//   slun, ختبا, _बाइट_, ròsc
  { {0x660d0163,0x290315b6,0x788608c5,0x7d0700d9}},	//   _avak, _meja_, _révé, dajs
  { {0x29fd0064,0x2a390012,0x68360032,0x7dc0008e}},	//   pňa_, _يكاد_, _südö, töso
  { {0x661a0002,0x201e0010,0x29052ba2,0x333f0025}},	//   ątko, auti_, pala_, meux_
  { {0x201e2ba3,0x9e760009,0x333f0025,0xc0e2003c}},	//   buti_, דגשה_, leux_, _кошк
  { {0x5c1500be,0x1c390800,0x67220010,0x5fd10011}},	//   льту, нять_, ygoj, तगाल
  { {0x6e960003,0x333f0061,0xe6960012,0x929d0034}},	//   _للعا, neux_, _للعد, nało
  { {0xe2970098,0x29c20028,0x7886000e,0x7db60012}},	// [7dc0] ват_, iðan_, _tévé, _لصدا
  { {0x91a70020,0x8c96002d,0xd1830015,0xc8d60012}},	//   _địa_, _армі, алуй, نزاع
  { {0x637803eb,0x6bd60003,0x7d7b0009,0x30860003}},	//   _líni, _لتحر, _חריג, خلاف
  { {0xf989000b,0xeb9a002d,0xbf130003,0x8a062ba4}},	//   חר_, _цим_, لومب, _изме
  { {0x3e340003,0x2574006f,0xc6f7002d,0x3f130024}},	//   افتر, _fält_, тніх_, рдіс
  { {0x63750065,0x1ea90003,0x61e200c1,0x29c20028}},	//   _mánu, راني_, _ruol, eðan_
  { {0x50c60037,0xed570001,0xab94002d,0xa2d60011}},	//   _वरिष, тој_, ликі, _मृत्
  { {0xe3af0003,0x61e21082,0x60c3003a,0x201e2ba5}},	//   يري_, _puol, ünme, vuti_
  { {0x55e6002d,0xc7d7000b,0xdfa50012,0xd7170009}},	//   _розб, _יולי_, _صحفي, _שחמט_
  { {0x443a1a41,0xd1300003,0x3f860017,0xa5450003}},	//   _opp_, حمد_, lhou_, _مضمو
  { {0x660d001c,0xf993000b,0x05770003,0x3f860066}},	//   _svak, שרת_, _جملة_, ohou_
  { {0xa3e60037,0x6d5e18c2,0xf8b3000b,0x68f5003a}},	//   _पढ़_, _anpa, ישת_, ızda
  { {0x443a2ba6,0x7d070328,0xc7b30009,0x2c510034}},	//   _app_, tajs, שבר_, _sąd_
  { {0xe8540003,0x69dc002c,0x201e003b,0xfe08001a}},	//   _منتد, _nire, puti_, iữ_
  { {0x984a0014,0xdb1b0054,0xfe08001a,0x113b0009}},	//   _цяла_, fluè, hữ_, _חתול
  { {0x29030149,0x2d980061,0x5b14022a,0x31db0011}},	//   _seja_, aire_, имст, बद्ध
  { {0x69dc003a,0x64580097,0x1bd4091c,0x23690159}},	// [7dd0] _bire, _ávin, ротя, rjaj_
  { {0x6f04008b,0x64430002,0x3d1c0037,0x6b820054}},	//   _zeic, ywni, नलों_, _llog
  { {0x29030149,0x43950014,0xe7190003,0x4815010c}},	//   _veja_, _банс, فيات_, умес
  { {0xf770000a,0xcc56000b,0x889b0009,0xa0c40012}},	//   يان_, _עברי_, ובבי, جيمو
  { {0xfe08001a,0xb2870015,0x3ea90054,0x333f0061}},	//   gữ_, _рынк, çat_, veux_
  { {0xceb4000b,0x69dc2ba7,0x6b821745,0x867c0009}},	//   סיס_, _gire, _alog, ורדו
  { {0xd4350003,0xe8d9001a,0x333f0025,0x5bb5004c}},	//   اعتب, _đỏ_, teux_, лсиф
  { {0x2a6d0002,0xe6130003,0x8cdc0009,0x0c360012}},	//   _żeby_, _نشط_, וחות, اكية_
  { {0x6f04008b,0x333f0061,0x9f5f004a,0x7bdd06b5}},	//   _reic, reux_, istä_, _misu
  { {0xd945004c,0xb2bc0009,0x6fe80030,0x99850012}},	//   ћени, ומחר, _věcn, الدو
  { {0x63a90416,0xc952000b,0x9be7002d,0x2d982ba8}},	//   čenj, זמי_, _різк, vire_
  { {0x32450012,0x29190060,0xd6110024,0x637501e3}},	//   _منصف, şsa_, _вiдб, _cánt
  { {0x645703eb,0xd2280003,0x2b40001e,0x63780028}},	//   _arxi, _لكنه_, veic_, _kínv
  { {0x69ca0044,0xceb20093,0x9f5f004a,0x6f040052}},	//   _सीपी, צים_, estä_, _weic
  { {0x3ceb0037,0x2d982ba9,0x69b90011,0xddcd0034}},	//   _चलने_, rire_, ्तनी, _brał
  { {0x6e3b0002,0x2d982baa,0xb8760009,0xe5200011}},	//   _opub, sire_, _תתקס_, _बाकि_
  { {0xec09001a,0x7bdd2bab,0xed5a0048,0x49ca047a}},	// [7de0] hế_, _disu, _зоп_, елан_
  { {0x2d870159,0x32170012,0x6d5e2bac,0x6abd2bad}},	//   jhne_, ايلد_, _unpa, _dysf
  { {0x443a2bae,0x200e0028,0xef1a031e,0xa5bb0097}},	//   _upp_, éfi_, еме_, fróf
  { {0x7aed00c1,0x29c20028,0x5f0611ed,0x8c1b0009}},	//   ccat, eðal_, узда, _אוטי
  { {0x8f9b0009,0x69dc2baf,0x63750097,0x63a42bb0}},	//   עיני, _tire, _láns, mnin
  { {0x63a401ab,0xbc4a0014,0xf9870012,0x75d30012}},	//   lnin, ечие_, _طب_, مينا
  { {0x07a60014,0xf98306fd,0x91bb0009,0x8fa60681}},	//   _бавн, _угро, _נמלי, _баве
  { {0x7afb002c,0xbb740001,0xd6260012,0xfba7003c}},	//   gbut, ргиј, _معطي, лтый_
  { {0xe8d90020,0x6b82009b,0x3f8421f1,0x63a42bb1}},	//   _đề_, _vlog, _ilmu_, inin
  { {0xdd8f000a,0x63a40163,0xc339000e,0x7afb002c}},	//   _فوق_, hnin, áírá, abut
  { {0x63a42bae,0xa5bb003e,0xb0ce0037,0xc057002d}},	//   knin, któr, हेंग, гія_
  { {0x8c1b000b,0x6b820027,0xf093000b,0x63a42bb2}},	//   _טובי, _ulog, מנת_, jnin
  { {0x7bdd01a2,0x957c003e,0x5f940098,0x69b90037}},	//   _risu, _ciąg, сият, ्तमी
  { {0xddc20013,0x7bdd0005,0xcdd4000b,0x7d0a00b6}},	//   tvoř, _sisu, יךָ_, nafs
  { {0x63780028,0x63a40028,0xa4d5002d,0x41bb0009}},	//   _línu, fnin, рові, _רצוע
  { {0x7d0a0028,0x63a40ca1,0x9aa50012,0xd7f8004b}},	//   hafs, gnin, لمزو, mpă_
  { {0xbda70003,0xdb040028,0xd3570009,0x92b70012}},	// [7df0] _محدو, rlið, נימי_, احزا
  { {0x6115002d,0xa5bb2bb3,0x63a42bb4,0x41770012}},	//   рджу, atór, anin, دارس
  { {0x31c40015,0x7bdd0027,0x80a40012,0x38c70365}},	//   сств, _tisu, ممكن, ущав
  { {0xa5bb0056,0x20570009,0xa8570009,0x87d40012}},	//   ctór, טיבל_, טיבה_, مغنا
  { {0xd246000a,0xaf04007c,0x11d90003,0x44230002}},	//   _بن_, спіл, _لوحة_, luj_
  { {0x5a9a0093,0xac39002d,0x2715001a,0x7ae2023f}},	//   _ישרא, вчих_, ền_, _agot
  { {0x0578000b,0xa5bb0028,0x55780009,0x64980048}},	//   רגום_, próf, רעון_, лтър_
  { {0x69ca0037,0x2d840035,0x7dc0008e,0x32350048}},	//   _सीबी, īmei_, tösk, ахос
  { {0x99800026,0xa3d60037,0xc3340009,0x3b820024}},	//   stiť_, िगत_, צוץ_, ільг
  { {0x44232bb5,0x8e840003,0x320d12bf,0x41b20012}},	//   kuj_, _الكه, rsey_, يمير
  { {0xfd100003,0x6ca700de,0xfb150012,0x64c40012}},	//   _رجل_, _сраж, _نواج, _هيكل
  { {0x20181bfb,0x6235027f,0x68b60009,0x9c820064}},	//   ária_, _веду, ילתא_, účen
  { {0x3984006f,0x80c90037,0x63a41f15,0xd7f8004b}},	//   _lösa_, हेजे, vnin, apă_
  { {0xe2c8002d,0xa5bb0002,0x90450012,0x621a0009}},	//   _слід_, wtór, _ننته, _יונק
  { {0x4423003e,0x4126002d,0xc3960001,0x3b960001}},	//   guj_, _тощо_, ајањ, ајат
  { {0xdca3002d,0x6fb30003,0x661d009b,0x2bbf0011}},	//   іати, _وموا, brsk, ्षगा
  { {0x6da6007c,0x6d432bb6,0xe5a6002d,0x5f770012}},	// [7e00] _випа, kena, _випи, _خميس_
  { {0x4423003e,0x6d430bec,0x63a40828,0xa5bb2bb7}},	//   buj_, jena, snin, stór
  { {0xd116000b,0x90e50003,0x63780672,0x69c12bb8}},	//   שקעה_, إسكن, _sínu, ille
  { {0xc169000b,0xc7af0012,0x2d852bb9,0xf1b90035}},	//   וח_, وّل_, _alle_, kušo_
  { {0x2bdf0037,0xf1b90035,0xad9b2451,0x7d0a2bba}},	//   _पंजा, jušo_, csús, tafs
  { {0xd657000b,0x7b3e0002,0xdcfe001e,0x6d4301db}},	//   יינת_, _dłuż, _impē, gena
  { {0x6b890065,0x04580003,0x3f9c0025,0xa0670d25}},	//   fheg, البة_, évus_, _кара_
  { {0x27e00006,0xea000020,0x2d852bbb,0xd3780027}},	//   _niin_, _luật_, _elle_, _kući_
  { {0x6d4300c6,0xf1b9001e,0x44231468,0xb7db0009}},	//   bena, gušo_, zuj_, _יקלי
  { {0x7c3e0119,0xca37000b,0x3a37000b,0x6d432bbc}},	//   _oppr, סניה_, סרים_, cena
  { {0xe8d9008a,0x3ceb0037,0xd7f8000d,0x23b60011}},	//   _để_, _चलते_, upă_, ंवाद
  { {0x25fd0044,0x7ae2012e,0x1df90015,0x6b890070}},	//   रीकी_, _ugot, лемы_, cheg
  { {0x5db70003,0x44230002,0x21f40012,0x27e0020d}},	//   لإسر, wuj_, _اكتس, _diin_
  { {0x6f160002,0x44232bbd,0xa6db0028,0xc27b000b}},	//   _edyc, tuj_, beðn, _ברדי
  { {0xd0f7000b,0x98a50010,0x98a3004c,0xdb000060}},	//   _דמות_, delė_, _миље, komü
  { {0x44230002,0x6d430017,0xdb040061,0xf8db0009}},	//   ruj_, zena, nniè, _בחומ
  { {0x4423003e,0x60e7002d,0x59c50012,0xdb0001e3}},	// [7e10] suj_, ацез, ميرك, lomó
  { {0xdebc000b,0x29072bbe,0x2d9c017b,0xcad70009}},	//   _במחל, úna_, jive_, שומת_
  { {0xa3c80037,0x7b3e0002,0x66160010,0xd8770012}},	//   ोगा_, _służ, šykl, جاذب
  { {0x6d4300b6,0xd8740012,0x201e0097,0x29070034}},	//   wena, غالب, irti_, źna_
  { {0x98a700a2,0xf770000a,0xef18002d,0x7d080058}},	//   ını_, بال_, рмі_, _beds
  { {0x2d9c00c5,0x9985000a,0x63782bbf,0xea760009}},	//   give_, _السو, _fíns, _הגשר_
  { {0xaadb0011,0x645a001b,0xd7fb004c,0x661a0034}},	//   _मृतक, _crti, _југ_, ątki
  { {0xa6db0065,0xf3490015,0x13680001,0x1b490593}},	//   veðn, упил_, ишњи_, узии_
  { {0x69c10054,0xd24e0003,0x22590097,0xe7eb0011}},	//   tlle, فني_, ísk_, _जूता_
  { {0x8d74000a,0x27e00005,0x05740003,0x7d740003}},	//   _والا, _siin_, _والد, _والط
  { {0xc3550014,0x66e60055,0xf6490009,0x39510035}},	//   _гълъ, йона, _רצ_, _mazs_
  { {0x290c00ff,0x4c9a0009,0x883a0009,0x8fa60557}},	//   aada_, _גבעו, נתרו, саме
  { {0xa142001e,0xeb900012,0x6fda0030,0xd7ba0009}},	//   šķie, _تظل_, _důch, רֶיך
  { {0xa2560009,0xd2560009,0x98a70030,0x225e0030}},	//   _לבנק_, _לשנה_, ýně_, _čtk_
  { {0xddc400a2,0x6ff50003,0x63a80066,0xf7f50003}},	//   _eriş, _استط, édno, _استد
  { {0x637c0061,0x501a0009,0x3a320248,0x2d9c25ff}},	//   _péni, _עופו, ttyp_, zive_
  { {0xae1c0037,0xe80a0011,0x98a50073,0xc64a0012}},	// [7e20] _निधन_, हीना_, telė_, _إجعل_
  { {0x186a0046,0x8e57000b,0x3a3202f1,0x3f82008e}},	//   лази_, _פייג_, rtyp_, lkku_
  { {0x7ee60003,0x63ad0470,0x3f820051,0x3a3202f1}},	//   مكان, čanj, okku_, styp_
  { {0xcb6a106a,0xf729002d,0x27e0004a,0x290c0583}},	//   _саме_, ицій_, öin_, zada_
  { {0x6eb60003,0x8bd70009,0xd1380034,0x443e016d}},	//   حصائ, _לוטו_, niąc_, _spt_
  { {0x86070003,0xdd900003,0x7d0e0032,0x290c2bc0}},	//   حقوق_, بوت_, nabs, xada_
  { {0x30860003,0xe4fb0037,0x7e7d0002,0xfd0f0012}},	//   _الأف, ्रति_, zysp, رجو_
  { {0x7d080070,0xddc90034,0x207b0009,0x645a090a}},	//   _weds, _kreś, _גאלא, _vrti
  { {0xdb1b0149,0xdb040108,0x6e960003,0x7d0e0058}},	//   cluí, rniè, _الذا, kabs
  { {0x20180149,0xa8140001,0x481400b3,0x39452bc1}},	//   ário_, одош, омос, gels_
  { {0xc32a000a,0xdb0f000e,0x7bc40010,0x493b000b}},	//   _مكان_, ődés, kliu, נגטו
  { {0x7e7d004a,0x3212004a,0xe61f0018,0xdb000031}},	//   tysp, ksyy_, trô_, romó
  { {0x8f9b000b,0x290c2a5f,0xbb3b0009,0x6e260031}},	//   ריכי, pada_, _תעדי, gukb
  { {0x291c000e,0x52d70009,0xdb000034,0x201e0159}},	//   óval_, _הודע_, pomó, prti_
  { {0x499b000b,0x219b0009,0x89370009,0xfc640048}},	//   _תשוב, _תבוא, _לרגע_, пътн
  { {0xec34002d,0x8fa40001,0x07a40001,0xab94002d}},	//   янсь, _наје, _најн, писі
  { {0x3a200070,0x52150063,0x2f980009,0xf1bf0064}},	// [7e30] grip_, юдат, _לכהן_, ššej_
  { {0x7bc40010,0x35f80012,0x32b80012,0xe9190024}},	//   aliu, _اريد_, صدقة_, рожі_
  { {0x26060037,0xa5bb0b95,0x290a01e3,0x6ff3004b}},	//   सीसी_, prób, _deba_, _tăce
  { {0x5fc90037,0xd378001b,0x6d472bc2,0xff070024}},	//   रतिल, _kuću_, leja, сяжн
  { {0xf770000a,0x7dcd0054,0xf625002d,0xa3d60011}},	//   عام_, júsc, ідко, िगर_
  { {0xce380093,0xb4fb0044,0xdb020065,0x6fe80013}},	//   צאות_, ्रिय_, _skoð, _těch
  { {0x39450087,0xc0580024,0x7db40012,0x6d552bc3}},	//   vels_, _літ_, أصنا, idza
  { {0x765b0020,0x39450132,0x9f340024,0x22150934}},	//   _truy, wels_, _несі, офор
  { {0xe667002d,0xdb0001a0,0x39452bc4,0x6d47114d}},	//   _утво, tomò, tels_, keja
  { {0xe8df0020,0x39790015,0x7dc008b5,0xa1e80012}},	//   _giới_, рсию_, nöst, حريك_
  { {0xa3d90037,0x0cab0014,0xd1380002,0x7ce80009}},	//   ाषा_, _стаи_, wiąc_, _הַנֶ
  { {0x3f890663,0x44270755,0xa856000b,0x6d551e1c}},	//   _clau_, mun_, קירה_, edza
  { {0x05560014,0x70c60037,0xe8c60011,0x63a92bc5}},	//   отвя, _वर्ल, _वर्च, mnen
  { {0x6d470cb1,0xc5f20009,0x63a92946,0x98a50035}},	//   geja, ודך_, lnen, nelī_
  { {0xa5bb0002,0xd1380002,0xe7320003,0x44272bc6}},	//   wróc, siąc_, _قصة_, nun_
  { {0x63bb002a,0x290a0029,0xbea600a6,0xd2520012}},	//   noun, _seba_, _майк, ونز_
  { {0x442700ec,0x89da0003,0x89160012,0xe2a90012}},	// [7e40] hun_, لورر_, قبائ, ماكن_
  { {0x2d84001e,0x63a90052,0x60260024,0x10a6022a}},	//   īmes_, hnen, жджа, оизн
  { {0xd12f000a,0x61eb00c1,0x63bb0027,0x46ea0345}},	//   ضمن_, _lugl, koun, аден_
  { {0xddc9003e,0x6b8d0108,0x7dcd0164,0xaec609c6}},	//   _treś, chag, yúsc, обел
  { {0x63bb0164,0x98be001e,0xceb30009,0x82360012}},	//   doun, ietā_, ֽיו_, _برجا
  { {0xa2da015f,0x8c43003a,0x44270028,0x7c660003}},	//   _पृष्, ışve, fun_, قابل
  { {0x61eb014d,0x0b8a0014,0x44272bc7,0x63bb06dc}},	//   _augl, исии_, gun_, foun
  { {0x9cd70009,0x6d470034,0x63a92bc8,0x6b841886}},	//   חוצה_, zeja, gnen, nkig
  { {0x05b90044,0xfbd30093,0xb6a3002d,0x61e3003a}},	//   ेतशब, ותה_, _житл, _binl
  { {0x6d230001,0x599a0009,0x24580081,0x44272bc9}},	//   _одуз, ישִׁ, _tĩm_, bun_
  { {0x3f8903eb,0x6f0f00c1,0x61e3003a,0x6c4a0003}},	//   _plau_, tacc, _dinl, _خلاف_
  { {0x6d550002,0x61e30052,0x63a90029,0x91e602e3}},	//   wdza, _einl, cnen, _доде
  { {0xdb09008b,0x9f4d0052,0x6602003a,0x7dc0004a}},	//   ließ, _ließ_, _çokl, yöst
  { {0x26c5001e,0x6440000d,0x94ab0048,0x0cab0048}},	//   ālo_, ămin, атба_, атби_
  { {0x672b0065,0xa5bb000e,0x61eb0052,0xe8d9001a}},	//   yggj, gróa, _zugl, _đệ_
  { {0x6e22281b,0x6d472bca,0x8c1b0009,0x48a90024}},	//   krob, seja, יולי, _утім_
  { {0x05ca0037,0x4427003a,0x6ce7002d,0x7dc00137}},	// [7e50] िताब, zun_, _міне, töst
  { {0x79d4002d,0x44270225,0x63a9142f,0x69c50018}},	//   джує, yun_, znen, ulhe
  { {0x6e22001e,0x4427001a,0x7dc002f1,0x1dd80012}},	//   erob, _ên_, röst, _ببيع_
  { {0x44270006,0x63a90042,0x9cd60009,0x7dc0008e}},	//   vun_, čens, _מותה_, söst
  { {0xaaf6000b,0xb4f80037,0x637c0028,0x8d65004d}},	//   _מזרח_, ुरूप_, _léns, звле
  { {0xc27a000b,0x44272bcb,0xd5fc0009,0xe5a5004c}},	//   _הרשי, tun_, ספור, џики
  { {0x63a90026,0x30a40001,0x61eb13ed,0x60180109}},	//   tnen, _жртв, _sugl, _моря_
  { {0x6441012e,0xf1b9001e,0x6f0d000d,0x44272bcc}},	//   _vpli, muši_, _neac, run_
  { {0x13060015,0x63a92bcd,0x63bb02d5,0x7dd20040}},	//   чный_, rnen, roun, læse
  { {0x442700c6,0xf5950012,0x63a92bce,0x63bb18bb}},	//   pun_, _علاج, snen, soun
  { {0x7dc0000f,0x637c000e,0xf9920009,0x6f0d2bcf}},	//   zöss, _pént, גרי_, _beac
  { {0x7b64005c,0x309a000b,0xe73a1478,0xba770012}},	//   _отче, משתמ, щем_, _واشت
  { {0xee37002d,0x9877009b,0xcdf60015,0x82640012}},	//   пня_, _išče_, ячны, _يهمن
  { {0xf1b9001e,0x2fc6017b,0xf9fa0009,0x6eba0009}},	//   kuši_, zlog_, _ההסמ, מזרח
  { {0xaffe0020,0xf1b90039,0x6e220034,0xcb6a004c}},	//   _trướ, juši_, zrob, баве_
  { {0x6d860065,0x6f0d00bd,0x66161863,0x7dc0004a}},	//   _aðal, _geac, šyki, töss
  { {0xe8d90020,0x997c0035,0xee3a0024,0x46a60048}},	// [7e60] _độ_, _dāņu_, _унп_, _хапв
  { {0x6f1b000d,0x7dc40054,0x7e9b0009,0x201c0018}},	//   _aduc, pòsi, _לספו, ávio_
  { {0xd12f0003,0x7d7b007e,0x6d7b000b,0x757b000b}},	//   امم_, _הניו, _האיח, _הטיפ
  { {0x442a0005,0x98be000d,0xdfd20012,0x91e60ef5}},	//   mub_, letă_, ريش_, _номе
  { {0x2fc60070,0x442a2bd0,0x443802e0,0x96660024}},	//   rlog_, lub_, ltr_, якде
  { {0xf5780003,0xdb0d0028,0xc5f30009,0x05780012}},	//   تمتع_, llað, עדו_, تمتة_
  { {0x4438007d,0x7467003c,0x34370012,0x2fc6001b}},	//   ntr_, зрыв_, كسيد_, plog_
  { {0xa0370009,0xeb920009,0x6c830012,0xbb980012}},	//   _מאלה_, ךָ֖_, عليم, تنبؤ_
  { {0x63a00029,0x2258003c,0xdcfc0035,0x645c005e}},	//   rimn, ципы_, zkrā, hvri
  { {0x44442bd1,0xb6030013,0x8dfb000b,0x442a05d7}},	//   _op_, ášen, _להמת, kub_
  { {0xdd8f000a,0x656800c5,0x4444003e,0xa3be0037}},	//   _حول_, _indh, _np_, ेता_
  { {0x442a0051,0x3f860042,0xd4690012,0x929d0034}},	//   dub_, nkou_, _بحكم_, tałt
  { {0xab27002d,0x645c003a,0xf1be0037,0x59be0011}},	//   _хоча_, evri, ्तान, ्तार
  { {0xcaa50003,0xaadb0009,0x89d80012,0x6e200031}},	//   _تصمي, _החדר, _بوتر_, ámba
  { {0x69da008b,0x657a002a,0x6f0d002a,0xc9730003}},	//   mmte, _moth, _teac, _ساوث
  { {0x69c8006f,0xe0850012,0x8bc4004c,0xf1b90035}},	//   llde, _تجهي, есуд, vuši_
  { {0x35b501b6,0xb5fd0604,0x717900b5,0x8bd70009}},	// [7e70] _обир, _krše, обар_, לולו_
  { {0x657a2bd2,0x442a005e,0x41b40012,0x6d580227}},	//   _noth, bub_, ّمْر, jdva
  { {0xdb0d0028,0xe7190012,0x47350d7c,0x69da0227}},	//   blað, قيات_, днес, imte
  { {0xe0d00003,0x69da0032,0x99840030,0x7dd20040}},	//   ازك_, hmte, kumů_, ræse
  { {0xddc9007d,0xa3c00037,0xe7300012,0xf1b90035}},	//   _creş, ंकन_, اصم_, suši_
  { {0x7bc2001c,0xd658000b,0xbe3c0009,0x6d4a2bd3}},	//   _akou, פיות_, צעות, gefa
  { {0xfd100003,0xad1c0009,0x63ad1506,0x7dcd0097}},	//   اجه_, מוגר, onan, búsn
  { {0x2d8c00a2,0x27fc0029,0x3f860145,0x291c000e}},	//   _elde_, ívne_, ckou_, _adva_
  { {0xddc9000d,0x6d4a038e,0xa6db0028,0x5b580009}},	//   _greş, befa, beði, לשהן_
  { {0x11d60012,0xdb000097,0x888502ba,0x657a15d0}},	//   ووية_, rnmá, длож, _goth
  { {0x8af90098,0xff260015,0x61e7120a,0x6d412244}},	//   _днес_, ммно, _mijl, _ibla
  { {0x444400c6,0x69da002e,0xcb080012,0x6b83004b}},	//   _rp_, amte, _فيمن_, _îngh
  { {0x2bb80003,0x7bdb0269,0xa3b80012,0xe7160009}},	//   _عامة_, mmuu, _عامر_, וחרר_
  { {0x7bc90108,0x290e0065,0x7bc20066,0x442a0cb1}},	//   lleu, _gefa_, _zkou, tub_
  { {0x61fd0333,0xef1f003a,0xdb0d0028,0x29050f4c}},	//   _atsl, mkün_, tlað, mbla_
  { {0x645c0070,0x98be000d,0x77690025,0x6d58001b}},	//   rvri, setă_, _nnex, zdva
  { {0xc332000b,0x61e70070,0x442a0051,0x44382bd4}},	// [7e80] כון_, _bijl, sub_, str_
  { {0x26170037,0xe9d706e6,0x7bc90052,0xf8d10011}},	//   _निजी_, дку_, hleu, _हराय
  { {0xa6db0065,0x7bc90070,0xa84a0003,0x3f8d0061}},	//   veði, kleu, تلام_, _bleu_
  { {0xddc9007d,0xc334000b,0x6d4123cb,0x6ac60012}},	//   _preş, _אוֹ_, _abla, _يقدم
  { {0x98a50010,0x69c80260,0xcb130009,0x35f70012}},	//   kelį_, ylde, _שלש_, ورود_
  { {0xa697000b,0x98be0010,0xb6bb0009,0xa4d40024}},	//   וכנה_, letą_, חצני, нолі
  { {0xd4670046,0xa157000b,0x98a50010,0xd6d90002}},	//   дије_, _קבלה_, delį_, _mały_
  { {0xaa540294,0x389b0009,0x109b0009,0xd3700012}},	//   евиш, _וילנ, _ובלב, اهة_
  { {0x07a30001,0x99890029,0xd1300003,0x657a0054}},	//   _ратн, stať_, همة_, _toth
  { {0x7bc90061,0x69c8002a,0x98a50010,0xa6970009}},	//   aleu, ulde, gelį_, _חכמה_
  { {0x69c8006f,0xc953000b,0x63a4004a,0x7bc90061}},	//   rlde, דמת_, kiin, bleu
  { {0x59d00037,0x29c20028,0x6e9500de,0x96f8003c}},	//   _तीसर, gðar_, еиму, меют_
  { {0xb50a0037,0x5f940014,0x8674002d,0xa3c90321}},	//   वरूप_, тият, вляє, _लीग_
  { {0xea000020,0xd6d90002,0x63ad0002,0x7bc01598}},	//   _xuất_, _cały_, wnan, lomu
  { {0x69cb0037,0x04c90003,0x63a4000d,0x70540012}},	//   हतरी, سوري_, fiin, _أنبا
  { {0x69d40044,0xcc570009,0x213e0132,0x394c0248}},	//   _बीबी, ובלי_, lfth_, leds_
  { {0xb6040013,0x61e70070,0xde190012,0xc2c40012}},	// [7e90] tvář, _pijl, _عقدت_, نيفي
  { {0xef19003e,0x64930010,0x39582bd5,0xab5d0002}},	//   _może_, ežiū, _cars_, może
  { {0x7d15003a,0x27e900b6,0x31c4048c,0x25f50011}},	//   mazs, _kian_, тств, _एंडी_
  { {0x46d30037,0xea00001a,0x60c70066,0xef120009}},	//   _सराह, _suất_, _vyjm, ָּא_
  { {0xbafa000b,0x05ca0011,0xbe4b0012,0x7bc02bd6}},	//   _מהרש, ितंब, تشام_, domu
  { {0xb5fb000f,0xc1050003,0xdd910012,0xdd02001b}},	//   ováb, _سوري, طوع_, čući
  { {0x6fca00d9,0xf9920009,0x57f4004c,0x66020031}},	//   kých, _גרם_, _апст, apok
  { {0x7769002a,0x7c840001,0xf0920009,0xef190034}},	//   _unex, ђује, _ענן_, _boże_
  { {0x7bdb004a,0xa5bb01c5,0x95cb004c,0x0dcb004c}},	//   rmuu, tról, _дужа_, _дужи_
  { {0x2dd40046,0x3cfb0037,0x84470003,0xaa850066}},	//   _ажур, ्रों_, _يخال, jvýš
  { {0xcea90093,0x2cfb0037,0x660d0ec4,0x7bc908a7}},	//   _פי_, ्रैल_, _awak, pleu
  { {0x29180028,0x1cb80012,0x63ad2bd7,0xe1ff01a0}},	//   órar_, _غالب_, čans, _otó_
  { {0x29c20065,0xe28e0953,0x8db6002d,0x27e92bd8}},	//   rðar_, _са_, есві, _dian_
  { {0xef1f000f,0xb176001a,0xc692000b,0x427a0009}},	//   lkül_, _thượ, נאם_, _מאנג
  { {0x1c390015,0x98be0010,0xf8c60321,0x8c4301d4}},	//   мять_, tetą_, _रुपय, лере
  { {0x27e90020,0x69c12bd9,0xf4120009,0xdb000025}},	//   _gian_, lole, טפל_, timé
  { {0x44271038,0x32290024,0x69c12bda,0xe7b30012}},	// [7ea0] hrn_, дієм_, oole, _حميد
  { {0x63bb048b,0xdb000061,0xb6bb000b,0xe0d20003}},	//   čuna, rimé, _מצפי, هزا_
  { {0x3958006f,0xf2c9000b,0x661b2145,0x660d0227}},	//   _vars_, צע_, _avuk, _zwak
  { {0x29070028,0x6d5c2bdb,0xd00f0012,0x39582bdc}},	//   ðnar_, ldra, صله_, _wars_
  { {0x6493007a,0x7bc60006,0xe534002d,0x44270052}},	//   ržiū, _ikku, вель, ern_
  { {0xb6030064,0xab5b0031,0x2d8a0031,0x6d4e2bdd}},	//   ášan, _lkül, nkbe_, neba
  { {0xf3f10020,0x68460015,0x53e602ad,0x5d3b0009}},	//   _cụ_, _янва, нциа, פתקא
  { {0xf3f10020,0xddcd000d,0xa3d00011,0x2a60005e}},	//   _dụ_, _oraş, षति_, ovib_
  { {0x394c0058,0x69c10051,0x79a60400,0xcaa60012}},	//   teds_, fole, ерне, عصبي
  { {0x3a37000b,0x3d0a0037,0x6d5c2bde,0x0ef90011}},	//   ערים_, वरों_, jdra, ंड्स_
  { {0x7bc60065,0xa3d00037,0x27e9004a,0xddcd003a}},	//   _okku, षता_, _pian_, _araş
  { {0x67100037,0x60da000e,0x6d5a1e68,0xa08b0009}},	//   ारिक_, _útmu, _hata, לְכִ
  { {0x8f9b000b,0xdb00006f,0x262a0009,0xae2a0009}},	//   ליטי, rnmä, הוָ֣, הוָ֛
  { {0xdca6000a,0x6d5c0070,0x7bc60b56,0xab5d0034}},	//   لى_, gdra, _akku, roże
  { {0x3ce5006f,0xf3f1001a,0xa6db0028,0x6d5a2bdf}},	//   älv_, ệ_, veðu, _mata
  { {0xa3c00044,0x5ba404b3,0xa3c20037,0xe6950003}},	//   ंकि_, груз, ृति_, _للبد
  { {0x6d4e00c6,0xa2940024,0xe1f30012,0x442e0032}},	// [7eb0] beba, гаті, اسر_, huf_
  { {0x6fd60066,0x6d5a2be0,0x7dd20040,0xdd04004b}},	//   ráce, _nata, læsn, ărăr
  { {0x29110027,0xa3c00037,0x2bac0066,0x30180012}},	//   _veza_, ंका_, pěch_, فتنة_
  { {0x8c1a000b,0xa0c40003,0x27fc0029,0x141a0009}},	//   _קורי, ديمو, ívna_, _קורב
  { {0x69d8005e,0xed5909e8,0x9b160009,0x7bcd0032}},	//   _ohve, дол_, _בחרה_, mlau
  { {0x63a22079,0xe5f8000b,0xa6db0028,0x6e3d0052}},	//   _amon, עזור_, leðs, itsb
  { {0xe73f0005,0x216401b6,0x69c12be1,0xf5320009}},	//   lnõu_, _стяг, vole, ׁ֥ה_
  { {0xf3f10020,0x44270052,0x69c10002,0xc24506da}},	//   _vụ_, rrn_, wole, вник
  { {0x2489001e,0x7bcd004a,0xe9d90ba0,0xd24e0012}},	//   ņam_, ilau, мки_, قني_
  { {0xd9450001,0x3f4c001a,0xd1b90003,0x69c1004a}},	//   њени, _ếu_, بابا_, uole
  { {0x7bcd007a,0x69c12be2,0x60250048,0xd8250048}},	//   klau, role, ъдна, ъдни
  { {0x69c10005,0xf0ee0037,0x7dcd0029,0x6d4e0623}},	//   sole, _जल्द_, kúsk, weba
  { {0x98b100a2,0x6d5a003a,0xb9b50048,0x539a0009}},	//   ızı_, _yata, _искъ, _קינו
  { {0x7afd2be3,0xe29f0097,0x644e0031,0x3a292be4}},	//   _afst, úðu_, _únió, drap_
  { {0x69ca0044,0x98be0010,0xf9920009,0xb8640012}},	//   _सीटी, ketę_, _דרג_, _مايو
  { {0xd6b60012,0x7c2e0ed7,0x6d4e2be5,0x7bcd2be6}},	//   _لإخب, rubr, seba, glau
  { {0xf5060098,0x6d5c00bd,0xcb120009,0x97570009}},	// [7ec0] _изпо, pdra, ילן_, _ישקף_
  { {0x3cf00044,0x7afd0028,0x41030024,0x41b30012}},	//   _चलें_, _efst, изув, لمقر
  { {0x7bcd016a,0xf1c20073,0x98bc0073,0xe73a0148}},	//   blau, _rašą_, _davė_, дее_
  { {0x34b70009,0x7bcd026b,0x7dcd0097,0x2d810032}},	//   _יפים_, clau, búsk, öhen_
  { {0x6d5a166b,0xc3330009,0xa3bf0011,0x442e016d}},	//   _pata, _דור_, इवर_, wuf_
  { {0xdb0d0061,0xf653000b,0xa2af0037,0x7c580012}},	//   nnaî, יצד_, ंपर्, فلتر_
  { {0x6d5a003a,0xe44f0012,0xe8d90081,0x61ea2be7}},	//   _vata, قضي_, _đở_, _rifl
  { {0x442e1b88,0xa2d90011,0xf4830024,0x7b63003c}},	//   ruf_, _मरम्, рушн, атье
  { {0x6d5a0175,0x442e00b6,0x4e0b0011,0x3a730048}},	//   _tata, suf_, सीआई_, илър
  { {0x11d80003,0x4974002d,0x69c3009b,0xce37000b}},	//   عودة_, улос, čneg, _באמת_
  { {0xc917000b,0xb4250012,0xe10b0009,0x7d182be8}},	//   כחית_, _معنو, וּכָ, mavs
  { {0x83830015,0x69d40011,0x7d182be9,0x6e3d2bea}},	//   _выше, _बीसी, lavs, ttsb
  { {0xdd910003,0xda970012,0x95cb0048,0xa2da0011}},	//   موح_, _لخوض_, дува_, _पृच्
  { {0x21a3004c,0x20180031,0x403400b5,0x8a170009}},	//   _кичм, áris_, _бекс, _יחדו_
  { {0xebc70001,0x7bcd0068,0x43950024,0x0c24003c}},	//   вљан, tlau, гавс, имён
  { {0x69c70119,0xf1b90027,0x63bb0133,0x7d181527}},	//   _skje, vrši_, čuno, havs
  { {0x6d410051,0x61d90015,0x7d02004b,0x7bcd2beb}},	// [7ed0] õlas, емая_, _şose, rlau
  { {0x7bcd007a,0xdb0005b1,0x31590012,0x90e70012}},	//   slau, dimí, علاج_, نسان
  { {0xdef10003,0x3984006f,0x661d2bec,0xa0c40012}},	//   مًا_, _röst_, lssk, ليكو
  { {0x4431003a,0x2d810052,0x5695004d,0xd6390024}},	//   muz_, _hohe_, лает, еякі_
  { {0x2d810051,0x539a000b,0x7afb003a,0xa6340024}},	//   _kohe_, _נישו, vcut, инці
  { {0xaac60037,0x69c70033,0xbbcb0011,0x6a9a0009}},	//   _लड़क, _ukje, ात्क, _טשרנ
  { {0x443100a2,0x7d7c0009,0x03a51671,0xf9920009}},	//   nuz_, ונגו, лико, _פרל_
  { {0xd2510003,0xddc20034,0xdb040018,0xdfd10012}},	//   منع_, owoś, rniç, _طيء_
  { {0x9915007c,0xa6db0097,0x51f50012,0x7bdc0009}},	//   льні, yfða, دسبر, וקהו
  { {0x60090015,0x7dcd0029,0x44310060,0xdd3c0073}},	//   нном_, kúsi, kuz_, _sąži
  { {0x80a5000a,0x5fb70037,0xf3350003,0x3cf001bd}},	//   امجن, _अदाल, _مفاج, ňové_
  { {0x44312bed,0x6f190034,0xddc90064,0xa5bb0034}},	//   duz_, nawc, _speň, orów
  { {0xe2f8002d,0x7a47001e,0x63a92bee,0xca080024}},	//   _речі_, nītā, mien, _аніж_
  { {0x27ed0108,0x2bcb0011,0xfe0b0011,0x395c0248}},	//   _lien_, ातका, सीएस_, _gavs_
  { {0x28020066,0xa0660014,0x113a000b,0x41cf0011}},	//   ěrné_, _баща_, _נתקל, _सीएस
  { {0xf3e60055,0x6b8d020d,0x2b5f004b,0xd467004c}},	//   ужбо, gkag, nduc_, ћите_
  { {0xe2970098,0x6f19003e,0x39960058,0xaac50012}},	// [7ee0] гат_, dawc, _læse_, لتكن
  { {0x7a470039,0x7e9b000b,0x63a90778,0xed5a004c}},	//   dītā, _נסיו, hien, _џон_
  { {0x27ed217d,0x6bd60012,0x7dc00031,0x63a92bef}},	//   _bien_, _متحر, kösz, kien
  { {0x4b560098,0x63a911a0,0x27ed134c,0xeb9a0ec6}},	//   _съот, jien, _cien_, _чим_
  { {0xde58002d,0x6d5e2bf0,0x41cf0011,0x80ca0011}},	//   талі_, _kapa, _सीऍस, _सुने
  { {0xa3be0037,0x6b83000d,0x9f990025,0x63a90227}},	//   ेतक_, _îngr, réé_, eien
  { {0x69dc008b,0x6d5e0101,0xd117000b,0xd7f8000d}},	//   _ihre, _mapa, _תקלה_, _îă_
  { {0x6d5e2bf1,0x6c470003,0x6d430028,0x395c001e}},	//   _lapa, اليف_, afna, _savs_
  { {0xe3af0012,0x20d30081,0x22402bf2,0x8383003c}},	//   ثرو_, _ại_, ntik_, сыще
  { {0x6e93000a,0x27ed00bd,0x291a00b6,0x3257000b}},	//   _الكا, _zien_, napa_, נסים_
  { {0x1f750048,0xab5d0034,0x291a016d,0x660419b3}},	//   алня, możn, iapa_, _atik
  { {0x9cd7000b,0xf4570009,0x6af60012,0xe1fa004c}},	//   _גובה_, _תיאר_, _إثار, _згд_
  { {0x291a006f,0x6d5e00b6,0x69dc0032,0x9df80148}},	//   kapa_, _bapa, _ohre, лнят_
  { {0x6b8200bd,0xf237000b,0x3a37000b,0x98b80010}},	//   _hoog, _ערוץ_, _תרגם_, _narį_
  { {0xfbd30003,0x6d5e050a,0x68fb000b,0x5f950024}},	//   متر_, _dapa, _אלוה, _вийт
  { {0x443100a2,0xaab5002d,0x6b820574,0x69d801c7}},	//   ruz_, айбі, _joog, _नीती
  { {0x27ed0108,0x39150046,0x248d001e,0x201e001e}},	// [7ef0] _rien_, имар, ņem_, lsti_
  { {0x61ee0061,0x6b8200ff,0x6f190034,0x67240159}},	//   _cibl, _loog, wawc, _zdij
  { {0xc94b0009,0x98170012,0xbf100011,0x84670048}},	//   עֲמֹ, ابطا, ारंभ_, _съпе
  { {0x7a47001e,0x6d4800b6,0x69dc0052,0x201e2bf3}},	//   tītā, _abda, _ehre, isti_
  { {0x6d5e00a2,0xb5fb0145,0x27ed0708,0x63a92bf4}},	//   _yapa, zván, _vien_, vien
  { {0x63a9003e,0x32090101,0x7c650003,0x6d430032}},	//   wien, mpay_, لاعل, ufna
  { {0x91ba000b,0xfaf10003,0x7a47001e,0x6d430028}},	//   _ימשי, يثة_, sītā, rfna
  { {0xba750003,0x36050003,0x5f9412d2,0xb9080011}},	//   لاخت, _نورف, _лист, मे_
  { {0x7f84000a,0x4999002d,0xf7840012,0xab5d0034}},	//   _القن, втня_, _القَ, bożn
  { {0xd49b0046,0xf1cf0011,0xb5fb0031,0x63a92bf5}},	//   _пре_, _सीखन, tván, sien
  { {0xe8d9001a,0xc9520009,0x6d5e2bf6,0x3a3f2629}},	//   _đồ_, חמי_, _rapa, stup_
  { {0x6d5e2bf7,0x547a0009,0x7c940012,0x6fb30012}},	//   _sapa, _בטעו, _اشكا, ْمَا
  { {0x28ac0037,0xdc3c009b,0x6d5e250c,0x97560009}},	//   _टेनि, ršče, _papa, בירו_
  { {0xceb20093,0xc0e50098,0xf2d2000b,0x929a007e}},	//   קים_, _колк, _ועד_, _בינת
  { {0x6d5e004a,0x443e0061,0x998900f1,0xb5fb000e}},	//   _vapa, ît_, mpaň_, lvál
  { {0x2240003a,0x61ee0bb5,0x69dc0f08,0xdb090227}},	//   ttik_, _sibl, _shre, dieë
  { {0x7983003e,0x5725000a,0x637c000f,0x2907003a}},	// [7f00] _konw, _طريق, _pénz, ınan_
  { {0xb5fb000e,0xa2dd0011,0x186a0dc2,0x44d50081}},	//   ivál, _परन्, кази_, _ó_
  { {0x291a00c6,0xb5fb00f1,0xdb090227,0x70530012}},	//   rapa_, hvál, gieë, ينكا
  { {0x9e660800,0x7f46002d,0xf62a002d,0xe1ff0002}},	//   ивед, редж, віки_, _król_
  { {0x69dc1bfe,0x5de60104,0x63bc000e,0x7e560024}},	//   _thre, ажда, _írni, ртец
  { {0x7e692bf8,0xceb3000b,0x23ba001e,0x7d1c2bf9}},	//   _drep, חיד_, dīja_, nars
  { {0x20b90047,0x91bb000b,0xdb0901bd,0x16d30011}},	//   _быть_, _סמלי, šnýc, _सर्ब
  { {0xfca90012,0x7ac62bfa,0x7d1c2bfb,0xc47700af}},	//   داهو_, испе, hars, שתקו_
  { {0xb5fb000f,0xcb670046,0xfe720003,0x1dc60037}},	//   gvál, рање_, _بدأ_, लकात
  { {0x3a20002c,0x71980012,0xa63b0009,0x2918016d}},	//   isip_, اندز_, _בגמר, _jera_
  { {0x201e007a,0xd0f7000b,0x00f70009,0x3fa70012}},	//   usti_, ימית_, יזים_, لصحف
  { {0x7d0e006f,0xdc3b0009,0x201e2bfc,0x3f8407ee}},	//   ebbs, _יעבר, rsti_, _jomu_
  { {0x539b000b,0x0e3400b3,0xa5bb0034,0x7c2e2bfd}},	//   _ביאו, оняю, krót, erbr
  { {0x44d50020,0x29180957,0x229b0009,0x80c10011}},	//   _ý_, _nera_, _שֹׁמ, _रुके
  { {0x69c82bfe,0xd5b80014,0x89db0009,0x9d180863}},	//   mode, рся_, _שחוי, рост_
  { {0xdce10039,0x5bb80015,0x2bb80012,0x987b0009}},	//   _solī, ался_, لاقة_, _ירוק
  { {0x764d00c6,0xd1380002,0x2b8e0066,0xb7dc000b}},	// [7f10] _upay, ogą_, _mých_, _בקהי
  { {0xd138007a,0x6f1d2bff,0x7d1c2c00,0x69c70159}},	//   ngą_, lasc, cars, čjeg
  { {0x6ff3007d,0x64410054,0xd3710012,0xc1e8003c}},	//   _făcu, àlid, _فهد_, рьте_
  { {0xdb0900bd,0xdcfa0035,0x637c0031,0xdb460012}},	//   rieë, _rotā, _tény, _عَ_
  { {0x6db2003e,0xf7700003,0x8e490003,0xdb0000f1}},	//   kład, ظام_, التك_, ximá
  { {0x2918189f,0xd6580009,0x5e580009,0x0dc80024}},	//   _gera_, יידת_, יידע_, алій_
  { {0x4095000a,0xe8df0020,0xb895000a,0x7dcd01d7}},	//   _الأر, _trực_, _الأع, dúst
  { {0x61b10044,0xa3d70037,0x7d1c0164,0xb5fb000e}},	//   ीक्ष, िति_, zars, tvál
  { {0x957c0002,0x6f1d10ac,0xf9910012,0x7d1c2c01}},	//   _piąt, dasc, كبد_, yars
  { {0x917b001a,0x69c82c02,0xdd000035,0xf1c80030}},	//   _kể_, gode, ātīg, _tvář_
  { {0x6ca70046,0xa3d70037,0x63ad03e9,0xb5fb000e}},	//   _траж, िता_, kian, svál
  { {0x2d850daa,0x64430248,0x6db20034,0xd1380073}},	//   _hole_, mtni, aład, agą_
  { {0xe8d9001a,0x6e290066,0x7d1c2c03,0x97560009}},	//   _đổ_, šebn, tars, זירו_
  { {0x799a0369,0x237f009b,0x69c8041a,0x64431ca8}},	//   chtw, ljuj_, code, otni
  { {0x7d1c1d52,0xdcfa000d,0x65610e6a,0x63ad2c04}},	//   rars, _hotă, _malh, fian
  { {0x9696007c,0x29182c05,0x03a3027f,0xfbdf0081}},	//   _грош, _sera_, писо, _chê_
  { {0x2441001a,0x6d550c89,0x29182c06,0x70f60012}},	// [7f20] hóm_, beza, _pera_, مسائ
  { {0x4223002d,0x6443256e,0x3f840035,0xa13c0035}},	//   ядув, ktni, _somu_, tiķi
  { {0x29182c07,0xa3c90037,0x3a2017e1,0x63ad2c08}},	//   _vera_, ोता_, ssip_, bian
  { {0x645e1597,0x5e260003,0xb5fd009b,0x86360009}},	//   _ispi, معتق, _gršk, ֶרֶב_
  { {0xd1380010,0xdfcf0012,0x59c70011,0xceb30009}},	//   ygą_, ريه_, रकार, ּיו_
  { {0xb996000a,0x27f8002a,0x64432244,0x2d852c09}},	//   _السب, _turn_, ftni, _cole_
  { {0x3f84014a,0x7878000b,0x7642004a,0x7d230012}},	//   _tomu_, _דָּו, stoy, سفين
  { {0xf7430015,0xfc2f0012,0x09d00011,0x69c80034}},	//   _несо, رحى_, हत्य, wode
  { {0x27e60036,0x65610017,0xf777000b,0xb9980339}},	//   mmon_, _falh, _פעמי_, ивих_
  { {0xd1380010,0x29180fe1,0x63bb013a,0x645e2c0a}},	//   ugą_, úra_, čuni, _ospi
  { {0x6d55152e,0x2b8e0029,0x54a60012,0x23c80011}},	//   veza, _tých_, _احذف, लवाद
  { {0x8b650012,0x69c816ab,0x6e220034,0x9b650012}},	//   _وانم, sode, osob, _وطنه
  { {0x41e6002d,0x98b8003a,0x3b630012,0xa5f9003c}},	//   _ліка, ırı_, _رُوِ, регу_
  { {0x63ad0002,0xd0100003,0xd2570009,0xe8940109}},	//   wian, _قلت_, _לשדה_, _маль
  { {0xfbdf001a,0x6f040061,0x7d1a0269,0x291e2c0b}},	//   _phê_, _ffic, _mets, mata_
  { {0xdb090017,0x5215022a,0x6ab40011,0x8c1b0009}},	//   rneç, ждат, ंपूर, טולי
  { {0x6d550164,0x75280002,0x29012c0c,0x645e2a83}},	// [7f30] peza, _oddz, tcha_, _espi
  { {0x661d0028,0xeab1000b,0x291e2c0d,0x64432c0e}},	//   _æski, וֹב_, nata_, ytni
  { {0x66160002,0x98a7003a,0x2d852c0f,0xe8550012}},	//   _zwyk, _yanı_, _role_, تناد
  { {0x2d8515f2,0xdcee0066,0x9be4002d,0xe6950012}},	//   _sole_, žděn, _ніяк, يلاد
  { {0x28cf0044,0xdce8007a,0xb5fd04d2,0x2d852c10}},	//   _सुनि, _kodė, _krši, _pole_
  { {0x64430163,0xdb000051,0xdcfe001e,0x99800064}},	//   ttni, himä, _kopā, triť_
  { {0xef19003e,0xcfe90003,0x6b9b0028,0x11da0009}},	//   _też_, _نفسه_, thug, _כחשב
  { {0xd498000b,0x02050ad3,0x7d1a0034,0xfdf90011}},	//   מכות_, озин, ótsz, ंदास_
  { {0xfebb0003,0xd179002d,0xeab10003,0x0cd60037}},	//   _صارت_, асні_, بعث_, _धर्म
  { {0xc9a90015,0x41750012,0x291e2c11,0x54450012}},	//   рвое_, زاخس, gata_, _ونذك
  { {0xb9010044,0xc174000b,0xadf30037,0x7e6d2c12}},	//   _दर_, לחץ_, _इंजन_, _arap
  { {0xe7c90044,0xe73a1498,0x291e0051,0x27fc000e}},	//   िकिप, шем_, aata_, ívni_
  { {0x44310002,0xa2d00037,0xbddb01a0,0xfbd50011}},	//   erz_, _डुप्, rtèn, _डीएम
  { {0x291e1b8f,0xbddb0054,0x29010051,0xb606009b}},	//   cata_, stèn, _üha_, vašč
  { {0xab1a0015,0x6fc90011,0x5fc90011,0x27e00132}},	//   ицах_, िकां, िकाल, _thin_
  { {0x7e6d0061,0x230a0012,0x24530012,0x6db20034}},	//   _frap, شتري_, بنفس, ołac
  { {0xd5e40020,0x42260014,0x69c30029,0x645e0002}},	// [7f40] _trì, юдав, čnen, _wspi
  { {0x3f820027,0xa50a0001,0xb6062c13,0x854a0024}},	//   ljku_, _њена_, rašč, _тзов_
  { {0x645e0027,0xa0670048,0xfbd50011,0x7d1a2c14}},	//   _uspi, жаха_, _डीऍम, _rets
  { {0x3cef0037,0xf8b2000b,0x44382c15,0x291e2c16}},	//   ेखने_, ושב_, mur_, zata_
  { {0x7d1a0101,0xb51e0037,0x291e046c,0x44382c17}},	//   _pets, _बजाय_, yata_, lur_
  { {0x443803f6,0xdb020032,0xd5b30009,0x85040012}},	//   our_, _bloß, ֽׁה_, أوغن
  { {0x44381514,0xac970003,0x291e2c18,0x7d7b0009}},	//   nur_, ينها_, vata_, ינסו
  { {0x2480001c,0x60970003,0x77640054,0xccf3000b}},	//   ćim_, _بنفس_, _naix, וכו_
  { {0xc17a002d,0xef1f003a,0x7d1a000e,0xdcfa0012}},	//   аїн_, kkür_, _tets, _نفذت_
  { {0x44380f92,0x59dd0011,0x6c760012,0xfa770009}},	//   kur_, _नीदर, _وطائ, קעית_
  { {0x26180044,0x75e0000e,0x78fb007e,0x77640327}},	//   बीसी_, közb, יפיו, _baix
  { {0xd36f0003,0x77640c75,0x291e2c19,0xcfa70024}},	//   _لهم_, _caix, sata_, ішни
  { {0x44380108,0x35df0037,0x80ca0011,0x9f580025}},	//   eur_, _पीड़, _सुरे, _curé_
  { {0x4438014d,0x6d580005,0x44310002,0x0dcb0232}},	//   fur_, neva, trz_, руми_
  { {0x77640017,0x5f950015,0xb5fd0027,0x4c980009}},	//   _faix, _никт, _vrši, זֹּא
  { {0x2b910020,0x6d58229b,0x889b0009,0xe2f80024}},	//   _cách_, heva, _כבוי, жеті_
  { {0xdce8007a,0xdb11000f,0x4438001e,0x5a350014}},	// [7f50] _todė, áfér, aur_, янат
  { {0x89370003,0x6d580133,0xd5e4001a,0x306b0001}},	//   تعرا, jeva, _trí, ијен_
  { {0x291c0054,0x8d5a000b,0x2a690051,0x2b9c0064}},	//   _meva_, _הכתי, svab_, _síce_
  { {0xf7730003,0x9ee90003,0xe8d70009,0x6d58005e}},	//   باط_, مفضل_, חובר_, eeva
  { {0xee38002d,0x4b7a007e,0xddc40027,0xa3ab0011}},	//   жні_, _הארו, _hriš, कोण_
  { {0x2b9c0013,0x05a8002d,0xce38000b,0xf9fa000b}},	//   _více_, овій_, קאות_, _להשמ
  { {0xeb910003,0x6c350012,0xf5320009,0xdb0d0018}},	//   فظة_, أفعا, ׂ֥ה_, gnaç
  { {0x8c1c000b,0xe4c80012,0x94bc0009,0x6d58005e}},	//   בוהי, غبون_, ימות, aeva
  { {0xfbd4000b,0x46380012,0x5f440012,0xad9b0097}},	//   ותק_, _وأكد_, _تنقل, npús
  { {0x394500be,0x291c000d,0x39790015,0x443800b6}},	//   чног, _ceva_, ссию_, yur_
  { {0x48b50014,0x6fd62c1a,0x6db20034,0x6c740012}},	//   ящит, láci, słac, _يطمئ
  { {0x6db20002,0xb69b004b,0xa3db0011,0x8bb70012}},	//   płac, rcân, _ढील_, _بإطا
  { {0xa5bb2c1b,0x4444002a,0x63bb003a,0xdcb7001a}},	//   rsón, _sq_, mnun, ổng_
  { {0x2b910020,0xbbc40037,0x44382c1c,0xa5bb1356}},	//   _sách_, वक्क, tur_, uróp
  { {0x61fd0052,0xb97a0009,0x6ab40011,0x64590034}},	//   _ausl, _לנסי, ंप्र, _ćwic
  { {0x6fd613b0,0x61f5001e,0x501a000b,0x60dc0d33}},	//   káci, _aizl, _פופו, ürme
  { {0xc73b000b,0x44382c1d,0xa5bb0018,0x4f3b0009}},	// [7f60] _התפת, sur_, próp, _התפע
  { {0x63bb0052,0x4444001a,0x44382c1e,0x291c0018}},	//   hnun, _tq_, pur_, úva_
  { {0xacfb000b,0x2b91001a,0xd5e90003,0x6d582b3d}},	//   _להיכ, _tách_, _بعين_, veva
  { {0x7d1e003a,0x20070d04,0xd47b0009,0x6fd60018}},	//   _heps, ínia_, _האטל, fáci
  { {0xc333000b,0x63bb0052,0x6fd60570,0x6d582c1f}},	//   _אור_, dnun, gáci, teva
  { {0x61f500a2,0x51550015,0x7dd20058,0x24b6000b}},	//   _gizl, _отсу, mæss, ּהֵן_
  { {0x09e3007c,0x63bb0795,0x399b0009,0x6fd80064}},	//   _чорн, fnun, _פילד, níck
  { {0x291c03eb,0x58bb000b,0x7d1e0002,0x7bc40010}},	//   _seva_, _המלצ, _leps, čiuo
  { {0xdcfc0039,0xaa530015,0xd5b20012,0x6fd60018}},	//   nkrē, евыш, _كفر_, cáci
  { {0x7e9b0009,0xd5ed0081,0x569b0009,0x0e9b0009}},	//   _הסמו, _trả, _הימצ, _השמל
  { {0x0735002d,0x9f35002d,0x68050073,0xf8be0011}},	//   меню, мені, _kėda, ्थिय
  { {0x7ceb0009,0x48a7003c,0x29070097,0xf8af0012}},	//   _הַדֶ, ятым_, _efna_, اةٌ_
  { {0xbddb0108,0x291c03eb,0x645a003a,0xe8b90011}},	//   stèm, _teva_, çtin, _आश्च
  { {0x24670066,0xf8be0037,0x61fd2c20,0xddc42c21}},	//   jímá_, ्थाय, _rusl, _priš
  { {0x58d302e2,0x6fd6120b,0x28ac0011,0xf1a90012}},	//   _пошт, záci, _टेलि, _بانه_
  { {0x61fd039c,0x58bb000b,0x00bb000b,0x88bb0009}},	//   _pusl, _למוצ, _למומ, _למוז
  { {0x6f7a0009,0xd2510012,0x6fdd0025,0x51f8003c}},	// [7f70] _וְיו, ضنا_, léco, зную_
  { {0xd1310003,0x213e002a,0x660d002c,0x6fd60fe1}},	//   ئما_, ngth_, _itak, váci
  { {0xe2f9002d,0xf8b10009,0x99840012,0x4af90fdf}},	//   _мені_, ֣שׁ_, علمو, _меню_
  { {0xa8180003,0x9ed90001,0xdef10012,0x63bb02a1}},	//   ستمر_, омет_, نًا_, čuns
  { {0xb8d40011,0x7bc40073,0x64dd0011,0x6fdd0025}},	//   _जे_, čiul, _यरुश, héco
  { {0x6fd6120b,0xddc90002,0xdb04000e,0x8a7a0009}},	//   ráci, _speł, zniü, _ואשת
  { {0x22490dcc,0xbd480012,0x23691577,0xa3e906d7}},	//   ltak_, سؤول_, odaj_, одка_
  { {0xdfd1000a,0xcc780009,0xc49c0009,0x8c1c0009}},	//   _شيء_, לגות_, משות, זוהי
  { {0xeab10003,0xa1350003,0x63bb1022,0x22492c22}},	//   ضعة_, وردش, rnun, ntak_
  { {0x2fcf07c7,0xf9910012,0x6d41001b,0x82880009}},	//   logg_, ئبة_, _ucla, לְתֶ
  { {0xa3bf0037,0x75232c23,0x04950012,0xf9920009}},	//   ेवा_, manz, _تلاح, דרי_
  { {0x26140037,0x75232c24,0x6be40012,0xbc380012}},	//   नीकी_, lanz, _ككلم, _رسما_
  { {0xd9450046,0x59bf0037,0xa3ca0037,0x61450104}},	//   _жели, ्वार, लकर_, _жела
  { {0xe9ff0020,0xe1ff003e,0x61fd022d,0x22490af2}},	//   _hoặc_, _osób_, íslu, dtak_
  { {0xe5020044,0x8d630048,0x33f60024,0x6db20034}},	//   रुटि_, ъвре, дчас, kłan
  { {0xee3a085b,0x09c60037,0x1efa0012,0x98c50030}},	//   _дни_, वव्य, _بعثة_, štět_
  { {0x6d4f0028,0x68080066,0xe6c60003,0x3cfa0012}},	// [7f80] únað, _věde, _تتغي, _وعدد_
  { {0x7e64002c,0x6b8b005b,0xa09a0012,0x2366001b}},	//   _isip, _logg, يضاء_, žoj_
  { {0x77660098,0xca29000b,0x757b0009,0x7d7b0009}},	//   дълж, שם_, _וטיפ, _וניו
  { {0xf413000b,0x6b8b006f,0x917b0081,0x6d5c2c25}},	//   _שפר_, _nogg, _lề_, lera
  { {0x5e5a0012,0xe5c60f28,0x75232c26,0x6fd82c27}},	//   تجاج_, мско, fanz, níci
  { {0x2d98000f,0x6db2003e,0x661b0002,0x7c3c0061}},	//   nkre_, ałan, _dwuk, ourr
  { {0x84e80011,0x6ca30048,0xcdb70009,0x6f090025}},	//   टेंट_, кръж, ופסה_, _ffec
  { {0x93fb0009,0xc0e30a32,0x2bac0034,0x256d0031}},	//   חלקי, _роск, ości_, völő_
  { {0xfbd3000b,0xc3330009,0x75460048,0x6d360012}},	//   כתה_, דוח_, _оназ, _يفرض
  { {0x67360002,0xb33b003a,0xc27b000b,0x75232ac7}},	//   łają, _ilçe, קריי, canz
  { {0x3137000b,0xe8df0020,0x0137000b,0x99d30003}},	//   ונים_, _thời_, ורית_, ختيا
  { {0x660d0034,0x443c005e,0x2d8c00b0,0x4c250012}},	//   _ptak, muv_, _hode_, _أعلِ
  { {0x4ae20044,0x02e20044,0x7d770003,0x91860012}},	//   _परिव, _परिभ, واسط, _يجتم
  { {0x28cf0044,0x31670052,0xa5bb0028,0xdcfa0002}},	//   _सुवि, _ganz_, msók, _potę
  { {0x0cd42c28,0xa4d4002d,0x6db20002,0x2d8c1f25}},	//   ворю, ворі, yłan, _mode_
  { {0x69da0883,0x22492c29,0x6d5c00b6,0x2d8c2c2a}},	//   llte, ttak_, aera, _lode_
  { {0xa3ab0044,0x45d527a8,0xe8df0020,0x657a0070}},	// [7f90] कोष_, _поис, _khởi_, _onth
  { {0xe5e70003,0x917b001a,0x3ea6001e,0x20070017}},	//   _تثبي, _kế_, dzot_, ínio_
  { {0xb907015f,0xa3be0037,0xe7190012,0xa3de0011}},	//   _पर_, ँचा_, كيات_, णता_
  { {0x2d9e2c2b,0x69da0052,0x671f0011,0x9f050012}},	//   _alte_, hlte, परिक_, روتو
  { {0xe618002d,0xa50916e6,0x1d0900db,0x67200032}},	//   дді_, пела_, пели_, _demj
  { {0x7bc20108,0x6db2003e,0xa3ab0037,0x6b8b00c1}},	//   _ajou, słan, कोर_, _sogg
  { {0x6fd8117f,0x351c0009,0x6db20034,0x98be0073}},	//   zíci, חוונ, płan, metė_
  { {0x61c70044,0x657a0f5c,0x36d5002d,0x6fd60066}},	//   रक्ष, _enth, _зобр, náct
  { {0xf7480003,0x3e350003,0x7c3c00b8,0xa3c00011}},	//   _تلقي_, _سفار, zurr, ूक़_
  { {0x6d5c2c2c,0x2d8c0a3b,0x65150012,0xdd150012}},	//   xera, _gode_, _أوائ, _أواخ
  { {0x917b0020,0x2bcc0037,0xf74601b6,0xe9a80012}},	//   _về_, ावशा, нено, بدين_
  { {0x6fd80e23,0x2bac0002,0x2d87017b,0x34940198}},	//   tíci, yści_, ljne_, _шахр
  { {0x9f96000b,0xf6d5002d,0x98be0010,0x99840010}},	//   גדרה_, віря, ketė_, gumų_
  { {0x7521000e,0x61450ec6,0x6d4e0032,0xb5fb0031}},	//   _jelz, _чека, ufba, evás
  { {0x6d5c0163,0x3a29003a,0xc1780010,0x2edc0011}},	//   rera, esap_, amės_, _बर्त
  { {0x8646002d,0x69d50052,0xd00e0003,0xb5fb2c2d}},	//   _зниж, _akze, _الي_, gvás
  { {0x211a0003,0xdb0f000e,0xfaa30400,0x52aa0048}},	// [7fa0] كتاب_, ájár, гато, чвам_
  { {0x75210013,0xcee90003,0x7c3c0420,0x28be0011}},	//   _nelz, _غرين_, purr, ्थलि
  { {0xe8df001a,0x2d8c20bd,0xc9520009,0xe58b0009}},	//   _khối_, _rode_, רמב_, _זָכָ
  { {0xd6d9003e,0x6db20002,0xa8a80009,0x03a60472}},	//   _był_, ałal, וֹנִ, _чимо
  { {0x2d8c05ab,0x76410010,0xa3bf0011,0xb5fb2c2e}},	//   _pode_, ąlyg, ेवर_, lvár
  { {0x443c005e,0x046600b5,0xd6cf0012,0x3ea62c2f}},	//   tuv_, етим, حقه_, rzot_
  { {0x71d7000b,0x6fd6000e,0x94d30001,0x2d8c27dc}},	//   _נולד_, nács, лошц, _vode_
  { {0xddc9000d,0x94730003,0x69da0052,0xfc570009}},	//   _preţ, ادوا, wlte, תבקש_
  { {0xdbc70051,0x2d8c0052,0x8fa3115e,0x6568020d}},	//   _tööh, _tode_, _сате, _tadh
  { {0xddc9007d,0xe4d60003,0x7a530012,0xc5690012}},	//   _vreţ, _كتاب, اضيا, _يحلل_
  { {0xc953000b,0x3cfa0011,0xc19b0009,0xb3b80011}},	//   אמת_, ंशों_, פשטי, ्कफ़्
  { {0xe8df0020,0x6d450518,0xc0530009,0x4c9b0009}},	//   _chối_, _scha, נזר_, _משבע
  { {0xd6db06e0,0x7f5d2c30,0x8fa40012,0xebe30198}},	//   ято_, resq, امُه, _соцп
  { {0x917b001a,0xa6db0028,0x99800010,0x63a401b7}},	//   _tế_, ggða, irių_, ehin
  { {0x6fd80164,0xa3bf0037,0x21670001,0xa9670001}},	//   lícu, ेवल_, _чији_, _чија_
  { {0xa3ab0044,0xd8db000b,0x80db000b,0x7bc00033}},	//   कों_, _מקור, _מחוז, nnmu
  { {0xdb040065,0x2d870002,0x99890029,0x3a29002c}},	// [7fb0] rnið, yjne_, hrať_, usap_
  { {0x63a4002c,0xdb040028,0xdebc0009,0xb6bc0009}},	//   ahin, snið, _ממחל, _מצחי
  { {0xbb1b0108,0x6fd80164,0x31c405fb,0xa9c40024}},	//   _boît, hícu, уств, устк
  { {0xdb07004a,0x2a660066,0x6db20034,0xf1c20035}},	//   ämät, _osob_, słal, ekšā_
  { {0x8e08002d,0x99890857,0x49bb0012,0x6db20034}},	//   енів_, erať_, _فاسد_, ałam
  { {0x395e0061,0xc58b003c,0x200e01a0,0xdb0d01a0}},	//   jets_, ящее_, ífic_, liaà
  { {0x65920001,0x917b001a,0xd4660511,0xcd280012}},	//   рају, _lễ_, вище_, رسون_
  { {0x58d40047,0x77d70003,0xbc7c000b,0x442c2c31}},	//   _сост, _أغسط, לנות, _dvd_
  { {0xab760003,0x395e0007,0x4222003c,0xdcfe001b}},	//   ئمًا_, fets_, адыв, _uopć
  { {0x6f0d007d,0x7bdb0065,0x99890026,0x6fdd0061}},	//   _afac, sluu, brať_, léch
  { {0x8fa60098,0xe8df0020,0x07a600be,0xddc90027}},	//   ване, _phối_, ванн, _greš
  { {0x00f6000b,0x29180028,0x23640012,0x27e92c32}},	//   כמתך_, ðrar_, _مهمّ, _chan_
  { {0xe28e00bc,0x16630014,0xfa370012,0x9f460032}},	//   _та_, авям, _أرصد, hloß_
  { {0x6d430101,0xceb2000b,0x917b001a,0x26060017}},	//   ngna, שיך_, _dễ_, _vôo_
  { {0x63a40036,0xb5fb0029,0x224d000e,0x98a2002d}},	//   thin, tvár, ltek_, _вище
  { {0x25e80037,0x6b89009b,0x99800010,0x6fd80029}},	//   _चीनी_, njeg, yrių_, níct
  { {0x224d000e,0xb1460048,0xb5fb0031,0xff5f0025}},	// [7fc0] ntek_, кнал, rvár, roît_
  { {0xd5af000a,0x6db20002,0x69c10993,0x957c0034}},	//   _وفي_, ałaj, nnle, _wiąz
  { {0x98b100a2,0xd59b000b,0xdca6035c,0xd8170024}},	//   _bazı_, _חביל, _рани, воєї_
  { {0x224d0182,0xd00f0012,0x90e50012,0x6d432c33}},	//   ktek_, زله_, اسكن, egna
  { {0x4733002d,0x06540003,0x99800010,0x7f830012}},	//   рніс, انتح, urių_, شلون
  { {0xdd8f000a,0xd6930046,0x35b60014,0xde930001}},	//   يون_, ришћ, ъщес, рашњ
  { {0x75e0000e,0x6c840012,0x03c60a2e,0x67e3005e}},	//   vözl, العم, ксим, sõja
  { {0x6fd802d1,0xfbcf0003,0x68e32c34,0xafe6002d}},	//   tícu, يتي_, ünde, _робл
  { {0x6027000f,0xc5660001,0x7d0f0081,0x61fc0060}},	//   _témá, _икак, _đcsv, _kirl
  { {0xddc9001e,0x69c10028,0x49730109,0xec7a0024}},	//   _treš, gnle, альс, _опз_
  { {0x25d7000b,0x6b890027,0x993b000b,0x493b000b}},	//   _יומן_, bjeg, ותיה, וגיו
  { {0x67220011,0x23ba0035,0xdb04005e,0x75e00060}},	//   मरिक_, tīju_, oniõ, sözl
  { {0x539b000b,0xd337000b,0x28d90037,0x395e2c35}},	//   _קידו, _יראה_, _बुनि, pets_
  { {0xe5c4003c,0x60a60012,0x66040227,0x2a570009}},	//   ассо, _لإبق, _duik, _סבון_
  { {0x27e903f2,0x7527000e,0xd404005c,0x1df8003c}},	//   _than_, rajz, ияти, теры_
  { {0xddcd004b,0xd0f70009,0x61fc2c36,0x69de2c37}},	//   _braţ, _במות_, _airl, elpe
  { {0x61fc00a2,0xd6d10012,0xc6f90024,0xb9550048}},	// [7fd0] _birl, _دقة_, _яних_, лващ
  { {0x6fdd190a,0x89340012,0xb1140024,0x61bf0011}},	//   déci, لعما, имуш, ्वेष
  { {0x351a000b,0x224d000e,0x6801001e,0xdb000034}},	//   _אותנ, ztek_, _pēdi, nimó
  { {0x6fd4002d,0xff530003,0x224d1396,0xe7300012}},	//   аціє, شخص_, ytek_, قصه_
  { {0x69c10028,0xf7700003,0x6fdd0061,0x61fc0028}},	//   ynle, تال_, réch, _firl
  { {0xdce800a2,0x63a210ab,0x69cb000e,0x58050003}},	//   _aldı, _alon, éged, _موسك
  { {0x26d2003a,0x7a47001e,0x45340024,0x200a0030}},	//   üyor_, sūtā, рхіт, íbil_
  { {0x0456000a,0x224d000f,0xdfd50015,0x24890027}},	//   الية_, ttek_, _собы, ćam_
  { {0xc7b20009,0xd24e0012,0xd1b90012,0xef1f0031}},	//   _הבן_, كني_, فادا_, rjül_
  { {0xef26005e,0x64682c38,0xa0350009,0xd49b0d21}},	//   _üüri_, äsiä, ְאָה_, _оре_
  { {0x6aa9000e,0x224d2c39,0xdb090248,0x66042c3a}},	//   szef, stek_, tieä, _suik
  { {0x66040010,0xa3de0011,0x39960097,0x224d0b89}},	//   _puik, णतः_, _hæst_, ptek_
  { {0x479a0009,0xd7ba0009,0x9b740012,0x2bc705f3}},	//   גירס, תֶיך, _خالص, रचना
  { {0xe8e0001a,0x26de001e,0x1dc30011,0x04460048}},	//   hiều_, āto_, वचित, легн
  { {0x8c95002d,0xc9520009,0x26180011,0x644e0248}},	//   арті, _המו_, बीजी_, utbi
  { {0xcb670046,0x38780058,0x39960399,0xe5140011}},	//   ласе_, ærre_, _læst_, _त्रि_
  { {0xade30044,0x3a2d00b6,0x4e1d0037,0x39ea004c}},	// [7fe0] गतान_, nsep_, बीआई_, едао_
  { {0x8d66005c,0x22400070,0xd5ed001a,0x39960028}},	//   _свое, ruik_, _trá, _næst_
  { {0x9476000a,0xb5f7000b,0xf99f0054,0x85f70009}},	//   _إدخا, _תציג_, _atès_, _תציע_
  { {0x8f450024,0xdd2f0030,0x46a60337,0xddcd0c71}},	//   ихід, měři, лаев, _iraš
  { {0xc7d7000b,0x9f8b0051,0xe2970048,0x6d4103d1}},	//   נוני_, _tööl_, _бая_, ólag
  { {0x01da0012,0xdb00005e,0x7bc42c3b,0xdd900012}},	//   _أوسع_, simü, lniu, توت_
  { {0xa5bb090d,0x07040011,0x89db0009,0xa9230030}},	//   msót, रखाव_, _נחלי, ížec
  { {0xb8f80037,0x6fdd10b7,0x5a3407d1,0xbddb0025}},	//   ाथ_, péci, анит, ntèr
  { {0x6f930003,0xf1260094,0x7bc40010,0x39960097}},	//   _القض, льно, iniu, _fæst_
  { {0x865b0009,0x76420060,0x92570012,0x39960040}},	//   _אדמי, muoy, اشير_, _gæst_
  { {0x68080066,0x23bf004a,0x9b460012,0x8afd0030}},	//   _vědo, näjä_, _مناو, veře
  { {0xb8ec0037,0x7c2e0058,0xf8b3000b,0x5ba50024}},	//   _रख_, dsbr, משת_, _кріз
  { {0xef1f000f,0x9f920065,0x3f800002,0xdb0d0017}},	//   ljük_, ráð_, _dniu_, liaç
  { {0xad9d0002,0x16190011,0x6fc80060,0xddcd09ef}},	//   _luźn, नीटर_, rıca, _braš
  { {0x2b9c0020,0xef1f000e,0x11db0009,0x2c340009}},	//   _kích_, njük_, _רחוב, יָּם_
  { {0xc2c50003,0x40eb000b,0xa4b70009,0xdc8b0009}},	//   ليزي, _אַחֲ, אללה_, תְךָ
  { {0x645c005e,0x9f980009,0x8afd0030,0x75e00031}},	// [7ff0] _ärif, _תדחה_, peře, közh
  { {0x7de70012,0xa2c50011,0xef1f0031,0x6f1d0032}},	//   _حسبم, ापत्, kjük_, lbsc
  { {0x45fa000b,0x15fa0009,0x3d080011,0x7ae20035}},	//   _שהתג, _שהתע, िखने_, ļota
  { {0xbddb0108,0xe8d7000b,0x6d470028,0x291c0028}},	//   ctèr, נואר_, lgja, ðvar_
  { {0x36691f10,0xe8e00081,0xe56e07a7,0x75e00031}},	//   тало_, riều_, оз_, fözh
  { {0xd6180003,0x6d470f92,0xa3bf0011,0xed590ed4}},	//   اتنا_, ngja, ेवक_, ток_
  { {0xcd98000b,0xa9880009,0x96260035,0x6d470097}},	//   רדות_, _עָשִ, _ziņā, igja
  { {0xf8b2000b,0x6b8d00b6,0x425505fb,0x69c60031}},	//   _ושל_, njag, атот, éken
  { {0xe6100003,0xe29f0028,0x69c50d7b,0x672b0031}},	//   _فشل_, áð_, onhe, magj
  { {0x69c52c3c,0xc5fb0012,0x7bc40031,0x499509c2}},	//   nnhe, _أعرض_, zniu, ршит
  { {0xdb0d0017,0xbfc6002d,0x27ed001a,0x69c5148a}},	//   ciaç, ибок, _khen_, inhe
  { {0xe8d6000b,0xc5e9000b,0xdd2f0066,0x141a0009}},	//   יותר_, _חד_, věři, _יועב
  { {0x539a0093,0xc7d6000b,0x63a91dbd,0x95960024}},	//   _שינו, שורי_, mhen, ашві
  { {0xddcd039c,0xdee3002d,0x61420001,0x6d470028}},	//   _praš, іори, _деша, ggja
  { {0x1c390800,0x232a05fb,0x91ba0009,0xcce50012}},	//   лять_, кови_, _שמצי, مسفي
  { {0xda08001a,0xd2520012,0x63a92c3d,0x3326005e}},	//   _hỏa_, ينز_, nhen, _xeox_

  };

static const uint32 kQuadTableInd[11326] = {
  // [0000]
  0x00000000, 0x00001e0f, 0x00000c0f, 0x0000370f,
  0x12004512, 0x0000191c, 0x0000041c, 0x38000512,
  0x451d4012, 0x00000706, 0x0000371c, 0x0000070f,
  0x05001412, 0x0000170f, 0x0000180f, 0x0000181c,
  // [0010]
  0x0000160f, 0x00002406, 0x00003706, 0x0000121c,
  0x00001c0f, 0x00000e0f, 0x17000822, 0x00000d0f,
  0x00000d06, 0x00001c2d, 0x0000430f, 0x00001d06,
  0x00001d1c, 0x0b000412, 0x0000150f, 0x21001912,
  // [0020]
  0x0000431c, 0x23000e12, 0x05000621, 0x1d450c21,
  0x00002306, 0x00000506, 0x0000451c, 0x00001d0f,
  0x0000140f, 0x0000450f, 0x0000010f, 0x27001914,
  0x0000210f, 0x0000230f, 0x06001911, 0x030b0221,
  // [0030]
  0x00001206, 0x00001806, 0x00000606, 0x00000b0f,
  0x00000c06, 0x00001506, 0x0000011c, 0x0000240f,
  0x19000414, 0x0000151c, 0x0000220f, 0x21002711,
  0x00000e06, 0x40001611, 0x00000c1c, 0x18000c20,
  // [0040]
  0x00000206, 0x01060407, 0x45001214, 0x020b14be,
  0x0000241c, 0x06020107, 0x00001e1c, 0x00000e1c,
  0x00001c06, 0x03001d12, 0x0000040f, 0x00001706,
  0x00001e06, 0x0e001c14, 0x06002212, 0x0f0d05a4,
  // [0050]
  0x0e231e09, 0x0000190f, 0x0000060f, 0x18000c13,
  0x0000380f, 0x0e002313, 0x0f000d12, 0x06102760,
  0x0000020f, 0x06100d12, 0x080f04ad, 0x020b1023,
  0x1c000e22, 0x27180321, 0x00001906, 0x0e1c1e11,
  // [0060]
  0x00002206, 0x0000050f, 0x01432121, 0x1c000e13,
  0x00004506, 0x0000141c, 0x0000120f, 0x16004511,
  0x06001412, 0x1e0e2360, 0x0c011621, 0x14001613,
  0x041d4020, 0x21000122, 0x03000411, 0x0000100f,
  // [0070]
  0x0000030f, 0x15001612, 0x22180312, 0x00001606,
  0x14001812, 0x1c000e20, 0x0c19046f, 0x21270112,
  0x06031012, 0x04001613, 0x0000161c, 0x27001612,
  0x0000231c, 0x0000171c, 0x0000070a, 0x03060513,
  // [0080]
  0x080d0112, 0x00004306, 0x40001d23, 0x0e001c11,
  0x0b000312, 0x14220420, 0x1e1c0e12, 0x03000112,
  0x01050314, 0x14002221, 0x0000432d, 0x0000061c,
  0x191422bc, 0x170416be, 0x00000406, 0x38000b08,
  // [0090]
  0x27191612, 0x14002213, 0x2221196f, 0x0000071c,
  0x0e002323, 0x05192221, 0x451d1511, 0x00001406,
  0x00001c1c, 0x0b000c09, 0x0c000311, 0x0000400f,
  0x0d002212, 0x380f0d13, 0x12004508, 0x02001011,
  // [00a0]
  0x0c011712, 0x0000222d, 0x0000221c, 0x220f0d21,
  0x19000434, 0x05000111, 0x230e1c12, 0x06001420,
  0x19000612, 0x40000b20, 0x05001607, 0x1e230e07,
  0x23001c12, 0x10000b12, 0x00003701, 0x00000701,
  // [00b0]
  0x00000b06, 0x060127ad, 0x380f0512, 0x0e002312,
  0x03001920, 0x1c001e07, 0x0000270f, 0x38000507,
  0x00000806, 0x04001922, 0x01050812, 0x1e000e12,
  0x0000232d, 0x0000031c, 0x0e002322, 0x00000724,
  // [00c0]
  0x0e002320, 0x0000080f, 0x06380455, 0x060119a4,
  0x00000000, 0x0000021c, 0x0000271c, 0x06000311,
  0x01001921, 0x05401955, 0x03001911, 0x19030112,
  0x01030613, 0x0000150a, 0x0f000d09, 0x08180509,
  // [00d0]
  0x00001201, 0x0d000b34, 0x14000213, 0x080d1007,
  0x05000114, 0x06050160, 0x03020621, 0x40150112,
  0x0b190412, 0x45001213, 0x03001412, 0x0e1c1e12,
  0x1c230e21, 0x050106af, 0x1c000e12, 0x27000612,
  // [00e0]
  0x12060112, 0x01050607, 0x0b000222, 0x00000e2d,
  0x0f1922be, 0x19001012, 0x19000413, 0x27001712,
  0x03002207, 0x0d001807, 0x22001920, 0x40001d13,
  0x0000272d, 0x06002711, 0x180414bb, 0x231e1cad,
  // [00f0]
  0x1d000307, 0x12004523, 0x43001814, 0x05000321,
  0x1c1e23ad, 0x1e001c13, 0x03000513, 0x0c000612,
  0x0b101921, 0x0f184513, 0x0e002311, 0x030104ad,
  0x1e0e1c60, 0x21000414, 0x19053821, 0x04001912,
  // [0100]
  0x18002211, 0x0000211c, 0x0c001811, 0x1e001c14,
  0x0e001c22, 0x040119ad, 0x03000521, 0x45001223,
  0x0000051c, 0x23000e13, 0x21002713, 0x0e001e11,
  0x0e001c12, 0x03010412, 0x04002121, 0x06000c07,
  // [0110]
  0x060b0212, 0x43010407, 0x06000c12, 0x16001523,
  0x19000314, 0x22002112, 0x06272112, 0x180b0212,
  0x19000b14, 0x00000b1c, 0x1d1708bc, 0x19000b21,
  0x05001612, 0x0e001e13, 0x14000b11, 0x1c001e22,
  // [0120]
  0x06000c11, 0x12004014, 0x27192112, 0x0c001812,
  0x120d0f12, 0x0b020322, 0x0c124021, 0x270508ad,
  0x03100612, 0x1e002314, 0x0c000622, 0x10001812,
  0x10000b36, 0x19000b20, 0x0000401c, 0x05001621,
  // [0130]
  0x40001513, 0x21190112, 0x00000106, 0x1d004022,
  0x180f12af, 0x18124521, 0x0e1c1e6f, 0x18000412,
  0x1e230e21, 0x0b001611, 0x40001d14, 0x0e1c1e21,
  0x1d001513, 0x22002713, 0x0b001013, 0x0b001012,
  // [0140]
  0x0b000622, 0x020d0f6f, 0x14001011, 0x0c012212,
  0x1d000211, 0x45001221, 0x1e001c22, 0x1e1c2313,
  0x0e001c07, 0x00000d1c, 0x45001222, 0x010c0407,
  0x05120da4, 0x0000142d, 0x05001811, 0x0b000211,
  // [0150]
  0x1d001907, 0x16000113, 0x031006ac, 0x080b1012,
  0x06001912, 0x08011712, 0x05001814, 0x270118bb,
  0x08170121, 0x00004006, 0x0000072d, 0x45001211,
  0x02170821, 0x12004521, 0x19000422, 0x0000242d,
  // [0160]
  0x27002122, 0x27002133, 0x020619af, 0x0000101c,
  0x00000f0f, 0x14151711, 0x03000609, 0x27002120,
  0x01000611, 0x12000611, 0x03000607, 0x020b10bc,
  0x271916af, 0x00002706, 0x1c230e13, 0x011714ad,
  // [0170]
  0x230e1ebe, 0x1d182212, 0x1019016f, 0x1c230e11,
  0x19062712, 0x27002121, 0x04001921, 0x23001e11,
  0x271d21be, 0x27000421, 0x12001807, 0x1d004014,
  0x10061710, 0x27172112, 0x02030612, 0x1d451211,
  // [0180]
  0x0f000312, 0x18020612, 0x18002713, 0x191417ac,
  0x01000311, 0x01003821, 0x041417bc, 0x0e1c2311,
  0x0e1e23bc, 0x1e000e07, 0x14004513, 0x210f2712,
  0x22181060, 0x013815ad, 0x020b1009, 0x0f000813,
  // [0190]
  0x19002712, 0x0b002212, 0x0b000213, 0x16151921,
  0x04002734, 0x19152721, 0x040d2721, 0x02101912,
  0x0e002307, 0x162740ad, 0x19000412, 0x04192712,
  0x0e1e1c07, 0x19004021, 0x01003813, 0x01003812,
  // [01a0]
  0x00003806, 0x0b401d23, 0x0000081c, 0x04001914,
  0x06001907, 0x19140421, 0x01002107, 0x18001d11,
  0x18451220, 0x01000212, 0x18000b12, 0x0000102d,
  0x19154021, 0x27001020, 0x0c001d12, 0x04151921,
  // [01b0]
  0x00000703, 0x02142760, 0x120c1d08, 0x0000172d,
  0x27000b12, 0x1d0d0f12, 0x1c002312, 0x19002713,
  0x1c1e0ebc, 0x17001510, 0x03050111, 0x061440bc,
  0x22124560, 0x12004514, 0x03061414, 0x1d004522,
  // [01c0]
  0x05192207, 0x0d030607, 0x45000d12, 0x051917af,
  0x0000180a, 0x0f000d14, 0x0e002309, 0x24004112,
  0x0d190822, 0x101d4023, 0x380503af, 0x06000308,
  0x401822ac, 0x0f004011, 0x121d4512, 0x18001412,
  // [01d0]
  0x0b0201be, 0x06121712, 0x16001d14, 0x16061412,
  0x0e002314, 0x01000421, 0x19003820, 0x38000d14,
  0x1d1510be, 0x0d041807, 0x06010512, 0x27060321,
  0x17162121, 0x38170512, 0x1e0e1cad, 0x221903a4,
  // [01e0]
  0x06000314, 0x24004122, 0x010d3812, 0x00000f06,
  0x0000032d, 0x0000212d, 0x40102722, 0x0d1927af,
  0x0c190312, 0x12004513, 0x27002112, 0x0f002712,
  0x23000e11, 0x011d17ad, 0x05080f6f, 0x1c002311,
  // [01f0]
  0x1d000813, 0x0f210612, 0x38000521, 0x010f0daf,
  0x380d05be, 0x080f0512, 0x01000c11, 0x01380521,
  0x0d040612, 0x0f001913, 0x0f380521, 0x02000b21,
  0x0b0f0812, 0x140108ad, 0x160f21ad, 0x15001621,
  // [0200]
  0x1d400b21, 0x0f380d22, 0x0b000611, 0x05001712,
  0x020b0621, 0x0b100312, 0x43010612, 0x38000522,
  0x0000140a, 0x231c1e21, 0x0f000521, 0x06000412,
  0x38000513, 0x00002106, 0x0e001e14, 0x1c0e2355,
  // [0210]
  0x231c0e6f, 0x371c1e6d, 0x02061812, 0x15001614,
  0x00000715, 0x0f040513, 0x1c1e23a4, 0x1e0e1c07,
  0x27000420, 0x050f0412, 0x401d12af, 0x19000112,
  0x0b0238af, 0x0f000420, 0x10000b14, 0x120118ac,
  // [0220]
  0x45001d07, 0x10050212, 0x06001811, 0x23000e07,
  0x05000207, 0x27002212, 0x0f030112, 0x00000306,
  0x010504be, 0x1e0e1c12, 0x0e001c13, 0x140b0223,
  0x03040512, 0x12004522, 0x1c002320, 0x180f0420,
  // [0230]
  0x210b0220, 0x02001414, 0x23001c13, 0x05010d12,
  0x451218a7, 0x0d001013, 0x10001820, 0x0e1c1e20,
  0x15004012, 0x0e1c1e13, 0x04081812, 0x1d124008,
  0x1d000f21, 0x10005135, 0x21000f13, 0x40000f12,
  // [0240]
  0x04001410, 0x10000b35, 0x451218bb, 0x0c1d4022,
  0x03000407, 0x06001007, 0x01061daf, 0x230e1c21,
  0x00001006, 0x18000f09, 0x12001811, 0x050d0cac,
  0x0b000223, 0x1e1c2312, 0x1d001213, 0x06050107,
  // [0250]
  0x15000c14, 0x04000321, 0x0c001222, 0x1d000513,
  0x1c0e1e11, 0x010605bb, 0x034504a4, 0x1e1c0ea4,
  0x01000411, 0x15001622, 0x18081921, 0x45121821,
  0x230e1cac, 0x19452712, 0x40004514, 0x12001920,
  // [0260]
  0x0b000214, 0x19044022, 0x02000b13, 0x01030cac,
  0x0e231c12, 0x1d190460, 0x0c1619be, 0x45001d20,
  0x0e2337ad, 0x04001913, 0x18044060, 0x0f003807,
  0x14450c21, 0x0e1e2312, 0x18001913, 0x01004507,
  // [0270]
  0x06001507, 0x120d1810, 0x0000182d, 0x16001920,
  0x0000012d, 0x1d041921, 0x231c1e23, 0x06041612,
  0x0c001713, 0x0c061912, 0x210201be, 0x12000112,
  0x1d401712, 0x06001711, 0x04000612, 0x23000e14,
  // [0280]
  0x43180113, 0x231c1e13, 0x15190412, 0x08040609,
  0x17000d12, 0x08000113, 0x160414af, 0x080b0112,
  0x230e1caf, 0x27001921, 0x1d190113, 0x1c0e2307,
  0x0c0d27bc, 0x0e231ebc, 0x10000b23, 0x21190121,
  // [0290]
  0x14001720, 0x1c1e2320, 0x14272222, 0x08380112,
  0x1c001e14, 0x01212721, 0x02001036, 0x2227216f,
  0x38001012, 0x0d212721, 0x22002712, 0x1e001c21,
  0x1d000407, 0x45001812, 0x21000120, 0x1d001512,
  // [02a0]
  0x21002712, 0x1d004013, 0x06000307, 0x0f0d03af,
  0x03000636, 0x0d002712, 0x38140521, 0x01030b22,
  0x121d0cad, 0x0f000412, 0x1d001608, 0x0e1c2314,
  0x23001c11, 0x1c000e14, 0x17000307, 0x0b040260,
  // [02b0]
  0x05381060, 0x05000d21, 0x14001820, 0x060538bc,
  0x01081612, 0x0000052d, 0x03010533, 0x17002712,
  0x08001707, 0x19000607, 0x0e1e1c14, 0x1c230e22,
  0x10003813, 0x19000423, 0x05003821, 0x451d12cf,
  // [02c0]
  0x05100407, 0x15160312, 0x27001722, 0x06000113,
  0x1c0e23be, 0x10003822, 0x03020b20, 0x38001022,
  0x02103813, 0x45000c09, 0x23001c22, 0x38001013,
  0x080b0233, 0x120c1d21, 0x08021760, 0x1d021512,
  // [02d0]
  0x0c451213, 0x00000f1c, 0x02001412, 0x0e1e1c6f,
  0x0d0119ad, 0x08050112, 0x0f0b1812, 0x19100121,
  0x060b0821, 0x17272120, 0x22000512, 0x27004514,
  0x14000612, 0x01001007, 0x041827ad, 0x1d002713,
  // [02e0]
  0x12000c14, 0x100601be, 0x23001e22, 0x23001e13,
  0x050601af, 0x170127be, 0x0f000113, 0x45004021,
  0x21030121, 0x05000133, 0x18000f11, 0x10001913,
  0x0f0d0112, 0x0b000122, 0x18000520, 0x06000122,
  // [02f0]
  0x03000b21, 0x06001012, 0x031d0407, 0x38001d20,
  0x231e0e20, 0x404503be, 0x1d000122, 0x18002213,
  0x0406105e, 0x38000611, 0x160145ac, 0x27001911,
  0x0f0b0207, 0x03000b08, 0x04001012, 0x02000413,
  // [0300]
  0x1d003820, 0x19000213, 0x24004135, 0x050f19ce,
  0x0b001911, 0x43211420, 0x1c000e07, 0x0c162712,
  0x0e231e60, 0x18001421, 0x0f002211, 0x010605ad,
  0x0f180811, 0x0d0f0112, 0x15221914, 0x06002211,
  // [0310]
  0x084519af, 0x17051d12, 0x04002112, 0x1e231cad,
  0x153840bc, 0x17212212, 0x16020b22, 0x05000f12,
  0x04000d11, 0x210f04ac, 0x0f001720, 0x19042721,
  0x0c000407, 0x10000612, 0x0e1e1c22, 0x0c000614,
  // [0320]
  0x270c4513, 0x24004113, 0x03001813, 0x0d000536,
  0x02101734, 0x05001422, 0x17000535, 0x0d003823,
  0x0c004012, 0x05170dbe, 0x18451512, 0x0000062d,
  0x01001412, 0x40451812, 0x06270512, 0x00000501,
  // [0330]
  0x1d4305ad, 0x1d004036, 0x05450faf, 0x0000152d,
  0x0f002714, 0x21001513, 0x45272221, 0x1c000e08,
  0x08194513, 0x1e002313, 0x1d4019bb, 0x14002220,
  0x401d08be, 0x231c1e07, 0x10000812, 0x19000221,
  // [0340]
  0x16004022, 0x1c230e6f, 0x18002214, 0x0c004011,
  0x18170812, 0x1e001c12, 0x12000108, 0x03000613,
  0x10000b11, 0x38001907, 0x231e0e21, 0x040306be,
  0x23001c20, 0x0e231c13, 0x0000082d, 0x22001812,
  // [0350]
  0x19020b12, 0x0000372d, 0x04001721, 0x400c1d13,
  0x40000112, 0x450c1d12, 0x451810ad, 0x0e001c09,
  0x03000622, 0x02000611, 0x1806146f, 0x1c000e21,
  0x1c001e12, 0x05040b6f, 0x231c0eac, 0x04001920,
  // [0360]
  0x08000420, 0x10002211, 0x08000512, 0x22002114,
  0x0f0127ac, 0x23001c07, 0x18004509, 0x23000e09,
  0x18002208, 0x06000321, 0x06000322, 0x010422bc,
  0x06000107, 0x38002213, 0x0b000209, 0x1e0e1cac,
  // [0370]
  0x01020b20, 0x0f0d0121, 0x18150822, 0x231e1c12,
  0x04000611, 0x270d01bb, 0x01002112, 0x1d000312,
  0x27001d22, 0x1d4027be, 0x12004534, 0x40000c21,
  0x451d4033, 0x10020bbe, 0x0b021914, 0x15000c13,
  // [0380]
  0x16001812, 0x1004196f, 0x45001235, 0x43001720,
  0x010d0321, 0x04002707, 0x120c19ad, 0x120c1612,
  0x040c1613, 0x40451220, 0x1e1c23bc, 0x04031621,
  0x06002214, 0x0b002233, 0x02000b23, 0x0e1e1c60,
  // [0390]
  0x01004021, 0x12002221, 0x05000d12, 0x020b18bb,
  0x22001d12, 0x10001422, 0x0f0d1721, 0x0d001712,
  0x0c102211, 0x14000212, 0x02002212, 0x40271013,
  0x0000162d, 0x06002221, 0x0b0204ad, 0x19002221,
  // [03a0]
  0x00000b2d, 0x17040560, 0x05000812, 0x1427066f,
  0x16001d22, 0x1d0117ad, 0x0c142211, 0x45001208,
  0x0e231ead, 0x0f190d09, 0x12000114, 0x01001612,
  0x191415bc, 0x10002212, 0x17001912, 0x05004314,
  // [03b0]
  0x1c001e08, 0x060105ad, 0x01080dbe, 0x1e1c0e11,
  0x10002220, 0x05000113, 0x38010522, 0x45001d23,
  0x08401d21, 0x14000411, 0x170501be, 0x01451d60,
  0x45000511, 0x04001907, 0x22382712, 0x24004121,
  // [03c0]
  0x01000612, 0x05010812, 0x19001412, 0x16021507,
  0x401d0813, 0x08121d21, 0x1d380812, 0x17183821,
  0x0d0f17bb, 0x171d08ac, 0x12004012, 0x120c1da4,
  0x0e1e2360, 0x1e1c0e60, 0x10001412, 0x21000133,
  // [03d0]
  0x1d001222, 0x14001808, 0x00000e01, 0x16001512,
  0x1c1e2313, 0x19000421, 0x38002720, 0x04000613,
  0x01001211, 0x12000111, 0x12000113, 0x0e231ebe,
  0x0d1d0412, 0x030601be, 0x03000611, 0x0d000413,
  // [03e0]
  0x45120112, 0x231c0e22, 0x1e1c0e21, 0x38000307,
  0x03000620, 0x0d003811, 0x40000d21, 0x0d0f38be,
  0x1e1c23ac, 0x27001620, 0x0b030620, 0x0000381c,
  0x04001612, 0x19042708, 0x0b000212, 0x38002211,
  // [03f0]
  0x06000d07, 0x38000121, 0x43000121, 0x04001021,
  0x450c16a4, 0x04001022, 0x01000522, 0x18000611,
  0x451922af, 0x020b0507, 0x06172712, 0x0000192d,
  0x0000042d, 0x0b080207, 0x01002707, 0x230e1e21,

  // [0400]
  0x1e0e2312, 0x040d17ad, 0x0d222112, 0x15161dad,
  0x1d000c12, 0x0c120faf, 0x1c000e23, 0x19001d08,
  0x1d001522, 0x38162712, 0x380d05af, 0x1d0b2707,
  0x43211d12, 0x212719bb, 0x100614ad, 0x380f0d21,
  // [0410]
  0x40121dbb, 0x38000d07, 0x40001d08, 0x04002713,
  0x40010507, 0x06002707, 0x40001d21, 0x03001809,
  0x100f01a4, 0x40041821, 0x06010312, 0x10000623,
  0x27042120, 0x01000614, 0x01002712, 0x0f001721,
  // [0420]
  0x0f000d07, 0x08001420, 0x10000611, 0x03060107,
  0x451210b2, 0x0d170fbe, 0x0e1c1e22, 0x40001622,
  0x1d000b11, 0x050f0112, 0x1c000e09, 0x27401d13,
  0x19000b33, 0x3819086f, 0x191814cf, 0x17000512,
  // [0430]
  0x23001e07, 0x0d000111, 0x1d000611, 0x080419af,
  0x231c0ebe, 0x1d401821, 0x380f1712, 0x190b0260,
  0x16120c12, 0x19000c22, 0x45401d6f, 0x01380fac,
  0x19001721, 0x43000511, 0x05221912, 0x06050111,
  // [0440]
  0x01000514, 0x06000114, 0x38001407, 0x380514ad,
  0x21000112, 0x180d0512, 0x450c1208, 0x1e002312,
  0x01140b21, 0x1c1e0eac, 0x04271921, 0x45004011,
  0x0c001614, 0x40451dbe, 0x04002214, 0x27001920,
  // [0450]
  0x1d0c40be, 0x1e001c09, 0x400c45ad, 0x1d0f2221,
  0x220427af, 0x16000c13, 0x03020b21, 0x14002212,
  0x1e0e1c6f, 0x190504a4, 0x08002212, 0x27002213,
  0x0f0827bc, 0x02000b35, 0x06450412, 0x0b000307,
  // [0460]
  0x08011911, 0x0b220320, 0x0c001721, 0x45001411,
  0x10000213, 0x121440be, 0x151d4023, 0x04272213,
  0x380f0d20, 0x1c231e12, 0x010f1821, 0x1d221712,
  0x22002720, 0x1c001e11, 0x1e0e1c13, 0x03000b12,
  // [0470]
  0x1d004021, 0x19001521, 0x1c002307, 0x221516ac,
  0x02000b09, 0x40002211, 0x23001e08, 0x18002709,
  0x0d000f07, 0x0e1c23af, 0x1e1c0e07, 0x22002711,
  0x100322ac, 0x14000b21, 0x19142212, 0x45000c13,
  // [0480]
  0x03000612, 0x0b190d12, 0x45121807, 0x01031807,
  0x12450122, 0x12004520, 0x0b021912, 0x1c0e236f,
  0x231e1c07, 0x231e1cbc, 0x45001820, 0x1d004023,
  0x231c0e21, 0x190306af, 0x14080b22, 0x170419ac,
  // [0490]
  0x121d0caf, 0x03121d07, 0x120c17bc, 0x0c001723,
  0x120c1712, 0x0c1d4014, 0x021006a4, 0x10430121,
  0x0d000312, 0x08381034, 0x03000222, 0x1217456f,
  0x14000b20, 0x0b001d21, 0x0d030511, 0x10020621,
  // [04a0]
  0x14272122, 0x02000811, 0x06191412, 0x06000313,
  0x020d01af, 0x0e002308, 0x22160da4, 0x100b0260,
  0x12004020, 0x220f0822, 0x0c041713, 0x120c17cf,
  0x231c0e12, 0x1c002313, 0x06000d21, 0x010c2212,
  // [04b0]
  0x06002112, 0x220b0221, 0x17000f11, 0x23000e22,
  0x0000452d, 0x17000612, 0x184512af, 0x02060308,
  0x05003823, 0x27010360, 0x1c0e23ad, 0x0c0f08cf,
  0x0d451221, 0x05020b22, 0x060b5112, 0x451d0c09,
  // [04c0]
  0x450d1221, 0x01060307, 0x43000d08, 0x06031612,
  0x190c1720, 0x06003813, 0x0d004523, 0x1d001720,
  0x0c0d01a4, 0x180210af, 0x0d380821, 0x45120daf,
  0x450c4014, 0x161419af, 0x45120d22, 0x1d001612,
  // [04d0]
  0x030b0234, 0x17000311, 0x1d004012, 0x160503bb,
  0x080d0512, 0x231c1e14, 0x1c0e1e07, 0x1d002213,
  0x0e1e236f, 0x45000611, 0x17003823, 0x27430121,
  0x22401d20, 0x38221d22, 0x0d221523, 0x040616af,
  // [04e0]
  0x020b1812, 0x0c1901ac, 0x02100b12, 0x030205bc,
  0x0b023812, 0x1d004507, 0x17190511, 0x22001907,
  0x0b000308, 0x01050421, 0x19041511, 0x14000b12,
  0x06001413, 0x38220c12, 0x030c0607, 0x03100608,
  // [04f0]
  0x1e000e22, 0x08001720, 0x03050112, 0x45000c11,
  0x45000c22, 0x17100823, 0x03001007, 0x030f2212,
  0x08171021, 0x01000d07, 0x45000c21, 0x1c1e0e21,
  0x451d4021, 0x081710be, 0x17002211, 0x18000c14,
  // [0500]
  0x08001735, 0x01000c21, 0x0d0f0121, 0x05000112,
  0x12000c11, 0x05273812, 0x14000208, 0x27211934,
  0x38450c82, 0x05060313, 0x21002723, 0x060345be,
  0x1e000c1f, 0x04001621, 0x101708be, 0x271d21af,
  // [0510]
  0x10081733, 0x0e1c2312, 0x45000c14, 0x0f272112,
  0x15000814, 0x08101721, 0x45120cad, 0x10040c12,
  0x03000623, 0x06000b13, 0x0f001021, 0x14000413,
  0x03000113, 0x0c0f0621, 0x0f000c23, 0x1d002712,
  // [0520]
  0x17044521, 0x0d003809, 0x00001901, 0x45042734,
  0x080c0621, 0x27000220, 0x02100bbb, 0x03050621,
  0x15060112, 0x03000608, 0x010b1060, 0x0f000621,
  0x23001c08, 0x01001611, 0x0d000f14, 0x03001411,
  // [0530]
  0x1e1c0e23, 0x05190420, 0x19002112, 0x270501be,
  0x050801ac, 0x27002935, 0x0f001507, 0x0d010607,
  0x23001e12, 0x01000d12, 0x08001711, 0x19000c13,
  0x14001622, 0x43050111, 0x17450c82, 0x03080107,
  // [0540]
  0x0c001813, 0x0f380814, 0x1e1c0e14, 0x17080c21,
  0x380f0812, 0x1e0e1c55, 0x06000c23, 0x15450334,
  0x05450ca4, 0x45164022, 0x180d0f08, 0x230e1e07,
  0x14002711, 0x064301a4, 0x10001907, 0x0d003808,
  // [0550]
  0x1d001811, 0x12451812, 0x08001820, 0x27060d21,
  0x14001920, 0x032101ad, 0x10190412, 0x00002301,
  0x10001908, 0x010527ad, 0x06000335, 0x27000313,
  0x16002712, 0x21001412, 0x45120cac, 0x380f0dad,
  // [0560]
  0x1e002307, 0x01031913, 0x19000313, 0x19061821,
  0x01170821, 0x120603ac, 0x19001d21, 0x14101d07,
  0x400c4521, 0x03004509, 0x180121a4, 0x10001807,
  0x0f080109, 0x40221821, 0x08020dad, 0x231c0e55,
  // [0570]
  0x45001822, 0x19180421, 0x10000212, 0x01000512,
  0x04001911, 0x03000413, 0x05000d13, 0x27000413,
  0x0e1c1eaf, 0x15451d6f, 0x27000222, 0x1c001e21,
  0x14001912, 0x05001813, 0x0e1c23ac, 0x06001807,
  // [0580]
  0x12001d12, 0x19002122, 0x0b011460, 0x0f000d23,
  0x1d001212, 0x40001411, 0x03021911, 0x45120c08,
  0x1e0e1c14, 0x12451dbc, 0x45001d21, 0x04221412,
  0x01380daf, 0x02001421, 0x0d4301af, 0x0d031812,
  // [0590]
  0x0c0b1907, 0x0c001407, 0x06080312, 0x1c000e11,
  0x1e002311, 0x23001e09, 0x06011aaf, 0x19001821,
  0x060b19ac, 0x05041420, 0x1c002321, 0x18002212,
  0x0c211455, 0x06080408, 0x27180c12, 0x06050413,
  // [05a0]
  0x04000221, 0x0c080112, 0x22000413, 0x08000135,
  0x08060107, 0x1d401214, 0x0c272112, 0x01170860,
  0x00000c0a, 0x0c001623, 0x19000111, 0x00000d2d,
  0x22000611, 0x06000d13, 0x45001912, 0x04121d60,
  // [05b0]
  0x1d124514, 0x45001212, 0x1d0518bc, 0x0c171221,
  0x0d0c0f21, 0x38080512, 0x1d002212, 0x1914046f,
  0x06000535, 0x1c00371f, 0x220c1512, 0x18041dad,
  0x19000c14, 0x1d000c21, 0x17002207, 0x031921af,
  // [05c0]
  0x05060121, 0x01140612, 0x04173811, 0x22001012,
  0x18400c12, 0x220c4021, 0x0e231e12, 0x08012707,
  0x0e001c08, 0x40000b08, 0x27191a21, 0x27040321,
  0x0e001c23, 0x01001911, 0x19270312, 0x19002121,
  // [05d0]
  0x04060d12, 0x06000511, 0x080501be, 0x08000407,
  0x1c0e1e14, 0x18431407, 0x17001621, 0x0c001912,
  0x230e1c07, 0x14001821, 0x050106ad, 0x12451821,
  0x190627ad, 0x45001d12, 0x06192112, 0x06001421,
  // [05e0]
  0x0c174521, 0x120c16ad, 0x0c002121, 0x08041913,
  0x22170812, 0x03062712, 0x0d453821, 0x0f001912,
  0x02001420, 0x1d000421, 0x22001914, 0x22000f20,
  0x0c002114, 0x00000b01, 0x061d2712, 0x04191621,
  // [05f0]
  0x0e231e21, 0x1722196f, 0x04001d20, 0x00002401,
  0x0e001e33, 0x27010d12, 0x0804056f, 0x231c1e12,
  0x0e1e1cac, 0x081405ad, 0x08051707, 0x1c001e13,
  0x050d1655, 0x16002709, 0x0c000f07, 0x1e231cbe,
  // [0600]
  0x0000060a, 0x0b021007, 0x00000601, 0x16000411,
  0x40001d12, 0x16002720, 0x16000412, 0x16002723,
  0x19041422, 0x03180660, 0x1e1c2360, 0x21002714,
  0x18000321, 0x43000107, 0x0d000f23, 0x03001821,
  // [0610]
  0x24004108, 0x060301ac, 0x1e450c12, 0x01061008,
  0x05080112, 0x06101907, 0x14120daf, 0x050f0d21,
  0x121d4020, 0x174501af, 0x45001408, 0x16270660,
  0x12451807, 0x45121daf, 0x03192707, 0x12401d14,
  // [0620]
  0x160f08a4, 0x0b0251be, 0x18001d12, 0x02000b14,
  0x100b0812, 0x0e002335, 0x12000612, 0x10161421,
  0x12004535, 0x27001821, 0x1d404513, 0x0b190112,
  0x1c1e2321, 0x190b0222, 0x1d000321, 0x40001914,
  // [0630]
  0x1d000313, 0x03002711, 0x011006bc, 0x21001214,
  0x020b51be, 0x1e002308, 0x18124512, 0x1d404555,
  0x10161509, 0x1d010507, 0x10020b09, 0x450d14bb,
  0x03001922, 0x14002735, 0x03270612, 0x01000321,
  // [0640]
  0x1d0b0222, 0x03001507, 0x27001820, 0x19000322,
  0x01000313, 0x05001611, 0x1e231cac, 0x03001912,
  0x45001414, 0x18000f12, 0x08030112, 0x121d4012,
  0x0c1240bc, 0x1e231c07, 0x08050dbc, 0x23000e23,
  // [0650]
  0x451d40be, 0x16001d21, 0x45001236, 0x0c1d40bc,
  0x18001007, 0x0b001011, 0x00000c2d, 0x0145126f,
  0x12001814, 0x0f001820, 0x04001421, 0x38180f12,
  0x18380f12, 0x0e1c23be, 0x38060322, 0x121d4013,
  // [0660]
  0x22004021, 0x0c010f21, 0x1e231c12, 0x0000382d,
  0x18004507, 0x16012713, 0x19000120, 0x231c0e08,
  0x034512af, 0x16192109, 0x450c4013, 0x19151611,
  0x27002214, 0x06001014, 0x0000402d, 0x1c0e1eac,
  // [0670]
  0x0c1d4512, 0x060b0220, 0x45001412, 0x22001921,
  0x1d400caf, 0x0b001007, 0x22001808, 0x22194009,
  0x06050f6f, 0x06000c13, 0x19002207, 0x101718bc,
  0x06000421, 0x15000f13, 0x06001921, 0x02101812,
  // [0680]
  0x0b100607, 0x1e001c08, 0x12004009, 0x02182221,
  0x38000c07, 0x03003811, 0x1c230e12, 0x0c001d21,
  0x14001911, 0x05000122, 0x02001407, 0x01001907,
  0x12004507, 0x050b0108, 0x00001801, 0x1c231eaf,
  // [0690]
  0x02001712, 0x06211212, 0x15001611, 0x141d1809,
  0x04401d82, 0x1c0e2312, 0x1c0e1e23, 0x03000f12,
  0x03001013, 0x18001908, 0x19401822, 0x0e001e22,
  0x18001620, 0x18001423, 0x27180612, 0x04001413,
  // [06a0]
  0x03000135, 0x01381721, 0x401d0260, 0x02000122,
  0x40000c14, 0x1e000e11, 0x08171812, 0x0f002207,
  0x15182714, 0x14190c20, 0x05170821, 0x190f0d6f,
  0x08002721, 0x10193812, 0x02101d14, 0x03000c09,
  // [06b0]
  0x17002721, 0x060d1012, 0x02001907, 0x0d001211,
  0x08172707, 0x01000812, 0x0d004012, 0x03061913,
  0x16001811, 0x121615ad, 0x01210408, 0x0c121012,
  0x0000122d, 0x1e001c07, 0x38001812, 0x0c004508,
  // [06c0]
  0x1d001707, 0x15191013, 0x03172712, 0x100206af,
  0x06001411, 0x1d030220, 0x1d451212, 0x0c1615ad,
  0x0b401d82, 0x03000b14, 0x271d1412, 0x04000322,
  0x14000312, 0x040b0f12, 0x0c400f12, 0x27190412,
  // [06d0]
  0x15000407, 0x010d0caf, 0x02002712, 0x38000821,
  0x0c001620, 0x17000813, 0x17000814, 0x231c0e11,
  0x18034021, 0x1940106f, 0x0e1e2321, 0x27002922,
  0x12000107, 0x45001209, 0x170f0809, 0x1c002323,
  // [06e0]
  0x0e231c21, 0x05080360, 0x06030512, 0x12450112,
  0x1e1c2323, 0x1c0e2314, 0x0e002321, 0x1d000311,
  0x01000334, 0x08013812, 0x06001822, 0x1c231e14,
  0x14001813, 0x06002208, 0x03000d12, 0x0f001812,
  // [06f0]
  0x14000623, 0x100245ad, 0x27402912, 0x16170434,
  0x00000f2d, 0x2719146f, 0x01030612, 0x45000207,
  0x16002221, 0x21000312, 0x18083860, 0x380f0d34,
  0x08000b07, 0x1e000e14, 0x0d000f11, 0x01061407,
  // [0700]
  0x231c0ea4, 0x0f000823, 0x02270baf, 0x05001920,
  0x14100b12, 0x12151609, 0x38000523, 0x22002708,
  0x16001521, 0x120c2223, 0x03040112, 0x100216ac,
  0x22002722, 0x080d17ad, 0x020116ac, 0x1c1e0ebe,
  // [0710]
  0x38271612, 0x45003707, 0x1d002211, 0x08000d08,
  0x170504af, 0x02000408, 0x16030cad, 0x15000f07,
  0x01000813, 0x45151612, 0x14005122, 0x161d2260,
  0x0d270113, 0x1d000308, 0x0c001d07, 0x15004007,
  // [0720]
  0x060115ac, 0x1c003712, 0x02000b12, 0x06000422,
  0x14081912, 0x14041921, 0x08010523, 0x03001d22,
  0x05001020, 0x0c001211, 0x15160421, 0x1e000e13,
  0x22004512, 0x01001212, 0x18001211, 0x40020b21,
  // [0730]
  0x0d0f0107, 0x23001e21, 0x03000621, 0x00002142,
  0x18000f20, 0x18001612, 0x19142122, 0x12454012,
  0x04002720, 0x15001635, 0x06001d12, 0x10004511,
  0x1d401021, 0x050301be, 0x1c0e2323, 0x430112ad,
  // [0740]
  0x150840af, 0x0d000c07, 0x06000121, 0x45120f07,
  0x19451222, 0x0b021721, 0x080c0112, 0x19000521,
  0x01162721, 0x03004512, 0x06000413, 0x45004022,
  0x16150814, 0x18160321, 0x0c104012, 0x19000613,
  // [0750]
  0x40001d35, 0x1c0e1e21, 0x1c231eac, 0x17000d13,
  0x10002707, 0x22002721, 0x0c001235, 0x04001622,
  0x40000312, 0x06001611, 0x1d0c1621, 0x18002922,
  0x38000314, 0x04100b20, 0x0d001711, 0x451812ad,
  // [0760]
  0x1e230e12, 0x04004012, 0x231c0ebc, 0x0f000511,
  0x40001507, 0x1c0e1e08, 0x1c001e33, 0x0c1d45ad,
  0x1d271222, 0x14000d07, 0x19052712, 0x0e001e07,
  0x1e1c0e22, 0x04161908, 0x03002707, 0x080f0555,
  // [0770]
  0x0f011721, 0x18001721, 0x030d22be, 0x19002213,
  0x22000414, 0x01060512, 0x17001811, 0x01000320,
  0x08000612, 0x04001422, 0x04010809, 0x1d22156f,
  0x210f3821, 0x00001d2d, 0x1c002314, 0x06020121,
  // [0780]
  0x16004312, 0x01060521, 0x03000634, 0x43000d07,
  0x271d2221, 0x101914be, 0x1d450c12, 0x08030421,
  0x061904af, 0x02141021, 0x01190412, 0x19000f21,
  0x061505bb, 0x1d001611, 0x21001014, 0x0b0222ad,
  // [0790]
  0x1c230eaf, 0x16004012, 0x40002213, 0x12431da4,
  0x1e000e23, 0x06001414, 0x24004134, 0x181d2221,
  0x03190412, 0x06100211, 0x192715af, 0x19000407,
  0x0c000213, 0x0b001014, 0x04100b22, 0x04001908,
  // [07a0]
  0x0b191411, 0x231c1ebe, 0x060b1912, 0x270205ad,
  0x22000612, 0x40001d07, 0x01001207, 0x0e1e2307,
  0x10000b22, 0x17000412, 0x0c124507, 0x040b1920,
  0x27000113, 0x011705ad, 0x1e0e1c22, 0x190b14bc,
  // [07b0]
  0x06032220, 0x140110ad, 0x03050daf, 0x0d180b12,
  0x15181712, 0x38010512, 0x15001721, 0x0b020321,
  0x17000808, 0x0e001e08, 0x0d001713, 0x0b0d1807,
  0x22000607, 0x17001812, 0x050f17a4, 0x16000621,
  // [07c0]
  0x080d1712, 0x120621ad, 0x0b000207, 0x18001420,
  0x14002713, 0x0b271012, 0x02001914, 0x10000b13,
  0x140b1022, 0x06000b12, 0x12000f12, 0x08003821,
  0x04001812, 0x1d451222, 0x0b001036, 0x19001809,
  // [07d0]
  0x22002111, 0x1e1c0e6f, 0x03002122, 0x0b1051be,
  0x02001822, 0x430b0612, 0x18140dbc, 0x02030611,
  0x04001212, 0x06000d11, 0x061912be, 0x18001207,
  0x06190dbc, 0x060408a4, 0x0c000412, 0x45170d09,
  // [07e0]
  0x16180d12, 0x181d0d12, 0x190d1812, 0x10001423,
  0x400d1223, 0x08010f11, 0x1e1c0ead, 0x04150c08,
  0x0e1e1c12, 0x160c4021, 0x0f001907, 0x230e1c11,
  0x170d0faf, 0x231c1ea4, 0x00001501, 0x00001401,
  // [07f0]
  0x04211620, 0x03180655, 0x03000d09, 0x0d1d1509,
  0x080f17af, 0x231e1cac, 0x04001923, 0x04031921,
  0x19001712, 0x01004511, 0x030119be, 0x19000107,
  0x03001921, 0x0d010cad, 0x02451812, 0x16000c12,

  // [0800]
  0x23000e21, 0x17000f21, 0x06000111, 0x1e000e20,
  0x03001923, 0x0403196f, 0x04031920, 0x21002721,
  0x0c170812, 0x18000220, 0x40001d22, 0x08004011,
  0x0c001007, 0x45124012, 0x40060107, 0x12004011,
  // [0810]
  0x10000609, 0x18004012, 0x22001d14, 0x45001814,
  0x011902ab, 0x0f380121, 0x18004011, 0x191527be,
  0x21001913, 0x27121612, 0x270d2133, 0x45001813,
  0x19003813, 0x21000f20, 0x1722276f, 0x0b001413,
  // [0820]
  0x05002922, 0x03060c21, 0x0d000635, 0x054001a4,
  0x01000412, 0x401d2712, 0x15000c12, 0x21002223,
  0x100b0222, 0x1e1c2321, 0x0b042721, 0x45001821,
  0x033805cf, 0x1c231e34, 0x03000134, 0x040c0fbb,
  // [0830]
  0x17000513, 0x16101521, 0x03000614, 0x04004514,
  0x01000307, 0x16000f21, 0x080f01bc, 0x0f003822,
  0x0e001e21, 0x22001412, 0x1e231c14, 0x18000108,
  0x19000420, 0x45000c20, 0x060105ac, 0x0c004514,
  // [0840]
  0x0f003814, 0x10000b08, 0x23000e08, 0x0d0f2122,
  0x0d000f21, 0x0b000413, 0x02100bbe, 0x0d190112,
  0x124045be, 0x0c451612, 0x10190460, 0x45000c12,
  0x0f000d21, 0x0f010520, 0x27000120, 0x0d000f22,
  // [0850]
  0x38000812, 0x14001012, 0x120d0107, 0x030d0f07,
  0x0d220112, 0x22000412, 0x16000d12, 0x0c004512,
  0x14451608, 0x19004012, 0x1d272211, 0x0e001c21,
  0x27000114, 0x231c0e60, 0x162215ce, 0x1c1e0eaf,
  // [0860]
  0x12080da4, 0x04001023, 0x191d1807, 0x0e1c1ead,
  0x40001d11, 0x15001812, 0x16041521, 0x1e001c11,
  0x1c0e2308, 0x15000422, 0x0b000607, 0x010518ad,
  0x190f0821, 0x03150c21, 0x06000411, 0x121d45a4,
  // [0870]
  0x100b0409, 0x15000c22, 0x19000411, 0x40041d23,
  0x14124560, 0x15170c13, 0x0b221011, 0x010f0dbc,
  0x380d15bb, 0x45001520, 0x27001412, 0x18000414,
  0x060801be, 0x0c004511, 0x14002222, 0x1e0e2308,
  // [0880]
  0x05062721, 0x10040860, 0x01450c07, 0x0b000620,
  0x120c4512, 0x381d08af, 0x14000611, 0x0f0127cf,
  0x01030fa4, 0x16002721, 0x27182121, 0x0f03066f,
  0x22001512, 0x042227af, 0x40272112, 0x27012121,
  // [0890]
  0x220c2121, 0x22002122, 0x270d0f13, 0x21002221,
  0x38000d20, 0x12000613, 0x0b140207, 0x02000307,
  0x010c1812, 0x0c001712, 0x40191dac, 0x40271621,
  0x05000620, 0x43012121, 0x060d1921, 0x100b05ac,
  // [08a0]
  0x14192221, 0x14001913, 0x03270121, 0x14000821,
  0x0d0f0113, 0x14192712, 0x380f0dbe, 0x06010507,
  0x03000522, 0x1d1640be, 0x100b02ad, 0x1d001911,
  0x05001713, 0x03450112, 0x07003709, 0x10000411,
  // [08b0]
  0x23000e20, 0x22190413, 0x40000c12, 0x19000812,
  0x03270521, 0x10000412, 0x0d003812, 0x17003821,
  0x05012121, 0x05003813, 0x0d000421, 0x0c002112,
  0x19041008, 0x0600100b, 0x08000414, 0x0d003814,
  // [08c0]
  0x17001920, 0x22080108, 0x05221921, 0x19004313,
  0x16000512, 0x18000513, 0x12381712, 0x010519af,
  0x0d003822, 0x05002714, 0x45001207, 0x0d003820,
  0x0d003821, 0x4500121f, 0x01000c12, 0x0f000507,
  // [08d0]
  0x12001407, 0x230e1c60, 0x02102212, 0x19002711,
  0x17000413, 0x0d002120, 0x1e0e2321, 0x0d0210ad,
  0x0f0d38ad, 0x0f2708ad, 0x0d082112, 0x0c004520,
  0x051d4021, 0x16004513, 0x01000312, 0x1d171212,
  // [08e0]
  0x1e1c2314, 0x0c1d1212, 0x40002711, 0x04213821,
  0x27000f14, 0x1e1c23af, 0x06181009, 0x45082709,
  0x22001722, 0x0f401960, 0x15401d60, 0x14001022,
  0x10000613, 0x1e230e08, 0x080f2707, 0x1d004009,
  // [08f0]
  0x40380808, 0x401d1908, 0x12450c13, 0x0f1427be,
  0x0f000c07, 0x060338af, 0x01030212, 0x140206ad,
  0x21042712, 0x210f16bb, 0x14000621, 0x04001013,
  0x0c164012, 0x01001d07, 0x27101434, 0x45121d21,
  // [0900]
  0x14000d20, 0x14120d22, 0x401d1214, 0x14430d60,
  0x16124513, 0x05030121, 0x06011012, 0x1d401809,
  0x0d004320, 0x0e1c1e23, 0x1d004008, 0x08020b6f,
  0x02050121, 0x0d001412, 0x18000d13, 0x18001407,
  // [0910]
  0x03000214, 0x0c001611, 0x19000108, 0x01051807,
  0x0c001612, 0x0c001621, 0x0c001622, 0x02100107,
  0x06080112, 0x00004501, 0x02000b34, 0x18100222,
  0x0e1c2307, 0x020114a4, 0x02100b21, 0x0e001c34,
  // [0920]
  0x40001511, 0x1d1214ad, 0x05002711, 0x100b0223,
  0x03060c07, 0x0c1503bc, 0x02100b23, 0x181410af,
  0x10000322, 0x12000c07, 0x0b021023, 0x08000614,
  0x03001908, 0x231e1ca4, 0x18001411, 0x16003812,
  // [0930]
  0x18270112, 0x18001011, 0x0f001607, 0x16270421,
  0x0e1c23a4, 0x271d4022, 0x08050121, 0x3816186f,
  0x16000422, 0x17212721, 0x0f0d12ad, 0x14000d13,
  0x08003808, 0x27001922, 0x1d212721, 0x051827ad,
  // [0940]
  0x014017ad, 0x451405a4, 0x0f081421, 0x40021dad,
  0x12401d60, 0x17000107, 0x14123821, 0x04002722,
  0x08001722, 0x401d15be, 0x40220412, 0x02271412,
  0x0f1904bc, 0x191d1521, 0x40001213, 0x0f0838cf,
  // [0950]
  0x0b000220, 0x15001020, 0x17160cad, 0x1c001e36,
  0x041917be, 0x1e231c13, 0x40004502, 0x16000812,
  0x02031421, 0x1e1c23be, 0x43000f11, 0x0d080f6f,
  0x16141021, 0x40001222, 0x12270112, 0x230e1c33,
  // [0960]
  0x16002112, 0x27000c22, 0x38000f14, 0x0d002707,
  0x12004321, 0x080601bb, 0x38120cad, 0x161408ac,
  0x14001d13, 0x080c01ad, 0x0b101434, 0x17181612,
  0x03060112, 0x18000408, 0x0e001e12, 0x17271423,
  // [0970]
  0x01033807, 0x030d0655, 0x00000c01, 0x1c0e1ea4,
  0x04161d12, 0x0c001213, 0x271716cf, 0x270401ac,
  0x05162721, 0x19000113, 0x18151622, 0x0d0f10ad,
  0x38000f07, 0x16002733, 0x17002212, 0x17002222,
  // [0980]
  0x27151620, 0x0c0806ac, 0x21041921, 0x271906af,
  0x05040107, 0x151816be, 0x27161814, 0x020601a4,
  0x38152722, 0x02000b22, 0x1d0f21ce, 0x140121af,
  0x231e0ebb, 0x45150c21, 0x0f1d1622, 0x16001511,
  // [0990]
  0x10060209, 0x10001407, 0x01081560, 0x14000b13,
  0x19151d14, 0x19001435, 0x16061512, 0x08000c07,
  0x05000314, 0x160c19bb, 0x180305bc, 0x03000520,
  0x0f000612, 0x40161d08, 0x00001701, 0x222127cf,
  // [09a0]
  0x06000320, 0x19000b11, 0x45271521, 0x01004509,
  0x27000521, 0x0b010d07, 0x0b000609, 0x0b0610bc,
  0x16000612, 0x18124523, 0x1d4018af, 0x05124521,
  0x170f2709, 0x0c121812, 0x270f0821, 0x1d274060,
  // [09b0]
  0x0c001608, 0x0e1c23bb, 0x18001408, 0x06050109,
  0x1d401209, 0x12451d21, 0x0d030612, 0x1d225121,
  0x00002201, 0x01000f13, 0x10401812, 0x0c001613,
  0x02000b07, 0x0f061012, 0x08061807, 0x06080107,
  // [09c0]
  0x020b0caf, 0x06000c21, 0x231c0e13, 0x02050112,
  0x05100ba4, 0x06001812, 0x1c1e0e12, 0x021001a4,
  0x0f010413, 0x10000222, 0x1e231caf, 0x27011d08,
  0x1e0e23ad, 0x0d142221, 0x230e1e6f, 0x0f000811,
  // [09d0]
  0x14002114, 0x06001011, 0x1d004011, 0x210f2720,
  0x16001513, 0x27451d12, 0x081d0c12, 0x19001413,
  0x10001411, 0x10000b20, 0x14002122, 0x14002714,
  0x14002121, 0x1d002113, 0x03001913, 0x1d004007,
  // [09e0]
  0x04190307, 0x1d002112, 0x12010d09, 0x0e231e11,
  0x0d0f2921, 0x01002134, 0x38000f20, 0x050f01ad,
  0x0e231c07, 0x430201ad, 0x40001d20, 0x210f27bc,
  0x05003811, 0x011d4511, 0x04001007, 0x12001d07,
  // [09f0]
  0x1e001c20, 0x18000d14, 0x02000109, 0x041621af,
  0x100b0214, 0x17000121, 0x18001712, 0x0d3808bb,
  0x231c0e07, 0x45001823, 0x05002112, 0x0f0d2712,
  0x220121be, 0x0d12456f, 0x43002122, 0x16001011,
  // [0a00]
  0x0c191607, 0x1e0e2314, 0x034301bb, 0x45000d20,
  0x0f003813, 0x16004013, 0x05000f21, 0x40000f13,
  0x0b001834, 0x01002120, 0x45222108, 0x05191611,
  0x04000107, 0x1d012912, 0x0b004011, 0x01270caf,
  // [0a10]
  0x00000403, 0x0f000807, 0x40002712, 0x08041807,
  0x27184020, 0x0e001e20, 0x1d454021, 0x04000812,
  0x10061912, 0x0d000f09, 0x1e000e21, 0x05380812,
  0x15001907, 0x22380109, 0x050f01a4, 0x12001621,
  // [0a20]
  0x1d121807, 0x1c0e2313, 0x12001512, 0x04081811,
  0x23001e23, 0x1c001e20, 0x21002722, 0x0d001811,
  0x16270f11, 0x0f1922ad, 0x220f0812, 0x03010812,
  0x1c0e2311, 0x100406ac, 0x1c0e1e13, 0x0d0f19ad,
  // [0a30]
  0x06004308, 0x0e1c1ebc, 0x1c230e07, 0x21004021,
  0x0b060360, 0x18001d07, 0x00001e01, 0x191801ad,
  0x0e231c11, 0x04000111, 0x06100421, 0x020b5121,
  0x40451211, 0x40004522, 0x04061512, 0x151d40ac,
  // [0a40]
  0x02061007, 0x231e0e12, 0x0b020112, 0x01000220,
  0x08054021, 0x45004012, 0x38000613, 0x12004013,
  0x12001d13, 0x03010c12, 0x16001913, 0x17001d12,
  0x27001512, 0x27060412, 0x14001611, 0x1d170c12,
  // [0a50]
  0x10001911, 0x16014512, 0x0d0f17af, 0x0d0108af,
  0x17031512, 0x19002935, 0x380516cf, 0x38000536,
  0x14000420, 0x38060582, 0x1d000821, 0x18000122,
  0x27430112, 0x22020521, 0x12453812, 0x27000112,
  // [0a60]
  0x27002113, 0x27212212, 0x06030212, 0x38002722,
  0x1900060b, 0x1e231c21, 0x38001714, 0x0f0801ac,
  0x1d120b07, 0x27000613, 0x19152112, 0x38002111,
  0x041d19ac, 0x16211922, 0x0c001911, 0x19002133,
  // [0a70]
  0x060801ad, 0x0f150daf, 0x0b002221, 0x19002222,
  0x05430121, 0x45401912, 0x1c231e21, 0x04001934,
  0x0f082121, 0x160f1921, 0x210c1613, 0x0b010612,
  0x10020612, 0x18000407, 0x0b382221, 0x223827be,
  // [0a80]
  0x0d000522, 0x210c2712, 0x00000301, 0x0c002713,
  0x45001d08, 0x27000c09, 0x1d000c07, 0x27000c14,
  0x0f192112, 0x06000c08, 0x06000b07, 0x231e0e07,
  0x1d000c14, 0x18160421, 0x18000c12, 0x0b000c07,
  // [0a90]
  0x45001513, 0x172240bc, 0x1804226f, 0x0c002721,
  0x0c001907, 0x12450c12, 0x21382213, 0x0f050607,
  0x22400fbc, 0x22000c12, 0x0c002213, 0x0f380822,
  0x27210b22, 0x10001912, 0x02161012, 0x010d0812,
  // [0aa0]
  0x10000608, 0x0f000d22, 0x0e231c60, 0x45004013,
  0x0b100112, 0x43080107, 0x080601a4, 0x01030608,
  0x230e1ead, 0x21004011, 0x00000201, 0x01052212,
  0x011038be, 0x0d0c0612, 0x1d4512af, 0x17060f07,
  // [0ab0]
  0x03061709, 0x0f0b1712, 0x02120112, 0x450c12bb,
  0x150b2760, 0x17001d14, 0x180f19ad, 0x17150112,
  0x0f0d40af, 0x151421ac, 0x21001813, 0x1e230e20,
  0x270203af, 0x121808ad, 0x16181d13, 0x0d100212,
  // [0ac0]
  0x061014ad, 0x27000c20, 0x021018cf, 0x0f081721,
  0x12010c12, 0x1e001c23, 0x45401221, 0x12000c13,
  0x04050113, 0x12041721, 0x0c0d08bb, 0x16002722,
  0x150f1d12, 0x15000c20, 0x120c1d60, 0x18001911,
  // [0ad0]
  0x0f062708, 0x041d1921, 0x06000312, 0x231e1c11,
  0x231c1eac, 0x15101d12, 0x14190433, 0x04191012,
  0x401d0812, 0x22190412, 0x06160321, 0x1200450d,
  0x1c002308, 0x08000413, 0x01182120, 0x06000414,
  // [0ae0]
  0x180410af, 0x0c000408, 0x18040821, 0x19101421,
  0x0c010412, 0x03010507, 0x0c4003ad, 0x05270b12,
  0x060310af, 0x0e1c23bc, 0x16002209, 0x0c000420,
  0x0000120a, 0x0b020f12, 0x38001409, 0x1d000f07,
  // [0af0]
  0x16001214, 0x10002213, 0x0b001812, 0x060c19bc,
  0x0b190414, 0x01430807, 0x060305bb, 0x05000b21,
  0x14000b22, 0x01000f20, 0x1d001021, 0x05001223,
  0x0203106f, 0x04030621, 0x170f0812, 0x05060209,
  // [0b00]
  0x380d0fbe, 0x050c0312, 0x21001612, 0x154014ac,
  0x020b0612, 0x0e1c2321, 0x150b1012, 0x0b210111,
  0x081505bc, 0x080d1daf, 0x08011d07, 0x0c000112,
  0x08000421, 0x10000407, 0x020b10be, 0x190b0421,
  // [0b10]
  0x04190613, 0x14001013, 0x0e1e2313, 0x05000235,
  0x0b222712, 0x191d406f, 0x40451260, 0x124540af,
  0x0c121da4, 0x01050412, 0x15002221, 0x03000408,
  0x17000b21, 0x08010514, 0x1d450c14, 0x0b000633,
  // [0b20]
  0x15061412, 0x06011412, 0x231c1ead, 0x100614a4,
  0x00004301, 0x0d1601a4, 0x0d0f3820, 0x45001607,
  0x1d004511, 0x0c224012, 0x15002707, 0x00001c01,
  0x01000c07, 0x40004512, 0x03161712, 0x27030bbb,
  // [0b30]
  0x401245bc, 0x401d4512, 0x12000c12, 0x0d001714,
  0x451d17bb, 0x18001013, 0x1d044011, 0x0c001d11,
  0x19000435, 0x06001023, 0x21000612, 0x0c100212,
  0x19030612, 0x06000323, 0x190b106f, 0x16001536,
  // [0b40]
  0x05000607, 0x08000307, 0x0b060223, 0x08002711,
  0x380f0809, 0x0d000f12, 0x021816ad, 0x22001711,
  0x1e231c11, 0x04001713, 0x27002222, 0x22001912,
  0x1d274520, 0x0f0b14af, 0x1e1c2307, 0x171d1612,
  // [0b50]
  0x14060bad, 0x22001821, 0x01160621, 0x19400c07,
  0x1d4045be, 0x15001909, 0x02060b12, 0x040b2712,
  0x19041755, 0x38041712, 0x01001012, 0x16041522,
  0x0f272209, 0x0f010509, 0x06011907, 0x0c401d07,
  // [0b60]
  0x1d000c08, 0x171451ad, 0x180219ac, 0x190d1d09,
  0x00001601, 0x0d000f02, 0x1d000511, 0x10000f13,
  0x121d40ad, 0x0f000812, 0x05010313, 0x0d041912,
  0x0f0d0814, 0x06000812, 0x03140221, 0x0c021921,
  // [0b70]
  0x22002113, 0x22001714, 0x2122276f, 0x21001911,
  0x38000f21, 0x06151207, 0x0d212712, 0x06001008,
  0x01000d21, 0x2721186f, 0x1400101f, 0x19000122,
  0x18002113, 0x19000321, 0x06050812, 0x0c004513,
  // [0b80]
  0x10190107, 0x01030ca4, 0x03000207, 0x19000d07,
  0x010c0608, 0x01100820, 0x19001611, 0x27000513,
  0x01222720, 0x0c001807, 0x16002111, 0x18000c07,
  0x03001914, 0x1d1645ac, 0x011908af, 0x10000307,
  // [0b90]
  0x0b021008, 0x040b0209, 0x01432707, 0x0c270607,
  0x10140baf, 0x0c001814, 0x0b080420, 0x0c010660,
  0x190427be, 0x02040b21, 0x400c1209, 0x0e001c02,
  0x1d004514, 0x06080b11, 0x121d40af, 0x45124014,
  // [0ba0]
  0x1c0e23af, 0x45124021, 0x191201ac, 0x1c231e20,
  0x04000b14, 0x1d451260, 0x450d01ac, 0x27000d23,
  0x05124512, 0x18002721, 0x0f4301ad, 0x1d102755,
  0x1c002322, 0x21000113, 0x40151d13, 0x18000f21,
  // [0bb0]
  0x40001207, 0x170d1921, 0x0c000613, 0x12001812,
  0x0d000107, 0x05000107, 0x0f001821, 0x12004007,
  0x0d0f18be, 0x18000313, 0x1d000b22, 0x05430112,
  0x1d0140bc, 0x100b0221, 0x0f013807, 0x10381612,
  // [0bc0]
  0x0f010807, 0x08000522, 0x05380108, 0x1d0c22ad,
  0x06001714, 0x38010520, 0x02140112, 0x27000614,
  0x0000170a, 0x40271d21, 0x27000c13, 0x14190421,
  0x02010312, 0x270f22a4, 0x38000f08, 0x10000522,
  // [0bd0]
  0x19001813, 0x12041012, 0x05173834, 0x1d001712,
  0x0e1c1e09, 0x14160411, 0x05001822, 0x0b192721,
  0x1e0e23af, 0x0f272212, 0x0e1c2313, 0x12050112,
  0x17000308, 0x18000514, 0x01002713, 0x17120dac,
  // [0be0]
  0x080c0212, 0x05001835, 0x21002214, 0x03010521,
  0x05001823, 0x05001820, 0x1d050812, 0x081915a4,
  0x05002111, 0x01000314, 0x05271412, 0x38002712,
  0x27001d12, 0x380f19bb, 0x03021909, 0x0f210dbb,
  // [0bf0]
  0x1c230e20, 0x22002134, 0x0f003808, 0x030601a4,
  0x0f001807, 0x0f1819ad, 0x140d3823, 0x1d400d12,
  0x06000112, 0x01060812, 0x38000623, 0x400c1d21,
  0x0c0406ad, 0x0f000c13, 0x45120512, 0x0d001812,

  // [0c00]
  0x01001613, 0x0f170834, 0x211001af, 0x0d002714,
  0x08000507, 0x0c021612, 0x02061d21, 0x15002212,
  0x06010807, 0x08040c21, 0x08192707, 0x18000d12,
  0x40000512, 0x0c1215ac, 0x01051812, 0x0c002711,
  // [0c10]
  0x120c1d12, 0x0f190d11, 0x16000f11, 0x38030112,
  0x45000622, 0x0d0f1912, 0x19001021, 0x0b1004ad,
  0x101d0607, 0x0b0118be, 0x19001014, 0x0f001013,
  0x16000d22, 0x04001d13, 0x0e1e1c21, 0x00001815,
  // [0c20]
  0x22000c23, 0x01030513, 0x05000614, 0x05003814,
  0x12150cad, 0x19002111, 0x05011010, 0x03050b21,
  0x06000b22, 0x01000b21, 0x04002111, 0x19001d13,
  0x27210460, 0x04000511, 0x0c150207, 0x02011455,
  // [0c30]
  0x401d18a4, 0x06011712, 0x0c042112, 0x140b06a4,
  0x0b1806af, 0x06100b12, 0x27001720, 0x010d03a4,
  0x05012108, 0x04000313, 0x0b270334, 0x27000312,
  0x17002123, 0x04001d12, 0x01212712, 0x17270112,
  // [0c40]
  0x1d4019ad, 0x380f0511, 0x04000311, 0x03041912,
  0x04000307, 0x05001810, 0x192704ad, 0x1d001908,
  0x05001807, 0x0f0827a4, 0x0b001213, 0x1e231c20,
  0x01050311, 0x0d000513, 0x14100c12, 0x061410af,
  // [0c50]
  0x170827af, 0x1d124560, 0x020310cf, 0x0d0f05ac,
  0x380f0d23, 0x04002712, 0x38000d12, 0x04001811,
  0x271d2260, 0x010d2107, 0x38031809, 0x0f380dbb,
  0x14002111, 0x1d0f0d6f, 0x0f002112, 0x0f380dad,
  // [0c60]
  0x06001013, 0x0e231cac, 0x03000211, 0x08000112,
  0x161510be, 0x01050822, 0x0f051d07, 0x0b101407,
  0x0d120f07, 0x0d0f4012, 0x0b1051af, 0x0c001720,
  0x0e1e1c09, 0x0e231ebb, 0x04002211, 0x18080111,
  // [0c70]
  0x0d0f0512, 0x16004008, 0x17003812, 0x40000d14,
  0x0b002707, 0x38000d21, 0x10211960, 0x27160c12,
  0x27004521, 0x01000808, 0x06000523, 0x0e1e1caf,
  0x18001907, 0x0b100121, 0x14000d12, 0x210f0d22,
  // [0c80]
  0x1c0e1eaf, 0x121d406f, 0x1d124021, 0x0c060109,
  0x00000801, 0x00004001, 0x10000312, 0x22001720,
  0x04000c22, 0x06000f12, 0x02001807, 0x0f000d08,
  0x05010660, 0x15000f11, 0x19001011, 0x22001507,
  // [0c90]
  0x27000f13, 0x270f1d12, 0x380210af, 0x06001d07,
  0x062204bc, 0x0c000414, 0x380d0fbc, 0x40000122,
  0x19210112, 0x10021621, 0x08050f12, 0x04124520,
  0x0f010da4, 0x0d000f08, 0x022101bc, 0x271d4021,
  // [0ca0]
  0x12000308, 0x0b1002be, 0x05001208, 0x160619ad,
  0x12004509, 0x05000312, 0x101416a4, 0x01000511,
  0x12161807, 0x0f0d01be, 0x05001213, 0x05004013,
  0x15001613, 0x06004008, 0x050118a4, 0x27190809,
  // [0cb0]
  0x01380f12, 0x27001912, 0x0f012712, 0x18000621,
  0x04212722, 0x050f1508, 0x27190612, 0x221519ad,
  0x18001214, 0x05020b12, 0x270f1912, 0x02061412,
  0x14060421, 0x22001833, 0x0f003811, 0x432101bc,
  // [0cc0]
  0x02000120, 0x05000612, 0x050801bb, 0x27030612,
  0x0d0f2221, 0x18060b21, 0x19000311, 0x15004011,
  0x14000112, 0x0f1218ac, 0x0d010822, 0x02000111,
  0x12380c07, 0x22000212, 0x21000420, 0x140b0421,
  // [0cd0]
  0x1d174021, 0x04151912, 0x19221407, 0x270805af,
  0x0d271d12, 0x15080f12, 0x40451213, 0x10450607,
  0x0b000807, 0x08000f11, 0x0d000521, 0x052201af,
  0x27081221, 0x06004512, 0x030608be, 0x05010612,
  // [0ce0]
  0x21050121, 0x0e231e07, 0x0f380809, 0x01003811,
  0x08001714, 0x0f001412, 0x19271820, 0x15002213,
  0x15450c22, 0x1d100b6f, 0x17003813, 0x01061821,
  0x16000313, 0x40001712, 0x0d002713, 0x18081221,
  // [0cf0]
  0x01210320, 0x05002712, 0x03223812, 0x40000f07,
  0x18001920, 0x052127af, 0x45121613, 0x16270112,
  0x270601bc, 0x45001613, 0x06030112, 0x27000520,
  0x010f2712, 0x23001c09, 0x05010322, 0x12001611,
  // [0d00]
  0x04001208, 0x03060212, 0x12060320, 0x1d001913,
  0x0d003813, 0x18000509, 0x0c1d4012, 0x08060512,
  0x45120513, 0x40004511, 0x0f0d1208, 0x10181dbb,
  0x10010dad, 0x0d001511, 0x0c010807, 0x060b0207,
  // [0d10]
  0x05004507, 0x061927ac, 0x22021413, 0x27080b6f,
  0x020b0421, 0x100119ad, 0x231e3712, 0x17000d09,
  0x0c0f17a4, 0x0b031921, 0x0f000833, 0x142722be,
  0x10020b12, 0x38001620, 0x14001922, 0x1d004512,
  // [0d20]
  0x18000822, 0x1c1e2307, 0x222115bc, 0x18000c22,
  0x0f270112, 0x0e231cad, 0x01000620, 0x0c001821,
  0x02211412, 0x01000507, 0x451218af, 0x04161512,
  0x0c0206bb, 0x010c1907, 0x19001422, 0x05002213,
  // [0d30]
  0x16000c14, 0x1d400221, 0x08001513, 0x06002213,
  0x27002221, 0x02450cac, 0x0c000611, 0x140419bc,
  0x22000614, 0x18000422, 0x17191412, 0x060514af,
  0x1d2719ad, 0x06001220, 0x031d4034, 0x05002212,
  // [0d40]
  0x27011612, 0x08001712, 0x1000021f, 0x0d0f16ad,
  0x22081821, 0x38000620, 0x170603ad, 0x06120c22,
  0x05000d11, 0x160d0f20, 0x06001021, 0x0b000121,
  0x10000607, 0x19041410, 0x1e1c0eaf, 0x08270108,
  // [0d50]
  0x1900102e, 0x10000622, 0x380d0f21, 0x18382712,
  0x21012712, 0x401d16be, 0x0b190213, 0x45000112,
  0x04271621, 0x011d1a12, 0x38191012, 0x01190fac,
  0x05011708, 0x10271909, 0x38001914, 0x0b451213,
  // [0d60]
  0x23001c14, 0x03000c07, 0x0d061d60, 0x16000312,
  0x19001013, 0x08000511, 0x04001614, 0x191602af,
  0x19161520, 0x02001911, 0x18020b12, 0x04000608,
  0x1d004020, 0x0e1c2323, 0x27000321, 0x06450c21,
  // [0d70]
  0x220b0412, 0x04061011, 0x16000c08, 0x10000408,
  0x0b021921, 0x04061912, 0x190103af, 0x0b001008,
  0x040319ad, 0x0d160fad, 0x1000040b, 0x03000d11,
  0x1c1e23af, 0x0c0d0f11, 0x0f000d35, 0x18002223,
  // [0d80]
  0x45141221, 0x15001634, 0x080f0121, 0x16271521,
  0x08161713, 0x0d000f13, 0x05000613, 0x22160b12,
  0x14000f20, 0x080106ad, 0x27222120, 0x03380612,
  0x19180408, 0x0d080620, 0x101d19a4, 0x213827bc,
  // [0d90]
  0x27060cbe, 0x221918cf, 0x08380160, 0x1c0e1e20,
  0x2221276f, 0x01003814, 0x27000108, 0x06001810,
  0x08030120, 0x14001008, 0x1d000213, 0x04000513,
  0x15061621, 0x17004312, 0x05061512, 0x21000213,
  // [0da0]
  0x05001212, 0x031927af, 0x0f1927ac, 0x221821bb,
  0x04001014, 0x16004514, 0x14000220, 0x15001911,
  0x06210412, 0x0e1c1ebe, 0x03000111, 0x22020b20,
  0x0c001207, 0x04051912, 0x17000d08, 0x0d000613,
  // [0db0]
  0x27001714, 0x1d271955, 0x1d002722, 0x16001911,
  0x0f060307, 0x0e231ca4, 0x03180607, 0x231c0e09,
  0x030601ad, 0x210103af, 0x1d0c4021, 0x0d002708,
  0x04050821, 0x0b001822, 0x080b0421, 0x0b1004af,
  // [0dc0]
  0x05040bbc, 0x10171d12, 0x1c1e2312, 0x10000821,
  0x01270612, 0x05000820, 0x19160412, 0x0b005122,
  0x0b1451be, 0x01031860, 0x05180813, 0x081804cf,
  0x0b001813, 0x01190b21, 0x04000814, 0x01041911,
  // [0dd0]
  0x08000213, 0x1d001211, 0x15002207, 0x270805bc,
  0x05001222, 0x1e1c0ebe, 0x10050107, 0x021606a4,
  0x1c231ead, 0x020b2212, 0x22054512, 0x22272112,
  0x02002111, 0x0c190412, 0x1d020b22, 0x08141911,
  // [0de0]
  0x08002122, 0x1e0e1c21, 0x231c1e22, 0x180b0cad,
  0x1e231c22, 0x21002222, 0x22002120, 0x010c17ac,
  0x270b0212, 0x10001420, 0x220f21ad, 0x1d4008be,
  0x0d1d0813, 0x12001d22, 0x0d000f20, 0x0c2706bc,
  // [0df0]
  0x18000612, 0x080301ac, 0x1d064007, 0x0f380da4,
  0x174301bb, 0x04002714, 0x080204be, 0x100b0121,
  0x230e1eac, 0x12000812, 0x06150413, 0x0e1c2360,
  0x0f000112, 0x22270460, 0x40002112, 0x230e1c20,
  // [0e00]
  0x01000607, 0x01124509, 0x040616be, 0x01001711,
  0x1e230e13, 0x0d032712, 0x06010412, 0x060117ad,
  0x04001823, 0x0f010407, 0x0f000d13, 0x030401ad,
  0x19002714, 0x04060321, 0x04002107, 0x1c001e23,
  // [0e10]
  0x03002111, 0x27212921, 0x06190112, 0x01001712,
  0x06001708, 0x06001d22, 0x19021721, 0x06004514,
  0x45121dbb, 0x0d001608, 0x0d060308, 0x04000314,
  0x45000612, 0x190614be, 0x45000620, 0x38000d08,
  // [0e20]
  0x10001611, 0x100b1421, 0x01000613, 0x38000d22,
  0x03000420, 0x04001608, 0x01001011, 0x160c0412,
  0x0b000812, 0x18003814, 0x14000608, 0x02220108,
  0x0d080f09, 0x21270612, 0x17000120, 0x01000f11,
  // [0e30]
  0x0f0d1712, 0x011003ad, 0x05001721, 0x14001933,
  0x01001720, 0x08001620, 0x40001814, 0x02100313,
  0x16001507, 0x27011712, 0x08060312, 0x19011760,
  0x10050112, 0x1d001507, 0x40000313, 0x08000313,
  // [0e40]
  0x03024012, 0x27000411, 0x40001912, 0x03063821,
  0x19001421, 0x020306ad, 0x0000022d, 0x400d19ac,
  0x0d0538bc, 0x100b0608, 0x0b0306bc, 0x1406036f,
  0x140b0621, 0x0d0516af, 0x38004021, 0x40001922,
  // [0e50]
  0x0c1d1611, 0x40001933, 0x03180411, 0x0d1806bc,
  0x0d000422, 0x0b064507, 0x05000611, 0x031706ad,
  0x06001233, 0x100b3713, 0x27000620, 0x060508ad,
  0x19001708, 0x06050d12, 0x401d1621, 0x1c0e1ebe,
  // [0e60]
  0x15171421, 0x06010cad, 0x0f081607, 0x1e0e2307,
  0x19002707, 0x04191407, 0x16004007, 0x04000512,
  0x16004020, 0x18001209, 0x0d000512, 0x45121d13,
  0x0d0f08bc, 0x080301ad, 0x45121d12, 0x19001d11,
  // [0e70]
  0x01050811, 0x45001611, 0x18141d13, 0x191d18bb,
  0x45173812, 0x0b0102af, 0x40121d13, 0x10000321,
  0x17000407, 0x0f000513, 0x02122707, 0x04001909,
  0x08000d14, 0x45001220, 0x17001907, 0x101614af,
  // [0e80]
  0x0c000411, 0x380827ac, 0x0f060b11, 0x22450112,
  0x21000d13, 0x0b221912, 0x0c002211, 0x03100b20,
  0x0c000509, 0x17001821, 0x1e1c0e20, 0x04180d13,
  0x38000f23, 0x0d001d12, 0x01001813, 0x010518bc,
  // [0e90]
  0x18000512, 0x01000822, 0x451d40bb, 0x0d050f22,
  0x38170834, 0x08161021, 0x12451811, 0x0d002210,
  0x1e0e1c11, 0x0e1e1c11, 0x401d1521, 0x18004035,
  0x080f3812, 0x0f0127af, 0x21002720, 0x17050cad,
  // [0ea0]
  0x18000c21, 0x010c18bc, 0x02121408, 0x05000102,
  0x00001d01, 0x05000135, 0x0c000609, 0x08001814,
  0x0b0206a4, 0x17150c08, 0x02000113, 0x27220421,
  0x19060460, 0x03060412, 0x03142221, 0x03000122,
  // [0eb0]
  0x12001813, 0x0d212720, 0x22001811, 0x1d000c13,
  0x1d000c20, 0x27001734, 0x22080112, 0x15000112,
  0x03270412, 0x15002111, 0x060c1811, 0x430b0607,
  0x1d001812, 0x17041920, 0x01000513, 0x06032221,
  // [0ec0]
  0x16030621, 0x1d4512ac, 0x06030c21, 0x1d122212,
  0x03000107, 0x10060b12, 0x23001e14, 0x1d000820,
  0x010306be, 0x380d0508, 0x19001020, 0x08000108,
  0x06142112, 0x05001912, 0x0d380f23, 0x16001d13,
  // [0ed0]
  0x231e1c20, 0x10021212, 0x0e1c2322, 0x0b001020,
  0x1c0e2321, 0x192104cf, 0x0f21146f, 0x19001007,
  0x45010308, 0x060d0c12, 0x06082207, 0x08000521,
  0x020b40af, 0x45121da4, 0x43170121, 0x01060c12,
  // [0ee0]
  0x06001211, 0x270601af, 0x15001d12, 0x38001212,
  0x18001914, 0x14020bad, 0x1c0e2322, 0x0c000114,
  0x17001512, 0x15001d23, 0x0c001214, 0x0000020a,
  0x16002222, 0x401d1520, 0x1d001514, 0x38001522,
  // [0ef0]
  0x1c0e1e22, 0x0f080dad, 0x45171214, 0x45191620,
  0x22003811, 0x231c0e23, 0x00000d01, 0x121d1412,
  0x01061921, 0x38000534, 0x12151d07, 0x1d001421,
  0x18000c08, 0x05000c12, 0x100b51be, 0x150c1208,
  // [0f00]
  0x03000212, 0x04160882, 0x15191634, 0x17192921,
  0x06190313, 0x0f382721, 0x19270812, 0x040603af,
  0x0f030107, 0x0e1e23ad, 0x0b100214, 0x14001621,
  0x18040834, 0x19161420, 0x050d0134, 0x400803ac,
  // [0f10]
  0x1e230eaf, 0x010d0f08, 0x01052707, 0x060105a4,
  0x0d000511, 0x401d0c20, 0x01030507, 0x0c121daf,
  0x121d17bc, 0x12000d12, 0x38431d09, 0x1d400c22,
  0x01221d11, 0x1d1916bc, 0x0c401d11, 0x06002207,
  // [0f20]
  0x450f0812, 0x1c230e60, 0x0f1701a4, 0x45004007,
  0x0d0b1812, 0x38401d12, 0x21271913, 0x05001512,
  0x1c0e1e60, 0x15001913, 0x1d010c12, 0x17031912,
  0x160d0f14, 0x050f3802, 0x15001921, 0x05170313,
  // [0f30]
  0x180106af, 0x16001514, 0x16001912, 0x10000b21,
  0x0d082721, 0x22141912, 0x1d272121, 0x27002134,
  0x22101412, 0x40002134, 0x45120ca4, 0x452721bb,
  0x16151021, 0x0c4540af, 0x1d0c18a4, 0x27160422,
  // [0f40]
  0x14001d21, 0x010f0bad, 0x104015af, 0x27161522,
  0x1d102212, 0x0c401dad, 0x06000522, 0x05150421,
  0x0d1951be, 0x40002714, 0x05000422, 0x02221013,
  0x05003812, 0x160515ad, 0x15080421, 0x08000d12,
  // [0f50]
  0x01002711, 0x0b010c12, 0x01000520, 0x17001620,
  0x060c0107, 0x1840146f, 0x08150daf, 0x152714af,
  0x04001521, 0x060d0121, 0x0c2218ac, 0x27102221,
  0x01000621, 0x1421036f, 0x43190107, 0x19002212,
  // [0f60]
  0x06000f13, 0x27142221, 0x0c001513, 0x05010fad,
  0x102719ad, 0x171821be, 0x08000111, 0x012721bc,
  0x27001621, 0x05271734, 0x02060b14, 0x051738be,
  0x380f0d08, 0x14001d22, 0x081d1921, 0x1710086d,
  // [0f70]
  0x08003822, 0x030d0612, 0x1d0b4020, 0x010b0c60,
  0x06450521, 0x22001707, 0x0d163809, 0x06161912,
  0x15211922, 0x0d004508, 0x45001811, 0x27161712,
  0x1d001922, 0x27190209, 0x010419bc, 0x00001703,
  // [0f80]
  0x1c0e2360, 0x14124512, 0x0f001d12, 0x06050f08,
  0x27001413, 0x02000b11, 0x0f381dac, 0x430c01ac,
  0x0f380821, 0x05010c12, 0x1227146f, 0x21190412,
  0x38010f12, 0x22001420, 0x0d001422, 0x02000612,
  // [0f90]
  0x19143820, 0x38004323, 0x27001421, 0x401d0821,
  0x40001521, 0x030106ad, 0x10002121, 0x22144512,
  0x452719ad, 0x38001911, 0x08001421, 0x14001811,
  0x0c4015af, 0x16004512, 0x0d1704bc, 0x17190455,
  // [0fa0]
  0x03020b13, 0x27004008, 0x0d042721, 0x1d4008af,
  0x0e1c236f, 0x19002107, 0x04002721, 0x38050860,
  0x121d4021, 0x434004ac, 0x14004011, 0x0f0d386f,
  0x40000507, 0x12030ca4, 0x0c004522, 0x0e1c2309,
  // [0fb0]
  0x45000602, 0x1e231c08, 0x170d0102, 0x17002722,
  0x08010512, 0x16001d07, 0x0c212721, 0x080f4521,
  0x270c2112, 0x062745ad, 0x430127bb, 0x1c230ebe,
  0x0f0601bb, 0x151416af, 0x21270c12, 0x030c0612,
  // [0fc0]
  0x0d0f0507, 0x030419ac, 0x22380f60, 0x04000623,
  0x14001822, 0x19140821, 0x18002220, 0x18140d21,
  0x16101821, 0x0d000514, 0x0f0d0582, 0x03001033,
  0x02001007, 0x010f4312, 0x05081708, 0x02030b09,
  // [0fd0]
  0x06001712, 0x18100312, 0x38001807, 0x161014bb,
  0x21080faf, 0x17050dbc, 0x0f002111, 0x22001007,
  0x19001512, 0x10021712, 0x22212723, 0x020b06af,
  0x0d0f3813, 0x17004507, 0x0f000821, 0x231c0eaf,
  // [0fe0]
  0x04001522, 0x18004513, 0x010d0512, 0x0e231c14,
  0x12000c21, 0x0c001822, 0x100627ad, 0x0d004507,
  0x27050111, 0x0f002707, 0x0b002720, 0x03000412,
  0x271406af, 0x01272121, 0x27102212, 0x45010312,
  // [0ff0]
  0x150604ad, 0x231e0ebe, 0x1c1e2314, 0x40010820,
  0x27001812, 0x1e230e6f, 0x1d000107, 0x16000c11,
  0x1505276f, 0x01081722, 0x06011912, 0x27000435,
  0x40001812, 0x2708046f, 0x18020bbc, 0x0d2205be,

  // [1000]
  0x05003822, 0x0b272121, 0x15041621, 0x1c0e1e12,
  0x19270822, 0x08051414, 0x22004521, 0x0f001811,
  0x43020c12, 0x0e231e20, 0x01124555, 0x38270cad,
  0x0c001011, 0x01020512, 0x0c124555, 0x15000611,
  // [1010]
  0x060b0307, 0x17190421, 0x230e1e60, 0x01002212,
  0x01030fac, 0x060501af, 0x04050108, 0x17000812,
  0x0c000113, 0x08210121, 0x05120cad, 0x08191607,
  0x03000512, 0x0d0f1d12, 0x0d000822, 0x05380612,
  // [1020]
  0x10150121, 0x05040113, 0x14000614, 0x011727ac,
  0x19011013, 0x01000b12, 0x05010faf, 0x00001001,
  0x10001813, 0x401d2720, 0x19060d09, 0x1d004033,
  0x1d004035, 0x231e1c22, 0x19000409, 0x19161560,
  // [1030]
  0x05000d07, 0x40001d36, 0x18451260, 0x0b190421,
  0x0f210413, 0x15100dbc, 0x1c0e23ac, 0x150b0220,
  0x18451212, 0x10021812, 0x22161407, 0x16004521,
  0x19182122, 0x05081612, 0x380822af, 0x141004be,
  // [1040]
  0x1c1e16ad, 0x40001423, 0x05160407, 0x04001514,
  0x1c1e0e60, 0x17002121, 0x1d001711, 0x43011712,
  0x0816216f, 0x15001914, 0x27001613, 0x05000421,
  0x15171960, 0x05120107, 0x01050409, 0x0e1c1ea4,
  // [1050]
  0x19001522, 0x05160112, 0x14151912, 0x16061907,
  0x01001622, 0x0105066f, 0x19001511, 0x02031912,
  0x17000607, 0x04101922, 0x040c19bb, 0x0d001612,
  0x180d1612, 0x191504ad, 0x05430107, 0x27451213,
  // [1060]
  0x06000c22, 0x160b22ad, 0x45000c23, 0x16000c22,
  0x03190421, 0x06010520, 0x08010fbe, 0x22002121,
  0x12450621, 0x27003814, 0x1e002320, 0x380d0f12,
  0x04031812, 0x45120cbe, 0x27000122, 0x45160c11,
  // [1070]
  0x05170caf, 0x45060c60, 0x17430c12, 0x22001413,
  0x38002711, 0x01000c14, 0x451d1812, 0x0e1e23ac,
  0x01000c13, 0x04001808, 0x19022114, 0x1e0e1cbc,
  0x0c1216ad, 0x10161dac, 0x1c002302, 0x00000f01,
  // [1080]
  0x450c04ad, 0x0d041955, 0x16000420, 0x10000512,
  0x15001723, 0x18000411, 0x0e1c2355, 0x18000507,
  0x18000613, 0x19001d09, 0x1d0604a4, 0x230e1e20,
  0x1d0601ad, 0x17001908, 0x1d000113, 0x19000811,
  // [1090]
  0x05001513, 0x141d4020, 0x15001712, 0x27000322,
  0x21182760, 0x0b060812, 0x14043811, 0x1c1e0e6f,
  0x17001413, 0x14220412, 0x21001920, 0x17001614,
  0x041908be, 0x10011d08, 0x45001710, 0x18040612,
  // [10a0]
  0x0f081707, 0x38060813, 0x010d0f11, 0x0b020609,
  0x0b081421, 0x14011821, 0x05000411, 0x0c000321,
  0x05380f22, 0x040d0511, 0x0b1014ce, 0x0f000120,
  0x08003813, 0x19000d14, 0x04001712, 0x0f180dad,
  // [10b0]
  0x104019af, 0x12000d13, 0x06190421, 0x0d000507,
  0x19140607, 0x120d1812, 0x22004513, 0x05000d14,
  0x17001d07, 0x1d451613, 0x040d2712, 0x08000412,
  0x02032109, 0x02100b55, 0x0d121809, 0x100616af,
  // [10c0]
  0x45120f12, 0x06001520, 0x231c0e14, 0x0c001d22,
  0x06001621, 0x0103216f, 0x14050612, 0x06001422,
  0x062701bc, 0x14060313, 0x01002113, 0x06030121,
  0x10000621, 0x08210113, 0x010621ac, 0x052717ad,
  // [10d0]
  0x06000c1f, 0x0e002302, 0x17080108, 0x0c004523,
  0x02030613, 0x0b1918be, 0x0e1e23bb, 0x17003807,
  0x18001512, 0x01061012, 0x180119a4, 0x08451707,
  0x40001612, 0x080627be, 0x16002711, 0x010805af,
  // [10e0]
  0x0b0214ac, 0x080322ac, 0x38001707, 0x0c002722,
  0x04010521, 0x19002913, 0x08050612, 0x0c1514bc,
  0x45121907, 0x19001820, 0x1c0e37ad, 0x230e1e09,
  0x022701af, 0x16401d12, 0x18002108, 0x1c1e2311,
  // [10f0]
  0x03001012, 0x0c430107, 0x182221be, 0x08004012,
  0x0d000523, 0x10020b23, 0x40000121, 0x08001812,
  0x22000807, 0x38000f09, 0x43212721, 0x27222122,
  0x18212712, 0x151621ce, 0x192721be, 0x0c001820,
  // [1100]
  0x221527bb, 0x060b0222, 0x1027216f, 0x0e001c20,
  0x1e002322, 0x19041712, 0x19002214, 0x18041960,
  0x190b04be, 0x0d004512, 0x122221af, 0x060b1411,
  0x03001812, 0x181522bb, 0x19000d08, 0x16000d14,
  // [1110]
  0x18002712, 0x0b020612, 0x040322bb, 0x10032208,
  0x45051260, 0x1d101907, 0x06001908, 0x0b060521,
  0x0d002711, 0x38082712, 0x042719ad, 0x06180307,
  0x19020412, 0x1d001521, 0x23001e20, 0x0b041912,
  // [1120]
  0x22001521, 0x06001914, 0x19050612, 0x05011a21,
  0x03000b13, 0x03191d07, 0x19010c09, 0x10000414,
  0x1e002321, 0x38050813, 0x151927af, 0x0d0504af,
  0x041d0c60, 0x231e0eaf, 0x1c1e0e23, 0x1d154021,
  // [1130]
  0x16190412, 0x04000520, 0x19210412, 0x17001514,
  0x140b16ad, 0x12451712, 0x0c002212, 0x10002713,
  0x27082920, 0x451d40ad, 0x041719bb, 0x22001611,
  0x45401d14, 0x041608cf, 0x0f180507, 0x1d001508,
  // [1140]
  0x04001935, 0x1d124522, 0x224512be, 0x01000523,
  0x06000222, 0x0c2701ad, 0x17002714, 0x21002212,
  0x084504ad, 0x27211412, 0x04161912, 0x160c21a4,
  0x0f0d38bc, 0x1d002707, 0x041408bc, 0x15161921,
  // [1150]
  0x27211821, 0x0b1922bc, 0x021938ac, 0x10060120,
  0x00001e2d, 0x03000114, 0x121d0512, 0x401927bc,
  0x21001433, 0x01143820, 0x401d4560, 0x40121507,
  0x27080f22, 0x161d17ac, 0x231c1e11, 0x03161707,
  // [1160]
  0x19000121, 0x08001813, 0x43002711, 0x170f0daf,
  0x380d1721, 0x04031922, 0x401d06a4, 0x19270412,
  0x14000613, 0x01271612, 0x1d0c1212, 0x06000507,
  0x19010612, 0x0b000512, 0x401d01af, 0x14000633,
  // [1170]
  0x080f056f, 0x19000307, 0x220443ba, 0x06001020,
  0x02002121, 0x100f0b34, 0x27190112, 0x43000135,
  0x210801be, 0x45401d12, 0x22451260, 0x21222722,
  0x45401212, 0x17190411, 0x22001622, 0x18004523,
  // [1180]
  0x45051d12, 0x17001911, 0x18190412, 0x16020b21,
  0x19001420, 0x0d0105ad, 0x0d011421, 0x1d001613,
  0x010d0f20, 0x05000214, 0x0f0d016f, 0x140610ac,
  0x0d173812, 0x231c0e20, 0x01222107, 0x45001907,
  // [1190]
  0x0d001d07, 0x1d1215bc, 0x08001d13, 0x1c230e14,
  0x19002709, 0x05180807, 0x101422bc, 0x27001d13,
  0x380d0512, 0x08381612, 0x15081912, 0x21000808,
  0x381517ad, 0x12004511, 0x0f0d05ac, 0x45060112,
  // [11a0]
  0x15001620, 0x06000d14, 0x0e001e09, 0x22001a22,
  0x27170312, 0x27002921, 0x10001814, 0x19001d07,
  0x38221913, 0x17000f34, 0x38000114, 0x0827016f,
  0x0000040a, 0x17004512, 0x12000d20, 0x06001808,
  // [11b0]
  0x1e0e1c08, 0x40163809, 0x15001d11, 0x050801bc,
  0x01380523, 0x121d4014, 0x02001413, 0x06011812,
  0x17161520, 0x181004ad, 0x06002721, 0x03180120,
  0x010f0d60, 0x0d0f2721, 0x21001d13, 0x10005122,
  // [11c0]
  0x0d001522, 0x124501bb, 0x14000414, 0x052701cf,
  0x170d0523, 0x01060312, 0x27170112, 0x19020121,
  0x27001509, 0x18000413, 0x450418ad, 0x1d0d4011,
  0x15000312, 0x18000f08, 0x020b16af, 0x0d170512,
  // [11d0]
  0x020301af, 0x04001813, 0x17001d13, 0x22002707,
  0x21451213, 0x0c004021, 0x15001610, 0x27000412,
  0x1800041f, 0x231e1c13, 0x170d0fbc, 0x0b020613,
  0x4504216f, 0x454002be, 0x27170820, 0x45000d11,
  // [11e0]
  0x230e1c13, 0x21000c13, 0x38170822, 0x19001411,
  0x0f000508, 0x050208cf, 0x16010c07, 0x451218ad,
  0x401d19af, 0x1d401912, 0x180f38af, 0x1d001511,
  0x18000f13, 0x0e1c1eac, 0x0f183821, 0x451218ac,
  // [11f0]
  0x04001220, 0x18003834, 0x270b0412, 0x16002113,
  0x01001022, 0x04001213, 0x18004020, 0x27000c12,
  0x38000f12, 0x12401d12, 0x17380d12, 0x060108af,
  0x40121d12, 0x01001811, 0x16002122, 0x12000512,
  // [1200]
  0x430d01ac, 0x12401dad, 0x1d004312, 0x01001914,
  0x0b001023, 0x03000f20, 0x150419bc, 0x0c001d14,
  0x0f083860, 0x38000f13, 0x03001712, 0x18004522,
  0x45003811, 0x1d002711, 0x06271908, 0x230e1cad,
  // [1210]
  0x01000322, 0x40000d12, 0x030521ac, 0x401922af,
  0x0f001813, 0x21001521, 0x0f172112, 0x05000f07,
  0x02100bad, 0x0d001512, 0x15221d60, 0x1d1622bc,
  0x22004020, 0x45380c08, 0x451217ad, 0x03001521,
  // [1220]
  0x12001411, 0x27181712, 0x04000c12, 0x02002120,
  0x020b0312, 0x01404512, 0x0f124507, 0x0c011021,
  0x21152712, 0x27213813, 0x0b031560, 0x1c230ebc,
  0x06004021, 0x18000511, 0x19000614, 0x020b0321,
  // [1230]
  0x0d123807, 0x21062712, 0x0f001211, 0x40171d21,
  0x18001221, 0x05030112, 0x22000d11, 0x1d404521,
  0x150c0313, 0x12180507, 0x38000311, 0x19121da4,
  0x1e0e23a4, 0x16451214, 0x05010308, 0x0b451211,
  // [1240]
  0x0e1c1e07, 0x0110146f, 0x45381807, 0x1200450e,
  0x01061812, 0x38001813, 0x0b271d11, 0x1d002107,
  0x40102160, 0x120d0f6b, 0x05001634, 0x22001014,
  0x40001212, 0x0d08226f, 0x18002120, 0x00001803,
  // [1250]
  0x0d4017bc, 0x43401512, 0x180445af, 0x19000d20,
  0x21001012, 0x1d001813, 0x191421be, 0x0c1217a0,
  0x121845ac, 0x1d0c1821, 0x0c0d10ad, 0x0f0d1812,
  0x0d100612, 0x14060360, 0x10000113, 0x19004512,
  // [1260]
  0x12450207, 0x45161921, 0x45030112, 0x45044009,
  0x18060312, 0x0f010c12, 0x171519a4, 0x03000102,
  0x18000113, 0x27000121, 0x19124512, 0x08002207,
  0x171921ad, 0x04192760, 0x01010107, 0x10140623,
  // [1270]
  0x43182212, 0x0e1e1cbe, 0x040c27ad, 0x380227ad,
  0x0f0d0512, 0x18190121, 0x021027cf, 0x1d001912,
  0x0f050821, 0x0f2714be, 0x06380107, 0x19000821,
  0x0d001810, 0x0b101412, 0x45002112, 0x01050ca4,
  // [1280]
  0x05041711, 0x120c4513, 0x141922ac, 0x03001407,
  0x06380d12, 0x0d3827a4, 0x03061055, 0x19002120,
  0x01160302, 0x01140460, 0x18120609, 0x08001614,
  0x08003812, 0x1c1e23bb, 0x031918ad, 0x164519af,
  // [1290]
  0x38000814, 0x06031821, 0x03402112, 0x01001809,
  0x010219a4, 0x0b0516bb, 0x0c100b07, 0x40031821,
  0x0b191811, 0x0b101907, 0x120f0c12, 0x05000109,
  0x082101ad, 0x15000f12, 0x21011212, 0x160c1511,
  // [12a0]
  0x22030c07, 0x144318ad, 0x271d406f, 0x0c000607,
  0x220306ad, 0x01042121, 0x40002722, 0x18150422,
  0x0b000507, 0x220b0360, 0x0b031812, 0x12000413,
  0x01002220, 0x0d380811, 0x05000123, 0x40000c13,
  // [12b0]
  0x1d001221, 0x3818156f, 0x38182707, 0x040c1521,
  0x0e1e1c08, 0x080105ac, 0x0c0416ad, 0x1d001721,
  0x19001812, 0x401d126f, 0x0c081722, 0x22001522,
  0x14001712, 0x27192121, 0x0f270412, 0x0f050112,
  // [12c0]
  0x380d27af, 0x10001520, 0x0d0c2221, 0x06001913,
  0x050c0421, 0x17000112, 0x08381713, 0x45001012,
  0x03002713, 0x17000c12, 0x1d120cbc, 0x08140612,
  0x052127ad, 0x12434514, 0x43141812, 0x020b1912,
  // [12d0]
  0x0f164034, 0x22004011, 0x1c231e6f, 0x032722ad,
  0x190b0612, 0x08012212, 0x40004533, 0x27001514,
  0x0c451211, 0x270f2120, 0x27001520, 0x06012134,
  0x27060cbc, 0x271051af, 0x10000112, 0x45000613,
  // [12e0]
  0x08001220, 0x401d0411, 0x450c1807, 0x19270f09,
  0x010603ac, 0x03080112, 0x08001821, 0x12450c21,
  0x19001807, 0x40000111, 0x38000111, 0x0f080107,
  0x012719bc, 0x451d4023, 0x17192760, 0x380106a4,
  // [12f0]
  0x012119bc, 0x45001d13, 0x1e0e1c23, 0x03000507,
  0x05450c60, 0x04081912, 0x21190209, 0x02182402,
  0x08451212, 0x04000f20, 0x1e0e2313, 0x06000407,
  0x04021407, 0x0410066f, 0x05060107, 0x16001d11,
  // [1300]
  0x160117bc, 0x0f170507, 0x162101af, 0x0d010612,
  0x19020b07, 0x03120107, 0x00001903, 0x400c1dbe,
  0x27000d22, 0x0c401d23, 0x0c1d40be, 0x10005113,
  0x0e1c1ebb, 0x15001920, 0x1c000e02, 0x19001714,
  // [1310]
  0x19000410, 0x060b14ac, 0x08190413, 0x38001920,
  0x14000622, 0x1d004520, 0x06002712, 0x01121712,
  0x0f0c176f, 0x100b1412, 0x03270611, 0x0b191812,
  0x0000430a, 0x02381812, 0x05381813, 0x06000b21,
  // [1320]
  0x04191820, 0x0b0c02ac, 0x0c030112, 0x08000233,
  0x06001208, 0x050614af, 0x01001912, 0x1c002335,
  0x45001d22, 0x04270111, 0x01100621, 0x190b1433,
  0x0322016f, 0x1e0e1caf, 0x030b0408, 0x04001010,
  // [1330]
  0x10000421, 0x1e231c23, 0x27140422, 0x19042714,
  0x03271412, 0x38270812, 0x0f000c12, 0x0c002111,
  0x1d000812, 0x011d0c12, 0x0f1805ac, 0x1d041512,
  0x380f0dbc, 0x03050420, 0x190415af, 0x38271921,
  // [1340]
  0x19030512, 0x06032720, 0x151922be, 0x031712bc,
  0x10381812, 0x171012be, 0x45001d11, 0x1d122121,
  0x010605af, 0x0f3812af, 0x450817af, 0x14222121,
  0x0f004512, 0x380f22af, 0x40000f22, 0x16001522,
  // [1350]
  0x12451622, 0x0c000d11, 0x01400c34, 0x0c4004bc,
  0x22274321, 0x43000c07, 0x18004512, 0x1e1c0ebb,
  0x40121dad, 0x10001413, 0x06143812, 0x12003812,
  0x08000f08, 0x40451209, 0x08002111, 0x190c0b09,
  // [1360]
  0x14000202, 0x0f001708, 0x27042112, 0x14000813,
  0x191427ac, 0x01001821, 0x38451211, 0x06000309,
  0x0d0f38a4, 0x40001714, 0x04003822, 0x06080208,
  0x15191608, 0x062245a4, 0x08010612, 0x16001508,
  // [1370]
  0x1545401f, 0x12004023, 0x45000c34, 0x0b002711,
  0x38004513, 0x0b001d20, 0x06013808, 0x220b1912,
  0x18000521, 0x1d000b13, 0x19001613, 0x1e1c2311,
  0x100b02a4, 0x16002714, 0x04100611, 0x230e1c14,
  // [1380]
  0x0d002113, 0x18001921, 0x03002922, 0x21080121,
  0x381006ac, 0x45180513, 0x01050834, 0x38000514,
  0x43080f82, 0x120518bb, 0x0d010512, 0x0b001907,
  0x012104bc, 0x0f050134, 0x104306ac, 0x01221912,
  // [1390]
  0x231c1eaf, 0x06052720, 0x16001923, 0x1d214521,
  0x0d162721, 0x0d002720, 0x0c001212, 0x06000820,
  0x02001912, 0x12000f07, 0x401d1560, 0x14001921,
  0x151918bc, 0x27000813, 0x041921bc, 0x45170813,
  // [13a0]
  0x020b1421, 0x03002212, 0x12001520, 0x12001d11,
  0x18041911, 0x10124012, 0x0c000122, 0x10030621,
  0x100b1212, 0x0d451207, 0x18222714, 0x0f012212,
  0x0f0d2721, 0x450419ac, 0x271d40af, 0x02000308,
  // [13b0]
  0x18004521, 0x12002722, 0x1d0b0121, 0x0f000d11,
  0x12004536, 0x18061212, 0x400b5133, 0x27002135,
  0x14001810, 0x27002123, 0x06002120, 0x05270121,
  0x10001414, 0x02002721, 0x15001623, 0x12450f08,
  // [13c0]
  0x450d0f55, 0x38001711, 0x0d0f05ad, 0x10020b13,
  0x432127be, 0x0b000613, 0x06000c14, 0x0b003813,
  0x01223821, 0x06010c21, 0x050106ac, 0x38000807,
  0x16000d11, 0x38000811, 0x0c001507, 0x15140321,
  // [13d0]
  0x21000421, 0x0f000d20, 0x10000620, 0x06140322,
  0x140b1020, 0x0d001213, 0x04060112, 0x0b005121,
  0x05191612, 0x0d050307, 0x17000410, 0x06012212,
  0x19041807, 0x04002113, 0x08003823, 0x04002221,
  // [13e0]
  0x02061021, 0x04000609, 0x08004508, 0x231e1c6f,
  0x010f05ac, 0x14061021, 0x08380d12, 0x0c001607,
  0x12001d08, 0x38170d07, 0x40001820, 0x020b01be,
  0x03004011, 0x1d000814, 0x1e1c2355, 0x0b1401be,
  // [13f0]
  0x0e231eaf, 0x0d000f36, 0x04000312, 0x1d080c21,
  0x16000c23, 0x10400812, 0x12401d20, 0x140b51be,
  0x18000d1f, 0x18001912, 0x1d4540bb, 0x0d001814,
  0x03060121, 0x17013809, 0x0f0d3855, 0x100219be,

  // [1400]
  0x0f010d12, 0x3800181f, 0x01191060, 0x1d004311,
  0x1d1940bc, 0x19000634, 0x38001007, 0x19002211,
  0x12450c11, 0x01012407, 0x1d124512, 0x45001d1d,
  0x15100ba4, 0x19272211, 0x19002208, 0x45000f14,
  // [1410]
  0x0d0f06ad, 0x06000212, 0x21000614, 0x45210112,
  0x19120421, 0x12002207, 0x17001808, 0x05012212,
  0x1d000613, 0x22001022, 0x01021012, 0x19001407,
  0x15182112, 0x181d15ad, 0x17121921, 0x150c16be,
  // [1420]
  0x19402712, 0x101521be, 0x1d150821, 0x1e0e23bb,
  0x40001614, 0x21171960, 0x1d16400c, 0x45030c21,
  0x0c001710, 0x1c231ebb, 0x020b19cf, 0x27161921,
  0x18272121, 0x43000411, 0x030419af, 0x1d004513,
  // [1430]
  0x1d000c22, 0x010f0d08, 0x1d404523, 0x19212712,
  0x190f3813, 0x1c1e0ea4, 0x0c001810, 0x14451211,
  0x1c000e35, 0x01100421, 0x40000c11, 0x01060faf,
  0x06000420, 0x1800031f, 0x02002211, 0x0c0301a4,
  // [1440]
  0x19001707, 0x06002722, 0x02001714, 0x05380121,
  0x19001408, 0x27000423, 0x03002723, 0x04000614,
  0x1d002207, 0x40001022, 0x0c451222, 0x06021055,
  0x0c0601a4, 0x0b0204bc, 0x040b026f, 0x0f1418ac,
  // [1450]
  0x05020baf, 0x020b51af, 0x10002207, 0x03002734,
  0x04000820, 0x08380121, 0x40001512, 0x0c000111,
  0x120c0121, 0x4012456f, 0x0c210121, 0x18000334,
  0x38171807, 0x380f01be, 0x190118ad, 0x1400181d,
  // [1460]
  0x06101807, 0x1d124023, 0x16270460, 0x142704ad,
  0x06191807, 0x042219ad, 0x0b061621, 0x380c1920,
  0x401d0c12, 0x04061421, 0x140b1011, 0x05041922,
  0x19002720, 0x10140312, 0x0c001412, 0x19001811,
  // [1470]
  0x27001814, 0x1d001411, 0x1d004523, 0x02100407,
  0x0b050314, 0x19000622, 0x18060d60, 0x22191dad,
  0x231c0ebb, 0x19380512, 0x061840ad, 0x0e1e1c20,
  0x14451260, 0x14000313, 0x0f3808ce, 0x16002713,
  // [1480]
  0x1e230e23, 0x18380612, 0x08040512, 0x06000807,
  0x1d0815ad, 0x451206ad, 0x401d0c07, 0x1d4301ad,
  0x01190311, 0x0b000208, 0x0d000612, 0x04190612,
  0x03221820, 0x04192221, 0x05192208, 0x0b221934,
  // [1490]
  0x38050108, 0x01001407, 0x27000111, 0x271701af,
  0x06031410, 0x27001422, 0x230e1e12, 0x01001913,
  0x0e001e23, 0x21271509, 0x062701ad, 0x0f01386f,
  0x0d010821, 0x0f190407, 0x17382708, 0x04061908,
  // [14a0]
  0x450d0f12, 0x1e1c2320, 0x43010507, 0x40001d33,
  0x0b2238be, 0x21001811, 0x1d050121, 0x021901be,
  0x1d181221, 0x0d171622, 0x15000612, 0x1d000b14,
  0x100b02bc, 0x19180121, 0x19042712, 0x063817ac,
  // [14b0]
  0x19000507, 0x451d406f, 0x05001536, 0x06000135,
  0x0c000123, 0x0b001022, 0x05041911, 0x21020122,
  0x191d01cf, 0x014019be, 0x020601bc, 0x21002213,
  0x0f001911, 0x230e1e22, 0x210b27af, 0x19000f08,
  // [14c0]
  0x1d164013, 0x22000421, 0x231e1c60, 0x14041934,
  0x14191d12, 0x14004512, 0x190204af, 0x22020b13,
  0x45080d07, 0x0d000811, 0x0c100322, 0x0c002708,
  0x0b000511, 0x38010fa4, 0x0f0401bc, 0x230e1eaf,
  // [14d0]
  0x0b0302be, 0x030b0223, 0x01003820, 0x08191021,
  0x01001812, 0x19002113, 0x040b02ad, 0x010f3812,
  0x45001807, 0x0f0d3821, 0x19010311, 0x030602bc,
  0x19001414, 0x0e1e23a4, 0x15001420, 0x0c002107,
  // [14e0]
  0x06030107, 0x0c161522, 0x0d380fad, 0x45180f60,
  0x101d4060, 0x180f1411, 0x1d4010be, 0x38030fac,
  0x061d0f12, 0x0103196f, 0x0e231caf, 0x10000320,
  0x191d2707, 0x16182208, 0x061d0312, 0x0d380f12,
  // [14f0]
  0x1d0d0f11, 0x1e231ca4, 0x0f451255, 0x45000f13,
  0x17001914, 0x06000813, 0x401d17af, 0x0c1d21ad,
  0x4045126f, 0x1d12456f, 0x15000421, 0x03020b6f,
  0x050c1d12, 0x38000f22, 0x0c272121, 0x0b060413,
  // [1500]
  0x080516a4, 0x0c142711, 0x22004007, 0x0d190121,
  0x1e1c0eac, 0x0d0f3810, 0x0f0d3813, 0x15271621,
  0x04162722, 0x04001011, 0x231e1c23, 0x04191807,
  0x01000309, 0x0f080d12, 0x16180412, 0x27000b20,
  // [1510]
  0x19210413, 0x17001214, 0x10000413, 0x04171d55,
  0x22001421, 0x1d002714, 0x080d1612, 0x020b1834,
  0x1d020521, 0x030104af, 0x08451207, 0x22000521,
  0x06000c20, 0x18450221, 0x151722ad, 0x190127ac,
  // [1520]
  0x06270112, 0x18030812, 0x12000212, 0x12031821,
  0x210b2221, 0x04272108, 0x0210141f, 0x100b02af,
  0x03000c12, 0x220b02af, 0x12020421, 0x18100baf,
  0x0d000812, 0x04271820, 0x1d004034, 0x0b105121,
  // [1530]
  0x380f08af, 0x05000412, 0x22000f13, 0x27001d14,
  0x1e231c6f, 0x27000414, 0x19020322, 0x19030c12,
  0x15042212, 0x0b2218ad, 0x14004533, 0x02001013,
  0x08210122, 0x010d0621, 0x0f041913, 0x05001821,
  // [1540]
  0x1d1712be, 0x0f002222, 0x03000c33, 0x231c1e6f,
  0x18001208, 0x19000408, 0x161d4013, 0x17161921,
  0x17003822, 0x02001212, 0x22004012, 0x030801a4,
  0x27190312, 0x12001d14, 0x1c002310, 0x1d0322bc,
  // [1550]
  0x03101420, 0x16000611, 0x43002211, 0x171d15ac,
  0x40081d21, 0x22030611, 0x051d1207, 0x0d401d13,
  0x27004021, 0x080d3821, 0x0c120455, 0x1d001520,
  0x22000d12, 0x1c1e2355, 0x0c451255, 0x12030112,
  // [1560]
  0x450b06a4, 0x433805a4, 0x06020b21, 0x45124007,
  0x18050112, 0x060110ad, 0x06040209, 0x22061412,
  0x190d0412, 0x03001607, 0x10140421, 0x05060411,
  0x16001534, 0x010f1612, 0x162717ad, 0x0c381512,
  // [1570]
  0x08151012, 0x12041921, 0x380f1221, 0x380f0821,
  0x1c0e23bb, 0x140315ad, 0x081615be, 0x1d400c12,
  0x4516156f, 0x45000435, 0x0b192755, 0x14273812,
  0x03002720, 0x1d1427af, 0x0c122713, 0x45211620,
  // [1580]
  0x170d0821, 0x15062713, 0x22451421, 0x38001721,
  0x17083812, 0x17003814, 0x382722be, 0x060301bc,
  0x0b1006a4, 0x0c1d4007, 0x19062212, 0x06010321,
  0x0b0106be, 0x05172712, 0x19010312, 0x21192712,
  // [1590]
  0x40001908, 0x08160bac, 0x0d004313, 0x120c0812,
  0x05004311, 0x14001608, 0x43000d11, 0x08001d21,
  0x16000413, 0x0415166f, 0x03001522, 0x00003801,
  0x03001520, 0x1c002309, 0x0b034308, 0x0000240a,
  // [15a0]
  0x04000c11, 0x052729a4, 0x15160311, 0x14080411,
  0x40181607, 0x22001614, 0x00000503, 0x040216a4,
  0x0d001633, 0x21182712, 0x06000822, 0x01141512,
  0x10140412, 0x0d1701bc, 0x1419046f, 0x151645be,
  // [15b0]
  0x01062711, 0x40002721, 0x27004022, 0x40002734,
  0x1c1e0e34, 0x01002211, 0x40002713, 0x27004014,
  0x271714bc, 0x1d402708, 0x05014012, 0x01224021,
  0x18003812, 0x19042213, 0x01402755, 0x0d1d0fbe,
  // [15c0]
  0x030615bc, 0x17401907, 0x140b03af, 0x030201bc,
  0x0d0619a4, 0x1d012207, 0x021d2212, 0x01080f07,
  0x1c0e23a4, 0x10271912, 0x050f1713, 0x0e1e1ca4,
  0x05000420, 0x06000811, 0x0b001d08, 0x211927be,
  // [15d0]
  0x06050108, 0x0b100107, 0x0c000807, 0x14451812,
  0x380d01af, 0x0f001608, 0x10030612, 0x45100260,
  0x01272113, 0x120c45be, 0x08190612, 0x0e1c23ad,
  0x021045be, 0x021006af, 0x10002111, 0x0d1d16ad,
  // [15e0]
  0x38050609, 0x0b1d03ac, 0x02000321, 0x04000f12,
  0x04000807, 0x041903bc, 0x14100b22, 0x19030420,
  0x10210322, 0x400c4534, 0x19160dbc, 0x082127bb,
  0x06042107, 0x10020b6f, 0x08170511, 0x01002207,
  // [15f0]
  0x121d1622, 0x17002111, 0x08000122, 0x052701be,
  0x18002111, 0x230e1e14, 0x22000812, 0x05101212,
  0x032218ac, 0x430f1412, 0x21000f35, 0x1815216f,
  0x380f02af, 0x030c0134, 0x08001408, 0x21000412,
  // [1600]
  0x18001d14, 0x27030112, 0x0f101913, 0x00000101,
  0x05010c07, 0x06181021, 0x380f0d6f, 0x080f2207,
  0x1900100d, 0x04001512, 0x38431abe, 0x10001808,
  0x19000520, 0x17002213, 0x45381509, 0x12101d09,
  // [1610]
  0x020601be, 0x03001611, 0x0e231c08, 0x220619ac,
  0x06000b08, 0x0e231c6f, 0x0d175121, 0x1d002120,
  0x160f0d09, 0x06000333, 0x06010cac, 0x0f0601a4,
  0x1c1e23bc, 0x1d124055, 0x1000191d, 0x1d401621,
  // [1620]
  0x08004021, 0x0d432107, 0x10001213, 0x0f381713,
  0x04000821, 0x22000f08, 0x063803ac, 0x032719bb,
  0x17000507, 0x01190312, 0x031701bc, 0x38001922,
  0x05000322, 0x080d05bb, 0x02000b08, 0x1d454060,
  // [1630]
  0x124045ba, 0x0b18026f, 0x1d120c07, 0x19001022,
  0x10005134, 0x1d182712, 0x18002133, 0x03011020,
  0x17001d21, 0x05081812, 0x401d4521, 0x19081507,
  0x05030107, 0x45001612, 0x08212720, 0x181d40ac,
  // [1640]
  0x0d002214, 0x013808ac, 0x27002114, 0x14100b6f,
  0x021017ac, 0x02065134, 0x05143821, 0x380106ad,
  0x080f2107, 0x062701bb, 0x0f0c1d60, 0x08000610,
  0x03060c6f, 0x380d51be, 0x16083882, 0x220f0d6f,
  // [1650]
  0x22210455, 0x16060408, 0x22001911, 0x01000622,
  0x0c001808, 0x01272122, 0x21271822, 0x15160112,
  0x100d2721, 0x17382722, 0x17030622, 0x05381722,
  0x16000822, 0x0d000420, 0x27173834, 0x18212734,
  // [1660]
  0x38080d21, 0x06001509, 0x05000313, 0x08380612,
  0x16012712, 0x050608be, 0x21001921, 0x40124514,
  0x141d1920, 0x0f001808, 0x14020b13, 0x16002123,
  0x162721be, 0x060221af, 0x0f001712, 0x01171921,
  // [1670]
  0x03210caf, 0x1e230e14, 0x01032121, 0x00000603,
  0x01170820, 0x43000520, 0x0f1917af, 0x0c271412,
  0x03000c02, 0x14401909, 0x08000514, 0x22000312,
  0x21272223, 0x38000d23, 0x0c004007, 0x22042107,
  // [1680]
  0x224504a4, 0x22030608, 0x00003803, 0x04000607,
  0x1d191007, 0x38000412, 0x02051912, 0x171627af,
  0x060b1021, 0x03061007, 0x04151655, 0x02062221,
  0x020d0121, 0x451427be, 0x050817be, 0x161838be,
  // [1690]
  0x05080612, 0x0b001407, 0x04001511, 0x060b1007,
  0x10021412, 0x18002112, 0x160f2112, 0x162127ce,
  0x0e1e2314, 0x10081421, 0x14272212, 0x1c1e0e13,
  0x14002211, 0x062703bb, 0x15002113, 0x19000b12,
  // [16a0]
  0x19001d12, 0x0c064021, 0x45120621, 0x1c230eac,
  0x0f030113, 0x06101823, 0x0b000221, 0x231e1cbe,
  0x01180312, 0x230e1cbb, 0x18191022, 0x06050112,
  0x380551be, 0x1e001c35, 0x17050b21, 0x05020b09,
  // [16b0]
  0x451204be, 0x17060107, 0x14432721, 0x18000123,
  0x17004021, 0x080301af, 0x18004312, 0x050c0411,
  0x12002112, 0x27061912, 0x10001821, 0x1406036b,
  0x270f0512, 0x0b171807, 0x0f010513, 0x27192214,
  // [16c0]
  0x15001d09, 0x16151d12, 0x0b030412, 0x02000622,
  0x06010212, 0x40000107, 0x21271812, 0x0d0f2212,
  0x0c050108, 0x02000807, 0x16022221, 0x19022221,
  0x451d4011, 0x16172708, 0x14212711, 0x0b151621,
  // [16d0]
  0x22002107, 0x10000b07, 0x06272212, 0x40121daf,
  0x1d0818ad, 0x16000407, 0x15221621, 0x06270c12,
  0x062210af, 0x220b1012, 0x0d0f3860, 0x401d1612,
  0x0c451207, 0x1e1c0ebc, 0x21001812, 0x190f0d60,
  // [16e0]
  0x16004507, 0x04001607, 0x43001412, 0x380f03af,
  0x22021907, 0x0c1d406f, 0x1c0e1ead, 0x17450107,
  0x010c0fa4, 0x08000d21, 0x12061712, 0x060522ad,
  0x12272160, 0x190d16ac, 0x0c081d09, 0x17000521,
  // [16f0]
  0x020601bb, 0x1d010caf, 0x1245156f, 0x08380c21,
  0x0b0201af, 0x40451612, 0x151d0311, 0x14000c07,
  0x01000c20, 0x21001622, 0x10211913, 0x230e1c22,
  0x380c1260, 0x1e230e60, 0x21000408, 0x06180411,
  // [1700]
  0x1c231e22, 0x1e001c10, 0x180538be, 0x451d1612,
  0x04272160, 0x06270323, 0x17014512, 0x1c230ead,
  0x19060807, 0x17000611, 0x38001713, 0x080501ac,
  0x0c12456f, 0x06212712, 0x121d4008, 0x18000c11,
  // [1710]
  0x430401af, 0x19000611, 0x14000b23, 0x17060322,
  0x12000311, 0x1d004508, 0x060301be, 0x1d001407,
  0x12000309, 0x19002708, 0x0b030109, 0x010d0f12,
  0x060801a4, 0x0600100d, 0x101822ba, 0x381703bc,
  // [1720]
  0x15123812, 0x04000b08, 0x01030609, 0x01080521,
  0x12000307, 0x01000811, 0x22001814, 0x19001608,
  0x1e1c0e13, 0x15164023, 0x05000811, 0x0b021407,
  0x16191512, 0x43000307, 0x0d190807, 0x0b190612,
  // [1730]
  0x19000312, 0x06020b22, 0x02001411, 0x02100614,
  0x0b140212, 0x16001535, 0x02100b22, 0x14180612,
  0x19272121, 0x451d0c12, 0x1d000412, 0x010c1712,
  0x06000b20, 0x06012708, 0x16124520, 0x230e1e08,
  // [1740]
  0x12401d21, 0x45121dad, 0x0b030207, 0x45121dbc,
  0x14100b20, 0x08000c11, 0x15001d21, 0x38190422,
  0x02000313, 0x03020107, 0x01210411, 0x1d000320,
  0x010d0612, 0x18001513, 0x27000d13, 0x1d400355,
  // [1750]
  0x121d1612, 0x141803ad, 0x18000312, 0x02062121,
  0x05001613, 0x27001213, 0x18140412, 0x06141611,
  0x15000412, 0x22272121, 0x270d2121, 0x12152260,
  0x0c000d22, 0x0d0f1dac, 0x01000207, 0x182238af,
  // [1760]
  0x381701ad, 0x14004312, 0x22001d08, 0x011d0612,
  0x380f0411, 0x12180c12, 0x380f0c13, 0x01001d13,
  0x17000122, 0x06001032, 0x2200181f, 0x190b0120,
  0x12021955, 0x231c1e08, 0x15000621, 0x16010312,
  // [1770]
  0x19010313, 0x08040107, 0x05011712, 0x16451212,
  0x45001d14, 0x010f0812, 0x16081daf, 0x081d40bc,
  0x08030107, 0x1d210111, 0x12454014, 0x0d030107,
  0x010d1712, 0x0f0318a4, 0x27001813, 0x17010caf,
  // [1780]
  0x451d4082, 0x023803bc, 0x0f001521, 0x01102212,
  0x080d0513, 0x08270112, 0x081701bc, 0x10210112,
  0x00001415, 0x12051707, 0x0f0d2112, 0x10450caf,
  0x17000322, 0x10000c12, 0x03002107, 0x1e002309,
  // [1790]
  0x21401607, 0x43000111, 0x16001921, 0x0b210222,
  0x0d0227ac, 0x0f000307, 0x22270660, 0x020b1022,
  0x021018af, 0x01380307, 0x45004014, 0x10001211,
  0x04000c13, 0x10222707, 0x1d16156f, 0x0d380faf,
  // [17a0]
  0x0c121d13, 0x12002212, 0x0d000112, 0x45004020,
  0x12450cbc, 0x19001814, 0x1d000d08, 0x16151d60,
  0x17380107, 0x0f080612, 0x01221807, 0x01431907,
  0x044512af, 0x06020112, 0x05271dad, 0x1e0e2311,
  // [17b0]
  0x05401d12, 0x0d001414, 0x01000b07, 0x0c001012,
  0x1d002214, 0x08052712, 0x06101612, 0x15181907,
  0x14000b09, 0x38081709, 0x060319bc, 0x01400607,
  0x05401d60, 0x1d000d12, 0x0d380507, 0x0f010512,
  // [17c0]
  0x170d0460, 0x16000c07, 0x45380fa4, 0x01031007,
  0x16001d09, 0x19001008, 0x16001d08, 0x18000212,
  0x15000311, 0x19000308, 0x14000c13, 0x01062212,
  0x10002112, 0x401d1912, 0x45120509, 0x0c000b12,
  // [17d0]
  0x08060507, 0x050810bc, 0x40000823, 0x190804ac,
  0x18001012, 0x05000d09, 0x0c003807, 0x27000d12,
  0x0c124522, 0x0d380f09, 0x12100c11, 0x1c231e11,
  0x45401214, 0x10020c12, 0x1e000e08, 0x100b06ad,
  // [17e0]
  0x23000e02, 0x08000107, 0x012721be, 0x05010307,
  0x15080621, 0x05000414, 0x01000c08, 0x08180b55,
  0x17000313, 0x041001af, 0x124540ad, 0x050f0cac,
  0x10124508, 0x12050121, 0x05001209, 0x45120521,
  // [17f0]
  0x19011dac, 0x124518af, 0x22001810, 0x060427bc,
  0x0d2208bb, 0x0d0f0509, 0x370e23bb, 0x0b030611,
  0x08124560, 0x02000514, 0x451d4022, 0x01380512,
  0x02000314, 0x010d27bc, 0x1e002323, 0x10020b60,

  // [1800]
  0x06080411, 0x08380d6f, 0x06030160, 0x19000c08,
  0x45000c08, 0x17001d22, 0x100618ab, 0x05181911,
  0x381505af, 0x05001021, 0x050138bb, 0x27000c21,
  0x401815bb, 0x27211921, 0x12000407, 0x1d001620,
  // [1810]
  0x380105bc, 0x140406ad, 0x2219146f, 0x38011912,
  0x40151da4, 0x0f140212, 0x18161521, 0x21000c23,
  0x0d0301a4, 0x04000c07, 0x22401d21, 0x19001520,
  0x230e1e55, 0x0b0d0207, 0x0f0d0413, 0x04180512,
  // [1820]
  0x010f15ac, 0x06041812, 0x18000522, 0x160d04ac,
  0x19051821, 0x43000c13, 0x19003822, 0x01080608,
  0x03000b22, 0x45004008, 0x08041912, 0x0d0f27ad,
  0x040210ac, 0x19404507, 0x15001012, 0x14000f12,
  // [1830]
  0x120c1407, 0x40001d09, 0x1c0e1ebc, 0x45401daf,
  0x020801ad, 0x0d001912, 0x012718bc, 0x22030621,
  0x1d002223, 0x23001e33, 0x15401d12, 0x27211012,
  0x10060b11, 0x06001407, 0x053801bc, 0x2714216f,
  // [1840]
  0x18451413, 0x452717bb, 0x22211721, 0x0c2217bb,
  0x45001614, 0x06272111, 0x0e1e2320, 0x03000220,
  0x22011712, 0x19000320, 0x0f002113, 0x19211722,
  0x22001723, 0x212717bc, 0x030105ac, 0x06003820,
  // [1850]
  0x45000f20, 0x1d001209, 0x1d00121d, 0x0b222160,
  0x18000d09, 0x182719af, 0x08271921, 0x27000621,
  0x27000622, 0x43000621, 0x27000623, 0x1d191611,
  0x1d041511, 0x40000307, 0x10000107, 0x27000634,
  // [1860]
  0x222127ad, 0x15030208, 0x1d002720, 0x0000160a,
  0x1d4015af, 0x121d4010, 0x16270420, 0x18004307,
  0x0b000612, 0x170d01be, 0x06120112, 0x060419ac,
  0x18000f07, 0x12001610, 0x0f001714, 0x0b000236,
  // [1870]
  0x02100baf, 0x430508bc, 0x10041907, 0x17000220,
  0x0c401012, 0x380117ad, 0x15000620, 0x0b272112,
  0x01001d12, 0x06190812, 0x080d1d12, 0x060302be,
  0x222729be, 0x151d4012, 0x02000311, 0x02011721,
  // [1880]
  0x15000420, 0x04270612, 0x190403bb, 0x04003820,
  0x1e231c60, 0x19000b13, 0x03001907, 0x270f0d13,
  0x210d0f22, 0x04151660, 0x080d19ad, 0x0d381921,
  0x02001014, 0x231e1c55, 0x04191007, 0x08002112,
  // [1890]
  0x01051712, 0x0b001412, 0x14001612, 0x0c2101ad,
  0x18000614, 0x041914af, 0x1c231e07, 0x081d0421,
  0x10001935, 0x10000211, 0x0c001823, 0x01002222,
  0x45001514, 0x141204ad, 0x0b002207, 0x16001421,
  // [18a0]
  0x06210111, 0x0f0d0812, 0x080f17a4, 0x03080511,
  0x0d141810, 0x0b010412, 0x12002120, 0x051506ac,
  0x0f184509, 0x010f0521, 0x061804ad, 0x0f1d4512,
  0x05001812, 0x0c000d12, 0x060d1521, 0x14004012,
  // [18b0]
  0x0c001522, 0x17002711, 0x05451212, 0x1404196d,
  0x050d0f21, 0x1214456f, 0x21145121, 0x40004513,
  0x101727bc, 0x45121d60, 0x06002223, 0x08050107,
  0x17080512, 0x03000213, 0x05380f13, 0x19031604,
  // [18c0]
  0x12001921, 0x190b16be, 0x06001022, 0x170b19be,
  0x0d011711, 0x08401d20, 0x020b10ad, 0x04001412,
  0x100b19cf, 0x01041912, 0x01000308, 0x060c0307,
  0x0b060309, 0x17002112, 0x011019a4, 0x05080107,
  // [18d0]
  0x10010baf, 0x1e0e2320, 0x0d0f3823, 0x0b001009,
  0x0b0210ad, 0x0e1e1c5e, 0x05010cac, 0x05001809,
  0x10020b14, 0x174322ac, 0x1d001622, 0x192127be,
  0x191d4013, 0x02100bce, 0x0b100207, 0x1d274014,
  // [18e0]
  0x080d21be, 0x1d0f04ac, 0x27001d08, 0x0c061012,
  0x100b51af, 0x06101412, 0x060b10af, 0x40000213,
  0x04000d21, 0x03001021, 0x10001620, 0x0d0121ac,
  0x0d080f12, 0x04002114, 0x14042121, 0x161d22ad,
  // [18f0]
  0x04002120, 0x01001020, 0x02180412, 0x161014a4,
  0x40271dbe, 0x12401d6f, 0x1d124012, 0x0e001c35,
  0x0d1d1212, 0x401d1213, 0x1d002733, 0x06140bac,
  0x041619be, 0x121d0812, 0x100b0c08, 0x27001721,
  // [1900]
  0x04001008, 0x04010fbb, 0x451240bb, 0x22100660,
  0x381d01a4, 0x0b1810ad, 0x0c124523, 0x1e1c0e02,
  0x02001612, 0x05000f20, 0x0f000512, 0x06080c12,
  0x0c0801af, 0x16001012, 0x45120c21, 0x27002912,
  // [1910]
  0x16050f12, 0x161719ad, 0x08050f21, 0x1c0e2320,
  0x0b000311, 0x02220307, 0x1d041912, 0x04140c12,
  0x061d1409, 0x434505ad, 0x0c011d12, 0x270f0612,
  0x010d0cad, 0x0e1c1e33, 0x27010812, 0x27010cbb,
  // [1920]
  0x0b010821, 0x27000814, 0x19450812, 0x0b160212,
  0x0f0108bc, 0x0d050412, 0x0d272920, 0x0d1d0cad,
  0x16000f12, 0x150316ad, 0x43000607, 0x43001421,
  0x1d0508ad, 0x08001708, 0x1d1940a4, 0x10001712,
  // [1930]
  0x0d1508af, 0x14000c11, 0x23001c21, 0x0d0f0812,
  0x1e231c09, 0x451243af, 0x45000d07, 0x27222160,
  0x45431208, 0x19100107, 0x19152714, 0x04191612,
  0x16080412, 0x0e1e1c13, 0x01053812, 0x180417ad,
  // [1940]
  0x1d000811, 0x1d0c0507, 0x15001d07, 0x02100b09,
  0x170f3821, 0x191d1012, 0x06100b07, 0x0f001d13,
  0x27001713, 0x0f0810be, 0x38000112, 0x27001022,
  0x10380212, 0x051d0112, 0x27010320, 0x01001721,
  // [1950]
  0x05001012, 0x0f1d1021, 0x08170308, 0x402710be,
  0x050c0f07, 0x010603a4, 0x05381021, 0x17051012,
  0x0c000f08, 0x40451d11, 0x10001512, 0x10001408,
  0x0f0d1412, 0x1d4017bc, 0x08001833, 0x08170509,
  // [1960]
  0x16221022, 0x18031412, 0x040d0f12, 0x45401d11,
  0x100f1921, 0x0d142113, 0x08041921, 0x0f190507,
  0x40101907, 0x220d0f14, 0x17121d07, 0x17040507,
  0x16001412, 0x0d191021, 0x0f080d22, 0x0d0614be,
  // [1970]
  0x050801ad, 0x030214bc, 0x02140312, 0x451d4007,
  0x06030bbe, 0x12001d20, 0x100b2221, 0x0b031012,
  0x18100212, 0x400817bc, 0x01060cac, 0x0622036f,
  0x17160c11, 0x17001213, 0x0c141612, 0x020b19af,
  // [1980]
  0x14002112, 0x221921ad, 0x01001620, 0x43190111,
  0x04140113, 0x17272221, 0x0c1d40ad, 0x14030dbc,
  0x210c0112, 0x05100107, 0x01000f21, 0x01001908,
  0x1e001c33, 0x450f27ac, 0x0d05016f, 0x0d000f10,
  // [1990]
  0x01004333, 0x02001023, 0x221d0c08, 0x03011920,
  0x18000f14, 0x0814106f, 0x02060bad, 0x150522af,
  0x161d4012, 0x27000812, 0x14001007, 0x43050112,
  0x17000811, 0x1d010513, 0x0e1c1e14, 0x0f0538be,
  // [19a0]
  0x04001507, 0x381d0d21, 0x0c032712, 0x0c000413,
  0x02040c20, 0x06001521, 0x401508af, 0x1d0b1012,
  0x40001620, 0x15002211, 0x19221021, 0x0f001620,
  0x05041612, 0x01000d11, 0x04101909, 0x010b0207,
  // [19b0]
  0x05081d08, 0x0c001013, 0x27401d6f, 0x1d001607,
  0x030406ad, 0x220f3807, 0x16271d12, 0x020b0dbe,
  0x401d1009, 0x451240af, 0x27001622, 0x0c000333,
  0x450c4021, 0x1e002335, 0x02000b36, 0x27000f22,
  // [19c0]
  0x05171912, 0x231e1c14, 0x01170833, 0x21020308,
  0x06001902, 0x38150155, 0x0d000114, 0x19001733,
  0x0e1e1c55, 0x14031908, 0x14100b60, 0x12002708,
  0x22000b08, 0x0e1e1c23, 0x18004514, 0x04002207,
  // [19d0]
  0x10000208, 0x231c0ead, 0x270f2214, 0x020601ad,
  0x062101ad, 0x18001212, 0x221815af, 0x0c000212,
  0x17210112, 0x06000512, 0x080519ad, 0x1d191612,
  0x0c270112, 0x19000822, 0x01191609, 0x45011208,
  // [19e0]
  0x45001407, 0x04161522, 0x0f170513, 0x0d080307,
  0x08001208, 0x18000208, 0x0f0105af, 0x38050621,
  0x082717ad, 0x05211712, 0x10002711, 0x27152220,
  0x010d0821, 0x0c1d4008, 0x27220420, 0x2716216f,
  // [19f0]
  0x23000e33, 0x02003811, 0x43061207, 0x12454021,
  0x1d161720, 0x0f001511, 0x0c124514, 0x10010312,
  0x1c1e0ead, 0x03143811, 0x27004012, 0x181d1912,
  0x0e1e23af, 0x40041921, 0x152719af, 0x15001923,
  // [1a00]
  0x080d0f22, 0x0b001620, 0x0c270baf, 0x19020ca4,
  0x1c1e236f, 0x06081d07, 0x030127af, 0x05002721,
  0x0f0d27be, 0x192701af, 0x401404bc, 0x10450812,
  0x02012712, 0x152738af, 0x0b100212, 0x1d100207,
  // [1a10]
  0x21271912, 0x060c0112, 0x0f171621, 0x080138be,
  0x1d2214af, 0x020b1011, 0x270d0421, 0x0b0210ac,
  0x152116be, 0x10020baf, 0x0c1d1507, 0x03172709,
  0x401d21bc, 0x22191612, 0x0b060412, 0x03000d07,
  // [1a20]
  0x0d0105af, 0x06450260, 0x1c1e2308, 0x22160f12,
  0x0f002214, 0x0c0306ad, 0x01050407, 0x16140fac,
  0x061901ad, 0x18191721, 0x01210222, 0x22271920,
  0x01380514, 0x17002220, 0x1d401623, 0x01182112,
  // [1a30]
  0x0f1804bc, 0x171d406f, 0x27001733, 0x18271721,
  0x03150512, 0x02100321, 0x10030d21, 0x191d4022,
  0x081d4020, 0x15190ca4, 0x121d40be, 0x020b1055,
  0x020b2712, 0x1d402221, 0x401d1812, 0x0c000d10,
  // [1a40]
  0x0c1d1712, 0x0b005135, 0x0d082712, 0x0e002336,
  0x0e1e1cad, 0x19004522, 0x01080c21, 0x0d380823,
  0x27050112, 0x12160c12, 0x451427ac, 0x190d21ad,
  0x00000842, 0x45000c07, 0x0e231e13, 0x271621af,
  // [1a50]
  0x38080508, 0x08380f20, 0x010b0220, 0x0b001d11,
  0x0f001921, 0x06001809, 0x19001235, 0x10060160,
  0x12184013, 0x38000107, 0x221615be, 0x0f381934,
  0x19001214, 0x00001403, 0x080f1907, 0x01381912,
  // [1a60]
  0x21120420, 0x011516ac, 0x120f4312, 0x18451207,
  0x101d2221, 0x18222134, 0x271821be, 0x1d152713,
  0x0f0d27bb, 0x212706be, 0x010d0f07, 0x060f2113,
  0x14000314, 0x101d1921, 0x060b0211, 0x14041534,
  // [1a70]
  0x02220412, 0x020b01a4, 0x0f001209, 0x1d061960,
  0x050316bb, 0x21010321, 0x0b100660, 0x101906ad,
  0x03061912, 0x19001d22, 0x23000e35, 0x0b100621,
  0x06001920, 0x10001921, 0x1d000420, 0x0b021012,
  // [1a80]
  0x0d401d20, 0x15000614, 0x38002707, 0x40001214,
  0x010604ac, 0x03060522, 0x0b0603af, 0x10080107,
  0x02010612, 0x08004511, 0x05000213, 0x06151812,
  0x06000408, 0x02220413, 0x05120122, 0x22402111,
  // [1a90]
  0x0c000307, 0x06000120, 0x0b010321, 0x0400100d,
  0x0b000111, 0x380601af, 0x0b2718ad, 0x14212721,
  0x12001412, 0x181245bc, 0x12030621, 0x15004013,
  0x270422af, 0x21000d08, 0x03010fac, 0x1d001921,
  // [1aa0]
  0x10004021, 0x38000813, 0x020b1020, 0x38000f11,
  0x19150412, 0x03000821, 0x03061521, 0x191d27ad,
  0x40171921, 0x40030112, 0x0b041009, 0x0e231cbb,
  0x081d1821, 0x1c0e23bc, 0x1d152113, 0x273804be,
  // [1ab0]
  0x053827cf, 0x012217bc, 0x45001512, 0x1e0e2323,
  0x061722bb, 0x05172721, 0x38000822, 0x0e1e2311,
  0x060121bb, 0x06192160, 0x14010412, 0x0f1721bb,
  0x03010512, 0x14000412, 0x19001507, 0x22000b11,
  // [1ac0]
  0x060d18ad, 0x19000d11, 0x212719bc, 0x451d1522,
  0x050d3820, 0x211614bc, 0x45221d21, 0x1403066f,
  0x08170112, 0x01190313, 0x04152709, 0x14000c12,
  0x12151d6f, 0x1d40456f, 0x0f003821, 0x011422ac,
  // [1ad0]
  0x1d1610bc, 0x032706af, 0x15002720, 0x10000614,
  0x01431d12, 0x0b100c21, 0x1e0e1cbe, 0x03401d12,
  0x1d400102, 0x05012109, 0x0b0219bb, 0x451214ad,
  0x17082212, 0x1e1c2322, 0x0c401d12, 0x05190421,
  // [1ae0]
  0x27031912, 0x0b15166f, 0x22190660, 0x0d060112,
  0x161d1912, 0x06030534, 0x38180612, 0x0f050107,
  0x011738be, 0x27031d12, 0x0d001214, 0x05020112,
  0x0d1d406f, 0x042108bb, 0x04001821, 0x21151921,
  // [1af0]
  0x041819bc, 0x12000d07, 0x0b220421, 0x12000d14,
  0x380f0d12, 0x06100209, 0x010503af, 0x40271dad,
  0x161d18ad, 0x14211821, 0x04192721, 0x04100612,
  0x03001512, 0x03401d21, 0x40121713, 0x190218bc,
  // [1b00]
  0x18451221, 0x021018bc, 0x401d02ad, 0x05173808,
  0x1d0c40bc, 0x17150607, 0x1e230eac, 0x14031023,
  0x06021909, 0x0c010212, 0x190c38cf, 0x03001420,
  0x100b02be, 0x0e1e1cbb, 0x020306bc, 0x020b1412,
  // [1b10]
  0x01000407, 0x011914af, 0x081727ac, 0x0d45126f,
  0x1d172121, 0x0c010522, 0x0c1d4060, 0x151d06a4,
  0x141d0508, 0x21000413, 0x010227ac, 0x10211612,
  0x02000412, 0x01430c07, 0x16181560, 0x380d1713,
  // [1b20]
  0x08000408, 0x03052111, 0x40161dbe, 0x01211934,
  0x060105bc, 0x05013834, 0x02001721, 0x191621bc,
  0x19000b34, 0x27142212, 0x18272120, 0x0b000c12,
  0x16002121, 0x060301af, 0x16001711, 0x08140107,
  // [1b30]
  0x454301a4, 0x272101bb, 0x0c1822ad, 0x0d2116bc,
  0x27212221, 0x16002133, 0x12020bad, 0x0c002712,
  0x0d001410, 0x06011721, 0x12002712, 0x121418bc,
  0x18001413, 0x100422ac, 0x050301bc, 0x14000421,
  // [1b40]
  0x06180160, 0x04401d5e, 0x2715166f, 0x05212760,
  0x0f000111, 0x08381821, 0x051d2721, 0x37001e10,
  0x404515bb, 0x05380111, 0x40001807, 0x19000212,
  0x020c2207, 0x040b0811, 0x0f0d2123, 0x19030413,
  // [1b50]
  0x271422be, 0x01271021, 0x17012721, 0x1d0f05ad,
  0x010527bc, 0x22270b11, 0x0b021423, 0x18222709,
  0x121d2121, 0x14151607, 0x0f001711, 0x02030b21,
  0x02040bbe, 0x0f004022, 0x22060121, 0x150b01af,
  // [1b60]
  0x19060107, 0x0d002722, 0x40151dbc, 0x120c1511,
  0x06002921, 0x193817bb, 0x01171621, 0x19031713,
  0x221719bc, 0x0c1d17ad, 0x04000f13, 0x1814046f,
  0x0b100612, 0x17001922, 0x05002120, 0x0d271721,
  // [1b70]
  0x04002122, 0x18000213, 0x45120c12, 0x14170dad,
  0x05000311, 0x04000622, 0x19270d12, 0x05001708,
  0x16001220, 0x430127af, 0x01030208, 0x03020522,
  0x19220107, 0x06002720, 0x0f011912, 0x38401d07,
  // [1b80]
  0x01053821, 0x18030b12, 0x0b1008be, 0x010d08ac,
  0x1e000e36, 0x16000613, 0x04060382, 0x1d0f27ad,
  0x06002713, 0x01030b12, 0x16002208, 0x0b000135,
  0x17000135, 0x18000812, 0x08000134, 0x17000820,
  // [1b90]
  0x220b0212, 0x05011207, 0x04102255, 0x100206bb,
  0x04000c21, 0x380d27be, 0x0c154521, 0x03060c12,
  0x05381721, 0x22000c11, 0x0c000f14, 0x06030b12,
  0x27000821, 0x220b02cf, 0x17163821, 0x0b0203af,
  // [1ba0]
  0x030f0c12, 0x01000608, 0x01273809, 0x19010b08,
  0x45000f12, 0x14000f11, 0x06140112, 0x05210122,
  0x01001633, 0x190b1022, 0x080b17ac, 0x45000111,
  0x10401421, 0x14001512, 0x02000133, 0x06002121,
  // [1bb0]
  0x17003808, 0x050b0212, 0x01272114, 0x0d0f08af,
  0x01002723, 0x270f3821, 0x020b01ad, 0x0b050111,
  0x0c004535, 0x04212721, 0x03000635, 0x06031812,
  0x22001908, 0x19001720, 0x1d160112, 0x0b001811,
  // [1bc0]
  0x0f181707, 0x030801ac, 0x01002721, 0x21182713,
  0x210127be, 0x01000807, 0x04012712, 0x15000134,
  0x1927216f, 0x45040521, 0x08123821, 0x06031007,
  0x21192721, 0x060d03ad, 0x06010513, 0x04272107,
  // [1bd0]
  0x04010607, 0x04181913, 0x0c380512, 0x22272120,
  0x050f0dbc, 0x1d0419ad, 0x171d15be, 0x10020321,
  0x0d052220, 0x450604bb, 0x03040612, 0x10000420,
  0x38170508, 0x04010312, 0x08004321, 0x04272121,
  // [1be0]
  0x15380421, 0x4045086f, 0x38001712, 0x03000f07,
  0x27041214, 0x22000c07, 0x04001d08, 0x10000111,
  0x05380f21, 0x0c4516ad, 0x1d270112, 0x21380faf,
  0x06170512, 0x05150434, 0x02270621, 0x45002721,
  // [1bf0]
  0x10020b22, 0x27151621, 0x01001512, 0x06271021,
  0x01270522, 0x0d010421, 0x18001021, 0x19001614,
  0x0c452723, 0x0d1821bc, 0x19020bbc, 0x18000d20,
  0x00001603, 0x0d0f3808, 0x21000121, 0x22001902,

  // [1c00]
  0x43010408, 0x210f0112, 0x02060112, 0x16380dad,
  0x100b0caf, 0x38000d13, 0x27021912, 0x04001411,
  0x21270b12, 0x14000223, 0x0f173822, 0x0d1d1912,
  0x430d2707, 0x18004311, 0x01102712, 0x010c4312,
  // [1c10]
  0x0d451012, 0x40001621, 0x1d030b12, 0x01080d07,
  0x04081911, 0x06121d07, 0x19101412, 0x04002711,
  0x080f2212, 0x14003822, 0x270d0121, 0x43060112,
  0x0f002213, 0x00000142, 0x220f1412, 0x0c1201af,
  // [1c20]
  0x01140412, 0x02001811, 0x040b2720, 0x08021412,
  0x04161921, 0x22001623, 0x170f0d14, 0x0f400daf,
  0x030b0260, 0x03011612, 0x05100b09, 0x0b1903af,
  0x1d080f6f, 0x4301156f, 0x02060323, 0x010b0d21,
  // [1c30]
  0x100c1212, 0x100b1408, 0x0b0214bb, 0x401227ad,
  0x08170f22, 0x06043821, 0x190c0412, 0x04194014,
  0x08141807, 0x100601ac, 0x10002107, 0x152101af,
  0x0d0304bc, 0x16402220, 0x10142721, 0x10002721,
  // [1c40]
  0x18061707, 0x140203af, 0x1e0e23ac, 0x27211833,
  0x06271912, 0x0f040d12, 0x18001613, 0x10003821,
  0x38451912, 0x18004013, 0x08000120, 0x1e003709,
  0x04380507, 0x050806bc, 0x08030620, 0x060819bb,
  // [1c50]
  0x06220322, 0x01001807, 0x06192712, 0x10180507,
  0x05380421, 0x1912046f, 0x18120d13, 0x16222113,
  0x01274312, 0x1c230ea4, 0x43002935, 0x38190521,
  0x050f38af, 0x171201ac, 0x19210811, 0x03002221,
  // [1c60]
  0x15001633, 0x0d1201ac, 0x01050212, 0x18002722,
  0x400c1221, 0x450c1d11, 0x43000611, 0x122719ad,
  0x100605af, 0x05103811, 0x06173860, 0x38170412,
  0x02080112, 0x21001d21, 0x0b101d21, 0x121d04ad,
  // [1c70]
  0x17060321, 0x43001921, 0x38001722, 0x01180609,
  0x010f12ac, 0x0f0d3814, 0x1d4002bc, 0x40001223,
  0x01181955, 0x0e1e1cbc, 0x19001810, 0x40121612,
  0x1d401921, 0x08001911, 0x080205ad, 0x19401d12,
  // [1c80]
  0x17050814, 0x17050821, 0x0f004513, 0x05011621,
  0x231e0eac, 0x1c230ebb, 0x173805bb, 0x03001711,
  0x10210cad, 0x05001714, 0x060c19ad, 0x0000220a,
  0x14004308, 0x14000c08, 0x19002722, 0x0b004013,
  // [1c90]
  0x21000814, 0x0f000214, 0x08000c22, 0x0c000821,
  0x40101912, 0x22001712, 0x45101920, 0x02081012,
  0x0f151634, 0x160f0d82, 0x160f0d14, 0x0f0c1607,
  0x121d4033, 0x1d0b19bc, 0x05002207, 0x0f002122,
  // [1ca0]
  0x160d0f6f, 0x1d061021, 0x0c000423, 0x160d0f34,
  0x14160c60, 0x05140212, 0x06191007, 0x15001d13,
  0x40000c07, 0x0c004022, 0x060d0112, 0x1c230e23,
  0x06000207, 0x272218be, 0x1e1c2309, 0x010f0b12,
  // [1cb0]
  0x100318ac, 0x401d1822, 0x100b19af, 0x27003820,
  0x01000521, 0x054301ad, 0x380d0f13, 0x27191412,
  0x0d083821, 0x1d002111, 0x19001211, 0x0b0301bb,
  0x191d1512, 0x43272133, 0x03210612, 0x01031911,
  // [1cc0]
  0x0f081622, 0x0b012112, 0x080f16af, 0x38030122,
  0x06432120, 0x3817066f, 0x222740bc, 0x1d124520,
  0x0d1d08bc, 0x0c0301bc, 0x27064012, 0x03003812,
  0x041d0f21, 0x15191621, 0x01001713, 0x041d1621,
  // [1cd0]
  0x040f1621, 0x04051811, 0x100103a4, 0x15160413,
  0x06380412, 0x05020d12, 0x08000d09, 0x1c001e09,
  0x40211da4, 0x0b101908, 0x38002713, 0x01001607,
  0x271d0412, 0x18001611, 0x12000412, 0x14010407,
  // [1ce0]
  0x05012712, 0x01402220, 0x1d1540be, 0x38170113,
  0x170138be, 0x38050d12, 0x27210f12, 0x43211612,
  0x08001d12, 0x05020bbb, 0x22000213, 0x27380120,
  0x08001012, 0x22000b12, 0x40451d34, 0x180312be,
  // [1cf0]
  0x19401d07, 0x0d272212, 0x140304be, 0x0e1e3713,
  0x191004be, 0x01002111, 0x0f380d14, 0x030f0120,
  0x061718ad, 0x03010655, 0x45002711, 0x10000114,
  0x14001021, 0x010504bc, 0x010514be, 0x16401923,
  // [1d00]
  0x0b190422, 0x010305be, 0x01170812, 0x021806af,
  0x05081730, 0x19171613, 0x17011812, 0x04030107,
  0x18000b13, 0x12141007, 0x06032112, 0x1800141d,
  0x08000211, 0x080d0f13, 0x08000d23, 0x01040512,
  // [1d10]
  0x040301af, 0x38000509, 0x080127ac, 0x0f0d0821,
  0x05000108, 0x21002233, 0x162227bb, 0x1d001014,
  0x22380d07, 0x22000d07, 0x03401d6f, 0x14004511,
  0x190604ac, 0x02060b13, 0x06000d12, 0x030f02be,
  // [1d20]
  0x0804196f, 0x451201bc, 0x17000613, 0x0b021014,
  0x19000211, 0x02100412, 0x1d274021, 0x100b06af,
  0x05013813, 0x10003811, 0x38000b21, 0x03062212,
  0x100603be, 0x15001912, 0x04270621, 0x140f3820,
  // [1d30]
  0x18004314, 0x22000311, 0x45151412, 0x45000512,
  0x06140122, 0x02030112, 0x0d380f11, 0x0b2204bb,
  0x032716be, 0x19170120, 0x03000423, 0x22060322,
  0x050d18af, 0x45121412, 0x05190fa4, 0x05160d22,
  // [1d40]
  0x02171912, 0x12401d22, 0x03020b12, 0x0f060107,
  0x02000433, 0x38001422, 0x08021907, 0x0f030512,
  0x02001008, 0x02002221, 0x03002220, 0x12000507,
  0x08001622, 0x14000b14, 0x06000c09, 0x0b180412,
  // [1d50]
  0x45120c13, 0x05001414, 0x08000f21, 0x27010c12,
  0x0d000820, 0x03002112, 0x180127ac, 0x162721af,
  0x16271912, 0x220c21af, 0x14060312, 0x18081712,
  0x16142760, 0x05002713, 0x0b002211, 0x40000c23,
  // [1d60]
  0x16000414, 0x1e15041d, 0x0c401da4, 0x10002221,
  0x190c22ce, 0x14102221, 0x38002212, 0x27190433,
  0x10000b09, 0x1014046b, 0x38002221, 0x19003811,
  0x12001821, 0x1e001c36, 0x06030412, 0x27001021,
  // [1d70]
  0x140306ad, 0x0d0f01a4, 0x0d0f3807, 0x03000422,
  0x0b022221, 0x16190413, 0x22000621, 0x0c000520,
  0x08001721, 0x08004312, 0x170c4307, 0x08001922,
  0x03060222, 0x06022221, 0x05002221, 0x044305ad,
  // [1d80]
  0x17000421, 0x43040512, 0x17000c11, 0x060d0107,
  0x0f014312, 0x22001511, 0x0d000320, 0x01053807,
  0x1d000121, 0x10181521, 0x27401d21, 0x380d1a34,
  0x06001723, 0x181516cf, 0x10001811, 0x430c0807,
  // [1d90]
  0x40271d09, 0x38001507, 0x080103a4, 0x1c1e2323,
  0x37001c10, 0x01151055, 0x0d010f07, 0x1200141f,
  0x0d0f386f, 0x141027be, 0x43001913, 0x0f000311,
  0x0d060307, 0x060b1421, 0x08012712, 0x0f083821,
  // [1da0]
  0x222719af, 0x40032712, 0x060322bc, 0x060b2211,
  0x12000c1d, 0x14002722, 0x06101960, 0x220c4013,
  0x06272221, 0x0c002707, 0x40451913, 0x160840be,
  0x431d0112, 0x21000f12, 0x182716be, 0x18002720,
  // [1db0]
  0x02060121, 0x020127af, 0x032718ad, 0x05001411,
  0x06032223, 0x100b1813, 0x010f0212, 0x080b0213,
  0x222704ad, 0x18000820, 0x01030655, 0x1c000e36,
  0x19001823, 0x0b001411, 0x14060321, 0x0c0801ac,
  // [1dc0]
  0x18004021, 0x120c1dbc, 0x22004014, 0x08382712,
  0x120416ac, 0x22050f12, 0x27192221, 0x0b020621,
  0x04001620, 0x43000821, 0x12050d13, 0x02002208,
  0x21002735, 0x04191611, 0x080b2760, 0x14150caf,
  // [1dd0]
  0x084017be, 0x40001412, 0x231c1e33, 0x16220512,
  0x38141011, 0x0d0f3822, 0x0d001411, 0x050108bb,
  0x0d451255, 0x020b0da4, 0x02010512, 0x38001207,
  0x1c0e2309, 0x1d0327ac, 0x0d381421, 0x0d030512,
  // [1de0]
  0x1d454012, 0x0c101707, 0x18160309, 0x18021012,
  0x06010521, 0x104003ac, 0x0b100520, 0x03000b20,
  0x06100312, 0x02401d21, 0x0f002220, 0x02010521,
  0x1d1240ac, 0x0b10026f, 0x17010512, 0x010306bc,
  // [1df0]
  0x18000134, 0x10080b13, 0x19060b07, 0x04000b13,
  0x0b0502be, 0x061001ad, 0x0d120512, 0x08381d12,
  0x03010520, 0x0d0801ad, 0x08430107, 0x05004007,
  0x1d270c11, 0x08000f14, 0x06271812, 0x0b105134,
  // [1e00]
  0x081d0c09, 0x05124533, 0x124505be, 0x05000f13,
  0x060821ac, 0x0b190312, 0x1d45126f, 0x1d082107,
  0x0c1d01ce, 0x15060307, 0x38001723, 0x05003820,
  0x050f0860, 0x10060baf, 0x45004313, 0x1d0c18ad,
  // [1e10]
  0x0d380cac, 0x0e1c2308, 0x1e1c0e08, 0x451412be,
  0x3845126f, 0x38000d11, 0x384345bb, 0x19000433,
  0x044512be, 0x04000813, 0x10001613, 0x0f380d13,
  0x0c001512, 0x08004323, 0x0d0617af, 0x17005135,
  // [1e20]
  0x43001534, 0x43002112, 0x38000122, 0x0d171012,
  0x08100312, 0x172708bb, 0x101901be, 0x0d001534,
  0x0c1805bc, 0x0f0d17be, 0x02030520, 0x16000435,
  0x3810176f, 0x0b020121, 0x380f19ac, 0x01030512,
  // [1e30]
  0x38001621, 0x08050312, 0x0d000f35, 0x01000820,
  0x19271612, 0x380d2721, 0x19000512, 0x270819a4,
  0x0c120107, 0x080f0d23, 0x01000508, 0x01174312,
  0x27430512, 0x0d000212, 0x27450112, 0x1c231ebc,
  // [1e40]
  0x0c000107, 0x27010560, 0x0c1d0121, 0x0c451d11,
  0x17001613, 0x0c121808, 0x231e1c08, 0x45104012,
  0x140422bc, 0x430127a4, 0x10003807, 0x22002714,
  0x12452212, 0x03001212, 0x210419be, 0x1d4016be,
  // [1e50]
  0x04141922, 0x02041960, 0x06100812, 0x100612af,
  0x041819be, 0x21000b13, 0x430601ad, 0x010805be,
  0x0204196f, 0x43450112, 0x10190421, 0x04001933,
  0x011d0407, 0x06000509, 0x18190460, 0x17001508,
  // [1e60]
  0x380d0c07, 0x02221d07, 0x2103196f, 0x21270421,
  0x270421af, 0x16121907, 0x27000422, 0x03270422,
  0x18002221, 0x0c121834, 0x03061012, 0x0c271dbc,
  0x40121dbe, 0x03270421, 0x230e1c23, 0x21042721,
  // [1e70]
  0x06000233, 0x0c182222, 0x0c4018cf, 0x100f0d13,
  0x0c000309, 0x10000313, 0x0f142212, 0x45000b21,
  0x01030f07, 0x06001814, 0x024301af, 0x12000313,
  0x27001414, 0x0f004322, 0x21002922, 0x0f010560,
  // [1e80]
  0x21000135, 0x43030112, 0x43000134, 0x43000122,
  0x1d0f08af, 0x1d0c1207, 0x12451008, 0x060f0808,
  0x02004502, 0x02001808, 0x22000120, 0x173822af,
  0x050140be, 0x08142212, 0x1c231e13, 0x21080fbc,
  // [1e90]
  0x04080f11, 0x27380f21, 0x0d1d2212, 0x0f220812,
  0x0f0d0c07, 0x0d011d09, 0x19100b21, 0x43000133,
  0x0b1d4060, 0x010306ad, 0x120c40bb, 0x01001513,
  0x05100109, 0x02000312, 0x40121d07, 0x100838bb,
  // [1ea0]
  0x0d001911, 0x1d000d07, 0x0f0838be, 0x100b0621,
  0x03010207, 0x12400513, 0x21001d12, 0x05191707,
  0x15000414, 0x19060407, 0x10142712, 0x02001035,
  0x080f2112, 0x0d000807, 0x10001212, 0x0b062712,
  // [1eb0]
  0x27013809, 0x1d001633, 0x030d0607, 0x38001512,
  0x0d080312, 0x221d4060, 0x1d041612, 0x06004523,
  0x10020b08, 0x100b0213, 0x150106bc, 0x01380da4,
  0x101915ad, 0x224003ac, 0x010610be, 0x38450108,
  // [1ec0]
  0x100b1411, 0x21004535, 0x43001707, 0x18000622,
  0x1d0c0312, 0x10380620, 0x43003811, 0x17002713,
  0x10142212, 0x0c012712, 0x454021cf, 0x43001736,
  0x050d3812, 0x01380807, 0x21000621, 0x06100807,
  // [1ed0]
  0x0f160c60, 0x190822a4, 0x21160cbe, 0x0d000814,
  0x401d12ac, 0x1e1c0e09, 0x1c231e09, 0x184016bc,
  0x17004514, 0x17011512, 0x38000c20, 0x081d06ac,
  0x01050614, 0x03180fbe, 0x03080612, 0x380d2712,
  // [1ee0]
  0x0c00041f, 0x1712456f, 0x061019ad, 0x19100208,
  0x270419af, 0x16151412, 0x38000612, 0x380f2212,
  0x43000512, 0x15002222, 0x120c4534, 0x0c182721,
  0x02001d08, 0x10000c08, 0x0c451223, 0x40001008,
  // [1ef0]
  0x0c4016cf, 0x0f011007, 0x450c40af, 0x12001707,
  0x06001212, 0x0f003812, 0x400c2121, 0x15120cac,
  0x40181dbc, 0x1d451213, 0x060c0111, 0x04170fbe,
  0x010c3812, 0x231e1caf, 0x1d1821ad, 0x06220307,
  // [1f00]
  0x04000d22, 0x12450cac, 0x231e1c21, 0x190108a4,
  0x0f0d1dad, 0x101701af, 0x152717af, 0x0f081dac,
  0x21140f6f, 0x05000307, 0x19010521, 0x27061d12,
  0x16001809, 0x06380212, 0x06001608, 0x15004023,
  // [1f10]
  0x0e231eac, 0x12000c08, 0x06002708, 0x18001213,
  0x03003813, 0x0b0210be, 0x080d0fbe, 0x08021009,
  0x10080160, 0x060419bc, 0x0e1c1e08, 0x170108bc,
  0x12161daf, 0x151403ac, 0x15001421, 0x04191821,
  // [1f20]
  0x100422a4, 0x0f170107, 0x10000422, 0x16000408,
  0x0b0c0207, 0x38050121, 0x1e0e1c20, 0x0c031212,
  0x05001211, 0x161819ad, 0x03001413, 0x1d160320,
  0x01061412, 0x10220307, 0x180b0260, 0x10001909,
  // [1f30]
  0x061910ad, 0x38170f09, 0x05060109, 0x1e0e2322,
  0x160b0222, 0x181522bc, 0x15004522, 0x19142712,
  0x22001922, 0x030f0107, 0x03010513, 0x27221d12,
  0x0800381f, 0x40001221, 0x21002220, 0x0c0119ba,
  // [1f40]
  0x38000411, 0x1912456f, 0x03000c11, 0x22004514,
  0x380f2112, 0x1d100113, 0x190d2212, 0x04004007,
  0x0b0f3807, 0x17454013, 0x06180109, 0x08020121,
  0x01002213, 0x22001423, 0x08000f12, 0x0d221421,
  // [1f50]
  0x210d4512, 0x0d0f08be, 0x04001d07, 0x040327ac,
  0x401d0c13, 0x38170f12, 0x04001820, 0x45000108,
  0x12000207, 0x06001513, 0x0d0f2707, 0x05001911,
  0x1d220807, 0x0d164512, 0x0d271912, 0x38000508,
  // [1f60]
  0x45121612, 0x141922ad, 0x05000d20, 0x17001511,
  0x04001009, 0x08001511, 0x45120407, 0x27002233,
  0x271d18cf, 0x0c000323, 0x14212760, 0x12050607,
  0x031d1821, 0x45271821, 0x1d272234, 0x22001013,
  // [1f70]
  0x0d040b20, 0x19082707, 0x17032713, 0x170b0807,
  0x08170d14, 0x14081613, 0x16000634, 0x08005135,
  0x14124508, 0x021d27af, 0x191622bc, 0x22380f13,
  0x021627cf, 0x150c1611, 0x190b27af, 0x0d192212,
  // [1f80]
  0x120d19a4, 0x19220b14, 0x060851be, 0x23001c34,
  0x22170f21, 0x19001612, 0x0f0422bc, 0x08004311,
  0x1d0c2221, 0x0406196f, 0x0b050121, 0x12080f21,
  0x01220621, 0x124518ac, 0x17080111, 0x08060311,
  // [1f90]
  0x0c271512, 0x21001d14, 0x10010421, 0x18100812,
  0x0d001833, 0x230e1cbc, 0x02060b34, 0x03000221,
  0x12451512, 0x38004318, 0x21002935, 0x14001235,
  0x03150112, 0x10062112, 0x400d1013, 0x19004013,
  // [1fa0]
  0x0d004023, 0x06190412, 0x1d0c4012, 0x1d151620,
  0x27172221, 0x0d2721bb, 0x0e231ea4, 0x030b02be,
  0x40041914, 0x45381d12, 0x01060311, 0x401d1212,
  0x0c0519ad, 0x0f000122, 0x1d001012, 0x19000f14,
  // [1fb0]
  0x050d0807, 0x0b0d0212, 0x10061407, 0x400c0312,
  0x0b0502cf, 0x03060411, 0x21000212, 0x060314bc,
  0x270f2112, 0x100406bc, 0x19000135, 0x08271512,
  0x19061207, 0x080f0d14, 0x1c1e23be, 0x0d0840af,
  // [1fc0]
  0x14191608, 0x38081808, 0x270610af, 0x22001913,
  0x0c180312, 0x16450c23, 0x21010311, 0x04001611,
  0x08010fad, 0x0b010209, 0x45001521, 0x43380fad,
  0x011738ad, 0x06124512, 0x401d27af, 0x060c0212,
  // [1fd0]
  0x08000d11, 0x194003ad, 0x01380412, 0x03001811,
  0x1d0604ac, 0x160c1908, 0x150d1634, 0x0d140f60,
  0x16000d13, 0x0f161534, 0x0d001820, 0x0c000820,
  0x22191421, 0x27152133, 0x081d04ac, 0x061903bb,
  // [1fe0]
  0x04001609, 0x150f0c21, 0x05080cad, 0x0d1615af,
  0x0b451660, 0x08001623, 0x27002913, 0x450c21ac,
  0x19001620, 0x17011055, 0x27180f08, 0x221516ad,
  0x0c000812, 0x19221612, 0x45000813, 0x0d0816be,
  // [1ff0]
  0x430316ac, 0x21000c14, 0x1d0d0507, 0x02100b07,
  0x21150460, 0x01101907, 0x14000511, 0x0b100360,
  0x01141d09, 0x00002203, 0x033805ad, 0x270d08ad,
  0x0b101607, 0x060b17ad, 0x01020322, 0x05271611,

  // [2000]
  0x05080607, 0x06100212, 0x06000508, 0x17180513,
  0x18450dbb, 0x45180d12, 0x12180512, 0x22001612,
  0x02270112, 0x45000411, 0x08050f60, 0x03190107,
  0x17211821, 0x10000d11, 0x08192113, 0x18000d21,
  // [2010]
  0x14000d11, 0x01000821, 0x19002114, 0x05120112,
  0x01272160, 0x10380faf, 0x0f001722, 0x19102721,
  0x38000d35, 0x450f1621, 0x22060312, 0x0c401d13,
  0x380d1412, 0x0c042160, 0x08001520, 0x041927ac,
  // [2020]
  0x18151611, 0x27380421, 0x210f0812, 0x18004510,
  0x050601ac, 0x080d17af, 0x16001712, 0x0b0204af,
  0x03000511, 0x1d0b40bc, 0x014327af, 0x103827ce,
  0x15382721, 0x0d0f06bb, 0x0d0f0513, 0x0f180512,
  // [2030]
  0x21273813, 0x180d0509, 0x0b001421, 0x14184512,
  0x01080412, 0x161904af, 0x380b2707, 0x050f0d09,
  0x191d4021, 0x08002123, 0x17002214, 0x14010608,
  0x01060320, 0x18000607, 0x1e0e2309, 0x101640ad,
  // [2040]
  0x04194060, 0x19002109, 0x17081911, 0x10001436,
  0x16001021, 0x16181913, 0x01061dac, 0x40124522,
  0x0f0d0813, 0x0d0f0c12, 0x16401d22, 0x0d16086f,
  0x10000d12, 0x0b001912, 0x011204ad, 0x270f1d11,
  // [2050]
  0x0f003823, 0x19000309, 0x12181d07, 0x19001621,
  0x1d380f6f, 0x160127a4, 0x06050121, 0x0b100221,
  0x020645ad, 0x100b15af, 0x06020b6f, 0x010b0282,
  0x020501a4, 0x14161914, 0x01020608, 0x05041809,
  // [2060]
  0x400c0412, 0x12021009, 0x1d082707, 0x02190bac,
  0x38001011, 0x06000214, 0x0d380fbe, 0x01101912,
  0x02061011, 0x0204166f, 0x16001822, 0x17001623,
  0x0b010207, 0x02000511, 0x17031612, 0x03124514,
  // [2070]
  0x06031655, 0x0d031d07, 0x05381821, 0x041618be,
  0x160c04ac, 0x12000b08, 0x18162721, 0x010203af,
  0x020b04ad, 0x05000120, 0x16004011, 0x0d001621,
  0x27080112, 0x060114af, 0x050801a4, 0x051708ad,
  // [2080]
  0x0f001514, 0x05000309, 0x151602af, 0x08000208,
  0x18450807, 0x02160b21, 0x012114af, 0x272116bc,
  0x12010cbc, 0x0d030112, 0x231e0e11, 0x450c1621,
  0x08401607, 0x27210c12, 0x0b0c4512, 0x0c001521,
  // [2090]
  0x0d401612, 0x27001822, 0x030108ac, 0x15000314,
  0x100b0307, 0x020b1021, 0x0d0f45af, 0x01004011,
  0x0b001d13, 0x04000112, 0x0f2719bc, 0x02061012,
  0x06220d07, 0x1e1c0e55, 0x0b1d4014, 0x21051921,
  // [20a0]
  0x12050f07, 0x16190820, 0x0f0d4521, 0x0d0f0c20,
  0x160306af, 0x1c230e08, 0x18003809, 0x22002734,
  0x04050107, 0x1c231e60, 0x19000814, 0x040338ac,
  0x16000409, 0x22000107, 0x4505437e, 0x10001d12,
  // [20b0]
  0x19084512, 0x0d011602, 0x1e230ead, 0x060b16ad,
  0x121819ad, 0x17001421, 0x04030c11, 0x27001411,
  0x15082712, 0x030c0209, 0x12164560, 0x0b083812,
  0x04000f11, 0x03000121, 0x0d0501bc, 0x1e230ebe,
  // [20c0]
  0x1c1e0e55, 0x0c001921, 0x060d1712, 0x161d19bb,
  0x38141912, 0x03100607, 0x0b001720, 0x0b141022,
  0x19272113, 0x03270c12, 0x06004012, 0x06430107,
  0x45124023, 0x0f190420, 0x380f0d09, 0x021903a4,
  // [20d0]
  0x10021421, 0x231c1ebc, 0x050f0307, 0x0d080212,
  0x22001520, 0x0c001834, 0x01083812, 0x1238066d,
  0x0f1527ac, 0x380c1711, 0x0c001920, 0x10060107,
  0x0f000d02, 0x0f080d21, 0x0f170307, 0x22001813,
  // [20e0]
  0x180d0812, 0x06030421, 0x1c1e0e07, 0x0d0804bc,
  0x19000808, 0x230e1c08, 0x19050108, 0x010d08af,
  0x05000407, 0x12454011, 0x120d2707, 0x15000f21,
  0x170d15be, 0x0d0522ac, 0x0d222721, 0x0f401507,
  // [20f0]
  0x02005135, 0x16220b13, 0x1600151f, 0x271d1621,
  0x1d0d1907, 0x0f001d21, 0x0d0b01a4, 0x14001914,
  0x06041013, 0x0d0f3814, 0x0c1d04a4, 0x0f0d17ad,
  0x08191d21, 0x45401d21, 0x05011907, 0x10000108,
  // [2100]
  0x1d002721, 0x100106ac, 0x18020b21, 0x40001821,
  0x06220412, 0x06010320, 0x06051911, 0x10004007,
  0x0c192712, 0x03101909, 0x00004315, 0x08401d60,
  0x38000823, 0x27210112, 0x21020b20, 0x04020112,
  // [2110]
  0x050d0360, 0x19270108, 0x011706ad, 0x1d0621a4,
  0x02140612, 0x1c1e0e14, 0x0d000411, 0x27001011,
  0x06003812, 0x1d001011, 0x38000b13, 0x082703bc,
  0x080421be, 0x06001613, 0x45400cac, 0x101404a4,
  // [2120]
  0x04004520, 0x0d012712, 0x06190410, 0x451d4060,
  0x38170609, 0x061903ad, 0x19060312, 0x0f000107,
  0x27221523, 0x380527af, 0x1216276b, 0x15001d20,
  0x191201ad, 0x16000b13, 0x020121ad, 0x0f081621,
  // [2130]
  0x160c0107, 0x45000513, 0x270501af, 0x080f0112,
  0x01020520, 0x0310016f, 0x101451be, 0x0d380f21,
  0x0f270dbc, 0x16002114, 0x16141921, 0x16002109,
  0x0b0301ac, 0x020b1907, 0x16011913, 0x380f0db2,
  // [2140]
  0x10180b21, 0x19400412, 0x043816ac, 0x051804ad,
  0x06001612, 0x04002213, 0x0b020412, 0x1d011212,
  0x38450107, 0x21004511, 0x06004507, 0x0e231e22,
  0x05000234, 0x1c1e0e22, 0x06271012, 0x0b040312,
  // [2150]
  0x19061608, 0x19001514, 0x03061420, 0x15000413,
  0x03220555, 0x10192721, 0x12001612, 0x19100412,
  0x14080d60, 0x04000508, 0x0f1608ac, 0x0d151422,
  0x0f401dac, 0x161d4021, 0x08050460, 0x0d000809,
  // [2160]
  0x18001711, 0x231c1e34, 0x14000422, 0x0b121421,
  0x15161d11, 0x0b401012, 0x401d45ad, 0x03080512,
  0x081d1409, 0x08000312, 0x050b01a4, 0x06010812,
  0x19100f21, 0x040319af, 0x10010612, 0x083805a4,
  // [2170]
  0x27170b6f, 0x430601ac, 0x16001520, 0x03401807,
  0x0f050108, 0x221619af, 0x021903ad, 0x03001511,
  0x10010d21, 0x0d000412, 0x01380509, 0x12451612,
  0x0f060dad, 0x0f000523, 0x10080112, 0x16011511,
  // [2180]
  0x17432712, 0x211901af, 0x160b1907, 0x161206bc,
  0x0c191855, 0x05210107, 0x18001622, 0x18271421,
  0x010418ad, 0x181d22ce, 0x0c004507, 0x0b0603bc,
  0x401d0609, 0x0b0302bc, 0x060d0812, 0x0d083823,
  // [2190]
  0x04001822, 0x181521bb, 0x0b000f20, 0x010f05ad,
  0x140406af, 0x380b1060, 0x16150411, 0x0b0127a4,
  0x08012207, 0x0c151709, 0x141004bc, 0x1d001820,
  0x081816bc, 0x21000f14, 0x10161514, 0x10001822,
  // [21a0]
  0x040321ac, 0x1d000413, 0x01050820, 0x1e230e11,
  0x18002207, 0x040f03bb, 0x120c4507, 0x12000312,
  0x010806af, 0x170f0dbe, 0x180b0521, 0x10002712,
  0x1d004521, 0x010f0813, 0x15000f09, 0x03170112,
  // [21b0]
  0x14030611, 0x020b1921, 0x04001807, 0x04004512,
  0x190b02af, 0x0f0d16af, 0x0f080dac, 0x27000611,
  0x27001623, 0x121d1520, 0x08001912, 0x1716196f,
  0x0d401660, 0x16000811, 0x050f1810, 0x22000609,
  // [21c0]
  0x12100607, 0x0d0418cf, 0x02191512, 0x14100312,
  0x220103af, 0x040b1d21, 0x450106ad, 0x381801bc,
  0x0603166f, 0x19003814, 0x0d060411, 0x160301cf,
  0x18003813, 0x08050122, 0x0f002121, 0x0d000f1a,
  // [21d0]
  0x01140bbe, 0x17190c07, 0x0f0d08a4, 0x04001720,
  0x031906bc, 0x050327be, 0x14100112, 0x0e231cbe,
  0x0f381407, 0x050306ac, 0x14020b22, 0x43124520,
  0x05003835, 0x400d18ad, 0x18000f34, 0x01030560,
  // [21e0]
  0x19212720, 0x1d020121, 0x100f1812, 0x010f03ad,
  0x05193812, 0x19041407, 0x160c0212, 0x060215af,
  0x01031d12, 0x04003807, 0x124515ad, 0x40010f12,
  0x010d05ac, 0x15000c11, 0x10080412, 0x010538ad,
  // [21f0]
  0x0b020514, 0x19002721, 0x17004309, 0x401d08af,
  0x16003813, 0x0b062721, 0x27220621, 0x04080112,
  0x0f0d1921, 0x08000613, 0x0b030613, 0x21002709,
  0x040b1909, 0x05010820, 0x16121d20, 0x1d000614,
  // [2200]
  0x0d0f16af, 0x17000d07, 0x08052112, 0x10191812,
  0x380422ad, 0x160f0d22, 0x0d0f16bb, 0x0b0210af,
  0x0d0f21ad, 0x0b001613, 0x05220421, 0x05001d12,
  0x21000c21, 0x1d120412, 0x081738ad, 0x08170507,
  // [2210]
  0x18270dbc, 0x040115bc, 0x38220511, 0x0b001422,
  0x06013811, 0x21001421, 0x45002710, 0x01031534,
  0x1d0f40ac, 0x053801be, 0x27031521, 0x0d0f01af,
  0x27161421, 0x400c14bc, 0x21040612, 0x021403ac,
  // [2220]
  0x16000522, 0x06020521, 0x081d4012, 0x0f380834,
  0x1445126b, 0x27000511, 0x220127bc, 0x100b0212,
  0x0b000821, 0x0605156f, 0x45121808, 0x06050420,
  0x0d00140b, 0x10060212, 0x060517ad, 0x020c0bac,
  // [2230]
  0x17272212, 0x14020b12, 0x011604bb, 0x38000511,
  0x05060820, 0x0b060213, 0x03000b07, 0x270f22af,
  0x22002123, 0x18004511, 0x06184512, 0x06020b12,
  0x27003821, 0x05010334, 0x02000411, 0x01060b21,
  // [2240]
  0x01001d11, 0x16124012, 0x1d001208, 0x0d0105ac,
  0x02001012, 0x40002707, 0x10060322, 0x040306cf,
  0x030b06af, 0x02000621, 0x03220612, 0x38000321,
  0x17003811, 0x38001623, 0x03060413, 0x12001511,
  // [2250]
  0x0d380822, 0x10060b07, 0x16050111, 0x380d1711,
  0x220f1912, 0x43053812, 0x0616046f, 0x161d15bc,
  0x10271955, 0x21191812, 0x08004522, 0x160d0fbb,
  0x04271912, 0x210d0f60, 0x03270522, 0x210f0d20,
  // [2260]
  0x06221911, 0x0f040507, 0x27211920, 0x080f0dbc,
  0x22000821, 0x10001434, 0x380d0fad, 0x210419ad,
  0x010816ad, 0x01060c07, 0x21272213, 0x0b000421,
  0x011816bc, 0x18001621, 0x170d0fbe, 0x100201bb,
  // [2270]
  0x0400181f, 0x050b2707, 0x010506be, 0x22182707,
  0x01000408, 0x101427bc, 0x382716be, 0x05172709,
  0x010b1055, 0x080f3821, 0x27220460, 0x0f082107,
  0x03380faf, 0x08001709, 0x1d404534, 0x21001722,
  // [2280]
  0x04030607, 0x0f0d0509, 0x1d001220, 0x0c0f27bb,
  0x434505ac, 0x38000212, 0x21000411, 0x04141612,
  0x0f004020, 0x02060ba4, 0x270140af, 0x102716ad,
  0x0f030612, 0x0b021060, 0x380f4012, 0x0f3804bb,
  // [2290]
  0x01151612, 0x150527ac, 0x19041521, 0x0e231c55,
  0x040b10af, 0x1d401507, 0x170d0509, 0x19220bac,
  0x401d456f, 0x0d030611, 0x22001411, 0x05001913,
  0x12401d11, 0x270b1060, 0x08020b34, 0x0f030621,
  // [22a0]
  0x19042212, 0x012221bc, 0x16400dad, 0x380b03ac,
  0x43000823, 0x08031707, 0x06050bad, 0x40451d13,
  0x031006a4, 0x230e1ca4, 0x21000f22, 0x40040811,
  0x38050414, 0x0f001612, 0x0d0208ad, 0x03000633,
  // [22b0]
  0x17010f07, 0x06430812, 0x08000523, 0x01081760,
  0x17000133, 0x011d40ac, 0x06170812, 0x16000813,
  0x08060333, 0x08000620, 0x1d004534, 0x16081512,
  0x1d124521, 0x06100160, 0x04162721, 0x27211534,
  // [22c0]
  0x0f1d16bc, 0x02030607, 0x04151621, 0x0d081612,
  0x05160107, 0x011408ac, 0x050418ad, 0x08001907,
  0x040f2112, 0x0619046f, 0x061804af, 0x0d1806af,
  0x0b0218be, 0x22000507, 0x03001d08, 0x190b0422,
  // [22d0]
  0x27211860, 0x01001722, 0x0c1d1912, 0x40451d22,
  0x38000607, 0x19102121, 0x080f15a4, 0x17150614,
  0x450c03a4, 0x27000f12, 0x0d001735, 0x03060420,
  0x0b000435, 0x22000813, 0x0f011012, 0x0d000414,
  // [22e0]
  0x27001212, 0x1400041f, 0x18031013, 0x181d406f,
  0x17012120, 0x060b2721, 0x18004014, 0x01062260,
  0x0c450213, 0x19001513, 0x40000222, 0x06081612,
  0x14000111, 0x14000113, 0x19002223, 0x21001607,
  // [22f0]
  0x17002107, 0x1d0d1612, 0x030f2707, 0x1d000212,
  0x0f0519ac, 0x0c011612, 0x38010555, 0x0d000122,
  0x08010560, 0x17001807, 0x18030612, 0x12001820,
  0x40001811, 0x02101408, 0x38001835, 0x10050120,
  // [2300]
  0x401d1914, 0x16000120, 0x19100611, 0x0b000114,
  0x1d000f14, 0x16121512, 0x21192722, 0x0c450112,
  0x08171607, 0x22162712, 0x14000320, 0x12151d12,
  0x45001511, 0x10004011, 0x0c001514, 0x17002720,
  // [2310]
  0x0b210120, 0x191614be, 0x0d002107, 0x15002711,
  0x22020607, 0x12184512, 0x40004507, 0x1c0e1e6f,
  0x03102712, 0x061d0107, 0x05081609, 0x03060baf,
  0x0d010809, 0x12451921, 0x27041960, 0x012127af,
  // [2320]
  0x0b005113, 0x0400190d, 0x05000413, 0x27003813,
  0x173801af, 0x0d001707, 0x380f046f, 0x0b124555,
  0x010504af, 0x0b025134, 0x021022a4, 0x27030121,
  0x121d17af, 0x17121d21, 0x16170420, 0x05011721,
  // [2330]
  0x06430507, 0x03001707, 0x170d38ad, 0x0d0106bb,
  0x01062712, 0x16001434, 0x010f0d12, 0x0d270520,
  0x0c004521, 0x052721bb, 0x06001620, 0x1d064021,
  0x17080f21, 0x0f0c2713, 0x04001711, 0x04000823,
  // [2340]
  0x05020b20, 0x06001607, 0x05060112, 0x08100612,
  0x0d000611, 0x02061960, 0x1d001734, 0x0d0f3821,
  0x010f0512, 0x0f080d09, 0x12044521, 0x1701056f,
  0x12400821, 0x1900101d, 0x01120c60, 0x38080dac,
  // [2350]
  0x04000833, 0x04401d11, 0x06001207, 0x40004508,
  0x0d380813, 0x45121d14, 0x1727226f, 0x21161d6f,
  0x150d1621, 0x191d2721, 0x03001807, 0x04181912,
  0x15001808, 0x01050307, 0x27191513, 0x041927bc,
  // [2360]
  0x10140b23, 0x12212755, 0x08020b11, 0x06140bad,
  0x38000312, 0x141d29af, 0x10002708, 0x0f002721,
  0x19000621, 0x01160620, 0x1d001914, 0x17001933,
  0x0d051920, 0x05000211, 0x0d051512, 0x05222721,
  // [2370]
  0x161914af, 0x401617af, 0x140d19ac, 0x18272221,
  0x141819a4, 0x01062207, 0x01270813, 0x27001809,
  0x40222711, 0x40120cac, 0x0b0614bc, 0x0c221855,
  0x0c004023, 0x38212712, 0x1d451207, 0x16190312,
  // [2380]
  0x19000323, 0x08001407, 0x04050621, 0x19270bbc,
  0x21001614, 0x01004508, 0x06000821, 0x010619ad,
  0x0e231e6f, 0x08030507, 0x0f380807, 0x08001d07,
  0x03061560, 0x031501af, 0x45121dbe, 0x060801bb,
  // [2390]
  0x19171207, 0x01001714, 0x38000c09, 0x080d1813,
  0x43000112, 0x030127a4, 0x010627ac, 0x010538af,
  0x01053814, 0x06051522, 0x10061521, 0x21222712,
  0x0b100421, 0x27052112, 0x19030421, 0x01380320,
  // [23a0]
  0x052221ad, 0x050115af, 0x14150122, 0x12000523,
  0x0b162712, 0x010d0f13, 0x1d274012, 0x14060b21,
  0x010f0d14, 0x45121812, 0x0c000312, 0x010817ad,
  0x04140cad, 0x16221713, 0x43210809, 0x16430612,
  // [23b0]
  0x22001721, 0x22170c12, 0x06020fa4, 0x17000514,
  0x17051921, 0x00002442, 0x19161507, 0x43270121,
  0x0d000823, 0x0d190412, 0x10001421, 0x0d051dbb,
  0x1905046f, 0x19180414, 0x02161d07, 0x12430d12,
  // [23c0]
  0x38000d09, 0x401d1613, 0x061d1209, 0x08380b21,
  0x12181d13, 0x0b121807, 0x43012707, 0x08050108,
  0x060501ac, 0x100b1912, 0x18151621, 0x06001813,
  0x01380d60, 0x18052212, 0x0b2202be, 0x15061612,
  // [23d0]
  0x22000321, 0x05191621, 0x03060c08, 0x0b061408,
  0x161527cf, 0x15164011, 0x17183822, 0x020b1434,
  0x010d0f21, 0x0f0d08be, 0x0d000835, 0x0f1d2712,
  0x121d0c07, 0x19042260, 0x03160b12, 0x02180612,
  // [23e0]
  0x160f176f, 0x18121d12, 0x080b0f07, 0x1d401212,
  0x21171621, 0x17000c07, 0x18001409, 0x06040307,
  0x061401ac, 0x0b001021, 0x171805bb, 0x05380d08,
  0x01380d07, 0x052201a4, 0x401d15bc, 0x0000050a,
  // [23f0]
  0x40001813, 0x1d45166d, 0x00000d0a, 0x0d0f18ad,
  0x38002721, 0x060315bb, 0x12401dbb, 0x12401d23,
  0x45150c13, 0x031d18a4, 0x03150c12, 0x40021021,
  0x19060c12, 0x15000c21, 0x45401da4, 0x06160c07,

  // [2400]
  0x03001213, 0x08000513, 0x1d0f40ad, 0x1c003710,
  0x0f0614ac, 0x27001013, 0x27020b6f, 0x04191460,
  0x0b001908, 0x27002136, 0x45002211, 0x12184560,
  0x17042280, 0x080105ad, 0x01000d20, 0x45001721,
  // [2410]
  0x451d1214, 0x00000401, 0x01061455, 0x030b1912,
  0x38221712, 0x06021921, 0x0b011507, 0x01171907,
  0x19161712, 0x161d1960, 0x451219ac, 0x27140412,
  0x0f451212, 0x18001709, 0x40451223, 0x121914bc,
  // [2420]
  0x12041955, 0x270c01bb, 0x03270455, 0x160c4522,
  0x40161712, 0x19002209, 0x06101d07, 0x04061012,
  0x38010f21, 0x18002122, 0x38192112, 0x0f001413,
  0x10060f07, 0x06122712, 0x17080d12, 0x38001411,
  // [2430]
  0x38170560, 0x22120cad, 0x03022712, 0x380d1421,
  0x22001414, 0x18102707, 0x03170f12, 0x17061412,
  0x0b002712, 0x01274509, 0x18000c09, 0x01003807,
  0x06220c11, 0x08380513, 0x401d45bc, 0x03013812,
  // [2440]
  0x0b001810, 0x04191607, 0x05190607, 0x0f0804be,
  0x1d0c2712, 0x12061512, 0x0d051607, 0x0c041612,
  0x19004011, 0x04084021, 0x0d1516ad, 0x45124020,
  0x14002720, 0x05160dad, 0x15000d20, 0x43000120,
  // [2450]
  0x40000d07, 0x14001807, 0x270801ad, 0x040f27bb,
  0x15050d21, 0x01005134, 0x12000411, 0x0d051660,
  0x140340bc, 0x1d400c21, 0x141d406f, 0x16000121,
  0x12150c12, 0x1c230e09, 0x380f0d22, 0x03040c12,
  // [2460]
  0x38140d12, 0x0b401daf, 0x19001622, 0x141027bb,
  0x400c1daf, 0x0817056f, 0x27001913, 0x10012712,
  0x0f3805be, 0x013802af, 0x01001707, 0x380805cf,
  0x18212722, 0x04151611, 0x06050823, 0x45221812,
  // [2470]
  0x211201af, 0x0f0105be, 0x02060d12, 0x151d1612,
  0x16003814, 0x171638ac, 0x380f0daf, 0x0f001221,
  0x17004012, 0x17041912, 0x0138056f, 0x0b0221af,
  0x15163812, 0x0c402123, 0x1d402121, 0x141627bc,
  // [2480]
  0x04062712, 0x1845126f, 0x14060b13, 0x18061421,
  0x21002734, 0x0c000320, 0x40001235, 0x03000421,
  0x0c001511, 0x03380f07, 0x43003812, 0x12000b12,
  0x08000d34, 0x27000822, 0x1d0f2707, 0x03100214,
  // [2490]
  0x040b0509, 0x2200061f, 0x08140555, 0x08010c12,
  0x0d451712, 0x170f2212, 0x1d000c09, 0x0b0402ad,
  0x24004310, 0x0f3827af, 0x19001212, 0x12431d09,
  0x14004021, 0x01000823, 0x01140321, 0x06170112,
  // [24a0]
  0x38000c11, 0x0f380d12, 0x06000108, 0x14010512,
  0x22001222, 0x40001711, 0x06000220, 0x03012707,
  0x16151908, 0x380d0f09, 0x1c1e0e08, 0x01100b12,
  0x020b05ac, 0x16001212, 0x220119a4, 0x02000820,
  // [24b0]
  0x141218ac, 0x081701ad, 0x0d210f09, 0x030b0212,
  0x080501af, 0x0d102207, 0x10061409, 0x080501ad,
  0x05270112, 0x0f080112, 0x18001909, 0x0c212713,
  0x1d100c13, 0x0d0c0455, 0x15161021, 0x0d0f18bc,
  // [24c0]
  0x45000d08, 0x0c1d0855, 0x27041d08, 0x060c2107,
  0x27001811, 0x080d0107, 0x180201af, 0x19011707,
  0x05020b60, 0x060b0260, 0x06212711, 0x0b0205ad,
  0x04002108, 0x18002711, 0x05001413, 0x0f382109,
  // [24d0]
  0x04161812, 0x08000622, 0x231e0e13, 0x14041621,
  0x45140611, 0x270616bb, 0x43050121, 0x1622196f,
  0x0b1606bc, 0x1d4045cf, 0x06430112, 0x430127ad,
  0x1d014509, 0x121d17ad, 0x40000321, 0x03180111,
  // [24e0]
  0x08010f07, 0x010521bc, 0x06000211, 0x06050212,
  0x14000b08, 0x1d030611, 0x10000d21, 0x380f27ad,
  0x08020607, 0x050c27ad, 0x14000820, 0x45124307,
  0x170603bb, 0x05182712, 0x45002712, 0x12000607,
  // [24f0]
  0x01050612, 0x0f120cbb, 0x01004007, 0x45401d07,
  0x12000511, 0x0d170fad, 0x080119ad, 0x0f01056f,
  0x020b1033, 0x0e1c1e60, 0x0c121807, 0x0b1001be,
  0x02000634, 0x0f0d04ac, 0x1d063813, 0x05002214,
  // [2500]
  0x0b381011, 0x0c012112, 0x14060422, 0x0c040b6f,
  0x17020120, 0x0b100412, 0x0b0408af, 0x0c270412,
  0x12002121, 0x40182212, 0x0d052709, 0x161422bb,
  0x16272121, 0x12004021, 0x21031812, 0x43003821,
  // [2510]
  0x22184034, 0x0b220407, 0x05430809, 0x06190408,
  0x160c1208, 0x27000836, 0x04001733, 0x101814ac,
  0x16000b20, 0x0f002720, 0x030f0512, 0x040c1607,
  0x0d221412, 0x0400051f, 0x451218ce, 0x12450512,
  // [2520]
  0x0b0306ac, 0x40000b11, 0x0c45126f, 0x1e0e1c09,
  0x0d050112, 0x081d2121, 0x060b0321, 0x04000323,
  0x06191011, 0x0110066f, 0x21000c20, 0x1200181f,
  0x401d2121, 0x0b000422, 0x08020313, 0x06012207,
  // [2530]
  0x0f172221, 0x0f0d1907, 0x10270daf, 0x382110af,
  0x21000609, 0x45004312, 0x01032712, 0x100603a4,
  0x22000811, 0x050118be, 0x12001507, 0x18004008,
  0x01001522, 0x40000813, 0x27171612, 0x08001913,
  // [2540]
  0x06001512, 0x12454020, 0x1d401513, 0x10000311,
  0x06124511, 0x08211912, 0x10451211, 0x02030b12,
  0x020b1523, 0x0f0104af, 0x27012113, 0x1d0103bc,
  0x12221912, 0x40124520, 0x1d001510, 0x032721be,
  // [2550]
  0x01271912, 0x40001920, 0x401916bc, 0x03215133,
  0x0d082707, 0x00002742, 0x08001920, 0x16401daf,
  0x05032221, 0x060116a4, 0x221001af, 0x27080f12,
  0x02000b20, 0x0b001922, 0x45002720, 0x380f0521,
  // [2560]
  0x1c230e34, 0x27000b11, 0x1c231e33, 0x08052212,
  0x0f220522, 0x08000434, 0x22100bad, 0x05061913,
  0x01160522, 0x1d001920, 0x15004512, 0x08010521,
  0x0b002213, 0x0d010520, 0x401d10bb, 0x22054034,
  // [2570]
  0x08002713, 0x0f004521, 0x060227be, 0x044027af,
  0x0b401d6f, 0x0b0619ad, 0x27002111, 0x19022212,
  0x01081721, 0x380f1734, 0x12181412, 0x401018cf,
  0x380f0122, 0x01001220, 0x190d0f21, 0x0d271021,
  // [2580]
  0x0f002234, 0x0b0227ad, 0x08004007, 0x10021521,
  0x0b001420, 0x0d272221, 0x0b101621, 0x08401d6f,
  0x40161dad, 0x12180614, 0x081d406f, 0x19180160,
  0x19020514, 0x1e002302, 0x081d4022, 0x1d45406f,
  // [2590]
  0x45004023, 0x40004523, 0x18000811, 0x1d4015ad,
  0x2740456f, 0x45004033, 0x1d0c4060, 0x12164012,
  0x21182221, 0x17081412, 0x12401dac, 0x15000321,
  0x0d0f43ab, 0x04031912, 0x40000314, 0x0c120312,
  // [25a0]
  0x16000c20, 0x03154011, 0x18002222, 0x0d001012,
  0x16154512, 0x01100c10, 0x430327ad, 0x03151612,
  0x1d020112, 0x010503ac, 0x01003808, 0x16000f07,
  0x0b100209, 0x140121bc, 0x01161707, 0x0d002223,
  // [25b0]
  0x04222134, 0x14210422, 0x38140612, 0x210422be,
  0x04002135, 0x04271521, 0x271521be, 0x27140513,
  0x0c002220, 0x38221821, 0x17221d07, 0x22042123,
  0x38050412, 0x03042234, 0x050f0d13, 0x04402122,
  // [25c0]
  0x06401d12, 0x02030821, 0x18004535, 0x19270112,
  0x22000610, 0x121d40bc, 0x0f0b0d12, 0x12151913,
  0x05001407, 0x18004508, 0x100b19a4, 0x1d024021,
  0x12401d07, 0x1e1c23ad, 0x19041011, 0x38001912,
  // [25d0]
  0x0d401d12, 0x02030b07, 0x01101407, 0x14272112,
  0x14151612, 0x0c000d14, 0x45000621, 0x0c010602,
  0x03003807, 0x0d380512, 0x18124511, 0x08000423,
  0x05222723, 0x22271420, 0x06001511, 0x06080555,
  // [25e0]
  0x0c0d22af, 0x0b1d2708, 0x19211608, 0x0c454021,
  0x0d002221, 0x06000f07, 0x100b01ac, 0x0d030121,
  0x061910af, 0x161706bc, 0x0c020614, 0x0d0105a4,
  0x040108af, 0x03052720, 0x050b0107, 0x06001923,
  // [25f0]
  0x06190407, 0x03190c12, 0x40004521, 0x01030620,
  0x0c401dbe, 0x020f1021, 0x15041913, 0x21000434,
  0x100314bc, 0x010f2112, 0x0f1422cf, 0x0c1d2121,
  0x08000422, 0x1d0d0f21, 0x16041933, 0x17401d11,
  // [2600]
  0x12000509, 0x0f0d14cf, 0x38221434, 0x18140c12,
  0x142210af, 0x21001712, 0x19001607, 0x0c140422,
  0x024012bc, 0x450c1221, 0x05010f12, 0x0b0503bb,
  0x061d4012, 0x0b001414, 0x12180c20, 0x18124560,
  // [2610]
  0x23000e36, 0x221d0bac, 0x0f0d1807, 0x17001612,
  0x050108af, 0x100104ac, 0x21010860, 0x171d4021,
  0x0f002713, 0x0b140c60, 0x0c041613, 0x082701be,
  0x0b0206ad, 0x022216be, 0x0d0f0521, 0x22171612,
  // [2620]
  0x0c1d2712, 0x221d1621, 0x38001412, 0x45000f11,
  0x22161721, 0x16002235, 0x15171912, 0x062101af,
  0x14124521, 0x12451dbe, 0x06001820, 0x04451612,
  0x210d0512, 0x0c1d06ce, 0x08060112, 0x061701be,
  // [2630]
  0x430f22ac, 0x43120cac, 0x17001d20, 0x1d4540be,
  0x04000811, 0x0b021009, 0x0d00180b, 0x381827a4,
  0x1d00400d, 0x400c08ac, 0x17001412, 0x0c124560,
  0x17080d14, 0x270c10ad, 0x45000313, 0x0d101912,
  // [2640]
  0x17001813, 0x0f053821, 0x45031521, 0x080f0d21,
  0x0d0538ad, 0x080f1721, 0x0d053820, 0x27140b12,
  0x17041613, 0x1d404520, 0x380f08be, 0x16002120,
  0x0d190821, 0x0f0d4021, 0x401d4511, 0x040105a4,
  // [2650]
  0x0d3817af, 0x02100611, 0x16000108, 0x06001423,
  0x17142760, 0x10020607, 0x08001514, 0x191705ac,
  0x100c1d22, 0x02001723, 0x10000207, 0x010c15ad,
  0x1d1001be, 0x19050412, 0x16000509, 0x1d1201a4,
  // [2660]
  0x170d05be, 0x011d4012, 0x401d08bc, 0x0d21086f,
  0x0f002711, 0x0f380d07, 0x0b0205be, 0x211022be,
  0x04001902, 0x0d1d4007, 0x1c1e2309, 0x19211421,
  0x0d0f0814, 0x0b1014ac, 0x0b081012, 0x18001414,
  // [2670]
  0x40000d13, 0x06001433, 0x0b190212, 0x21001013,
  0x061021ad, 0x141922af, 0x05000836, 0x190801ac,
  0x23001e1f, 0x0227036f, 0x380f0c12, 0x190b2212,
  0x16002211, 0x06380fad, 0x273821ad, 0x27000320,
  // [2680]
  0x0b450112, 0x0b002713, 0x2204036f, 0x27002220,
  0x27220821, 0x10020107, 0x0b100307, 0x0f00181f,
  0x05450112, 0x0d040fad, 0x021922bc, 0x184022af,
  0x1d224513, 0x0f012709, 0x0f000c14, 0x032206ad,
  // [2690]
  0x0b02186f, 0x03170609, 0x03002722, 0x06003808,
  0x451d12bc, 0x0d060412, 0x05001711, 0x06382721,
  0x0f0138af, 0x03001934, 0x02080109, 0x100d0f55,
  0x40000521, 0x040c19ac, 0x0c0f1407, 0x020f0121,
  // [26a0]
  0x27052212, 0x01050d12, 0x16000c21, 0x12450c07,
  0x18124509, 0x40000812, 0x180f0dac, 0x04082920,
  0x12450d13, 0x051001ad, 0x03001822, 0x0b100523,
  0x06451212, 0x080201cf, 0x190b0407, 0x1d400cbe,
  // [26b0]
  0x050f01ac, 0x010b0612, 0x173801be, 0x12001020,
  0x17380322, 0x1d001020, 0x12061021, 0x010817af,
  0x1e000e34, 0x08161912, 0x22031d13, 0x0b4503bb,
  0x10041960, 0x101d4021, 0x121d4022, 0x16000311,
  // [26c0]
  0x08000d22, 0x050d0f09, 0x380d04bc, 0x451219af,
  0x121d1621, 0x16000511, 0x27211712, 0x15214023,
  0x080f0134, 0x0c004033, 0x010c1222, 0x0c0d01af,
  0x01000c23, 0x06082760, 0x08000f22, 0x03004523,
  // [26d0]
  0x38161912, 0x011d2707, 0x22000112, 0x06400134,
  0x38004007, 0x06004513, 0x1d1501e6, 0x10271421,
  0x0f0601ac, 0x06000334, 0x45431234, 0x0d00450d,
  0x17080514, 0x15000320, 0x0c0f4512, 0x270b0222,
  // [26e0]
  0x081d15bc, 0x0645126f, 0x05001507, 0x02101421,
  0x0117086f, 0x03001222, 0x0d170521, 0x380d0fa4,
  0x10060b55, 0x02385121, 0x01122709, 0x0d0f27af,
  0x10000122, 0x16001413, 0x100806ac, 0x05001722,
  // [26f0]
  0x2704196f, 0x04180ba4, 0x04010513, 0x0b1415ac,
  0x0f3810ac, 0x17020bad, 0x080f0dbe, 0x190b16ad,
  0x38000113, 0x141d18bc, 0x0f001207, 0x1d190207,
  0x0f380307, 0x17002210, 0x19181d12, 0x221d1813,
  // [2700]
  0x381604bb, 0x151629be, 0x19062707, 0x100b01af,
  0x0f430107, 0x0f0210af, 0x0b060313, 0x0d190f12,
  0x210f0c12, 0x02001021, 0x050104ac, 0x04031907,
  0x40450c6f, 0x0d041612, 0x01001021, 0x1d1915bc,
  // [2710]
  0x191522ac, 0x01041960, 0x041619ac, 0x03041921,
  0x160d1521, 0x45000b10, 0x0f124508, 0x10010308,
  0x40080134, 0x18001511, 0x19000d12, 0x0b002722,
  0x15000f20, 0x0b000411, 0x03041913, 0x08380d07,
  // [2720]
  0x45031560, 0x19210321, 0x38050607, 0x27210bbc,
  0x06004321, 0x04210634, 0x0b100334, 0x0b081860,
  0x400b04af, 0x0b003807, 0x17010812, 0x22000623,
  0x10001511, 0x0f180682, 0x06040f21, 0x1d0f1612,
  // [2730]
  0x10430112, 0x0f0522be, 0x1806386d, 0x40010334,
  0x100214af, 0x38000614, 0x181003be, 0x10003812,
  0x14001211, 0x0f0d04be, 0x100206ad, 0x0f2719af,
  0x401d1512, 0x22101521, 0x40001911, 0x12380602,
  // [2740]
  0x45041d12, 0x17270107, 0x1d0b0107, 0x03000108,
  0x05400107, 0x050f0d12, 0x0c030121, 0x020b1013,
  0x02061009, 0x06002111, 0x22002921, 0x03120c07,
  0x014338ad, 0x27000213, 0x451202ad, 0x051901ac,
  // [2750]
  0x0d062712, 0x0c1014bb, 0x17001d11, 0x08380607,
  0x18052221, 0x401705bc, 0x10062709, 0x01000f09,
  0x173805ac, 0x22000f07, 0x220f0521, 0x010f2107,
  0x22082721, 0x03001235, 0x08020112, 0x1800121d,
  // [2760]
  0x03381412, 0x0c121d07, 0x061d0120, 0x02270160,
  0x38000420, 0x27222121, 0x014327bb, 0x14001814,
  0x1d22216f, 0x45041612, 0x270521be, 0x0d380112,
  0x1d190407, 0x270f21be, 0x041903ad, 0x21191523,
  // [2770]
  0x15041922, 0x05060123, 0x03100b13, 0x1843216f,
  0x430217ce, 0x01083820, 0x031d4023, 0x0c064523,
  0x12222707, 0x060110ac, 0x18004334, 0x1d452134,
  0x05381733, 0x0622216f, 0x03004022, 0x012227ad,
  // [2780]
  0x05000822, 0x00001442, 0x27000512, 0x03062707,
  0x190d01bb, 0x0d1808ac, 0x03001408, 0x19030607,
  0x10040612, 0x180b04bb, 0x15080121, 0x1d222712,
  0x01190612, 0x380419a4, 0x434019ad, 0x04000507,
  // [2790]
  0x15001711, 0x0d082121, 0x0d220834, 0x22151612,
  0x05004307, 0x0b1804ad, 0x451d40af, 0x45000d22,
  0x061904ad, 0x0d270111, 0x011014ac, 0x16001435,
  0x0119045e, 0x191d0107, 0x141516bc, 0x01151712,
  // [27a0]
  0x06010307, 0x12401d13, 0x02100b60, 0x0f380509,
  0x06224512, 0x0b1401bc, 0x22000322, 0x08001021,
  0x1c000e33, 0x171d0cbc, 0x04000122, 0x054301af,
  0x15450c20, 0x06012112, 0x38174521, 0x19272921,
  // [27b0]
  0x01082122, 0x120f18bb, 0x06001508, 0x06150cac,
  0x190301af, 0x18001222, 0x0f001823, 0x45180f21,
  0x450c1520, 0x19002134, 0x03061921, 0x0b0218af,
  0x05000c11, 0x06100112, 0x14060320, 0x05004334,
  // [27c0]
  0x030c4511, 0x0e001e02, 0x0c001208, 0x38150309,
  0x0c1d1207, 0x0b020314, 0x03000c13, 0x04000f22,
  0x01001920, 0x161245ac, 0x030d0821, 0x120b1020,
  0x050b02a4, 0x19041009, 0x0b190608, 0x21050d12,
  // [27d0]
  0x380f1807, 0x43080111, 0x0f013809, 0x06004023,
  0x0b102212, 0x082206bc, 0x06181a12, 0x0d050f09,
  0x0d002211, 0x03000807, 0x22000c14, 0x401d4522,
  0x401d4520, 0x40002221, 0x0d270f21, 0x19000114,
  // [27e0]
  0x01151621, 0x12382707, 0x43001821, 0x43001811,
  0x14001711, 0x010306af, 0x40004520, 0x010d0f09,
  0x384514ac, 0x0b161522, 0x04080113, 0x15170fbb,
  0x040127bc, 0x19060412, 0x22001713, 0x14020b20,
  // [27f0]
  0x0c000822, 0x401706ac, 0x011027ad, 0x22272912,
  0x17000411, 0x08401813, 0x1d210821, 0x01002122,
  0x0610026f, 0x15000608, 0x1d002723, 0x19151660,
  0x08401d22, 0x19451212, 0x1d274013, 0x04051908,

  // [2800]
  0x21051912, 0x03001008, 0x10080212, 0x400419ad,
  0x0d050107, 0x0c001409, 0x40154521, 0x21180120,
  0x16381912, 0x150d16bc, 0x0d160813, 0x10151621,
  0x160d1860, 0x15101607, 0x050b0fac, 0x0c401d60,
  // [2810]
  0x100b1dac, 0x17100213, 0x0d0f1614, 0x16121507,
  0x161d456d, 0x10154509, 0x08011760, 0x04030155,
  0x0d0b0822, 0x06270560, 0x21001814, 0x27001012,
  0x0c221d12, 0x03061722, 0x430f0d11, 0x06382707,
  // [2820]
  0x21031912, 0x27004020, 0x01194508, 0x030506a4,
  0x02001913, 0x10212708, 0x050f0d23, 0x380515bc,
  0x1d1404be, 0x15004022, 0x170f0121, 0x401612ad,
  0x1d400f14, 0x01002221, 0x27222133, 0x031d0421,
  // [2830]
  0x10212782, 0x16002220, 0x1d212733, 0x27011912,
  0x171d4020, 0x14011912, 0x0000380a, 0x380c1721,
  0x080f3823, 0x43271911, 0x1d161512, 0x0c0106ac,
  0x10004020, 0x0b2714bb, 0x02100512, 0x02004011,
  // [2840]
  0x080d0f08, 0x014021ac, 0x0b080212, 0x041d4060,
  0x081419ad, 0x041d2760, 0x0b000112, 0x06001d13,
  0x18031020, 0x06401d07, 0x100b01be, 0x0f001d11,
  0x27430412, 0x06170107, 0x02030808, 0x270201af,
  // [2850]
  0x12011da4, 0x0b000210, 0x231e0ead, 0x210f0121,
  0x08002222, 0x10450609, 0x020627af, 0x0d0f1812,
  0x1d211407, 0x06000f08, 0x0c004020, 0x16143820,
  0x03100107, 0x0d002111, 0x19270612, 0x0c150f12,
  // [2860]
  0x010b026f, 0x0d081813, 0x12174522, 0x38060107,
  0x12004022, 0x020508ac, 0x08000607, 0x18063812,
  0x0d380522, 0x0f100d13, 0x401d4514, 0x120d1807,
  0x10020b21, 0x380d0f6f, 0x010627af, 0x050108ac,
  // [2870]
  0x15270412, 0x1e0e23bc, 0x061519ad, 0x01082182,
  0x020108bc, 0x12001413, 0x12454060, 0x02000d14,
  0x01080512, 0x03000109, 0x0b0203be, 0x021027af,
  0x0b1d16af, 0x0f080daf, 0x194540ad, 0x050b02ad,
  // [2880]
  0x38000535, 0x12191dac, 0x38191007, 0x45121921,
  0x0d192707, 0x19172107, 0x172716af, 0x18380122,
  0x14030613, 0x27011812, 0x08004507, 0x270d0f6f,
  0x050f0107, 0x03140155, 0x100301a4, 0x15101612,
  // [2890]
  0x16150112, 0x020b1014, 0x43003814, 0x17000108,
  0x211d40bc, 0x08030611, 0x1d271812, 0x020c15ac,
  0x05451220, 0x03161abe, 0x0c170807, 0x15160134,
  0x05000b35, 0x21000c12, 0x0b003820, 0x01001423,
  // [28a0]
  0x21450c21, 0x10020bbc, 0x02170121, 0x401d0121,
  0x12001810, 0x1d170cbe, 0x18271912, 0x1d041821,
  0x100119af, 0x271622cf, 0x230e1e11, 0x06012221,
  0x400d0509, 0x0f1d4012, 0x030f01a4, 0x17020b23,
  // [28b0]
  0x22100dbc, 0x0f210414, 0x27001513, 0x400c1d12,
  0x12002734, 0x12401d09, 0x17080534, 0x161801cf,
  0x1d170533, 0x0d1d0c09, 0x0f001922, 0x401d0faf,
  0x21000f08, 0x03001020, 0x04002723, 0x230e1e23,
  // [28c0]
  0x01000f12, 0x12220134, 0x1d4003be, 0x15002713,
  0x174540bc, 0x0f030d12, 0x0c191712, 0x380d01ad,
  0x450518ac, 0x0d081708, 0x031019ac, 0x050138be,
  0x18050d12, 0x100d2207, 0x230e1ea4, 0x00003742,
  // [28d0]
  0x38030607, 0x17211420, 0x17002223, 0x081d27bb,
  0x180f0d22, 0x21172221, 0x16222160, 0x1d4512be,
  0x17224012, 0x43050107, 0x40140b12, 0x0c224021,
  0x081904be, 0x01212221, 0x10040822, 0x19080460,
  // [28e0]
  0x1d404511, 0x0b050209, 0x21000611, 0x18002707,
  0x0d0f1412, 0x0d002207, 0x080b0107, 0x020b22be,
  0x0b161055, 0x020c2708, 0x1d0c40ad, 0x21041920,
  0x18081521, 0x1d000822, 0x140b0260, 0x15000811,
  // [28f0]
  0x031506a4, 0x45120821, 0x0c050607, 0x0c004509,
  0x12060c13, 0x45010512, 0x1d0418af, 0x401d1011,
  0x0b000320, 0x21030112, 0x140601be, 0x38001810,
  0x04380521, 0x100406ad, 0x080d1507, 0x1c1e2360,
  // [2900]
  0x050d18ba, 0x080315af, 0x041d1607, 0x080c06bc,
  0x08004512, 0x151d4560, 0x45122112, 0x07002310,
  0x23003709, 0x400f0d07, 0x45161521, 0x162721bc,
  0x03150421, 0x190415ad, 0x08004521, 0x150f3820,
  // [2910]
  0x0f150855, 0x0f001512, 0x22000508, 0x05000f11,
  0x190110ac, 0x19032112, 0x0f000d36, 0x1d194555,
  0x081927bb, 0x16380f21, 0x0300014a, 0x14000235,
  0x16380821, 0x0d000520, 0x1e1c23a4, 0x010b0208,
  // [2920]
  0x15000513, 0x231e1ccf, 0x10182112, 0x43170112,
  0x1d270c08, 0x1d124533, 0x08001512, 0x06451220,
  0x0c001922, 0x06173812, 0x03450c12, 0x21011760,
  0x0f0d0855, 0x191051af, 0x121d4509, 0x40061d12,
  // [2930]
  0x210d0f12, 0x0c162708, 0x27100b12, 0x060f2707,
  0x0c004009, 0x1d010b07, 0x19060323, 0x272221af,
  0x45121407, 0x052721af, 0x100602af, 0x0d051009,
  0x04002708, 0x1400271d, 0x0d270814, 0x271621be,
  // [2940]
  0x220427be, 0x1c1e0e09, 0x17142713, 0x1d401207,
  0x121d4007, 0x0117196f, 0x19004513, 0x06191021,
  0x060b10a4, 0x06001408, 0x0e1e2355, 0x0f0106ad,
  0x08000608, 0x22001822, 0x05081721, 0x100306be,
  // [2950]
  0x0300381d, 0x06002709, 0x06001821, 0x27100621,
  0x06002714, 0x180b1022, 0x27210412, 0x102218ad,
  0x011d2712, 0x0d0506a7, 0x38011812, 0x01080323,
  0x011903bc, 0x06221812, 0x04001633, 0x0d000509,
  // [2960]
  0x40151dad, 0x19030211, 0x0d170821, 0x451216ad,
  0x18000813, 0x16000423, 0x04211621, 0x0b021907,
  0x0000100a, 0x0d170109, 0x01381d07, 0x12001509,
  0x38080412, 0x40451d21, 0x010f1714, 0x38001d07,
  // [2970]
  0x01004020, 0x050d3821, 0x010317be, 0x03191007,
  0x04000309, 0x401d2721, 0x16051912, 0x0b0203ad,
  0x0d000813, 0x22061912, 0x17000208, 0x0f161012,
  0x0b020312, 0x38000520, 0x19040611, 0x380d0108,
  // [2980]
  0x401d02af, 0x27041660, 0x12451d23, 0x08170512,
  0x041019ab, 0x03001910, 0x380622bc, 0x180b1912,
  0x45001533, 0x05002211, 0x45160412, 0x05271812,
  0x10000314, 0x12404521, 0x3827226f, 0x020b4021,
  // [2990]
  0x1d001614, 0x19100d13, 0x190f0d13, 0x12454013,
  0x192227a4, 0x121845ad, 0x05004511, 0x0e1e23be,
  0x050601ad, 0x22211912, 0x011d1912, 0x011219ac,
  0x0c401d6f, 0x04401dbc, 0x02011921, 0x02190121,
  // [29a0]
  0x17401912, 0x01030607, 0x02124513, 0x06001214,
  0x0f170412, 0x10001d11, 0x40451d14, 0x02380508,
  0x01004012, 0x27162222, 0x18001a35, 0x170d2721,
  0x0c1218ac, 0x101d0413, 0x0c180407, 0x010c1208,
  // [29b0]
  0x0c1245be, 0x1d001534, 0x151d2707, 0x1016046f,
  0x40061033, 0x16451213, 0x161d40a4, 0x1d271512,
  0x38170808, 0x08002720, 0x02005113, 0x02000423,
  0x27002211, 0x15002723, 0x21001621, 0x18000d11,
  // [29c0]
  0x38001913, 0x15001608, 0x030806be, 0x40161512,
  0x18001d08, 0x0b181012, 0x0f221421, 0x27100612,
  0x02100dbb, 0x06002220, 0x0f042121, 0x0d210812,
  0x011d0c07, 0x45120121, 0x0b1243ad, 0x041427be,
  // [29d0]
  0x12450134, 0x05001410, 0x05150cbb, 0x21004312,
  0x190c2212, 0x1d000b12, 0x14004313, 0x38182212,
  0x080201bc, 0x01060507, 0x10001707, 0x162219bb,
  0x05010814, 0x10000809, 0x03010607, 0x180b0214,
  // [29e0]
  0x1003146d, 0x17083823, 0x38170809, 0x38221909,
  0x45000c35, 0x1d000507, 0x21000134, 0x08003834,
  0x45040c22, 0x0b0c1613, 0x210f2208, 0x06081021,
  0x08271712, 0x0d000c13, 0x0f1d0c21, 0x0e231c20,
  // [29f0]
  0x0f380109, 0x0c1605af, 0x22080512, 0x05001808,
  0x14001513, 0x16013812, 0x1d190412, 0x0c021009,
  0x05120c21, 0x1d0c1521, 0x16041511, 0x0b0110af,
  0x01100b6f, 0x1d151412, 0x45181207, 0x02050113,
  // [2a00]
  0x010d08cf, 0x0f050334, 0x081d0407, 0x40001522,
  0x160121ad, 0x10000c13, 0x27401d20, 0x0d0f3833,
  0x213822ad, 0x08031912, 0x18050621, 0x0d010807,
  0x1d120cbe, 0x121d4011, 0x120218ad, 0x080f1621,
  // [2a10]
  0x451916ad, 0x0212451f, 0x12450c6f, 0x23001e34,
  0x1d0c1807, 0x10030607, 0x02001812, 0x0f380113,
  0x02082211, 0x17001409, 0x190b16ba, 0x14190420,
  0x01190321, 0x14005113, 0x0d001914, 0x17000114,
  // [2a20]
  0x0b210612, 0x0b001712, 0x19053812, 0x10021512,
  0x14061012, 0x054017ad, 0x02221011, 0x45401d60,
  0x451d1655, 0x023803ac, 0x08003814, 0x05060cac,
  0x06100255, 0x19030da4, 0x02100b6f, 0x02000112,
  // [2a30]
  0x12451d12, 0x03192212, 0x08191412, 0x1d0c1812,
  0x0f0d1913, 0x17000c13, 0x061d18af, 0x16002213,
  0x161419bc, 0x01051707, 0x051706ad, 0x06001622,
  0x030801ad, 0x15000d12, 0x141922bc, 0x0f004507,
  // [2a40]
  0x45122221, 0x040d1460, 0x40124523, 0x160d0622,
  0x04000621, 0x38050fbc, 0x0b001913, 0x15000408,
  0x12000520, 0x14000f1f, 0x271d1912, 0x060104ad,
  0x05170813, 0x150c0f12, 0x17000f13, 0x02001022,
  // [2a50]
  0x0c1d02a4, 0x1d050108, 0x18450d09, 0x010c06a4,
  0x0c000313, 0x27160612, 0x010c0607, 0x041716bb,
  0x06101812, 0x00000215, 0x0d0821bc, 0x161406ac,
  0x38080112, 0x1c1e3712, 0x161d4082, 0x0c1d2721,
  // [2a60]
  0x0f0d01ac, 0x0d0401ac, 0x38010560, 0x17010360,
  0x19400b23, 0x12170612, 0x1d380112, 0x010516bc,
  0x081601ac, 0x0b020134, 0x380d2121, 0x0d004311,
  0x1d02056f, 0x38450112, 0x15271dbe, 0x14001908,
  // [2a70]
  0x03041982, 0x270f14bb, 0x10221421, 0x0b0c1012,
  0x16080f08, 0x020b15ad, 0x011927bc, 0x122227a4,
  0x22001708, 0x40451dac, 0x081d2112, 0x1d270c12,
  0x1416156f, 0x050108ad, 0x15050b09, 0x0d190455,
  // [2a80]
  0x060419ad, 0x17150321, 0x17000f09, 0x380f0d14,
  0x04161721, 0x15272921, 0x080601af, 0x05380107,
  0x02030bbc, 0x27001d23, 0x051538be, 0x170403ac,
  0x010f1dac, 0x22212912, 0x0e1e2308, 0x02032212,
  // [2a90]
  0x10190407, 0x45022260, 0x19271422, 0x0f381909,
  0x190440af, 0x15002721, 0x10001914, 0x18004313,
  0x0f004012, 0x0d0103ad, 0x150b1013, 0x400614ad,
  0x22270d12, 0x1d160107, 0x0d1d05a4, 0x190421ad,
  // [2aa0]
  0x021d03bb, 0x100604ad, 0x1d101507, 0x15030608,
  0x21171abe, 0x02030621, 0x21401d21, 0x221704ac,
  0x21000320, 0x050f3821, 0x22401d6f, 0x0f001508,
  0x1d001807, 0x06191812, 0x03180860, 0x0b100223,
  // [2ab0]
  0x0b191012, 0x080d386f, 0x0b0201ac, 0x140322af,
  0x020501ad, 0x0f3840be, 0x100508a4, 0x030b1020,
  0x211427be, 0x19040207, 0x45190c07, 0x1d000f12,
  0x0f0527af, 0x06003807, 0x02002113, 0x06002210,
  // [2ac0]
  0x18001422, 0x02001002, 0x171027be, 0x1d2715ad,
  0x0f430dad, 0x0b061421, 0x19271d07, 0x08000f13,
  0x21001723, 0x210d27af, 0x14191021, 0x1d122107,
  0x01172209, 0x02221512, 0x19171521, 0x0b184021,
  // [2ad0]
  0x0c15066f, 0x141722ad, 0x08380f21, 0x1645126f,
  0x0b100321, 0x080d1821, 0x01170c07, 0x12002114,
  0x40161511, 0x17210121, 0x38000108, 0x1d272221,
  0x15001607, 0x40124560, 0x0b061007, 0x18450f12,
  // [2ae0]
  0x011d2207, 0x100622af, 0x12000433, 0x22041dac,
  0x15002722, 0x14060809, 0x1d060809, 0x12000c22,
  0x1d454009, 0x40160d12, 0x010803be, 0x14000c20,
  0x14000c14, 0x08002208, 0x06010813, 0x381d1722,
  // [2af0]
  0x040b0260, 0x12000814, 0x18000b22, 0x38010612,
  0x0c161008, 0x273819be, 0x27081713, 0x0500180b,
  0x15003812, 0x0c381621, 0x19141612, 0x19001423,
  0x1d001412, 0x012705bc, 0x03451207, 0x010f0d22,
  // [2b00]
  0x18012212, 0x101619af, 0x121d0c13, 0x12164509,
  0x142701bc, 0x150b1921, 0x080d0f07, 0x1e00231d,
  0x060b0c11, 0x01171607, 0x01140609, 0x10030b21,
  0x1d010607, 0x100c0f11, 0x01051022, 0x22100622,
  // [2b10]
  0x06190121, 0x22042112, 0x19180412, 0x0c220421,
  0x0d0f08a4, 0x03190420, 0x40141d60, 0x10060321,
  0x02272222, 0x27001633, 0x150106ac, 0x083818be,
  0x38052721, 0x010b14ac, 0x03010612, 0x0c1d04ac,
  // [2b20]
  0x40061d08, 0x02000f11, 0x06180812, 0x380c06ac,
  0x161906ad, 0x43000113, 0x03192221, 0x06002222,
  0x17000113, 0x03060811, 0x21050809, 0x0d001208,
  0x1d060820, 0x190c1dbb, 0x01004320, 0x01060bbc,
  // [2b30]
  0x0f3806be, 0x19141511, 0x270106bc, 0x04020b6f,
  0x222117ad, 0x0c004013, 0x0d1d0112, 0x38000635,
  0x45161d12, 0x060d01a4, 0x180103ad, 0x0b1d0121,
  0x0b400c11, 0x19000807, 0x050f14cf, 0x01000414,
  // [2b40]
  0x08451221, 0x38191022, 0x01052112, 0x03001d13,
  0x0b402221, 0x011d22af, 0x0c451821, 0x220b0607,
  0x101427be, 0x451222ad, 0x45221822, 0x27032221,
  0x27062213, 0x15001636, 0x17161522, 0x10002234,
  // [2b50]
  0x0d004513, 0x03272121, 0x220106ad, 0x271d22bc,
  0x27400221, 0x010d1207, 0x04190812, 0x16052712,
  0x17081d22, 0x05190612, 0x051708cf, 0x12000b11,
  0x06180512, 0x05012221, 0x40451212, 0x05040221,
  // [2b60]
  0x0c001520, 0x0f001611, 0x170f0d21, 0x451d27ad,
  0x162704bb, 0x0c0805bb, 0x02002711, 0x16150412,
  0x12160407, 0x0b012107, 0x21082712, 0x38050f21,
  0x0527216f, 0x170c2107, 0x40211dbe, 0x05180d12,
  // [2b70]
  0x01081521, 0x0f0105ad, 0x08061912, 0x21270414,
  0x10060bad, 0x060b1012, 0x0d000b11, 0x04001207,
  0x27170808, 0x17183811, 0x380f2712, 0x0d002220,
  0x27181912, 0x45181212, 0x120b0d22, 0x12000621,
  // [2b80]
  0x0d0508bb, 0x0d0806af, 0x0d001821, 0x04222712,
  0x011d1707, 0x121d1912, 0x45011407, 0x0d0f1711,
  0x150c1609, 0x05381511, 0x18030134, 0x211d0b12,
  0x06033860, 0x02000d35, 0x0d1d08ac, 0x03141807,
  // [2b90]
  0x01182711, 0x01060513, 0x0d000135, 0x05192121,
  0x10010813, 0x0c000b14, 0x1001026f, 0x10401d21,
  0x38000135, 0x122721bb, 0x19271521, 0x181921ce,
  0x04080121, 0x06101821, 0x101d21af, 0x401408af,
  // [2ba0]
  0x191d0821, 0x1d4540ad, 0x171d27bb, 0x08002121,
  0x1c1e0e33, 0x08001914, 0x27000820, 0x38002222,
  0x1d0517bc, 0x05170822, 0x05011713, 0x080f2712,
  0x06012709, 0x45010509, 0x10001435, 0x040105af,
  // [2bb0]
  0x0b101413, 0x03011421, 0x020310bb, 0x180f0d09,
  0x19012111, 0x40000c20, 0x0300271f, 0x0c450d6d,
  0x19030521, 0x0b0251af, 0x02142707, 0x22000520,
  0x381d0f12, 0x12000c20, 0x010d1410, 0x45001420,
  // [2bc0]
  0x0f380d11, 0x060103bb, 0x0c1519af, 0x04001508,
  0x050603af, 0x1d4519ad, 0x1404226f, 0x143822be,
  0x050b0213, 0x17272260, 0x27000d14, 0x221404be,
  0x27142223, 0x120645bb, 0x221945ad, 0x08010660,
  // [2bd0]
  0x01031912, 0x02000334, 0x14060112, 0x02061460,
  0x150c12ad, 0x15000111, 0x45161512, 0x401d1260,
  0x010327ac, 0x450c1912, 0x45081907, 0x141018af,
  0x030201a4, 0x02102708, 0x401d03ad, 0x0d272121,
  // [2be0]
  0x274021be, 0x0312456f, 0x152703be, 0x14020360,
  0x27004508, 0x1d012713, 0x16140607, 0x0f010860,
  0x45100b08, 0x0b104007, 0x010b10af, 0x141906af,
  0x020b14ad, 0x38450dac, 0x450c0f33, 0x170c4508,
  // [2bf0]
  0x272221cf, 0x27001522, 0x061827af, 0x14121612,
  0x0f0515cf, 0x27160c13, 0x050d2760, 0x270d21bb,
  0x0b001721, 0x0f1d1421, 0x231e0ea4, 0x0c1d4009,
  0x19401614, 0x43030607, 0x02004022, 0x1d0f0812,

  // [2c00]
  0x1d080f12, 0x430f2207, 0x190240ac, 0x0c0f1421,
  0x010805bb, 0x08000520, 0x12382112, 0x14005135,
  0x05080c13, 0x43010d12, 0x21150812, 0x12271921,
  0x451d10ac, 0x271d086f, 0x021045af, 0x0c120112,
  // [2c10]
  0x12190134, 0x1d1908af, 0x22001d13, 0x40001613,
  0x10021911, 0x0b142720, 0x17081812, 0x22271421,
  0x10190821, 0x08192721, 0x180d45bc, 0x0f0d14ba,
  0x06271434, 0x15162712, 0x012714bc, 0x08401912,
  // [2c20]
  0x270314bc, 0x1d4540bc, 0x0b212721, 0x0f0608ad,
  0x080f0612, 0x01102709, 0x061d08a4, 0x18450d13,
  0x07002312, 0x0b001820, 0x01084507, 0x06001722,
  0x38001014, 0x45001810, 0x451218a4, 0x0d081507,
  // [2c30]
  0x01000509, 0x03011aaf, 0x0c012912, 0x18000807,
  0x22000622, 0x05100bad, 0x02270108, 0x010b0307,
  0x45000408, 0x180c22af, 0x0f032255, 0x08181612,
  0x060b1412, 0x0d0b0460, };

COMPILE_ASSERT(11326 < (1 << 16), k_indirectbits_too_small);

extern const cld::CLDTableSummary kQuadTable_obj = {
  kQuadTable,
  kQuadTableInd,
  kQuadTableSize,
  arraysize(kQuadTableInd),
  kQuadTableKeyMask,
  kQuadTableBuildDate,
};

// End of generated tables
